--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: books; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE books (
    id integer NOT NULL,
    volume_id smallint NOT NULL,
    book_title character varying(22) DEFAULT ''::character varying NOT NULL,
    book_long_title character varying(59) DEFAULT ''::character varying NOT NULL,
    book_subtitle character varying(80) DEFAULT ''::character varying NOT NULL,
    book_short_title character varying(8) DEFAULT ''::character varying NOT NULL,
    book_lds_url character varying(6) DEFAULT ''::character varying NOT NULL
);


--
-- Name: chapters; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE chapters (
    id integer NOT NULL,
    book_id integer NOT NULL,
    chapter_number smallint NOT NULL
);


--
-- Name: pilcrow; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE pilcrow (
    verse_id integer
);


--
-- Name: verses; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE verses (
    id integer NOT NULL,
    chapter_id smallint NOT NULL,
    verse_number smallint NOT NULL,
    scripture_text text DEFAULT ''::text NOT NULL
);


--
-- Name: volumes; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE volumes (
    id integer NOT NULL,
    volume_title character varying(22) DEFAULT ''::character varying NOT NULL,
    volume_long_title character varying(26) DEFAULT ''::character varying NOT NULL,
    volume_subtitle character varying(36) DEFAULT ''::character varying NOT NULL,
    volume_short_title character varying(3) DEFAULT ''::character varying NOT NULL,
    volume_lds_url character varying(3) DEFAULT ''::character varying NOT NULL
);


--
-- Name: scriptures; Type: VIEW; Schema: public; Owner: -
--

CREATE VIEW scriptures AS
    SELECT volumes.id AS volume_id, books.id AS book_id, chapters.id AS chapter_id, verses.id AS verse_id, volumes.volume_title, books.book_title, volumes.volume_long_title, books.book_long_title, volumes.volume_subtitle, books.book_subtitle, volumes.volume_short_title, books.book_short_title, volumes.volume_lds_url, books.book_lds_url, chapters.chapter_number, verses.verse_number, verses.scripture_text, pg_catalog.concat(books.book_title, ' ', chapters.chapter_number, ':', verses.verse_number) AS verse_title, pg_catalog.concat(books.book_short_title, ' ', chapters.chapter_number, ':', verses.verse_number) AS verse_short_title FROM (((volumes JOIN books ON ((books.volume_id = volumes.id))) JOIN chapters ON ((chapters.book_id = books.id))) JOIN verses ON ((verses.chapter_id = chapters.id))) ORDER BY volumes.id, books.id, chapters.id, verses.id;


--
-- Name: updates; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE updates (
    scripture_text text
);


--
-- Data for Name: books; Type: TABLE DATA; Schema: public; Owner: -
--

COPY books (id, volume_id, book_title, book_long_title, book_subtitle, book_short_title, book_lds_url) FROM stdin;
1	1	Genesis	The First Book of Moses called Genesis		Gen.	gen
2	1	Exodus	The Second Book of Moses called Exodus		Ex.	ex
3	1	Leviticus	The Third Book of Moses called Leviticus		Lev.	lev
4	1	Numbers	The Fourth Book of Moses called Numbers		Num.	num
5	1	Deuteronomy	The Fifth Book of Moses called Deuteronomy		Deut.	deut
6	1	Joshua	The Book of Joshua		Josh.	josh
7	1	Judges	The Book of Judges		Judg.	judg
8	1	Ruth	The Book of Ruth		Ruth	ruth
9	1	1 Samuel	The First Book of Samuel	Otherwise called the First Book of the Kings	1 Sam.	1-sam
10	1	2 Samuel	The Second Book of Samuel	Otherwise called the Second Book of the Kings	2 Sam.	2-sam
11	1	1 Kings	The First Book of the Kings	Commonly called the Third Book of the Kings	1 Kgs.	1-kgs
12	1	2 Kings	The Second Book of the King	Commonly called the Fourth Book of the Kings	2 Kgs.	2-kgs
13	1	1 Chronicles	The First Book of the Chronicles		1 Chr.	1-chr
14	1	2 Chronicles	The Second Book of the Chronicles		2 Chr.	2-chr
15	1	Ezra	Ezra		Ezra	ezra
16	1	Nehemiah	The Book of Nehemiah		Neh.	neh
17	1	Esther	The Book of Esther		Esth.	esth
18	1	Job	The Book of Job		Job	job
19	1	Psalms	The Book of Psalms		Ps.	ps
20	1	Proverbs	The Proverbs		Prov.	prov
21	1	Ecclesiastes	Ecclesiastes or, The Preacher		Eccl.	eccl
22	1	Solomon's Song	The Song of Solomon		Song.	song
23	1	Isaiah	The Book of the Prophet Isaiah		Isa.	isa
24	1	Jeremiah	The Book of the Prophet Jeremiah		Jer.	jer
25	1	Lamentations	The Lamentations of Jeremiah		Lam.	lam
26	1	Ezekiel	The Book of the Prophet Ezekiel		Ezek.	ezek
27	1	Daniel	The Book of Daniel		Dan.	dan
28	1	Hosea	Hosea		Hosea	hosea
29	1	Joel	Joel		Joel	joel
30	1	Amos	Amos		Amos	amos
31	1	Obadiah	Obadiah		Obad.	obad
32	1	Jonah	Jonah		Jonah	jonah
33	1	Micah	Micah		Micah	micah
34	1	Nahum	Nahum		Nahum	nahum
35	1	Habakkuk	Habakkuk		Hab.	hab
36	1	Zephaniah	Zephaniah		Zeph.	zeph
37	1	Haggai	Haggai		Hag.	hag
38	1	Zechariah	Zechariah		Zech.	zech
39	1	Malachi	Malachi		Mal.	mal
40	2	Matthew	The Gospel According to St Matthew		Matt.	matt
41	2	Mark	The Gospel According to St Mark		Mark	mark
42	2	Luke	The Gospel According to St Luke		Luke	luke
43	2	John	The Gospel According to St John		John	john
44	2	Acts	The Acts of the Apostles		Acts	acts
45	2	Romans	The Epistle of Paul the Apostle to the Romans		Rom.	rom
46	2	1 Corinthians	The First Epistle of Paul the Apostle to the Corinthians		1 Cor.	1-cor
47	2	2 Corinthians	The Second Epistle of Paul the Apostle to the Corinthians		2 Cor.	2-cor
48	2	Galatians	The Epistle of Paul the Apostle to the Galatians		Gal.	gal
49	2	Ephesians	The Epistle of Paul the Apostle to the Ephesians		Eph.	eph
50	2	Philippians	The Epistle of Paul the Apostle to the Philippians		Philip.	philip
51	2	Colossians	The Epistle of Paul the Apostle to the Colossians		Col.	col
52	2	1 Thessalonians	The First Epistle of Paul the Apostle to the Thessalonians		1 Thes.	1-thes
53	2	2 Thessalonians	The Second Epistle of Paul the Apostle to the Thessalonians		2 Thes.	2-thes
54	2	1 Timothy	The First Epistle of Paul the Apostle to Timothy		1 Tim.	1-tim
55	2	2 Timothy	The Second Epistle of Paul the Apostle to Timothy		2 Tim.	2-tim
56	2	Titus	The Epistle of Paul to Titus		Titus	titus
57	2	Philemon	The Epistle of Paul to Philemon		Philem.	philem
58	2	Hebrews	The Epistle of Paul to the Hebrews		Heb.	heb
59	2	James	The General Epistle of James		James	james
60	2	1 Peter	The First Epistle General of Peter		1 Pet.	1-pet
61	2	2 Peter	The Second Epistle General of Peter		2 Pet.	2-pet
62	2	1 John	The First Epistle General of John		1 Jn.	1-jn
63	2	2 John	The Second Epistle of John		2 Jn.	2-jn
64	2	3 John	The Third Epistle of John		3 Jn.	3-jn
65	2	Jude	The General Epistle of Jude		Jude	jude
66	2	Revelation	The Revelation of St John the Divine		Rev.	rev
67	3	1 Nephi	The First Book of Nephi	His Reign and Ministry	1 Ne.	1-ne
68	3	2 Nephi	The Second Book of Nephi		2 Ne.	2-ne
69	3	Jacob	The Book of Jacob	The Brother of Nephi	Jacob	jacob
70	3	Enos	The Book of Enos		Enos	enos
71	3	Jarom	The Book of Jarom		Jarom	jarom
72	3	Omni	The Book of Omni		Omni	omni
73	3	Words of Mormon	Words of Mormon		W of M	w-of-m
74	3	Mosiah	The Book of Mosiah		Mosiah	mosiah
75	3	Alma	The Book of Alma	The Son of Alma	Alma	alma
76	3	Helaman	The Book of Helaman		Hel.	hel
77	3	3 Nephi	The Third Book of Nephi	The Book of Nephi\nThe Son of Nephi, who was the Son of Helaman	3 Ne.	3-ne
78	3	4 Nephi	The Fourth Book of Nephi	The Book of Nephi\r\nWho is the son of Nephi, one of the disciples of Jesus Christ	4 Ne.	4-ne
79	3	Mormon	The Book of Mormon		Morm.	morm
80	3	Ether	The Book of Ether		Ether	ether
81	3	Moroni	The Book of Moroni		Moro.	moro
82	4	Doctrine and Covenants	The Doctrine and Covenants	of the Church of Jesus Christ of Latter-day Saints	D&C	dc
83	5	Moses	Selections from the Book of Moses		Moses	moses
84	5	Abraham	The Book of Abraham	Translated from the papyrus, by Joseph Smith	Abr.	abr
85	5	Joseph Smith--Matthew	Joseph Smith--Matthew		JS-M	js-m
86	5	Joseph Smith--History	Joseph Smith--History	Extracts from The History of Joseph Smith, the Prophet	JS-H	js-h
87	5	Articles of Faith	The Articles of Faith	Of The Church of Jesus Christ of Latter-day Saints	A of F	a-of-f
\.


--
-- Data for Name: chapters; Type: TABLE DATA; Schema: public; Owner: -
--

COPY chapters (id, book_id, chapter_number) FROM stdin;
1	1	1
2	1	2
3	1	3
4	1	4
5	1	5
6	1	6
7	1	7
8	1	8
9	1	9
10	1	10
11	1	11
12	1	12
13	1	13
14	1	14
15	1	15
16	1	16
17	1	17
18	1	18
19	1	19
20	1	20
21	1	21
22	1	22
23	1	23
24	1	24
25	1	25
26	1	26
27	1	27
28	1	28
29	1	29
30	1	30
31	1	31
32	1	32
33	1	33
34	1	34
35	1	35
36	1	36
37	1	37
38	1	38
39	1	39
40	1	40
41	1	41
42	1	42
43	1	43
44	1	44
45	1	45
46	1	46
47	1	47
48	1	48
49	1	49
50	1	50
51	2	1
52	2	2
53	2	3
54	2	4
55	2	5
56	2	6
57	2	7
58	2	8
59	2	9
60	2	10
61	2	11
62	2	12
63	2	13
64	2	14
65	2	15
66	2	16
67	2	17
68	2	18
69	2	19
70	2	20
71	2	21
72	2	22
73	2	23
74	2	24
75	2	25
76	2	26
77	2	27
78	2	28
79	2	29
80	2	30
81	2	31
82	2	32
83	2	33
84	2	34
85	2	35
86	2	36
87	2	37
88	2	38
89	2	39
90	2	40
91	3	1
92	3	2
93	3	3
94	3	4
95	3	5
96	3	6
97	3	7
98	3	8
99	3	9
100	3	10
101	3	11
102	3	12
103	3	13
104	3	14
105	3	15
106	3	16
107	3	17
108	3	18
109	3	19
110	3	20
111	3	21
112	3	22
113	3	23
114	3	24
115	3	25
116	3	26
117	3	27
118	4	1
119	4	2
120	4	3
121	4	4
122	4	5
123	4	6
124	4	7
125	4	8
126	4	9
127	4	10
128	4	11
129	4	12
130	4	13
131	4	14
132	4	15
133	4	16
134	4	17
135	4	18
136	4	19
137	4	20
138	4	21
139	4	22
140	4	23
141	4	24
142	4	25
143	4	26
144	4	27
145	4	28
146	4	29
147	4	30
148	4	31
149	4	32
150	4	33
151	4	34
152	4	35
153	4	36
154	5	1
155	5	2
156	5	3
157	5	4
158	5	5
159	5	6
160	5	7
161	5	8
162	5	9
163	5	10
164	5	11
165	5	12
166	5	13
167	5	14
168	5	15
169	5	16
170	5	17
171	5	18
172	5	19
173	5	20
174	5	21
175	5	22
176	5	23
177	5	24
178	5	25
179	5	26
180	5	27
181	5	28
182	5	29
183	5	30
184	5	31
185	5	32
186	5	33
187	5	34
188	6	1
189	6	2
190	6	3
191	6	4
192	6	5
193	6	6
194	6	7
195	6	8
196	6	9
197	6	10
198	6	11
199	6	12
200	6	13
201	6	14
202	6	15
203	6	16
204	6	17
205	6	18
206	6	19
207	6	20
208	6	21
209	6	22
210	6	23
211	6	24
212	7	1
213	7	2
214	7	3
215	7	4
216	7	5
217	7	6
218	7	7
219	7	8
220	7	9
221	7	10
222	7	11
223	7	12
224	7	13
225	7	14
226	7	15
227	7	16
228	7	17
229	7	18
230	7	19
231	7	20
232	7	21
233	8	1
234	8	2
235	8	3
236	8	4
237	9	1
238	9	2
239	9	3
240	9	4
241	9	5
242	9	6
243	9	7
244	9	8
245	9	9
246	9	10
247	9	11
248	9	12
249	9	13
250	9	14
251	9	15
252	9	16
253	9	17
254	9	18
255	9	19
256	9	20
257	9	21
258	9	22
259	9	23
260	9	24
261	9	25
262	9	26
263	9	27
264	9	28
265	9	29
266	9	30
267	9	31
268	10	1
269	10	2
270	10	3
271	10	4
272	10	5
273	10	6
274	10	7
275	10	8
276	10	9
277	10	10
278	10	11
279	10	12
280	10	13
281	10	14
282	10	15
283	10	16
284	10	17
285	10	18
286	10	19
287	10	20
288	10	21
289	10	22
290	10	23
291	10	24
292	11	1
293	11	2
294	11	3
295	11	4
296	11	5
297	11	6
298	11	7
299	11	8
300	11	9
301	11	10
302	11	11
303	11	12
304	11	13
305	11	14
306	11	15
307	11	16
308	11	17
309	11	18
310	11	19
311	11	20
312	11	21
313	11	22
314	12	1
315	12	2
316	12	3
317	12	4
318	12	5
319	12	6
320	12	7
321	12	8
322	12	9
323	12	10
324	12	11
325	12	12
326	12	13
327	12	14
328	12	15
329	12	16
330	12	17
331	12	18
332	12	19
333	12	20
334	12	21
335	12	22
336	12	23
337	12	24
338	12	25
339	13	1
340	13	2
341	13	3
342	13	4
343	13	5
344	13	6
345	13	7
346	13	8
347	13	9
348	13	10
349	13	11
350	13	12
351	13	13
352	13	14
353	13	15
354	13	16
355	13	17
356	13	18
357	13	19
358	13	20
359	13	21
360	13	22
361	13	23
362	13	24
363	13	25
364	13	26
365	13	27
366	13	28
367	13	29
368	14	1
369	14	2
370	14	3
371	14	4
372	14	5
373	14	6
374	14	7
375	14	8
376	14	9
377	14	10
378	14	11
379	14	12
380	14	13
381	14	14
382	14	15
383	14	16
384	14	17
385	14	18
386	14	19
387	14	20
388	14	21
389	14	22
390	14	23
391	14	24
392	14	25
393	14	26
394	14	27
395	14	28
396	14	29
397	14	30
398	14	31
399	14	32
400	14	33
401	14	34
402	14	35
403	14	36
404	15	1
405	15	2
406	15	3
407	15	4
408	15	5
409	15	6
410	15	7
411	15	8
412	15	9
413	15	10
414	16	1
415	16	2
416	16	3
417	16	4
418	16	5
419	16	6
420	16	7
421	16	8
422	16	9
423	16	10
424	16	11
425	16	12
426	16	13
427	17	1
428	17	2
429	17	3
430	17	4
431	17	5
432	17	6
433	17	7
434	17	8
435	17	9
436	17	10
437	18	1
438	18	2
439	18	3
440	18	4
441	18	5
442	18	6
443	18	7
444	18	8
445	18	9
446	18	10
447	18	11
448	18	12
449	18	13
450	18	14
451	18	15
452	18	16
453	18	17
454	18	18
455	18	19
456	18	20
457	18	21
458	18	22
459	18	23
460	18	24
461	18	25
462	18	26
463	18	27
464	18	28
465	18	29
466	18	30
467	18	31
468	18	32
469	18	33
470	18	34
471	18	35
472	18	36
473	18	37
474	18	38
475	18	39
476	18	40
477	18	41
478	18	42
479	19	1
480	19	2
481	19	3
482	19	4
483	19	5
484	19	6
485	19	7
486	19	8
487	19	9
488	19	10
489	19	11
490	19	12
491	19	13
492	19	14
493	19	15
494	19	16
495	19	17
496	19	18
497	19	19
498	19	20
499	19	21
500	19	22
501	19	23
502	19	24
503	19	25
504	19	26
505	19	27
506	19	28
507	19	29
508	19	30
509	19	31
510	19	32
511	19	33
512	19	34
513	19	35
514	19	36
515	19	37
516	19	38
517	19	39
518	19	40
519	19	41
520	19	42
521	19	43
522	19	44
523	19	45
524	19	46
525	19	47
526	19	48
527	19	49
528	19	50
529	19	51
530	19	52
531	19	53
532	19	54
533	19	55
534	19	56
535	19	57
536	19	58
537	19	59
538	19	60
539	19	61
540	19	62
541	19	63
542	19	64
543	19	65
544	19	66
545	19	67
546	19	68
547	19	69
548	19	70
549	19	71
550	19	72
551	19	73
552	19	74
553	19	75
554	19	76
555	19	77
556	19	78
557	19	79
558	19	80
559	19	81
560	19	82
561	19	83
562	19	84
563	19	85
564	19	86
565	19	87
566	19	88
567	19	89
568	19	90
569	19	91
570	19	92
571	19	93
572	19	94
573	19	95
574	19	96
575	19	97
576	19	98
577	19	99
578	19	100
579	19	101
580	19	102
581	19	103
582	19	104
583	19	105
584	19	106
585	19	107
586	19	108
587	19	109
588	19	110
589	19	111
590	19	112
591	19	113
592	19	114
593	19	115
594	19	116
595	19	117
596	19	118
597	19	119
598	19	120
599	19	121
600	19	122
601	19	123
602	19	124
603	19	125
604	19	126
605	19	127
606	19	128
607	19	129
608	19	130
609	19	131
610	19	132
611	19	133
612	19	134
613	19	135
614	19	136
615	19	137
616	19	138
617	19	139
618	19	140
619	19	141
620	19	142
621	19	143
622	19	144
623	19	145
624	19	146
625	19	147
626	19	148
627	19	149
628	19	150
629	20	1
630	20	2
631	20	3
632	20	4
633	20	5
634	20	6
635	20	7
636	20	8
637	20	9
638	20	10
639	20	11
640	20	12
641	20	13
642	20	14
643	20	15
644	20	16
645	20	17
646	20	18
647	20	19
648	20	20
649	20	21
650	20	22
651	20	23
652	20	24
653	20	25
654	20	26
655	20	27
656	20	28
657	20	29
658	20	30
659	20	31
660	21	1
661	21	2
662	21	3
663	21	4
664	21	5
665	21	6
666	21	7
667	21	8
668	21	9
669	21	10
670	21	11
671	21	12
672	22	1
673	22	2
674	22	3
675	22	4
676	22	5
677	22	6
678	22	7
679	22	8
680	23	1
681	23	2
682	23	3
683	23	4
684	23	5
685	23	6
686	23	7
687	23	8
688	23	9
689	23	10
690	23	11
691	23	12
692	23	13
693	23	14
694	23	15
695	23	16
696	23	17
697	23	18
698	23	19
699	23	20
700	23	21
701	23	22
702	23	23
703	23	24
704	23	25
705	23	26
706	23	27
707	23	28
708	23	29
709	23	30
710	23	31
711	23	32
712	23	33
713	23	34
714	23	35
715	23	36
716	23	37
717	23	38
718	23	39
719	23	40
720	23	41
721	23	42
722	23	43
723	23	44
724	23	45
725	23	46
726	23	47
727	23	48
728	23	49
729	23	50
730	23	51
731	23	52
732	23	53
733	23	54
734	23	55
735	23	56
736	23	57
737	23	58
738	23	59
739	23	60
740	23	61
741	23	62
742	23	63
743	23	64
744	23	65
745	23	66
746	24	1
747	24	2
748	24	3
749	24	4
750	24	5
751	24	6
752	24	7
753	24	8
754	24	9
755	24	10
756	24	11
757	24	12
758	24	13
759	24	14
760	24	15
761	24	16
762	24	17
763	24	18
764	24	19
765	24	20
766	24	21
767	24	22
768	24	23
769	24	24
770	24	25
771	24	26
772	24	27
773	24	28
774	24	29
775	24	30
776	24	31
777	24	32
778	24	33
779	24	34
780	24	35
781	24	36
782	24	37
783	24	38
784	24	39
785	24	40
786	24	41
787	24	42
788	24	43
789	24	44
790	24	45
791	24	46
792	24	47
793	24	48
794	24	49
795	24	50
796	24	51
797	24	52
798	25	1
799	25	2
800	25	3
801	25	4
802	25	5
803	26	1
804	26	2
805	26	3
806	26	4
807	26	5
808	26	6
809	26	7
810	26	8
811	26	9
812	26	10
813	26	11
814	26	12
815	26	13
816	26	14
817	26	15
818	26	16
819	26	17
820	26	18
821	26	19
822	26	20
823	26	21
824	26	22
825	26	23
826	26	24
827	26	25
828	26	26
829	26	27
830	26	28
831	26	29
832	26	30
833	26	31
834	26	32
835	26	33
836	26	34
837	26	35
838	26	36
839	26	37
840	26	38
841	26	39
842	26	40
843	26	41
844	26	42
845	26	43
846	26	44
847	26	45
848	26	46
849	26	47
850	26	48
851	27	1
852	27	2
853	27	3
854	27	4
855	27	5
856	27	6
857	27	7
858	27	8
859	27	9
860	27	10
861	27	11
862	27	12
863	28	1
864	28	2
865	28	3
866	28	4
867	28	5
868	28	6
869	28	7
870	28	8
871	28	9
872	28	10
873	28	11
874	28	12
875	28	13
876	28	14
877	29	1
878	29	2
879	29	3
880	30	1
881	30	2
882	30	3
883	30	4
884	30	5
885	30	6
886	30	7
887	30	8
888	30	9
889	31	1
890	32	1
891	32	2
892	32	3
893	32	4
894	33	1
895	33	2
896	33	3
897	33	4
898	33	5
899	33	6
900	33	7
901	34	1
902	34	2
903	34	3
904	35	1
905	35	2
906	35	3
907	36	1
908	36	2
909	36	3
910	37	1
911	37	2
912	38	1
913	38	2
914	38	3
915	38	4
916	38	5
917	38	6
918	38	7
919	38	8
920	38	9
921	38	10
922	38	11
923	38	12
924	38	13
925	38	14
926	39	1
927	39	2
928	39	3
929	39	4
930	40	1
931	40	2
932	40	3
933	40	4
934	40	5
935	40	6
936	40	7
937	40	8
938	40	9
939	40	10
940	40	11
941	40	12
942	40	13
943	40	14
944	40	15
945	40	16
946	40	17
947	40	18
948	40	19
949	40	20
950	40	21
951	40	22
952	40	23
953	40	24
954	40	25
955	40	26
956	40	27
957	40	28
958	41	1
959	41	2
960	41	3
961	41	4
962	41	5
963	41	6
964	41	7
965	41	8
966	41	9
967	41	10
968	41	11
969	41	12
970	41	13
971	41	14
972	41	15
973	41	16
974	42	1
975	42	2
976	42	3
977	42	4
978	42	5
979	42	6
980	42	7
981	42	8
982	42	9
983	42	10
984	42	11
985	42	12
986	42	13
987	42	14
988	42	15
989	42	16
990	42	17
991	42	18
992	42	19
993	42	20
994	42	21
995	42	22
996	42	23
997	42	24
998	43	1
999	43	2
1000	43	3
1001	43	4
1002	43	5
1003	43	6
1004	43	7
1005	43	8
1006	43	9
1007	43	10
1008	43	11
1009	43	12
1010	43	13
1011	43	14
1012	43	15
1013	43	16
1014	43	17
1015	43	18
1016	43	19
1017	43	20
1018	43	21
1019	44	1
1020	44	2
1021	44	3
1022	44	4
1023	44	5
1024	44	6
1025	44	7
1026	44	8
1027	44	9
1028	44	10
1029	44	11
1030	44	12
1031	44	13
1032	44	14
1033	44	15
1034	44	16
1035	44	17
1036	44	18
1037	44	19
1038	44	20
1039	44	21
1040	44	22
1041	44	23
1042	44	24
1043	44	25
1044	44	26
1045	44	27
1046	44	28
1047	45	1
1048	45	2
1049	45	3
1050	45	4
1051	45	5
1052	45	6
1053	45	7
1054	45	8
1055	45	9
1056	45	10
1057	45	11
1058	45	12
1059	45	13
1060	45	14
1061	45	15
1062	45	16
1063	46	1
1064	46	2
1065	46	3
1066	46	4
1067	46	5
1068	46	6
1069	46	7
1070	46	8
1071	46	9
1072	46	10
1073	46	11
1074	46	12
1075	46	13
1076	46	14
1077	46	15
1078	46	16
1079	47	1
1080	47	2
1081	47	3
1082	47	4
1083	47	5
1084	47	6
1085	47	7
1086	47	8
1087	47	9
1088	47	10
1089	47	11
1090	47	12
1091	47	13
1092	48	1
1093	48	2
1094	48	3
1095	48	4
1096	48	5
1097	48	6
1098	49	1
1099	49	2
1100	49	3
1101	49	4
1102	49	5
1103	49	6
1104	50	1
1105	50	2
1106	50	3
1107	50	4
1108	51	1
1109	51	2
1110	51	3
1111	51	4
1112	52	1
1113	52	2
1114	52	3
1115	52	4
1116	52	5
1117	53	1
1118	53	2
1119	53	3
1120	54	1
1121	54	2
1122	54	3
1123	54	4
1124	54	5
1125	54	6
1126	55	1
1127	55	2
1128	55	3
1129	55	4
1130	56	1
1131	56	2
1132	56	3
1133	57	1
1134	58	1
1135	58	2
1136	58	3
1137	58	4
1138	58	5
1139	58	6
1140	58	7
1141	58	8
1142	58	9
1143	58	10
1144	58	11
1145	58	12
1146	58	13
1147	59	1
1148	59	2
1149	59	3
1150	59	4
1151	59	5
1152	60	1
1153	60	2
1154	60	3
1155	60	4
1156	60	5
1157	61	1
1158	61	2
1159	61	3
1160	62	1
1161	62	2
1162	62	3
1163	62	4
1164	62	5
1165	63	1
1166	64	1
1167	65	1
1168	66	1
1169	66	2
1170	66	3
1171	66	4
1172	66	5
1173	66	6
1174	66	7
1175	66	8
1176	66	9
1177	66	10
1178	66	11
1179	66	12
1180	66	13
1181	66	14
1182	66	15
1183	66	16
1184	66	17
1185	66	18
1186	66	19
1187	66	20
1188	66	21
1189	66	22
1190	67	1
1191	67	2
1192	67	3
1193	67	4
1194	67	5
1195	67	6
1196	67	7
1197	67	8
1198	67	9
1199	67	10
1200	67	11
1201	67	12
1202	67	13
1203	67	14
1204	67	15
1205	67	16
1206	67	17
1207	67	18
1208	67	19
1209	67	20
1210	67	21
1211	67	22
1212	68	1
1213	68	2
1214	68	3
1215	68	4
1216	68	5
1217	68	6
1218	68	7
1219	68	8
1220	68	9
1221	68	10
1222	68	11
1223	68	12
1224	68	13
1225	68	14
1226	68	15
1227	68	16
1228	68	17
1229	68	18
1230	68	19
1231	68	20
1232	68	21
1233	68	22
1234	68	23
1235	68	24
1236	68	25
1237	68	26
1238	68	27
1239	68	28
1240	68	29
1241	68	30
1242	68	31
1243	68	32
1244	68	33
1245	69	1
1246	69	2
1247	69	3
1248	69	4
1249	69	5
1250	69	6
1251	69	7
1252	70	1
1253	71	1
1254	72	1
1255	73	1
1256	74	1
1257	74	2
1258	74	3
1259	74	4
1260	74	5
1261	74	6
1262	74	7
1263	74	8
1264	74	9
1265	74	10
1266	74	11
1267	74	12
1268	74	13
1269	74	14
1270	74	15
1271	74	16
1272	74	17
1273	74	18
1274	74	19
1275	74	20
1276	74	21
1277	74	22
1278	74	23
1279	74	24
1280	74	25
1281	74	26
1282	74	27
1283	74	28
1284	74	29
1285	75	1
1286	75	2
1287	75	3
1288	75	4
1289	75	5
1290	75	6
1291	75	7
1292	75	8
1293	75	9
1294	75	10
1295	75	11
1296	75	12
1297	75	13
1298	75	14
1299	75	15
1300	75	16
1301	75	17
1302	75	18
1303	75	19
1304	75	20
1305	75	21
1306	75	22
1307	75	23
1308	75	24
1309	75	25
1310	75	26
1311	75	27
1312	75	28
1313	75	29
1314	75	30
1315	75	31
1316	75	32
1317	75	33
1318	75	34
1319	75	35
1320	75	36
1321	75	37
1322	75	38
1323	75	39
1324	75	40
1325	75	41
1326	75	42
1327	75	43
1328	75	44
1329	75	45
1330	75	46
1331	75	47
1332	75	48
1333	75	49
1334	75	50
1335	75	51
1336	75	52
1337	75	53
1338	75	54
1339	75	55
1340	75	56
1341	75	57
1342	75	58
1343	75	59
1344	75	60
1345	75	61
1346	75	62
1347	75	63
1348	76	1
1349	76	2
1350	76	3
1351	76	4
1352	76	5
1353	76	6
1354	76	7
1355	76	8
1356	76	9
1357	76	10
1358	76	11
1359	76	12
1360	76	13
1361	76	14
1362	76	15
1363	76	16
1364	77	1
1365	77	2
1366	77	3
1367	77	4
1368	77	5
1369	77	6
1370	77	7
1371	77	8
1372	77	9
1373	77	10
1374	77	11
1375	77	12
1376	77	13
1377	77	14
1378	77	15
1379	77	16
1380	77	17
1381	77	18
1382	77	19
1383	77	20
1384	77	21
1385	77	22
1386	77	23
1387	77	24
1388	77	25
1389	77	26
1390	77	27
1391	77	28
1392	77	29
1393	77	30
1394	78	1
1395	79	1
1396	79	2
1397	79	3
1398	79	4
1399	79	5
1400	79	6
1401	79	7
1402	79	8
1403	79	9
1404	80	1
1405	80	2
1406	80	3
1407	80	4
1408	80	5
1409	80	6
1410	80	7
1411	80	8
1412	80	9
1413	80	10
1414	80	11
1415	80	12
1416	80	13
1417	80	14
1418	80	15
1419	81	1
1420	81	2
1421	81	3
1422	81	4
1423	81	5
1424	81	6
1425	81	7
1426	81	8
1427	81	9
1428	81	10
1429	82	1
1430	82	2
1431	82	3
1432	82	4
1433	82	5
1434	82	6
1435	82	7
1436	82	8
1437	82	9
1438	82	10
1439	82	11
1440	82	12
1441	82	13
1442	82	14
1443	82	15
1444	82	16
1445	82	17
1446	82	18
1447	82	19
1448	82	20
1449	82	21
1450	82	22
1451	82	23
1452	82	24
1453	82	25
1454	82	26
1455	82	27
1456	82	28
1457	82	29
1458	82	30
1459	82	31
1460	82	32
1461	82	33
1462	82	34
1463	82	35
1464	82	36
1465	82	37
1466	82	38
1467	82	39
1468	82	40
1469	82	41
1470	82	42
1471	82	43
1472	82	44
1473	82	45
1474	82	46
1475	82	47
1476	82	48
1477	82	49
1478	82	50
1479	82	51
1480	82	52
1481	82	53
1482	82	54
1483	82	55
1484	82	56
1485	82	57
1486	82	58
1487	82	59
1488	82	60
1489	82	61
1490	82	62
1491	82	63
1492	82	64
1493	82	65
1494	82	66
1495	82	67
1496	82	68
1497	82	69
1498	82	70
1499	82	71
1500	82	72
1501	82	73
1502	82	74
1503	82	75
1504	82	76
1505	82	77
1506	82	78
1507	82	79
1508	82	80
1509	82	81
1510	82	82
1511	82	83
1512	82	84
1513	82	85
1514	82	86
1515	82	87
1516	82	88
1517	82	89
1518	82	90
1519	82	91
1520	82	92
1521	82	93
1522	82	94
1523	82	95
1524	82	96
1525	82	97
1526	82	98
1527	82	99
1528	82	100
1529	82	101
1530	82	102
1531	82	103
1532	82	104
1533	82	105
1534	82	106
1535	82	107
1536	82	108
1537	82	109
1538	82	110
1539	82	111
1540	82	112
1541	82	113
1542	82	114
1543	82	115
1544	82	116
1545	82	117
1546	82	118
1547	82	119
1548	82	120
1549	82	121
1550	82	122
1551	82	123
1552	82	124
1553	82	125
1554	82	126
1555	82	127
1556	82	128
1557	82	129
1558	82	130
1559	82	131
1560	82	132
1561	82	133
1562	82	134
1563	82	135
1564	82	136
1565	82	137
1566	82	138
1567	83	1
1568	83	2
1569	83	3
1570	83	4
1571	83	5
1572	83	6
1573	83	7
1574	83	8
1575	84	1
1576	84	2
1577	84	3
1578	84	4
1579	84	5
1580	85	1
1581	86	1
1582	87	1
\.


--
-- Data for Name: pilcrow; Type: TABLE DATA; Schema: public; Owner: -
--

COPY pilcrow (verse_id) FROM stdin;
6
9
14
24
26
29
35
39
49
78
89
96
99
105
109
115
118
121
124
127
134
143
147
152
167
171
190
197
199
204
214
224
234
241
250
256
277
294
305
309
313
324
333
350
354
386
389
397
407
413
421
434
441
448
462
470
473
475
481
484
485
487
513
520
523
526
536
547
551
563
568
575
589
599
602
607
621
624
653
664
670
671
678
683
688
699
710
719
727
734
746
758
769
780
784
790
805
811
817
827
845
853
856
868
891
899
910
917
935
938
942
953
977
979
987
1001
1006
1018
1021
1028
1033
1039
1050
1055
1056
1058
1059
1061
1072
1089
1093
1096
1099
1107
1113
1132
1144
1147
1157
1171
1178
1193
1205
1210
1221
1233
1242
1249
1256
1274
1278
1282
1288
1306
1317
1331
1339
1343
1375
1384
1395
1397
1398
1399
1400
1401
1403
1404
1407
1408
1410
1411
1415
1432
1434
1448
1457
1467
1477
1479
1482
1487
1488
1490
1493
1494
1495
1496
1501
1502
1514
1521
1522
1529
1540
1548
1560
1566
1578
1587
1591
1599
1608
1612
1620
1626
1629
1631
1643
1648
1653
1665
1670
1672
1677
1684
1694
1696
1700
1705
1716
1719
1727
1731
1736
1751
1756
1765
1770
1790
1794
1799
1802
1805
1820
1828
1835
1838
1846
1848
1854
1857
1860
1871
1873
1876
1879
1882
1885
1888
1895
1900
1903
1905
1909
1913
1916
1941
1944
1948
1952
1957
1959
1964
1970
1975
1980
1992
2007
2013
2027
2034
2037
2041
2043
2064
2070
2074
2076
2085
2090
2093
2094
2095
2096
2098
2100
2104
2106
2111
2113
2116
2119
2120
2121
2128
2130
2132
2133
2134
2135
2136
2139
2142
2143
2145
2147
2148
2149
2153
2154
2159
2165
2171
2181
2187
2190
2206
2219
2227
2243
2251
2262
2267
2269
2282
2285
2289
2291
2293
2300
2307
2309
2316
2320
2324
2325
2327
2330
2333
2334
2352
2356
2366
2368
2375
2382
2394
2400
2405
2417
2433
2446
2454
2458
2464
2469
2478
2486
2501
2507
2515
2518
2519
2520
2526
2536
2552
2562
2572
2575
2581
2587
2598
2602
2604
2611
2615
2622
2630
2634
2642
2643
2655
2671
2673
2687
2692
2695
2697
2698
2725
2728
2730
2732
2734
2736
2738
2742
2756
2760
2767
2768
2770
2775
2785
2791
2809
2818
2823
2842
2845
2848
2858
2864
2869
2874
2902
2908
2915
2936
2940
2949
2959
2962
2969
2986
2990
2994
3007
3011
3027
3062
3071
3077
3082
3091
3100
3145
3188
3217
3222
3231
3244
3246
3258
3285
3286
3287
3291
3293
3294
3295
3296
3297
3298
3299
3300
3301
3302
3305
3308
3311
3312
3313
3314
3315
3317
3325
3326
3328
3329
3341
3346
3355
3362
3384
3387
3396
3407
3412
3418
3425
3426
3429
3436
3452
3457
3464
3470
3478
3488
3493
3495
3505
3509
3517
3527
3528
3539
3546
3585
3597
3610
3622
3627
3629
3631
3633
3635
3637
3639
3641
3643
3645
3647
3652
3669
3676
3677
3684
3688
3691
3698
3707
3720
3726
3731
3733
3737
3749
3760
3761
3765
3773
3778
3786
3798
3804
3837
3846
3861
3863
3869
3875
3881
3887
3893
3899
3905
3911
3917
3923
3929
3945
3963
3972
3975
3981
4000
4003
4007
4011
4014
4018
4022
4029
4035
4041
4049
4056
4074
4093
4097
4102
4115
4120
4122
4124
4135
4149
4171
4176
4181
4184
4186
4191
4207
4218
4226
4231
4236
4239
4241
4251
4255
4266
4278
4283
4301
4319
4324
4326
4334
4345
4348
4351
4353
4358
4362
4372
4374
4378
4391
4398
4412
4431
4442
4444
4457
4462
4467
4478
4482
4488
4495
4502
4505
4509
4513
4516
4518
4523
4525
4528
4532
4534
4538
4542
4547
4553
4561
4567
4570
4573
4587
4589
4604
4616
4621
4626
4629
4632
4635
4638
4641
4644
4678
4686
4690
4713
4725
4735
4739
4753
4811
4826
4855
4902
4912
4915
4955
4963
4965
4994
4997
5019
5030
5046
5049
5060
5070
5076
5090
5103
5124
5165
5193
5195
5199
5219
5222
5227
5231
5235
5258
5261
5270
5279
5285
5294
5300
5302
5312
5319
5327
5332
5339
5352
5356
5359
5361
5364
5367
5373
5379
5388
5391
5394
5400
5411
5418
5421
5422
5423
5433
5438
5447
5458
5463
5466
5470
5475
5476
5477
5479
5480
5481
5482
5483
5484
5493
5494
5496
5499
5501
5508
5510
5511
5513
5516
5518
5520
5522
5525
5531
5532
5533
5534
5536
5540
5543
5545
5552
5553
5559
5561
5565
5579
5583
5595
5597
5600
5627
5682
5690
5720
5724
5736
5738
5743
5745
5751
5753
5757
5766
5774
5803
5817
5818
5819
5823
5824
5829
5831
5833
5834
5835
5837
5845
5847
5848
5849
5850
5862
5864
5868
5878
5893
5901
5903
5908
5921
5925
5930
5937
5945
5947
5948
5956
5958
5959
5962
5967
5976
5983
5987
5993
5999
6006
6012
6017
6033
6035
6041
6054
6060
6071
6073
6077
6080
6093
6096
6098
6099
6103
6105
6114
6118
6123
6129
6135
6138
6140
6170
6177
6184
6194
6216
6219
6251
6266
6271
6279
6283
6302
6304
6305
6332
6339
6346
6354
6362
6371
6380
6391
6395
6402
6409
6416
6425
6434
6436
6437
6438
6442
6448
6457
6459
6491
6503
6506
6509
6519
6526
6532
6537
6539
6540
6541
6543
6552
6557
6560
6562
6566
6574
6577
6581
6600
6604
6610
6618
6662
6666
6674
6676
6680
6683
6688
6691
6704
6710
6714
6719
6724
6726
6728
6730
6731
6733
6738
6742
6744
6748
6749
6752
6762
6777
6785
6789
6801
6805
6811
6815
6818
6822
6827
6834
6842
6859
6862
6864
6878
6881
6883
6887
6891
6900
6909
6915
6918
6920
6922
6929
6933
6936
6937
6939
6944
6948
6954
6956
6965
6971
6988
7001
7005
7008
7016
7024
7030
7041
7047
7054
7063
7067
7073
7081
7111
7119
7134
7147
7154
7168
7179
7181
7187
7197
7200
7204
7209
7217
7222
7232
7237
7253
7259
7261
7263
7268
7288
7292
7296
7301
7308
7310
7317
7323
7330
7342
7351
7353
7356
7362
7366
7376
7380
7389
7403
7407
7417
7428
7433
7436
7445
7450
7458
7467
7477
7481
7491
7494
7497
7503
7505
7513
7528
7533
7542
7545
7556
7567
7571
7585
7593
7595
7602
7610
7615
7623
7631
7639
7647
7651
7657
7674
7682
7687
7689
7694
7699
7705
7711
7715
7719
7725
7742
7755
7766
7772
7781
7783
7791
7793
7794
7797
7805
7808
7818
7820
7824
7827
7830
7838
7840
7849
7856
7866
7872
7876
7880
7894
7898
7901
7906
7911
7919
7927
7936
7939
7946
7950
7958
7964
7974
7976
7982
7990
7995
8000
8005
8017
8021
8036
8040
8055
8058
8062
8068
8075
8082
8084
8088
8094
8095
8099
8104
8110
8113
8130
8137
8139
8144
8146
8150
8155
8164
8170
8175
8178
8185
8193
8199
8213
8219
8224
8233
8235
8237
8247
8256
8262
8266
8274
8278
8282
8286
8294
8302
8311
8313
8324
8333
8337
8339
8341
8346
8348
8355
8361
8378
8382
8385
8397
8400
8403
8409
8414
8420
8421
8422
8432
8436
8442
8447
8465
8473
8475
8477
8485
8488
8497
8498
8512
8521
8523
8528
8536
8543
8553
8558
8559
8569
8571
8578
8591
8593
8596
8660
8662
8698
8703
8708
8711
8723
8729
8733
8740
8746
8750
8759
8768
8783
8784
8790
8797
8799
8806
8807
8822
8833
8852
8865
8867
8871
8874
8886
8892
8902
8908
8920
8928
8933
8934
8937
8941
8942
8943
8948
8958
8962
8973
8975
8998
9008
9017
9019
9021
9023
9030
9048
9062
9067
9076
9077
9078
9094
9096
9098
9101
9104
9106
9108
9118
9123
9132
9135
9150
9158
9164
9168
9173
9177
9196
9205
9208
9218
9224
9236
9240
9244
9248
9259
9266
9275
9277
9281
9292
9295
9299
9305
9307
9309
9313
9318
9326
9335
9342
9349
9359
9383
9392
9397
9407
9422
9431
9437
9440
9444
9457
9467
9469
9477
9496
9518
9522
9531
9532
9539
9547
9551
9561
9564
9568
9571
9575
9581
9583
9598
9603
9612
9622
9642
9646
9656
9663
9668
9683
9688
9694
9699
9705
9711
9720
9725
9735
9744
9748
9753
9756
9761
9768
9784
9787
9802
9806
9809
9812
9823
9826
9834
9843
9847
9855
9868
9870
9875
9880
9882
9886
9892
9894
9902
9905
9912
9914
9918
9920
9925
9931
9934
9939
9942
9947
9949
9953
9958
9961
9962
9969
9974
9981
9983
9987
9989
9990
10008
10029
10034
10038
10042
10068
10070
10076
10082
10097
10107
10111
10113
10119
10130
10137
10139
10143
10149
10154
10161
10169
10181
10187
10190
10192
10195
10197
10202
10208
10211
10213
10220
10227
10231
10241
10245
10250
10258
10261
10270
10277
10282
10285
10288
10296
10304
10310
10320
10325
10328
10332
10341
10349
10357
10372
10379
10391
10395
10397
10407
10410
10425
10440
10447
10452
10454
10459
10471
10504
10509
10542
10546
10549
10550
10556
10557
10559
10564
10566
10609
10618
10626
10643
10651
10668
10671
10673
10678
10684
10689
10694
10700
10744
10770
10778
10783
10817
10821
10825
10828
10858
10867
10875
10880
10894
10900
10902
10904
10905
10914
10924
10931
10940
10944
10949
10953
10963
10971
10982
10986
10991
10996
11005
11008
11036
11043
11055
11091
11098
11107
11126
11133
11135
11153
11155
11171
11175
11185
11191
11202
11208
11215
11223
11229
11233
11241
11244
11249
11253
11256
11266
11271
11280
11295
11305
11307
11309
11311
11315
11329
11333
11337
11354
11358
11359
11361
11364
11378
11380
11385
11388
11390
11391
11394
11402
11412
11420
11428
11433
11443
11451
11458
11467
11475
11482
11485
11507
11509
11517
11521
11523
11531
11534
11536
11547
11582
11585
11593
11602
11608
11610
11614
11619
11623
11630
11633
11637
11641
11643
11650
11655
11669
11673
11682
11693
11701
11705
11708
11710
11716
11718
11719
11722
11730
11732
11749
11755
11761
11763
11765
11771
11781
11787
11791
11795
11804
11812
11841
11855
11857
11860
11866
11875
11885
11897
11900
11903
11907
11908
11912
11920
11927
11929
11930
11934
11937
11942
11948
11957
11963
11987
11992
11999
12003
12005
12008
12016
12022
12024
12064
12068
12069
12070
12071
12083
12089
12092
12096
12106
12118
12122
12128
12134
12138
12141
12165
12168
12185
12201
12217
12223
12226
12233
12235
12238
12243
12259
12262
12268
12271
12301
12317
12320
12325
12367
12373
12379
12389
12397
12417
12419
12426
12460
12464
12465
12466
12467
12478
12484
12487
12491
12503
12507
12510
12516
12578
12592
12609
12635
12647
12652
12669
12676
12682
12687
12695
12713
12716
12730
12733
12737
12740
12746
12755
12756
12767
12773
12778
12786
12789
12794
12798
12806
12813
12815
12821
12825
12833
12847
12855
12876
12883
12899
12901
12903
13868
13871
13880
13930
16408
16411
16421
16425
16444
16461
16463
16467
16469
16477
16483
16486
16487
16489
16505
16511
16514
16521
16533
16540
16547
16553
16557
16561
16582
16600
16652
17295
17328
17346
17352
17358
17376
17386
17389
17391
17395
17406
17407
17416
17421
17424
17427
17429
17432
17437
17441
17453
17465
17471
17475
17480
17483
17487
17489
17510
17512
17513
17514
17521
17523
17532
17537
17546
17550
17563
17569
17571
17578
17591
17599
17601
17608
17619
17625
17638
17647
17649
17655
17660
17665
17671
17676
17680
17683
17692
17696
17717
17720
17724
17748
17751
17753
17760
17766
17775
17779
17783
17793
17800
17813
17817
17819
17827
17838
17843
17848
17856
17871
17875
17895
17913
17926
17933
17953
17958
17976
17979
17982
17990
17993
17996
18005
18016
18023
18028
18047
18049
18061
18068
18073
18095
18109
18112
18125
18128
18136
18143
18151
18159
18164
18170
18172
18179
18181
18183
18188
18201
18203
18207
18212
18226
18236
18245
18257
18259
18269
18293
18315
18320
18324
18335
18342
18343
18353
18359
18361
18367
18374
18390
18395
18400
18416
18424
18430
18433
18439
18449
18462
18486
18498
18514
18520
18524
18528
18543
18555
18567
18582
18590
18592
18599
18606
18607
18610
18611
18624
18627
18631
18635
18642
18650
18655
18661
18668
18670
18673
18678
18681
18683
18691
18695
18704
18706
18708
18710
18716
18722
18735
18741
18747
18749
18757
18763
18769
18779
18790
18795
18800
18810
18817
18821
18848
18851
18860
18865
18874
18877
18882
18884
18895
18906
18909
18915
18928
18954
18958
18964
18971
18975
18980
18986
18997
19009
19015
19023
19031
19047
19066
19069
19078
19084
19089
19096
19099
19108
19116
19128
19137
19141
19149
19152
19158
19167
19172
19185
19188
19193
19199
19201
19219
19221
19225
19238
19245
19255
19257
19264
19279
19282
19289
19301
19304
19307
19311
19326
19331
19335
19347
19351
19353
19363
19367
19370
19373
19377
19396
19403
19430
19433
19437
19444
19449
19452
19465
19468
19475
19490
19494
19518
19529
19533
19543
19547
19550
19569
19581
19583
19585
19589
19609
19616
19624
19629
19631
19634
19644
19646
19651
19656
19660
19666
19672
19678
19686
19702
19707
19710
19714
19719
19723
19727
19730
19738
19745
19748
19758
19768
19785
19791
19793
19795
19810
19814
19836
19842
19854
19863
19870
19875
19881
19886
19891
19903
19910
19920
19928
19932
19935
19939
19949
19955
19969
19983
19989
19995
20006
20022
20026
20031
20040
20045
20059
20073
20088
20092
20095
20107
20128
20135
20151
20156
20158
20162
20167
20171
20176
20184
20188
20200
20202
20272
20281
20285
20289
20301
20308
20323
20329
20353
20377
20392
20410
20419
20434
20442
20443
20469
20480
20491
20499
20502
20507
20518
20525
20539
20552
20559
20572
20575
20594
20598
20601
20610
20612
20618
20620
20622
20628
20631
20642
20660
20669
20678
20680
20689
20698
20702
20707
20719
20726
20738
20744
20747
20749
20751
20754
20761
20769
20778
20798
20807
20823
20837
20848
20855
20860
20864
20869
20874
20875
20881
20892
20901
20906
20923
20929
20941
20953
20963
20970
20973
20990
21000
21030
21044
21053
21063
21072
21076
21092
21096
21099
21108
21116
21148
21169
21178
21182
21192
21197
21201
21205
21225
21234
21241
21249
21260
21266
21298
21301
21302
21311
21321
21325
21334
21368
21376
21381
21385
21409
21413
21416
21418
21434
21440
21457
21460
21466
21472
21484
21498
21502
21510
21513
21517
21522
21526
21566
21572
21580
21583
21586
21591
21604
21609
21615
21617
21637
21638
21640
21665
21672
21675
21686
21693
21702
21711
21718
21724
21733
21741
21746
21755
21769
21773
21778
21783
21790
21795
21805
21816
21821
21827
21834
21842
21846
21857
21866
21880
21885
21892
21900
21905
21910
21916
21924
21930
21931
21943
21949
21975
21977
21992
22005
22009
22026
22042
22067
22087
22101
22103
22105
22112
22120
22140
22146
22149
22168
22172
22190
22200
22246
22256
22260
22272
22276
22282
22287
22300
22306
22324
22327
22330
22333
22340
22353
22362
22371
22374
22376
22378
22384
22386
22389
22405
22415
22417
22428
22445
22458
22463
22469
22472
22475
22479
22481
22486
22493
22507
22514
22521
22528
22536
22543
22549
22559
22564
22569
22573
22590
22600
22603
22608
22614
22617
22624
22629
22632
22638
22642
22655
22659
22665
22668
22670
22673
22679
22681
22737
22744
22754
22758
22761
22764
22767
22786
22810
22814
22818
22829
22835
22848
22853
22866
22876
22886
22891
22897
22906
22910
22934
22942
22957
22967
22971
22986
22993
22995
23009
23012
23022
23032
23039
23044
23049
23052
23055
23062
23067
23073
23081
23085
23089
23096
23102
23115
23118
23121
23128
23129
23134
23137
23141
23143
23144
23163
23181
23186
23189
23200
23206
23222
23227
23228
23233
23248
23252
23256
23262
23268
23273
23278
23288
23299
23302
23307
23323
23324
23330
23332
23338
23341
23351
23360
23362
23364
23369
23374
23389
23390
23394
23398
23400
23407
23412
23416
23434
23458
23467
23476
23480
23485
23488
23500
23504
23512
23521
23528
23536
23558
23564
23571
23573
23584
23585
23587
23593
23601
23611
23613
23620
23632
23644
23655
23666
23679
23686
23694
23697
23715
23723
23725
23735
23743
23749
23751
23766
23773
23776
23779
23786
23790
23810
23813
23823
23839
23844
23850
23855
23860
23884
23888
23896
23907
23914
23932
23953
23961
23987
23994
24000
24023
24040
24061
24069
24072
24081
24091
24102
24112
24124
24133
24149
24154
24156
24159
24164
24169
24180
24192
24205
24207
24212
24215
24311
24320
24338
24345
24350
24354
24415
24478
24488
24495
24511
24515
24523
24528
24535
24541
24550
24553
24569
24572
24577
24591
24602
24606
24612
24617
24621
24624
24635
24653
24656
24661
24668
24687
24692
24702
24709
24712
24715
24727
24732
24742
24750
24758
24765
24767
24777
24781
24798
24801
24808
24821
24842
24866
24869
24883
24886
24888
24893
24899
25078
25080
25097
25102
25104
25120
25124
25126
25135
25141
25144
25160
25164
25167
25174
25193
25207
25215
25220
25227
25232
25250
25262
25265
25268
25272
25283
25287
25289
25295
25309
25312
25320
25325
25330
25339
25345
25348
25351
25353
25359
25381
25385
25387
25389
25402
25420
25433
25435
25443
25451
25473
25482
25491
25501
25509
25514
25518
25525
25530
25537
25543
25550
25561
25566
25569
25579
25588
25592
25597
25600
25634
25640
25655
25663
25672
25720
25724
25760
25773
25799
25807
25819
25825
25832
25852
25861
25868
25872
25884
25886
25889
25896
25904
25912
25915
25919
25928
25931
25944
25948
25949
25963
25970
25975
25982
25986
26005
26028
26041
26042
26060
26064
26074
26080
26088
26108
26109
26114
26119
26135
26137
26139
26143
26144
26146
26184
26188
26196
26200
26221
26228
26243
26247
26250
26263
26273
26280
26324
26339
26343
26361
26369
26374
26394
26415
26449
26454
26480
26501
26504
26571
26579
26591
26593
26601
26604
26618
26623
26625
26649
26662
26667
26684
26801
26805
26814
26834
26839
26845
26849
26851
26854
26864
26879
26887
26892
26894
26898
26914
26939
26964
26987
26991
27009
27016
27028
27036
27046
27054
27072
27077
27089
27093
27101
27107
27111
27154
27168
27171
27227
27240
27249
27253
27269
27279
27294
27304
27327
27330
27335
27358
27362
27367
27377
27401
27407
27423
27434
27449
27455
27456
27479
27498
27500
27503
27509
27529
27534
27540
27546
27556
27565
27570
27576
27582
27599
27607
27640
27644
27655
27663
\.


--
-- Data for Name: updates; Type: TABLE DATA; Schema: public; Owner: -
--

COPY updates (scripture_text) FROM stdin;
Q. What is the sea of glass spoken of by John, 4th chapter, and 6th verse of the Revelation? A. It is the earth, in its sanctified, immortal, and eternal state.
Q. What are we to understand by the four beasts, spoken of in the same verse? A. They are figurative expressions, used by the Revelator, John, in describing heaven, the paradise of God, the happiness of man, and of beasts, and of creeping things, and of the fowls of the air; that which is spiritual being in the likeness of that which is temporal; and that which is temporal in the likeness of that which is spiritual; the spirit of man in the likeness of his person, as also the spirit of the beast, and every other creature which God has created.
Q. Are the four beasts limited to individual beasts, or do they represent classes or orders? A. They are limited to four individual beasts, which were shown to John, to represent the glory of the classes of beings in their destined order or sphere of creation, in the enjoyment of their eternal felicity.
Q. What are we to understand by the eyes and wings, which the beasts had? A. Their eyes are a representation of light and knowledge, that is, they are full of knowledge; and their wings are a representation of power, to move, to act, etc.
Q. What are we to understand by the four and twenty elders, spoken of by John? A. We are to understand that these elders whom John saw, were elders who had been faithful in the work of the ministry and were dead; who belonged to the seven churches, and were then in the paradise of God.
Q. What are we to understand by the book which John saw, which was sealed on the back with seven seals? A. We are to understand that it contains the revealed will, mysteries, and the works of God; the hidden things of his economy concerning this earth during the seven thousand years of its continuance, or its temporal existence.
Q. What are we to understand by the seven seals with which it was sealed? A. We are to understand that the first seal contains the things of the first thousand years, and the second also of the second thousand years, and so on until the seventh.
Q. What are we to understand by the four angels, spoken of in the 7th chapter and 1st verse of Revelation? A. We are to understand that they are four angels sent forth from God, to whom is given power over the four parts of the earth, to save life and to destroy; these are they who have the everlasting gospel to commit to every nation, kindred, tongue, and people; having power to shut up the heavens, to seal up unto life, or to cast down to the regions of darkness.
Q. What are we to understand by the angel ascending from the east, Revelation 7th chapter and 2nd verse? A. We are to understand that the angel ascending from the east is he to whom is given the seal of the living God over the twelve tribes of Israel; wherefore, he crieth unto the four angels having the everlasting gospel, saying: Hurt not the earth, neither the sea, nor the trees, till we have sealed the servants of our God in their foreheads. And, if you will receive it, this is Elias which was to come to gather together the tribes of Israel and restore all things.
Q. What time are the things spoken of in this chapter to be accomplished? A. They are to be accomplished in the sixth thousand years, or the opening of the sixth seal.
Q. What are we to understand by sealing the one hundred and forty-four thousand, out of all the tribes of Israel--twelve thousand out of every tribe? A. We are to understand that those who are sealed are high priests, ordained unto the holy order of God, to administer the everlasting gospel; for they are they who are ordained out of every nation, kindred, tongue, and people, by the angels to whom is given power over the nations of the earth, to bring as many as will come to the church of the Firstborn.
Q. What are we to understand by the sounding of the trumpets, mentioned in the 8th chapter of Revelation? A. We are to understand that as God made the world in six days, and on the seventh day he finished his work, and sanctified it, and also formed man out of the dust of the earth, even so, in the beginning of the seventh thousand years will the Lord God sanctify the earth, and complete the salvation of man, and judge all things, and shall redeem all things, except that which he hath not put into his power, when he shall have sealed all things, unto the end of all things; and the sounding of the trumpets of the seven angels are the preparing and finishing of his work, in the beginning of the seventh thousand years--the preparing of the way before the time of his coming.
Q. When are the things to be accomplished, which are written in the 9th chapter of Revelation? A. They are to be accomplished after the opening of the seventh seal, before the coming of Christ.
Q. What are we to understand by the little book which was eaten by John, as mentioned in the 10th chapter of Revelation? A. We are to understand that it was a mission, and an ordinance, for him to gather the tribes of Israel; behold, this is Elias, who, as it is written, must come and restore all things.
Q. What is to be understood by the two witnesses, in the eleventh chapter of Revelation? A. They are two prophets that are to be raised up to the Jewish nation in the last days, at the time of the restoration, and to prophesy to the Jews after they are gathered and have built the city of Jerusalem in the land of their fathers.
\.


--
-- Data for Name: verses; Type: TABLE DATA; Schema: public; Owner: -
--

COPY verses (id, chapter_id, verse_number, scripture_text) FROM stdin;
1	1	1	IN the beginning God created the heaven and the earth.
2	1	2	And the earth was without form, and void; and darkness was upon the face of the deep. And the Spirit of God moved upon the face of the waters.
3	1	3	And God said, Let there be light: and there was light.
4	1	4	And God saw the light, that it was good: and God divided the light from the darkness.
5	1	5	And God called the light Day, and the darkness he called Night. And the evening and the morning were the first day.
6	1	6	And God said, Let there be a firmament in the midst of the waters, and let it divide the waters from the waters.
7	1	7	And God made the firmament, and divided the waters which were under the firmament from the waters which were above the firmament: and it was so.
8	1	8	And God called the firmament Heaven. And the evening and the morning were the second day.
9	1	9	And God said, Let the waters under the heaven be gathered together unto one place, and let the dry land appear: and it was so.
10	1	10	And God called the dry land Earth; and the gathering together of the waters called he Seas: and God saw that it was good.
11	1	11	And God said, Let the earth bring forth grass, the herb yielding seed, and the fruit tree yielding fruit after his kind, whose seed is in itself, upon the earth: and it was so.
12	1	12	And the earth brought forth grass, and herb yielding seed after his kind, and the tree yielding fruit, whose seed was in itself, after his kind: and God saw that it was good.
13	1	13	And the evening and the morning were the third day.
14	1	14	And God said, Let there be lights in the firmament of the heaven to divide the day from the night; and let them be for signs, and for seasons, and for days, and years:
15	1	15	And let them be for lights in the firmament of the heaven to give light upon the earth: and it was so.
16	1	16	And God made two great lights; the greater light to rule the day, and the lesser light to rule the night: he made the stars also.
17	1	17	And God set them in the firmament of the heaven to give light upon the earth,
18	1	18	And to rule over the day and over the night, and to divide the light from the darkness: and God saw that it was good.
19	1	19	And the evening and the morning were the fourth day.
20	1	20	And God said, Let the waters bring forth abundantly the moving creature that hath life, and fowl that may fly above the earth in the open firmament of heaven.
21	1	21	And God created great whales, and every living creature that moveth, which the waters brought forth abundantly, after their kind, and every winged fowl after his kind: and God saw that it was good.
22	1	22	And God blessed them, saying, Be fruitful, and multiply, and fill the waters in the seas, and let fowl multiply in the earth.
23	1	23	And the evening and the morning were the fifth day.
24	1	24	And God said, Let the earth bring forth the living creature after his kind, cattle, and creeping thing, and beast of the earth after his kind: and it was so.
25	1	25	And God made the beast of the earth after his kind, and cattle after their kind, and every thing that creepeth upon the earth after his kind: and God saw that it was good.
26	1	26	And God said, Let us make man in our image, after our likeness: and let them have dominion over the fish of the sea, and over the fowl of the air, and over the cattle, and over all the earth, and over every creeping thing that creepeth upon the earth.
27	1	27	So God created man in his own image, in the image of God created he him; male and female created he them.
28	1	28	And God blessed them, and God said unto them, Be fruitful, and multiply, and replenish the earth, and subdue it: and have dominion over the fish of the sea, and over the fowl of the air, and over every living thing that moveth upon the earth.
29	1	29	And God said, Behold, I have given you every herb bearing seed, which is upon the face of all the earth, and every tree, in the which is the fruit of a tree yielding seed; to you it shall be for meat.
30	1	30	And to every beast of the earth, and to every fowl of the air, and to every thing that creepeth upon the earth, wherein there is life, I have given every green herb for meat: and it was so.
31	1	31	And God saw every thing that he had made, and, behold, it was very good. And the evening and the morning were the sixth day.
32	2	1	THUS the heavens and the earth were finished, and all the host of them.
33	2	2	And on the seventh day God ended his work which he had made; and he rested on the seventh day from all his work which he had made.
34	2	3	And God blessed the seventh day, and sanctified it: because that in it he had rested from all his work which God created and made.
35	2	4	These are the generations of the heavens and of the earth when they were created, in the day that the LORD God made the earth and the heavens,
36	2	5	And every plant of the field before it was in the earth, and every herb of the field before it grew: for the LORD God had not caused it to rain upon the earth, and there was not a man to till the ground.
37	2	6	But there went up a mist from the earth, and watered the whole face of the ground.
38	2	7	And the LORD God formed man of the dust of the ground, and breathed into his nostrils the breath of life; and man became a living soul.
39	2	8	And the LORD God planted a garden eastward in Eden; and there he put the man whom he had formed.
40	2	9	And out of the ground made the LORD God to grow every tree that is pleasant to the sight, and good for food; the tree of life also in the midst of the garden, and the tree of knowledge of good and evil.
41	2	10	And a river went out of Eden to water the garden; and from thence it was parted, and became into four heads.
42	2	11	The name of the first is Pison: that is it which compasseth the whole land of Havilah, where there is gold;
43	2	12	And the gold of that land is good: there is bdellium and the onyx stone.
44	2	13	And the name of the second river is Gihon: the same is it that compasseth the whole land of Ethiopia.
45	2	14	And the name of the third river is Hiddekel: that is it which goeth toward the east of Assyria. And the fourth river is Euphrates.
46	2	15	And the LORD God took the man, and put him into the garden of Eden to dress it and to keep it.
47	2	16	And the LORD God commanded the man, saying, Of every tree of the garden thou mayest freely eat:
48	2	17	But of the tree of the knowledge of good and evil, thou shalt not eat of it: for in the day that thou eatest thereof thou shalt surely die.
49	2	18	And the LORD God said, It is not good that the man should be alone; I will make him an help meet for him.
50	2	19	And out of the ground the LORD God formed every beast of the field, and every fowl of the air; and brought them unto Adam to see what he would call them: and whatsoever Adam called every living creature, that was the name thereof.
51	2	20	And Adam gave names to all cattle, and to the fowl of the air, and to every beast of the field; but for Adam there was not found an help meet for him.
52	2	21	And the LORD God caused a deep sleep to fall upon Adam, and he slept: and he took one of his ribs, and closed up the flesh instead thereof;
53	2	22	And the rib, which the LORD God had taken from man, made he a woman, and brought her unto the man.
54	2	23	And Adam said, This is now bone of my bones, and flesh of my flesh: she shall be called Woman, because she was taken out of Man.
55	2	24	Therefore shall a man leave his father and his mother, and shall cleave unto his wife: and they shall be one flesh.
56	2	25	And they were both naked, the man and his wife, and were not ashamed.
57	3	1	NOW the serpent was more subtil than any beast of the field which the LORD God had made. And he said unto the woman, Yea, hath God said, Ye shall not eat of every tree of the garden?
58	3	2	And the woman said unto the serpent, We may eat of the fruit of the trees of the garden:
59	3	3	But of the fruit of the tree which is in the midst of the garden, God hath said, Ye shall not eat of it, neither shall ye touch it, lest ye die.
60	3	4	And the serpent said unto the woman, Ye shall not surely die:
61	3	5	For God doth know that in the day ye eat thereof, then your eyes shall be opened, and ye shall be as gods, knowing good and evil.
62	3	6	And when the woman saw that the tree was good for food, and that it was pleasant to the eyes, and a tree to be desired to make one wise, she took of the fruit thereof, and did eat, and gave also unto her husband with her; and he did eat.
63	3	7	And the eyes of them both were opened, and they knew that they were naked; and they sewed fig leaves together, and made themselves aprons.
64	3	8	And they heard the voice of the LORD God walking in the garden in the cool of the day: and Adam and his wife hid themselves from the presence of the LORD God amongst the trees of the garden.
65	3	9	And the LORD God called unto Adam, and said unto him, Where art thou?
66	3	10	And he said, I heard thy voice in the garden, and I was afraid, because I was naked; and I hid myself.
67	3	11	And he said, Who told thee that thou wast naked? Hast thou eaten of the tree, whereof I commanded thee that thou shouldest not eat?
68	3	12	And the man said, The woman whom thou gavest to be with me, she gave me of the tree, and I did eat.
69	3	13	And the LORD God said unto the woman, What is this that thou hast done? And the woman said, The serpent beguiled me, and I did eat.
70	3	14	And the LORD God said unto the serpent, Because thou hast done this, thou art cursed above all cattle, and above every beast of the field; upon thy belly shalt thou go, and dust shalt thou eat all the days of thy life:
71	3	15	And I will put enmity between thee and the woman, and between thy seed and her seed; it shall bruise thy head, and thou shalt bruise his heel.
72	3	16	Unto the woman he said, I will greatly multiply thy sorrow and thy conception; in sorrow thou shalt bring forth children; and thy desire shall be to thy husband, and he shall rule over thee.
73	3	17	And unto Adam he said, Because thou hast hearkened unto the voice of thy wife, and hast eaten of the tree, of which I commanded thee, saying, Thou shalt not eat of it: cursed is the ground for thy sake; in sorrow shalt thou eat of it all the days of thy life;
74	3	18	Thorns also and thistles shall it bring forth to thee; and thou shalt eat the herb of the field;
75	3	19	In the sweat of thy face shalt thou eat bread, till thou return unto the ground; for out of it wast thou taken: for dust thou art, and unto dust shalt thou return.
76	3	20	And Adam called his wife's name Eve; because she was the mother of all living.
77	3	21	Unto Adam also and to his wife did the LORD God make coats of skins, and clothed them.
78	3	22	And the LORD God said, Behold, the man is become as one of us, to know good and evil: and now, lest he put forth his hand, and take also of the tree of life, and eat, and live for ever:
79	3	23	Therefore the LORD God sent him forth from the garden of Eden, to till the ground from whence he was taken.
80	3	24	So he drove out the man; and he placed at the east of the garden of Eden Cherubims, and a flaming sword which turned every way, to keep the way of the tree of life.
81	4	1	AND Adam knew Eve his wife; and she conceived, and bare Cain, and said, I have gotten a man from the LORD.
82	4	2	And she again bare his brother Abel. And Abel was a keeper of sheep, but Cain was a tiller of the ground.
83	4	3	And in process of time it came to pass, that Cain brought of the fruit of the ground an offering unto the LORD.
84	4	4	And Abel, he also brought of the firstlings of his flock and of the fat thereof. And the LORD had respect unto Abel and to his offering:
85	4	5	But unto Cain and to his offering he had not respect. And Cain was very wroth, and his countenance fell.
86	4	6	And the LORD said unto Cain, Why art thou wroth? and why is thy countenance fallen?
87	4	7	If thou doest well, shalt thou not be accepted? and if thou doest not well, sin lieth at the door. And unto thee shall be his desire, and thou shalt rule over him.
88	4	8	And Cain talked with Abel his brother: and it came to pass, when they were in the field, that Cain rose up against Abel his brother, and slew him.
89	4	9	And the LORD said unto Cain, Where is Abel thy brother? And he said, I know not: Am I my brother's keeper?
90	4	10	And he said, What hast thou done? the voice of thy brother's blood crieth unto me from the ground.
91	4	11	And now art thou cursed from the earth, which hath opened her mouth to receive thy brother's blood from thy hand;
92	4	12	When thou tillest the ground, it shall not henceforth yield unto thee her strength; a fugitive and a vagabond shalt thou be in the earth.
93	4	13	And Cain said unto the LORD, My punishment is greater than I can bear.
94	4	14	Behold, thou hast driven me out this day from the face of the earth; and from thy face shall I be hid; and I shall be a fugitive and a vagabond in the earth; and it shall come to pass, that every one that findeth me shall slay me.
95	4	15	And the LORD said unto him, Therefore whosoever slayeth Cain, vengeance shall be taken on him sevenfold. And the LORD set a mark upon Cain, lest any finding him should kill him.
96	4	16	And Cain went out from the presence of the LORD, and dwelt in the land of Nod, on the east of Eden.
97	4	17	And Cain knew his wife; and she conceived, and bare Enoch: and he builded a city, and called the name of the city, after the name of his son, Enoch.
98	4	18	And unto Enoch was born Irad: and Irad begat Mehujael: and Mehujael begat Methusael: and Methusael begat Lamech.
99	4	19	And Lamech took unto him two wives: the name of the one was Adah, and the name of the other Zillah.
100	4	20	And Adah bare Jabal: he was the father of such as dwell in tents, and of such as have cattle.
101	4	21	And his brother's name was Jubal: he was the father of all such as handle the harp and organ.
102	4	22	And Zillah, she also bare Tubal-cain, an instructer of every artificer in brass and iron: and the sister of Tubal-cain was Naamah.
103	4	23	And Lamech said unto his wives, Adah and Zillah, Hear my voice; ye wives of Lamech, hearken unto my speech: for I have slain a man to my wounding, and a young man to my hurt.
104	4	24	If Cain shall be avenged sevenfold, truly Lamech seventy and sevenfold.
105	4	25	And Adam knew his wife again; and she bare a son, and called his name Seth: For God, said she, hath appointed me another seed instead of Abel, whom Cain slew.
106	4	26	And to Seth, to him also there was born a son; and he called his name Enos: then began men to call upon the name of the LORD.
107	5	1	THIS is the book of the generations of Adam. In the day that God created man, in the likeness of God made he him;
108	5	2	Male and female created he them; and blessed them, and called their name Adam, in the day when they were created.
109	5	3	And Adam lived an hundred and thirty years, and begat a son in his own likeness, after his image; and called his name Seth:
110	5	4	And the days of Adam after he had begotten Seth were eight hundred years: and he begat sons and daughters:
111	5	5	And all the days that Adam lived were nine hundred and thirty years: and he died.
112	5	6	And Seth lived an hundred and five years, and begat Enos:
113	5	7	And Seth lived after he begat Enos eight hundred and seven years, and begat sons and daughters:
114	5	8	And all the days of Seth were nine hundred and twelve years: and he died.
115	5	9	And Enos lived ninety years, and begat Cainan:
116	5	10	And Enos lived after he begat Cainan eight hundred and fifteen years, and begat sons and daughters:
117	5	11	And all the days of Enos were nine hundred and five years: and he died.
118	5	12	And Cainan lived seventy years, and begat Mahalaleel:
119	5	13	And Cainan lived after he begat Mahalaleel eight hundred and forty years, and begat sons and daughters:
120	5	14	And all the days of Cainan were nine hundred and ten years: and he died.
121	5	15	And Mahalaleel lived sixty and five years, and begat Jared:
122	5	16	And Mahalaleel lived after he begat Jared eight hundred and thirty years, and begat sons and daughters:
123	5	17	And all the days of Mahalaleel were eight hundred and ninety and five years: and he died.
124	5	18	And Jared lived an hundred sixty and two years, and he begat Enoch:
125	5	19	And Jared lived after he begat Enoch eight hundred years, and begat sons and daughters:
126	5	20	And all the days of Jared were nine hundred sixty and two years: and he died.
127	5	21	And Enoch lived sixty and five years, and begat Methuselah:
128	5	22	And Enoch walked with God after he begat Methuselah three hundred years, and begat sons and daughters:
129	5	23	And all the days of Enoch were three hundred sixty and five years:
130	5	24	And Enoch walked with God: and he was not; for God took him.
131	5	25	And Methuselah lived an hundred eighty and seven years, and begat Lamech:
132	5	26	And Methuselah lived after he begat Lamech seven hundred eighty and two years, and begat sons and daughters:
133	5	27	And all the days of Methuselah were nine hundred sixty and nine years: and he died.
134	5	28	And Lamech lived an hundred eighty and two years, and begat a son:
135	5	29	And he called his name Noah, saying, This same shall comfort us concerning our work and toil of our hands, because of the ground which the LORD hath cursed.
136	5	30	And Lamech lived after he begat Noah five hundred ninety and five years, and begat sons and daughters:
137	5	31	And all the days of Lamech were seven hundred seventy and seven years: and he died.
138	5	32	And Noah was five hundred years old: and Noah begat Shem, Ham, and Japheth.
139	6	1	AND it came to pass, when men began to multiply on the face of the earth, and daughters were born unto them,
140	6	2	That the sons of God saw the daughters of men that they were fair; and they took them wives of all which they chose.
141	6	3	And the LORD said, My spirit shall not always strive with man, for that he also is flesh: yet his days shall be an hundred and twenty years.
142	6	4	There were giants in the earth in those days; and also after that, when the sons of God came in unto the daughters of men, and they bare children to them, the same became mighty men which were of old, men of renown.
143	6	5	And GOD saw that the wickedness of man was great in the earth, and that every imagination of the thoughts of his heart was only evil continually.
144	6	6	And it repented the LORD that he had made man on the earth, and it grieved him at his heart.
145	6	7	And the LORD said, I will destroy man whom I have created from the face of the earth; both man, and beast, and the creeping thing, and the fowls of the air; for it repenteth me that I have made them.
146	6	8	But Noah found grace in the eyes of the LORD.
147	6	9	These are the generations of Noah: Noah was a just man and perfect in his generations, and Noah walked with God.
148	6	10	And Noah begat three sons, Shem, Ham, and Japheth.
149	6	11	The earth also was corrupt before God, and the earth was filled with violence.
150	6	12	And God looked upon the earth, and, behold, it was corrupt; for all flesh had corrupted his way upon the earth.
151	6	13	And God said unto Noah, The end of all flesh is come before me; for the earth is filled with violence through them; and, behold, I will destroy them with the earth.
152	6	14	Make thee an ark of gopher wood; rooms shalt thou make in the ark, and shalt pitch it within and without with pitch.
153	6	15	And this is the fashion which thou shalt make it of: The length of the ark shall be three hundred cubits, the breadth of it fifty cubits, and the height of it thirty cubits.
154	6	16	A window shalt thou make to the ark, and in a cubit shalt thou finish it above; and the door of the ark shalt thou set in the side thereof; with lower, second, and third stories shalt thou make it.
155	6	17	And, behold, I, even I, do bring a flood of waters upon the earth, to destroy all flesh, wherein is the breath of life, from under heaven; and every thing that is in the earth shall die.
156	6	18	But with thee will I establish my covenant; and thou shalt come into the ark, thou, and thy sons, and thy wife, and thy sons' wives with thee.
157	6	19	And of every living thing of all flesh, two of every sort shalt thou bring into the ark, to keep them alive with thee; they shall be male and female.
158	6	20	Of fowls after their kind, and of cattle after their kind, of every creeping thing of the earth after his kind, two of every sort shall come unto thee, to keep them alive.
159	6	21	And take thou unto thee of all food that is eaten, and thou shalt gather it to thee; and it shall be for food for thee, and for them.
160	6	22	Thus did Noah; according to all that God commanded him, so did he.
161	7	1	AND the LORD said unto Noah, Come thou and all thy house into the ark; for thee have I seen righteous before me in this generation.
162	7	2	Of every clean beast thou shalt take to thee by sevens, the male and his female: and of beasts that are not clean by two, the male and his female.
163	7	3	Of fowls also of the air by sevens, the male and the female; to keep seed alive upon the face of all the earth.
164	7	4	For yet seven days, and I will cause it to rain upon the earth forty days and forty nights; and every living substance that I have made will I destroy from off the face of the earth.
165	7	5	And Noah did according unto all that the LORD commanded him.
166	7	6	And Noah was six hundred years old when the flood of waters was upon the earth.
167	7	7	And Noah went in, and his sons, and his wife, and his sons' wives with him, into the ark, because of the waters of the flood.
168	7	8	Of clean beasts, and of beasts that are not clean, and of fowls, and of every thing that creepeth upon the earth,
169	7	9	There went in two and two unto Noah into the ark, the male and the female, as God had commanded Noah.
170	7	10	And it came to pass after seven days, that the waters of the flood were upon the earth.
171	7	11	In the six hundredth year of Noah's life, in the second month, the seventeenth day of the month, the same day were all the fountains of the great deep broken up, and the windows of heaven were opened.
172	7	12	And the rain was upon the earth forty days and forty nights.
173	7	13	In the selfsame day entered Noah, and Shem, and Ham, and Japheth, the sons of Noah, and Noah's wife, and the three wives of his sons with them, into the ark;
174	7	14	They, and every beast after his kind, and all the cattle after their kind, and every creeping thing that creepeth upon the earth after his kind, and every fowl after his kind, every bird of every sort.
175	7	15	And they went in unto Noah into the ark, two and two of all flesh, wherein is the breath of life.
176	7	16	And they that went in, went in male and female of all flesh, as God had commanded him: and the LORD shut him in.
177	7	17	And the flood was forty days upon the earth; and the waters increased, and bare up the ark, and it was lift up above the earth.
178	7	18	And the waters prevailed, and were increased greatly upon the earth; and the ark went upon the face of the waters.
179	7	19	And the waters prevailed exceedingly upon the earth; and all the high hills, that were under the whole heaven, were covered.
180	7	20	Fifteen cubits upward did the waters prevail; and the mountains were covered.
181	7	21	And all flesh died that moved upon the earth, both of fowl, and of cattle, and of beast, and of every creeping thing that creepeth upon the earth, and every man:
182	7	22	All in whose nostrils was the breath of life, of all that was in the dry land, died.
183	7	23	And every living substance was destroyed which was upon the face of the ground, both man, and cattle, and the creeping things, and the fowl of the heaven; and they were destroyed from the earth: and Noah only remained alive, and they that were with him in the ark.
184	7	24	And the waters prevailed upon the earth an hundred and fifty days.
185	8	1	AND God remembered Noah, and every living thing, and all the cattle that was with him in the ark: and God made a wind to pass over the earth, and the waters asswaged;
186	8	2	The fountains also of the deep and the windows of heaven were stopped, and the rain from heaven was restrained;
187	8	3	And the waters returned from off the earth continually: and after the end of the hundred and fifty days the waters were abated.
188	8	4	And the ark rested in the seventh month, on the seventeenth day of the month, upon the mountains of Ararat.
189	8	5	And the waters decreased continually until the tenth month: in the tenth month, on the first day of the month, were the tops of the mountains seen.
190	8	6	And it came to pass at the end of forty days, that Noah opened the window of the ark which he had made:
191	8	7	And he sent forth a raven, which went forth to and fro, until the waters were dried up from off the earth.
192	8	8	Also he sent forth a dove from him, to see if the waters were abated from off the face of the ground;
193	8	9	But the dove found no rest for the sole of her foot, and she returned unto him into the ark, for the waters were on the face of the whole earth: then he put forth his hand, and took her, and pulled her in unto him into the ark.
194	8	10	And he stayed yet other seven days; and again he sent forth the dove out of the ark;
195	8	11	And the dove came in to him in the evening; and, lo, in her mouth was an olive leaf pluckt off: so Noah knew that the waters were abated from off the earth.
196	8	12	And he stayed yet other seven days; and sent forth the dove; which returned not again unto him any more.
197	8	13	And it came to pass in the six hundredth and first year, in the first month, the first day of the month, the waters were dried up from off the earth: and Noah removed the covering of the ark, and looked, and, behold, the face of the ground was dry.
198	8	14	And in the second month, on the seven and twentieth day of the month, was the earth dried.
199	8	15	And God spake unto Noah, saying,
200	8	16	Go forth of the ark, thou, and thy wife, and thy sons, and thy sons' wives with thee.
201	8	17	Bring forth with thee every living thing that is with thee, of all flesh, both of fowl, and of cattle, and of every creeping thing that creepeth upon the earth; that they may breed abundantly in the earth, and be fruitful, and multiply upon the earth.
202	8	18	And Noah went forth, and his sons, and his wife, and his sons' wives with him:
203	8	19	Every beast, every creeping thing, and every fowl, and whatsoever creepeth upon the earth, after their kinds, went forth out of the ark.
204	8	20	And Noah builded an altar unto the LORD; and took of every clean beast, and of every clean fowl, and offered burnt offerings on the altar.
205	8	21	And the LORD smelled a sweet savour; and the LORD said in his heart, I will not again curse the ground any more for man's sake; for the imagination of man's heart is evil from his youth; neither will I again smite any more every thing living, as I have done.
206	8	22	While the earth remaineth, seedtime and harvest, and cold and heat, and summer and winter, and day and night shall not cease.
207	9	1	AND God blessed Noah and his sons, and said unto them, Be fruitful, and multiply, and replenish the earth.
208	9	2	And the fear of you and the dread of you shall be upon every beast of the earth, and upon every fowl of the air, upon all that moveth upon the earth, and upon all the fishes of the sea; into your hand are they delivered.
209	9	3	Every moving thing that liveth shall be meat for you; even as the green herb have I given you all things.
210	9	4	But flesh with the life thereof, which is the blood thereof, shall ye not eat.
211	9	5	And surely your blood of your lives will I require; at the hand of every beast will I require it, and at the hand of man; at the hand of every man's brother will I require the life of man.
212	9	6	Whoso sheddeth man's blood, by man shall his blood be shed: for in the image of God made he man.
213	9	7	And you, be ye fruitful, and multiply; bring forth abundantly in the earth, and multiply therein.
214	9	8	And God spake unto Noah, and to his sons with him, saying,
215	9	9	And I, behold, I establish my covenant with you, and with your seed after you;
216	9	10	And with every living creature that is with you, of the fowl, of the cattle, and of every beast of the earth with you; from all that go out of the ark, to every beast of the earth.
217	9	11	And I will establish my covenant with you; neither shall all flesh be cut off any more by the waters of a flood; neither shall there any more be a flood to destroy the earth.
218	9	12	And God said, This is the token of the covenant which I make between me and you and every living creature that is with you, for perpetual generations:
219	9	13	I do set my bow in the cloud, and it shall be for a token of a covenant between me and the earth.
220	9	14	And it shall come to pass, when I bring a cloud over the earth, that the bow shall be seen in the cloud:
221	9	15	And I will remember my covenant, which is between me and you and every living creature of all flesh; and the waters shall no more become a flood to destroy all flesh.
222	9	16	And the bow shall be in the cloud; and I will look upon it, that I may remember the everlasting covenant between God and every living creature of all flesh that is upon the earth.
223	9	17	And God said unto Noah, This is the token of the covenant, which I have established between me and all flesh that is upon the earth.
224	9	18	And the sons of Noah, that went forth of the ark, were Shem, and Ham, and Japheth: and Ham is the father of Canaan.
225	9	19	These are the three sons of Noah: and of them was the whole earth overspread.
226	9	20	And Noah began to be an husbandman, and he planted a vineyard:
227	9	21	And he drank of the wine, and was drunken; and he was uncovered within his tent.
228	9	22	And Ham, the father of Canaan, saw the nakedness of his father, and told his two brethren without.
229	9	23	And Shem and Japheth took a garment, and laid it upon both their shoulders, and went backward, and covered the nakedness of their father; and their faces were backward, and they saw not their father's nakedness.
230	9	24	And Noah awoke from his wine, and knew what his younger son had done unto him.
231	9	25	And he said, Cursed be Canaan; a servant of servants shall he be unto his brethren.
232	9	26	And he said, Blessed be the LORD God of Shem; and Canaan shall be his servant.
233	9	27	God shall enlarge Japheth, and he shall dwell in the tents of Shem; and Canaan shall be his servant.
234	9	28	And Noah lived after the flood three hundred and fifty years.
235	9	29	And all the days of Noah were nine hundred and fifty years: and he died.
236	10	1	NOW these are the generations of the sons of Noah, Shem, Ham, and Japheth: and unto them were sons born after the flood.
237	10	2	The sons of Japheth; Gomer, and Magog, and Madai, and Javan, and Tubal, and Meshech, and Tiras.
238	10	3	And the sons of Gomer; Ashkenaz, and Riphath, and Togarmah.
239	10	4	And the sons of Javan; Elishah, and Tarshish, Kittim, and Dodanim.
240	10	5	By these were the isles of the Gentiles divided in their lands; every one after his tongue, after their families, in their nations.
241	10	6	And the sons of Ham; Cush, and Mizraim, and Phut, and Canaan.
242	10	7	And the sons of Cush; Seba, and Havilah, and Sabtah, and Raamah, and Sabtecha: and the sons of Raamah; Sheba, and Dedan.
243	10	8	And Cush begat Nimrod: he began to be a mighty one in the earth.
244	10	9	He was a mighty hunter before the LORD: wherefore it is said, Even as Nimrod the mighty hunter before the LORD.
245	10	10	And the beginning of his kingdom was Babel, and Erech, and Accad, and Calneh, in the land of Shinar.
246	10	11	Out of that land went forth Asshur, and builded Nineveh, and the city Rehoboth, and Calah,
247	10	12	And Resen between Nineveh and Calah: the same is a great city.
248	10	13	And Mizraim begat Ludim, and Anamim, and Lehabim, and Naphtuhim,
249	10	14	And Pathrusim, and Casluhim, (out of whom came Philistim,) and Caphtorim.
250	10	15	And Canaan begat Sidon his firstborn, and Heth,
251	10	16	And the Jebusite, and the Amorite, and the Girgasite,
252	10	17	And the Hivite, and the Arkite, and the Sinite,
253	10	18	And the Arvadite, and the Zemarite, and the Hamathite: and afterward were the families of the Canaanites spread abroad.
254	10	19	And the border of the Canaanites was from Sidon, as thou comest to Gerar, unto Gaza; as thou goest, unto Sodom, and Gomorrah, and Admah, and Zeboim, even unto Lasha.
255	10	20	These are the sons of Ham, after their families, after their tongues, in their countries, and in their nations.
256	10	21	Unto Shem also, the father of all the children of Eber, the brother of Japheth the elder, even to him were children born.
257	10	22	The children of Shem; Elam, and Asshur, and Arphaxad, and Lud, and Aram.
258	10	23	And the children of Aram; Uz, and Hul, and Gether, and Mash.
259	10	24	And Arphaxad begat Salah; and Salah begat Eber.
260	10	25	And unto Eber were born two sons: the name of one was Peleg; for in his days was the earth divided; and his brother's name was Joktan.
261	10	26	And Joktan begat Almodad, and Sheleph, and Hazarmaveth, and Jerah,
262	10	27	And Hadoram, and Uzal, and Diklah,
263	10	28	And Obal, and Abimael, and Sheba,
264	10	29	And Ophir, and Havilah, and Jobab: all these were the sons of Joktan.
265	10	30	And their dwelling was from Mesha, as thou goest unto Sephar a mount of the east.
266	10	31	These are the sons of Shem, after their families, after their tongues, in their lands, after their nations.
267	10	32	These are the families of the sons of Noah, after their generations, in their nations: and by these were the nations divided in the earth after the flood.
268	11	1	AND the whole earth was of one language, and of one speech.
269	11	2	And it came to pass, as they journeyed from the east, that they found a plain in the land of Shinar; and they dwelt there.
270	11	3	And they said one to another, Go to, let us make brick, and burn them throughly. And they had brick for stone, and slime had they for morter.
271	11	4	And they said, Go to, let us build us a city and a tower, whose top may reach unto heaven; and let us make us a name, lest we be scattered abroad upon the face of the whole earth.
272	11	5	And the LORD came down to see the city and the tower, which the children of men builded.
273	11	6	And the LORD said, Behold, the people is one, and they have all one language; and this they begin to do: and now nothing will be restrained from them, which they have imagined to do.
274	11	7	Go to, let us go down, and there confound their language, that they may not understand one another's speech.
275	11	8	So the LORD scattered them abroad from thence upon the face of all the earth: and they left off to build the city.
276	11	9	Therefore is the name of it called Babel; because the LORD did there confound the language of all the earth: and from thence did the LORD scatter them abroad upon the face of all the earth.
277	11	10	These are the generations of Shem: Shem was an hundred years old, and begat Arphaxad two years after the flood:
278	11	11	And Shem lived after he begat Arphaxad five hundred years, and begat sons and daughters.
279	11	12	And Arphaxad lived five and thirty years, and begat Salah:
280	11	13	And Arphaxad lived after he begat Salah four hundred and three years, and begat sons and daughters.
281	11	14	And Salah lived thirty years, and begat Eber:
282	11	15	And Salah lived after he begat Eber four hundred and three years, and begat sons and daughters.
283	11	16	And Eber lived four and thirty years, and begat Peleg:
284	11	17	And Eber lived after he begat Peleg four hundred and thirty years, and begat sons and daughters.
285	11	18	And Peleg lived thirty years, and begat Reu:
286	11	19	And Peleg lived after he begat Reu two hundred and nine years, and begat sons and daughters.
287	11	20	And Reu lived two and thirty years, and begat Serug:
288	11	21	And Reu lived after he begat Serug two hundred and seven years, and begat sons and daughters.
289	11	22	And Serug lived thirty years, and begat Nahor:
290	11	23	And Serug lived after he begat Nahor two hundred years, and begat sons and daughters.
291	11	24	And Nahor lived nine and twenty years, and begat Terah:
292	11	25	And Nahor lived after he begat Terah an hundred and nineteen years, and begat sons and daughters.
293	11	26	And Terah lived seventy years, and begat Abram, Nahor, and Haran.
294	11	27	Now these are the generations of Terah: Terah begat Abram, Nahor, and Haran; and Haran begat Lot.
295	11	28	And Haran died before his father Terah in the land of his nativity, in Ur of the Chaldees.
296	11	29	And Abram and Nahor took them wives: the name of Abram's wife was Sarai; and the name of Nahor's wife, Milcah, the daughter of Haran, the father of Milcah, and the father of Iscah.
297	11	30	But Sarai was barren; she had no child.
298	11	31	And Terah took Abram his son, and Lot the son of Haran his son's son, and Sarai his daughter in law, his son Abram's wife; and they went forth with them from Ur of the Chaldees, to go into the land of Canaan; and they came unto Haran, and dwelt there.
299	11	32	And the days of Terah were two hundred and five years: and Terah died in Haran.
300	12	1	NOW the LORD had said unto Abram, Get thee out of thy country, and from thy kindred, and from thy father's house, unto a land that I will shew thee:
301	12	2	And I will make of thee a great nation, and I will bless thee, and make thy name great; and thou shalt be a blessing:
302	12	3	And I will bless them that bless thee, and curse him that curseth thee: and in thee shall all families of the earth be blessed.
303	12	4	So Abram departed, as the LORD had spoken unto him; and Lot went with him: and Abram was seventy and five years old when he departed out of Haran.
304	12	5	And Abram took Sarai his wife, and Lot his brother's son, and all their substance that they had gathered, and the souls that they had gotten in Haran; and they went forth to go into the land of Canaan; and into the land of Canaan they came.
305	12	6	And Abram passed through the land unto the place of Sichem, unto the plain of Moreh. And the Canaanite was then in the land.
306	12	7	And the LORD appeared unto Abram, and said, Unto thy seed will I give this land: and there builded he an altar unto the LORD, who appeared unto him.
307	12	8	And he removed from thence unto a mountain on the east of Beth-el, and pitched his tent, having Beth-el on the west, and Hai on the east: and there he builded an altar unto the LORD, and called upon the name of the LORD.
308	12	9	And Abram journeyed, going on still toward the south.
309	12	10	And there was a famine in the land: and Abram went down into Egypt to sojourn there; for the famine was grievous in the land.
310	12	11	And it came to pass, when he was come near to enter into Egypt, that he said unto Sarai his wife, Behold now, I know that thou art a fair woman to look upon:
311	12	12	Therefore it shall come to pass, when the Egyptians shall see thee, that they shall say, This is his wife: and they will kill me, but they will save thee alive.
312	12	13	Say, I pray thee, thou art my sister: that it may be well with me for thy sake; and my soul shall live because of thee.
313	12	14	And it came to pass, that, when Abram was come into Egypt, the Egyptians beheld the woman that she was very fair.
314	12	15	The princes also of Pharaoh saw her, and commended her before Pharaoh: and the woman was taken into Pharaoh's house.
315	12	16	And he entreated Abram well for her sake: and he had sheep, and oxen, and he asses, and menservants, and maidservants, and she asses, and camels.
316	12	17	And the LORD plagued Pharaoh and his house with great plagues because of Sarai Abram's wife.
317	12	18	And Pharaoh called Abram, and said, What is this that thou hast done unto me? why didst thou not tell me that she was thy wife?
318	12	19	Why saidst thou, She is my sister? so I might have taken her to me to wife: now therefore behold thy wife, take her, and go thy way.
319	12	20	And Pharaoh commanded his men concerning him: and they sent him away, and his wife, and all that he had.
320	13	1	AND Abram went up out of Egypt, he, and his wife, and all that he had, and Lot with him, into the south.
321	13	2	And Abram was very rich in cattle, in silver, and in gold.
322	13	3	And he went on his journeys from the south even to Beth-el, unto the place where his tent had been at the beginning, between Beth-el and Hai;
323	13	4	Unto the place of the altar, which he had made there at the first: and there Abram called on the name of the LORD.
324	13	5	And Lot also, which went with Abram, had flocks, and herds, and tents.
325	13	6	And the land was not able to bear them, that they might dwell together: for their substance was great, so that they could not dwell together.
326	13	7	And there was a strife between the herdmen of Abram's cattle and the herdmen of Lot's cattle: and the Canaanite and the Perizzite dwelled then in the land.
327	13	8	And Abram said unto Lot, Let there be no strife, I pray thee, between me and thee, and between my herdmen and thy herdmen; for we be brethren.
328	13	9	Is not the whole land before thee? separate thyself, I pray thee, from me: if thou wilt take the left hand, then I will go to the right; or if thou depart to the right hand, then I will go to the left.
329	13	10	And Lot lifted up his eyes, and beheld all the plain of Jordan, that it was well watered every where, before the LORD destroyed Sodom and Gomorrah, even as the garden of the LORD, like the land of Egypt, as thou comest unto Zoar.
330	13	11	Then Lot chose him all the plain of Jordan; and Lot journeyed east: and they separated themselves the one from the other.
331	13	12	Abram dwelled in the land of Canaan, and Lot dwelled in the cities of the plain, and pitched his tent toward Sodom.
332	13	13	But the men of Sodom were wicked and sinners before the LORD exceedingly.
333	13	14	And the LORD said unto Abram, after that Lot was separated from him, Lift up now thine eyes, and look from the place where thou art northward, and southward, and eastward, and westward:
334	13	15	For all the land which thou seest, to thee will I give it, and to thy seed for ever.
335	13	16	And I will make thy seed as the dust of the earth: so that if a man can number the dust of the earth, then shall thy seed also be numbered.
336	13	17	Arise, walk through the land in the length of it and in the breadth of it; for I will give it unto thee.
337	13	18	Then Abram removed his tent, and came and dwelt in the plain of Mamre, which is in Hebron, and built there an altar unto the LORD.
338	14	1	AND it came to pass in the days of Amraphel king of Shinar, Arioch king of Ellasar, Chedorlaomer king of Elam, and Tidal king of nations;
339	14	2	That these made war with Bera king of Sodom, and with Birsha king of Gomorrah, Shinab king of Admah, and Shemeber king of Zeboiim, and the king of Bela, which is Zoar.
340	14	3	All these were joined together in the vale of Siddim, which is the salt sea.
341	14	4	Twelve years they served Chedorlaomer, and in the thirteenth year they rebelled.
342	14	5	And in the fourteenth year came Chedorlaomer, and the kings that were with him, and smote the Rephaims in Ashteroth Karnaim, and the Zuzims in Ham, and the Emims in Shaveh Kiriathaim,
343	14	6	And the Horites in their mount Seir, unto El-paran, which is by the wilderness.
344	14	7	And they returned, and came to En-mishpat, which is Kadesh, and smote all the country of the Amalekites, and also the Amorites, that dwelt in Hazezon-tamar.
345	14	8	And there went out the king of Sodom, and the king of Gomorrah, and the king of Admah, and the king of Zeboiim, and the king of Bela (the same is Zoar;) and they joined battle with them in the vale of Siddim;
346	14	9	With Chedorlaomer the king of Elam, and with Tidal king of nations, and Amraphel king of Shinar, and Arioch king of Ellasar; four kings with five.
347	14	10	And the vale of Siddim was full of slimepits; and the kings of Sodom and Gomorrah fled, and fell there; and they that remained fled to the mountain.
348	14	11	And they took all the goods of Sodom and Gomorrah, and all their victuals, and went their way.
349	14	12	And they took Lot, Abram's brother's son, who dwelt in Sodom, and his goods, and departed.
350	14	13	And there came one that had escaped, and told Abram the Hebrew; for he dwelt in the plain of Mamre the Amorite, brother of Eschol, and brother of Aner: and these were confederate with Abram.
351	14	14	And when Abram heard that his brother was taken captive, he armed his trained servants, born in his own house, three hundred and eighteen, and pursued them unto Dan.
352	14	15	And he divided himself against them, he and his servants, by night, and smote them, and pursued them unto Hobah, which is on the left hand of Damascus.
353	14	16	And he brought back all the goods, and also brought again his brother Lot, and his goods, and the women also, and the people.
354	14	17	And the king of Sodom went out to meet him after his return from the slaughter of Chedorlaomer, and of the kings that were with him, at the valley of Shaveh, which is the king's dale.
355	14	18	And Melchizedek king of Salem brought forth bread and wine: and he was the priest of the most high God.
356	14	19	And he blessed him, and said, Blessed be Abram of the most high God, possessor of heaven and earth:
357	14	20	And blessed be the most high God, which hath delivered thine enemies into thy hand. And he gave him tithes of all.
358	14	21	And the king of Sodom said unto Abram, Give me the persons, and take the goods to thyself.
359	14	22	And Abram said to the king of Sodom, I have lift up mine hand unto the LORD, the most high God, the possessor of heaven and earth,
360	14	23	That I will not take from a thread even to a shoelatchet, and that I will not take any thing that is thine, lest thou shouldest say, I have made Abram rich:
361	14	24	Save only that which the young men have eaten, and the portion of the men which went with me, Aner, Eshcol, and Mamre; let them take their portion.
362	15	1	AFTER these things the word of the LORD came unto Abram in a vision, saying, Fear not, Abram: I am thy shield, and thy exceeding great reward.
363	15	2	And Abram said, Lord GOD, what wilt thou give me, seeing I go childless, and the steward of my house is this Eliezer of Damascus?
364	15	3	And Abram said, Behold, to me thou hast given no seed: and, lo, one born in my house is mine heir.
365	15	4	And, behold, the word of the LORD came unto him, saying, This shall not be thine heir; but he that shall come forth out of thine own bowels shall be thine heir.
366	15	5	And he brought him forth abroad, and said, Look now toward heaven, and tell the stars, if thou be able to number them: and he said unto him, So shall thy seed be.
367	15	6	And he believed in the LORD; and he counted it to him for righteousness.
368	15	7	And he said unto him, I am the LORD that brought thee out of Ur of the Chaldees, to give thee this land to inherit it.
369	15	8	And he said, Lord GOD, whereby shall I know that I shall inherit it?
370	15	9	And he said unto him, Take me an heifer of three years old, and a she goat of three years old, and a ram of three years old, and a turtledove, and a young pigeon.
371	15	10	And he took unto him all these, and divided them in the midst, and laid each piece one against another: but the birds divided he not.
372	15	11	And when the fowls came down upon the carcases, Abram drove them away.
373	15	12	And when the sun was going down, a deep sleep fell upon Abram; and, lo, an horror of great darkness fell upon him.
374	15	13	And he said unto Abram, Know of a surety that thy seed shall be a stranger in a land that is not theirs, and shall serve them; and they shall afflict them four hundred years;
375	15	14	And also that nation, whom they shall serve, will I judge: and afterward shall they come out with great substance.
376	15	15	And thou shalt go to thy fathers in peace; thou shalt be buried in a good old age.
377	15	16	But in the fourth generation they shall come hither again: for the iniquity of the Amorites is not yet full.
378	15	17	And it came to pass, that, when the sun went down, and it was dark, behold a smoking furnace, and a burning lamp that passed between those pieces.
379	15	18	In the same day the LORD made a covenant with Abram, saying, Unto thy seed have I given this land, from the river of Egypt unto the great river, the river Euphrates:
380	15	19	The Kenites, and the Kenizzites, and the Kadmonites,
381	15	20	And the Hittites, and the Perizzites, and the Rephaims,
382	15	21	And the Amorites, and the Canaanites, and the Girgashites, and the Jebusites.
383	16	1	NOW Sarai Abram's wife bare him no children: and she had an handmaid, an Egyptian, whose name was Hagar.
384	16	2	And Sarai said unto Abram, Behold now, the LORD hath restrained me from bearing: I pray thee, go in unto my maid; it may be that I may obtain children by her. And Abram hearkened to the voice of Sarai.
385	16	3	And Sarai Abram's wife took Hagar her maid the Egyptian, after Abram had dwelt ten years in the land of Canaan, and gave her to her husband Abram to be his wife.
386	16	4	And he went in unto Hagar, and she conceived: and when she saw that she had conceived, her mistress was despised in her eyes.
387	16	5	And Sarai said unto Abram, My wrong be upon thee: I have given my maid into thy bosom; and when she saw that she had conceived, I was despised in her eyes: the LORD judge between me and thee.
388	16	6	But Abram said unto Sarai, Behold, thy maid is in thy hand; do to her as it pleaseth thee. And when Sarai dealt hardly with her, she fled from her face.
389	16	7	And the angel of the LORD found her by a fountain of water in the wilderness, by the fountain in the way to Shur.
390	16	8	And he said, Hagar, Sarai's maid, whence camest thou? and whither wilt thou go? And she said, I flee from the face of my mistress Sarai.
391	16	9	And the angel of the LORD said unto her, Return to thy mistress, and submit thyself under her hands.
392	16	10	And the angel of the LORD said unto her, I will multiply thy seed exceedingly, that it shall not be numbered for multitude.
393	16	11	And the angel of the LORD said unto her, Behold, thou art with child, and shalt bear a son, and shalt call his name Ishmael; because the LORD hath heard thy affliction.
394	16	12	And he will be a wild man; his hand will be against every man, and every man's hand against him; and he shall dwell in the presence of all his brethren.
395	16	13	And she called the name of the LORD that spake unto her, Thou God seest me: for she said, Have I also here looked after him that seeth me?
396	16	14	Wherefore the well was called Beer-lahai-roi; behold, it is between Kadesh and Bered.
397	16	15	And Hagar bare Abram a son: and Abram called his son's name, which Hagar bare, Ishmael.
398	16	16	And Abram was fourscore and six years old, when Hagar bare Ishmael to Abram.
399	17	1	AND when Abram was ninety years old and nine, the LORD appeared to Abram, and said unto him, I am the Almighty God; walk before me, and be thou perfect.
400	17	2	And I will make my covenant between me and thee, and will multiply thee exceedingly.
401	17	3	And Abram fell on his face: and God talked with him, saying,
402	17	4	As for me, behold, my covenant is with thee, and thou shalt be a father of many nations.
403	17	5	Neither shall thy name any more be called Abram, but thy name shall be Abraham; for a father of many nations have I made thee.
404	17	6	And I will make thee exceeding fruitful, and I will make nations of thee, and kings shall come out of thee.
405	17	7	And I will establish my covenant between me and thee and thy seed after thee in their generations for an everlasting covenant, to be a God unto thee, and to thy seed after thee.
406	17	8	And I will give unto thee, and to thy seed after thee, the land wherein thou art a stranger, all the land of Canaan, for an everlasting possession; and I will be their God.
407	17	9	And God said unto Abraham, Thou shalt keep my covenant therefore, thou, and thy seed after thee in their generations.
408	17	10	This is my covenant, which ye shall keep, between me and you and thy seed after thee; Every man child among you shall be circumcised.
409	17	11	And ye shall circumcise the flesh of your foreskin; and it shall be a token of the covenant betwixt me and you.
410	17	12	And he that is eight days old shall be circumcised among you, every man child in your generations, he that is born in the house, or bought with money of any stranger, which is not of thy seed.
411	17	13	He that is born in thy house, and he that is bought with thy money, must needs be circumcised: and my covenant shall be in your flesh for an everlasting covenant.
412	17	14	And the uncircumcised man child whose flesh of his foreskin is not circumcised, that soul shall be cut off from his people; he hath broken my covenant.
413	17	15	And God said unto Abraham, As for Sarai thy wife, thou shalt not call her name Sarai, but Sarah shall her name be.
414	17	16	And I will bless her, and give thee a son also of her: yea, I will bless her, and she shall be a mother of nations; kings of people shall be of her.
415	17	17	Then Abraham fell upon his face, and laughed, and said in his heart, Shall a child be born unto him that is an hundred years old? and shall Sarah, that is ninety years old, bear?
416	17	18	And Abraham said unto God, O that Ishmael might live before thee!
417	17	19	And God said, Sarah thy wife shall bear thee a son indeed; and thou shalt call his name Isaac: and I will establish my covenant with him for an everlasting covenant, and with his seed after him.
418	17	20	And as for Ishmael, I have heard thee: Behold, I have blessed him, and will make him fruitful, and will multiply him exceedingly; twelve princes shall he beget, and I will make him a great nation.
419	17	21	But my covenant will I establish with Isaac, which Sarah shall bear unto thee at this set time in the next year.
420	17	22	And he left off talking with him, and God went up from Abraham.
421	17	23	And Abraham took Ishmael his son, and all that were born in his house, and all that were bought with his money, every male among the men of Abraham's house; and circumcised the flesh of their foreskin in the selfsame day, as God had said unto him.
422	17	24	And Abraham was ninety years old and nine, when he was circumcised in the flesh of his foreskin.
423	17	25	And Ishmael his son was thirteen years old, when he was circumcised in the flesh of his foreskin.
424	17	26	In the selfsame day was Abraham circumcised, and Ishmael his son.
425	17	27	And all the men of his house, born in the house, and bought with money of the stranger, were circumcised with him.
426	18	1	AND the LORD appeared unto him in the plains of Mamre: and he sat in the tent door in the heat of the day;
427	18	2	And he lift up his eyes and looked, and, lo, three men stood by him: and when he saw them, he ran to meet them from the tent door, and bowed himself toward the ground,
428	18	3	And said, My Lord, if now I have found favour in thy sight, pass not away, I pray thee, from thy servant:
429	18	4	Let a little water, I pray you, be fetched, and wash your feet, and rest yourselves under the tree:
430	18	5	And I will fetch a morsel of bread, and comfort ye your hearts; after that ye shall pass on: for therefore are ye come to your servant. And they said, So do, as thou hast said.
431	18	6	And Abraham hastened into the tent unto Sarah, and said, Make ready quickly three measures of fine meal, knead it, and make cakes upon the hearth.
432	18	7	And Abraham ran unto the herd, and fetcht a calf tender and good, and gave it unto a young man; and he hasted to dress it.
433	18	8	And he took butter, and milk, and the calf which he had dressed, and set it before them; and he stood by them under the tree, and they did eat.
434	18	9	And they said unto him, Where is Sarah thy wife? And he said, Behold, in the tent.
435	18	10	And he said, I will certainly return unto thee according to the time of life; and, lo, Sarah thy wife shall have a son. And Sarah heard it in the tent door, which was behind him.
436	18	11	Now Abraham and Sarah were old and well stricken in age; and it ceased to be with Sarah after the manner of women.
437	18	12	Therefore Sarah laughed within herself, saying, After I am waxed old shall I have pleasure, my lord being old also?
438	18	13	And the LORD said unto Abraham, Wherefore did Sarah laugh, saying, Shall I of a surety bear a child, which am old?
439	18	14	Is any thing too hard for the LORD? At the time appointed I will return unto thee, according to the time of life, and Sarah shall have a son.
440	18	15	Then Sarah denied, saying, I laughed not; for she was afraid. And he said, Nay; but thou didst laugh.
441	18	16	And the men rose up from thence, and looked toward Sodom: and Abraham went with them to bring them on the way.
442	18	17	And the LORD said, Shall I hide from Abraham that thing which I do;
443	18	18	Seeing that Abraham shall surely become a great and mighty nation, and all the nations of the earth shall be blessed in him?
444	18	19	For I know him, that he will command his children and his household after him, and they shall keep the way of the LORD, to do justice and judgment; that the LORD may bring upon Abraham that which he hath spoken of him.
445	18	20	And the LORD said, Because the cry of Sodom and Gomorrah is great, and because their sin is very grievous;
446	18	21	I will go down now, and see whether they have done altogether according to the cry of it, which is come unto me; and if not, I will know.
447	18	22	And the men turned their faces from thence, and went toward Sodom: but Abraham stood yet before the LORD.
448	18	23	And Abraham drew near, and said, Wilt thou also destroy the righteous with the wicked?
449	18	24	Peradventure there be fifty righteous within the city: wilt thou also destroy and not spare the place for the fifty righteous that are therein?
450	18	25	That be far from thee to do after this manner, to slay the righteous with the wicked: and that the righteous should be as the wicked, that be far from thee: Shall not the Judge of all the earth do right?
451	18	26	And the LORD said, If I find in Sodom fifty righteous within the city, then I will spare all the place for their sakes.
452	18	27	And Abraham answered and said, Behold now, I have taken upon me to speak unto the Lord, which am but dust and ashes:
453	18	28	Peradventure there shall lack five of the fifty righteous: wilt thou destroy all the city for lack of five? And he said, If I find there forty and five, I will not destroy it.
454	18	29	And he spake unto him yet again, and said, Peradventure there shall be forty found there. And he said, I will not do it for forty's sake.
455	18	30	And he said unto him, Oh let not the Lord be angry, and I will speak: Peradventure there shall thirty be found there. And he said, I will not do it, if I find thirty there.
456	18	31	And he said, Behold now, I have taken upon me to speak unto the Lord: Peradventure there shall be twenty found there. And he said, I will not destroy it for twenty's sake.
457	18	32	And he said, Oh let not the Lord be angry, and I will speak yet but this once: Peradventure ten shall be found there. And he said, I will not destroy it for ten's sake.
458	18	33	And the LORD went his way, as soon as he had left communing with Abraham: and Abraham returned unto his place.
459	19	1	AND there came two angels to Sodom at even; and Lot sat in the gate of Sodom: and Lot seeing them rose up to meet them; and he bowed himself with his face toward the ground;
460	19	2	And he said, Behold now, my lords, turn in, I pray you, into your servant's house, and tarry all night, and wash your feet, and ye shall rise up early, and go on your ways. And they said, Nay; but we will abide in the street all night.
461	19	3	And he pressed upon them greatly; and they turned in unto him, and entered into his house; and he made them a feast, and did bake unleavened bread, and they did eat.
462	19	4	But before they lay down, the men of the city, even the men of Sodom, compassed the house round, both old and young, all the people from every quarter:
463	19	5	And they called unto Lot, and said unto him, Where are the men which came in to thee this night? bring them out unto us, that we may know them.
464	19	6	And Lot went out at the door unto them, and shut the door after him,
465	19	7	And said, I pray you, brethren, do not so wickedly.
466	19	8	Behold now, I have two daughters which have not known man; let me, I pray you, bring them out unto you, and do ye to them as is good in your eyes: only unto these men do nothing; for therefore came they under the shadow of my roof.
467	19	9	And they said, Stand back. And they said again, This one fellow came in to sojourn, and he will needs be a judge: now will we deal worse with thee, than with them. And they pressed sore upon the man, even Lot, and came near to break the door.
468	19	10	But the men put forth their hand, and pulled Lot into the house to them, and shut to the door.
469	19	11	And they smote the men that were at the door of the house with blindness, both small and great: so that they wearied themselves to find the door.
470	19	12	And the men said unto Lot, Hast thou here any besides? son in law, and thy sons, and thy daughters, and whatsoever thou hast in the city, bring them out of this place:
471	19	13	For we will destroy this place, because the cry of them is waxen great before the face of the LORD; and the LORD hath sent us to destroy it.
472	19	14	And Lot went out, and spake unto his sons in law, which married his daughters, and said, Up, get you out of this place; for the LORD will destroy this city. But he seemed as one that mocked unto his sons in law.
473	19	15	And when the morning arose, then the angels hastened Lot, saying, Arise, take thy wife, and thy two daughters, which are here; lest thou be consumed in the iniquity of the city.
474	19	16	And while he lingered, the men laid hold upon his hand, and upon the hand of his wife, and upon the hand of his two daughters; the LORD being merciful unto him: and they brought him forth, and set him without the city.
475	19	17	And it came to pass, when they had brought them forth abroad, that he said, Escape for thy life; look not behind thee, neither stay thou in all the plain; escape to the mountain, lest thou be consumed.
476	19	18	And Lot said unto them, Oh, not so, my Lord:
477	19	19	Behold now, thy servant hath found grace in thy sight, and thou hast magnified thy mercy, which thou hast shewed unto me in saving my life; and I cannot escape to the mountain, lest some evil take me, and I die:
478	19	20	Behold now, this city is near to flee unto, and it is a little one: Oh, let me escape thither, (is it not a little one?) and my soul shall live.
479	19	21	And he said unto him, See, I have accepted thee concerning this thing also, that I will not overthrow this city, for the which thou hast spoken.
480	19	22	Haste thee, escape thither; for I cannot do any thing till thou be come thither. Therefore the name of the city was called Zoar.
481	19	23	The sun was risen upon the earth when Lot entered into Zoar.
482	19	24	Then the LORD rained upon Sodom and upon Gomorrah brimstone and fire from the LORD out of heaven;
483	19	25	And he overthrew those cities, and all the plain, and all the inhabitants of the cities, and that which grew upon the ground.
484	19	26	But his wife looked back from behind him, and she became a pillar of salt.
485	19	27	And Abraham gat up early in the morning to the place where he stood before the LORD:
486	19	28	And he looked toward Sodom and Gomorrah, and toward all the land of the plain, and beheld, and, lo, the smoke of the country went up as the smoke of a furnace.
487	19	29	And it came to pass, when God destroyed the cities of the plain, that God remembered Abraham, and sent Lot out of the midst of the overthrow, when he overthrew the cities in the which Lot dwelt.
488	19	30	And Lot went up out of Zoar, and dwelt in the mountain, and his two daughters with him; for he feared to dwell in Zoar: and he dwelt in a cave, he and his two daughters.
489	19	31	And the firstborn said unto the younger, Our father is old, and there is not a man in the earth to come in unto us after the manner of all the earth:
490	19	32	Come, let us make our father drink wine, and we will lie with him, that we may preserve seed of our father.
491	19	33	And they made their father drink wine that night: and the firstborn went in, and lay with her father; and he perceived not when she lay down, nor when she arose.
492	19	34	And it came to pass on the morrow, that the firstborn said unto the younger, Behold, I lay yesternight with my father: let us make him drink wine this night also; and go thou in, and lie with him, that we may preserve seed of our father.
493	19	35	And they made their father drink wine that night also: and the younger arose, and lay with him; and he perceived not when she lay down, nor when she arose.
494	19	36	Thus were both the daughters of Lot with child by their father.
495	19	37	And the firstborn bare a son, and called his name Moab: the same is the father of the Moabites unto this day.
496	19	38	And the younger, she also bare a son, and called his name Benammi: the same is the father of the children of Ammon unto this day.
497	20	1	AND Abraham journeyed from thence toward the south country, and dwelled between Kadesh and Shur, and sojourned in Gerar.
498	20	2	And Abraham said of Sarah his wife, She is my sister: and Abimelech king of Gerar sent, and took Sarah.
499	20	3	But God came to Abimelech in a dream by night, and said to him, Behold, thou art but a dead man, for the woman which thou hast taken; for she is a man's wife.
500	20	4	But Abimelech had not come near her: and he said, Lord, wilt thou slay also a righteous nation?
501	20	5	Said he not unto me, She is my sister? and she, even she herself said, He is my brother: in the integrity of my heart and innocency of my hands have I done this.
502	20	6	And God said unto him in a dream, Yea, I know that thou didst this in the integrity of thy heart; for I also withheld thee from sinning against me: therefore suffered I thee not to touch her.
503	20	7	Now therefore restore the man his wife; for he is a prophet, and he shall pray for thee, and thou shalt live: and if thou restore her not, know thou that thou shalt surely die, thou, and all that are thine.
504	20	8	Therefore Abimelech rose early in the morning, and called all his servants, and told all these things in their ears: and the men were sore afraid.
505	20	9	Then Abimelech called Abraham, and said unto him, What hast thou done unto us? and what have I offended thee, that thou hast brought on me and on my kingdom a great sin? thou hast done deeds unto me that ought not to be done.
506	20	10	And Abimelech said unto Abraham, What sawest thou, that thou hast done this thing?
507	20	11	And Abraham said, Because I thought, Surely the fear of God is not in this place; and they will slay me for my wife's sake.
508	20	12	And yet indeed she is my sister; she is the daughter of my father, but not the daughter of my mother; and she became my wife.
509	20	13	And it came to pass, when God caused me to wander from my father's house, that I said unto her, This is thy kindness which thou shalt shew unto me; at every place whither we shall come, say of me, He is my brother.
510	20	14	And Abimelech took sheep, and oxen, and menservants, and womenservants, and gave them unto Abraham, and restored him Sarah his wife.
511	20	15	And Abimelech said, Behold, my land is before thee: dwell where it pleaseth thee.
512	20	16	And unto Sarah he said, Behold, I have given thy brother a thousand pieces of silver: behold, he is to thee a covering of the eyes, unto all that are with thee, and with all other: thus she was reproved.
513	20	17	So Abraham prayed unto God: and God healed Abimelech, and his wife, and his maidservants; and they bare children.
514	20	18	For the LORD had fast closed up all the wombs of the house of Abimelech, because of Sarah Abraham's wife.
515	21	1	AND the LORD visited Sarah as he had said, and the LORD did unto Sarah as he had spoken.
516	21	2	For Sarah conceived, and bare Abraham a son in his old age, at the set time of which God had spoken to him.
517	21	3	And Abraham called the name of his son that was born unto him, whom Sarah bare to him, Isaac.
518	21	4	And Abraham circumcised his son Isaac being eight days old, as God had commanded him.
519	21	5	And Abraham was an hundred years old, when his son Isaac was born unto him.
520	21	6	And Sarah said, God hath made me to laugh, so that all that hear will laugh with me.
521	21	7	And she said, Who would have said unto Abraham, that Sarah should have given children suck? for I have born him a son in his old age.
522	21	8	And the child grew, and was weaned: and Abraham made a great feast the same day that Isaac was weaned.
523	21	9	And Sarah saw the son of Hagar the Egyptian, which she had born unto Abraham, mocking.
524	21	10	Wherefore she said unto Abraham, Cast out this bondwoman and her son: for the son of this bondwoman shall not be heir with my son, even with Isaac.
525	21	11	And the thing was very grievous in Abraham's sight because of his son.
526	21	12	And God said unto Abraham, Let it not be grievous in thy sight because of the lad, and because of thy bondwoman; in all that Sarah hath said unto thee, hearken unto her voice; for in Isaac shall thy seed be called.
527	21	13	And also of the son of the bondwoman will I make a nation, because he is thy seed.
528	21	14	And Abraham rose up early in the morning, and took bread, and a bottle of water, and gave it unto Hagar, putting it on her shoulder, and the child, and sent her away: and she departed, and wandered in the wilderness of Beer-sheba.
529	21	15	And the water was spent in the bottle, and she cast the child under one of the shrubs.
530	21	16	And she went, and sat her down over against him a good way off, as it were a bowshot: for she said, Let me not see the death of the child. And she sat over against him, and lift up her voice, and wept.
531	21	17	And God heard the voice of the lad; and the angel of God called to Hagar out of heaven, and said unto her, What aileth thee, Hagar? fear not; for God hath heard the voice of the lad where he is.
532	21	18	Arise, lift up the lad, and hold him in thine hand; for I will make him a great nation.
533	21	19	And God opened her eyes, and she saw a well of water; and she went, and filled the bottle with water, and gave the lad drink.
534	21	20	And God was with the lad; and he grew, and dwelt in the wilderness, and became an archer.
535	21	21	And he dwelt in the wilderness of Paran: and his mother took him a wife out of the land of Egypt.
536	21	22	And it came to pass at that time, that Abimelech and Phichol the chief captain of his host spake unto Abraham, saying, God is with thee in all that thou doest:
537	21	23	Now therefore swear unto me here by God that thou wilt not deal falsely with me, nor with my son, nor with my son's son: but according to the kindness that I have done unto thee, thou shalt do unto me, and to the land wherein thou hast sojourned.
538	21	24	And Abraham said, I will swear.
539	21	25	And Abraham reproved Abimelech because of a well of water, which Abimelech's servants had violently taken away.
540	21	26	And Abimelech said, I wot not who hath done this thing: neither didst thou tell me, neither yet heard I of it, but to day.
541	21	27	And Abraham took sheep and oxen, and gave them unto Abimelech; and both of them made a covenant.
542	21	28	And Abraham set seven ewe lambs of the flock by themselves.
543	21	29	And Abimelech said unto Abraham, What mean these seven ewe lambs which thou hast set by themselves?
544	21	30	And he said, For these seven ewe lambs shalt thou take of my hand, that they may be a witness unto me, that I have digged this well.
545	21	31	Wherefore he called that place Beer-sheba; because there they sware both of them.
546	21	32	Thus they made a covenant at Beer-sheba: then Abimelech rose up, and Phichol the chief captain of his host, and they returned into the land of the Philistines.
547	21	33	And Abraham planted a grove in Beer-sheba, and called there on the name of the LORD, the everlasting God.
548	21	34	And Abraham sojourned in the Philistines' land many days.
549	22	1	AND it came to pass after these things, that God did tempt Abraham, and said unto him, Abraham: and he said, Behold, here I am.
550	22	2	And he said, Take now thy son, thine only son Isaac, whom thou lovest, and get thee into the land of Moriah; and offer him there for a burnt offering upon one of the mountains which I will tell thee of.
551	22	3	And Abraham rose up early in the morning, and saddled his ass, and took two of his young men with him, and Isaac his son, and clave the wood for the burnt offering, and rose up, and went unto the place of which God had told him.
552	22	4	Then on the third day Abraham lifted up his eyes, and saw the place afar off.
553	22	5	And Abraham said unto his young men, Abide ye here with the ass; and I and the lad will go yonder and worship, and come again to you.
554	22	6	And Abraham took the wood of the burnt offering, and laid it upon Isaac his son; and he took the fire in his hand, and a knife; and they went both of them together.
555	22	7	And Isaac spake unto Abraham his father, and said, My father: and he said, Here am I, my son. And he said, Behold the fire and the wood: but where is the lamb for a burnt offering?
556	22	8	And Abraham said, My son, God will provide himself a lamb for a burnt offering: so they went both of them together.
557	22	9	And they came to the place which God had told him of; and Abraham built an altar there, and laid the wood in order, and bound Isaac his son, and laid him on the altar upon the wood.
558	22	10	And Abraham stretched forth his hand, and took the knife to slay his son.
559	22	11	And the angel of the LORD called unto him out of heaven, and said, Abraham, Abraham: and he said, Here am I.
560	22	12	And he said, Lay not thine hand upon the lad, neither do thou any thing unto him: for now I know that thou fearest God, seeing thou hast not withheld thy son, thine only son from me.
561	22	13	And Abraham lifted up his eyes, and looked, and behold behind him a ram caught in a thicket by his horns: and Abraham went and took the ram, and offered him up for a burnt offering in the stead of his son.
562	22	14	And Abraham called the name of that place Jehovah-jireh: as it is said to this day, In the mount of the LORD it shall be seen.
563	22	15	And the angel of the LORD called unto Abraham out of heaven the second time,
564	22	16	And said, By myself have I sworn, saith the LORD, for because thou hast done this thing, and hast not withheld thy son, thine only son:
565	22	17	That in blessing I will bless thee, and in multiplying I will multiply thy seed as the stars of the heaven, and as the sand which is upon the sea shore; and thy seed shall possess the gate of his enemies;
566	22	18	And in thy seed shall all the nations of the earth be blessed; because thou hast obeyed my voice.
567	22	19	So Abraham returned unto his young men, and they rose up and went together to Beer-sheba; and Abraham dwelt at Beer-sheba.
568	22	20	And it came to pass after these things, that it was told Abraham, saying, Behold, Milcah, she hath also born children unto thy brother Nahor;
569	22	21	Huz his firstborn, and Buz his brother, and Kemuel the father of Aram,
570	22	22	And Chesed, and Hazo, and Pildash, and Jidlaph, and Bethuel.
571	22	23	And Bethuel begat Rebekah: these eight Milcah did bear to Nahor, Abraham's brother.
572	22	24	And his concubine, whose name was Reumah, she bare also Tebah, and Gaham, and Thahash, and Maachah.
573	23	1	AND Sarah was an hundred and seven and twenty years old: these were the years of the life of Sarah.
574	23	2	And Sarah died in Kirjath-arba; the same is Hebron in the land of Canaan: and Abraham came to mourn for Sarah, and to weep for her.
575	23	3	And Abraham stood up from before his dead, and spake unto the sons of Heth, saying,
576	23	4	I am a stranger and a sojourner with you: give me a possession of a buryingplace with you, that I may bury my dead out of my sight.
577	23	5	And the children of Heth answered Abraham, saying unto him,
578	23	6	Hear us, my lord: thou art a mighty prince among us: in the choice of our sepulchres bury thy dead; none of us shall withhold from thee his sepulchre, but that thou mayest bury thy dead.
579	23	7	And Abraham stood up, and bowed himself to the people of the land, even to the children of Heth.
580	23	8	And he communed with them, saying, If it be your mind that I should bury my dead out of my sight; hear me, and intreat for me to Ephron the son of Zohar,
581	23	9	That he may give me the cave of Machpelah, which he hath, which is in the end of his field; for as much money as it is worth he shall give it me for a possession of a buryingplace amongst you.
582	23	10	And Ephron dwelt among the children of Heth: and Ephron the Hittite answered Abraham in the audience of the children of Heth, even of all that went in at the gate of his city, saying,
583	23	11	Nay, my lord, hear me: the field give I thee, and the cave that is therein, I give it thee; in the presence of the sons of my people give I it thee: bury thy dead.
584	23	12	And Abraham bowed down himself before the people of the land.
585	23	13	And he spake unto Ephron in the audience of the people of the land, saying, But if thou wilt give it, I pray thee, hear me: I will give thee money for the field; take it of me, and I will bury my dead there.
586	23	14	And Ephron answered Abraham, saying unto him,
587	23	15	My lord, hearken unto me: the land is worth four hundred shekels of silver; what is that betwixt me and thee? bury therefore thy dead.
588	23	16	And Abraham hearkened unto Ephron; and Abraham weighed to Ephron the silver, which he had named in the audience of the sons of Heth, four hundred shekels of silver, current money with the merchant.
589	23	17	And the field of Ephron, which was in Machpelah, which was before Mamre, the field, and the cave which was therein, and all the trees that were in the field, that were in all the borders round about, were made sure
590	23	18	Unto Abraham for a possession in the presence of the children of Heth, before all that went in at the gate of his city.
591	23	19	And after this, Abraham buried Sarah his wife in the cave of the field of Machpelah before Mamre: the same is Hebron in the land of Canaan.
592	23	20	And the field, and the cave that is therein, were made sure unto Abraham for a possession of a buryingplace by the sons of Heth.
593	24	1	AND Abraham was old, and well stricken in age: and the LORD had blessed Abraham in all things.
594	24	2	And Abraham said unto his eldest servant of his house, that ruled over all that he had, Put, I pray thee, thy hand under my thigh:
595	24	3	And I will make thee swear by the LORD, the God of heaven, and the God of the earth, that thou shalt not take a wife unto my son of the daughters of the Canaanites, among whom I dwell:
596	24	4	But thou shalt go unto my country, and to my kindred, and take a wife unto my son Isaac.
597	24	5	And the servant said unto him, Peradventure the woman will not be willing to follow me unto this land: must I needs bring thy son again unto the land from whence thou camest?
598	24	6	And Abraham said unto him, Beware thou that thou bring not my son thither again.
599	24	7	The LORD God of heaven, which took me from my father's house, and from the land of my kindred, and which spake unto me, and that sware unto me, saying, Unto thy seed will I give this land; he shall send his angel before thee, and thou shalt take a wife unto my son from thence.
600	24	8	And if the woman will not be willing to follow thee, then thou shalt be clear from this my oath: only bring not my son thither again.
601	24	9	And the servant put his hand under the thigh of Abraham his master, and sware to him concerning that matter.
602	24	10	And the servant took ten camels of the camels of his master, and departed; for all the goods of his master were in his hand: and he arose, and went to Mesopotamia, unto the city of Nahor.
603	24	11	And he made his camels to kneel down without the city by a well of water at the time of the evening, even the time that women go out to draw water.
604	24	12	And he said, O LORD God of my master Abraham, I pray thee, send me good speed this day, and shew kindness unto my master Abraham.
605	24	13	Behold, I stand here by the well of water; and the daughters of the men of the city come out to draw water:
606	24	14	And let it come to pass, that the damsel to whom I shall say, Let down thy pitcher, I pray thee, that I may drink; and she shall say, Drink, and I will give thy camels drink also: let the same be she that thou hast appointed for thy servant Isaac; and thereby shall I know that thou hast shewed kindness unto my master.
607	24	15	And it came to pass, before he had done speaking, that, behold, Rebekah came out, who was born to Bethuel, son of Milcah, the wife of Nahor, Abraham's brother, with her pitcher upon her shoulder.
608	24	16	And the damsel was very fair to look upon, a virgin, neither had any man known her: and she went down to the well, and filled her pitcher, and came up.
609	24	17	And the servant ran to meet her, and said, Let me, I pray thee, drink a little water of thy pitcher.
610	24	18	And she said, Drink, my lord: and she hasted, and let down her pitcher upon her hand, and gave him drink.
611	24	19	And when she had done giving him drink, she said, I will draw water for thy camels also, until they have done drinking.
612	24	20	And she hasted, and emptied her pitcher into the trough, and ran again unto the well to draw water, and drew for all his camels.
613	24	21	And the man wondering at her held his peace, to wit whether the LORD had made his journey prosperous or not.
614	24	22	And it came to pass, as the camels had done drinking, that the man took a golden earring of half a shekel weight, and two bracelets for her hands of ten shekels weight of gold;
615	24	23	And said, Whose daughter art thou? tell me, I pray thee: is there room in thy father's house for us to lodge in?
616	24	24	And she said unto him, I am the daughter of Bethuel the son of Milcah, which she bare unto Nahor.
617	24	25	She said moreover unto him, We have both straw and provender enough, and room to lodge in.
618	24	26	And the man bowed down his head, and worshipped the LORD.
619	24	27	And he said, Blessed be the LORD God of my master Abraham, who hath not left destitute my master of his mercy and his truth: I being in the way, the LORD led me to the house of my master's brethren.
620	24	28	And the damsel ran, and told them of her mother's house these things.
621	24	29	And Rebekah had a brother, and his name was Laban: and Laban ran out unto the man, unto the well.
622	24	30	And it came to pass, when he saw the earring and bracelets upon his sister's hands, and when he heard the words of Rebekah his sister, saying, Thus spake the man unto me; that he came unto the man; and, behold, he stood by the camels at the well.
623	24	31	And he said, Come in, thou blessed of the LORD; wherefore standest thou without? for I have prepared the house, and room for the camels.
624	24	32	And the man came into the house: and he ungirded his camels, and gave straw and provender for the camels, and water to wash his feet, and the men's feet that were with him.
625	24	33	And there was set meat before him to eat: but he said, I will not eat, until I have told mine errand. And he said, Speak on.
626	24	34	And he said, I am Abraham's servant.
627	24	35	And the LORD hath blessed my master greatly; and he is become great: and he hath given him flocks, and herds, and silver, and gold, and menservants, and maidservants, and camels, and asses.
628	24	36	And Sarah my master's wife bare a son to my master when she was old: and unto him hath he given all that he hath.
629	24	37	And my master made me swear, saying, Thou shalt not take a wife to my son of the daughters of the Canaanites, in whose land I dwell:
630	24	38	But thou shalt go unto my father's house, and to my kindred, and take a wife unto my son.
631	24	39	And I said unto my master, Peradventure the woman will not follow me.
632	24	40	And he said unto me, The LORD, before whom I walk, will send his angel with thee, and prosper thy way; and thou shalt take a wife for my son of my kindred, and of my father's house:
633	24	41	Then shalt thou be clear from this my oath, when thou comest to my kindred; and if they give not thee one, thou shalt be clear from my oath.
634	24	42	And I came this day unto the well, and said, O LORD God of my master Abraham, if now thou do prosper my way which I go:
635	24	43	Behold, I stand by the well of water; and it shall come to pass, that when the virgin cometh forth to draw water, and I say to her, Give me, I pray thee, a little water of thy pitcher to drink;
636	24	44	And she say to me, Both drink thou, and I will also draw for thy camels: let the same be the woman whom the LORD hath appointed out for my master's son.
637	24	45	And before I had done speaking in mine heart, behold, Rebekah came forth with her pitcher on her shoulder; and she went down unto the well, and drew water: and I said unto her, Let me drink, I pray thee.
638	24	46	And she made haste, and let down her pitcher from her shoulder, and said, Drink, and I will give thy camels drink also: so I drank, and she made the camels drink also.
639	24	47	And I asked her, and said, Whose daughter art thou? And she said, The daughter of Bethuel, Nahor's son, whom Milcah bare unto him: and I put the earring upon her face, and the bracelets upon her hands.
640	24	48	And I bowed down my head, and worshipped the LORD, and blessed the LORD God of my master Abraham, which had led me in the right way to take my master's brother's daughter unto his son.
641	24	49	And now if ye will deal kindly and truly with my master, tell me: and if not, tell me; that I may turn to the right hand, or to the left.
642	24	50	Then Laban and Bethuel answered and said, The thing proceedeth from the LORD: we cannot speak unto thee bad or good.
643	24	51	Behold, Rebekah is before thee, take her, and go, and let her be thy master's son's wife, as the LORD hath spoken.
644	24	52	And it came to pass, that, when Abraham's servant heard their words, he worshipped the LORD, bowing himself to the earth.
645	24	53	And the servant brought forth jewels of silver, and jewels of gold, and raiment, and gave them to Rebekah: he gave also to her brother and to her mother precious things.
646	24	54	And they did eat and drink, he and the men that were with him, and tarried all night; and they rose up in the morning, and he said, Send me away unto my master.
647	24	55	And her brother and her mother said, Let the damsel abide with us a few days, at the least ten; after that she shall go.
648	24	56	And he said unto them, Hinder me not, seeing the LORD hath prospered my way; send me away that I may go to my master.
649	24	57	And they said, We will call the damsel, and enquire at her mouth.
650	24	58	And they called Rebekah, and said unto her, Wilt thou go with this man? And she said, I will go.
651	24	59	And they sent away Rebekah their sister, and her nurse, and Abraham's servant, and his men.
652	24	60	And they blessed Rebekah, and said unto her, Thou art our sister, be thou the mother of thousands of millions, and let thy seed possess the gate of those which hate them.
653	24	61	And Rebekah arose, and her damsels, and they rode upon the camels, and followed the man: and the servant took Rebekah, and went his way.
654	24	62	And Isaac came from the way of the well Lahai-roi; for he dwelt in the south country.
655	24	63	And Isaac went out to meditate in the field at the eventide: and he lifted up his eyes, and saw, and, behold, the camels were coming.
656	24	64	And Rebekah lifted up her eyes, and when she saw Isaac, she lighted off the camel.
657	24	65	For she had said unto the servant, What man is this that walketh in the field to meet us? And the servant had said, It is my master: therefore she took a vail, and covered herself.
658	24	66	And the servant told Isaac all things that he had done.
659	24	67	And Isaac brought her into his mother Sarah's tent, and took Rebekah, and she became his wife; and he loved her: and Isaac was comforted after his mother's death.
660	25	1	THEN again Abraham took a wife, and her name was Keturah.
661	25	2	And she bare him Zimran, and Jokshan, and Medan, and Midian, and Ishbak, and Shuah.
662	25	3	And Jokshan begat Sheba, and Dedan. And the sons of Dedan were Asshurim, and Letushim, and Leummim.
663	25	4	And the sons of Midian; Ephah, and Epher, and Hanoch, and Abida, and Eldaah. All these were the children of Keturah.
664	25	5	And Abraham gave all that he had unto Isaac.
665	25	6	But unto the sons of the concubines, which Abraham had, Abraham gave gifts, and sent them away from Isaac his son, while he yet lived, eastward, unto the east country.
666	25	7	And these are the days of the years of Abraham's life which he lived, an hundred threescore and fifteen years.
667	25	8	Then Abraham gave up the ghost, and died in a good old age, an old man, and full of years; and was gathered to his people.
668	25	9	And his sons Isaac and Ishmael buried him in the cave of Machpelah, in the field of Ephron the son of Zohar the Hittite, which is before Mamre;
669	25	10	The field which Abraham purchased of the sons of Heth: there was Abraham buried, and Sarah his wife.
670	25	11	And it came to pass after the death of Abraham, that God blessed his son Isaac; and Isaac dwelt by the well Lahai-roi.
671	25	12	Now these are the generations of Ishmael, Abraham's son, whom Hagar the Egyptian, Sarah's handmaid, bare unto Abraham:
672	25	13	And these are the names of the sons of Ishmael, by their names, according to their generations: the firstborn of Ishmael, Nebajoth; and Kedar, and Adbeel, and Mibsam,
673	25	14	And Mishma, and Dumah, and Massa,
674	25	15	Hadar, and Tema, Jetur, Naphish, and Kedemah:
675	25	16	These are the sons of Ishmael, and these are their names, by their towns, and by their castles; twelve princes according to their nations.
676	25	17	And these are the years of the life of Ishmael, an hundred and thirty and seven years: and he gave up the ghost and died; and was gathered unto his people.
677	25	18	And they dwelt from Havilah unto Shur, that is before Egypt, as thou goest toward Assyria: and he died in the presence of all his brethren.
678	25	19	And these are the generations of Isaac, Abraham's son: Abraham begat Isaac:
679	25	20	And Isaac was forty years old when he took Rebekah to wife, the daughter of Bethuel the Syrian of Padan-aram, the sister to Laban the Syrian.
680	25	21	And Isaac intreated the LORD for his wife, because she was barren: and the LORD was intreated of him, and Rebekah his wife conceived.
681	25	22	And the children struggled together within her; and she said, If it be so, why am I thus? And she went to enquire of the LORD.
682	25	23	And the LORD said unto her, Two nations are in thy womb, and two manner of people shall be separated from thy bowels; and the one people shall be stronger than the other people; and the elder shall serve the younger.
683	25	24	And when her days to be delivered were fulfilled, behold, there were twins in her womb.
684	25	25	And the first came out red, all over like an hairy garment; and they called his name Esau.
685	25	26	And after that came his brother out, and his hand took hold on Esau's heel; and his name was called Jacob: and Isaac was threescore years old when she bare them.
686	25	27	And the boys grew: and Esau was a cunning hunter, a man of the field; and Jacob was a plain man, dwelling in tents.
687	25	28	And Isaac loved Esau, because he did eat of his venison: but Rebekah loved Jacob.
688	25	29	And Jacob sod pottage: and Esau came from the field, and he was faint:
689	25	30	And Esau said to Jacob, Feed me, I pray thee, with that same red pottage; for I am faint: therefore was his name called Edom.
690	25	31	And Jacob said, Sell me this day thy birthright.
691	25	32	And Esau said, Behold, I am at the point to die: and what profit shall this birthright do to me?
692	25	33	And Jacob said, Swear to me this day; and he sware unto him: and he sold his birthright unto Jacob.
693	25	34	Then Jacob gave Esau bread and pottage of lentiles; and he did eat and drink, and rose up, and went his way: thus Esau despised his birthright.
694	26	1	AND there was a famine in the land, beside the first famine that was in the days of Abraham. And Isaac went unto Abimelech king of the Philistines unto Gerar.
695	26	2	And the LORD appeared unto him, and said, Go not down into Egypt; dwell in the land which I shall tell thee of:
696	26	3	Sojourn in this land, and I will be with thee, and will bless thee; for unto thee, and unto thy seed, I will give all these countries, and I will perform the oath which I sware unto Abraham thy father;
697	26	4	And I will make thy seed to multiply as the stars of heaven, and will give unto thy seed all these countries; and in thy seed shall all the nations of the earth be blessed;
698	26	5	Because that Abraham obeyed my voice, and kept my charge, my commandments, my statutes, and my laws.
699	26	6	And Isaac dwelt in Gerar:
700	26	7	And the men of the place asked him of his wife; and he said, She is my sister: for he feared to say, She is my wife; lest, said he, the men of the place should kill me for Rebekah; because she was fair to look upon.
701	26	8	And it came to pass, when he had been there a long time, that Abimelech king of the Philistines looked out at a window, and saw, and, behold, Isaac was sporting with Rebekah his wife.
702	26	9	And Abimelech called Isaac, and said, Behold, of a surety she is thy wife: and how saidst thou, She is my sister? And Isaac said unto him, Because I said, Lest I die for her.
703	26	10	And Abimelech said, What is this thou hast done unto us? one of the people might lightly have lien with thy wife, and thou shouldest have brought guiltiness upon us.
704	26	11	And Abimelech charged all his people, saying, He that toucheth this man or his wife shall surely be put to death.
705	26	12	Then Isaac sowed in that land, and received in the same year an hundredfold: and the LORD blessed him.
706	26	13	And the man waxed great, and went forward, and grew until he became very great:
707	26	14	For he had possession of flocks, and possession of herds, and great store of servants: and the Philistines envied him.
708	26	15	For all the wells which his father's servants had digged in the days of Abraham his father, the Philistines had stopped them, and filled them with earth.
709	26	16	And Abimelech said unto Isaac, Go from us; for thou art much mightier than we.
710	26	17	And Isaac departed thence, and pitched his tent in the valley of Gerar, and dwelt there.
711	26	18	And Isaac digged again the wells of water, which they had digged in the days of Abraham his father; for the Philistines had stopped them after the death of Abraham: and he called their names after the names by which his father had called them.
712	26	19	And Isaac's servants digged in the valley, and found there a well of springing water.
713	26	20	And the herdmen of Gerar did strive with Isaac's herdmen, saying, The water is ours: and he called the name of the well Esek; because they strove with him.
714	26	21	And they digged another well, and strove for that also: and he called the name of it Sitnah.
715	26	22	And he removed from thence, and digged another well; and for that they strove not: and he called the name of it Rehoboth; and he said, For now the LORD hath made room for us, and we shall be fruitful in the land.
716	26	23	And he went up from thence to Beer-sheba.
717	26	24	And the LORD appeared unto him the same night, and said, I am the God of Abraham thy father: fear not, for I am with thee, and will bless thee, and multiply thy seed for my servant Abraham's sake.
718	26	25	And he builded an altar there, and called upon the name of the LORD and pitched his tent there: and there Isaac's servants digged a well.
719	26	26	Then Abimelech went to him from Gerar, and Ahuzzath one of his friends, and Phichol the chief captain of his army.
720	26	27	And Isaac said unto them, Wherefore come ye to me, seeing ye hate me, and have sent me away from you?
721	26	28	And they said, We saw certainly that the LORD was with thee: and we said, Let there be now an oath betwixt us, even betwixt us and thee, and let us make a covenant with thee;
722	26	29	That thou wilt do us no hurt, as we have not touched thee, and as we have done unto thee nothing but good, and have sent thee away in peace: thou art now the blessed of the LORD.
723	26	30	And he made them a feast, and they did eat and drink.
724	26	31	And they rose up betimes in the morning, and sware one to another: and Isaac sent them away, and they departed from him in peace.
725	26	32	And it came to pass the same day, that Isaac's servants came, and told him concerning the well which they had digged, and said unto him, We have found water.
726	26	33	And he called it Shebah: therefore the name of the city is Beer-sheba unto this day.
727	26	34	And Esau was forty years old when he took to wife Judith the daughter of Beeri the Hittite, and Bashemath the daughter of Elon the Hittite:
728	26	35	Which were a grief of mind unto Isaac and to Rebekah.
729	27	1	AND it came to pass, that when Isaac was old, and his eyes were dim, so that he could not see, he called Esau his eldest son, and said unto him, My son: and he said unto him, Behold, here am I.
730	27	2	And he said, Behold now, I am old, I know not the day of my death:
731	27	3	Now therefore take, I pray thee, thy weapons, thy quiver and thy bow, and go out to the field, and take me some venison;
732	27	4	And make me savoury meat, such as I love, and bring it to me, that I may eat; that my soul may bless thee before I die.
733	27	5	And Rebekah heard when Isaac spake to Esau his son. And Esau went to the field to hunt for venison, and to bring it.
734	27	6	And Rebekah spake unto Jacob her son, saying, Behold, I heard thy father speak unto Esau thy brother, saying,
735	27	7	Bring me venison, and make me savoury meat, that I may eat, and bless thee before the LORD before my death.
736	27	8	Now therefore, my son, obey my voice according to that which I command thee.
737	27	9	Go now to the flock, and fetch me from thence two good kids of the goats; and I will make them savoury meat for thy father, such as he loveth:
738	27	10	And thou shalt bring it to thy father, that he may eat, and that he may bless thee before his death.
739	27	11	And Jacob said to Rebekah his mother, Behold, Esau my brother is a hairy man, and I am a smooth man:
740	27	12	My father peradventure will feel me, and I shall seem to him as a deceiver; and I shall bring a curse upon me, and not a blessing.
741	27	13	And his mother said unto him, Upon me be thy curse, my son: only obey my voice, and go fetch me them.
742	27	14	And he went, and fetched, and brought them to his mother: and his mother made savoury meat, such as his father loved.
743	27	15	And Rebekah took goodly raiment of her eldest son Esau, which were with her in the house, and put them upon Jacob her younger son:
744	27	16	And she put the skins of the kids of the goats upon his hands, and upon the smooth of his neck:
745	27	17	And she gave the savoury meat and the bread, which she had prepared, into the hand of her son Jacob.
746	27	18	And he came unto his father, and said, My father: and he said, Here am I; who art thou, my son?
747	27	19	And Jacob said unto his father, I am Esau thy firstborn; I have done according as thou badest me: arise, I pray thee, sit and eat of my venison, that thy soul may bless me.
748	27	20	And Isaac said unto his son, How is it that thou hast found it so quickly, my son? And he said, Because the LORD thy God brought it to me.
749	27	21	And Isaac said unto Jacob, Come near, I pray thee, that I may feel thee, my son, whether thou be my very son Esau or not.
750	27	22	And Jacob went near unto Isaac his father; and he felt him, and said, The voice is Jacob's voice, but the hands are the hands of Esau.
751	27	23	And he discerned him not, because his hands were hairy, as his brother Esau's hands: so he blessed him.
752	27	24	And he said, Art thou my very son Esau? And he said, I am.
753	27	25	And he said, Bring it near to me, and I will eat of my son's venison, that my soul may bless thee. And he brought it near to him, and he did eat: and he brought him wine, and he drank.
754	27	26	And his father Isaac said unto him, Come near now, and kiss me, my son.
755	27	27	And he came near, and kissed him: and he smelled the smell of his raiment, and blessed him, and said, See, the smell of my son is as the smell of a field which the LORD hath blessed:
756	27	28	Therefore God give thee of the dew of heaven, and the fatness of the earth, and plenty of corn and wine:
757	27	29	Let people serve thee, and nations bow down to thee: be lord over thy brethren, and let thy mother's sons bow down to thee: cursed be every one that curseth thee, and blessed be he that blesseth thee.
758	27	30	And it came to pass, as soon as Isaac had made an end of blessing Jacob, and Jacob was yet scarce gone out from the presence of Isaac his father, that Esau his brother came in from his hunting.
759	27	31	And he also had made savoury meat, and brought it unto his father, and said unto his father, Let my father arise, and eat of his son's venison, that thy soul may bless me.
760	27	32	And Isaac his father said unto him, Who art thou? And he said, I am thy son, thy firstborn Esau.
761	27	33	And Isaac trembled very exceedingly, and said, Who? where is he that hath taken venison, and brought it me, and I have eaten of all before thou camest, and have blessed him? yea, and he shall be blessed.
762	27	34	And when Esau heard the words of his father, he cried with a great and exceeding bitter cry, and said unto his father, Bless me, even me also, O my father.
763	27	35	And he said, Thy brother came with subtilty, and hath taken away thy blessing.
764	27	36	And he said, Is not he rightly named Jacob? for he hath supplanted me these two times: he took away my birthright; and, behold, now he hath taken away my blessing. And he said, Hast thou not reserved a blessing for me?
765	27	37	And Isaac answered and said unto Esau, Behold, I have made him thy lord, and all his brethren have I given to him for servants; and with corn and wine have I sustained him: and what shall I do now unto thee, my son?
766	27	38	And Esau said unto his father, Hast thou but one blessing, my father? bless me, even me also, O my father. And Esau lifted up his voice, and wept.
767	27	39	And Isaac his father answered and said unto him, Behold, thy dwelling shall be the fatness of the earth, and of the dew of heaven from above;
768	27	40	And by thy sword shalt thou live, and shalt serve thy brother; and it shall come to pass when thou shalt have the dominion, that thou shalt break his yoke from off thy neck.
769	27	41	And Esau hated Jacob because of the blessing wherewith his father blessed him: and Esau said in his heart, The days of mourning for my father are at hand; then will I slay my brother Jacob.
770	27	42	And these words of Esau her elder son were told to Rebekah: and she sent and called Jacob her younger son, and said unto him, Behold, thy brother Esau, as touching thee, doth comfort himself, purposing to kill thee.
771	27	43	Now therefore, my son, obey my voice; and arise, flee thou to Laban my brother to Haran;
772	27	44	And tarry with him a few days, until thy brother's fury turn away;
773	27	45	Until thy brother's anger turn away from thee, and he forget that which thou hast done to him: then I will send, and fetch thee from thence: why should I be deprived also of you both in one day?
774	27	46	And Rebekah said to Isaac, I am weary of my life because of the daughters of Heth: if Jacob take a wife of the daughters of Heth, such as these which are of the daughters of the land, what good shall my life do me?
775	28	1	AND Isaac called Jacob, and blessed him, and charged him, and said unto him, Thou shalt not take a wife of the daughters of Canaan.
776	28	2	Arise, go to Padan-aram, to the house of Bethuel thy mother's father; and take thee a wife from thence of the daughters of Laban thy mother's brother.
777	28	3	And God Almighty bless thee, and make thee fruitful, and multiply thee, that thou mayest be a multitude of people;
778	28	4	And give thee the blessing of Abraham, to thee, and to thy seed with thee; that thou mayest inherit the land wherein thou art a stranger, which God gave unto Abraham.
779	28	5	And Isaac sent away Jacob: and he went to Padan-aram unto Laban, son of Bethuel the Syrian, the brother of Rebekah, Jacob's and Esau's mother.
780	28	6	When Esau saw that Isaac had blessed Jacob, and sent him away to Padan-aram, to take him a wife from thence; and that as he blessed him he gave him a charge, saying, Thou shalt not take a wife of the daughters of Canaan;
781	28	7	And that Jacob obeyed his father and his mother, and was gone to Padan-aram;
782	28	8	And Esau seeing that the daughters of Canaan pleased not Isaac his father;
783	28	9	Then went Esau unto Ishmael, and took unto the wives which he had Mahalath the daughter of Ishmael Abraham's son, the sister of Nebajoth, to be his wife.
784	28	10	And Jacob went out from Beer-sheba, and went toward Haran.
785	28	11	And he lighted upon a certain place, and tarried there all night, because the sun was set; and he took of the stones of that place, and put them for his pillows, and lay down in that place to sleep.
786	28	12	And he dreamed, and behold a ladder set up on the earth, and the top of it reached to heaven: and behold the angels of God ascending and descending on it.
787	28	13	And, behold, the LORD stood above it, and said, I am the LORD God of Abraham thy father, and the God of Isaac: the land whereon thou liest, to thee will I give it, and to thy seed;
788	28	14	And thy seed shall be as the dust of the earth, and thou shalt spread abroad to the west, and to the east, and to the north, and to the south: and in thee and in thy seed shall all the families of the earth be blessed.
789	28	15	And, behold, I am with thee, and will keep thee in all places whither thou goest, and will bring thee again into this land; for I will not leave thee, until I have done that which I have spoken to thee of.
790	28	16	And Jacob awaked out of his sleep, and he said, Surely the LORD is in this place; and I knew it not.
791	28	17	And he was afraid, and said, How dreadful is this place! this is none other but the house of God, and this is the gate of heaven.
792	28	18	And Jacob rose up early in the morning, and took the stone that he had put for his pillows, and set it up for a pillar, and poured oil upon the top of it.
793	28	19	And he called the name of that place Beth-el: but the name of that city was called Luz at the first.
794	28	20	And Jacob vowed a vow, saying, If God will be with me, and will keep me in this way that I go, and will give me bread to eat, and raiment to put on,
795	28	21	So that I come again to my father's house in peace; then shall the LORD be my God:
796	28	22	And this stone, which I have set for a pillar, shall be God's house: and of all that thou shalt give me I will surely give the tenth unto thee.
797	29	1	THEN Jacob went on his journey, and came into the land of the people of the east.
798	29	2	And he looked, and behold a well in the field, and, lo, there were three flocks of sheep lying by it; for out of that well they watered the flocks: and a great stone was upon the well's mouth.
799	29	3	And thither were all the flocks gathered: and they rolled the stone from the well's mouth, and watered the sheep, and put the stone again upon the well's mouth in his place.
800	29	4	And Jacob said unto them, My brethren, whence be ye? And they said, Of Haran are we.
801	29	5	And he said unto them, Know ye Laban the son of Nahor? And they said, We know him.
802	29	6	And he said unto them, Is he well? And they said, He is well: and, behold, Rachel his daughter cometh with the sheep.
803	29	7	And he said, Lo, it is yet high day, neither is it time that the cattle should be gathered together: water ye the sheep, and go and feed them.
804	29	8	And they said, We cannot, until all the flocks be gathered together, and till they roll the stone from the well's mouth; then we water the sheep.
805	29	9	And while he yet spake with them, Rachel came with her father's sheep: for she kept them.
806	29	10	And it came to pass, when Jacob saw Rachel the daughter of Laban his mother's brother, and the sheep of Laban his mother's brother, that Jacob went near, and rolled the stone from the well's mouth, and watered the flock of Laban his mother's brother.
807	29	11	And Jacob kissed Rachel, and lifted up his voice, and wept.
808	29	12	And Jacob told Rachel that he was her father's brother, and that he was Rebekah's son: and she ran and told her father.
809	29	13	And it came to pass, when Laban heard the tidings of Jacob his sister's son, that he ran to meet him, and embraced him, and kissed him, and brought him to his house. And he told Laban all these things.
810	29	14	And Laban said to him, Surely thou art my bone and my flesh. And he abode with him the space of a month.
811	29	15	And Laban said unto Jacob, Because thou art my brother, shouldest thou therefore serve me for nought? tell me, what shall thy wages be?
812	29	16	And Laban had two daughters: the name of the elder was Leah, and the name of the younger was Rachel.
813	29	17	Leah was tender eyed; but Rachel was beautiful and well favoured.
814	29	18	And Jacob loved Rachel; and said, I will serve thee seven years for Rachel thy younger daughter.
815	29	19	And Laban said, It is better that I give her to thee, than that I should give her to another man: abide with me.
816	29	20	And Jacob served seven years for Rachel; and they seemed unto him but a few days, for the love he had to her.
817	29	21	And Jacob said unto Laban, Give me my wife, for my days are fulfilled, that I may go in unto her.
818	29	22	And Laban gathered together all the men of the place, and made a feast.
819	29	23	And it came to pass in the evening, that he took Leah his daughter, and brought her to him; and he went in unto her.
820	29	24	And Laban gave unto his daughter Leah Zilpah his maid for an handmaid.
821	29	25	And it came to pass, that in the morning, behold, it was Leah: and he said to Laban, What is this thou hast done unto me? did not I serve with thee for Rachel? wherefore then hast thou beguiled me?
822	29	26	And Laban said, It must not be so done in our country, to give the younger before the firstborn.
823	29	27	Fulfil her week, and we will give thee this also for the service which thou shalt serve with me yet seven other years.
824	29	28	And Jacob did so, and fulfilled her week: and he gave him Rachel his daughter to wife also.
825	29	29	And Laban gave to Rachel his daughter Bilhah his handmaid to be her maid.
826	29	30	And he went in also unto Rachel, and he loved also Rachel more than Leah, and served with him yet seven other years.
827	29	31	And when the LORD saw that Leah was hated, he opened her womb: but Rachel was barren.
828	29	32	And Leah conceived, and bare a son, and she called his name Reuben: for she said, Surely the LORD hath looked upon my affliction; now therefore my husband will love me.
829	29	33	And she conceived again, and bare a son; and said, Because the LORD hath heard that I was hated, he hath therefore given me this son also: and she called his name Simeon.
830	29	34	And she conceived again, and bare a son; and said, Now this time will my husband be joined unto me, because I have born him three sons: therefore was his name called Levi.
831	29	35	And she conceived again, and bare a son: and she said, Now will I praise the LORD: therefore she called his name Judah; and left bearing.
832	30	1	AND when Rachel saw that she bare Jacob no children, Rachel envied her sister; and said unto Jacob, Give me children, or else I die.
833	30	2	And Jacob's anger was kindled against Rachel: and he said, Am I in God's stead, who hath withheld from thee the fruit of the womb?
834	30	3	And she said, Behold my maid Bilhah, go in unto her; and she shall bear upon my knees that I may also have children by her.
835	30	4	And she gave him Bilhah her handmaid to wife: and Jacob went in unto her.
836	30	5	And Bilhah conceived, and bare Jacob a son.
837	30	6	And Rachel said, God hath judged me, and hath also heard my voice, and hath given me a son: therefore called she his name Dan.
838	30	7	And Bilhah Rachel's maid conceived again, and bare Jacob a second son.
839	30	8	And Rachel said, With great wrestlings have I wrestled with my sister, and I have prevailed: and she called his name Naphtali.
840	30	9	When Leah saw that she had left bearing, she took Zilpah her maid, and gave her Jacob to wife.
841	30	10	And Zilpah Leah's maid bare Jacob a son.
842	30	11	And Leah said, A troop cometh: and she called his name Gad.
843	30	12	And Zilpah Leah's maid bare Jacob a second son.
844	30	13	And Leah said, Happy am I, for the daughters will call me blessed: and she called his name Asher.
845	30	14	And Reuben went in the days of wheat harvest, and found mandrakes in the field, and brought them unto his mother Leah. Then Rachel said to Leah, Give me, I pray thee, of thy son's mandrakes.
846	30	15	And she said unto her, Is it a small matter that thou hast taken my husband? and wouldest thou take away my son's mandrakes also? And Rachel said, Therefore he shall lie with thee to night for thy son's mandrakes.
847	30	16	And Jacob came out of the field in the evening, and Leah went out to meet him, and said, Thou must come in unto me; for surely I have hired thee with my son's mandrakes. And he lay with her that night.
848	30	17	And God hearkened unto Leah, and she conceived, and bare Jacob the fifth son.
849	30	18	And Leah said, God hath given me my hire, because I have given my maiden to my husband: and she called his name Issachar.
850	30	19	And Leah conceived again, and bare Jacob the sixth son.
851	30	20	And Leah said, God hath endued me with a good dowry; now will my husband dwell with me, because I have born him six sons: and she called his name Zebulun.
852	30	21	And afterwards she bare a daughter, and called her name Dinah.
853	30	22	And God remembered Rachel, and God hearkened to her, and opened her womb.
854	30	23	And she conceived, and bare a son; and said, God hath taken away my reproach:
855	30	24	And she called his name Joseph; and said, The LORD shall add to me another son.
856	30	25	And it came to pass, when Rachel had born Joseph, that Jacob said unto Laban, Send me away, that I may go unto mine own place, and to my country.
857	30	26	Give me my wives and my children, for whom I have served thee, and let me go: for thou knowest my service which I have done thee.
858	30	27	And Laban said unto him, I pray thee, if I have found favour in thine eyes, tarry: for I have learned by experience that the LORD hath blessed me for thy sake.
859	30	28	And he said, Appoint me thy wages, and I will give it.
860	30	29	And he said unto him, Thou knowest how I have served thee, and how thy cattle was with me.
861	30	30	For it was little which thou hadst before I came, and it is now increased unto a multitude; and the LORD hath blessed thee since my coming: and now when shall I provide for mine own house also?
862	30	31	And he said, What shall I give thee? And Jacob said, Thou shalt not give me any thing: if thou wilt do this thing for me, I will again feed and keep thy flock.
863	30	32	I will pass through all thy flock to day, removing from thence all the speckled and spotted cattle, and all the brown cattle among the sheep, and the spotted and speckled among the goats: and of such shall be my hire.
864	30	33	So shall my righteousness answer for me in time to come, when it shall come for my hire before thy face: every one that is not speckled and spotted among the goats, and brown among the sheep, that shall be counted stolen with me.
865	30	34	And Laban said, Behold, I would it might be according to thy word.
866	30	35	And he removed that day the he goats that were ringstraked and spotted, and all the she goats that were speckled and spotted, and every one that had some white in it, and all the brown among the sheep, and gave them into the hand of his sons.
867	30	36	And he set three days' journey betwixt himself and Jacob: and Jacob fed the rest of Laban's flocks.
868	30	37	And Jacob took him rods of green poplar, and of the hazel and chesnut tree; and pilled white strakes in them, and made the white appear which was in the rods.
869	30	38	And he set the rods which he had pilled before the flocks in the gutters in the watering troughs when the flocks came to drink, that they should conceive when they came to drink.
870	30	39	And the flocks conceived before the rods, and brought forth cattle ringstraked, speckled, and spotted.
871	30	40	And Jacob did separate the lambs, and set the faces of the flocks toward the ringstraked, and all the brown in the flock of Laban; and he put his own flocks by themselves, and put them not unto Laban's cattle.
872	30	41	And it came to pass, whensoever the stronger cattle did conceive, that Jacob laid the rods before the eyes of the cattle in the gutters, that they might conceive among the rods.
873	30	42	But when the cattle were feeble, he put them not in: so the feebler were Laban's, and the stronger Jacob's.
874	30	43	And the man increased exceedingly, and had much cattle, and maidservants, and menservants, and camels, and asses.
875	31	1	AND he heard the words of Laban's sons, saying, Jacob hath taken away all that was our father's; and of that which was our father's hath he gotten all this glory.
876	31	2	And Jacob beheld the countenance of Laban, and, behold, it was not toward him as before.
877	31	3	And the LORD said unto Jacob, Return unto the land of thy fathers, and to thy kindred; and I will be with thee.
878	31	4	And Jacob sent and called Rachel and Leah to the field unto his flock,
879	31	5	And said unto them, I see your father's countenance, that it is not toward me as before; but the God of my father hath been with me.
880	31	6	And ye know that with all my power I have served your father.
881	31	7	And your father hath deceived me, and changed my wages ten times; but God suffered him not to hurt me.
882	31	8	If he said thus, The speckled shall be thy wages; then all the cattle bare speckled: and if he said thus, The ringstraked shall be thy hire; then bare all the cattle ringstraked.
883	31	9	Thus God hath taken away the cattle of your father, and given them to me.
884	31	10	And it came to pass at the time that the cattle conceived, that I lifted up mine eyes, and saw in a dream, and, behold, the rams which leaped upon the cattle were ringstraked, speckled, and grisled.
885	31	11	And the angel of God spake unto me in a dream, saying, Jacob: And I said, Here am I.
886	31	12	And he said, Lift up now thine eyes, and see, all the rams which leap upon the cattle are ringstraked, speckled, and grisled: for I have seen all that Laban doeth unto thee.
887	31	13	I am the God of Beth-el, where thou anointedst the pillar, and where thou vowedst a vow unto me: now arise, get thee out from this land, and return unto the land of thy kindred.
888	31	14	And Rachel and Leah answered and said unto him, Is there yet any portion or inheritance for us in our father's house?
889	31	15	Are we not counted of him strangers? for he hath sold us, and hath quite devoured also our money.
890	31	16	For all the riches which God hath taken from our father, that is ours, and our children's: now then, whatsoever God hath said unto thee, do.
891	31	17	Then Jacob rose up, and set his sons and his wives upon camels;
892	31	18	And he carried away all his cattle, and all his goods which he had gotten, the cattle of his getting, which he had gotten in Padan-aram, for to go to Isaac his father in the land of Canaan.
893	31	19	And Laban went to shear his sheep: and Rachel had stolen the images that were her father's.
894	31	20	And Jacob stole away unawares to Laban the Syrian, in that he told him not that he fled.
895	31	21	So he fled with all that he had; and he rose up, and passed over the river, and set his face toward the mount Gilead.
896	31	22	And it was told Laban on the third day that Jacob was fled.
897	31	23	And he took his brethren with him, and pursued after him seven days' journey; and they overtook him in the mount Gilead.
898	31	24	And God came to Laban the Syrian in a dream by night, and said unto him, Take heed that thou speak not to Jacob either good or bad.
899	31	25	Then Laban overtook Jacob. Now Jacob had pitched his tent in the mount: and Laban with his brethren pitched in the mount of Gilead.
900	31	26	And Laban said to Jacob, What hast thou done, that thou hast stolen away unawares to me, and carried away my daughters, as captives taken with the sword?
901	31	27	Wherefore didst thou flee away secretly, and steal away from me; and didst not tell me, that I might have sent thee away with mirth, and with songs, with tabret, and with harp?
902	31	28	And hast not suffered me to kiss my sons and my daughters? thou hast now done foolishly in so doing.
903	31	29	It is in the power of my hand to do you hurt: but the God of your father spake unto me yesternight, saying, Take thou heed that thou speak not to Jacob either good or bad.
904	31	30	And now, though thou wouldest needs be gone, because thou sore longedst after thy father's house, yet wherefore hast thou stolen my gods?
905	31	31	And Jacob answered and said to Laban, Because I was afraid: for I said, Peradventure thou wouldest take by force thy daughters from me.
906	31	32	With whomsoever thou findest thy gods, let him not live: before our brethren discern thou what is thine with me, and take it to thee. For Jacob knew not that Rachel had stolen them.
907	31	33	And Laban went into Jacob's tent, and into Leah's tent, and into the two maidservants' tents; but he found them not. Then went he out of Leah's tent, and entered into Rachel's tent.
908	31	34	Now Rachel had taken the images, and put them in the camel's furniture, and sat upon them. And Laban searched all the tent, but found them not.
909	31	35	And she said to her father, Let it not displease my lord that I cannot rise up before thee; for the custom of women is upon me. And he searched, but found not the images.
910	31	36	And Jacob was wroth, and chode with Laban: and Jacob answered and said to Laban, What is my trespass? what is my sin, that thou hast so hotly pursued after me?
911	31	37	Whereas thou hast searched all my stuff, what hast thou found of all thy household stuff? set it here before my brethren and thy brethren, that they may judge betwixt us both.
912	31	38	This twenty years have I been with thee; thy ewes and thy she goats have not cast their young, and the rams of thy flock have I not eaten.
913	31	39	That which was torn of beasts I brought not unto thee; I bare the loss of it; of my hand didst thou require it, whether stolen by day, or stolen by night.
914	31	40	Thus I was; in the day the drought consumed me, and the frost by night; and my sleep departed from mine eyes.
915	31	41	Thus have I been twenty years in thy house; I served thee fourteen years for thy two daughters, and six years for thy cattle: and thou hast changed my wages ten times.
916	31	42	Except the God of my father, the God of Abraham, and the fear of Isaac, had been with me, surely thou hadst sent me away now empty. God hath seen mine affliction and the labour of my hands, and rebuked thee yesternight.
917	31	43	And Laban answered and said unto Jacob, These daughters are my daughters, and these children are my children, and these cattle are my cattle, and all that thou seest is mine: and what can I do this day unto these my daughters, or unto their children which they have born?
918	31	44	Now therefore come thou, let us make a covenant, I and thou; and let it be for a witness between me and thee.
919	31	45	And Jacob took a stone, and set it up for a pillar.
920	31	46	And Jacob said unto his brethren, Gather stones; and they took stones, and made an heap: and they did eat there upon the heap.
921	31	47	And Laban called it Jegar-sahadutha: but Jacob called it Galeed.
922	31	48	And Laban said, This heap is a witness between me and thee this day. Therefore was the name of it called Galeed;
923	31	49	And Mizpah; for he said, The LORD watch between me and thee, when we are absent one from another.
924	31	50	If thou shalt afflict my daughters, or if thou shalt take other wives beside my daughters, no man is with us; see, God is witness betwixt me and thee.
925	31	51	And Laban said to Jacob, Behold this heap, and behold this pillar, which I have cast betwixt me and thee;
926	31	52	This heap be witness, and this pillar be witness, that I will not pass over this heap to thee, and that thou shalt not pass over this heap and this pillar unto me, for harm.
927	31	53	The God of Abraham, and the God of Nahor, the God of their father, judge betwixt us. And Jacob sware by the fear of his father Isaac.
928	31	54	Then Jacob offered sacrifice upon the mount, and called his brethren to eat bread: and they did eat bread, and tarried all night in the mount.
929	31	55	And early in the morning Laban rose up, and kissed his sons and his daughters, and blessed them: and Laban departed, and returned unto his place.
930	32	1	AND Jacob went on his way, and the angels of God met him.
931	32	2	And when Jacob saw them, he said, This is God's host: and he called the name of that place Mahanaim.
932	32	3	And Jacob sent messengers before him to Esau his brother unto the land of Seir, the country of Edom.
933	32	4	And he commanded them, saying, Thus shall ye speak unto my lord Esau; Thy servant Jacob saith thus, I have sojourned with Laban, and stayed there until now:
934	32	5	And I have oxen, and asses, flocks, and menservants, and womenservants: and I have sent to tell my lord, that I may find grace in thy sight.
935	32	6	And the messengers returned to Jacob, saying, We came to thy brother Esau, and also he cometh to meet thee, and four hundred men with him.
936	32	7	Then Jacob was greatly afraid and distressed: and he divided the people that was with him, and the flocks, and herds, and the camels, into two bands;
937	32	8	And said, If Esau come to the one company, and smite it, then the other company which is left shall escape.
938	32	9	And Jacob said, O God of my father Abraham, and God of my father Isaac, the LORD which saidst unto me, Return unto thy country, and to thy kindred, and I will deal well with thee:
939	32	10	I am not worthy of the least of all the mercies, and of all the truth, which thou hast shewed unto thy servant; for with my staff I passed over this Jordan; and now I am become two bands.
940	32	11	Deliver me, I pray thee, from the hand of my brother, from the hand of Esau: for I fear him, lest he will come and smite me, and the mother with the children.
941	32	12	And thou saidst, I will surely do thee good, and make thy seed as the sand of the sea, which cannot be numbered for multitude.
942	32	13	And he lodged there that same night; and took of that which came to his hand a present for Esau his brother;
943	32	14	Two hundred she goats, and twenty he goats, two hundred ewes, and twenty rams,
944	32	15	Thirty milch camels with their colts, forty kine, and ten bulls, twenty she asses, and ten foals.
945	32	16	And he delivered them into the hand of his servants, every drove by themselves; and said unto his servants, Pass over before me, and put a space betwixt drove and drove.
946	32	17	And he commanded the foremost, saying, When Esau my brother meeteth thee, and asketh thee, saying, Whose art thou? and whither goest thou? and whose are these before thee?
947	32	18	Then thou shalt say, They be thy servant Jacob's; it is a present sent unto my lord Esau: and, behold, also he is behind us.
948	32	19	And so commanded he the second, and the third, and all that followed the droves, saying, On this manner shall ye speak unto Esau, when ye find him.
949	32	20	And say ye moreover, Behold, thy servant Jacob is behind us. For he said, I will appease him with the present that goeth before me, and afterward I will see his face; peradventure he will accept of me.
950	32	21	So went the present over before him: and himself lodged that night in the company.
951	32	22	And he rose up that night, and took his two wives, and his two womenservants, and his eleven sons, and passed over the ford Jabbok.
952	32	23	And he took them, and sent them over the brook, and sent over that he had.
953	32	24	And Jacob was left alone; and there wrestled a man with him until the breaking of the day.
954	32	25	And when he saw that he prevailed not against him, he touched the hollow of his thigh; and the hollow of Jacob's thigh was out of joint, as he wrestled with him.
955	32	26	And he said, Let me go, for the day breaketh. And he said, I will not let thee go, except thou bless me.
956	32	27	And he said unto him, What is thy name? And he said, Jacob.
957	32	28	And he said, Thy name shall be called no more Jacob, but Israel: for as a prince hast thou power with God and with men, and hast prevailed.
958	32	29	And Jacob asked him, and said, Tell me, I pray thee, thy name. And he said, Wherefore is it that thou dost ask after my name? And he blessed him there.
959	32	30	And Jacob called the name of the place Peniel: for I have seen God face to face, and my life is preserved.
960	32	31	And as he passed over Penuel the sun rose upon him, and he halted upon his thigh.
961	32	32	Therefore the children of Israel eat not of the sinew which shrank, which is upon the hollow of the thigh, unto this day: because he touched the hollow of Jacob's thigh in the sinew that shrank.
962	33	1	AND Jacob lifted up his eyes, and looked, and, behold, Esau came, and with him four hundred men. And he divided the children unto Leah, and unto Rachel, and unto the two handmaids.
963	33	2	And he put the handmaids and their children foremost, and Leah and her children after, and Rachel and Joseph hindermost.
964	33	3	And he passed over before them, and bowed himself to the ground seven times, until he came near to his brother.
965	33	4	And Esau ran to meet him, and embraced him, and fell on his neck, and kissed him: and they wept.
966	33	5	And he lifted up his eyes, and saw the women and the children; and said, Who are those with thee? And he said, The children which God hath graciously given thy servant.
967	33	6	Then the handmaidens came near, they and their children, and they bowed themselves.
968	33	7	And Leah also with her children came near, and bowed themselves: and after came Joseph near and Rachel, and they bowed themselves.
969	33	8	And he said, What meanest thou by all this drove which I met? And he said, These are to find grace in the sight of my lord.
970	33	9	And Esau said, I have enough, my brother; keep that thou hast unto thyself.
971	33	10	And Jacob said, Nay, I pray thee, if now I have found grace in thy sight, then receive my present at my hand: for therefore I have seen thy face, as though I had seen the face of God, and thou wast pleased with me.
972	33	11	Take, I pray thee, my blessing that is brought to thee; because God hath dealt graciously with me, and because I have enough. And he urged him, and he took it.
973	33	12	And he said, Let us take our journey, and let us go, and I will go before thee.
974	33	13	And he said unto him, My lord knoweth that the children are tender, and the flocks and herds with young are with me: and if men should overdrive them one day, all the flock will die.
975	33	14	Let my lord, I pray thee, pass over before his servant: and I will lead on softly, according as the cattle that goeth before me and the children be able to endure, until I come unto my lord unto Seir.
976	33	15	And Esau said, Let me now leave with thee some of the folk that are with me. And he said, What needeth it? let me find grace in the sight of my lord.
977	33	16	So Esau returned that day on his way unto Seir.
978	33	17	And Jacob journeyed to Succoth, and built him an house, and made booths for his cattle: therefore the name of the place is called Succoth.
979	33	18	And Jacob came to Shalem, a city of Shechem, which is in the land of Canaan, when he came from Padan-aram; and pitched his tent before the city.
980	33	19	And he bought a parcel of a field, where he had spread his tent, at the hand of the children of Hamor, Shechem's father, for an hundred pieces of money.
981	33	20	And he erected there an altar, and called it El-elohe-Israel.
982	34	1	AND Dinah the daughter of Leah, which she bare unto Jacob, went out to see the daughters of the land.
983	34	2	And when Shechem the son of Hamor the Hivite, prince of the country, saw her, he took her, and lay with her, and defiled her.
984	34	3	And his soul clave unto Dinah the daughter of Jacob, and he loved the damsel, and spake kindly unto the damsel.
985	34	4	And Shechem spake unto his father Hamor, saying, Get me this damsel to wife.
986	34	5	And Jacob heard that he had defiled Dinah his daughter: now his sons were with his cattle in the field: and Jacob held his peace until they were come.
987	34	6	And Hamor the father of Shechem went out unto Jacob to commune with him.
988	34	7	And the sons of Jacob came out of the field when they heard it: and the men were grieved, and they were very wroth, because he had wrought folly in Israel in lying with Jacob's daughter; which thing ought not to be done.
989	34	8	And Hamor communed with them, saying, The soul of my son Shechem longeth for your daughter: I pray you give her him to wife.
990	34	9	And make ye marriages with us, and give your daughters unto us, and take our daughters unto you.
991	34	10	And ye shall dwell with us: and the land shall be before you; dwell and trade ye therein, and get you possessions therein.
992	34	11	And Shechem said unto her father and unto her brethren, Let me find grace in your eyes, and what ye shall say unto me I will give.
993	34	12	Ask me never so much dowry and gift, and I will give according as ye shall say unto me: but give me the damsel to wife.
994	34	13	And the sons of Jacob answered Shechem and Hamor his father deceitfully, and said, because he had defiled Dinah their sister:
995	34	14	And they said unto them, We cannot do this thing, to give our sister to one that is uncircumcised; for that were a reproach unto us:
996	34	15	But in this will we consent unto you: If ye will be as we be, that every male of you be circumcised;
997	34	16	Then will we give our daughters unto you, and we will take your daughters to us, and we will dwell with you, and we will become one people.
998	34	17	But if ye will not hearken unto us, to be circumcised; then will we take our daughter, and we will be gone.
999	34	18	And their words pleased Hamor, and Shechem Hamor's son.
1000	34	19	And the young man deferred not to do the thing, because he had delight in Jacob's daughter: and he was more honourable than all the house of his father.
1001	34	20	And Hamor and Shechem his son came unto the gate of their city, and communed with the men of their city, saying,
1002	34	21	These men are peaceable with us; therefore let them dwell in the land, and trade therein; for the land, behold, it is large enough for them; let us take their daughters to us for wives, and let us give them our daughters.
1003	34	22	Only herein will the men consent unto us for to dwell with us, to be one people, if every male among us be circumcised, as they are circumcised.
1004	34	23	Shall not their cattle and their substance and every beast of theirs be ours? only let us consent unto them, and they will dwell with us.
1005	34	24	And unto Hamor and unto Shechem his son hearkened all that went out of the gate of his city; and every male was circumcised, all that went out of the gate of his city.
1006	34	25	And it came to pass on the third day, when they were sore, that two of the sons of Jacob, Simeon and Levi, Dinah's brethren, took each man his sword, and came upon the city boldly, and slew all the males.
1007	34	26	And they slew Hamor and Shechem his son with the edge of the sword, and took Dinah out of Shechem's house, and went out.
1008	34	27	The sons of Jacob came upon the slain, and spoiled the city, because they had defiled their sister.
1009	34	28	They took their sheep, and their oxen, and their asses, and that which was in the city, and that which was in the field,
1010	34	29	And all their wealth, and all their little ones, and their wives took they captive, and spoiled even all that was in the house.
1011	34	30	And Jacob said to Simeon and Levi, Ye have troubled me to make me to stink among the inhabitants of the land, among the Canaanites and the Perizzites: and I being few in number, they shall gather themselves together against me, and slay me; and I shall be destroyed, I and my house.
1012	34	31	And they said, Should he deal with our sister as with an harlot?
1013	35	1	AND God said unto Jacob, Arise, go up to Beth-el, and dwell there: and make there an altar unto God, that appeared unto thee when thou fleddest from the face of Esau thy brother.
1014	35	2	Then Jacob said unto his household, and to all that were with him, Put away the strange gods that are among you, and be clean, and change your garments:
1015	35	3	And let us arise, and go up to Beth-el; and I will make there an altar unto God, who answered me in the day of my distress, and was with me in the way which I went.
1016	35	4	And they gave unto Jacob all the strange gods which were in their hand, and all their earrings which were in their ears; and Jacob hid them under the oak which was by Shechem.
1017	35	5	And they journeyed: and the terror of God was upon the cities that were round about them, and they did not pursue after the sons of Jacob.
1018	35	6	So Jacob came to Luz, which is in the land of Canaan, that is, Beth-el, he and all the people that were with him.
1019	35	7	And he built there an altar, and called the place El-beth-el: because there God appeared unto him, when he fled from the face of his brother.
1020	35	8	But Deborah Rebekah's nurse died, and she was buried beneath Beth-el under an oak: and the name of it was called Allon-bachuth.
1021	35	9	And God appeared unto Jacob again, when he came out of Padan-aram, and blessed him.
1022	35	10	And God said unto him, Thy name is Jacob: thy name shall not be called any more Jacob, but Israel shall be thy name: and he called his name Israel.
1023	35	11	And God said unto him, I am God Almighty: be fruitful and multiply; a nation and a company of nations shall be of thee, and kings shall come out of thy loins;
1024	35	12	And the land which I gave Abraham and Isaac, to thee I will give it, and to thy seed after thee will I give the land.
1025	35	13	And God went up from him in the place where he talked with him.
1026	35	14	And Jacob set up a pillar in the place where he talked with him, even a pillar of stone: and he poured a drink offering thereon, and he poured oil thereon.
1027	35	15	And Jacob called the name of the place where God spake with him, Beth-el.
1028	35	16	And they journeyed from Beth-el; and there was but a little way to come to Ephrath: and Rachel travailed, and she had hard labour.
1029	35	17	And it came to pass, when she was in hard labour, that the midwife said unto her, Fear not; thou shalt have this son also.
1030	35	18	And it came to pass, as her soul was in departing, (for she died) that she called his name Ben-oni: but his father called him Benjamin.
1031	35	19	And Rachel died, and was buried in the way to Ephrath, which is Beth-lehem.
1032	35	20	And Jacob set a pillar upon her grave: that is the pillar of Rachel's grave unto this day.
1033	35	21	And Israel journeyed, and spread his tent beyond the tower of Edar.
1034	35	22	And it came to pass, when Israel dwelt in that land, that Reuben went and lay with Bilhah his father's concubine: and Israel heard it. Now the sons of Jacob were twelve:
1035	35	23	The sons of Leah; Reuben, Jacob's firstborn, and Simeon, and Levi, and Judah, and Issachar, and Zebulun:
1036	35	24	The sons of Rachel; Joseph, and Benjamin:
1037	35	25	And the sons of Bilhah, Rachel's handmaid; Dan, and Naphtali:
1038	35	26	And the sons of Zilpah, Leah's handmaid; Gad, and Asher: these are the sons of Jacob, which were born to him in Padan-aram.
1039	35	27	And Jacob came unto Isaac his father unto Mamre, unto the city of Arbah, which is Hebron, where Abraham and Isaac sojourned.
1040	35	28	And the days of Isaac were an hundred and fourscore years.
1041	35	29	And Isaac gave up the ghost, and died, and was gathered unto his people, being old and full of days: and his sons Esau and Jacob buried him.
1042	36	1	NOW these are the generations of Esau, who is Edom.
1043	36	2	Esau took his wives of the daughters of Canaan; Adah the daughter of Elon the Hittite, and Aholibamah the daughter of Anah the daughter of Zibeon the Hivite;
1044	36	3	And Bashemath Ishmael's daughter, sister of Nebajoth.
1045	36	4	And Adah bare to Esau Eliphaz; and Bashemath bare Reuel;
1046	36	5	And Aholibamah bare Jeush, and Jaalam, and Korah: these are the sons of Esau, which were born unto him in the land of Canaan.
1047	36	6	And Esau took his wives, and his sons, and his daughters, and all the persons of his house, and his cattle, and all his beasts, and all his substance, which he had got in the land of Canaan; and went into the country from the face of his brother Jacob.
1048	36	7	For their riches were more than that they might dwell together; and the land wherein they were strangers could not bear them because of their cattle.
1049	36	8	Thus dwelt Esau in mount Seir: Esau is Edom.
1050	36	9	And these are the generations of Esau the father of the Edomites in mount Seir:
1051	36	10	These are the names of Esau's sons; Eliphaz the son of Adah the wife of Esau, Reuel the son of Bashemath the wife of Esau.
1052	36	11	And the sons of Eliphaz were Teman, Omar, Zepho, and Gatam, and Kenaz.
1053	36	12	And Timna was concubine to Eliphaz Esau's son; and she bare to Eliphaz Amalek: these were the sons of Adah Esau's wife.
1054	36	13	And these are the sons of Reuel; Nahath, and Zerah, Shammah, and Mizzah: these were the sons of Bashemath Esau's wife.
1055	36	14	And these were the sons of Aholibamah, the daughter of Anah the daughter of Zibeon, Esau's wife: and she bare to Esau Jeush, and Jaalam, and Korah.
1056	36	15	These were dukes of the sons of Esau: the sons of Eliphaz the firstborn son of Esau; duke Teman, duke Omar, duke Zepho, duke Kenaz,
1057	36	16	Duke Korah, duke Gatam, and duke Amalek: these are the dukes that came of Eliphaz in the land of Edom; these were the sons of Adah.
1058	36	17	And these are the sons of Reuel Esau's son; duke Nahath, duke Zerah, duke Shammah, duke Mizzah: these are the dukes that came of Reuel in the land of Edom; these are the sons of Bashemath Esau's wife.
1059	36	18	And these are the sons of Aholibamah Esau's wife; duke Jeush, duke Jaalam, duke Korah: these were the dukes that came of Aholibamah the daughter of Anah, Esau's wife.
1060	36	19	These are the sons of Esau, who is Edom, and these are their dukes.
1061	36	20	These are the sons of Seir the Horite, who inhabited the land; Lotan, and Shobal, and Zibeon, and Anah,
1062	36	21	And Dishon, and Ezer, and Dishan: these are the dukes of the Horites, the children of Seir in the land of Edom.
1063	36	22	And the children of Lotan were Hori and Hemam; and Lotan's sister was Timna.
1064	36	23	And the children of Shobal were these; Alvan, and Manahath, and Ebal, Shepho, and Onam.
1065	36	24	And these are the children of Zibeon; both Ajah, and Anah: this was that Anah that found the mules in the wilderness, as he fed the asses of Zibeon his father.
1066	36	25	And the children of Anah were these; Dishon, and Aholibamah the daughter of Anah.
1067	36	26	And these are the children of Dishon; Hemdan, and Eshban, and Ithran, and Cheran.
1068	36	27	The children of Ezer are these; Bilhan, and Zaavan, and Akan.
1069	36	28	The children of Dishan are these; Uz, and Aran.
1070	36	29	These are the dukes that came of the Horites; duke Lotan, duke Shobal, duke Zibeon, duke Anah,
1071	36	30	Duke Dishon, duke Ezer, duke Dishan: these are the dukes that came of Hori, among their dukes in the land of Seir.
1072	36	31	And these are the kings that reigned in the land of Edom, before there reigned any king over the children of Israel.
1073	36	32	And Bela the son of Beor reigned in Edom: and the name of his city was Dinhabah.
1074	36	33	And Bela died, and Jobab the son of Zerah of Bozrah reigned in his stead.
1075	36	34	And Jobab died, and Husham of the land of Temani reigned in his stead.
1076	36	35	And Husham died, and Hadad the son of Bedad, who smote Midian in the field of Moab, reigned in his stead: and the name of his city was Avith.
1077	36	36	And Hadad died, and Samlah of Masrekah reigned in his stead.
1078	36	37	And Samlah died, and Saul of Rehoboth by the river reigned in his stead.
1079	36	38	And Saul died, and Baal-hanan the son of Achbor reigned in his stead.
1080	36	39	And Baal-hanan the son of Achbor died, and Hadar reigned in his stead: and the name of his city was Pau; and his wife's name was Mehetabel, the daughter of Matred, the daughter of Mezahab.
1081	36	40	And these are the names of the dukes that came of Esau, according to their families, after their places, by their names; duke Timnah, duke Alvah, duke Jetheth,
1082	36	41	Duke Aholibamah, duke Elah, duke Pinon,
1083	36	42	Duke Kenaz, duke Teman, duke Mibzar,
1084	36	43	Duke Magdiel, duke Iram: these be the dukes of Edom, according to their habitations in the land of their possession: he is Esau the father of the Edomites.
1085	37	1	AND Jacob dwelt in the land wherein his father was a stranger, in the land of Canaan.
1086	37	2	These are the generations of Jacob. Joseph, being seventeen years old, was feeding the flock with his brethren; and the lad was with the sons of Bilhah, and with the sons of Zilpah, his father's wives: and Joseph brought unto his father their evil report.
1087	37	3	Now Israel loved Joseph more than all his children, because he was the son of his old age: and he made him a coat of many colours.
1088	37	4	And when his brethren saw that their father loved him more than all his brethren, they hated him, and could not speak peaceably unto him.
1089	37	5	And Joseph dreamed a dream, and he told it his brethren: and they hated him yet the more.
1090	37	6	And he said unto them, Hear, I pray you, this dream which I have dreamed:
1091	37	7	For, behold, we were binding sheaves in the field, and, lo, my sheaf arose, and also stood upright; and, behold, your sheaves stood round about, and made obeisance to my sheaf.
1092	37	8	And his brethren said to him, Shalt thou indeed reign over us? or shalt thou indeed have dominion over us? And they hated him yet the more for his dreams, and for his words.
1093	37	9	And he dreamed yet another dream, and told it his brethren, and said, Behold, I have dreamed a dream more; and, behold, the sun and the moon and the eleven stars made obeisance to me.
1094	37	10	And he told it to his father, and to his brethren: and his father rebuked him, and said unto him, What is this dream that thou hast dreamed? Shall I and thy mother and thy brethren indeed come to bow down ourselves to thee to the earth?
1095	37	11	And his brethren envied him; but his father observed the saying.
1096	37	12	And his brethren went to feed their father's flock in Shechem.
1097	37	13	And Israel said unto Joseph, Do not thy brethren feed the flock in Shechem? come, and I will send thee unto them. And he said to him, Here am I.
1098	37	14	And he said to him, Go, I pray thee, see whether it be well with thy brethren, and well with the flocks; and bring me word again. So he sent him out of the vale of Hebron, and he came to Shechem.
1099	37	15	And a certain man found him, and, behold, he was wandering in the field: and the man asked him, saying, What seekest thou?
1100	37	16	And he said, I seek my brethren: tell me, I pray thee, where they feed their flocks.
1101	37	17	And the man said, They are departed hence; for I heard them say, Let us go to Dothan. And Joseph went after his brethren, and found them in Dothan.
1102	37	18	And when they saw him afar off, even before he came near unto them, they conspired against him to slay him.
1103	37	19	And they said one to another, Behold, this dreamer cometh.
1104	37	20	Come now therefore, and let us slay him, and cast him into some pit, and we will say, Some evil beast hath devoured him: and we shall see what will become of his dreams.
1105	37	21	And Reuben heard it, and he delivered him out of their hands; and said, Let us not kill him.
1106	37	22	And Reuben said unto them, Shed no blood, but cast him into this pit that is in the wilderness, and lay no hand upon him; that he might rid him out of their hands, to deliver him to his father again.
1107	37	23	And it came to pass, when Joseph was come unto his brethren, that they stript Joseph out of his coat, his coat of many colours that was on him;
1108	37	24	And they took him, and cast him into a pit: and the pit was empty, there was no water in it.
1109	37	25	And they sat down to eat bread: and they lifted up their eyes and looked, and, behold, a company of Ishmeelites came from Gilead with their camels bearing spicery and balm and myrrh, going to carry it down to Egypt.
1110	37	26	And Judah said unto his brethren, What profit is it if we slay our brother, and conceal his blood?
1111	37	27	Come, and let us sell him to the Ishmeelites, and let not our hand be upon him; for he is our brother and our flesh. And his brethren were content.
1112	37	28	Then there passed by Midianites merchantmen; and they drew and lifted up Joseph out of the pit, and sold Joseph to the Ishmeelites for twenty pieces of silver: and they brought Joseph into Egypt.
1113	37	29	And Reuben returned unto the pit; and, behold, Joseph was not in the pit; and he rent his clothes.
1114	37	30	And he returned unto his brethren, and said, The child is not; and I, whither shall I go?
1115	37	31	And they took Joseph's coat, and killed a kid of the goats, and dipped the coat in the blood;
1116	37	32	And they sent the coat of many colours, and they brought it to their father; and said, This have we found: know now whether it be thy son's coat or no.
1117	37	33	And he knew it, and said, It is my son's coat; an evil beast hath devoured him; Joseph is without doubt rent in pieces.
1118	37	34	And Jacob rent his clothes, and put sackcloth upon his loins, and mourned for his son many days.
1119	37	35	And all his sons and all his daughters rose up to comfort him; but he refused to be comforted; and he said, For I will go down into the grave unto my son mourning. Thus his father wept for him.
1120	37	36	And the Midianites sold him into Egypt unto Potiphar, an officer of Pharaoh's, and captain of the guard.
1121	38	1	AND it came to pass at that time, that Judah went down from his brethren, and turned in to a certain Adullamite, whose name was Hirah.
1122	38	2	And Judah saw there a daughter of a certain Canaanite, whose name was Shuah; and he took her, and went in unto her.
1123	38	3	And she conceived, and bare a son; and he called his name Er.
1124	38	4	And she conceived again, and bare a son; and she called his name Onan.
1125	38	5	And she yet again conceived, and bare a son; and called his name Shelah: and he was at Chezib, when she bare him.
1126	38	6	And Judah took a wife for Er his firstborn, whose name was Tamar.
1127	38	7	And Er, Judah's firstborn, was wicked in the sight of the LORD; and the LORD slew him.
1128	38	8	And Judah said unto Onan, Go in unto thy brother's wife, and marry her, and raise up seed to thy brother.
1129	38	9	And Onan knew that the seed should not be his; and it came to pass, when he went in unto his brother's wife, that he spilled it on the ground, lest that he should give seed to his brother.
1130	38	10	And the thing which he did displeased the LORD: wherefore he slew him also.
1131	38	11	Then said Judah to Tamar his daughter in law, Remain a widow at thy father's house, till Shelah my son be grown: for he said, Lest peradventure he die also, as his brethren did. And Tamar went and dwelt in her father's house.
1132	38	12	And in process of time the daughter of Shuah Judah's wife died; and Judah was comforted, and went up unto his sheepshearers to Timnath, he and his friend Hirah the Adullamite.
1133	38	13	And it was told Tamar, saying, Behold thy father in law goeth up to Timnath to shear his sheep.
1134	38	14	And she put her widow's garments off from her, and covered her with a vail, and wrapped herself, and sat in an open place, which is by the way to Timnath; for she saw that Shelah was grown, and she was not given unto him to wife.
1135	38	15	When Judah saw her, he thought her to be an harlot; because she had covered her face.
1136	38	16	And he turned unto her by the way, and said, Go to, I pray thee, let me come in unto thee; (for he knew not that she was his daughter in law.) And she said, What wilt thou give me, that thou mayest come in unto me?
1137	38	17	And he said, I will send thee a kid from the flock. And she said, Wilt thou give me a pledge, till thou send it?
1138	38	18	And he said, What pledge shall I give thee? And she said, Thy signet, and thy bracelets, and thy staff that is in thine hand. And he gave it her, and came in unto her, and she conceived by him.
1139	38	19	And she arose, and went away, and laid by her vail from her, and put on the garments of her widowhood.
1140	38	20	And Judah sent the kid by the hand of his friend the Adullamite, to receive his pledge from the woman's hand: but he found her not.
1141	38	21	Then he asked the men of that place, saying, Where is the harlot, that was openly by the way side? And they said, There was no harlot in this place.
1142	38	22	And he returned to Judah, and said, I cannot find her; and also the men of the place said, that there was no harlot in this place.
1143	38	23	And Judah said, Let her take it to her, lest we be shamed: behold, I sent this kid, and thou hast not found her.
1144	38	24	And it came to pass about three months after, that it was told Judah, saying, Tamar thy daughter in law hath played the harlot; and also, behold, she is with child by whoredom. And Judah said, Bring her forth, and let her be burnt.
1145	38	25	When she was brought forth, she sent to her father in law, saying, By the man, whose these are, am I with child: and she said, Discern, I pray thee, whose are these, the signet, and bracelets, and staff.
1146	38	26	And Judah acknowledged them, and said, She hath been more righteous than I; because that I gave her not to Shelah my son. And he knew her again no more.
1147	38	27	And it came to pass in the time of her travail, that, behold, twins were in her womb.
1148	38	28	And it came to pass, when she travailed, that the one put out his hand: and the midwife took and bound upon his hand a scarlet thread, saying, This came out first.
1149	38	29	And it came to pass, as he drew back his hand, that, behold, his brother came out: and she said, How hast thou broken forth? this breach be upon thee: therefore his name was called Pharez.
1150	38	30	And afterward came out his brother, that had the scarlet thread upon his hand: and his name was called Zarah.
1151	39	1	AND Joseph was brought down to Egypt; and Potiphar, an officer of Pharaoh, captain of the guard, an Egyptian, bought him of the hands of the Ishmeelites, which had brought him down thither.
1152	39	2	And the LORD was with Joseph, and he was a prosperous man; and he was in the house of his master the Egyptian.
1153	39	3	And his master saw that the LORD was with him, and that the LORD made all that he did to prosper in his hand.
1154	39	4	And Joseph found grace in his sight, and he served him: and he made him overseer over his house, and all that he had he put into his hand.
1155	39	5	And it came to pass from the time that he had made him overseer in his house, and over all that he had, that the LORD blessed the Egyptian's house for Joseph's sake; and the blessing of the LORD was upon all that he had in the house, and in the field.
1156	39	6	And he left all that he had in Joseph's hand; and he knew not ought he had, save the bread which he did eat. And Joseph was a goodly person, and well favoured.
1157	39	7	And it came to pass after these things, that his master's wife cast her eyes upon Joseph; and she said, Lie with me.
1158	39	8	But he refused, and said unto his master's wife, Behold, my master wotteth not what is with me in the house, and he hath committed all that he hath to my hand;
1159	39	9	There is none greater in this house than I; neither hath he kept back any thing from me but thee, because thou art his wife: how then can I do this great wickedness, and sin against God?
1160	39	10	And it came to pass, as she spake to Joseph day by day, that he hearkened not unto her, to lie by her, or to be with her.
1161	39	11	And it came to pass about this time, that Joseph went into the house to do his business; and there was none of the men of the house there within.
1162	39	12	And she caught him by his garment, saying, Lie with me: and he left his garment in her hand, and fled, and got him out.
1163	39	13	And it came to pass, when she saw that he had left his garment in her hand, and was fled forth,
1164	39	14	That she called unto the men of her house, and spake unto them, saying, See, he hath brought in an Hebrew unto us to mock us; he came in unto me to lie with me, and I cried with a loud voice:
1165	39	15	And it came to pass, when he heard that I lifted up my voice and cried, that he left his garment with me, and fled, and got him out.
1166	39	16	And she laid up his garment by her, until his lord came home.
1167	39	17	And she spake unto him according to these words, saying, The Hebrew servant, which thou hast brought unto us, came in unto me to mock me:
1168	39	18	And it came to pass, as I lifted up my voice and cried, that he left his garment with me, and fled out.
1169	39	19	And it came to pass, when his master heard the words of his wife, which she spake unto him, saying, After this manner did thy servant to me; that his wrath was kindled.
1170	39	20	And Joseph's master took him, and put him into the prison, a place where the king's prisoners were bound: and he was there in the prison.
1171	39	21	But the LORD was with Joseph, and shewed him mercy, and gave him favour in the sight of the keeper of the prison.
1172	39	22	And the keeper of the prison committed to Joseph's hand all the prisoners that were in the prison; and whatsoever they did there, he was the doer of it.
1173	39	23	The keeper of the prison looked not to any thing that was under his hand; because the LORD was with him, and that which he did, the LORD made it to prosper.
1174	40	1	AND it came to pass after these things, that the butler of the king of Egypt and his baker had offended their lord the king of Egypt.
1175	40	2	And Pharaoh was wroth against two of his officers, against the chief of the butlers, and against the chief of the bakers.
1176	40	3	And he put them in ward in the house of the captain of the guard, into the prison, the place where Joseph was bound.
1177	40	4	And the captain of the guard charged Joseph with them, and he served them: and they continued a season in ward.
1178	40	5	And they dreamed a dream both of them, each man his dream in one night, each man according to the interpretation of his dream, the butler and the baker of the king of Egypt, which were bound in the prison.
1179	40	6	And Joseph came in unto them in the morning, and looked upon them, and, behold, they were sad.
1180	40	7	And he asked Pharaoh's officers that were with him in the ward of his lord's house, saying, Wherefore look ye so sadly to day?
1181	40	8	And they said unto him, We have dreamed a dream, and there is no interpreter of it. And Joseph said unto them, Do not interpretations belong to God? tell me them, I pray you.
1182	40	9	And the chief butler told his dream to Joseph, and said to him, In my dream, behold, a vine was before me;
1183	40	10	And in the vine were three branches: and it was as though it budded, and her blossoms shot forth; and the clusters thereof brought forth ripe grapes:
1184	40	11	And Pharaoh's cup was in my hand: and I took the grapes, and pressed them into Pharaoh's cup, and I gave the cup into Pharaoh's hand.
1185	40	12	And Joseph said unto him, This is the interpretation of it: The three branches are three days:
1186	40	13	Yet within three days shall Pharaoh lift up thine head, and restore thee unto thy place: and thou shalt deliver Pharaoh's cup into his hand, after the former manner when thou wast his butler.
1187	40	14	But think on me when it shall be well with thee, and shew kindness, I pray thee, unto me, and make mention of me unto Pharaoh, and bring me out of this house:
1188	40	15	For indeed I was stolen away out of the land of the Hebrews: and here also have I done nothing that they should put me into the dungeon.
1189	40	16	When the chief baker saw that the interpretation was good, he said unto Joseph, I also was in my dream, and, behold, I had three white baskets on my head:
1190	40	17	And in the uppermost basket there was of all manner of bakemeats for Pharaoh; and the birds did eat them out of the basket upon my head.
1191	40	18	And Joseph answered and said, This is the interpretation thereof: The three baskets are three days:
1192	40	19	Yet within three days shall Pharaoh lift up thy head from off thee, and shall hang thee on a tree; and the birds shall eat thy flesh from off thee.
1193	40	20	And it came to pass the third day, which was Pharaoh's birthday, that he made a feast unto all his servants: and he lifted up the head of the chief butler and of the chief baker among his servants.
1194	40	21	And he restored the chief butler unto his butlership again; and he gave the cup into Pharaoh's hand:
1195	40	22	But he hanged the chief baker: as Joseph had interpreted to them.
1196	40	23	Yet did not the chief butler remember Joseph, but forgat him.
1197	41	1	AND it came to pass at the end of two full years, that Pharaoh dreamed: and, behold, he stood by the river.
1198	41	2	And, behold, there came up out of the river seven well favoured kine and fatfleshed; and they fed in a meadow.
1199	41	3	And, behold, seven other kine came up after them out of the river, ill favoured and leanfleshed; and stood by the other kine upon the brink of the river.
1200	41	4	And the ill favoured and leanfleshed kine did eat up the seven well favoured and fat kine. So Pharaoh awoke.
1201	41	5	And he slept and dreamed the second time: and, behold, seven ears of corn came up upon one stalk, rank and good.
1202	41	6	And, behold, seven thin ears and blasted with the east wind sprung up after them.
1203	41	7	And the seven thin ears devoured the seven rank and full ears. And Pharaoh awoke, and, behold, it was a dream.
1204	41	8	And it came to pass in the morning that his spirit was troubled; and he sent and called for all the magicians of Egypt, and all the wise men thereof: and Pharaoh told them his dream; but there was none that could interpret them unto Pharaoh.
1205	41	9	Then spake the chief butler unto Pharaoh, saying, I do remember my faults this day:
1206	41	10	Pharaoh was wroth with his servants, and put me in ward in the captain of the guard's house, both me and the chief baker:
1207	41	11	And we dreamed a dream in one night, I and he; we dreamed each man according to the interpretation of his dream.
1208	41	12	And there was there with us a young man, an Hebrew, servant to the captain of the guard; and we told him, and he interpreted to us our dreams; to each man according to his dream he did interpret.
1209	41	13	And it came to pass, as he interpreted to us, so it was; me he restored unto mine office, and him he hanged.
1210	41	14	Then Pharaoh sent and called Joseph, and they brought him hastily out of the dungeon: and he shaved himself, and changed his raiment, and came in unto Pharaoh.
1211	41	15	And Pharaoh said unto Joseph, I have dreamed a dream, and there is none that can interpret it: and I have heard say of thee, that thou canst understand a dream to interpret it.
1212	41	16	And Joseph answered Pharaoh, saying, It is not in me: God shall give Pharaoh an answer of peace.
1213	41	17	And Pharaoh said unto Joseph, In my dream, behold, I stood upon the bank of the river:
1214	41	18	And, behold, there came up out of the river seven kine, fatfleshed and well favoured; and they fed in a meadow:
1215	41	19	And, behold, seven other kine came up after them, poor and very ill favoured and leanfleshed, such as I never saw in all the land of Egypt for badness:
1216	41	20	And the lean and the ill favoured kine did eat up the first seven fat kine:
1217	41	21	And when they had eaten them up, it could not be known that they had eaten them; but they were still ill favoured, as at the beginning. So I awoke.
1218	41	22	And I saw in my dream, and, behold, seven ears came up in one stalk, full and good:
1219	41	23	And, behold, seven ears, withered, thin, and blasted with the east wind, sprung up after them:
1220	41	24	And the thin ears devoured the seven good ears: and I told this unto the magicians; but there was none that could declare it to me.
1221	41	25	And Joseph said unto Pharaoh, The dream of Pharaoh is one: God hath shewed Pharaoh what he is about to do.
1222	41	26	The seven good kine are seven years; and the seven good ears are seven years: the dream is one.
1223	41	27	And the seven thin and ill favoured kine that came up after them are seven years; and the seven empty ears blasted with the east wind shall be seven years of famine.
1224	41	28	This is the thing which I have spoken unto Pharaoh: What God is about to do he sheweth unto Pharaoh.
1225	41	29	Behold, there come seven years of great plenty throughout all the land of Egypt:
1226	41	30	And there shall arise after them seven years of famine; and all the plenty shall be forgotten in the land of Egypt; and the famine shall consume the land;
1227	41	31	And the plenty shall not be known in the land by reason of that famine following; for it shall be very grievous.
1228	41	32	And for that the dream was doubled unto Pharaoh twice; it is because the thing is established by God, and God will shortly bring it to pass.
1229	41	33	Now therefore let Pharaoh look out a man discreet and wise, and set him over the land of Egypt.
1230	41	34	Let Pharaoh do this, and let him appoint officers over the land, and take up the fifth part of the land of Egypt in the seven plenteous years.
1231	41	35	And let them gather all the food of those good years that come, and lay up corn under the hand of Pharaoh, and let them keep food in the cities.
1232	41	36	And that food shall be for store to the land against the seven years of famine, which shall be in the land of Egypt; that the land perish not through the famine.
1233	41	37	And the thing was good in the eyes of Pharaoh, and in the eyes of all his servants.
1234	41	38	And Pharaoh said unto his servants, Can we find such a one as this is, a man in whom the Spirit of God is?
1235	41	39	And Pharaoh said unto Joseph, Forasmuch as God hath shewed thee all this, there is none so discreet and wise as thou art:
1236	41	40	Thou shalt be over my house, and according unto thy word shall all my people be ruled: only in the throne will I be greater than thou.
1237	41	41	And Pharaoh said unto Joseph, See, I have set thee over all the land of Egypt.
1238	41	42	And Pharaoh took off his ring from his hand, and put it upon Joseph's hand, and arrayed him in vestures of fine linen, and put a gold chain about his neck;
1239	41	43	And he made him to ride in the second chariot which he had; and they cried before him, Bow the knee: and he made him ruler over all the land of Egypt.
1240	41	44	And Pharaoh said unto Joseph, I am Pharaoh, and without thee shall no man lift up his hand or foot in all the land of Egypt.
1241	41	45	And Pharaoh called Joseph's name Zaphnath-paaneah; and he gave him to wife Asenath the daughter of Potipherah priest of On. And Joseph went out over all the land of Egypt.
1242	41	46	And Joseph was thirty years old when he stood before Pharaoh king of Egypt. And Joseph went out from the presence of Pharaoh, and went throughout all the land of Egypt.
1243	41	47	And in the seven plenteous years the earth brought forth by handfuls.
1244	41	48	And he gathered up all the food of the seven years, which were in the land of Egypt, and laid up the food in the cities: the food of the field, which was round about every city, laid he up in the same.
1245	41	49	And Joseph gathered corn as the sand of the sea, very much, until he left numbering; for it was without number.
1246	41	50	And unto Joseph were born two sons before the years of famine came, which Asenath the daughter of Potipherah priest of On bare unto him.
1247	41	51	And Joseph called the name of the firstborn Manasseh: For God, said he, hath made me forget all my toil, and all my father's house.
1248	41	52	And the name of the second called he Ephraim: For God hath caused me to be fruitful in the land of my affliction.
1249	41	53	And the seven years of plenteousness, that was in the land of Egypt, were ended.
1250	41	54	And the seven years of dearth began to come, according as Joseph had said: and the dearth was in all lands; but in all the land of Egypt there was bread.
1251	41	55	And when all the land of Egypt was famished, the people cried to Pharaoh for bread: and Pharaoh said unto all the Egyptians, Go unto Joseph; what he saith to you, do.
1252	41	56	And the famine was over all the face of the earth: And Joseph opened all the storehouses, and sold unto the Egyptians; and the famine waxed sore in the land of Egypt.
1253	41	57	And all countries came into Egypt to Joseph for to buy corn; because that the famine was so sore in all lands.
1254	42	1	NOW when Jacob saw that there was corn in Egypt, Jacob said unto his sons, Why do ye look one upon another?
1255	42	2	And he said, Behold, I have heard that there is corn in Egypt: get you down thither, and buy for us from thence; that we may live, and not die.
1256	42	3	And Joseph's ten brethren went down to buy corn in Egypt.
1257	42	4	But Benjamin, Joseph's brother, Jacob sent not with his brethren; for he said, Lest peradventure mischief befall him.
1258	42	5	And the sons of Israel came to buy corn among those that came: for the famine was in the land of Canaan.
1259	42	6	And Joseph was the governor over the land, and he it was that sold to all the people of the land: and Joseph's brethren came, and bowed down themselves before him with their faces to the earth.
1260	42	7	And Joseph saw his brethren, and he knew them, but made himself strange unto them, and spake roughly unto them; and he said unto them, Whence come ye? And they said, From the land of Canaan to buy food.
1261	42	8	And Joseph knew his brethren, but they knew not him.
1262	42	9	And Joseph remembered the dreams which he dreamed of them, and said unto them, Ye are spies; to see the nakedness of the land ye are come.
1263	42	10	And they said unto him, Nay, my lord, but to buy food are thy servants come.
1264	42	11	We are all one man's sons; we are true men, thy servants are no spies.
1265	42	12	And he said unto them, Nay, but to see the nakedness of the land ye are come.
1266	42	13	And they said, Thy servants are twelve brethren, the sons of one man in the land of Canaan; and, behold, the youngest is this day with our father, and one is not.
1267	42	14	And Joseph said unto them, That is it that I spake unto you, saying, Ye are spies:
1268	42	15	Hereby ye shall be proved: By the life of Pharaoh ye shall not go forth hence, except your youngest brother come hither.
1269	42	16	Send one of you, and let him fetch your brother, and ye shall be kept in prison, that your words may be proved, whether there be any truth in you: or else by the life of Pharaoh surely ye are spies.
1270	42	17	And he put them all together into ward three days.
1271	42	18	And Joseph said unto them the third day, This do, and live; for I fear God:
1272	42	19	If ye be true men, let one of your brethren be bound in the house of your prison: go ye, carry corn for the famine of your houses:
1273	42	20	But bring your youngest brother unto me; so shall your words be verified, and ye shall not die. And they did so.
1274	42	21	And they said one to another, We are verily guilty concerning our brother, in that we saw the anguish of his soul, when he besought us, and we would not hear; therefore is this distress come upon us.
1275	42	22	And Reuben answered them, saying, Spake I not unto you, saying, Do not sin against the child; and ye would not hear? therefore, behold, also his blood is required.
1276	42	23	And they knew not that Joseph understood them; for he spake unto them by an interpreter.
1277	42	24	And he turned himself about from them, and wept; and returned to them again, and communed with them, and took from them Simeon, and bound him before their eyes.
1278	42	25	Then Joseph commanded to fill their sacks with corn, and to restore every man's money into his sack, and to give them provision for the way: and thus did he unto them.
1279	42	26	And they laded their asses with the corn, and departed thence.
1280	42	27	And as one of them opened his sack to give his ass provender in the inn, he espied his money; for, behold, it was in his sack's mouth.
1281	42	28	And he said unto his brethren, My money is restored; and, lo, it is even in my sack: and their heart failed them, and they were afraid, saying one to another, What is this that God hath done unto us?
1282	42	29	And they came unto Jacob their father unto the land of Canaan, and told him all that befell unto them; saying,
1283	42	30	The man, who is the lord of the land, spake roughly to us, and took us for spies of the country.
1284	42	31	And we said unto him, We are true men; we are no spies:
1285	42	32	We be twelve brethren, sons of our father; one is not, and the youngest is this day with our father in the land of Canaan.
1286	42	33	And the man, the lord of the country, said unto us, Hereby shall I know that ye are true men; leave one of your brethren here with me, and take food for the famine of your households, and be gone:
1287	42	34	And bring your youngest brother unto me: then shall I know that ye are no spies, but that ye are true men: so will I deliver you your brother, and ye shall traffick in the land.
1288	42	35	And it came to pass as they emptied their sacks, that, behold, every man's bundle of money was in his sack: and when both they and their father saw the bundles of money, they were afraid.
1289	42	36	And Jacob their father said unto them, Me have ye bereaved of my children: Joseph is not, and Simeon is not, and ye will take Benjamin away: all these things are against me.
1290	42	37	And Reuben spake unto his father, saying, Slay my two sons, if I bring him not to thee: deliver him into my hand, and I will bring him to thee again.
1291	42	38	And he said, My son shall not go down with you; for his brother is dead, and he is left alone: if mischief befall him by the way in the which ye go, then shall ye bring down my gray hairs with sorrow to the grave.
1292	43	1	AND the famine was sore in the land.
1293	43	2	And it came to pass, when they had eaten up the corn which they had brought out of Egypt, their father said unto them, Go again, buy us a little food.
1294	43	3	And Judah spake unto him, saying, The man did solemnly protest unto us, saying, Ye shall not see my face, except your brother be with you.
1295	43	4	If thou wilt send our brother with us, we will go down and buy thee food:
1296	43	5	But if thou wilt not send him, we will not go down: for the man said unto us, Ye shall not see my face, except your brother be with you.
1297	43	6	And Israel said, Wherefore dealt ye so ill with me, as to tell the man whether ye had yet a brother?
1298	43	7	And they said, The man asked us straitly of our state, and of our kindred, saying, Is your father yet alive? have ye another brother? and we told him according to the tenor of these words: could we certainly know that he would say, Bring your brother down?
1299	43	8	And Judah said unto Israel his father, Send the lad with me, and we will arise and go; that we may live, and not die, both we, and thou, and also our little ones.
1300	43	9	I will be surety for him; of my hand shalt thou require him: if I bring him not unto thee, and set him before thee, then let me bear the blame for ever:
1301	43	10	For except we had lingered, surely now we had returned this second time.
1302	43	11	And their father Israel said unto them, If it must be so now, do this; take of the best fruits of the land in your vessels, and carry down the man a present, a little balm, and a little honey, spices, and myrrh, nuts, and almonds:
1303	43	12	And take double money in your hand; and the money that was brought again in the mouth of your sacks, carry it again in your hand; peradventure it was an oversight:
1304	43	13	Take also your brother, and arise, go again unto the man:
1305	43	14	And God Almighty give you mercy before the man, that he may send away your other brother, and Benjamin. If I be bereaved of my children, I am bereaved.
1306	43	15	And the men took that present, and they took double money in their hand, and Benjamin; and rose up, and went down to Egypt, and stood before Joseph.
1307	43	16	And when Joseph saw Benjamin with them, he said to the ruler of his house, Bring these men home, and slay, and make ready; for these men shall dine with me at noon.
1308	43	17	And the man did as Joseph bade; and the man brought the men into Joseph's house.
1309	43	18	And the men were afraid, because they were brought into Joseph's house; and they said, Because of the money that was returned in our sacks at the first time are we brought in; that he may seek occasion against us, and fall upon us, and take us for bondmen, and our asses.
1310	43	19	And they came near to the steward of Joseph's house, and they communed with him at the door of the house,
1311	43	20	And said, O sir, we came indeed down at the first time to buy food:
1312	43	21	And it came to pass, when we came to the inn, that we opened our sacks, and, behold, every man's money was in the mouth of his sack, our money in full weight: and we have brought it again in our hand.
1313	43	22	And other money have we brought down in our hands to buy food: we cannot tell who put our money in our sacks.
1314	43	23	And he said, Peace be to you, fear not: your God, and the God of your father, hath given you treasure in your sacks: I had your money. And he brought Simeon out unto them.
1315	43	24	And the man brought the men into Joseph's house, and gave them water, and they washed their feet; and he gave their asses provender.
1316	43	25	And they made ready the present against Joseph came at noon: for they heard that they should eat bread there.
1317	43	26	And when Joseph came home, they brought him the present which was in their hand into the house, and bowed themselves to him to the earth.
1318	43	27	And he asked them of their welfare, and said, Is your father well, the old man of whom ye spake? Is he yet alive?
1319	43	28	And they answered, Thy servant our father is in good health, he is yet alive. And they bowed down their heads, and made obeisance.
1320	43	29	And he lifted up his eyes, and saw his brother Benjamin, his mother's son, and said, Is this your younger brother, of whom ye spake unto me? And he said, God be gracious unto thee, my son.
1321	43	30	And Joseph made haste; for his bowels did yearn upon his brother: and he sought where to weep; and he entered into his chamber, and wept there.
1322	43	31	And he washed his face, and went out, and refrained himself, and said, Set on bread.
1323	43	32	And they set on for him by himself, and for them by themselves, and for the Egyptians, which did eat with him, by themselves: because the Egyptians might not eat bread with the Hebrews; for that is an abomination unto the Egyptians.
1324	43	33	And they sat before him, the firstborn according to his birthright, and the youngest according to his youth: and the men marvelled one at another.
1325	43	34	And he took and sent messes unto them from before him: but Benjamin's mess was five times so much as any of theirs. And they drank, and were merry with him.
1326	44	1	AND he commanded the steward of his house, saying, Fill the men's sacks with food, as much as they can carry, and put every man's money in his sack's mouth.
1327	44	2	And put my cup, the silver cup, in the sack's mouth of the youngest, and his corn money. And he did according to the word that Joseph had spoken.
1328	44	3	As soon as the morning was light, the men were sent away, they and their asses.
1329	44	4	And when they were gone out of the city, and not yet far off, Joseph said unto his steward, Up, follow after the men; and when thou dost overtake them, say unto them, Wherefore have ye rewarded evil for good?
1330	44	5	Is not this it in which my lord drinketh, and whereby indeed he divineth? ye have done evil in so doing.
1331	44	6	And he overtook them, and he spake unto them these same words.
1332	44	7	And they said unto him, Wherefore saith my lord these words? God forbid that thy servants should do according to this thing:
1333	44	8	Behold, the money, which we found in our sacks' mouths, we brought again unto thee out of the land of Canaan: how then should we steal out of thy lord's house silver or gold?
1334	44	9	With whomsoever of thy servants it be found, both let him die, and we also will be my lord's bondmen.
1335	44	10	And he said, Now also let it be according unto your words: he with whom it is found shall be my servant; and ye shall be blameless.
1336	44	11	Then they speedily took down every man his sack to the ground, and opened every man his sack.
1337	44	12	And he searched, and began at the eldest, and left at the youngest: and the cup was found in Benjamin's sack.
1338	44	13	Then they rent their clothes, and laded every man his ass, and returned to the city.
1339	44	14	And Judah and his brethren came to Joseph's house; for he was yet there: and they fell before him on the ground.
1340	44	15	And Joseph said unto them, What deed is this that ye have done? wot ye not that such a man as I can certainly divine?
1341	44	16	And Judah said, What shall we say unto my lord? what shall we speak? or how shall we clear ourselves? God hath found out the iniquity of thy servants: behold, we are my lord's servants, both we, and he also with whom the cup is found.
1342	44	17	And he said, God forbid that I should do so: but the man in whose hand the cup is found, he shall be my servant; and as for you, get you up in peace unto your father.
1343	44	18	Then Judah came near unto him, and said, Oh my lord, let thy servant, I pray thee, speak a word in my lord's ears, and let not thine anger burn against thy servant: for thou art even as Pharaoh.
1344	44	19	My lord asked his servants, saying, Have ye a father, or a brother?
1345	44	20	And we said unto my lord, We have a father, an old man, and a child of his old age, a little one; and his brother is dead, and he alone is left of his mother, and his father loveth him.
1346	44	21	And thou saidst unto thy servants, Bring him down unto me, that I may set mine eyes upon him.
1347	44	22	And we said unto my lord, The lad cannot leave his father: for if he should leave his father, his father would die.
1348	44	23	And thou saidst unto thy servants, Except your youngest brother come down with you, ye shall see my face no more.
1349	44	24	And it came to pass when we came up unto thy servant my father, we told him the words of my lord.
1350	44	25	And our father said, Go again, and buy us a little food.
1351	44	26	And we said, We cannot go down: if our youngest brother be with us, then will we go down: for we may not see the man's face, except our youngest brother be with us.
1352	44	27	And thy servant my father said unto us, Ye know that my wife bare me two sons:
1353	44	28	And the one went out from me, and I said, Surely he is torn in pieces; and I saw him not since:
1354	44	29	And if ye take this also from me, and mischief befall him, ye shall bring down my gray hairs with sorrow to the grave.
1355	44	30	Now therefore when I come to thy servant my father, and the lad be not with us; seeing that his life is bound up in the lad's life;
1356	44	31	It shall come to pass, when he seeth that the lad is not with us, that he will die: and thy servants shall bring down the gray hairs of thy servant our father with sorrow to the grave.
1357	44	32	For thy servant became surety for the lad unto my father, saying, If I bring him not unto thee, then I shall bear the blame to my father for ever.
1358	44	33	Now therefore, I pray thee, let thy servant abide instead of the lad a bondman to my lord; and let the lad go up with his brethren.
1359	44	34	For how shall I go up to my father, and the lad be not with me? lest peradventure I see the evil that shall come on my father.
1360	45	1	THEN Joseph could not refrain himself before all them that stood by him; and he cried, Cause every man to go out from me. And there stood no man with him, while Joseph made himself known unto his brethren.
1361	45	2	And he wept aloud: and the Egyptians and the house of Pharaoh heard.
1362	45	3	And Joseph said unto his brethren, I am Joseph; doth my father yet live? And his brethren could not answer him; for they were troubled at his presence.
1363	45	4	And Joseph said unto his brethren, Come near to me, I pray you. And they came near. And he said, I am Joseph your brother, whom ye sold into Egypt.
1364	45	5	Now therefore be not grieved, nor angry with yourselves, that ye sold me hither: for God did send me before you to preserve life.
1365	45	6	For these two years hath the famine been in the land: and yet there are five years, in the which there shall neither be earing nor harvest.
1366	45	7	And God sent me before you to preserve you a posterity in the earth, and to save your lives by a great deliverance.
1367	45	8	So now it was not you that sent me hither, but God: and he hath made me a father to Pharaoh, and lord of all his house, and a ruler throughout all the land of Egypt.
1368	45	9	Haste ye, and go up to my father, and say unto him, Thus saith thy son Joseph, God hath made me lord of all Egypt: come down unto me, tarry not:
1369	45	10	And thou shalt dwell in the land of Goshen, and thou shalt be near unto me, thou, and thy children, and thy children's children, and thy flocks, and thy herds, and all that thou hast:
1370	45	11	And there will I nourish thee; for yet there are five years of famine; lest thou, and thy household, and all that thou hast, come to poverty.
1371	45	12	And, behold, your eyes see, and the eyes of my brother Benjamin, that it is my mouth that speaketh unto you.
1372	45	13	And ye shall tell my father of all my glory in Egypt, and of all that ye have seen: and ye shall haste and bring down my father hither.
1373	45	14	And he fell upon his brother Benjamin's neck, and wept; and Benjamin wept upon his neck.
1374	45	15	Moreover he kissed all his brethren, and wept upon them: and after that his brethren talked with him.
1375	45	16	And the fame thereof was heard in Pharaoh's house, saying, Joseph's brethren are come: and it pleased Pharaoh well, and his servants.
1376	45	17	And Pharaoh said unto Joseph, Say unto thy brethren, This do ye; lade your beasts, and go, get you unto the land of Canaan;
1377	45	18	And take your father and your households, and come unto me: and I will give you the good of the land of Egypt, and ye shall eat the fat of the land.
1378	45	19	Now thou art commanded, this do ye; take you wagons out of the land of Egypt for your little ones, and for your wives, and bring your father, and come.
1379	45	20	Also regard not your stuff; for the good of all the land of Egypt is yours.
1380	45	21	And the children of Israel did so: and Joseph gave them wagons, according to the commandment of Pharaoh, and gave them provision for the way.
1381	45	22	To all of them he gave each man changes of raiment; but to Benjamin he gave three hundred pieces of silver, and five changes of raiment.
1382	45	23	And to his father he sent after this manner; ten asses laden with the good things of Egypt, and ten she asses laden with corn and bread and meat for his father by the way.
1383	45	24	So he sent his brethren away, and they departed: and he said unto them, See that ye fall not out by the way.
1384	45	25	And they went up out of Egypt, and came into the land of Canaan unto Jacob their father,
1385	45	26	And told him, saying, Joseph is yet alive, and he is governor over all the land of Egypt. And Jacob's heart fainted, for he believed them not.
1386	45	27	And they told him all the words of Joseph, which he had said unto them: and when he saw the wagons which Joseph had sent to carry him, the spirit of Jacob their father revived:
1387	45	28	And Israel said, It is enough; Joseph my son is yet alive: I will go and see him before I die.
1388	46	1	AND Israel took his journey with all that he had, and came to Beer-sheba, and offered sacrifices unto the God of his father Isaac.
1389	46	2	And God spake unto Israel in the visions of the night, and said, Jacob, Jacob. And he said, Here am I.
1390	46	3	And he said, I am God, the God of thy father: fear not to go down into Egypt; for I will there make of thee a great nation:
1391	46	4	I will go down with thee into Egypt; and I will also surely bring thee up again: and Joseph shall put his hand upon thine eyes.
1392	46	5	And Jacob rose up from Beer-sheba: and the sons of Israel carried Jacob their father, and their little ones, and their wives, in the wagons which Pharaoh had sent to carry him.
1393	46	6	And they took their cattle, and their goods, which they had gotten in the land of Canaan, and came into Egypt, Jacob, and all his seed with him:
1394	46	7	His sons, and his sons' sons with him, his daughters, and his sons' daughters, and all his seed brought he with him into Egypt.
1395	46	8	And these are the names of the children of Israel, which came into Egypt, Jacob and his sons: Reuben, Jacob's firstborn.
1396	46	9	And the sons of Reuben; Hanoch, and Phallu, and Hezron, and Carmi.
1397	46	10	And the sons of Simeon; Jemuel, and Jamin, and Ohad, and Jachin, and Zohar, and Shaul the son of a Canaanitish woman.
1398	46	11	And the sons of Levi; Gershon, Kohath, and Merari.
1399	46	12	And the sons of Judah; Er, and Onan, and Shelah, and Pharez, and Zerah: but Er and Onan died in the land of Canaan. And the sons of Pharez were Hezron and Hamul.
1400	46	13	And the sons of Issachar; Tola, and Phuvah, and Job, and Shimron.
1401	46	14	And the sons of Zebulun; Sered, and Elon, and Jahleel.
1402	46	15	These be the sons of Leah, which she bare unto Jacob in Padan-aram, with his daughter Dinah: all the souls of his sons and his daughters were thirty and three.
1403	46	16	And the sons of Gad; Ziphion, and Haggi, Shuni, and Ezbon, Eri, and Arodi, and Areli.
1404	46	17	And the sons of Asher; Jimnah, and Ishuah, and Isui, and Beriah, and Serah their sister: and the sons of Beriah; Heber, and Malchiel.
1405	46	18	These are the sons of Zilpah, whom Laban gave to Leah his daughter, and these she bare unto Jacob, even sixteen souls.
1406	46	19	The sons of Rachel Jacob's wife; Joseph, and Benjamin.
1407	46	20	And unto Joseph in the land of Egypt were born Manasseh and Ephraim, which Asenath the daughter of Poti-pherah priest of On bare unto him.
1408	46	21	And the sons of Benjamin were Belah, and Becher, and Ashbel, Gera, and Naaman, Ehi, and Rosh, Muppim, and Huppim, and Ard.
1409	46	22	These are the sons of Rachel, which were born to Jacob: all the souls were fourteen.
1410	46	23	And the sons of Dan; Hushim.
1411	46	24	And the sons of Naphtali; Jahzeel, and Guni, and Jezer, and Shillem.
1412	46	25	These are the sons of Bilhah, which Laban gave unto Rachel his daughter, and she bare these unto Jacob: all the souls were seven.
1413	46	26	All the souls that came with Jacob into Egypt, which came out of his loins, besides Jacob's sons' wives, all the souls were threescore and six;
1414	46	27	And the sons of Joseph, which were born him in Egypt, were two souls: all the souls of the house of Jacob, which came into Egypt, were threescore and ten.
1415	46	28	And he sent Judah before him unto Joseph, to direct his face unto Goshen; and they came into the land of Goshen.
1416	46	29	And Joseph made ready his chariot, and went up to meet Israel his father, to Goshen, and presented himself unto him; and he fell on his neck, and wept on his neck a good while.
1417	46	30	And Israel said unto Joseph, Now let me die, since I have seen thy face, because thou art yet alive.
1418	46	31	And Joseph said unto his brethren, and unto his father's house, I will go up, and shew Pharaoh, and say unto him, My brethren, and my father's house, which were in the land of Canaan, are come unto me;
1419	46	32	And the men are shepherds, for their trade hath been to feed cattle; and they have brought their flocks, and their herds, and all that they have.
1420	46	33	And it shall come to pass, when Pharaoh shall call you, and shall say, What is your occupation?
1421	46	34	That ye shall say, Thy servants' trade hath been about cattle from our youth even until now, both we, and also our fathers: that ye may dwell in the land of Goshen; for every shepherd is an abomination unto the Egyptians.
1422	47	1	THEN Joseph came and told Pharaoh, and said, My father and my brethren, and their flocks, and their herds, and all that they have, are come out of the land of Canaan; and, behold, they are in the land of Goshen.
1423	47	2	And he took some of his brethren, even five men, and presented them unto Pharaoh.
1424	47	3	And Pharaoh said unto his brethren, What is your occupation? And they said unto Pharaoh, Thy servants are shepherds, both we, and also our fathers.
1425	47	4	They said moreover unto Pharaoh, For to sojourn in the land are we come; for thy servants have no pasture for their flocks; for the famine is sore in the land of Canaan: now therefore, we pray thee, let thy servants dwell in the land of Goshen.
1426	47	5	And Pharaoh spake unto Joseph, saying, Thy father and thy brethren are come unto thee:
1427	47	6	The land of Egypt is before thee; in the best of the land make thy father and brethren to dwell; in the land of Goshen let them dwell: and if thou knowest any men of activity among them, then make them rulers over my cattle.
1428	47	7	And Joseph brought in Jacob his father, and set him before Pharaoh: and Jacob blessed Pharaoh.
1429	47	8	And Pharaoh said unto Jacob, How old art thou?
1430	47	9	And Jacob said unto Pharaoh, The days of the years of my pilgrimage are an hundred and thirty years: few and evil have the days of the years of my life been, and have not attained unto the days of the years of the life of my fathers in the days of their pilgrimage.
1431	47	10	And Jacob blessed Pharaoh, and went out from before Pharaoh.
1432	47	11	And Joseph placed his father and his brethren, and gave them a possession in the land of Egypt, in the best of the land, in the land of Rameses, as Pharaoh had commanded.
1433	47	12	And Joseph nourished his father, and his brethren, and all his father's household, with bread, according to their families.
1434	47	13	And there was no bread in all the land; for the famine was very sore, so that the land of Egypt and all the land of Canaan fainted by reason of the famine.
1435	47	14	And Joseph gathered up all the money that was found in the land of Egypt, and in the land of Canaan, for the corn which they bought: and Joseph brought the money into Pharaoh's house.
1436	47	15	And when money failed in the land of Egypt, and in the land of Canaan, all the Egyptians came unto Joseph, and said, Give us bread: for why should we die in thy presence? for the money faileth.
1437	47	16	And Joseph said, Give your cattle; and I will give you for your cattle, if money fail.
1438	47	17	And they brought their cattle unto Joseph: and Joseph gave them bread in exchange for horses, and for the flocks, and for the cattle of the herds, and for the asses: and he fed them with bread for all their cattle for that year.
1439	47	18	When that year was ended, they came unto him the second year, and said unto him, We will not hide it from my lord, how that our money is spent; my lord also hath our herds of cattle; there is not ought left in the sight of my lord, but our bodies, and our lands:
1440	47	19	Wherefore shall we die before thine eyes, both we and our land? buy us and our land for bread, and we and our land will be servants unto Pharaoh: and give us seed, that we may live, and not die, that the land be not desolate.
1441	47	20	And Joseph bought all the land of Egypt for Pharaoh; for the Egyptians sold every man his field, because the famine prevailed over them: so the land became Pharaoh's.
1442	47	21	And as for the people, he removed them to cities from one end of the borders of Egypt even to the other end thereof.
1443	47	22	Only the land of the priests bought he not; for the priests had a portion assigned them of Pharaoh, and did eat their portion which Pharaoh gave them: wherefore they sold not their lands.
1444	47	23	Then Joseph said unto the people, Behold, I have bought you this day and your land for Pharaoh: lo, here is seed for you, and ye shall sow the land.
1445	47	24	And it shall come to pass in the increase, that ye shall give the fifth part unto Pharaoh, and four parts shall be your own, for seed of the field, and for your food, and for them of your households, and for food for your little ones.
1446	47	25	And they said, Thou hast saved our lives: let us find grace in the sight of my lord, and we will be Pharaoh's servants.
1447	47	26	And Joseph made it a law over the land of Egypt unto this day, that Pharaoh should have the fifth part; except the land of the priests only, which became not Pharaoh's.
1448	47	27	And Israel dwelt in the land of Egypt, in the country of Goshen; and they had possessions therein, and grew, and multiplied exceedingly.
1449	47	28	And Jacob lived in the land of Egypt seventeen years: so the whole age of Jacob was an hundred forty and seven years.
1450	47	29	And the time drew nigh that Israel must die: and he called his son Joseph, and said unto him, If now I have found grace in thy sight, put, I pray thee, thy hand under my thigh, and deal kindly and truly with me; bury me not, I pray thee, in Egypt:
1451	47	30	But I will lie with my fathers, and thou shalt carry me out of Egypt, and bury me in their buryingplace. And he said, I will do as thou hast said.
1452	47	31	And he said, Swear unto me. And he sware unto him. And Israel bowed himself upon the bed's head.
1453	48	1	AND it came to pass after these things, that one told Joseph, Behold, thy father is sick: and he took with him his two sons, Manasseh and Ephraim.
1454	48	2	And one told Jacob, and said, Behold, thy son Joseph cometh unto thee: and Israel strengthened himself, and sat upon the bed.
1455	48	3	And Jacob said unto Joseph, God Almighty appeared unto me at Luz in the land of Canaan, and blessed me,
1456	48	4	And said unto me, Behold, I will make thee fruitful, and multiply thee, and I will make of thee a multitude of people; and will give this land to thy seed after thee for an everlasting possession.
1457	48	5	And now thy two sons, Ephraim and Manasseh, which were born unto thee in the land of Egypt before I came unto thee into Egypt, are mine; as Reuben and Simeon, they shall be mine.
1458	48	6	And thy issue, which thou begettest after them, shall be thine, and shall be called after the name of their brethren in their inheritance.
1459	48	7	And as for me, when I came from Padan, Rachel died by me in the land of Canaan in the way, when yet there was but a little way to come unto Ephrath: and I buried her there in the way of Ephrath; the same is Beth-lehem.
1460	48	8	And Israel beheld Joseph's sons, and said, Who are these?
1461	48	9	And Joseph said unto his father, They are my sons, whom God hath given me in this place. And he said, Bring them, I pray thee, unto me, and I will bless them.
1462	48	10	Now the eyes of Israel were dim for age, so that he could not see. And he brought them near unto him; and he kissed them, and embraced them.
1463	48	11	And Israel said unto Joseph, I had not thought to see thy face: and, lo, God hath shewed me also thy seed.
1464	48	12	And Joseph brought them out from between his knees, and he bowed himself with his face to the earth.
1465	48	13	And Joseph took them both, Ephraim in his right hand toward Israel's left hand, and Manasseh in his left hand toward Israel's right hand, and brought them near unto him.
1466	48	14	And Israel stretched out his right hand, and laid it upon Ephraim's head, who was the younger, and his left hand upon Manasseh's head, guiding his hands wittingly; for Manasseh was the firstborn.
1467	48	15	And he blessed Joseph, and said, God, before whom my fathers Abraham and Isaac did walk, the God which fed me all my life long unto this day.
1468	48	16	The Angel which redeemed me from all evil, bless the lads; and let my name be named on them, and the name of my fathers Abraham and Isaac; and let them grow into a multitude in the midst of the earth.
1469	48	17	And when Joseph saw that his father laid his right hand upon the head of Ephraim, it displeased him: and he held up his father's hand, to remove it from Ephraim's head unto Manasseh's head.
1470	48	18	And Joseph said unto his father, Not so, my father: for this is the firstborn; put thy right hand upon his head.
1471	48	19	And his father refused, and said, I know it, my son, I know it: he also shall become a people, and he also shall be great: but truly his younger brother shall be greater than he, and his seed shall become a multitude of nations.
1472	48	20	And he blessed them that day, saying, In thee shall Israel bless, saying, God make thee as Ephraim and as Manasseh: and he set Ephraim before Manasseh.
1473	48	21	And Israel said unto Joseph, Behold, I die: but God shall be with you, and bring you again unto the land of your fathers.
1474	48	22	Moreover I have given to thee one portion above thy brethren, which I took out of the hand of the Amorite with my sword and with my bow.
1475	49	1	AND Jacob called unto his sons, and said, Gather yourselves together, that I may tell you that which shall befall you in the last days.
1476	49	2	Gather yourselves together, and hear, ye sons of Jacob; and hearken unto Israel your father.
1477	49	3	Reuben, thou art my firstborn, my might, and the beginning of my strength, the excellency of dignity, and the excellency of power:
1478	49	4	Unstable as water, thou shalt not excel; because thou wentest up to thy father's bed; then defiledst thou it: he went up to my couch.
1479	49	5	Simeon and Levi are brethren; instruments of cruelty are in their habitations.
1480	49	6	O my soul, come not thou into their secret; unto their assembly, mine honour, be not thou united: for in their anger they slew a man, and in their selfwill they digged down a wall.
1481	49	7	Cursed be their anger, for it was fierce; and their wrath, for it was cruel: I will divide them in Jacob, and scatter them in Israel.
1482	49	8	Judah, thou art he whom thy brethren shall praise: thy hand shall be in the neck of thine enemies; thy father's children shall bow down before thee.
1483	49	9	Judah is a lion's whelp: from the prey, my son, thou art gone up: he stooped down, he couched as a lion, and as an old lion; who shall rouse him up?
1484	49	10	The sceptre shall not depart from Judah, nor a lawgiver from between his feet, until Shiloh come; and unto him shall the gathering of the people be.
1485	49	11	Binding his foal unto the vine, and his ass's colt unto the choice vine; he washed his garments in wine, and his clothes in the blood of grapes:
1486	49	12	His eyes shall be red with wine, and his teeth white with milk.
1487	49	13	Zebulun shall dwell at the haven of the sea; and he shall be for an haven of ships; and his border shall be unto Zidon.
1488	49	14	Issachar is a strong ass couching down between two burdens:
1489	49	15	And he saw that rest was good, and the land that it was pleasant; and bowed his shoulder to bear, and became a servant unto tribute.
1490	49	16	Dan shall judge his people, as one of the tribes of Israel.
1491	49	17	Dan shall be a serpent by the way, an adder in the path, that biteth the horse heels, so that his rider shall fall backward.
1492	49	18	I have waited for thy salvation, O LORD.
1493	49	19	Gad, a troop shall overcome him: but he shall overcome at the last.
1494	49	20	Out of Asher his bread shall be fat, and he shall yield royal dainties.
1495	49	21	Naphtali is a hind let loose: he giveth goodly words.
1496	49	22	Joseph is a fruitful bough, even a fruitful bough by a well; whose branches run over the wall:
1497	49	23	The archers have sorely grieved him, and shot at him, and hated him:
1498	49	24	But his bow abode in strength, and the arms of his hands were made strong by the hands of the mighty God of Jacob; (from thence is the shepherd, the stone of Israel:)
1499	49	25	Even by the God of thy father, who shall help thee; and by the Almighty, who shall bless thee with blessings of heaven above, blessings of the deep that lieth under, blessings of the breasts, and of the womb:
1500	49	26	The blessings of thy father have prevailed above the blessings of my progenitors unto the utmost bound of the everlasting hills: they shall be on the head of Joseph, and on the crown of the head of him that was separate from his brethren.
1501	49	27	Benjamin shall ravin as a wolf: in the morning he shall devour the prey, and at night he shall divide the spoil.
1502	49	28	All these are the twelve tribes of Israel: and this is it that their father spake unto them, and blessed them; every one according to his blessing he blessed them.
1503	49	29	And he charged them, and said unto them, I am to be gathered unto my people: bury me with my fathers in the cave that is in the field of Ephron the Hittite,
1504	49	30	In the cave that is in the field of Machpelah, which is before Mamre, in the land of Canaan, which Abraham bought with the field of Ephron the Hittite for a possession of a buryingplace.
1505	49	31	There they buried Abraham and Sarah his wife; there they buried Isaac and Rebekah his wife; and there I buried Leah.
1506	49	32	The purchase of the field and of the cave that is therein was from the children of Heth.
1507	49	33	And when Jacob had made an end of commanding his sons, he gathered up his feet into the bed, and yielded up the ghost, and was gathered unto his people.
1508	50	1	AND Joseph fell upon his father's face, and wept upon him, and kissed him.
1509	50	2	And Joseph commanded his servants the physicians to embalm his father: and the physicians embalmed Israel.
1510	50	3	And forty days were fulfilled for him; for so are fulfilled the days of those which are embalmed: and the Egyptians mourned for him threescore and ten days.
1511	50	4	And when the days of his mourning were past, Joseph spake unto the house of Pharaoh, saying, If now I have found grace in your eyes, speak, I pray you, in the ears of Pharaoh, saying,
1512	50	5	My father made me swear, saying, Lo, I die: in my grave which I have digged for me in the land of Canaan, there shalt thou bury me. Now therefore let me go up, I pray thee, and bury my father, and I will come again.
1513	50	6	And Pharaoh said, Go up, and bury thy father, according as he made thee swear.
1514	50	7	And Joseph went up to bury his father: and with him went up all the servants of Pharaoh, the elders of his house, and all the elders of the land of Egypt,
1515	50	8	And all the house of Joseph, and his brethren, and his father's house: only their little ones, and their flocks, and their herds, they left in the land of Goshen.
1516	50	9	And there went up with him both chariots and horsemen: and it was a very great company.
1517	50	10	And they came to the threshingfloor of Atad, which is beyond Jordan, and there they mourned with a great and very sore lamentation: and he made a mourning for his father seven days.
1518	50	11	And when the inhabitants of the land, the Canaanites, saw the mourning in the floor of Atad, they said, This is a grievous mourning to the Egyptians: wherefore the name of it was called Abel-mizraim, which is beyond Jordan.
1519	50	12	And his sons did unto him according as he commanded them:
1520	50	13	For his sons carried him into the land of Canaan, and buried him in the cave of the field of Machpelah, which Abraham bought with the field for a possession of a buryingplace of Ephron the Hittite, before Mamre.
1521	50	14	And Joseph returned into Egypt, he, and his brethren, and all that went up with him to bury his father, after he had buried his father.
1522	50	15	And when Joseph's brethren saw that their father was dead, they said, Joseph will peradventure hate us, and will certainly requite us all the evil which we did unto him.
1523	50	16	And they sent a messenger unto Joseph, saying, Thy father did command before he died, saying,
1524	50	17	So shall ye say unto Joseph, Forgive, I pray thee now, the trespass of thy brethren, and their sin; for they did unto thee evil: and now, we pray thee, forgive the trespass of the servants of the God of thy father. And Joseph wept when they spake unto him.
1525	50	18	And his brethren also went and fell down before his face; and they said, Behold, we be thy servants.
1526	50	19	And Joseph said unto them, Fear not: for am I in the place of God?
1527	50	20	But as for you, ye thought evil against me; but God meant it unto good, to bring to pass, as it is this day, to save much people alive.
1528	50	21	Now therefore fear ye not: I will nourish you, and your little ones. And he comforted them, and spake kindly unto them.
1529	50	22	And Joseph dwelt in Egypt, he, and his father's house: and Joseph lived an hundred and ten years.
1530	50	23	And Joseph saw Ephraim's children of the third generation: the children also of Machir the son of Manasseh were brought up upon Joseph's knees.
1531	50	24	And Joseph said unto his brethren, I die: and God will surely visit you, and bring you out of this land unto the land which he sware to Abraham, to Isaac, and to Jacob.
1532	50	25	And Joseph took an oath of the children of Israel, saying, God will surely visit you, and ye shall carry up my bones from hence.
1533	50	26	So Joseph died, being an hundred and ten years old: and they embalmed him, and he was put in a coffin in Egypt.
1534	51	1	NOW these are the names of the children of Israel, which came into Egypt; every man and his household came with Jacob.
1535	51	2	Reuben, Simeon, Levi, and Judah,
1536	51	3	Issachar, Zebulun, and Benjamin,
1537	51	4	Dan, and Naphtali, Gad, and Asher.
1538	51	5	And all the souls that came out of the loins of Jacob were seventy souls: for Joseph was in Egypt already.
1539	51	6	And Joseph died, and all his brethren, and all that generation.
1540	51	7	And the children of Israel were fruitful, and increased abundantly, and multiplied, and waxed exceeding mighty; and the land was filled with them.
1541	51	8	Now there arose up a new king over Egypt, which knew not Joseph.
1542	51	9	And he said unto his people, Behold, the people of the children of Israel are more and mightier than we:
1543	51	10	Come on, let us deal wisely with them; lest they multiply, and it come to pass, that, when there falleth out any war, they join also unto our enemies, and fight against us, and so get them up out of the land.
1544	51	11	Therefore they did set over them taskmasters to afflict them with their burdens. And they built for Pharaoh treasure cities, Pithom and Raamses.
1545	51	12	But the more they afflicted them, the more they multiplied and grew. And they were grieved because of the children of Israel.
1546	51	13	And the Egyptians made the children of Israel to serve with rigour:
1547	51	14	And they made their lives bitter with hard bondage, in morter, and in brick, and in all manner of service in the field: all their service, wherein they made them serve, was with rigour.
1548	51	15	And the king of Egypt spake to the Hebrew midwives, of which the name of the one was Shiphrah, and the name of the other Puah:
1549	51	16	And he said, When ye do the office of a midwife to the Hebrew women, and see them upon the stools; if it be a son, then ye shall kill him: but if it be a daughter, then she shall live.
1550	51	17	But the midwives feared God, and did not as the king of Egypt commanded them, but saved the men children alive.
1551	51	18	And the king of Egypt called for the midwives, and said unto them, Why have ye done this thing, and have saved the men children alive?
1552	51	19	And the midwives said unto Pharaoh, Because the Hebrew women are not as the Egyptian women; for they are lively, and are delivered ere the midwives come in unto them.
1553	51	20	Therefore God dealt well with the midwives: and the people multiplied, and waxed very mighty.
1554	51	21	And it came to pass, because the midwives feared God, that he made them houses.
1555	51	22	And Pharaoh charged all his people, saying, Every son that is born ye shall cast into the river, and every daughter ye shall save alive.
1556	52	1	AND there went a man of the house of Levi, and took to wife a daughter of Levi.
1557	52	2	And the woman conceived, and bare a son: and when she saw him that he was a goodly child, she hid him three months.
1558	52	3	And when she could not longer hide him, she took for him an ark of bulrushes, and daubed it with slime and with pitch, and put the child therein; and she laid it in the flags by the river's brink.
1559	52	4	And his sister stood afar off, to wit what would be done to him.
1560	52	5	And the daughter of Pharaoh came down to wash herself at the river; and her maidens walked along by the river's side; and when she saw the ark among the flags, she sent her maid to fetch it.
1561	52	6	And when she had opened it, she saw the child: and, behold, the babe wept. And she had compassion on him, and said, This is one of the Hebrews' children.
1562	52	7	Then said his sister to Pharaoh's daughter, Shall I go and call to thee a nurse of the Hebrew women, that she may nurse the child for thee?
1563	52	8	And Pharaoh's daughter said to her, Go. And the maid went and called the child's mother.
1564	52	9	And Pharaoh's daughter said unto her, Take this child away, and nurse it for me, and I will give thee thy wages. And the woman took the child, and nursed it.
1565	52	10	And the child grew, and she brought him unto Pharaoh's daughter, and he became her son. And she called his name Moses: and she said, Because I drew him out of the water.
1566	52	11	And it came to pass in those days, when Moses was grown, that he went out unto his brethren, and looked on their burdens: and he spied an Egyptian smiting an Hebrew, one of his brethren.
1567	52	12	And he looked this way and that way, and when he saw that there was no man, he slew the Egyptian, and hid him in the sand.
1568	52	13	And when he went out the second day, behold, two men of the Hebrews strove together: and he said to him that did the wrong, Wherefore smitest thou thy fellow?
1569	52	14	And he said, Who made thee a prince and a judge over us? intendest thou to kill me, as thou killedst the Egyptian? And Moses feared, and said, Surely this thing is known.
1570	52	15	Now when Pharaoh heard this thing, he sought to slay Moses. But Moses fled from the face of Pharaoh, and dwelt in the land of Midian: and he sat down by a well.
1571	52	16	Now the priest of Midian had seven daughters: and they came and drew water, and filled the troughs to water their father's flock.
1572	52	17	And the shepherds came and drove them away: but Moses stood up and helped them, and watered their flock.
1573	52	18	And when they came to Reuel their father, he said, How is it that ye are come so soon to day?
1574	52	19	And they said, An Egyptian delivered us out of the hand of the shepherds, and also drew water enough for us, and watered the flock.
1575	52	20	And he said unto his daughters, And where is he? why is it that ye have left the man? call him, that he may eat bread.
1576	52	21	And Moses was content to dwell with the man: and he gave Moses Zipporah his daughter.
1577	52	22	And she bare him a son, and he called his name Gershom: for he said, I have been a stranger in a strange land.
1578	52	23	And it came to pass in process of time, that the king of Egypt died: and the children of Israel sighed by reason of the bondage, and they cried, and their cry came up unto God by reason of the bondage.
1579	52	24	And God heard their groaning, and God remembered his covenant with Abraham, with Isaac, and with Jacob.
1580	52	25	And God looked upon the children of Israel, and God had respect unto them.
1581	53	1	NOW Moses kept the flock of Jethro his father in law, the priest of Midian: and he led the flock to the backside of the desert, and came to the mountain of God, even to Horeb.
1582	53	2	And the angel of the LORD appeared unto him in a flame of fire out of the midst of a bush: and he looked, and, behold, the bush burned with fire, and the bush was not consumed.
1583	53	3	And Moses said, I will now turn aside, and see this great sight, why the bush is not burnt.
1584	53	4	And when the LORD saw that he turned aside to see, God called unto him out of the midst of the bush, and said, Moses, Moses. And he said, Here am I.
1585	53	5	And he said, Draw not nigh hither: put off thy shoes from off thy feet, for the place whereon thou standest is holy ground.
1586	53	6	Moreover he said, I am the God of thy father, the God of Abraham, the God of Isaac, and the God of Jacob. And Moses hid his face; for he was afraid to look upon God.
1587	53	7	And the LORD said, I have surely seen the affliction of my people which are in Egypt, and have heard their cry by reason of their taskmasters; for I know their sorrows;
1588	53	8	And I am come down to deliver them out of the hand of the Egyptians, and to bring them up out of that land unto a good land and a large, unto a land flowing with milk and honey; unto the place of the Canaanites, and the Hittites, and the Amorites, and the Perizzites, and the Hivites, and the Jebusites.
1589	53	9	Now therefore, behold, the cry of the children of Israel is come unto me: and I have also seen the oppression wherewith the Egyptians oppress them.
1590	53	10	Come now therefore, and I will send thee unto Pharaoh, that thou mayest bring forth my people the children of Israel out of Egypt.
1591	53	11	And Moses said unto God, Who am I, that I should go unto Pharaoh, and that I should bring forth the children of Israel out of Egypt?
1592	53	12	And he said, Certainly I will be with thee; and this shall be a token unto thee, that I have sent thee: When thou hast brought forth the people out of Egypt, ye shall serve God upon this mountain.
1593	53	13	And Moses said unto God, Behold, when I come unto the children of Israel, and shall say unto them, The God of your fathers hath sent me unto you; and they shall say to me, What is his name? what shall I say unto them?
1594	53	14	And God said unto Moses, I AM THAT I AM: and he said, Thus shalt thou say unto the children of Israel, I AM hath sent me unto you.
1595	53	15	And God said moreover unto Moses, Thus shalt thou say unto the children of Israel, The LORD God of your fathers, the God of Abraham, the God of Isaac, and the God of Jacob, hath sent me unto you: this is my name for ever, and this is my memorial unto all generations.
1596	53	16	Go, and gather the elders of Israel together, and say unto them, The LORD God of your fathers, the God of Abraham, of Isaac, and of Jacob, appeared unto me, saying, I have surely visited you, and seen that which is done to you in Egypt:
1597	53	17	And I have said, I will bring you up out of the affliction of Egypt unto the land of the Canaanites, and the Hittites, and the Amorites, and the Perizzites, and the Hivites, and the Jebusites, unto a land flowing with milk and honey.
1598	53	18	And they shall hearken to thy voice: and thou shalt come, thou and the elders of Israel, unto the king of Egypt, and ye shall say unto him, The LORD God of the Hebrews hath met with us: and now let us go, we beseech thee, three days' journey into the wilderness, that we may sacrifice to the LORD our God.
1599	53	19	And I am sure that the king of Egypt will not let you go, no, not by a mighty hand.
1600	53	20	And I will stretch out my hand, and smite Egypt with all my wonders which I will do in the midst thereof: and after that he will let you go.
1601	53	21	And I will give this people favour in the sight of the Egyptians: and it shall come to pass, that, when ye go, ye shall not go empty:
1602	53	22	But every woman shall borrow of her neighbour, and of her that sojourneth in her house, jewels of silver, and jewels of gold, and raiment: and ye shall put them upon your sons, and upon your daughters; and ye shall spoil the Egyptians.
1603	54	1	AND Moses answered and said, But, behold, they will not believe me, nor hearken unto my voice: for they will say, The LORD hath not appeared unto thee.
1604	54	2	And the LORD said unto him, What is that in thine hand? And he said, A rod.
1605	54	3	And he said, Cast it on the ground. And he cast it on the ground, and it became a serpent; and Moses fled from before it.
1606	54	4	And the LORD said unto Moses, Put forth thine hand, and take it by the tail. And he put forth his hand, and caught it, and it became a rod in his hand:
1607	54	5	That they may believe that the LORD God of their fathers, the God of Abraham, the God of Isaac, and the God of Jacob, hath appeared unto thee.
1608	54	6	And the LORD said furthermore unto him, Put now thine hand into thy bosom. And he put his hand into his bosom: and when he took it out, behold, his hand was leprous as snow.
1609	54	7	And he said, Put thine hand into thy bosom again. And he put his hand into his bosom again; and plucked it out of his bosom, and, behold, it was turned again as his other flesh.
1610	54	8	And it shall come to pass, if they will not believe thee, neither hearken to the voice of the first sign, that they will believe the voice of the latter sign.
1611	54	9	And it shall come to pass, if they will not believe also these two signs, neither hearken unto thy voice, that thou shalt take of the water of the river, and pour it upon the dry land: and the water which thou takest out of the river shall become blood upon the dry land.
1612	54	10	And Moses said unto the LORD, O my Lord, I am not eloquent, neither heretofore, nor since thou hast spoken unto thy servant: but I am slow of speech, and of a slow tongue.
1613	54	11	And the LORD said unto him, Who hath made man's mouth? or who maketh the dumb, or deaf, or the seeing, or the blind? have not I the LORD?
1614	54	12	Now therefore go, and I will be with thy mouth, and teach thee what thou shalt say.
1615	54	13	And he said, O my Lord, send, I pray thee, by the hand of him whom thou wilt send.
1616	54	14	And the anger of the LORD was kindled against Moses, and he said, Is not Aaron the Levite thy brother? I know that he can speak well. And also, behold, he cometh forth to meet thee: and when he seeth thee, he will be glad in his heart.
1617	54	15	And thou shalt speak unto him, and put words in his mouth: and I will be with thy mouth, and with his mouth, and will teach you what ye shall do.
1618	54	16	And he shall be thy spokesman unto the people: and he shall be, even he shall be to thee instead of a mouth, and thou shalt be to him instead of God.
1619	54	17	And thou shalt take this rod in thine hand, wherewith thou shalt do signs.
1620	54	18	And Moses went and returned to Jethro his father in law, and said unto him, Let me go, I pray thee, and return unto my brethren which are in Egypt, and see whether they be yet alive. And Jethro said to Moses, Go in peace.
1621	54	19	And the LORD said unto Moses in Midian, Go, return into Egypt: for all the men are dead which sought thy life.
1622	54	20	And Moses took his wife and his sons, and set them upon an ass, and he returned to the land of Egypt: and Moses took the rod of God in his hand.
1623	54	21	And the LORD said unto Moses, When thou goest to return into Egypt, see that thou do all those wonders before Pharaoh, which I have put in thine hand: but I will harden his heart, that he shall not let the people go.
1624	54	22	And thou shalt say unto Pharaoh, Thus saith the LORD, Israel is my son, even my firstborn:
1625	54	23	And I say unto thee, Let my son go, that he may serve me: and if thou refuse to let him go, behold, I will slay thy son, even thy firstborn.
1626	54	24	And it came to pass by the way in the inn, that the LORD met him, and sought to kill him.
1627	54	25	Then Zipporah took a sharp stone, and cut off the foreskin of her son, and cast it at his feet, and said, Surely a bloody husband art thou to me.
1628	54	26	So he let him go: then she said, A bloody husband thou art, because of the circumcision.
1629	54	27	And the LORD said to Aaron, Go into the wilderness to meet Moses. And he went, and met him in the mount of God, and kissed him.
1630	54	28	And Moses told Aaron all the words of the LORD who had sent him, and all the signs which he had commanded him.
1631	54	29	And Moses and Aaron went and gathered together all the elders of the children of Israel:
1632	54	30	And Aaron spake all the words which the LORD had spoken unto Moses, and did the signs in the sight of the people.
1633	54	31	And the people believed: and when they heard that the LORD had visited the children of Israel, and that he had looked upon their affliction, then they bowed their heads and worshipped.
1634	55	1	AND afterward Moses and Aaron went in, and told Pharaoh, Thus saith the LORD God of Israel, Let my people go, that they may hold a feast unto me in the wilderness.
1635	55	2	And Pharaoh said, Who is the LORD, that I should obey his voice to let Israel go? I know not the LORD, neither will I let Israel go.
1636	55	3	And they said, The God of the Hebrews hath met with us: let us go, we pray thee, three days' journey into the desert, and sacrifice unto the LORD our God; lest he fall upon us with pestilence, or with the sword.
1637	55	4	And the king of Egypt said unto them, Wherefore do ye, Moses and Aaron, let the people from their works? get you unto your burdens.
1638	55	5	And Pharaoh said, Behold, the people of the land now are many, and ye make them rest from their burdens.
1639	55	6	And Pharaoh commanded the same day the taskmasters of the people, and their officers, saying,
1640	55	7	Ye shall no more give the people straw to make brick, as heretofore: let them go and gather straw for themselves.
1641	55	8	And the tale of the bricks, which they did make heretofore, ye shall lay upon them; ye shall not diminish ought thereof: for they be idle; therefore they cry, saying, Let us go and sacrifice to our God.
1642	55	9	Let there more work be laid upon the men, that they may labour therein; and let them not regard vain words.
1643	55	10	And the taskmasters of the people went out, and their officers, and they spake to the people, saying, Thus saith Pharaoh, I will not give you straw.
1644	55	11	Go ye, get you straw where ye can find it: yet not ought of your work shall be diminished.
1645	55	12	So the people were scattered abroad throughout all the land of Egypt to gather stubble instead of straw.
1646	55	13	And the taskmasters hasted them, saying, Fulfil your works, your daily tasks, as when there was straw.
1647	55	14	And the officers of the children of Israel, which Pharaoh's taskmasters had set over them, were beaten, and demanded, Wherefore have ye not fulfilled your task in making brick both yesterday and to day, as heretofore?
1648	55	15	Then the officers of the children of Israel came and cried unto Pharaoh, saying, Wherefore dealest thou thus with thy servants?
1649	55	16	There is no straw given unto thy servants, and they say to us, Make brick: and, behold, thy servants are beaten; but the fault is in thine own people.
1650	55	17	But he said, Ye are idle, ye are idle: therefore ye say, Let us go and do sacrifice to the LORD.
1651	55	18	Go therefore now, and work; for there shall no straw be given you, yet shall ye deliver the tale of bricks.
1652	55	19	And the officers of the children of Israel did see that they were in evil case, after it was said, Ye shall not minish ought from your bricks of your daily task.
1653	55	20	And they met Moses and Aaron, who stood in the way, as they came forth from Pharaoh:
1654	55	21	And they said unto them, The LORD look upon you, and judge; because ye have made our savour to be abhorred in the eyes of Pharaoh, and in the eyes of his servants, to put a sword in their hand to slay us.
1655	55	22	And Moses returned unto the LORD, and said, Lord, wherefore hast thou so evil entreated this people? why is it that thou hast sent me?
1656	55	23	For since I came to Pharaoh to speak in thy name, he hath done evil to this people; neither hast thou delivered thy people at all.
1657	56	1	THEN the LORD said unto Moses, Now shalt thou see what I will do to Pharaoh: for with a strong hand shall he let them go, and with a strong hand shall he drive them out of his land.
1658	56	2	And God spake unto Moses, and said unto him, I am the LORD:
1659	56	3	And I appeared unto Abraham, unto Isaac, and unto Jacob, by the name of God Almighty, but by my name JEHOVAH was I not known to them.
1660	56	4	And I have also established my covenant with them, to give them the land of Canaan, the land of their pilgrimage, wherein they were strangers.
1661	56	5	And I have also heard the groaning of the children of Israel, whom the Egyptians keep in bondage; and I have remembered my covenant.
1662	56	6	Wherefore say unto the children of Israel, I am the LORD, and I will bring you out from under the burdens of the Egyptians, and I will rid you out of their bondage, and I will redeem you with a stretched out arm, and with great judgments:
1663	56	7	And I will take you to me for a people, and I will be to you a God: and ye shall know that I am the LORD your God, which bringeth you out from under the burdens of the Egyptians.
1664	56	8	And I will bring you in unto the land, concerning the which I did swear to give it to Abraham, to Isaac, and to Jacob; and I will give it you for an heritage: I am the LORD.
1665	56	9	And Moses spake so unto the children of Israel: but they hearkened not unto Moses for anguish of spirit, and for cruel bondage.
1666	56	10	And the LORD spake unto Moses, saying,
1667	56	11	Go in, speak unto Pharaoh king of Egypt, that he let the children of Israel go out of his land.
1668	56	12	And Moses spake before the LORD, saying, Behold, the children of Israel have not hearkened unto me; how then shall Pharaoh hear me, who am of uncircumcised lips?
1669	56	13	And the LORD spake unto Moses and unto Aaron, and gave them a charge unto the children of Israel, and unto Pharaoh king of Egypt, to bring the children of Israel out of the land of Egypt.
1670	56	14	These be the heads of their fathers' houses: The sons of Reuben the firstborn of Israel; Hanoch, and Pallu, Hezron, and Carmi: these be the families of Reuben.
1671	56	15	And the sons of Simeon; Jemuel, and Jamin, and Ohad, and Jachin, and Zohar, and Shaul the son of a Canaanitish woman: these are the families of Simeon.
1672	56	16	And these are the names of the sons of Levi according to their generations; Gershon, and Kohath, and Merari: and the years of the life of Levi were an hundred thirty and seven years.
1673	56	17	The sons of Gershon; Libni, and Shimi, according to their families.
1674	56	18	And the sons of Kohath; Amram, and Izhar, and Hebron, and Uzziel: and the years of the life of Kohath were an hundred thirty and three years.
1675	56	19	And the sons of Merari; Mahali and Mushi: these are the families of Levi according to their generations.
1676	56	20	And Amram took him Jochebed his father's sister to wife; and she bare him Aaron and Moses: and the years of the life of Amram were an hundred and thirty and seven years.
1677	56	21	And the sons of Izhar; Korah, and Nepheg, and Zichri.
1678	56	22	And the sons of Uzziel; Mishael, and Elzaphan, and Zithri.
1679	56	23	And Aaron took him Elisheba, daughter of Amminadab, sister of Naashon, to wife; and she bare him Nadab, and Abihu, Eleazar, and Ithamar.
1680	56	24	And the sons of Korah; Assir, and Elkanah, and Abiasaph: these are the families of the Korhites.
1681	56	25	And Eleazar Aaron's son took him one of the daughters of Putiel to wife; and she bare him Phinehas: these are the heads of the fathers of the Levites according to their families.
1682	56	26	These are that Aaron and Moses, to whom the LORD said, Bring out the children of Israel from the land of Egypt according to their armies.
1683	56	27	These are they which spake to Pharaoh king of Egypt, to bring out the children of Israel from Egypt: these are that Moses and Aaron.
1684	56	28	And it came to pass on the day when the LORD spake unto Moses in the land of Egypt,
1685	56	29	That the LORD spake unto Moses, saying, I am the LORD: speak thou unto Pharaoh king of Egypt all that I say unto thee.
1686	56	30	And Moses said before the LORD, Behold, I am of uncircumcised lips, and how shall Pharaoh hearken unto me?
1687	57	1	AND the LORD said unto Moses, See, I have made thee a god to Pharaoh: and Aaron thy brother shall be thy prophet.
1688	57	2	Thou shalt speak all that I command thee: and Aaron thy brother shall speak unto Pharaoh, that he send the children of Israel out of his land.
1689	57	3	And I will harden Pharaoh's heart, and multiply my signs and my wonders in the land of Egypt.
1690	57	4	But Pharaoh shall not hearken unto you, that I may lay my hand upon Egypt, and bring forth mine armies, and my people the children of Israel, out of the land of Egypt by great judgments.
1691	57	5	And the Egyptians shall know that I am the LORD, when I stretch forth mine hand upon Egypt, and bring out the children of Israel from among them.
1692	57	6	And Moses and Aaron did as the LORD commanded them, so did they.
1693	57	7	And Moses was fourscore years old, and Aaron fourscore and three years old, when they spake unto Pharaoh.
1694	57	8	And the LORD spake unto Moses and unto Aaron, saying,
1695	57	9	When Pharaoh shall speak unto you, saying, Shew a miracle for you: then thou shalt say unto Aaron, Take thy rod, and cast it before Pharaoh, and it shall become a serpent.
1696	57	10	And Moses and Aaron went in unto Pharaoh, and they did so as the LORD had commanded: and Aaron cast down his rod before Pharaoh, and before his servants, and it became a serpent.
1697	57	11	Then Pharaoh also called the wise men and the sorcerers: now the magicians of Egypt, they also did in like manner with their enchantments.
1698	57	12	For they cast down every man his rod, and they became serpents: but Aaron's rod swallowed up their rods.
1699	57	13	And he hardened Pharaoh's heart, that he hearkened not unto them; as the LORD had said.
1700	57	14	And the LORD said unto Moses, Pharaoh's heart is hardened, he refuseth to let the people go.
1701	57	15	Get thee unto Pharaoh in the morning; lo, he goeth out unto the water; and thou shalt stand by the river's brink against he come; and the rod which was turned to a serpent shalt thou take in thine hand.
1702	57	16	And thou shalt say unto him, The LORD God of the Hebrews hath sent me unto thee, saying, Let my people go, that they may serve me in the wilderness: and, behold, hitherto thou wouldest not hear.
1703	57	17	Thus saith the LORD, In this thou shalt know that I am the LORD: behold, I will smite with the rod that is in mine hand upon the waters which are in the river, and they shall be turned to blood.
1704	57	18	And the fish that is in the river shall die, and the river shall stink; and the Egyptians shall lothe to drink of the water of the river.
1705	57	19	And the LORD spake unto Moses, Say unto Aaron, Take thy rod, and stretch out thine hand upon the waters of Egypt, upon their streams, upon their rivers, and upon their ponds, and upon all their pools of water, that they may become blood; and that there may be blood throughout all the land of Egypt, both in vessels of wood, and in vessels of stone.
1706	57	20	And Moses and Aaron did so, as the LORD commanded; and he lifted up the rod, and smote the waters that were in the river, in the sight of Pharaoh, and in the sight of his servants; and all the waters that were in the river were turned to blood.
1707	57	21	And the fish that was in the river died; and the river stank, and the Egyptians could not drink of the water of the river; and there was blood throughout all the land of Egypt.
1708	57	22	And the magicians of Egypt did so with their enchantments: and Pharaoh's heart was hardened, neither did he hearken unto them; as the LORD had said.
1709	57	23	And Pharaoh turned and went into his house, neither did he set his heart to this also.
1710	57	24	And all the Egyptians digged round about the river for water to drink; for they could not drink of the water of the river.
1711	57	25	And seven days were fulfilled, after that the LORD had smitten the river.
1712	58	1	AND the LORD spake unto Moses, Go unto Pharaoh, and say unto him, Thus saith the LORD, Let my people go, that they may serve me.
1713	58	2	And if thou refuse to let them go, behold, I will smite all thy borders with frogs:
1714	58	3	And the river shall bring forth frogs abundantly, which shall go up and come into thine house, and into thy bedchamber, and upon thy bed, and into the house of thy servants, and upon thy people, and into thine ovens, and into thy kneadingtroughs:
1715	58	4	And the frogs shall come up both on thee, and upon thy people, and upon all thy servants.
1716	58	5	And the LORD spake unto Moses, Say unto Aaron, Stretch forth thine hand with thy rod over the streams, over the rivers, and over the ponds, and cause frogs to come up upon the land of Egypt.
1717	58	6	And Aaron stretched out his hand over the waters of Egypt; and the frogs came up, and covered the land of Egypt.
1718	58	7	And the magicians did so with their enchantments, and brought up frogs upon the land of Egypt.
1719	58	8	Then Pharaoh called for Moses and Aaron, and said, Intreat the LORD, that he may take away the frogs from me, and from my people; and I will let the people go, that they may do sacrifice unto the LORD.
1720	58	9	And Moses said unto Pharaoh, Glory over me: when shall I intreat for thee, and for thy servants, and for thy people, to destroy the frogs from thee and thy houses, that they may remain in the river only?
1721	58	10	And he said, To morrow. And he said, Be it according to thy word: that thou mayest know that there is none like unto the LORD our God.
1722	58	11	And the frogs shall depart from thee, and from thy houses, and from thy servants, and from thy people; they shall remain in the river only.
1723	58	12	And Moses and Aaron went out from Pharaoh: and Moses cried unto the LORD because of the frogs which he had brought against Pharaoh.
1724	58	13	And the LORD did according to the word of Moses; and the frogs died out of the houses, out of the villages, and out of the fields.
1725	58	14	And they gathered them together upon heaps: and the land stank.
1726	58	15	But when Pharaoh saw that there was respite, he hardened his heart, and hearkened not unto them; as the LORD had said.
1727	58	16	And the LORD said unto Moses, Say unto Aaron, Stretch out thy rod, and smite the dust of the land, that it may become lice throughout all the land of Egypt.
1728	58	17	And they did so; for Aaron stretched out his hand with his rod, and smote the dust of the earth, and it became lice in man, and in beast; all the dust of the land became lice throughout all the land of Egypt.
1729	58	18	And the magicians did so with their enchantments to bring forth lice, but they could not: so there were lice upon man, and upon beast.
1730	58	19	Then the magicians said unto Pharaoh, This is the finger of God: and Pharaoh's heart was hardened, and he hearkened not unto them; as the LORD had said.
1731	58	20	And the LORD said unto Moses, Rise up early in the morning, and stand before Pharaoh; lo, he cometh forth to the water; and say unto him, Thus saith the LORD, Let my people go, that they may serve me.
1732	58	21	Else, if thou wilt not let my people go, behold, I will send swarms of flies upon thee, and upon thy servants, and upon thy people, and into thy houses: and the houses of the Egyptians shall be full of swarms of flies, and also the ground whereon they are.
1733	58	22	And I will sever in that day the land of Goshen, in which my people dwell, that no swarms of flies shall be there; to the end thou mayest know that I am the LORD in the midst of the earth.
1734	58	23	And I will put a division between my people and thy people: to morrow shall this sign be.
1735	58	24	And the LORD did so; and there came a grievous swarm of flies into the house of Pharaoh, and into his servants' houses, and into all the land of Egypt: the land was corrupted by reason of the swarm of flies.
1736	58	25	And Pharaoh called for Moses and for Aaron, and said, Go ye, sacrifice to your God in the land.
1737	58	26	And Moses said, It is not meet so to do; for we shall sacrifice the abomination of the Egyptians to the LORD our God: lo, shall we sacrifice the abomination of the Egyptians before their eyes, and will they not stone us?
1738	58	27	We will go three days' journey into the wilderness, and sacrifice to the LORD our God, as he shall command us.
1739	58	28	And Pharaoh said, I will let you go, that ye may sacrifice to the LORD your God in the wilderness; only ye shall not go very far away: intreat for me.
1740	58	29	And Moses said, Behold, I go out from thee, and I will intreat the LORD that the swarms of flies may depart from Pharaoh, from his servants, and from his people, to morrow: but let not Pharaoh deal deceitfully any more in not letting the people go to sacrifice to the LORD.
1741	58	30	And Moses went out from Pharaoh, and intreated the LORD.
1742	58	31	And the LORD did according to the word of Moses; and he removed the swarms of flies from Pharaoh, from his servants, and from his people; there remained not one.
1743	58	32	And Pharaoh hardened his heart at this time also, neither would he let the people go.
1744	59	1	THEN the LORD said unto Moses, Go in unto Pharaoh, and tell him, Thus saith the LORD God of the Hebrews, Let my people go, that they may serve me.
1745	59	2	For if thou refuse to let them go, and wilt hold them still,
1746	59	3	Behold, the hand of the LORD is upon thy cattle which is in the field, upon the horses, upon the asses, upon the camels, upon the oxen, and upon the sheep: there shall be a very grievous murrain.
1747	59	4	And the LORD shall sever between the cattle of Israel and the cattle of Egypt: and there shall nothing die of all that is the children's of Israel.
1748	59	5	And the LORD appointed a set time, saying, To morrow the LORD shall do this thing in the land.
1749	59	6	And the LORD did that thing on the morrow, and all the cattle of Egypt died: but of the cattle of the children of Israel died not one.
1750	59	7	And Pharaoh sent, and, behold, there was not one of the cattle of the Israelites dead. And the heart of Pharaoh was hardened, and he did not let the people go.
1751	59	8	And the LORD said unto Moses and unto Aaron, Take to you handfuls of ashes of the furnace, and let Moses sprinkle it toward the heaven in the sight of Pharaoh.
1752	59	9	And it shall become small dust in all the land of Egypt, and shall be a boil breaking forth with blains upon man, and upon beast, throughout all the land of Egypt.
1753	59	10	And they took ashes of the furnace, and stood before Pharaoh; and Moses sprinkled it up toward heaven; and it became a boil breaking forth with blains upon man, and upon beast.
1754	59	11	And the magicians could not stand before Moses because of the boils; for the boil was upon the magicians, and upon all the Egyptians.
1755	59	12	And the LORD hardened the heart of Pharaoh, and he hearkened not unto them; as the LORD had spoken unto Moses.
1756	59	13	And the LORD said unto Moses, Rise up early in the morning, and stand before Pharaoh, and say unto him, Thus saith the LORD God of the Hebrews, Let my people go, that they may serve me.
1757	59	14	For I will at this time send all my plagues upon thine heart, and upon thy servants, and upon thy people; that thou mayest know that there is none like me in all the earth.
1758	59	15	For now I will stretch out my hand, that I may smite thee and thy people with pestilence; and thou shalt be cut off from the earth.
1759	59	16	And in very deed for this cause have I raised thee up, for to shew in thee my power; and that my name may be declared throughout all the earth.
1760	59	17	As yet exaltest thou thyself against my people, that thou wilt not let them go?
1761	59	18	Behold, to morrow about this time I will cause it to rain a very grievous hail, such as hath not been in Egypt since the foundation thereof even until now.
1762	59	19	Send therefore now, and gather thy cattle, and all that thou hast in the field; for upon every man and beast which shall be found in the field, and shall not be brought home, the hail shall come down upon them, and they shall die.
1763	59	20	He that feared the word of the LORD among the servants of Pharaoh made his servants and his cattle flee into the houses:
1764	59	21	And he that regarded not the word of the LORD left his servants and his cattle in the field.
1765	59	22	And the LORD said unto Moses, Stretch forth thine hand toward heaven, that there may be hail in all the land of Egypt, upon man, and upon beast, and upon every herb of the field, throughout the land of Egypt.
1766	59	23	And Moses stretched forth his rod toward heaven: and the LORD sent thunder and hail, and the fire ran along upon the ground; and the LORD rained hail upon the land of Egypt.
1767	59	24	So there was hail, and fire mingled with the hail, very grievous, such as there was none like it in all the land of Egypt since it became a nation.
1768	59	25	And the hail smote throughout all the land of Egypt all that was in the field, both man and beast; and the hail smote every herb of the field, and brake every tree of the field.
1769	59	26	Only in the land of Goshen, where the children of Israel were, was there no hail.
1770	59	27	And Pharaoh sent, and called for Moses and Aaron, and said unto them, I have sinned this time: the LORD is righteous, and I and my people are wicked.
1771	59	28	Intreat the LORD (for it is enough) that there be no more mighty thunderings and hail; and I will let you go, and ye shall stay no longer.
1772	59	29	And Moses said unto him, As soon as I am gone out of the city, I will spread abroad my hands unto the LORD; and the thunder shall cease, neither shall there be any more hail; that thou mayest know how that the earth is the LORD's.
1773	59	30	But as for thee and thy servants, I know that ye will not yet fear the LORD God.
1774	59	31	And the flax and the barley was smitten: for the barley was in the ear, and the flax was bolled.
1775	59	32	But the wheat and the rie were not smitten: for they were not grown up.
1776	59	33	And Moses went out of the city from Pharaoh, and spread abroad his hands unto the LORD: and the thunders and hail ceased, and the rain was not poured upon the earth.
1777	59	34	And when Pharaoh saw that the rain and the hail and the thunders were ceased, he sinned yet more, and hardened his heart, he and his servants.
1778	59	35	And the heart of Pharaoh was hardened, neither would he let the children of Israel go; as the LORD had spoken by Moses.
1779	60	1	AND the LORD said unto Moses, Go in unto Pharaoh: for I have hardened his heart, and the heart of his servants, that I might shew these my signs before him:
1780	60	2	And that thou mayest tell in the ears of thy son, and of thy son's son, what things I have wrought in Egypt, and my signs which I have done among them; that ye may know how that I am the LORD.
1781	60	3	And Moses and Aaron came in unto Pharaoh, and said unto him, Thus saith the LORD God of the Hebrews, How long wilt thou refuse to humble thyself before me? let my people go, that they may serve me.
1782	60	4	Else, if thou refuse to let my people go, behold, to morrow will I bring the locusts into thy coast:
1783	60	5	And they shall cover the face of the earth, that one cannot be able to see the earth: and they shall eat the residue of that which is escaped, which remaineth unto you from the hail, and shall eat every tree which groweth for you out of the field:
1784	60	6	And they shall fill thy houses, and the houses of all thy servants, and the houses of all the Egyptians; which neither thy fathers, nor thy fathers' fathers have seen, since the day that they were upon the earth unto this day. And he turned himself, and went out from Pharaoh.
1785	60	7	And Pharaoh's servants said unto him, How long shall this man be a snare unto us? let the men go, that they may serve the LORD their God: knowest thou not yet that Egypt is destroyed?
1786	60	8	And Moses and Aaron were brought again unto Pharaoh: and he said unto them, Go, serve the LORD your God: but who are they that shall go?
1787	60	9	And Moses said, We will go with our young and with our old, with our sons and with our daughters, with our flocks and with our herds will we go; for we must hold a feast unto the LORD.
1788	60	10	And he said unto them, Let the LORD be so with you, as I will let you go, and your little ones: look to it; for evil is before you.
1789	60	11	Not so: go now ye that are men, and serve the LORD; for that ye did desire. And they were driven out from Pharaoh's presence.
1790	60	12	And the LORD said unto Moses, Stretch out thine hand over the land of Egypt for the locusts, that they may come up upon the land of Egypt, and eat every herb of the land, even all that the hail hath left.
1791	60	13	And Moses stretched forth his rod over the land of Egypt, and the LORD brought an east wind upon the land all that day, and all that night; and when it was morning, the east wind brought the locusts.
1792	60	14	And the locusts went up over all the land of Egypt, and rested in all the coasts of Egypt: very grievous were they; before them there were no such locusts as they, neither after them shall be such.
1793	60	15	For they covered the face of the whole earth, so that the land was darkened; and they did eat every herb of the land, and all the fruit of the trees which the hail had left: and there remained not any green thing in the trees, or in the herbs of the field, through all the land of Egypt.
1794	60	16	Then Pharaoh called for Moses and Aaron in haste; and he said, I have sinned against the LORD your God, and against you.
1795	60	17	Now therefore forgive, I pray thee, my sin only this once, and intreat the LORD your God, that he may take away from me this death only.
1796	60	18	And he went out from Pharaoh, and intreated the LORD.
1797	60	19	And the LORD turned a mighty strong west wind, which took away the locusts, and cast them into the Red sea; there remained not one locust in all the coasts of Egypt.
1798	60	20	But the LORD hardened Pharaoh's heart, so that he would not let the children of Israel go.
1799	60	21	And the LORD said unto Moses, Stretch out thine hand toward heaven, that there may be darkness over the land of Egypt, even darkness which may be felt.
1800	60	22	And Moses stretched forth his hand toward heaven; and there was a thick darkness in all the land of Egypt three days:
1801	60	23	They saw not one another, neither rose any from his place for three days: but all the children of Israel had light in their dwellings.
1802	60	24	And Pharaoh called unto Moses, and said, Go ye, serve the LORD; only let your flocks and your herds be stayed: let your little ones also go with you.
1803	60	25	And Moses said, Thou must give us also sacrifices and burnt offerings, that we may sacrifice unto the LORD our God.
1804	60	26	Our cattle also shall go with us; there shall not an hoof be left behind; for thereof must we take to serve the LORD our God; and we know not with what we must serve the LORD, until we come thither.
1805	60	27	But the LORD hardened Pharaoh's heart, and he would not let them go.
1806	60	28	And Pharaoh said unto him, Get thee from me, take heed to thyself, see my face no more; for in that day thou seest my face thou shalt die.
1807	60	29	And Moses said, Thou hast spoken well, I will see thy face again no more.
1808	61	1	AND the LORD said unto Moses, Yet will I bring one plague more upon Pharaoh, and upon Egypt; afterwards he will let you go hence: when he shall let you go, he shall surely thrust you out hence altogether.
1809	61	2	Speak now in the ears of the people, and let every man borrow of his neighbour, and every woman of her neighbour, jewels of silver, and jewels of gold.
1810	61	3	And the LORD gave the people favour in the sight of the Egyptians. Moreover the man Moses was very great in the land of Egypt, in the sight of Pharaoh's servants, and in the sight of the people.
1811	61	4	And Moses said, Thus saith the LORD, About midnight will I go out into the midst of Egypt:
1812	61	5	And all the firstborn in the land of Egypt shall die, from the firstborn of Pharaoh that sitteth upon his throne, even unto the firstborn of the maidservant that is behind the mill; and all the firstborn of beasts.
1813	61	6	And there shall be a great cry throughout all the land of Egypt, such as there was none like it, nor shall be like it any more.
1814	61	7	But against any of the children of Israel shall not a dog move his tongue, against man or beast: that ye may know how that the LORD doth put a difference between the Egyptians and Israel.
1815	61	8	And all these thy servants shall come down unto me, and bow down themselves unto me, saying, Get thee out, and all the people that follow thee: and after that I will go out. And he went out from Pharaoh in a great anger.
1816	61	9	And the LORD said unto Moses, Pharaoh shall not hearken unto you; that my wonders may be multiplied in the land of Egypt.
1817	61	10	And Moses and Aaron did all these wonders before Pharaoh: and the LORD hardened Pharaoh's heart, so that he would not let the children of Israel go out of his land.
1818	62	1	AND the LORD spake unto Moses and Aaron in the land of Egypt, saying,
1819	62	2	This month shall be unto you the beginning of months: it shall be the first month of the year to you.
1820	62	3	Speak ye unto all the congregation of Israel, saying, In the tenth day of this month they shall take to them every man a lamb, according to the house of their fathers, a lamb for an house:
1821	62	4	And if the household be too little for the lamb, let him and his neighbour next unto his house take it according to the number of the souls; every man according to his eating shall make your count for the lamb.
1822	62	5	Your lamb shall be without blemish, a male of the first year: ye shall take it out from the sheep, or from the goats:
1823	62	6	And ye shall keep it up until the fourteenth day of the same month: and the whole assembly of the congregation of Israel shall kill it in the evening.
1824	62	7	And they shall take of the blood, and strike it on the two side posts and on the upper door post of the houses, wherein they shall eat it.
1825	62	8	And they shall eat the flesh in that night, roast with fire, and unleavened bread; and with bitter herbs they shall eat it.
1826	62	9	Eat not of it raw, nor sodden at all with water, but roast with fire; his head with his legs, and with the purtenance thereof.
1827	62	10	And ye shall let nothing of it remain until the morning; and that which remaineth of it until the morning ye shall burn with fire.
1828	62	11	And thus shall ye eat it; with your loins girded, your shoes on your feet, and your staff in your hand; and ye shall eat it in haste: it is the LORD's passover.
1829	62	12	For I will pass through the land of Egypt this night, and will smite all the firstborn in the land of Egypt, both man and beast; and against all the gods of Egypt I will execute judgment: I am the LORD.
1830	62	13	And the blood shall be to you for a token upon the houses where ye are: and when I see the blood, I will pass over you, and the plague shall not be upon you to destroy you, when I smite the land of Egypt.
1831	62	14	And this day shall be unto you for a memorial; and ye shall keep it a feast to the LORD throughout your generations; ye shall keep it a feast by an ordinance for ever.
1832	62	15	Seven days shall ye eat unleavened bread; even the first day ye shall put away leaven out of your houses: for whosoever eateth leavened bread from the first day until the seventh day, that soul shall be cut off from Israel.
1833	62	16	And in the first day there shall be an holy convocation, and in the seventh day there shall be an holy convocation to you; no manner of work shall be done in them, save that which every man must eat, that only may be done of you.
1834	62	17	And ye shall observe the feast of unleavened bread; for in this selfsame day have I brought your armies out of the land of Egypt: therefore shall ye observe this day in your generations by an ordinance for ever.
1835	62	18	In the first month, on the fourteenth day of the month at even, ye shall eat unleavened bread, until the one and twentieth day of the month at even.
1836	62	19	Seven days shall there be no leaven found in your houses: for whosoever eateth that which is leavened, even that soul shall be cut off from the congregation of Israel, whether he be a stranger, or born in the land.
1837	62	20	Ye shall eat nothing leavened; in all your habitations shall ye eat unleavened bread.
1838	62	21	Then Moses called for all the elders of Israel, and said unto them, Draw out and take you a lamb according to your families, and kill the passover.
1839	62	22	And ye shall take a bunch of hyssop, and dip it in the blood that is in the bason, and strike the lintel and the two side posts with the blood that is in the bason; and none of you shall go out at the door of his house until the morning.
1840	62	23	For the LORD will pass through to smite the Egyptians; and when he seeth the blood upon the lintel, and on the two side posts, the LORD will pass over the door, and will not suffer the destroyer to come in unto your houses to smite you.
1841	62	24	And ye shall observe this thing for an ordinance to thee and to thy sons for ever.
1842	62	25	And it shall come to pass, when ye be come to the land which the LORD will give you, according as he hath promised, that ye shall keep this service.
1843	62	26	And it shall come to pass, when your children shall say unto you, What mean ye by this service?
1844	62	27	That ye shall say, It is the sacrifice of the LORD's passover, who passed over the houses of the children of Israel in Egypt, when he smote the Egyptians, and delivered our houses. And the people bowed the head and worshipped.
1845	62	28	And the children of Israel went away, and did as the LORD had commanded Moses and Aaron, so did they.
1846	62	29	And it came to pass, that at midnight the LORD smote all the firstborn in the land of Egypt, from the firstborn of Pharaoh that sat on his throne unto the firstborn of the captive that was in the dungeon; and all the firstborn of cattle.
1847	62	30	And Pharaoh rose up in the night, he, and all his servants, and all the Egyptians; and there was a great cry in Egypt; for there was not a house where there was not one dead.
1848	62	31	And he called for Moses and Aaron by night, and said, Rise up, and get you forth from among my people, both ye and the children of Israel; and go, serve the LORD, as ye have said.
1849	62	32	Also take your flocks and your herds, as ye have said, and be gone; and bless me also.
1850	62	33	And the Egyptians were urgent upon the people, that they might send them out of the land in haste; for they said, We be all dead men.
1851	62	34	And the people took their dough before it was leavened, their kneadingtroughs being bound up in their clothes upon their shoulders.
1852	62	35	And the children of Israel did according to the word of Moses; and they borrowed of the Egyptians jewels of silver, and jewels of gold, and raiment:
1853	62	36	And the LORD gave the people favour in the sight of the Egyptians, so that they lent unto them such things as they required. And they spoiled the Egyptians.
1854	62	37	And the children of Israel journeyed from Rameses to Succoth, about six hundred thousand on foot that were men, beside children.
1855	62	38	And a mixed multitude went up also with them; and flocks, and herds, even very much cattle.
1856	62	39	And they baked unleavened cakes of the dough which they brought forth out of Egypt, for it was not leavened; because they were thrust out of Egypt, and could not tarry, neither had they prepared for themselves any victual.
1857	62	40	Now the sojourning of the children of Israel, who dwelt in Egypt, was four hundred and thirty years.
1858	62	41	And it came to pass at the end of the four hundred and thirty years, even the selfsame day it came to pass, that all the hosts of the LORD went out from the land of Egypt.
1859	62	42	It is a night to be much observed unto the LORD for bringing them out from the land of Egypt: this is that night of the LORD to be observed of all the children of Israel in their generations.
1860	62	43	And the LORD said unto Moses and Aaron, This is the ordinance of the passover: There shall no stranger eat thereof:
1861	62	44	But every man's servant that is bought for money, when thou hast circumcised him, then shall he eat thereof.
1862	62	45	A foreigner and an hired servant shall not eat thereof.
1863	62	46	In one house shall it be eaten; thou shalt not carry forth ought of the flesh abroad out of the house; neither shall ye break a bone thereof.
1864	62	47	All the congregation of Israel shall keep it.
1865	62	48	And when a stranger shall sojourn with thee, and will keep the passover to the LORD, let all his males be circumcised, and then let him come near and keep it; and he shall be as one that is born in the land: for no uncircumcised person shall eat thereof.
1866	62	49	One law shall be to him that is homeborn, and unto the stranger that sojourneth among you.
1867	62	50	Thus did all the children of Israel; as the LORD commanded Moses and Aaron, so did they.
1868	62	51	And it came to pass the selfsame day, that the LORD did bring the children of Israel out of the land of Egypt by their armies.
1869	63	1	AND the LORD spake unto Moses, saying,
1870	63	2	Sanctify unto me all the firstborn, whatsoever openeth the womb among the children of Israel, both of man and of beast: it is mine.
1871	63	3	And Moses said unto the people, Remember this day, in which ye came out from Egypt, out of the house of bondage; for by strength of hand the LORD brought you out from this place: there shall no leavened bread be eaten.
1872	63	4	This day came ye out in the month Abib.
1873	63	5	And it shall be when the LORD shall bring thee into the land of the Canaanites, and the Hittites, and the Amorites, and the Hivites, and the Jebusites, which he sware unto thy fathers to give thee, a land flowing with milk and honey, that thou shalt keep this service in this month.
1874	63	6	Seven days thou shalt eat unleavened bread, and in the seventh day shall be a feast to the LORD.
1875	63	7	Unleavened bread shall be eaten seven days; and there shall no leavened bread be seen with thee, neither shall there be leaven seen with thee in all thy quarters.
1876	63	8	And thou shalt shew thy son in that day, saying, This is done because of that which the LORD did unto me when I came forth out of Egypt.
1877	63	9	And it shall be for a sign unto thee upon thine hand, and for a memorial between thine eyes, that the LORD's law may be in thy mouth: for with a strong hand hath the LORD brought thee out of Egypt.
1878	63	10	Thou shalt therefore keep this ordinance in his season from year to year.
1879	63	11	And it shall be when the LORD shall bring thee into the land of the Canaanites, as he sware unto thee and to thy fathers, and shall give it thee,
1880	63	12	That thou shalt set apart unto the LORD all that openeth the matrix, and every firstling that cometh of a beast which thou hast; the males shall be the LORD's.
1881	63	13	And every firstling of an ass thou shalt redeem with a lamb; and if thou wilt not redeem it, then thou shalt break his neck: and all the firstborn of man among thy children shalt thou redeem.
1882	63	14	And it shall be when thy son asketh thee in time to come, saying, What is this? that thou shalt say unto him, By strength of hand the LORD brought us out from Egypt, from the house of bondage:
1883	63	15	And it came to pass, when Pharaoh would hardly let us go, that the LORD slew all the firstborn in the land of Egypt, both the firstborn of man, and the firstborn of beast: therefore I sacrifice to the LORD all that openeth the matrix, being males; but all the firstborn of my children I redeem.
1884	63	16	And it shall be for a token upon thine hand, and for frontlets between thine eyes: for by strength of hand the LORD brought us forth out of Egypt.
1885	63	17	And it came to pass, when Pharaoh had let the people go, that God led them not through the way of the land of the Philistines, although that was near; for God said, Lest peradventure the people repent when they see war, and they return to Egypt:
1886	63	18	But God led the people about, through the way of the wilderness of the Red sea: and the children of Israel went up harnessed out of the land of Egypt.
1887	63	19	And Moses took the bones of Joseph with him: for he had straitly sworn the children of Israel, saying, God will surely visit you; and ye shall carry up my bones away hence with you.
1888	63	20	And they took their journey from Succoth, and encamped in Etham, in the edge of the wilderness.
1889	63	21	And the LORD went before them by day in a pillar of a cloud, to lead them the way; and by night in a pillar of fire, to give them light; to go by day and night:
1890	63	22	He took not away the pillar of the cloud by day, nor the pillar of fire by night, from before the people.
1891	64	1	AND the LORD spake unto Moses, saying,
1892	64	2	Speak unto the children of Israel, that they turn and encamp before Pi-hahiroth, between Migdol and the sea, over against Baal-zephon: before it shall ye encamp by the sea.
1893	64	3	For Pharaoh will say of the children of Israel, They are entangled in the land, the wilderness hath shut them in.
1894	64	4	And I will harden Pharaoh's heart, that he shall follow after them; and I will be honoured upon Pharaoh, and upon all his host; that the Egyptians may know that I am the LORD. And they did so.
1895	64	5	And it was told the king of Egypt that the people fled: and the heart of Pharaoh and of his servants was turned against the people, and they said, Why have we done this, that we have let Israel go from serving us?
1896	64	6	And he made ready his chariot, and took his people with him:
1897	64	7	And he took six hundred chosen chariots, and all the chariots of Egypt, and captains over every one of them.
1898	64	8	And the LORD hardened the heart of Pharaoh king of Egypt, and he pursued after the children of Israel: and the children of Israel went out with an high hand.
1899	64	9	But the Egyptians pursued after them, all the horses and chariots of Pharaoh, and his horsemen, and his army, and overtook them encamping by the sea, beside Pi-hahiroth, before Baal-zephon.
1900	64	10	And when Pharaoh drew nigh, the children of Israel lifted up their eyes, and, behold, the Egyptians marched after them; and they were sore afraid: and the children of Israel cried out unto the LORD.
1901	64	11	And they said unto Moses, Because there were no graves in Egypt, hast thou taken us away to die in the wilderness? wherefore hast thou dealt thus with us, to carry us forth out of Egypt?
1902	64	12	Is not this the word that we did tell thee in Egypt, saying, Let us alone, that we may serve the Egyptians? For it had been better for us to serve the Egyptians, than that we should die in the wilderness.
1903	64	13	And Moses said unto the people, Fear ye not, stand still, and see the salvation of the LORD, which he will shew to you to day: for the Egyptians whom ye have seen to day, ye shall see them again no more for ever.
1904	64	14	The LORD shall fight for you, and ye shall hold your peace.
1905	64	15	And the LORD said unto Moses, Wherefore criest thou unto me? speak unto the children of Israel, that they go forward:
1906	64	16	But lift thou up thy rod, and stretch out thine hand over the sea, and divide it: and the children of Israel shall go on dry ground through the midst of the sea.
1907	64	17	And I, behold, I will harden the hearts of the Egyptians, and they shall follow them: and I will get me honour upon Pharaoh, and upon all his host, upon his chariots, and upon his horsemen.
1908	64	18	And the Egyptians shall know that I am the LORD, when I have gotten me honour upon Pharaoh, upon his chariots, and upon his horsemen.
1909	64	19	And the angel of God, which went before the camp of Israel, removed and went behind them; and the pillar of the cloud went from before their face, and stood behind them:
1910	64	20	And it came between the camp of the Egyptians and the camp of Israel; and it was a cloud and darkness to them, but it gave light by night to these: so that the one came not near the other all the night.
1911	64	21	And Moses stretched out his hand over the sea; and the LORD caused the sea to go back by a strong east wind all that night, and made the sea dry land, and the waters were divided.
1912	64	22	And the children of Israel went into the midst of the sea upon the dry ground: and the waters were a wall unto them on their right hand, and on their left.
1913	64	23	And the Egyptians pursued, and went in after them to the midst of the sea, even all Pharaoh's horses, his chariots, and his horsemen.
1914	64	24	And it came to pass, that in the morning watch the LORD looked unto the host of the Egyptians through the pillar of fire and of the cloud, and troubled the host of the Egyptians,
1915	64	25	And took off their chariot wheels, that they drave them heavily: so that the Egyptians said, Let us flee from the face of Israel; for the LORD fighteth for them against the Egyptians.
1916	64	26	And the LORD said unto Moses, Stretch out thine hand over the sea, that the waters may come again upon the Egyptians, upon their chariots, and upon their horsemen.
1917	64	27	And Moses stretched forth his hand over the sea, and the sea returned to his strength when the morning appeared; and the Egyptians fled against it; and the LORD overthrew the Egyptians in the midst of the sea.
1918	64	28	And the waters returned, and covered the chariots, and the horsemen, and all the host of Pharaoh that came into the sea after them; there remained not so much as one of them.
1919	64	29	But the children of Israel walked upon dry land in the midst of the sea; and the waters were a wall unto them on their right hand, and on their left.
1920	64	30	Thus the LORD saved Israel that day out of the hand of the Egyptians; and Israel saw the Egyptians dead upon the sea shore.
1921	64	31	And Israel saw that great work which the LORD did upon the Egyptians: and the people feared the LORD, and believed the LORD, and his servant Moses.
1922	65	1	THEN sang Moses and the children of Israel this song unto the LORD, and spake, saying, I will sing unto the LORD, for he hath triumphed gloriously: the horse and his rider hath he thrown into the sea.
1923	65	2	The LORD is my strength and song, and he is become my salvation: he is my God, and I will prepare him an habitation; my father's God, and I will exalt him.
1924	65	3	The LORD is a man of war: the LORD is his name.
1925	65	4	Pharaoh's chariots and his host hath he cast into the sea: his chosen captains also are drowned in the Red sea.
1926	65	5	The depths have covered them: they sank into the bottom as a stone.
1927	65	6	Thy right hand, O LORD, is become glorious in power: thy right hand, O LORD, hath dashed in pieces the enemy.
1928	65	7	And in the greatness of thine excellency thou hast overthrown them that rose up against thee: thou sentest forth thy wrath, which consumed them as stubble.
1929	65	8	And with the blast of thy nostrils the waters were gathered together, the floods stood upright as an heap, and the depths were congealed in the heart of the sea.
1930	65	9	The enemy said, I will pursue, I will overtake, I will divide the spoil; my lust shall be satisfied upon them; I will draw my sword, my hand shall destroy them.
1931	65	10	Thou didst blow with thy wind, the sea covered them: they sank as lead in the mighty waters.
1932	65	11	Who is like unto thee, O LORD, among the gods? who is like thee, glorious in holiness, fearful in praises, doing wonders?
1933	65	12	Thou stretchedst out thy right hand, the earth swallowed them.
1934	65	13	Thou in thy mercy hast led forth the people which thou hast redeemed: thou hast guided them in thy strength unto thy holy habitation.
1935	65	14	The people shall hear, and be afraid: sorrow shall take hold on the inhabitants of Palestina.
1936	65	15	Then the dukes of Edom shall be amazed; the mighty men of Moab, trembling shall take hold upon them; all the inhabitants of Canaan shall melt away.
1937	65	16	Fear and dread shall fall upon them; by the greatness of thine arm they shall be as still as a stone; till thy people pass over, O LORD, till the people pass over, which thou hast purchased.
1938	65	17	Thou shalt bring them in, and plant them in the mountain of thine inheritance, in the place, O LORD, which thou hast made for thee to dwell in, in the Sanctuary, O Lord, which thy hands have established.
1939	65	18	The LORD shall reign for ever and ever.
1940	65	19	For the horse of Pharaoh went in with his chariots and with his horsemen into the sea, and the LORD brought again the waters of the sea upon them; but the children of Israel went on dry land in the midst of the sea.
1941	65	20	And Miriam the prophetess, the sister of Aaron, took a timbrel in her hand; and all the women went out after her with timbrels and with dances.
1942	65	21	And Miriam answered them, Sing ye to the LORD, for he hath triumphed gloriously; the horse and his rider hath he thrown into the sea.
1943	65	22	So Moses brought Israel from the Red sea, and they went out into the wilderness of Shur; and they went three days in the wilderness, and found no water.
1944	65	23	And when they came to Marah, they could not drink of the waters of Marah, for they were bitter: therefore the name of it was called Marah.
1945	65	24	And the people murmured against Moses, saying, What shall we drink?
1946	65	25	And he cried unto the LORD; and the LORD shewed him a tree, which when he had cast into the waters, the waters were made sweet: there he made for them a statute and an ordinance, and there he proved them,
1947	65	26	And said, If thou wilt diligently hearken to the voice of the LORD thy God, and wilt do that which is right in his sight, and wilt give ear to his commandments, and keep all his statutes, I will put none of these diseases upon thee, which I have brought upon the Egyptians: for I am the LORD that healeth thee.
1948	65	27	And they came to Elim, where were twelve wells of water, and threescore and ten palm trees: and they encamped there by the waters.
1949	66	1	AND they took their journey from Elim, and all the congregation of the children of Israel came unto the wilderness of Sin, which is between Elim and Sinai, on the fifteenth day of the second month after their departing out of the land of Egypt.
1950	66	2	And the whole congregation of the children of Israel murmured against Moses and Aaron in the wilderness:
1951	66	3	And the children of Israel said unto them, Would to God we had died by the hand of the LORD in the land of Egypt, when we sat by the flesh pots, and when we did eat bread to the full; for ye have brought us forth into this wilderness, to kill this whole assembly with hunger.
1952	66	4	Then said the LORD unto Moses, Behold, I will rain bread from heaven for you; and the people shall go out and gather a certain rate every day, that I may prove them, whether they will walk in my law, or no.
1953	66	5	And it shall come to pass, that on the sixth day they shall prepare that which they bring in; and it shall be twice as much as they gather daily.
1954	66	6	And Moses and Aaron said unto all the children of Israel, At even, then ye shall know that the LORD hath brought you out from the land of Egypt:
1955	66	7	And in the morning, then ye shall see the glory of the LORD; for that he heareth your murmurings against the LORD: and what are we, that ye murmur against us?
1956	66	8	And Moses said, This shall be, when the LORD shall give you in the evening flesh to eat, and in the morning bread to the full; for that the LORD heareth your murmurings which ye murmur against him: and what are we? your murmurings are not against us, but against the LORD.
1957	66	9	And Moses spake unto Aaron, Say unto all the congregation of the children of Israel, Come near before the LORD: for he hath heard your murmurings.
1958	66	10	And it came to pass, as Aaron spake unto the whole congregation of the children of Israel, that they looked toward the wilderness, and, behold, the glory of the LORD appeared in the cloud.
1959	66	11	And the LORD spake unto Moses, saying,
1960	66	12	I have heard the murmurings of the children of Israel: speak unto them, saying, At even ye shall eat flesh, and in the morning ye shall be filled with bread; and ye shall know that I am the LORD your God.
1961	66	13	And it came to pass, that at even the quails came up, and covered the camp: and in the morning the dew lay round about the host.
1962	66	14	And when the dew that lay was gone up, behold, upon the face of the wilderness there lay a small round thing, as small as the hoar frost on the ground.
1963	66	15	And when the children of Israel saw it, they said one to another, It is manna: for they wist not what it was. And Moses said unto them, This is the bread which the LORD hath given you to eat.
1964	66	16	This is the thing which the LORD hath commanded, Gather of it every man according to his eating, an omer for every man, according to the number of your persons; take ye every man for them which are in his tents.
1965	66	17	And the children of Israel did so, and gathered, some more, some less.
1966	66	18	And when they did mete it with an omer, he that gathered much had nothing over, and he that gathered little had no lack; they gathered every man according to his eating.
1967	66	19	And Moses said, Let no man leave of it till the morning.
1968	66	20	Notwithstanding they hearkened not unto Moses; but some of them left of it until the morning, and it bred worms, and stank: and Moses was wroth with them.
1969	66	21	And they gathered it every morning, every man according to his eating: and when the sun waxed hot, it melted.
1970	66	22	And it came to pass, that on the sixth day they gathered twice as much bread, two omers for one man: and all the rulers of the congregation came and told Moses.
1971	66	23	And he said unto them, This is that which the LORD hath said, To morrow is the rest of the holy sabbath unto the LORD: bake that which ye will bake to day, and seethe that ye will seethe; and that which remaineth over lay up for you to be kept until the morning.
1972	66	24	And they laid it up till the morning, as Moses bade: and it did not stink, neither was there any worm therein.
1973	66	25	And Moses said, Eat that to day; for to day is a sabbath unto the LORD: to day ye shall not find it in the field.
1974	66	26	Six days ye shall gather it; but on the seventh day, which is the sabbath, in it there shall be none.
1975	66	27	And it came to pass, that there went out some of the people on the seventh day for to gather, and they found none.
1976	66	28	And the LORD said unto Moses, How long refuse ye to keep my commandments and my laws?
1977	66	29	See, for that the LORD hath given you the sabbath, therefore he giveth you on the sixth day the bread of two days; abide ye every man in his place, let no man go out of his place on the seventh day.
1978	66	30	So the people rested on the seventh day.
1979	66	31	And the house of Israel called the name thereof Manna: and it was like coriander seed, white; and the taste of it was like wafers made with honey.
1980	66	32	And Moses said, This is the thing which the LORD commandeth, Fill an omer of it to be kept for your generations; that they may see the bread wherewith I have fed you in the wilderness, when I brought you forth from the land of Egypt.
1981	66	33	And Moses said unto Aaron, Take a pot, and put an omer full of manna therein, and lay it up before the LORD, to be kept for your generations.
1982	66	34	As the LORD commanded Moses, so Aaron laid it up before the Testimony, to be kept.
1983	66	35	And the children of Israel did eat manna forty years, until they came to a land inhabited; they did eat manna, until they came unto the borders of the land of Canaan.
1984	66	36	Now an omer is the tenth part of an ephah.
1985	67	1	AND all the congregation of the children of Israel journeyed from the wilderness of Sin, after their journeys, according to the commandment of the LORD, and pitched in Rephidim: and there was no water for the people to drink.
1986	67	2	Wherefore the people did chide with Moses, and said, Give us water that we may drink. And Moses said unto them, Why chide ye with me? wherefore do ye tempt the LORD?
1987	67	3	And the people thirsted there for water; and the people murmured against Moses, and said, Wherefore is this that thou hast brought us up out of Egypt, to kill us and our children and our cattle with thirst?
1988	67	4	And Moses cried unto the LORD, saying, What shall I do unto this people? they be almost ready to stone me.
1989	67	5	And the LORD said unto Moses, Go on before the people, and take with thee of the elders of Israel; and thy rod, wherewith thou smotest the river, take in thine hand, and go.
1990	67	6	Behold, I will stand before thee there upon the rock in Horeb; and thou shalt smite the rock, and there shall come water out of it, that the people may drink. And Moses did so in the sight of the elders of Israel.
1991	67	7	And he called the name of the place Massah, and Meribah, because of the chiding of the children of Israel, and because they tempted the LORD, saying, Is the LORD among us, or not?
1992	67	8	Then came Amalek, and fought with Israel in Rephidim.
1993	67	9	And Moses said unto Joshua, Choose us out men, and go out, fight with Amalek: to morrow I will stand on the top of the hill with the rod of God in mine hand.
1994	67	10	So Joshua did as Moses had said to him, and fought with Amalek: and Moses, Aaron, and Hur went up to the top of the hill.
1995	67	11	And it came to pass, when Moses held up his hand, that Israel prevailed: and when he let down his hand, Amalek prevailed.
1996	67	12	But Moses' hands were heavy; and they took a stone, and put it under him, and he sat thereon; and Aaron and Hur stayed up his hands, the one on the one side, and the other on the other side; and his hands were steady until the going down of the sun.
1997	67	13	And Joshua discomfited Amalek and his people with the edge of the sword.
1998	67	14	And the LORD said unto Moses, Write this for a memorial in a book, and rehearse it in the ears of Joshua: for I will utterly put out the remembrance of Amalek from under heaven.
1999	67	15	And Moses built an altar, and called the name of it Jehovah-nissi:
2000	67	16	For he said, Because the LORD hath sworn that the LORD will have war with Amalek from generation to generation.
2001	68	1	WHEN Jethro, the priest of Midian, Moses' father in law, heard of all that God had done for Moses, and for Israel his people, and that the LORD had brought Israel out of Egypt;
2002	68	2	Then Jethro, Moses' father in law, took Zipporah, Moses' wife, after he had sent her back,
2003	68	3	And her two sons; of which the name of the one was Gershom; for he said, I have been an alien in a strange land:
2004	68	4	And the name of the other was Eliezer; for the God of my father, said he, was mine help, and delivered me from the sword of Pharaoh:
2005	68	5	And Jethro, Moses' father in law, came with his sons and his wife unto Moses into the wilderness, where he encamped at the mount of God:
2006	68	6	And he said unto Moses, I thy father in law Jethro am come unto thee, and thy wife, and her two sons with her.
2007	68	7	And Moses went out to meet his father in law, and did obeisance, and kissed him; and they asked each other of their welfare; and they came into the tent.
2008	68	8	And Moses told his father in law all that the LORD had done unto Pharaoh and to the Egyptians for Israel's sake, and all the travail that had come upon them by the way, and how the LORD delivered them.
2009	68	9	And Jethro rejoiced for all the goodness which the LORD had done to Israel, whom he had delivered out of the hand of the Egyptians.
2010	68	10	And Jethro said, Blessed be the LORD, who hath delivered you out of the hand of the Egyptians, and out of the hand of Pharaoh, who hath delivered the people from under the hand of the Egyptians.
2011	68	11	Now I know that the LORD is greater than all gods: for in the thing wherein they dealt proudly he was above them.
2012	68	12	And Jethro, Moses' father in law, took a burnt offering and sacrifices for God: and Aaron came, and all the elders of Israel, to eat bread with Moses' father in law before God.
2013	68	13	And it came to pass on the morrow, that Moses sat to judge the people: and the people stood by Moses from the morning unto the evening.
2014	68	14	And when Moses' father in law saw all that he did to the people, he said, What is this thing that thou doest to the people? why sittest thou thyself alone, and all the people stand by thee from morning unto even?
2015	68	15	And Moses said unto his father in law, Because the people come unto me to enquire of God:
2016	68	16	When they have a matter, they come unto me; and I judge between one and another, and I do make them know the statutes of God, and his laws.
2017	68	17	And Moses' father in law said unto him, The thing that thou doest is not good.
2018	68	18	Thou wilt surely wear away, both thou, and this people that is with thee: for this thing is too heavy for thee; thou art not able to perform it thyself alone.
2019	68	19	Hearken now unto my voice, I will give thee counsel, and God shall be with thee: Be thou for the people to God-ward, that thou mayest bring the causes unto God:
2020	68	20	And thou shalt teach them ordinances and laws, and shalt shew them the way wherein they must walk, and the work that they must do.
2021	68	21	Moreover thou shalt provide out of all the people able men, such as fear God, men of truth, hating covetousness; and place such over them, to be rulers of thousands, and rulers of hundreds, rulers of fifties, and rulers of tens:
2022	68	22	And let them judge the people at all seasons: and it shall be, that every great matter they shall bring unto thee, but every small matter they shall judge: so shall it be easier for thyself, and they shall bear the burden with thee.
2023	68	23	If thou shalt do this thing, and God command thee so, then thou shalt be able to endure, and all this people shall also go to their place in peace.
2024	68	24	So Moses hearkened to the voice of his father in law, and did all that he had said.
2025	68	25	And Moses chose able men out of all Israel, and made them heads over the people, rulers of thousands, rulers of hundreds, rulers of fifties, and rulers of tens.
2026	68	26	And they judged the people at all seasons: the hard causes they brought unto Moses, but every small matter they judged themselves.
2027	68	27	And Moses let his father in law depart; and he went his way into his own land.
2028	69	1	IN the third month, when the children of Israel were gone forth out of the land of Egypt, the same day came they into the wilderness of Sinai.
2029	69	2	For they were departed from Rephidim, and were come to the desert of Sinai, and had pitched in the wilderness; and there Israel camped before the mount.
2030	69	3	And Moses went up unto God, and the LORD called unto him out of the mountain, saying, Thus shalt thou say to the house of Jacob, and tell the children of Israel;
2031	69	4	Ye have seen what I did unto the Egyptians, and how I bare you on eagles' wings, and brought you unto myself.
2032	69	5	Now therefore, if ye will obey my voice indeed, and keep my covenant, then ye shall be a peculiar treasure unto me above all people: for all the earth is mine:
2033	69	6	And ye shall be unto me a kingdom of priests, and an holy nation. These are the words which thou shalt speak unto the children of Israel.
2034	69	7	And Moses came and called for the elders of the people, and laid before their faces all these words which the LORD commanded him.
2035	69	8	And all the people answered together, and said, All that the LORD hath spoken we will do. And Moses returned the words of the people unto the LORD.
2036	69	9	And the LORD said unto Moses, Lo, I come unto thee in a thick cloud, that the people may hear when I speak with thee, and believe thee for ever. And Moses told the words of the people unto the LORD.
2037	69	10	And the LORD said unto Moses, Go unto the people, and sanctify them to day and to morrow, and let them wash their clothes,
2038	69	11	And be ready against the third day: for the third day the LORD will come down in the sight of all the people upon mount Sinai.
2039	69	12	And thou shalt set bounds unto the people round about, saying, Take heed to yourselves, that ye go not up into the mount, or touch the border of it: whosoever toucheth the mount shall be surely put to death:
2040	69	13	There shall not an hand touch it, but he shall surely be stoned, or shot through; whether it be beast or man, it shall not live: when the trumpet soundeth long, they shall come up to the mount.
2041	69	14	And Moses went down from the mount unto the people, and sanctified the people; and they washed their clothes.
2042	69	15	And he said unto the people, Be ready against the third day: come not at your wives.
2043	69	16	And it came to pass on the third day in the morning, that there were thunders and lightnings, and a thick cloud upon the mount, and the voice of the trumpet exceeding loud; so that all the people that was in the camp trembled.
2044	69	17	And Moses brought forth the people out of the camp to meet with God; and they stood at the nether part of the mount.
2045	69	18	And mount Sinai was altogether on a smoke, because the LORD descended upon it in fire: and the smoke thereof ascended as the smoke of a furnace, and the whole mount quaked greatly.
2046	69	19	And when the voice of the trumpet sounded long, and waxed louder and louder, Moses spake, and God answered him by a voice.
2047	69	20	And the LORD came down upon mount Sinai, on the top of the mount: and the LORD called Moses up to the top of the mount; and Moses went up.
2048	69	21	And the LORD said unto Moses, Go down, charge the people, lest they break through unto the LORD to gaze, and many of them perish.
2049	69	22	And let the priests also, which come near to the LORD, sanctify themselves, lest the LORD break forth upon them.
2050	69	23	And Moses said unto the LORD, The people cannot come up to mount Sinai: for thou chargedst us, saying, Set bounds about the mount, and sanctify it.
2051	69	24	And the LORD said unto him, Away, get thee down, and thou shalt come up, thou, and Aaron with thee: but let not the priests and the people break through to come up unto the LORD, lest he break forth upon them.
2052	69	25	So Moses went down unto the people, and spake unto them.
2053	70	1	AND God spake all these words, saying,
2054	70	2	I am the LORD thy God, which have brought thee out of the land of Egypt, out of the house of bondage.
2055	70	3	Thou shalt have no other gods before me.
2056	70	4	Thou shalt not make unto thee any graven image, or any likeness of any thing that is in heaven above, or that is in the earth beneath, or that is in the water under the earth:
2057	70	5	Thou shalt not bow down thyself to them, nor serve them: for I the LORD thy God am a jealous God, visiting the iniquity of the fathers upon the children unto the third and fourth generation of them that hate me;
2058	70	6	And shewing mercy unto thousands of them that love me, and keep my commandments.
2059	70	7	Thou shalt not take the name of the LORD thy God in vain; for the LORD will not hold him guiltless that taketh his name in vain.
2060	70	8	Remember the sabbath day, to keep it holy.
2061	70	9	Six days shalt thou labour, and do all thy work:
2062	70	10	But the seventh day is the sabbath of the LORD thy God: in it thou shalt not do any work, thou, nor thy son, nor thy daughter, thy manservant, nor thy maidservant, nor thy cattle, nor thy stranger that is within thy gates:
2063	70	11	For in six days the LORD made heaven and earth, the sea, and all that in them is, and rested the seventh day: wherefore the LORD blessed the sabbath day, and hallowed it.
2064	70	12	Honour thy father and thy mother: that thy days may be long upon the land which the LORD thy God giveth thee.
2065	70	13	Thou shalt not kill.
2066	70	14	Thou shalt not commit adultery.
2067	70	15	Thou shalt not steal.
2068	70	16	Thou shalt not bear false witness against thy neighbour.
2069	70	17	Thou shalt not covet thy neighbour's house, thou shalt not covet thy neighbour's wife, nor his manservant, nor his maidservant, nor his ox, nor his ass, nor any thing that is thy neighbour's.
2070	70	18	And all the people saw the thunderings, and the lightnings, and the noise of the trumpet, and the mountain smoking: and when the people saw it, they removed, and stood afar off.
2071	70	19	And they said unto Moses, Speak thou with us, and we will hear: but let not God speak with us, lest we die.
2072	70	20	And Moses said unto the people, Fear not: for God is come to prove you, and that his fear may be before your faces, that ye sin not.
2073	70	21	And the people stood afar off, and Moses drew near unto the thick darkness where God was.
2074	70	22	And the LORD said unto Moses, Thus thou shalt say unto the children of Israel, Ye have seen that I have talked with you from heaven.
2075	70	23	Ye shall not make with me gods of silver, neither shall ye make unto you gods of gold.
2076	70	24	An altar of earth thou shalt make unto me, and shalt sacrifice thereon thy burnt offerings, and thy peace offerings, thy sheep, and thine oxen: in all places where I record my name I will come unto thee, and I will bless thee.
2077	70	25	And if thou wilt make me an altar of stone, thou shalt not build it of hewn stone: for if thou lift up thy tool upon it, thou hast polluted it.
2078	70	26	Neither shalt thou go up by steps unto mine altar, that thy nakedness be not discovered thereon.
2079	71	1	NOW these are the judgments which thou shalt set before them.
2080	71	2	If thou buy an Hebrew servant, six years he shall serve: and in the seventh he shall go out free for nothing.
2081	71	3	If he came in by himself, he shall go out by himself: if he were married, then his wife shall go out with him.
2082	71	4	If his master have given him a wife, and she have born him sons or daughters; the wife and her children shall be her master's, and he shall go out by himself.
2083	71	5	And if the servant shall plainly say, I love my master, my wife, and my children; I will not go out free:
2084	71	6	Then his master shall bring him unto the judges; he shall also bring him to the door, or unto the door post; and his master shall bore his ear through with an aul; and he shall serve him for ever.
2085	71	7	And if a man sell his daughter to be a maidservant, she shall not go out as the menservants do.
2086	71	8	If she please not her master, who hath betrothed her to himself, then shall he let her be redeemed: to sell her unto a strange nation he shall have no power, seeing he hath dealt deceitfully with her.
2087	71	9	And if he have betrothed her unto his son, he shall deal with her after the manner of daughters.
2088	71	10	If he take him another wife; her food, her raiment, and her duty of marriage, shall he not diminish.
2089	71	11	And if he do not these three unto her, then shall she go out free without money.
2090	71	12	He that smiteth a man, so that he die, shall be surely put to death.
2091	71	13	And if a man lie not in wait, but God deliver him into his hand; then I will appoint thee a place whither he shall flee.
2092	71	14	But if a man come presumptuously upon his neighbour, to slay him with guile; thou shalt take him from mine altar, that he may die.
2093	71	15	And he that smiteth his father, or his mother, shall be surely put to death.
2094	71	16	And he that stealeth a man, and selleth him, or if he be found in his hand, he shall surely be put to death.
2095	71	17	And he that curseth his father, or his mother, shall surely be put to death.
2096	71	18	And if men strive together, and one smite another with a stone, or with his fist, and he die not, but keepeth his bed:
2097	71	19	If he rise again, and walk abroad upon his staff, then shall he that smote him be quit: only he shall pay for the loss of his time, and shall cause him to be thoroughly healed.
2098	71	20	And if a man smite his servant, or his maid, with a rod, and he die under his hand; he shall be surely punished.
2099	71	21	Notwithstanding, if he continue a day or two, he shall not be punished: for he is his money.
2100	71	22	If men strive, and hurt a woman with child, so that her fruit depart from her, and yet no mischief follow: he shall be surely punished, according as the woman's husband will lay upon him; and he shall pay as the judges determine.
2101	71	23	And if any mischief follow, then thou shalt give life for life,
2102	71	24	Eye for eye, tooth for tooth, hand for hand, foot for foot,
2103	71	25	Burning for burning, wound for wound, stripe for stripe.
2104	71	26	And if a man smite the eye of his servant, or the eye of his maid, that it perish; he shall let him go free for his eye's sake.
2105	71	27	And if he smite out his manservant's tooth, or his maidservant's tooth; he shall let him go free for his tooth's sake.
2106	71	28	If an ox gore a man or a woman, that they die: then the ox shall be surely stoned, and his flesh shall not be eaten; but the owner of the ox shall be quit.
2107	71	29	But if the ox were wont to push with his horn in time past, and it hath been testified to his owner, and he hath not kept him in, but that he hath killed a man or a woman; the ox shall be stoned, and his owner also shall be put to death.
2108	71	30	If there be laid on him a sum of money, then he shall give for the ransom of his life whatsoever is laid upon him.
2109	71	31	Whether he have gored a son, or have gored a daughter, according to this judgment shall it be done unto him.
2110	71	32	If the ox shall push a manservant or a maidservant; he shall give unto their master thirty shekels of silver, and the ox shall be stoned.
2111	71	33	And if a man shall open a pit, or if a man shall dig a pit, and not cover it, and an ox or an ass fall therein;
2112	71	34	The owner of the pit shall make it good, and give money unto the owner of them; and the dead beast shall be his.
2113	71	35	And if one man's ox hurt another's, that he die; then they shall sell the live ox, and divide the money of it; and the dead ox also they shall divide.
2114	71	36	Or if it be known that the ox hath used to push in time past, and his owner hath not kept him in; he shall surely pay ox for ox; and the dead shall be his own.
2115	72	1	IF a man shall steal an ox, or a sheep, and kill it, or sell it; he shall restore five oxen for an ox, and four sheep for a sheep.
2116	72	2	If a thief be found breaking up, and be smitten that he die, there shall no blood be shed for him.
2117	72	3	If the sun be risen upon him, there shall be blood shed for him; for he should make full restitution; if he have nothing, then he shall be sold for his theft.
2118	72	4	If the theft be certainly found in his hand alive, whether it be ox, or ass, or sheep; he shall restore double.
2119	72	5	If a man shall cause a field or vineyard to be eaten, and shall put in his beast, and shall feed in another man's field; of the best of his own field, and of the best of his own vineyard, shall he make restitution.
2120	72	6	If fire break out, and catch in thorns, so that the stacks of corn, or the standing corn, or the field, be consumed therewith; he that kindled the fire shall surely make restitution.
2121	72	7	If a man shall deliver unto his neighbour money or stuff to keep, and it be stolen out of the man's house; if the thief be found, let him pay double.
2122	72	8	If the thief be not found, then the master of the house shall be brought unto the judges, to see whether he have put his hand unto his neighbour's goods.
2123	72	9	For all manner of trespass, whether it be for ox, for ass, for sheep, for raiment, or for any manner of lost thing, which another challengeth to be his, the cause of both parties shall come before the judges; and whom the judges shall condemn, he shall pay double unto his neighbour.
2124	72	10	If a man deliver unto his neighbour an ass, or an ox, or a sheep, or any beast, to keep; and it die, or be hurt, or driven away, no man seeing it:
2125	72	11	Then shall an oath of the LORD be between them both, that he hath not put his hand unto his neighbour's goods; and the owner of it shall accept thereof, and he shall not make it good.
2126	72	12	And if it be stolen from him, he shall make restitution unto the owner thereof.
2127	72	13	If it be torn in pieces, then let him bring it for witness, and he shall not make good that which was torn.
2128	72	14	And if a man borrow ought of his neighbour, and it be hurt, or die, the owner thereof being not with it, he shall surely make it good.
2129	72	15	But if the owner thereof be with it, he shall not make it good: if it be an hired thing, it came for his hire.
2130	72	16	And if a man entice a maid that is not betrothed, and lie with her, he shall surely endow her to be his wife.
2131	72	17	If her father utterly refuse to give her unto him, he shall pay money according to the dowry of virgins.
2132	72	18	Thou shalt not suffer a witch to live.
2133	72	19	Whosoever lieth with a beast shall surely be put to death.
2134	72	20	He that sacrificeth unto any god, save unto the LORD only, he shall be utterly destroyed.
2135	72	21	Thou shalt neither vex a stranger, nor oppress him: for ye were strangers in the land of Egypt.
2136	72	22	Ye shall not afflict any widow, or fatherless child.
2137	72	23	If thou afflict them in any wise, and they cry at all unto me, I will surely hear their cry;
2138	72	24	And my wrath shall wax hot, and I will kill you with the sword; and your wives shall be widows, and your children fatherless.
2139	72	25	If thou lend money to any of my people that is poor by thee, thou shalt not be to him as an usurer, neither shalt thou lay upon him usury.
2140	72	26	If thou at all take thy neighbour's raiment to pledge, thou shalt deliver it unto him by that the sun goeth down:
2141	72	27	For that is his covering only, it is his raiment for his skin: wherein shall he sleep? and it shall come to pass, when he crieth unto me, that I will hear; for I am gracious.
2142	72	28	Thou shalt not revile the gods, nor curse the ruler of thy people.
2143	72	29	Thou shalt not delay to offer the first of thy ripe fruits, and of thy liquors: the firstborn of thy sons shalt thou give unto me.
2144	72	30	Likewise shalt thou do with thine oxen, and with thy sheep: seven days it shall be with his dam; on the eighth day thou shalt give it me.
2145	72	31	And ye shall be holy men unto me: neither shall ye eat any flesh that is torn of beasts in the field; ye shall cast it to the dogs.
2146	73	1	THOU shalt not raise a false report: put not thine hand with the wicked to be an unrighteous witness.
2147	73	2	Thou shalt not follow a multitude to do evil; neither shalt thou speak in a cause to decline after many to wrest judgment:
2148	73	3	Neither shalt thou countenance a poor man in his cause.
2149	73	4	If thou meet thine enemy's ox or his ass going astray, thou shalt surely bring it back to him again.
2150	73	5	If thou see the ass of him that hateth thee lying under his burden, and wouldest forbear to help him, thou shalt surely help with him.
2151	73	6	Thou shalt not wrest the judgment of thy poor in his cause.
2152	73	7	Keep thee far from a false matter; and the innocent and righteous slay thou not: for I will not justify the wicked.
2153	73	8	And thou shalt take no gift: for the gift blindeth the wise, and perverteth the words of the righteous.
2154	73	9	Also thou shalt not oppress a stranger: for ye know the heart of a stranger, seeing ye were strangers in the land of Egypt.
2155	73	10	And six years thou shalt sow thy land, and shalt gather in the fruits thereof:
2156	73	11	But the seventh year thou shalt let it rest and lie still; that the poor of thy people may eat: and what they leave the beasts of the field shall eat. In like manner thou shalt deal with thy vineyard, and with thy oliveyard.
2157	73	12	Six days thou shalt do thy work, and on the seventh day thou shalt rest: that thine ox and thine ass may rest, and the son of thy handmaid, and the stranger, may be refreshed.
2158	73	13	And in all things that I have said unto you be circumspect: and make no mention of the name of other gods, neither let it be heard out of thy mouth.
2159	73	14	Three times thou shalt keep a feast unto me in the year.
2160	73	15	Thou shalt keep the feast of unleavened bread: (thou shalt eat unleavened bread seven days, as I commanded thee, in the time appointed of the month Abib; for in it thou camest out from Egypt: and none shall appear before me empty:)
2161	73	16	And the feast of harvest, the firstfruits of thy labours, which thou hast sown in the field: and the feast of ingathering, which is in the end of the year, when thou hast gathered in thy labours out of the field.
2162	73	17	Three times in the year all thy males shall appear before the Lord GOD.
2163	73	18	Thou shalt not offer the blood of my sacrifice with leavened bread; neither shall the fat of my sacrifice remain until the morning.
2164	73	19	The first of the firstfruits of thy land thou shalt bring into the house of the LORD thy God. Thou shalt not seethe a kid in his mother's milk.
2165	73	20	Behold, I send an Angel before thee, to keep thee in the way, and to bring thee into the place which I have prepared.
2166	73	21	Beware of him, and obey his voice, provoke him not; for he will not pardon your transgressions: for my name is in him.
2167	73	22	But if thou shalt indeed obey his voice, and do all that I speak; then I will be an enemy unto thine enemies, and an adversary unto thine adversaries.
2168	73	23	For mine Angel shall go before thee, and bring thee in unto the Amorites, and the Hittites, and the Perizzites, and the Canaanites, and the Hivites, and the Jebusites: and I will cut them off.
2169	73	24	Thou shalt not bow down to their gods, nor serve them, nor do after their works: but thou shalt utterly overthrow them, and quite break down their images.
2170	73	25	And ye shall serve the LORD your God, and he shall bless thy bread, and thy water; and I will take sickness away from the midst of thee.
2171	73	26	There shall nothing cast their young, nor be barren, in thy land: the number of thy days I will fulfil.
2172	73	27	I will send my fear before thee, and will destroy all the people to whom thou shalt come, and I will make all thine enemies turn their backs unto thee.
2173	73	28	And I will send hornets before thee, which shall drive out the Hivite, the Canaanite, and the Hittite, from before thee.
2174	73	29	I will not drive them out from before thee in one year; lest the land become desolate, and the beast of the field multiply against thee.
2175	73	30	By little and little I will drive them out from before thee, until thou be increased, and inherit the land.
2176	73	31	And I will set thy bounds from the Red sea even unto the sea of the Philistines, and from the desert unto the river: for I will deliver the inhabitants of the land into your hand; and thou shalt drive them out before thee.
2177	73	32	Thou shalt make no covenant with them, nor with their gods.
2178	73	33	They shall not dwell in thy land, lest they make thee sin against me: for if thou serve their gods, it will surely be a snare unto thee.
2179	74	1	AND he said unto Moses, Come up unto the LORD, thou, and Aaron, Nadab, and Abihu, and seventy of the elders of Israel; and worship ye afar off.
2180	74	2	And Moses alone shall come near the LORD: but they shall not come nigh; neither shall the people go up with him.
2181	74	3	And Moses came and told the people all the words of the LORD, and all the judgments: and all the people answered with one voice, and said, All the words which the LORD hath said will we do.
2182	74	4	And Moses wrote all the words of the LORD, and rose up early in the morning, and builded an altar under the hill, and twelve pillars, according to the twelve tribes of Israel.
2183	74	5	And he sent young men of the children of Israel, which offered burnt offerings, and sacrificed peace offerings of oxen unto the LORD.
2184	74	6	And Moses took half of the blood, and put it in basons; and half of the blood he sprinkled on the altar.
2185	74	7	And he took the book of the covenant, and read in the audience of the people: and they said, All that the LORD hath said will we do, and be obedient.
2186	74	8	And Moses took the blood, and sprinkled it on the people, and said, Behold the blood of the covenant, which the LORD hath made with you concerning all these words.
2187	74	9	Then went up Moses, and Aaron, Nadab, and Abihu, and seventy of the elders of Israel:
2188	74	10	And they saw the God of Israel: and there was under his feet as it were a paved work of a sapphire stone, and as it were the body of heaven in his clearness.
2189	74	11	And upon the nobles of the children of Israel he laid not his hand: also they saw God, and did eat and drink.
2190	74	12	And the LORD said unto Moses, Come up to me into the mount, and be there: and I will give thee tables of stone, and a law, and commandments which I have written; that thou mayest teach them.
2191	74	13	And Moses rose up, and his minister Joshua: and Moses went up into the mount of God.
2192	74	14	And he said unto the elders, Tarry ye here for us, until we come again unto you: and, behold, Aaron and Hur are with you: if any man have any matters to do, let him come unto them.
2193	74	15	And Moses went up into the mount, and a cloud covered the mount.
2194	74	16	And the glory of the LORD abode upon mount Sinai, and the cloud covered it six days: and the seventh day he called unto Moses out of the midst of the cloud.
2195	74	17	And the sight of the glory of the LORD was like devouring fire on the top of the mount in the eyes of the children of Israel.
2196	74	18	And Moses went into the midst of the cloud, and gat him up into the mount: and Moses was in the mount forty days and forty nights.
2197	75	1	AND the LORD spake unto Moses, saying,
2198	75	2	Speak unto the children of Israel, that they bring me an offering: of every man that giveth it willingly with his heart ye shall take my offering.
2199	75	3	And this is the offering which ye shall take of them; gold, and silver, and brass,
2200	75	4	And blue, and purple, and scarlet, and fine linen, and goats' hair,
2201	75	5	And rams' skins dyed red, and badgers' skins, and shittim wood,
2202	75	6	Oil for the light, spices for anointing oil, and for sweet incense,
2203	75	7	Onyx stones, and stones to be set in the ephod, and in the breastplate.
2204	75	8	And let them make me a sanctuary; that I may dwell among them.
2205	75	9	According to all that I shew thee, after the pattern of the tabernacle, and the pattern of all the instruments thereof, even so shall ye make it.
2206	75	10	And they shall make an ark of shittim wood: two cubits and a half shall be the length thereof, and a cubit and a half the breadth thereof, and a cubit and a half the height thereof.
2207	75	11	And thou shalt overlay it with pure gold, within and without shalt thou overlay it, and shalt make upon it a crown of gold round about.
2208	75	12	And thou shalt cast four rings of gold for it, and put them in the four corners thereof; and two rings shall be in the one side of it, and two rings in the other side of it.
2209	75	13	And thou shalt make staves of shittim wood, and overlay them with gold.
2210	75	14	And thou shalt put the staves into the rings by the sides of the ark, that the ark may be borne with them.
2211	75	15	The staves shall be in the rings of the ark: they shall not be taken from it.
2212	75	16	And thou shalt put into the ark the testimony which I shall give thee.
2213	75	17	And thou shalt make a mercy seat of pure gold: two cubits and a half shall be the length thereof, and a cubit and a half the breadth thereof.
2214	75	18	And thou shalt make two cherubims of gold, of beaten work shalt thou make them, in the two ends of the mercy seat.
2215	75	19	And make one cherub on the one end, and the other cherub on the other end: even of the mercy seat shall ye make the cherubims on the two ends thereof.
2216	75	20	And the cherubims shall stretch forth their wings on high, covering the mercy seat with their wings, and their faces shall look one to another; toward the mercy seat shall the faces of the cherubims be.
2217	75	21	And thou shalt put the mercy seat above upon the ark; and in the ark thou shalt put the testimony that I shall give thee.
2218	75	22	And there I will meet with thee, and I will commune with thee from above the mercy seat, from between the two cherubims which are upon the ark of the testimony, of all things which I will give thee in commandment unto the children of Israel.
2219	75	23	Thou shalt also make a table of shittim wood: two cubits shall be the length thereof, and a cubit the breadth thereof, and a cubit and a half the height thereof.
2220	75	24	And thou shalt overlay it with pure gold, and make thereto a crown of gold round about.
2221	75	25	And thou shalt make unto it a border of an hand breadth round about, and thou shalt make a golden crown to the border thereof round about.
2222	75	26	And thou shalt make for it four rings of gold, and put the rings in the four corners that are on the four feet thereof.
2223	75	27	Over against the border shall the rings be for places of the staves to bear the table.
2224	75	28	And thou shalt make the staves of shittim wood, and overlay them with gold, that the table may be borne with them.
2225	75	29	And thou shalt make the dishes thereof, and spoons thereof, and covers thereof, and bowls thereof, to cover withal: of pure gold shalt thou make them.
2226	75	30	And thou shalt set upon the table shewbread before me alway.
2227	75	31	And thou shalt make a candlestick of pure gold: of beaten work shall the candlestick be made: his shaft, and his branches, his bowls, his knops, and his flowers, shall be of the same.
2228	75	32	And six branches shall come out of the sides of it; three branches of the candlestick out of the one side, and three branches of the candlestick out of the other side:
2229	75	33	Three bowls made like unto almonds, with a knop and a flower in one branch; and three bowls made like almonds in the other branch, with a knop and a flower: so in the six branches that come out of the candlestick.
2230	75	34	And in the candlestick shall be four bowls made like unto almonds, with their knops and their flowers.
2231	75	35	And there shall be a knop under two branches of the same, and a knop under two branches of the same, and a knop under two branches of the same, according to the six branches that proceed out of the candlestick.
2232	75	36	Their knops and their branches shall be of the same: all it shall be one beaten work of pure gold.
2233	75	37	And thou shalt make the seven lamps thereof: and they shall light the lamps thereof, that they may give light over against it.
2234	75	38	And the tongs thereof, and the snuffdishes thereof, shall be of pure gold.
2235	75	39	Of a talent of pure gold shall he make it, with all these vessels.
2236	75	40	And look that thou make them after their pattern, which was shewed thee in the mount.
2237	76	1	MOREOVER thou shalt make the tabernacle with ten curtains of fine twined linen, and blue, and purple, and scarlet: with cherubims of cunning work shalt thou make them.
2238	76	2	The length of one curtain shall be eight and twenty cubits, and the breadth of one curtain four cubits: and every one of the curtains shall have one measure.
2239	76	3	The five curtains shall be coupled together one to another; and other five curtains shall be coupled one to another.
2240	76	4	And thou shalt make loops of blue upon the edge of the one curtain from the selvedge in the coupling; and likewise shalt thou make in the uttermost edge of another curtain, in the coupling of the second.
2241	76	5	Fifty loops shalt thou make in the one curtain, and fifty loops shalt thou make in the edge of the curtain that is in the coupling of the second; that the loops may take hold one of another.
2242	76	6	And thou shalt make fifty taches of gold, and couple the curtains together with the taches: and it shall be one tabernacle.
2243	76	7	And thou shalt make curtains of goats' hair to be a covering upon the tabernacle: eleven curtains shalt thou make.
2244	76	8	The length of one curtain shall be thirty cubits, and the breadth of one curtain four cubits: and the eleven curtains shall be all of one measure.
2245	76	9	And thou shalt couple five curtains by themselves, and six curtains by themselves, and shalt double the sixth curtain in the forefront of the tabernacle.
2246	76	10	And thou shalt make fifty loops on the edge of the one curtain that is outmost in the coupling, and fifty loops in the edge of the curtain which coupleth the second.
2247	76	11	And thou shalt make fifty taches of brass, and put the taches into the loops, and couple the tent together, that it may be one.
2248	76	12	And the remnant that remaineth of the curtains of the tent, the half curtain that remaineth, shall hang over the backside of the tabernacle.
2249	76	13	And a cubit on the one side, and a cubit on the other side of that which remaineth in the length of the curtains of the tent, it shall hang over the sides of the tabernacle on this side and on that side, to cover it.
2250	76	14	And thou shalt make a covering for the tent of rams' skins dyed red, and a covering above of badgers' skins.
2251	76	15	And thou shalt make boards for the tabernacle of shittim wood standing up.
2252	76	16	Ten cubits shall be the length of a board, and a cubit and a half shall be the breadth of one board.
2253	76	17	Two tenons shall there be in one board, set in order one against another: thus shalt thou make for all the boards of the tabernacle.
2254	76	18	And thou shalt make the boards for the tabernacle, twenty boards on the south side southward.
2255	76	19	And thou shalt make forty sockets of silver under the twenty boards; two sockets under one board for his two tenons, and two sockets under another board for his two tenons.
2256	76	20	And for the second side of the tabernacle on the north side there shall be twenty boards:
2257	76	21	And their forty sockets of silver; two sockets under one board, and two sockets under another board.
2258	76	22	And for the sides of the tabernacle westward thou shalt make six boards.
2259	76	23	And two boards shalt thou make for the corners of the tabernacle in the two sides.
2260	76	24	And they shall be coupled together beneath, and they shall be coupled together above the head of it unto one ring: thus shall it be for them both; they shall be for the two corners.
2261	76	25	And they shall be eight boards, and their sockets of silver, sixteen sockets; two sockets under one board, and two sockets under another board.
2262	76	26	And thou shalt make bars of shittim wood; five for the boards of the one side of the tabernacle,
2263	76	27	And five bars for the boards of the other side of the tabernacle, and five bars for the boards of the side of the tabernacle, for the two sides westward.
2264	76	28	And the middle bar in the midst of the boards shall reach from end to end.
2265	76	29	And thou shalt overlay the boards with gold, and make their rings of gold for places for the bars: and thou shalt overlay the bars with gold.
2266	76	30	And thou shalt rear up the tabernacle according to the fashion thereof which was shewed thee in the mount.
2267	76	31	And thou shalt make a vail of blue, and purple, and scarlet, and fine twined linen of cunning work: with cherubims shall it be made:
2268	76	32	And thou shalt hang it upon four pillars of shittim wood overlaid with gold: their hooks shall be of gold, upon the four sockets of silver.
2269	76	33	And thou shalt hang up the vail under the taches, that thou mayest bring in thither within the vail the ark of the testimony: and the vail shall divide unto you between the holy place and the most holy.
2270	76	34	And thou shalt put the mercy seat upon the ark of the testimony in the most holy place.
2271	76	35	And thou shalt set the table without the vail, and the candlestick over against the table on the side of the tabernacle toward the south: and thou shalt put the table on the north side.
2272	76	36	And thou shalt make an hanging for the door of the tent, of blue, and purple, and scarlet, and fine twined linen, wrought with needlework.
2273	76	37	And thou shalt make for the hanging five pillars of shittim wood, and overlay them with gold, and their hooks shall be of gold: and thou shalt cast five sockets of brass for them.
2274	77	1	AND thou shalt make an altar of shittim wood, five cubits long, and five cubits broad; the altar shall be foursquare: and the height thereof shall be three cubits.
2275	77	2	And thou shalt make the horns of it upon the four corners thereof: his horns shall be of the same: and thou shalt overlay it with brass.
2276	77	3	And thou shalt make his pans to receive his ashes, and his shovels, and his basons, and his fleshhooks, and his firepans: all the vessels thereof thou shalt make of brass.
2277	77	4	And thou shalt make for it a grate of network of brass; and upon the net shalt thou make four brasen rings in the four corners thereof.
2278	77	5	And thou shalt put it under the compass of the altar beneath, that the net may be even to the midst of the altar.
2279	77	6	And thou shalt make staves for the altar, staves of shittim wood, and overlay them with brass.
2280	77	7	And the staves shall be put into the rings, and the staves shall be upon the two sides of the altar, to bear it.
2281	77	8	Hollow with boards shalt thou make it: as it was shewed thee in the mount, so shall they make it.
2282	77	9	And thou shalt make the court of the tabernacle: for the south side southward there shall be hangings for the court of fine twined linen of an hundred cubits long for one side:
2283	77	10	And the twenty pillars thereof and their twenty sockets shall be of brass; the hooks of the pillars and their fillets shall be of silver.
2284	77	11	And likewise for the north side in length there shall be hangings of an hundred cubits long, and his twenty pillars and their twenty sockets of brass; the hooks of the pillars and their fillets of silver.
2285	77	12	And for the breadth of the court on the west side shall be hangings of fifty cubits: their pillars ten, and their sockets ten.
2286	77	13	And the breadth of the court on the east side eastward shall be fifty cubits.
2287	77	14	The hangings of one side of the gate shall be fifteen cubits: their pillars three, and their sockets three.
2288	77	15	And on the other side shall be hangings fifteen cubits: their pillars three, and their sockets three.
2289	77	16	And for the gate of the court shall be an hanging of twenty cubits, of blue, and purple, and scarlet, and fine twined linen, wrought with needlework: and their pillars shall be four, and their sockets four.
2290	77	17	All the pillars round about the court shall be filleted with silver; their hooks shall be of silver, and their sockets of brass.
2291	77	18	The length of the court shall be an hundred cubits, and the breadth fifty every where, and the height five cubits of fine twined linen, and their sockets of brass.
2292	77	19	All the vessels of the tabernacle in all the service thereof, and all the pins thereof, and all the pins of the court, shall be of brass.
2293	77	20	And thou shalt command the children of Israel, that they bring thee pure oil olive beaten for the light, to cause the lamp to burn always.
2294	77	21	In the tabernacle of the congregation without the vail, which is before the testimony, Aaron and his sons shall order it from evening to morning before the LORD: it shall be a statute for ever unto their generations on the behalf of the children of Israel.
2295	78	1	AND take thou unto thee Aaron thy brother, and his sons with him, from among the children of Israel, that he may minister unto me in the priest's office, even Aaron, Nadab and Abihu, Eleazar and Ithamar, Aaron's sons.
2296	78	2	And thou shalt make holy garments for Aaron thy brother for glory and for beauty.
2297	78	3	And thou shalt speak unto all that are wise hearted, whom I have filled with the spirit of wisdom, that they may make Aaron's garments to consecrate him, that he may minister unto me in the priest's office.
2298	78	4	And these are the garments which they shall make; a breastplate, and an ephod, and a robe, and a broidered coat, a mitre, and a girdle: and they shall make holy garments for Aaron thy brother, and his sons, that he may minister unto me in the priest's office.
2299	78	5	And they shall take gold, and blue, and purple, and scarlet, and fine linen.
2300	78	6	And they shall make the ephod of gold, of blue, and of purple, of scarlet, and fine twined linen, with cunning work.
2301	78	7	It shall have the two shoulderpieces thereof joined at the two edges thereof; and so it shall be joined together.
2302	78	8	And the curious girdle of the ephod, which is upon it, shall be of the same, according to the work thereof; even of gold, of blue, and purple, and scarlet, and fine twined linen.
2303	78	9	And thou shalt take two onyx stones, and grave on them the names of the children of Israel:
2304	78	10	Six of their names on one stone, and the other six names of the rest on the other stone, according to their birth.
2305	78	11	With the work of an engraver in stone, like the engravings of a signet, shalt thou engrave the two stones with the names of the children of Israel: thou shalt make them to be set in ouches of gold.
2306	78	12	And thou shalt put the two stones upon the shoulders of the ephod for stones of memorial unto the children of Israel: and Aaron shall bear their names before the LORD upon his two shoulders for a memorial.
2307	78	13	And thou shalt make ouches of gold;
2308	78	14	And two chains of pure gold at the ends; of wreathen work shalt thou make them, and fasten the wreathen chains to the ouches.
2309	78	15	And thou shalt make the breastplate of judgment with cunning work; after the work of the ephod thou shalt make it; of gold, of blue, and of purple, and of scarlet, and of fine twined linen, shalt thou make it.
2310	78	16	Foursquare it shall be being doubled; a span shall be the length thereof, and a span shall be the breadth thereof.
2311	78	17	And thou shalt set in it settings of stones, even four rows of stones: the first row shall be a sardius, a topaz, and a carbuncle: this shall be the first row.
2312	78	18	And the second row shall be an emerald, a sapphire, and a diamond.
2313	78	19	And the third row a ligure, an agate, and an amethyst.
2314	78	20	And the fourth row a beryl, and an onyx, and a jasper: they shall be set in gold in their inclosings.
2315	78	21	And the stones shall be with the names of the children of Israel, twelve, according to their names, like the engravings of a signet; every one with his name shall they be according to the twelve tribes.
2316	78	22	And thou shalt make upon the breastplate chains at the ends of wreathen work of pure gold.
2317	78	23	And thou shalt make upon the breastplate two rings of gold, and shalt put the two rings on the two ends of the breastplate.
2318	78	24	And thou shalt put the two wreathen chains of gold in the two rings which are on the ends of the breastplate.
2319	78	25	And the other two ends of the two wreathen chains thou shalt fasten in the two ouches, and put them on the shoulderpieces of the ephod before it.
2320	78	26	And thou shalt make two rings of gold, and thou shalt put them upon the two ends of the breastplate in the border thereof, which is in the side of the ephod inward.
2321	78	27	And two other rings of gold thou shalt make, and shalt put them on the two sides of the ephod underneath, toward the forepart thereof, over against the other coupling thereof, above the curious girdle of the ephod.
2322	78	28	And they shall bind the breastplate by the rings thereof unto the rings of the ephod with a lace of blue, that it may be above the curious girdle of the ephod, and that the breastplate be not loosed from the ephod.
2323	78	29	And Aaron shall bear the names of the children of Israel in the breastplate of judgment upon his heart, when he goeth in unto the holy place, for a memorial before the LORD continually.
2324	78	30	And thou shalt put in the breastplate of judgment the Urim and the Thummim; and they shall be upon Aaron's heart, when he goeth in before the LORD: and Aaron shall bear the judgment of the children of Israel upon his heart before the LORD continually.
2325	78	31	And thou shalt make the robe of the ephod all of blue.
2326	78	32	And there shall be an hole in the top of it, in the midst thereof: it shall have a binding of woven work round about the hole of it, as it were the hole of an habergeon, that it be not rent.
2327	78	33	And beneath upon the hem of it thou shalt make pomegranates of blue, and of purple, and of scarlet, round about the hem thereof; and bells of gold between them round about:
2328	78	34	A golden bell and a pomegranate, a golden bell and a pomegranate, upon the hem of the robe round about.
2329	78	35	And it shall be upon Aaron to minister: and his sound shall be heard when he goeth in unto the holy place before the LORD, and when he cometh out, that he die not.
2330	78	36	And thou shalt make a plate of pure gold, and grave upon it, like the engravings of a signet, HOLINESS TO THE LORD.
2331	78	37	And thou shalt put it on a blue lace, that it may be upon the mitre; upon the forefront of the mitre it shall be.
2332	78	38	And it shall be upon Aaron's forehead, that Aaron may bear the iniquity of the holy things, which the children of Israel shall hallow in all their holy gifts; and it shall be always upon his forehead, that they may be accepted before the LORD.
2333	78	39	And thou shalt embroider the coat of fine linen, and thou shalt make the mitre of fine linen, and thou shalt make the girdle of needlework.
2334	78	40	And for Aaron's sons thou shalt make coats, and thou shalt make for them girdles, and bonnets shalt thou make for them, for glory and for beauty.
2335	78	41	And thou shalt put them upon Aaron thy brother, and his sons with him; and shalt anoint them, and consecrate them, and sanctify them, that they may minister unto me in the priest's office.
2336	78	42	And thou shalt make them linen breeches to cover their nakedness; from the loins even unto the thighs they shall reach:
2337	78	43	And they shall be upon Aaron, and upon his sons, when they come in unto the tabernacle of the congregation, or when they come near unto the altar to minister in the holy place; that they bear not iniquity, and die: it shall be a statute for ever unto him and his seed after him.
2338	79	1	AND this is the thing that thou shalt do unto them to hallow them, to minister unto me in the priest's office: Take one young bullock, and two rams without blemish,
2339	79	2	And unleavened bread, and cakes unleavened tempered with oil, and wafers unleavened anointed with oil: of wheaten flour shalt thou make them.
2340	79	3	And thou shalt put them into one basket, and bring them in the basket, with the bullock and the two rams.
2341	79	4	And Aaron and his sons thou shalt bring unto the door of the tabernacle of the congregation, and shalt wash them with water.
2342	79	5	And thou shalt take the garments, and put upon Aaron the coat, and the robe of the ephod, and the ephod, and the breastplate, and gird him with the curious girdle of the ephod:
2343	79	6	And thou shalt put the mitre upon his head, and put the holy crown upon the mitre.
2344	79	7	Then shalt thou take the anointing oil, and pour it upon his head, and anoint him.
2345	79	8	And thou shalt bring his sons, and put coats upon them.
2346	79	9	And thou shalt gird them with girdles, Aaron and his sons, and put the bonnets on them: and the priest's office shall be theirs for a perpetual statute: and thou shalt consecrate Aaron and his sons.
2347	79	10	And thou shalt cause a bullock to be brought before the tabernacle of the congregation: and Aaron and his sons shall put their hands upon the head of the bullock.
2348	79	11	And thou shalt kill the bullock before the LORD, by the door of the tabernacle of the congregation.
2349	79	12	And thou shalt take of the blood of the bullock, and put it upon the horns of the altar with thy finger, and pour all the blood beside the bottom of the altar.
2350	79	13	And thou shalt take all the fat that covereth the inwards, and the caul that is above the liver, and the two kidneys, and the fat that is upon them, and burn them upon the altar.
2351	79	14	But the flesh of the bullock, and his skin, and his dung, shalt thou burn with fire without the camp: it is a sin offering.
2352	79	15	Thou shalt also take one ram; and Aaron and his sons shall put their hands upon the head of the ram.
2353	79	16	And thou shalt slay the ram, and thou shalt take his blood, and sprinkle it round about upon the altar.
2354	79	17	And thou shalt cut the ram in pieces, and wash the inwards of him, and his legs, and put them unto his pieces, and unto his head.
2355	79	18	And thou shalt burn the whole ram upon the altar: it is a burnt offering unto the LORD: it is a sweet savour, an offering made by fire unto the LORD.
2356	79	19	And thou shalt take the other ram; and Aaron and his sons shall put their hands upon the head of the ram.
2357	79	20	Then shalt thou kill the ram, and take of his blood, and put it upon the tip of the right ear of Aaron, and upon the tip of the right ear of his sons, and upon the thumb of their right hand, and upon the great toe of their right foot, and sprinkle the blood upon the altar round about.
2358	79	21	And thou shalt take of the blood that is upon the altar, and of the anointing oil, and sprinkle it upon Aaron, and upon his garments, and upon his sons, and upon the garments of his sons with him: and he shall be hallowed, and his garments, and his sons, and his sons' garments with him.
2359	79	22	Also thou shalt take of the ram the fat and the rump, and the fat that covereth the inwards, and the caul above the liver, and the two kidneys, and the fat that is upon them, and the right shoulder; for it is a ram of consecration:
2360	79	23	And one loaf of bread, and one cake of oiled bread, and one wafer out of the basket of the unleavened bread that is before the LORD:
2361	79	24	And thou shalt put all in the hands of Aaron, and in the hands of his sons; and shalt wave them for a wave offering before the LORD.
2362	79	25	And thou shalt receive them of their hands, and burn them upon the altar for a burnt offering, for a sweet savour before the LORD: it is an offering made by fire unto the LORD.
2363	79	26	And thou shalt take the breast of the ram of Aaron's consecration, and wave it for a wave offering before the LORD: and it shall be thy part.
2364	79	27	And thou shalt sanctify the breast of the wave offering, and the shoulder of the heave offering, which is waved, and which is heaved up, of the ram of the consecration, even of that which is for Aaron, and of that which is for his sons:
2365	79	28	And it shall be Aaron's and his sons' by a statute for ever from the children of Israel: for it is an heave offering: and it shall be an heave offering from the children of Israel of the sacrifice of their peace offerings, even their heave offering unto the LORD.
2366	79	29	And the holy garments of Aaron shall be his sons' after him, to be anointed therein, and to be consecrated in them.
2367	79	30	And that son that is priest in his stead shall put them on seven days, when he cometh into the tabernacle of the congregation to minister in the holy place.
2368	79	31	And thou shalt take the ram of the consecration, and seethe his flesh in the holy place.
2369	79	32	And Aaron and his sons shall eat the flesh of the ram, and the bread that is in the basket, by the door of the tabernacle of the congregation.
2370	79	33	And they shall eat those things wherewith the atonement was made, to consecrate and to sanctify them: but a stranger shall not eat thereof, because they are holy.
2371	79	34	And if ought of the flesh of the consecrations, or of the bread, remain unto the morning, then thou shalt burn the remainder with fire: it shall not be eaten, because it is holy.
2372	79	35	And thus shalt thou do unto Aaron, and to his sons, according to all things which I have commanded thee: seven days shalt thou consecrate them.
2373	79	36	And thou shalt offer every day a bullock for a sin offering for atonement: and thou shalt cleanse the altar, when thou hast made an atonement for it, and thou shalt anoint it, to sanctify it.
2374	79	37	Seven days thou shalt make an atonement for the altar, and sanctify it; and it shall be an altar most holy: whatsoever toucheth the altar shall be holy.
2375	79	38	Now this is that which thou shalt offer upon the altar; two lambs of the first year day by day continually.
2376	79	39	The one lamb thou shalt offer in the morning; and the other lamb thou shalt offer at even:
2377	79	40	And with the one lamb a tenth deal of flour mingled with the fourth part of an hin of beaten oil; and the fourth part of an hin of wine for a drink offering.
2378	79	41	And the other lamb thou shalt offer at even, and shalt do thereto according to the meat offering of the morning, and according to the drink offering thereof, for a sweet savour, an offering made by fire unto the LORD.
2379	79	42	This shall be a continual burnt offering throughout your generations at the door of the tabernacle of the congregation before the LORD: where I will meet you, to speak there unto thee.
2380	79	43	And there I will meet with the children of Israel, and the tabernacle shall be sanctified by my glory.
2381	79	44	And I will sanctify the tabernacle of the congregation, and the altar: I will sanctify also both Aaron and his sons, to minister to me in the priest's office.
2382	79	45	And I will dwell among the children of Israel, and will be their God.
2383	79	46	And they shall know that I am the LORD their God, that brought them forth out of the land of Egypt, that I may dwell among them: I am the LORD their God.
2384	80	1	AND thou shalt make an altar to burn incense upon: of shittim wood shalt thou make it.
2385	80	2	A cubit shall be the length thereof, and a cubit the breadth thereof; foursquare shall it be: and two cubits shall be the height thereof: the horns thereof shall be of the same.
2386	80	3	And thou shalt overlay it with pure gold, the top thereof, and the sides thereof round about, and the horns thereof; and thou shalt make unto it a crown of gold round about.
2387	80	4	And two golden rings shalt thou make to it under the crown of it, by the two corners thereof, upon the two sides of it shalt thou make it; and they shall be for places for the staves to bear it withal.
2388	80	5	And thou shalt make the staves of shittim wood, and overlay them with gold.
2389	80	6	And thou shalt put it before the vail that is by the ark of the testimony, before the mercy seat that is over the testimony, where I will meet with thee.
2390	80	7	And Aaron shall burn thereon sweet incense every morning: when he dresseth the lamps, he shall burn incense upon it.
2391	80	8	And when Aaron lighteth the lamps at even, he shall burn incense upon it, a perpetual incense before the LORD throughout your generations.
2392	80	9	Ye shall offer no strange incense thereon, nor burnt sacrifice, nor meat offering; neither shall ye pour drink offering thereon.
2393	80	10	And Aaron shall make an atonement upon the horns of it once in a year with the blood of the sin offering of atonements: once in the year shall he make atonement upon it throughout your generations: it is most holy unto the LORD.
2394	80	11	And the LORD spake unto Moses, saying,
2395	80	12	When thou takest the sum of the children of Israel after their number, then shall they give every man a ransom for his soul unto the LORD, when thou numberest them; that there be no plague among them, when thou numberest them.
2396	80	13	This they shall give, every one that passeth among them that are numbered, half a shekel after the shekel of the sanctuary: (a shekel is twenty gerahs:) an half shekel shall be the offering of the LORD.
2397	80	14	Every one that passeth among them that are numbered, from twenty years old and above, shall give an offering unto the LORD.
2398	80	15	The rich shall not give more, and the poor shall not give less than half a shekel, when they give an offering unto the LORD, to make an atonement for your souls.
2399	80	16	And thou shalt take the atonement money of the children of Israel, and shalt appoint it for the service of the tabernacle of the congregation; that it may be a memorial unto the children of Israel before the LORD, to make an atonement for your souls.
2400	80	17	And the LORD spake unto Moses, saying,
2401	80	18	Thou shalt also make a laver of brass, and his foot also of brass, to wash withal: and thou shalt put it between the tabernacle of the congregation and the altar, and thou shalt put water therein.
2402	80	19	For Aaron and his sons shall wash their hands and their feet thereat:
2403	80	20	When they go into the tabernacle of the congregation, they shall wash with water, that they die not; or when they come near to the altar to minister, to burn offering made by fire unto the LORD:
2404	80	21	So they shall wash their hands and their feet, that they die not: and it shall be a statute for ever to them, even to him and to his seed throughout their generations.
2405	80	22	Moreover the LORD spake unto Moses, saying,
2406	80	23	Take thou also unto thee principal spices, of pure myrrh five hundred shekels, and of sweet cinnamon half so much, even two hundred and fifty shekels, and of sweet calamus two hundred and fifty shekels,
2407	80	24	And of cassia five hundred shekels, after the shekel of the sanctuary, and of oil olive an hin:
2408	80	25	And thou shalt make it an oil of holy ointment, an ointment compound after the art of the apothecary: it shall be an holy anointing oil.
2409	80	26	And thou shalt anoint the tabernacle of the congregation therewith, and the ark of the testimony,
2410	80	27	And the table and all his vessels, and the candlestick and his vessels, and the altar of incense,
2411	80	28	And the altar of burnt offering with all his vessels, and the laver and his foot.
2412	80	29	And thou shalt sanctify them, that they may be most holy: whatsoever toucheth them shall be holy.
2413	80	30	And thou shalt anoint Aaron and his sons, and consecrate them, that they may minister unto me in the priest's office.
2414	80	31	And thou shalt speak unto the children of Israel, saying, This shall be an holy anointing oil unto me throughout your generations.
2415	80	32	Upon man's flesh shall it not be poured, neither shall ye make any other like it, after the composition of it: it is holy, and it shall be holy unto you.
2416	80	33	Whosoever compoundeth any like it, or whosoever putteth any of it upon a stranger, shall even be cut off from his people.
2417	80	34	And the LORD said unto Moses, Take unto thee sweet spices, stacte, and onycha, and galbanum; these sweet spices with pure frankincense: of each shall there be a like weight:
2418	80	35	And thou shalt make it a perfume, a confection after the art of the apothecary, tempered together, pure and holy:
2419	80	36	And thou shalt beat some of it very small, and put of it before the testimony in the tabernacle of the congregation, where I will meet with thee: it shall be unto you most holy.
2420	80	37	And as for the perfume which thou shalt make, ye shall not make to yourselves according to the composition thereof: it shall be unto thee holy for the LORD.
2421	80	38	Whosoever shall make like unto that, to smell thereto, shall even be cut off from his people.
2422	81	1	AND the LORD spake unto Moses, saying,
2423	81	2	See, I have called by name Bezaleel the son of Uri, the son of Hur, of the tribe of Judah:
2424	81	3	And I have filled him with the spirit of God, in wisdom, and in understanding, and in knowledge, and in all manner of workmanship,
2425	81	4	To devise cunning works, to work in gold, and in silver, and in brass,
2426	81	5	And in cutting of stones, to set them, and in carving of timber, to work in all manner of workmanship.
2427	81	6	And I, behold, I have given with him Aholiab, the son of Ahisamach, of the tribe of Dan: and in the hearts of all that are wise hearted I have put wisdom, that they may make all that I have commanded thee;
2428	81	7	The tabernacle of the congregation, and the ark of the testimony, and the mercy seat that is thereupon, and all the furniture of the tabernacle,
2429	81	8	And the table and his furniture, and the pure candlestick with all his furniture, and the altar of incense,
2430	81	9	And the altar of burnt offering with all his furniture, and the laver and his foot,
2431	81	10	And the cloths of service, and the holy garments for Aaron the priest, and the garments of his sons, to minister in the priest's office,
2432	81	11	And the anointing oil, and sweet incense for the holy place: according to all that I have commanded thee shall they do.
2433	81	12	And the LORD spake unto Moses, saying,
2434	81	13	Speak thou also unto the children of Israel, saying, Verily my sabbaths ye shall keep: for it is a sign between me and you throughout your generations; that ye may know that I am the LORD that doth sanctify you.
2435	81	14	Ye shall keep the sabbath therefore; for it is holy unto you: every one that defileth it shall surely be put to death: for whosoever doeth any work therein, that soul shall be cut off from among his people.
2436	81	15	Six days may work be done; but in the seventh is the sabbath of rest, holy to the LORD: whosoever doeth any work in the sabbath day, he shall surely be put to death.
2437	81	16	Wherefore the children of Israel shall keep the sabbath, to observe the sabbath throughout their generations, for a perpetual covenant.
2438	81	17	It is a sign between me and the children of Israel for ever: for in six days the LORD made heaven and earth, and on the seventh day he rested, and was refreshed.
2439	81	18	And he gave unto Moses, when he had made an end of communing with him upon mount Sinai, two tables of testimony, tables of stone, written with the finger of God.
2440	82	1	AND when the people saw that Moses delayed to come down out of the mount, the people gathered themselves together unto Aaron, and said unto him, Up, make us gods, which shall go before us; for as for this Moses, the man that brought us up out of the land of Egypt, we wot not what is become of him.
2441	82	2	And Aaron said unto them, Break off the golden earrings, which are in the ears of your wives, of your sons, and of your daughters, and bring them unto me.
2442	82	3	And all the people brake off the golden earrings which were in their ears, and brought them unto Aaron.
2443	82	4	And he received them at their hand, and fashioned it with a graving tool, after he had made it a molten calf: and they said, These be thy gods, O Israel, which brought thee up out of the land of Egypt.
2444	82	5	And when Aaron saw it, he built an altar before it; and Aaron made proclamation, and said, To morrow is a feast to the LORD.
2445	82	6	And they rose up early on the morrow, and offered burnt offerings, and brought peace offerings; and the people sat down to eat and to drink, and rose up to play.
2446	82	7	And the LORD said unto Moses, Go, get thee down; for thy people, which thou broughtest out of the land of Egypt, have corrupted themselves:
2447	82	8	They have turned aside quickly out of the way which I commanded them: they have made them a molten calf, and have worshipped it, and have sacrificed thereunto, and said, These be thy gods, O Israel, which have brought thee up out of the land of Egypt.
2448	82	9	And the LORD said unto Moses, I have seen this people, and, behold, it is a stiffnecked people:
2449	82	10	Now therefore let me alone, that my wrath may wax hot against them, and that I may consume them: and I will make of thee a great nation.
2450	82	11	And Moses besought the LORD his God, and said, LORD, why doth thy wrath wax hot against thy people, which thou hast brought forth out of the land of Egypt with great power, and with a mighty hand?
2451	82	12	Wherefore should the Egyptians speak, and say, For mischief did he bring them out, to slay them in the mountains, and to consume them from the face of the earth? Turn from thy fierce wrath, and repent of this evil against thy people.
2452	82	13	Remember Abraham, Isaac, and Israel, thy servants, to whom thou swarest by thine own self, and saidst unto them, I will multiply your seed as the stars of heaven, and all this land that I have spoken of will I give unto your seed, and they shall inherit it for ever.
2453	82	14	And the LORD repented of the evil which he thought to do unto his people.
2454	82	15	And Moses turned, and went down from the mount, and the two tables of the testimony were in his hand: the tables were written on both their sides; on the one side and on the other were they written.
2455	82	16	And the tables were the work of God, and the writing was the writing of God, graven upon the tables.
2456	82	17	And when Joshua heard the noise of the people as they shouted, he said unto Moses, There is a noise of war in the camp.
2457	82	18	And he said, It is not the voice of them that shout for mastery, neither is it the voice of them that cry for being overcome: but the noise of them that sing do I hear.
2458	82	19	And it came to pass, as soon as he came nigh unto the camp, that he saw the calf, and the dancing: and Moses' anger waxed hot, and he cast the tables out of his hands, and brake them beneath the mount.
2459	82	20	And he took the calf which they had made, and burnt it in the fire, and ground it to powder, and strawed it upon the water, and made the children of Israel drink of it.
2460	82	21	And Moses said unto Aaron, What did this people unto thee, that thou hast brought so great a sin upon them?
2461	82	22	And Aaron said, Let not the anger of my lord wax hot: thou knowest the people, that they are set on mischief.
2462	82	23	For they said unto me, Make us gods, which shall go before us: for as for this Moses, the man that brought us up out of the land of Egypt, we wot not what is become of him.
2463	82	24	And I said unto them, Whosoever hath any gold, let them break it off. So they gave it me: then I cast it into the fire, and there came out this calf.
2464	82	25	And when Moses saw that the people were naked; (for Aaron had made them naked unto their shame among their enemies:)
2465	82	26	Then Moses stood in the gate of the camp, and said, Who is on the LORD's side? let him come unto me. And all the sons of Levi gathered themselves together unto him.
2466	82	27	And he said unto them, Thus saith the LORD God of Israel, Put every man his sword by his side, and go in and out from gate to gate throughout the camp, and slay every man his brother, and every man his companion, and every man his neighbour.
2467	82	28	And the children of Levi did according to the word of Moses: and there fell of the people that day about three thousand men.
2468	82	29	For Moses had said, Consecrate yourselves to day to the LORD, even every man upon his son, and upon his brother; that he may bestow upon you a blessing this day.
2469	82	30	And it came to pass on the morrow, that Moses said unto the people, Ye have sinned a great sin: and now I will go up unto the LORD; peradventure I shall make an atonement for your sin.
2470	82	31	And Moses returned unto the LORD, and said, Oh, this people have sinned a great sin, and have made them gods of gold.
2471	82	32	Yet now, if thou wilt forgive their sin--; and if not, blot me, I pray thee, out of thy book which thou hast written.
2472	82	33	And the LORD said unto Moses, Whosoever hath sinned against me, him will I blot out of my book.
2473	82	34	Therefore now go, lead the people unto the place of which I have spoken unto thee: behold, mine Angel shall go before thee: nevertheless in the day when I visit I will visit their sin upon them.
2474	82	35	And the LORD plagued the people, because they made the calf, which Aaron made.
2475	83	1	AND the LORD said unto Moses, Depart, and go up hence, thou and the people which thou hast brought up out of the land of Egypt, unto the land which I sware unto Abraham, to Isaac, and to Jacob, saying, Unto thy seed will I give it:
2476	83	2	And I will send an angel before thee; and I will drive out the Canaanite, the Amorite, and the Hittite, and the Perizzite, the Hivite, and the Jebusite:
2477	83	3	Unto a land flowing with milk and honey: for I will not go up in the midst of thee; for thou art a stiffnecked people: lest I consume thee in the way.
2478	83	4	And when the people heard these evil tidings, they mourned: and no man did put on him his ornaments.
2479	83	5	For the LORD had said unto Moses, Say unto the children of Israel, Ye are a stiffnecked people: I will come up into the midst of thee in a moment, and consume thee: therefore now put off thy ornaments from thee, that I may know what to do unto thee.
2480	83	6	And the children of Israel stripped themselves of their ornaments by the mount Horeb.
2481	83	7	And Moses took the tabernacle, and pitched it without the camp, afar off from the camp, and called it the Tabernacle of the congregation. And it came to pass, that every one which sought the LORD went out unto the tabernacle of the congregation, which was without the camp.
2482	83	8	And it came to pass, when Moses went out unto the tabernacle, that all the people rose up, and stood every man at his tent door, and looked after Moses, until he was gone into the tabernacle.
2483	83	9	And it came to pass, as Moses entered into the tabernacle, the cloudy pillar descended, and stood at the door of the tabernacle, and the LORD talked with Moses.
2484	83	10	And all the people saw the cloudy pillar stand at the tabernacle door: and all the people rose up and worshipped, every man in his tent door.
2485	83	11	And the LORD spake unto Moses face to face, as a man speaketh unto his friend. And he turned again into the camp: but his servant Joshua, the son of Nun, a young man, departed not out of the tabernacle.
2486	83	12	And Moses said unto the LORD, See, thou sayest unto me, Bring up this people: and thou hast not let me know whom thou wilt send with me. Yet thou hast said, I know thee by name, and thou hast also found grace in my sight.
2487	83	13	Now therefore, I pray thee, if I have found grace in thy sight, shew me now thy way, that I may know thee, that I may find grace in thy sight: and consider that this nation is thy people.
2488	83	14	And he said, My presence shall go with thee, and I will give thee rest.
2489	83	15	And he said unto him, If thy presence go not with me, carry us not up hence.
2490	83	16	For wherein shall it be known here that I and thy people have found grace in thy sight? is it not in that thou goest with us? so shall we be separated, I and thy people, from all the people that are upon the face of the earth.
2491	83	17	And the LORD said unto Moses, I will do this thing also that thou hast spoken: for thou hast found grace in my sight, and I know thee by name.
2492	83	18	And he said, I beseech thee, shew me thy glory.
2493	83	19	And he said, I will make all my goodness pass before thee, and I will proclaim the name of the LORD before thee; and will be gracious to whom I will be gracious, and will shew mercy on whom I will shew mercy.
2494	83	20	And he said, Thou canst not see my face: for there shall no man see me, and live.
2495	83	21	And the LORD said, Behold, there is a place by me, and thou shalt stand upon a rock:
2496	83	22	And it shall come to pass, while my glory passeth by, that I will put thee in a clift of the rock, and will cover thee with my hand while I pass by:
2497	83	23	And I will take away mine hand, and thou shalt see my back parts: but my face shall not be seen.
2498	84	1	AND the LORD said unto Moses, Hew thee two tables of stone like unto the first: and I will write upon these tables the words that were in the first tables, which thou brakest.
2499	84	2	And be ready in the morning, and come up in the morning unto mount Sinai, and present thyself there to me in the top of the mount.
2500	84	3	And no man shall come up with thee, neither let any man be seen throughout all the mount; neither let the flocks nor herds feed before that mount.
2501	84	4	And he hewed two tables of stone like unto the first; and Moses rose up early in the morning, and went up unto mount Sinai, as the LORD had commanded him, and took in his hand the two tables of stone.
2502	84	5	And the LORD descended in the cloud, and stood with him there, and proclaimed the name of the LORD.
2503	84	6	And the LORD passed by before him, and proclaimed, The LORD, The LORD God, merciful and gracious, longsuffering, and abundant in goodness and truth,
2504	84	7	Keeping mercy for thousands, forgiving iniquity and transgression and sin, and that will by no means clear the guilty; visiting the iniquity of the fathers upon the children, and upon the children's children, unto the third and to the fourth generation.
2505	84	8	And Moses made haste, and bowed his head toward the earth, and worshipped.
2506	84	9	And he said, If now I have found grace in thy sight, O Lord, let my Lord, I pray thee, go among us; for it is a stiffnecked people; and pardon our iniquity and our sin, and take us for thine inheritance.
2507	84	10	And he said, Behold, I make a covenant: before all thy people I will do marvels, such as have not been done in all the earth, nor in any nation: and all the people among which thou art shall see the work of the LORD: for it is a terrible thing that I will do with thee.
2508	84	11	Observe thou that which I command thee this day: behold, I drive out before thee the Amorite, and the Canaanite, and the Hittite, and the Perizzite, and the Hivite, and the Jebusite.
2509	84	12	Take heed to thyself, lest thou make a covenant with the inhabitants of the land whither thou goest, lest it be for a snare in the midst of thee:
2510	84	13	But ye shall destroy their altars, break their images, and cut down their groves:
2511	84	14	For thou shalt worship no other god: for the LORD, whose name is Jealous, is a jealous God:
2512	84	15	Lest thou make a covenant with the inhabitants of the land, and they go a whoring after their gods, and do sacrifice unto their gods, and one call thee, and thou eat of his sacrifice;
2513	84	16	And thou take of their daughters unto thy sons, and their daughters go a whoring after their gods, and make thy sons go a whoring after their gods.
2514	84	17	Thou shalt make thee no molten gods.
2515	84	18	The feast of unleavened bread shalt thou keep. Seven days thou shalt eat unleavened bread, as I commanded thee, in the time of the month Abib: for in the month Abib thou camest out from Egypt.
2516	84	19	All that openeth the matrix is mine; and every firstling among thy cattle, whether ox or sheep, that is male.
2517	84	20	But the firstling of an ass thou shalt redeem with a lamb: and if thou redeem him not, then shalt thou break his neck. All the firstborn of thy sons thou shalt redeem. And none shall appear before me empty.
2518	84	21	Six days thou shalt work, but on the seventh day thou shalt rest: in earing time and in harvest thou shalt rest.
2519	84	22	And thou shalt observe the feast of weeks, of the firstfruits of wheat harvest, and the feast of ingathering at the year's end.
2520	84	23	Thrice in the year shall all your men children appear before the Lord GOD, the God of Israel.
2521	84	24	For I will cast out the nations before thee, and enlarge thy borders: neither shall any man desire thy land, when thou shalt go up to appear before the LORD thy God thrice in the year.
2522	84	25	Thou shalt not offer the blood of my sacrifice with leaven; neither shall the sacrifice of the feast of the passover be left unto the morning.
2523	84	26	The first of the firstfruits of thy land thou shalt bring unto the house of the LORD thy God. Thou shalt not seethe a kid in his mother's milk.
2524	84	27	And the LORD said unto Moses, Write thou these words: for after the tenor of these words I have made a covenant with thee and with Israel.
2525	84	28	And he was there with the LORD forty days and forty nights; he did neither eat bread, nor drink water. And he wrote upon the tables the words of the covenant, the ten commandments.
2526	84	29	And it came to pass, when Moses came down from mount Sinai with the two tables of testimony in Moses' hand, when he came down from the mount, that Moses wist not that the skin of his face shone while he talked with him.
2527	84	30	And when Aaron and all the children of Israel saw Moses, behold, the skin of his face shone; and they were afraid to come nigh him.
2528	84	31	And Moses called unto them; and Aaron and all the rulers of the congregation returned unto him: and Moses talked with them.
2529	84	32	And afterward all the children of Israel came nigh: and he gave them in commandment all that the LORD had spoken with him in mount Sinai.
2530	84	33	And till Moses had done speaking with them, he put a vail on his face.
2531	84	34	But when Moses went in before the LORD to speak with him, he took the vail off, until he came out. And he came out, and spake unto the children of Israel that which he was commanded.
2532	84	35	And the children of Israel saw the face of Moses, that the skin of Moses' face shone: and Moses put the vail upon his face again, until he went in to speak with him.
2533	85	1	AND Moses gathered all the congregation of the children of Israel together, and said unto them, These are the words which the LORD hath commanded, that ye should do them.
2534	85	2	Six days shall work be done, but on the seventh day there shall be to you an holy day, a sabbath of rest to the LORD: whosoever doeth work therein shall be put to death.
2535	85	3	Ye shall kindle no fire throughout your habitations upon the sabbath day.
2536	85	4	And Moses spake unto all the congregation of the children of Israel, saying, This is the thing which the LORD commanded, saying,
2537	85	5	Take ye from among you an offering unto the LORD: whosoever is of a willing heart, let him bring it, an offering of the LORD; gold, and silver, and brass,
2538	85	6	And blue, and purple, and scarlet, and fine linen, and goats' hair,
2539	85	7	And rams' skins dyed red, and badgers' skins, and shittim wood,
2540	85	8	And oil for the light, and spices for anointing oil, and for the sweet incense,
2541	85	9	And onyx stones, and stones to be set for the ephod, and for the breastplate.
2542	85	10	And every wise hearted among you shall come, and make all that the LORD hath commanded;
2543	85	11	The tabernacle, his tent, and his covering, his taches, and his boards, his bars, his pillars, and his sockets,
2544	85	12	The ark, and the staves thereof, with the mercy seat, and the vail of the covering,
2545	85	13	The table, and his staves, and all his vessels, and the shewbread,
2546	85	14	The candlestick also for the light, and his furniture, and his lamps, with the oil for the light,
2547	85	15	And the incense altar, and his staves, and the anointing oil, and the sweet incense, and the hanging for the door at the entering in of the tabernacle,
2548	85	16	The altar of burnt offering, with his brasen grate, his staves, and all his vessels, the laver and his foot,
2549	85	17	The hangings of the court, his pillars, and their sockets, and the hanging for the door of the court,
2550	85	18	The pins of the tabernacle, and the pins of the court, and their cords,
2551	85	19	The cloths of service, to do service in the holy place, the holy garments for Aaron the priest, and the garments of his sons, to minister in the priest's office.
2552	85	20	And all the congregation of the children of Israel departed from the presence of Moses.
2553	85	21	And they came, every one whose heart stirred him up, and every one whom his spirit made willing, and they brought the LORD's offering to the work of the tabernacle of the congregation, and for all his service, and for the holy garments.
2554	85	22	And they came, both men and women, as many as were willing hearted, and brought bracelets, and earrings, and rings, and tablets, all jewels of gold: and every man that offered offered an offering of gold unto the LORD.
2555	85	23	And every man, with whom was found blue, and purple, and scarlet, and fine linen, and goats' hair, and red skins of rams, and badgers' skins, brought them.
2556	85	24	Every one that did offer an offering of silver and brass brought the LORD's offering: and every man, with whom was found shittim wood for any work of the service, brought it.
2557	85	25	And all the women that were wise hearted did spin with their hands, and brought that which they had spun, both of blue, and of purple, and of scarlet, and of fine linen.
2558	85	26	And all the women whose heart stirred them up in wisdom spun goats' hair.
2559	85	27	And the rulers brought onyx stones, and stones to be set, for the ephod, and for the breastplate;
2560	85	28	And spice, and oil for the light, and for the anointing oil, and for the sweet incense.
2561	85	29	The children of Israel brought a willing offering unto the LORD, every man and woman, whose heart made them willing to bring for all manner of work, which the LORD had commanded to be made by the hand of Moses.
2562	85	30	And Moses said unto the children of Israel, See, the LORD hath called by name Bezaleel the son of Uri, the son of Hur, of the tribe of Judah;
2563	85	31	And he hath filled him with the spirit of God, in wisdom, in understanding, and in knowledge, and in all manner of workmanship;
2564	85	32	And to devise curious works, to work in gold, and in silver, and in brass,
2565	85	33	And in the cutting of stones, to set them, and in carving of wood, to make any manner of cunning work.
2566	85	34	And he hath put in his heart that he may teach, both he, and Aholiab, the son of Ahisamach, of the tribe of Dan.
2567	85	35	Them hath he filled with wisdom of heart, to work all manner of work, of the engraver, and of the cunning workman, and of the embroiderer, in blue, and in purple, in scarlet, and in fine linen, and of the weaver, even of them that do any work, and of those that devise cunning work.
2568	86	1	THEN wrought Bezaleel and Aholiab, and every wise hearted man, in whom the LORD put wisdom and understanding to know how to work all manner of work for the service of the sanctuary, according to all that the LORD had commanded.
2569	86	2	And Moses called Bezaleel and Aholiab, and every wise hearted man, in whose heart the LORD had put wisdom, even every one whose heart stirred him up to come unto the work to do it:
2570	86	3	And they received of Moses all the offering, which the children of Israel had brought for the work of the service of the sanctuary, to make it withal. And they brought yet unto him free offerings every morning.
2571	86	4	And all the wise men, that wrought all the work of the sanctuary, came every man from his work which they made;
2572	86	5	And they spake unto Moses, saying, The people bring much more than enough for the service of the work, which the LORD commanded to make.
2573	86	6	And Moses gave commandment, and they caused it to be proclaimed throughout the camp, saying, Let neither man nor woman make any more work for the offering of the sanctuary. So the people were restrained from bringing.
2574	86	7	For the stuff they had was sufficient for all the work to make it, and too much.
2575	86	8	And every wise hearted man among them that wrought the work of the tabernacle made ten curtains of fine twined linen, and blue, and purple, and scarlet: with cherubims of cunning work made he them.
2576	86	9	The length of one curtain was twenty and eight cubits, and the breadth of one curtain four cubits: the curtains were all of one size.
2577	86	10	And he coupled the five curtains one unto another: and the other five curtains he coupled one unto another.
2578	86	11	And he made loops of blue on the edge of one curtain from the selvedge in the coupling: likewise he made in the uttermost side of another curtain, in the coupling of the second.
2579	86	12	Fifty loops made he in one curtain, and fifty loops made he in the edge of the curtain which was in the coupling of the second: the loops held one curtain to another.
2580	86	13	And he made fifty taches of gold, and coupled the curtains one unto another with the taches: so it became one tabernacle.
2581	86	14	And he made curtains of goats' hair for the tent over the tabernacle: eleven curtains he made them.
2582	86	15	The length of one curtain was thirty cubits, and four cubits was the breadth of one curtain: the eleven curtains were of one size.
2583	86	16	And he coupled five curtains by themselves, and six curtains by themselves.
2584	86	17	And he made fifty loops upon the uttermost edge of the curtain in the coupling, and fifty loops made he upon the edge of the curtain which coupleth the second.
2585	86	18	And he made fifty taches of brass to couple the tent together, that it might be one.
2586	86	19	And he made a covering for the tent of rams' skins dyed red, and a covering of badgers' skins above that.
2587	86	20	And he made boards for the tabernacle of shittim wood, standing up.
2588	86	21	The length of a board was ten cubits, and the breadth of a board one cubit and a half.
2589	86	22	One board had two tenons, equally distant one from another: thus did he make for all the boards of the tabernacle.
2590	86	23	And he made boards for the tabernacle; twenty boards for the south side southward:
2591	86	24	And forty sockets of silver he made under the twenty boards; two sockets under one board for his two tenons, and two sockets under another board for his two tenons.
2592	86	25	And for the other side of the tabernacle, which is toward the north corner, he made twenty boards,
2593	86	26	And their forty sockets of silver; two sockets under one board, and two sockets under another board.
2594	86	27	And for the sides of the tabernacle westward he made six boards.
2595	86	28	And two boards made he for the corners of the tabernacle in the two sides.
2596	86	29	And they were coupled beneath, and coupled together at the head thereof, to one ring: thus he did to both of them in both the corners.
2597	86	30	And there were eight boards; and their sockets were sixteen sockets of silver, under every board two sockets.
2598	86	31	And he made bars of shittim wood; five for the boards of the one side of the tabernacle,
2599	86	32	And five bars for the boards of the other side of the tabernacle, and five bars for the boards of the tabernacle for the sides westward.
2600	86	33	And he made the middle bar to shoot through the boards from the one end to the other.
2601	86	34	And he overlaid the boards with gold, and made their rings of gold to be places for the bars, and overlaid the bars with gold.
2602	86	35	And he made a vail of blue, and purple, and scarlet, and fine twined linen: with cherubims made he it of cunning work.
2603	86	36	And he made thereunto four pillars of shittim wood, and overlaid them with gold: their hooks were of gold; and he cast for them four sockets of silver.
2604	86	37	And he made an hanging for the tabernacle door of blue, and purple, and scarlet, and fine twined linen, of needlework;
2605	86	38	And the five pillars of it with their hooks: and he overlaid their chapiters and their fillets with gold: but their five sockets were of brass.
2606	87	1	AND Bezaleel made the ark of shittim wood: two cubits and a half was the length of it, and a cubit and a half the breadth of it, and a cubit and a half the height of it:
2607	87	2	And he overlaid it with pure gold within and without, and made a crown of gold to it round about.
2608	87	3	And he cast for it four rings of gold, to be set by the four corners of it; even two rings upon the one side of it, and two rings upon the other side of it.
2609	87	4	And he made staves of shittim wood, and overlaid them with gold.
2610	87	5	And he put the staves into the rings by the sides of the ark, to bear the ark.
2611	87	6	And he made the mercy seat of pure gold: two cubits and a half was the length thereof, and one cubit and a half the breadth thereof.
2612	87	7	And he made two cherubims of gold, beaten out of one piece made he them, on the two ends of the mercy seat;
2613	87	8	One cherub on the end on this side, and another cherub on the other end on that side: out of the mercy seat made he the cherubims on the two ends thereof.
2614	87	9	And the cherubims spread out their wings on high, and covered with their wings over the mercy seat, with their faces one to another; even to the mercy seatward were the faces of the cherubims.
2615	87	10	And he made the table of shittim wood: two cubits was the length thereof, and a cubit the breadth thereof, and a cubit and a half the height thereof:
2616	87	11	And he overlaid it with pure gold, and made thereunto a crown of gold round about.
2617	87	12	Also he made thereunto a border of an handbreadth round about; and made a crown of gold for the border thereof round about.
2618	87	13	And he cast for it four rings of gold, and put the rings upon the four corners that were in the four feet thereof.
2619	87	14	Over against the border were the rings, the places for the staves to bear the table.
2620	87	15	And he made the staves of shittim wood, and overlaid them with gold, to bear the table.
2621	87	16	And he made the vessels which were upon the table, his dishes, and his spoons, and his bowls, and his covers to cover withal, of pure gold.
2622	87	17	And he made the candlestick of pure gold: of beaten work made he the candlestick; his shaft, and his branch, his bowls, his knops, and his flowers, were of the same:
2623	87	18	And six branches going out of the sides thereof; three branches of the candlestick out of the one side thereof, and three branches of the candlestick out of the other side thereof:
2624	87	19	Three bowls made after the fashion of almonds in one branch, a knop and a flower; and three bowls made like almonds in another branch, a knop and a flower: so throughout the six branches going out of the candlestick.
2625	87	20	And in the candlestick were four bowls made like almonds, his knops, and his flowers:
2626	87	21	And a knop under two branches of the same, and a knop under two branches of the same, and a knop under two branches of the same, according to the six branches going out of it.
2627	87	22	Their knops and their branches were of the same: all of it was one beaten work of pure gold.
2628	87	23	And he made his seven lamps, and his snuffers, and his snuffdishes, of pure gold.
2629	87	24	Of a talent of pure gold made he it, and all the vessels thereof.
2630	87	25	And he made the incense altar of shittim wood: the length of it was a cubit, and the breadth of it a cubit; it was foursquare; and two cubits was the height of it; the horns thereof were of the same.
2631	87	26	And he overlaid it with pure gold, both the top of it, and the sides thereof round about, and the horns of it: also he made unto it a crown of gold round about.
2632	87	27	And he made two rings of gold for it under the crown thereof, by the two corners of it, upon the two sides thereof, to be places for the staves to bear it withal.
2633	87	28	And he made the staves of shittim wood, and overlaid them with gold.
2634	87	29	And he made the holy anointing oil, and the pure incense of sweet spices, according to the work of the apothecary.
2635	88	1	AND he made the altar of burnt offering of shittim wood: five cubits was the length thereof, and five cubits the breadth thereof; it was foursquare; and three cubits the height thereof.
2636	88	2	And he made the horns thereof on the four corners of it; the horns thereof were of the same: and he overlaid it with brass.
2637	88	3	And he made all the vessels of the altar, the pots, and the shovels, and the basons, and the fleshhooks, and the firepans: all the vessels thereof made he of brass.
2638	88	4	And he made for the altar a brasen grate of network under the compass thereof beneath unto the midst of it.
2639	88	5	And he cast four rings for the four ends of the grate of brass, to be places for the staves.
2640	88	6	And he made the staves of shittim wood, and overlaid them with brass.
2641	88	7	And he put the staves into the rings on the sides of the altar, to bear it withal; he made the altar hollow with boards.
2642	88	8	And he made the laver of brass, and the foot of it of brass, of the lookingglasses of the women assembling, which assembled at the door of the tabernacle of the congregation.
2643	88	9	And he made the court: on the south side southward the hangings of the court were of fine twined linen, an hundred cubits:
2644	88	10	Their pillars were twenty, and their brasen sockets twenty; the hooks of the pillars and their fillets were of silver.
2645	88	11	And for the north side the hangings were an hundred cubits, their pillars were twenty, and their sockets of brass twenty; the hooks of the pillars and their fillets of silver.
2646	88	12	And for the west side were hangings of fifty cubits, their pillars ten, and their sockets ten; the hooks of the pillars and their fillets of silver.
2647	88	13	And for the east side eastward fifty cubits.
2648	88	14	The hangings of the one side of the gate were fifteen cubits; their pillars three, and their sockets three.
2649	88	15	And for the other side of the court gate, on this hand and that hand, were hangings of fifteen cubits; their pillars three, and their sockets three.
2650	88	16	All the hangings of the court round about were of fine twined linen.
2651	88	17	And the sockets for the pillars were of brass; the hooks of the pillars and their fillets of silver; and the overlaying of their chapiters of silver; and all the pillars of the court were filleted with silver.
2652	88	18	And the hanging for the gate of the court was needlework, of blue, and purple, and scarlet, and fine twined linen: and twenty cubits was the length, and the height in the breadth was five cubits, answerable to the hangings of the court.
2653	88	19	And their pillars were four, and their sockets of brass four; their hooks of silver, and the overlaying of their chapiters and their fillets of silver.
2654	88	20	And all the pins of the tabernacle, and of the court round about, were of brass.
2655	88	21	This is the sum of the tabernacle, even of the tabernacle of testimony, as it was counted, according to the commandment of Moses, for the service of the Levites, by the hand of Ithamar, son to Aaron the priest.
2656	88	22	And Bezaleel the son of Uri, the son of Hur, of the tribe of Judah, made all that the LORD commanded Moses.
2657	88	23	And with him was Aholiab, son of Ahisamach, of the tribe of Dan, an engraver, and a cunning workman, and an embroiderer in blue, and in purple, and in scarlet, and fine linen.
2658	88	24	All the gold that was occupied for the work in all the work of the holy place, even the gold of the offering, was twenty and nine talents, and seven hundred and thirty shekels, after the shekel of the sanctuary.
2659	88	25	And the silver of them that were numbered of the congregation was an hundred talents, and a thousand seven hundred and threescore and fifteen shekels, after the shekel of the sanctuary:
2660	88	26	A bekah for every man, that is, half a shekel, after the shekel of the sanctuary, for every one that went to be numbered, from twenty years old and upward, for six hundred thousand and three thousand and five hundred and fifty men.
2661	88	27	And of the hundred talents of silver were cast the sockets of the sanctuary, and the sockets of the vail; an hundred sockets of the hundred talents, a talent for a socket.
2662	88	28	And of the thousand seven hundred seventy and five shekels he made hooks for the pillars, and overlaid their chapiters, and filleted them.
2663	88	29	And the brass of the offering was seventy talents, and two thousand and four hundred shekels.
2664	88	30	And therewith he made the sockets to the door of the tabernacle of the congregation, and the brasen altar, and the brasen grate for it, and all the vessels of the altar,
2665	88	31	And the sockets of the court round about, and the sockets of the court gate, and all the pins of the tabernacle, and all the pins of the court round about.
2666	89	1	AND of the blue, and purple, and scarlet, they made cloths of service, to do service in the holy place, and made the holy garments for Aaron; as the LORD commanded Moses.
2667	89	2	And he made the ephod of gold, blue, and purple, and scarlet, and fine twined linen.
2668	89	3	And they did beat the gold into thin plates, and cut it into wires, to work it in the blue, and in the purple, and in the scarlet, and in the fine linen, with cunning work.
2669	89	4	They made shoulderpieces for it, to couple it together: by the two edges was it coupled together.
2670	89	5	And the curious girdle of his ephod, that was upon it, was of the same, according to the work thereof; of gold, blue, and purple, and scarlet, and fine twined linen; as the LORD commanded Moses.
2671	89	6	And they wrought onyx stones inclosed in ouches of gold, graven, as signets are graven, with the names of the children of Israel.
2672	89	7	And he put them on the shoulders of the ephod, that they should be stones for a memorial to the children of Israel; as the LORD commanded Moses.
2673	89	8	And he made the breastplate of cunning work, like the work of the ephod; of gold, blue, and purple, and scarlet, and fine twined linen.
2674	89	9	It was foursquare; they made the breastplate double: a span was the length thereof, and a span the breadth thereof, being doubled.
2675	89	10	And they set in it four rows of stones: the first row was a sardius, a topaz, and a carbuncle: this was the first row.
2676	89	11	And the second row, an emerald, a sapphire, and a diamond.
2677	89	12	And the third row, a ligure, an agate, and an amethyst.
2678	89	13	And the fourth row, a beryl, an onyx, and a jasper: they were inclosed in ouches of gold in their inclosings.
2679	89	14	And the stones were according to the names of the children of Israel, twelve, according to their names, like the engravings of a signet, every one with his name, according to the twelve tribes.
2680	89	15	And they made upon the breastplate chains at the ends, of wreathen work of pure gold.
2681	89	16	And they made two ouches of gold, and two gold rings; and put the two rings in the two ends of the breastplate.
2682	89	17	And they put the two wreathen chains of gold in the two rings on the ends of the breastplate.
2683	89	18	And the two ends of the two wreathen chains they fastened in the two ouches, and put them on the shoulderpieces of the ephod, before it.
2684	89	19	And they made two rings of gold, and put them on the two ends of the breastplate, upon the border of it, which was on the side of the ephod inward.
2685	89	20	And they made two other golden rings, and put them on the two sides of the ephod underneath, toward the forepart of it, over against the other coupling thereof, above the curious girdle of the ephod.
2686	89	21	And they did bind the breastplate by his rings unto the rings of the ephod with a lace of blue, that it might be above the curious girdle of the ephod, and that the breastplate might not be loosed from the ephod; as the LORD commanded Moses.
2687	89	22	And he made the robe of the ephod of woven work, all of blue.
2688	89	23	And there was an hole in the midst of the robe, as the hole of an habergeon, with a band round about the hole, that it should not rend.
2689	89	24	And they made upon the hems of the robe pomegranates of blue, and purple, and scarlet, and twined linen.
2690	89	25	And they made bells of pure gold, and put the bells between the pomegranates upon the hem of the robe, round about between the pomegranates;
2691	89	26	A bell and a pomegranate, a bell and a pomegranate, round about the hem of the robe to minister in; as the LORD commanded Moses.
2692	89	27	And they made coats of fine linen of woven work for Aaron, and for his sons,
2693	89	28	And a mitre of fine linen, and goodly bonnets of fine linen, and linen breeches of fine twined linen,
2694	89	29	And a girdle of fine twined linen, and blue, and purple, and scarlet, of needlework; as the LORD commanded Moses.
2695	89	30	And they made the plate of the holy crown of pure gold, and wrote upon it a writing, like to the engravings of a signet, HOLINESS TO THE LORD.
2696	89	31	And they tied unto it a lace of blue, to fasten it on high upon the mitre; as the LORD commanded Moses.
2697	89	32	Thus was all the work of the tabernacle of the tent of the congregation finished: and the children of Israel did according to all that the LORD commanded Moses, so did they.
2698	89	33	And they brought the tabernacle unto Moses, the tent, and all his furniture, his taches, his boards, his bars, and his pillars, and his sockets,
2699	89	34	And the covering of rams' skins dyed red, and the covering of badgers' skins, and the vail of the covering,
2700	89	35	The ark of the testimony, and the staves thereof, and the mercy seat,
2701	89	36	The table, and all the vessels thereof, and the shewbread,
2702	89	37	The pure candlestick, with the lamps thereof, even with the lamps to be set in order, and all the vessels thereof, and the oil for light,
2703	89	38	And the golden altar, and the anointing oil, and the sweet incense, and the hanging for the tabernacle door,
2704	89	39	The brasen altar, and his grate of brass, his staves, and all his vessels, the laver and his foot,
2705	89	40	The hangings of the court, his pillars, and his sockets, and the hanging for the court gate, his cords, and his pins, and all the vessels of the service of the tabernacle, for the tent of the congregation,
2706	89	41	The cloths of service to do service in the holy place, and the holy garments for Aaron the priest, and his sons' garments, to minister in the priest's office.
2707	89	42	According to all that the LORD commanded Moses, so the children of Israel made all the work.
2708	89	43	And Moses did look upon all the work, and, behold, they had done it as the LORD had commanded, even so had they done it: and Moses blessed them.
2709	90	1	AND the LORD spake unto Moses, saying,
2710	90	2	On the first day of the first month shalt thou set up the tabernacle of the tent of the congregation.
2711	90	3	And thou shalt put therein the ark of the testimony, and cover the ark with the vail.
2712	90	4	And thou shalt bring in the table, and set in order the things that are to be set in order upon it; and thou shalt bring in the candlestick, and light the lamps thereof.
2713	90	5	And thou shalt set the altar of gold for the incense before the ark of the testimony, and put the hanging of the door to the tabernacle.
2714	90	6	And thou shalt set the altar of the burnt offering before the door of the tabernacle of the tent of the congregation.
2715	90	7	And thou shalt set the laver between the tent of the congregation and the altar, and shalt put water therein.
2716	90	8	And thou shalt set up the court round about, and hang up the hanging at the court gate.
2717	90	9	And thou shalt take the anointing oil, and anoint the tabernacle, and all that is therein, and shalt hallow it, and all the vessels thereof: and it shall be holy.
2718	90	10	And thou shalt anoint the altar of the burnt offering, and all his vessels, and sanctify the altar: and it shall be an altar most holy.
2719	90	11	And thou shalt anoint the laver and his foot, and sanctify it.
2720	90	12	And thou shalt bring Aaron and his sons unto the door of the tabernacle of the congregation, and wash them with water.
2721	90	13	And thou shalt put upon Aaron the holy garments, and anoint him, and sanctify him; that he may minister unto me in the priest's office.
2722	90	14	And thou shalt bring his sons, and clothe them with coats:
2723	90	15	And thou shalt anoint them, as thou didst anoint their father, that they may minister unto me in the priest's office: for their anointing shall surely be an everlasting priesthood throughout their generations.
2724	90	16	Thus did Moses: according to all that the LORD commanded him, so did he.
2725	90	17	And it came to pass in the first month in the second year, on the first day of the month, that the tabernacle was reared up.
2726	90	18	And Moses reared up the tabernacle, and fastened his sockets, and set up the boards thereof, and put in the bars thereof, and reared up his pillars.
2727	90	19	And he spread abroad the tent over the tabernacle, and put the covering of the tent above upon it; as the LORD commanded Moses.
2728	90	20	And he took and put the testimony into the ark, and set the staves on the ark, and put the mercy seat above upon the ark:
2729	90	21	And he brought the ark into the tabernacle, and set up the vail of the covering, and covered the ark of the testimony; as the LORD commanded Moses.
2730	90	22	And he put the table in the tent of the congregation, upon the side of the tabernacle northward, without the vail.
2731	90	23	And he set the bread in order upon it before the LORD; as the LORD had commanded Moses.
2732	90	24	And he put the candlestick in the tent of the congregation, over against the table, on the side of the tabernacle southward.
2733	90	25	And he lighted the lamps before the LORD; as the LORD commanded Moses.
2734	90	26	And he put the golden altar in the tent of the congregation before the vail:
2735	90	27	And he burnt sweet incense thereon; as the LORD commanded Moses.
2736	90	28	And he set up the hanging at the door of the tabernacle.
2737	90	29	And he put the altar of burnt offering by the door of the tabernacle of the tent of the congregation, and offered upon it the burnt offering and the meat offering; as the LORD commanded Moses.
2738	90	30	And he set the laver between the tent of the congregation and the altar, and put water there, to wash withal.
2739	90	31	And Moses and Aaron and his sons washed their hands and their feet thereat:
2740	90	32	When they went into the tent of the congregation, and when they came near unto the altar, they washed; as the LORD commanded Moses.
2741	90	33	And he reared up the court round about the tabernacle and the altar, and set up the hanging of the court gate. So Moses finished the work.
2742	90	34	Then a cloud covered the tent of the congregation, and the glory of the LORD filled the tabernacle.
2743	90	35	And Moses was not able to enter into the tent of the congregation, because the cloud abode thereon, and the glory of the LORD filled the tabernacle.
2744	90	36	And when the cloud was taken up from over the tabernacle, the children of Israel went onward in all their journeys:
2745	90	37	But if the cloud were not taken up, then they journeyed not till the day that it was taken up.
2746	90	38	For the cloud of the LORD was upon the tabernacle by day, and fire was on it by night, in the sight of all the house of Israel, throughout all their journeys.
2747	91	1	AND the LORD called unto Moses, and spake unto him out of the tabernacle of the congregation, saying,
2748	91	2	Speak unto the children of Israel, and say unto them, If any man of you bring an offering unto the LORD, ye shall bring your offering of the cattle, even of the herd, and of the flock.
2749	91	3	If his offering be a burnt sacrifice of the herd, let him offer a male without blemish: he shall offer it of his own voluntary will at the door of the tabernacle of the congregation before the LORD.
2750	91	4	And he shall put his hand upon the head of the burnt offering; and it shall be accepted for him to make atonement for him.
2751	91	5	And he shall kill the bullock before the LORD: and the priests, Aaron's sons, shall bring the blood, and sprinkle the blood round about upon the altar that is by the door of the tabernacle of the congregation.
2752	91	6	And he shall flay the burnt offering, and cut it into his pieces.
2753	91	7	And the sons of Aaron the priest shall put fire upon the altar, and lay the wood in order upon the fire:
2754	91	8	And the priests, Aaron's sons, shall lay the parts, the head, and the fat, in order upon the wood that is on the fire which is upon the altar:
2755	91	9	But his inwards and his legs shall he wash in water: and the priest shall burn all on the altar, to be a burnt sacrifice, an offering made by fire, of a sweet savour unto the LORD.
2756	91	10	And if his offering be of the flocks, namely, of the sheep, or of the goats, for a burnt sacrifice; he shall bring it a male without blemish.
2757	91	11	And he shall kill it on the side of the altar northward before the LORD: and the priests, Aaron's sons, shall sprinkle his blood round about upon the altar.
2758	91	12	And he shall cut it into his pieces, with his head and his fat: and the priest shall lay them in order on the wood that is on the fire which is upon the altar:
2759	91	13	But he shall wash the inwards and the legs with water: and the priest shall bring it all, and burn it upon the altar: it is a burnt sacrifice, an offering made by fire, of a sweet savour unto the LORD.
2760	91	14	And if the burnt sacrifice for his offering to the LORD be of fowls, then he shall bring his offering of turtledoves, or of young pigeons.
2761	91	15	And the priest shall bring it unto the altar, and wring off his head, and burn it on the altar; and the blood thereof shall be wrung out at the side of the altar:
2762	91	16	And he shall pluck away his crop with his feathers, and cast it beside the altar on the east part, by the place of the ashes:
2763	91	17	And he shall cleave it with the wings thereof, but shall not divide it asunder: and the priest shall burn it upon the altar, upon the wood that is upon the fire: it is a burnt sacrifice, an offering made by fire, of a sweet savour unto the LORD.
2764	92	1	AND when any will offer a meat offering unto the LORD, his offering shall be of fine flour; and he shall pour oil upon it, and put frankincense thereon:
2765	92	2	And he shall bring it to Aaron's sons the priests: and he shall take thereout his handful of the flour thereof, and of the oil thereof, with all the frankincense thereof; and the priest shall burn the memorial of it upon the altar, to be an offering made by fire, of a sweet savour unto the LORD:
2766	92	3	And the remnant of the meat offering shall be Aaron's and his sons': it is a thing most holy of the offerings of the LORD made by fire.
2767	92	4	And if thou bring an oblation of a meat offering baken in the oven, it shall be unleavened cakes of fine flour mingled with oil, or unleavened wafers anointed with oil.
2768	92	5	And if thy oblation be a meat offering baken in a pan, it shall be of fine flour unleavened, mingled with oil.
2769	92	6	Thou shalt part it in pieces, and pour oil thereon: it is a meat offering.
2770	92	7	And if thy oblation be a meat offering baken in the fryingpan, it shall be made of fine flour with oil.
2771	92	8	And thou shalt bring the meat offering that is made of these things unto the LORD: and when it is presented unto the priest, he shall bring it unto the altar.
2772	92	9	And the priest shall take from the meat offering a memorial thereof, and shall burn it upon the altar: it is an offering made by fire, of a sweet savour unto the LORD.
2773	92	10	And that which is left of the meat offering shall be Aaron's and his sons': it is a thing most holy of the offerings of the LORD made by fire.
2774	92	11	No meat offering, which ye shall bring unto the LORD, shall be made with leaven: for ye shall burn no leaven, nor any honey, in any offering of the LORD made by fire.
2775	92	12	As for the oblation of the firstfruits, ye shall offer them unto the LORD: but they shall not be burnt on the altar for a sweet savour.
2776	92	13	And every oblation of thy meat offering shalt thou season with salt; neither shalt thou suffer the salt of the covenant of thy God to be lacking from thy meat offering: with all thine offerings thou shalt offer salt.
2777	92	14	And if thou offer a meat offering of thy firstfruits unto the LORD, thou shalt offer for the meat offering of thy firstfruits green ears of corn dried by the fire, even corn beaten out of full ears.
2778	92	15	And thou shalt put oil upon it, and lay frankincense thereon: it is a meat offering.
2779	92	16	And the priest shall burn the memorial of it, part of the beaten corn thereof, and part of the oil thereof, with all the frankincense thereof: it is an offering made by fire unto the LORD.
2780	93	1	AND if his oblation be a sacrifice of peace offering, if he offer it of the herd; whether it be a male or female, he shall offer it without blemish before the LORD.
2781	93	2	And he shall lay his hand upon the head of his offering, and kill it at the door of the tabernacle of the congregation: and Aaron's sons the priests shall sprinkle the blood upon the altar round about.
2782	93	3	And he shall offer of the sacrifice of the peace offering an offering made by fire unto the LORD; the fat that covereth the inwards, and all the fat that is upon the inwards,
2783	93	4	And the two kidneys, and the fat that is on them, which is by the flanks, and the caul above the liver, with the kidneys, it shall he take away.
2784	93	5	And Aaron's sons shall burn it on the altar upon the burnt sacrifice, which is upon the wood that is on the fire: it is an offering made by fire, of a sweet savour unto the LORD.
2785	93	6	And if his offering for a sacrifice of peace offering unto the LORD be of the flock; male or female, he shall offer it without blemish.
2786	93	7	If he offer a lamb for his offering, then shall he offer it before the LORD.
2787	93	8	And he shall lay his hand upon the head of his offering, and kill it before the tabernacle of the congregation: and Aaron's sons shall sprinkle the blood thereof round about upon the altar.
2788	93	9	And he shall offer of the sacrifice of the peace offering an offering made by fire unto the LORD; the fat thereof, and the whole rump, it shall he take off hard by the backbone; and the fat that covereth the inwards, and all the fat that is upon the inwards,
2789	93	10	And the two kidneys, and the fat that is upon them, which is by the flanks, and the caul above the liver, with the kidneys, it shall he take away.
2790	93	11	And the priest shall burn it upon the altar: it is the food of the offering made by fire unto the LORD.
2791	93	12	And if his offering be a goat, then he shall offer it before the LORD.
2792	93	13	And he shall lay his hand upon the head of it, and kill it before the tabernacle of the congregation: and the sons of Aaron shall sprinkle the blood thereof upon the altar round about.
2793	93	14	And he shall offer thereof his offering, even an offering made by fire unto the LORD; the fat that covereth the inwards, and all the fat that is upon the inwards,
2794	93	15	And the two kidneys, and the fat that is upon them, which is by the flanks, and the caul above the liver, with the kidneys, it shall he take away.
2795	93	16	And the priest shall burn them upon the altar: it is the food of the offering made by fire for a sweet savour: all the fat is the LORD's.
2796	93	17	It shall be a perpetual statute for your generations throughout all your dwellings, that ye eat neither fat nor blood.
2797	94	1	AND the LORD spake unto Moses, saying,
2798	94	2	Speak unto the children of Israel, saying, If a soul shall sin through ignorance against any of the commandments of the LORD concerning things which ought not to be done, and shall do against any of them:
2799	94	3	If the priest that is anointed do sin according to the sin of the people; then let him bring for his sin, which he hath sinned, a young bullock without blemish unto the LORD for a sin offering.
2800	94	4	And he shall bring the bullock unto the door of the tabernacle of the congregation before the LORD; and shall lay his hand upon the bullock's head, and kill the bullock before the LORD.
2801	94	5	And the priest that is anointed shall take of the bullock's blood, and bring it to the tabernacle of the congregation:
2802	94	6	And the priest shall dip his finger in the blood, and sprinkle of the blood seven times before the LORD, before the vail of the sanctuary.
2803	94	7	And the priest shall put some of the blood upon the horns of the altar of sweet incense before the LORD, which is in the tabernacle of the congregation; and shall pour all the blood of the bullock at the bottom of the altar of the burnt offering, which is at the door of the tabernacle of the congregation.
2804	94	8	And he shall take off from it all the fat of the bullock for the sin offering; the fat that covereth the inwards, and all the fat that is upon the inwards,
2805	94	9	And the two kidneys, and the fat that is upon them, which is by the flanks, and the caul above the liver, with the kidneys, it shall he take away,
2806	94	10	As it was taken off from the bullock of the sacrifice of peace offerings: and the priest shall burn them upon the altar of the burnt offering.
2807	94	11	And the skin of the bullock, and all his flesh, with his head, and with his legs, and his inwards, and his dung,
2808	94	12	Even the whole bullock shall he carry forth without the camp unto a clean place, where the ashes are poured out, and burn him on the wood with fire: where the ashes are poured out shall he be burnt.
2809	94	13	And if the whole congregation of Israel sin through ignorance, and the thing be hid from the eyes of the assembly, and they have done somewhat against any of the commandments of the LORD concerning things which should not be done, and are guilty;
2810	94	14	When the sin, which they have sinned against it, is known, then the congregation shall offer a young bullock for the sin, and bring him before the tabernacle of the congregation.
2811	94	15	And the elders of the congregation shall lay their hands upon the head of the bullock before the LORD: and the bullock shall be killed before the LORD.
2812	94	16	And the priest that is anointed shall bring of the bullock's blood to the tabernacle of the congregation:
2813	94	17	And the priest shall dip his finger in some of the blood, and sprinkle it seven times before the LORD, even before the vail.
2814	94	18	And he shall put some of the blood upon the horns of the altar which is before the LORD, that is in the tabernacle of the congregation, and shall pour out all the blood at the bottom of the altar of the burnt offering, which is at the door of the tabernacle of the congregation.
2815	94	19	And he shall take all his fat from him, and burn it upon the altar.
2816	94	20	And he shall do with the bullock as he did with the bullock for a sin offering, so shall he do with this: and the priest shall make an atonement for them, and it shall be forgiven them.
2817	94	21	And he shall carry forth the bullock without the camp, and burn him as he burned the first bullock: it is a sin offering for the congregation.
2818	94	22	When a ruler hath sinned, and done somewhat through ignorance against any of the commandments of the LORD his God concerning things which should not be done, and is guilty;
2819	94	23	Or if his sin, wherein he hath sinned, come to his knowledge; he shall bring his offering, a kid of the goats, a male without blemish:
2820	94	24	And he shall lay his hand upon the head of the goat, and kill it in the place where they kill the burnt offering before the LORD: it is a sin offering.
2821	94	25	And the priest shall take of the blood of the sin offering with his finger, and put it upon the horns of the altar of burnt offering, and shall pour out his blood at the bottom of the altar of burnt offering.
2822	94	26	And he shall burn all his fat upon the altar, as the fat of the sacrifice of peace offerings: and the priest shall make an atonement for him as concerning his sin, and it shall be forgiven him.
2823	94	27	And if any one of the common people sin through ignorance, while he doeth somewhat against any of the commandments of the LORD concerning things which ought not to be done, and be guilty;
2824	94	28	Or if his sin, which he hath sinned, come to his knowledge: then he shall bring his offering, a kid of the goats, a female without blemish, for his sin which he hath sinned.
2825	94	29	And he shall lay his hand upon the head of the sin offering, and slay the sin offering in the place of the burnt offering.
2826	94	30	And the priest shall take of the blood thereof with his finger, and put it upon the horns of the altar of burnt offering, and shall pour out all the blood thereof at the bottom of the altar.
2827	94	31	And he shall take away all the fat thereof, as the fat is taken away from off the sacrifice of peace offerings; and the priest shall burn it upon the altar for a sweet savour unto the LORD; and the priest shall make an atonement for him, and it shall be forgiven him.
2828	94	32	And if he bring a lamb for a sin offering, he shall bring it a female without blemish.
2829	94	33	And he shall lay his hand upon the head of the sin offering, and slay it for a sin offering in the place where they kill the burnt offering.
2830	94	34	And the priest shall take of the blood of the sin offering with his finger, and put it upon the horns of the altar of burnt offering, and shall pour out all the blood thereof at the bottom of the altar:
2831	94	35	And he shall take away all the fat thereof, as the fat of the lamb is taken away from the sacrifice of the peace offerings; and the priest shall burn them upon the altar, according to the offerings made by fire unto the LORD: and the priest shall make an atonement for his sin that he hath committed, and it shall be forgiven him.
2832	95	1	AND if a soul sin, and hear the voice of swearing, and is a witness, whether he hath seen or known of it; if he do not utter it, then he shall bear his iniquity.
2833	95	2	Or if a soul touch any unclean thing, whether it be a carcase of an unclean beast, or a carcase of unclean cattle, or the carcase of unclean creeping things, and if it be hidden from him; he also shall be unclean, and guilty.
2834	95	3	Or if he touch the uncleanness of man, whatsoever uncleanness it be that a man shall be defiled withal, and it be hid from him; when he knoweth of it, then he shall be guilty.
2835	95	4	Or if a soul swear, pronouncing with his lips to do evil, or to do good, whatsoever it be that a man shall pronounce with an oath, and it be hid from him; when he knoweth of it, then he shall be guilty in one of these.
2836	95	5	And it shall be, when he shall be guilty in one of these things, that he shall confess that he hath sinned in that thing:
2837	95	6	And he shall bring his trespass offering unto the LORD for his sin which he hath sinned, a female from the flock, a lamb or a kid of the goats, for a sin offering; and the priest shall make an atonement for him concerning his sin.
2838	95	7	And if he be not able to bring a lamb, then he shall bring for his trespass, which he hath committed, two turtledoves, or two young pigeons, unto the LORD; one for a sin offering, and the other for a burnt offering.
2839	95	8	And he shall bring them unto the priest, who shall offer that which is for the sin offering first, and wring off his head from his neck, but shall not divide it asunder:
2840	95	9	And he shall sprinkle of the blood of the sin offering upon the side of the altar; and the rest of the blood shall be wrung out at the bottom of the altar: it is a sin offering.
2841	95	10	And he shall offer the second for a burnt offering, according to the manner: and the priest shall make an atonement for him for his sin which he hath sinned, and it shall be forgiven him.
2842	95	11	But if he be not able to bring two turtledoves, or two young pigeons, then he that sinned shall bring for his offering the tenth part of an ephah of fine flour for a sin offering; he shall put no oil upon it, neither shall he put any frankincense thereon: for it is a sin offering.
2843	95	12	Then shall he bring it to the priest, and the priest shall take his handful of it, even a memorial thereof, and burn it on the altar, according to the offerings made by fire unto the LORD: it is a sin offering.
2844	95	13	And the priest shall make an atonement for him as touching his sin that he hath sinned in one of these, and it shall be forgiven him: and the remnant shall be the priest's, as a meat offering.
2845	95	14	And the LORD spake unto Moses, saying,
2846	95	15	If a soul commit a trespass, and sin through ignorance, in the holy things of the LORD; then he shall bring for his trespass unto the LORD a ram without blemish out of the flocks, with thy estimation by shekels of silver, after the shekel of the sanctuary, for a trespass offering:
2847	95	16	And he shall make amends for the harm that he hath done in the holy thing, and shall add the fifth part thereto, and give it unto the priest: and the priest shall make an atonement for him with the ram of the trespass offering, and it shall be forgiven him.
2848	95	17	And if a soul sin, and commit any of these things which are forbidden to be done by the commandments of the LORD; though he wist it not, yet is he guilty, and shall bear his iniquity.
2849	95	18	And he shall bring a ram without blemish out of the flock, with thy estimation, for a trespass offering, unto the priest: and the priest shall make an atonement for him concerning his ignorance wherein he erred and wist it not, and it shall be forgiven him.
2850	95	19	It is a trespass offering: he hath certainly trespassed against the LORD.
2851	96	1	AND the LORD spake unto Moses, saying,
2852	96	2	If a soul sin, and commit a trespass against the LORD, and lie unto his neighbour in that which was delivered him to keep, or in fellowship, or in a thing taken away by violence, or hath deceived his neighbour;
2853	96	3	Or have found that which was lost, and lieth concerning it, and sweareth falsely; in any of all these that a man doeth, sinning therein:
2854	96	4	Then it shall be, because he hath sinned, and is guilty, that he shall restore that which he took violently away, or the thing which he hath deceitfully gotten, or that which was delivered him to keep, or the lost thing which he found,
2855	96	5	Or all that about which he hath sworn falsely; he shall even restore it in the principal, and shall add the fifth part more thereto, and give it unto him to whom it appertaineth, in the day of his trespass offering.
2856	96	6	And he shall bring his trespass offering unto the LORD, a ram without blemish out of the flock, with thy estimation, for a trespass offering, unto the priest:
2857	96	7	And the priest shall make an atonement for him before the LORD: and it shall be forgiven him for any thing of all that he hath done in trespassing therein.
2858	96	8	And the LORD spake unto Moses, saying,
2859	96	9	Command Aaron and his sons, saying, This is the law of the burnt offering: It is the burnt offering, because of the burning upon the altar all night unto the morning, and the fire of the altar shall be burning in it.
2860	96	10	And the priest shall put on his linen garment, and his linen breeches shall he put upon his flesh, and take up the ashes which the fire hath consumed with the burnt offering on the altar, and he shall put them beside the altar.
2861	96	11	And he shall put off his garments, and put on other garments, and carry forth the ashes without the camp unto a clean place.
2862	96	12	And the fire upon the altar shall be burning in it; it shall not be put out: and the priest shall burn wood on it every morning, and lay the burnt offering in order upon it; and he shall burn thereon the fat of the peace offerings.
2863	96	13	The fire shall ever be burning upon the altar; it shall never go out.
2864	96	14	And this is the law of the meat offering: the sons of Aaron shall offer it before the LORD, before the altar.
2865	96	15	And he shall take of it his handful, of the flour of the meat offering, and of the oil thereof, and all the frankincense which is upon the meat offering, and shall burn it upon the altar for a sweet savour, even the memorial of it, unto the LORD.
2866	96	16	And the remainder thereof shall Aaron and his sons eat: with unleavened bread shall it be eaten in the holy place; in the court of the tabernacle of the congregation they shall eat it.
2867	96	17	It shall not be baken with leaven. I have given it unto them for their portion of my offerings made by fire; it is most holy, as is the sin offering, and as the trespass offering.
2868	96	18	All the males among the children of Aaron shall eat of it. It shall be a statute for ever in your generations concerning the offerings of the LORD made by fire: every one that toucheth them shall be holy.
2869	96	19	And the LORD spake unto Moses, saying,
2870	96	20	This is the offering of Aaron and of his sons, which they shall offer unto the LORD in the day when he is anointed; the tenth part of an ephah of fine flour for a meat offering perpetual, half of it in the morning, and half thereof at night.
2871	96	21	In a pan it shall be made with oil; and when it is baken, thou shalt bring it in: and the baken pieces of the meat offering shalt thou offer for a sweet savour unto the LORD.
2872	96	22	And the priest of his sons that is anointed in his stead shall offer it: it is a statute for ever unto the LORD, it shall be wholly burnt.
2873	96	23	For every meat offering for the priest shall be wholly burnt: it shall not be eaten.
2874	96	24	And the LORD spake unto Moses, saying,
2875	96	25	Speak unto Aaron and to his sons, saying, This is the law of the sin offering: In the place where the burnt offering is killed shall the sin offering be killed before the LORD: it is most holy.
2876	96	26	The priest that offereth it for sin shall eat it: in the holy place shall it be eaten, in the court of the tabernacle of the congregation.
2877	96	27	Whatsoever shall touch the flesh thereof shall be holy: and when there is sprinkled of the blood thereof upon any garment, thou shalt wash that whereon it was sprinkled in the holy place.
2878	96	28	But the earthen vessel wherein it is sodden shall be broken: and if it be sodden in a brasen pot, it shall be both scoured, and rinsed in water.
2879	96	29	All the males among the priests shall eat thereof: it is most holy.
2880	96	30	And no sin offering, whereof any of the blood is brought into the tabernacle of the congregation to reconcile withal in the holy place, shall be eaten: it shall be burnt in the fire.
2881	97	1	LIKEWISE this is the law of the trespass offering: it is most holy.
2882	97	2	In the place where they kill the burnt offering shall they kill the trespass offering: and the blood thereof shall he sprinkle round about upon the altar.
2883	97	3	And he shall offer of it all the fat thereof; the rump, and the fat that covereth the inwards,
2884	97	4	And the two kidneys, and the fat that is on them, which is by the flanks, and the caul that is above the liver, with the kidneys, it shall he take away:
2885	97	5	And the priest shall burn them upon the altar for an offering made by fire unto the LORD: it is a trespass offering.
2886	97	6	Every male among the priests shall eat thereof: it shall be eaten in the holy place: it is most holy.
2887	97	7	As the sin offering is, so is the trespass offering: there is one law for them: the priest that maketh atonement therewith shall have it.
2888	97	8	And the priest that offereth any man's burnt offering, even the priest shall have to himself the skin of the burnt offering which he hath offered.
2889	97	9	And all the meat offering that is baken in the oven, and all that is dressed in the fryingpan, and in the pan, shall be the priest's that offereth it.
2890	97	10	And every meat offering, mingled with oil, and dry, shall all the sons of Aaron have, one as much as another.
2891	97	11	And this is the law of the sacrifice of peace offerings, which he shall offer unto the LORD.
2892	97	12	If he offer it for a thanksgiving, then he shall offer with the sacrifice of thanksgiving unleavened cakes mingled with oil, and unleavened wafers anointed with oil, and cakes mingled with oil, of fine flour, fried.
2893	97	13	Besides the cakes, he shall offer for his offering leavened bread with the sacrifice of thanksgiving of his peace offerings.
2894	97	14	And of it he shall offer one out of the whole oblation for an heave offering unto the LORD, and it shall be the priest's that sprinkleth the blood of the peace offerings.
2895	97	15	And the flesh of the sacrifice of his peace offerings for thanksgiving shall be eaten the same day that it is offered; he shall not leave any of it until the morning.
2896	97	16	But if the sacrifice of his offering be a vow, or a voluntary offering, it shall be eaten the same day that he offereth his sacrifice: and on the morrow also the remainder of it shall be eaten:
2897	97	17	But the remainder of the flesh of the sacrifice on the third day shall be burnt with fire.
2898	97	18	And if any of the flesh of the sacrifice of his peace offerings be eaten at all on the third day, it shall not be accepted, neither shall it be imputed unto him that offereth it: it shall be an abomination, and the soul that eateth of it shall bear his iniquity.
2899	97	19	And the flesh that toucheth any unclean thing shall not be eaten; it shall be burnt with fire: and as for the flesh, all that be clean shall eat thereof.
2900	97	20	But the soul that eateth of the flesh of the sacrifice of peace offerings, that pertain unto the LORD, having his uncleanness upon him, even that soul shall be cut off from his people.
2901	97	21	Moreover the soul that shall touch any unclean thing, as the uncleanness of man, or any unclean beast, or any abominable unclean thing, and eat of the flesh of the sacrifice of peace offerings, which pertain unto the LORD, even that soul shall be cut off from his people.
2902	97	22	And the LORD spake unto Moses, saying,
2903	97	23	Speak unto the children of Israel, saying, Ye shall eat no manner of fat, of ox, or of sheep, or of goat.
2904	97	24	And the fat of the beast that dieth of itself, and the fat of that which is torn with beasts, may be used in any other use: but ye shall in no wise eat of it.
2905	97	25	For whosoever eateth the fat of the beast, of which men offer an offering made by fire unto the LORD, even the soul that eateth it shall be cut off from his people.
2906	97	26	Moreover ye shall eat no manner of blood, whether it be of fowl or of beast, in any of your dwellings.
2907	97	27	Whatsoever soul it be that eateth any manner of blood, even that soul shall be cut off from his people.
2908	97	28	And the LORD spake unto Moses, saying,
2909	97	29	Speak unto the children of Israel, saying, He that offereth the sacrifice of his peace offerings unto the LORD shall bring his oblation unto the LORD of the sacrifice of his peace offerings.
2910	97	30	His own hands shall bring the offerings of the LORD made by fire, the fat with the breast, it shall he bring, that the breast may be waved for a wave offering before the LORD.
2911	97	31	And the priest shall burn the fat upon the altar: but the breast shall be Aaron's and his sons'.
2912	97	32	And the right shoulder shall ye give unto the priest for an heave offering of the sacrifices of your peace offerings.
2913	97	33	He among the sons of Aaron, that offereth the blood of the peace offerings, and the fat, shall have the right shoulder for his part.
2914	97	34	For the wave breast and the heave shoulder have I taken of the children of Israel from off the sacrifices of their peace offerings, and have given them unto Aaron the priest and unto his sons by a statute for ever from among the children of Israel.
2915	97	35	This is the portion of the anointing of Aaron, and of the anointing of his sons, out of the offerings of the LORD made by fire, in the day when he presented them to minister unto the LORD in the priest's office;
2916	97	36	Which the LORD commanded to be given them of the children of Israel, in the day that he anointed them, by a statute for ever throughout their generations.
2917	97	37	This is the law of the burnt offering, of the meat offering, and of the sin offering, and of the trespass offering, and of the consecrations, and of the sacrifice of the peace offerings;
2918	97	38	Which the LORD commanded Moses in mount Sinai, in the day that he commanded the children of Israel to offer their oblations unto the LORD, in the wilderness of Sinai.
2919	98	1	AND the LORD spake unto Moses, saying,
2920	98	2	Take Aaron and his sons with him, and the garments, and the anointing oil, and a bullock for the sin offering, and two rams, and a basket of unleavened bread;
2921	98	3	And gather thou all the congregation together unto the door of the tabernacle of the congregation.
2922	98	4	And Moses did as the LORD commanded him; and the assembly was gathered together unto the door of the tabernacle of the congregation.
2923	98	5	And Moses said unto the congregation, This is the thing which the LORD commanded to be done.
2924	98	6	And Moses brought Aaron and his sons, and washed them with water.
2925	98	7	And he put upon him the coat, and girded him with the girdle, and clothed him with the robe, and put the ephod upon him, and he girded him with the curious girdle of the ephod, and bound it unto him therewith.
2926	98	8	And he put the breastplate upon him: also he put in the breastplate the Urim and the Thummim.
2927	98	9	And he put the mitre upon his head; also upon the mitre, even upon his forefront, did he put the golden plate, the holy crown; as the LORD commanded Moses.
2928	98	10	And Moses took the anointing oil, and anointed the tabernacle and all that was therein, and sanctified them.
2929	98	11	And he sprinkled thereof upon the altar seven times, and anointed the altar and all his vessels, both the laver and his foot, to sanctify them.
2930	98	12	And he poured of the anointing oil upon Aaron's head, and anointed him, to sanctify him.
2931	98	13	And Moses brought Aaron's sons, and put coats upon them, and girded them with girdles, and put bonnets upon them; as the LORD commanded Moses.
2932	98	14	And he brought the bullock for the sin offering: and Aaron and his sons laid their hands upon the head of the bullock for the sin offering.
2933	98	15	And he slew it; and Moses took the blood, and put it upon the horns of the altar round about with his finger, and purified the altar, and poured the blood at the bottom of the altar, and sanctified it, to make reconciliation upon it.
2934	98	16	And he took all the fat that was upon the inwards, and the caul above the liver, and the two kidneys, and their fat, and Moses burned it upon the altar.
2935	98	17	But the bullock, and his hide, his flesh, and his dung, he burnt with fire without the camp; as the LORD commanded Moses.
2936	98	18	And he brought the ram for the burnt offering: and Aaron and his sons laid their hands upon the head of the ram.
2937	98	19	And he killed it; and Moses sprinkled the blood upon the altar round about.
2938	98	20	And he cut the ram into pieces; and Moses burnt the head, and the pieces, and the fat.
2939	98	21	And he washed the inwards and the legs in water; and Moses burnt the whole ram upon the altar: it was a burnt sacrifice for a sweet savour, and an offering made by fire unto the LORD; as the LORD commanded Moses.
2940	98	22	And he brought the other ram, the ram of consecration: and Aaron and his sons laid their hands upon the head of the ram.
2941	98	23	And he slew it; and Moses took of the blood of it, and put it upon the tip of Aaron's right ear, and upon the thumb of his right hand, and upon the great toe of his right foot.
2942	98	24	And he brought Aaron's sons, and Moses put of the blood upon the tip of their right ear, and upon the thumbs of their right hands, and upon the great toes of their right feet: and Moses sprinkled the blood upon the altar round about.
2943	98	25	And he took the fat, and the rump, and all the fat that was upon the inwards, and the caul above the liver, and the two kidneys, and their fat, and the right shoulder:
2944	98	26	And out of the basket of unleavened bread, that was before the LORD, he took one unleavened cake, and a cake of oiled bread, and one wafer, and put them on the fat, and upon the right shoulder:
2945	98	27	And he put all upon Aaron's hands, and upon his sons' hands, and waved them for a wave offering before the LORD.
2946	98	28	And Moses took them from off their hands, and burnt them on the altar upon the burnt offering: they were consecrations for a sweet savour: it is an offering made by fire unto the LORD.
2947	98	29	And Moses took the breast, and waved it for a wave offering before the LORD: for of the ram of consecration it was Moses' part; as the LORD commanded Moses.
2948	98	30	And Moses took of the anointing oil, and of the blood which was upon the altar, and sprinkled it upon Aaron, and upon his garments, and upon his sons, and upon his sons' garments with him; and sanctified Aaron, and his garments, and his sons, and his sons' garments with him.
2949	98	31	And Moses said unto Aaron and to his sons, Boil the flesh at the door of the tabernacle of the congregation: and there eat it with the bread that is in the basket of consecrations, as I commanded, saying, Aaron and his sons shall eat it.
2950	98	32	And that which remaineth of the flesh and of the bread shall ye burn with fire.
2951	98	33	And ye shall not go out of the door of the tabernacle of the congregation in seven days, until the days of your consecration be at an end: for seven days shall he consecrate you.
2952	98	34	As he hath done this day, so the LORD hath commanded to do, to make an atonement for you.
2953	98	35	Therefore shall ye abide at the door of the tabernacle of the congregation day and night seven days, and keep the charge of the LORD, that ye die not: for so I am commanded.
2954	98	36	So Aaron and his sons did all things which the LORD commanded by the hand of Moses.
2955	99	1	AND it came to pass on the eighth day, that Moses called Aaron and his sons, and the elders of Israel;
2956	99	2	And he said unto Aaron, Take thee a young calf for a sin offering, and a ram for a burnt offering, without blemish, and offer them before the LORD.
2957	99	3	And unto the children of Israel thou shalt speak, saying, Take ye a kid of the goats for a sin offering; and a calf and a lamb, both of the first year, without blemish, for a burnt offering;
2958	99	4	Also a bullock and a ram for peace offerings, to sacrifice before the LORD; and a meat offering mingled with oil: for to day the LORD will appear unto you.
2959	99	5	And they brought that which Moses commanded before the tabernacle of the congregation: and all the congregation drew near and stood before the LORD.
2960	99	6	And Moses said, This is the thing which the LORD commanded that ye should do: and the glory of the LORD shall appear unto you.
2961	99	7	And Moses said unto Aaron, Go unto the altar, and offer thy sin offering, and thy burnt offering, and make an atonement for thyself, and for the people: and offer the offering of the people, and make an atonement for them; as the LORD commanded.
2962	99	8	Aaron therefore went unto the altar, and slew the calf of the sin offering, which was for himself.
2963	99	9	And the sons of Aaron brought the blood unto him: and he dipped his finger in the blood, and put it upon the horns of the altar, and poured out the blood at the bottom of the altar:
2964	99	10	But the fat, and the kidneys, and the caul above the liver of the sin offering, he burnt upon the altar; as the LORD commanded Moses.
2965	99	11	And the flesh and the hide he burnt with fire without the camp.
2966	99	12	And he slew the burnt offering; and Aaron's sons presented unto him the blood, which he sprinkled round about upon the altar.
2967	99	13	And they presented the burnt offering unto him, with the pieces thereof, and the head: and he burnt them upon the altar.
2968	99	14	And he did wash the inwards and the legs, and burnt them upon the burnt offering on the altar.
2969	99	15	And he brought the people's offering, and took the goat, which was the sin offering for the people, and slew it, and offered it for sin, as the first.
2970	99	16	And he brought the burnt offering, and offered it according to the manner.
2971	99	17	And he brought the meat offering, and took an handful thereof, and burnt it upon the altar, beside the burnt sacrifice of the morning.
2972	99	18	He slew also the bullock and the ram for a sacrifice of peace offerings, which was for the people: and Aaron's sons presented unto him the blood, which he sprinkled upon the altar round about,
2973	99	19	And the fat of the bullock and of the ram, the rump, and that which covereth the inwards, and the kidneys, and the caul above the liver:
2974	99	20	And they put the fat upon the breasts, and he burnt the fat upon the altar:
2975	99	21	And the breasts and the right shoulder Aaron waved for a wave offering before the LORD; as Moses commanded.
2976	99	22	And Aaron lifted up his hand toward the people, and blessed them, and came down from offering of the sin offering, and the burnt offering, and peace offerings.
2977	99	23	And Moses and Aaron went into the tabernacle of the congregation, and came out, and blessed the people: and the glory of the LORD appeared unto all the people.
2978	99	24	And there came a fire out from before the LORD, and consumed upon the altar the burnt offering and the fat: which when all the people saw, they shouted, and fell on their faces.
2979	100	1	AND Nadab and Abihu, the sons of Aaron, took either of them his censer, and put fire therein, and put incense thereon, and offered strange fire before the LORD, which he commanded them not.
2980	100	2	And there went out fire from the LORD, and devoured them, and they died before the LORD.
2981	100	3	Then Moses said unto Aaron, This is it that the LORD spake, saying, I will be sanctified in them that come nigh me, and before all the people I will be glorified. And Aaron held his peace.
2982	100	4	And Moses called Mishael and Elzaphan, the sons of Uzziel the uncle of Aaron, and said unto them, Come near, carry your brethren from before the sanctuary out of the camp.
2983	100	5	So they went near, and carried them in their coats out of the camp; as Moses had said.
2984	100	6	And Moses said unto Aaron, and unto Eleazar and unto Ithamar, his sons, Uncover not your heads, neither rend your clothes; lest ye die, and lest wrath come upon all the people: but let your brethren, the whole house of Israel, bewail the burning which the LORD hath kindled.
2985	100	7	And ye shall not go out from the door of the tabernacle of the congregation, lest ye die: for the anointing oil of the LORD is upon you. And they did according to the word of Moses.
2986	100	8	And the LORD spake unto Aaron, saying,
2987	100	9	Do not drink wine nor strong drink, thou, nor thy sons with thee, when ye go into the tabernacle of the congregation, lest ye die: it shall be a statute for ever throughout your generations:
2988	100	10	And that ye may put difference between holy and unholy, and between unclean and clean;
2989	100	11	And that ye may teach the children of Israel all the statutes which the LORD hath spoken unto them by the hand of Moses.
2990	100	12	And Moses spake unto Aaron, and unto Eleazar and unto Ithamar, his sons that were left, Take the meat offering that remaineth of the offerings of the LORD made by fire, and eat it without leaven beside the altar: for it is most holy:
2991	100	13	And ye shall eat it in the holy place, because it is thy due, and thy sons' due, of the sacrifices of the LORD made by fire: for so I am commanded.
2992	100	14	And the wave breast and heave shoulder shall ye eat in a clean place; thou, and thy sons, and thy daughters with thee: for they be thy due, and thy sons' due, which are given out of the sacrifices of peace offerings of the children of Israel.
2993	100	15	The heave shoulder and the wave breast shall they bring with the offerings made by fire of the fat, to wave it for a wave offering before the LORD; and it shall be thine, and thy sons' with thee, by a statute for ever; as the LORD hath commanded.
2994	100	16	And Moses diligently sought the goat of the sin offering, and, behold, it was burnt: and he was angry with Eleazar and Ithamar, the sons of Aaron which were left alive, saying,
2995	100	17	Wherefore have ye not eaten the sin offering in the holy place, seeing it is most holy, and God hath given it you to bear the iniquity of the congregation, to make atonement for them before the LORD?
2996	100	18	Behold, the blood of it was not brought in within the holy place: ye should indeed have eaten it in the holy place, as I commanded.
2997	100	19	And Aaron said unto Moses, Behold, this day have they offered their sin offering and their burnt offering before the LORD; and such things have befallen me: and if I had eaten the sin offering to day, should it have been accepted in the sight of the LORD?
2998	100	20	And when Moses heard that, he was content.
2999	101	1	AND the LORD spake unto Moses and to Aaron, saying unto them,
3000	101	2	Speak unto the children of Israel, saying, These are the beasts which ye shall eat among all the beasts that are on the earth.
3001	101	3	Whatsoever parteth the hoof, and is clovenfooted, and cheweth the cud, among the beasts, that shall ye eat.
3002	101	4	Nevertheless these shall ye not eat of them that chew the cud, or of them that divide the hoof: as the camel, because he cheweth the cud, but divideth not the hoof; he is unclean unto you.
3003	101	5	And the coney, because he cheweth the cud, but divideth not the hoof; he is unclean unto you.
3004	101	6	And the hare, because he cheweth the cud, but divideth not the hoof; he is unclean unto you.
3005	101	7	And the swine, though he divide the hoof, and be clovenfooted, yet he cheweth not the cud; he is unclean to you.
3006	101	8	Of their flesh shall ye not eat, and their carcase shall ye not touch; they are unclean to you.
3007	101	9	These shall ye eat of all that are in the waters: whatsoever hath fins and scales in the waters, in the seas, and in the rivers, them shall ye eat.
3008	101	10	And all that have not fins and scales in the seas, and in the rivers, of all that move in the waters, and of any living thing which is in the waters, they shall be an abomination unto you:
3009	101	11	They shall be even an abomination unto you; ye shall not eat of their flesh, but ye shall have their carcases in abomination.
3010	101	12	Whatsoever hath no fins nor scales in the waters, that shall be an abomination unto you.
3011	101	13	And these are they which ye shall have in abomination among the fowls; they shall not be eaten, they are an abomination: the eagle, and the ossifrage, and the ospray,
3012	101	14	And the vulture, and the kite after his kind;
3013	101	15	Every raven after his kind;
3014	101	16	And the owl, and the night hawk, and the cuckow, and the hawk after his kind,
3015	101	17	And the little owl, and the cormorant, and the great owl,
3016	101	18	And the swan, and the pelican, and the gier eagle,
3017	101	19	And the stork, the heron after her kind, and the lapwing, and the bat.
3018	101	20	All fowls that creep, going upon all four, shall be an abomination unto you.
3019	101	21	Yet these may ye eat of every flying creeping thing that goeth upon all four, which have legs above their feet, to leap withal upon the earth;
3020	101	22	Even these of them ye may eat; the locust after his kind, and the bald locust after his kind, and the beetle after his kind, and the grasshopper after his kind.
3021	101	23	But all other flying creeping things, which have four feet, shall be an abomination unto you.
3022	101	24	And for these ye shall be unclean: whosoever toucheth the carcase of them shall be unclean until the even.
3023	101	25	And whosoever beareth ought of the carcase of them shall wash his clothes, and be unclean until the even.
3024	101	26	The carcases of every beast which divideth the hoof, and is not clovenfooted, nor cheweth the cud, are unclean unto you: every one that toucheth them shall be unclean.
3025	101	27	And whatsoever goeth upon his paws, among all manner of beasts that go on all four, those are unclean unto you: whoso toucheth their carcase shall be unclean until the even.
3026	101	28	And he that beareth the carcase of them shall wash his clothes, and be unclean until the even: they are unclean unto you.
3027	101	29	These also shall be unclean unto you among the creeping things that creep upon the earth; the weasel, and the mouse, and the tortoise after his kind,
3028	101	30	And the ferret, and the chameleon, and the lizard, and the snail, and the mole.
3029	101	31	These are unclean to you among all that creep: whosoever doth touch them, when they be dead, shall be unclean until the even.
3030	101	32	And upon whatsoever any of them, when they are dead, doth fall, it shall be unclean; whether it be any vessel of wood, or raiment, or skin, or sack, whatsoever vessel it be, wherein any work is done, it must be put into water, and it shall be unclean until the even; so it shall be cleansed.
3031	101	33	And every earthen vessel, whereinto any of them falleth, whatsoever is in it shall be unclean; and ye shall break it.
3032	101	34	Of all meat which may be eaten, that on which such water cometh shall be unclean: and all drink that may be drunk in every such vessel shall be unclean.
3033	101	35	And every thing whereupon any part of their carcase falleth shall be unclean; whether it be oven, or ranges for pots, they shall be broken down: for they are unclean, and shall be unclean unto you.
3034	101	36	Nevertheless a fountain or pit, wherein there is plenty of water, shall be clean: but that which toucheth their carcase shall be unclean.
3035	101	37	And if any part of their carcase fall upon any sowing seed which is to be sown, it shall be clean.
3036	101	38	But if any water be put upon the seed, and any part of their carcase fall thereon, it shall be unclean unto you.
3037	101	39	And if any beast, of which ye may eat, die; he that toucheth the carcase thereof shall be unclean until the even.
3038	101	40	And he that eateth of the carcase of it shall wash his clothes, and be unclean until the even: he also that beareth the carcase of it shall wash his clothes, and be unclean until the even.
3039	101	41	And every creeping thing that creepeth upon the earth shall be an abomination; it shall not be eaten.
3040	101	42	Whatsoever goeth upon the belly, and whatsoever goeth upon all four, or whatsoever hath more feet among all creeping things that creep upon the earth, them ye shall not eat; for they are an abomination.
3041	101	43	Ye shall not make yourselves abominable with any creeping thing that creepeth, neither shall ye make yourselves unclean with them, that ye should be defiled thereby.
3042	101	44	For I am the LORD your God: ye shall therefore sanctify yourselves, and ye shall be holy; for I am holy: neither shall ye defile yourselves with any manner of creeping thing that creepeth upon the earth.
3043	101	45	For I am the LORD that bringeth you up out of the land of Egypt, to be your God: ye shall therefore be holy, for I am holy.
3044	101	46	This is the law of the beasts, and of the fowl, and of every living creature that moveth in the waters, and of every creature that creepeth upon the earth:
3045	101	47	To make a difference between the unclean and the clean, and between the beast that may be eaten and the beast that may not be eaten.
3046	102	1	AND the LORD spake unto Moses, saying,
3047	102	2	Speak unto the children of Israel, saying, If a woman have conceived seed, and born a man child: then she shall be unclean seven days; according to the days of the separation for her infirmity shall she be unclean.
3048	102	3	And in the eighth day the flesh of his foreskin shall be circumcised.
3049	102	4	And she shall then continue in the blood of her purifying three and thirty days; she shall touch no hallowed thing, nor come into the sanctuary, until the days of her purifying be fulfilled.
3050	102	5	But if she bear a maid child, then she shall be unclean two weeks, as in her separation: and she shall continue in the blood of her purifying threescore and six days.
3051	102	6	And when the days of her purifying are fulfilled, for a son, or for a daughter, she shall bring a lamb of the first year for a burnt offering, and a young pigeon, or a turtledove, for a sin offering, unto the door of the tabernacle of the congregation, unto the priest:
3052	102	7	Who shall offer it before the LORD, and make an atonement for her; and she shall be cleansed from the issue of her blood. This is the law for her that hath born a male or a female.
3053	102	8	And if she be not able to bring a lamb, then she shall bring two turtles, or two young pigeons; the one for the burnt offering, and the other for a sin offering: and the priest shall make an atonement for her, and she shall be clean.
3054	103	1	AND the LORD spake unto Moses and Aaron, saying,
3055	103	2	When a man shall have in the skin of his flesh a rising, a scab, or bright spot, and it be in the skin of his flesh like the plague of leprosy; then he shall be brought unto Aaron the priest, or unto one of his sons the priests:
3056	103	3	And the priest shall look on the plague in the skin of the flesh: and when the hair in the plague is turned white, and the plague in sight be deeper than the skin of his flesh, it is a plague of leprosy: and the priest shall look on him, and pronounce him unclean.
3057	103	4	If the bright spot be white in the skin of his flesh, and in sight be not deeper than the skin, and the hair thereof be not turned white; then the priest shall shut up him that hath the plague seven days:
3058	103	5	And the priest shall look on him the seventh day: and, behold, if the plague in his sight be at a stay, and the plague spread not in the skin; then the priest shall shut him up seven days more:
3059	103	6	And the priest shall look on him again the seventh day: and, behold, if the plague be somewhat dark, and the plague spread not in the skin, the priest shall pronounce him clean: it is but a scab: and he shall wash his clothes, and be clean.
3060	103	7	But if the scab spread much abroad in the skin, after that he hath been seen of the priest for his cleansing, he shall be seen of the priest again:
3061	103	8	And if the priest see that, behold, the scab spreadeth in the skin, then the priest shall pronounce him unclean: it is a leprosy.
3062	103	9	When the plague of leprosy is in a man, then he shall be brought unto the priest;
3063	103	10	And the priest shall see him: and, behold, if the rising be white in the skin, and it have turned the hair white, and there be quick raw flesh in the rising;
3064	103	11	It is an old leprosy in the skin of his flesh, and the priest shall pronounce him unclean, and shall not shut him up: for he is unclean.
3065	103	12	And if a leprosy break out abroad in the skin, and the leprosy cover all the skin of him that hath the plague from his head even to his foot, wheresoever the priest looketh;
3066	103	13	Then the priest shall consider: and, behold, if the leprosy have covered all his flesh, he shall pronounce him clean that hath the plague: it is all turned white: he is clean.
3067	103	14	But when raw flesh appeareth in him, he shall be unclean.
3068	103	15	And the priest shall see the raw flesh, and pronounce him to be unclean: for the raw flesh is unclean: it is a leprosy.
3069	103	16	Or if the raw flesh turn again, and be changed unto white, he shall come unto the priest;
3070	103	17	And the priest shall see him: and, behold, if the plague be turned into white; then the priest shall pronounce him clean that hath the plague: he is clean.
3071	103	18	The flesh also, in which, even in the skin thereof, was a boil, and is healed,
3072	103	19	And in the place of the boil there be a white rising, or a bright spot, white, and somewhat reddish, and it be shewed to the priest;
3073	103	20	And if, when the priest seeth it, behold, it be in sight lower than the skin, and the hair thereof be turned white; the priest shall pronounce him unclean: it is a plague of leprosy broken out of the boil.
3074	103	21	But if the priest look on it, and, behold, there be no white hairs therein, and if it be not lower than the skin, but be somewhat dark; then the priest shall shut him up seven days:
3075	103	22	And if it spread much abroad in the skin, then the priest shall pronounce him unclean: it is a plague.
3076	103	23	But if the bright spot stay in his place, and spread not, it is a burning boil; and the priest shall pronounce him clean.
3077	103	24	Or if there be any flesh, in the skin whereof there is a hot burning, and the quick flesh that burneth have a white bright spot, somewhat reddish, or white;
3078	103	25	Then the priest shall look upon it: and, behold, if the hair in the bright spot be turned white, and it be in sight deeper than the skin; it is a leprosy broken out of the burning: wherefore the priest shall pronounce him unclean: it is the plague of leprosy.
3079	103	26	But if the priest look on it, and, behold, there be no white hair in the bright spot, and it be no lower than the other skin, but be somewhat dark; then the priest shall shut him up seven days:
3080	103	27	And the priest shall look upon him the seventh day: and if it be spread much abroad in the skin, then the priest shall pronounce him unclean: it is the plague of leprosy.
3081	103	28	And if the bright spot stay in his place, and spread not in the skin, but it be somewhat dark; it is a rising of the burning, and the priest shall pronounce him clean: for it is an inflammation of the burning.
3082	103	29	If a man or woman have a plague upon the head or the beard;
3083	103	30	Then the priest shall see the plague: and, behold, if it be in sight deeper than the skin; and there be in it a yellow thin hair; then the priest shall pronounce him unclean: it is a dry scall, even a leprosy upon the head or beard.
3084	103	31	And if the priest look on the plague of the scall, and, behold, it be not in sight deeper than the skin, and that there is no black hair in it; then the priest shall shut up him that hath the plague of the scall seven days:
3085	103	32	And in the seventh day the priest shall look on the plague: and, behold, if the scall spread not, and there be in it no yellow hair, and the scall be not in sight deeper than the skin;
3086	103	33	He shall be shaven, but the scall shall he not shave; and the priest shall shut up him that hath the scall seven days more:
3087	103	34	And in the seventh day the priest shall look on the scall: and, behold, if the scall be not spread in the skin, nor be in sight deeper than the skin; then the priest shall pronounce him clean: and he shall wash his clothes, and be clean.
3088	103	35	But if the scall spread much in the skin after his cleansing;
3089	103	36	Then the priest shall look on him: and, behold, if the scall be spread in the skin, the priest shall not seek for yellow hair; he is unclean.
3090	103	37	But if the scall be in his sight at a stay, and that there is black hair grown up therein; the scall is healed, he is clean: and the priest shall pronounce him clean.
3091	103	38	If a man also or a woman have in the skin of their flesh bright spots, even white bright spots;
3092	103	39	Then the priest shall look: and, behold, if the bright spots in the skin of their flesh be darkish white; it is a freckled spot that groweth in the skin; he is clean.
3093	103	40	And the man whose hair is fallen off his head, he is bald; yet is he clean.
3094	103	41	And he that hath his hair fallen off from the part of his head toward his face, he is forehead bald: yet is he clean.
3095	103	42	And if there be in the bald head, or bald forehead, a white reddish sore; it is a leprosy sprung up in his bald head, or his bald forehead.
3096	103	43	Then the priest shall look upon it: and, behold, if the rising of the sore be white reddish in his bald head, or in his bald forehead, as the leprosy appeareth in the skin of the flesh;
3097	103	44	He is a leprous man, he is unclean: the priest shall pronounce him utterly unclean; his plague is in his head.
3098	103	45	And the leper in whom the plague is, his clothes shall be rent, and his head bare, and he shall put a covering upon his upper lip, and shall cry, Unclean, unclean.
3099	103	46	All the days wherein the plague shall be in him he shall be defiled; he is unclean: he shall dwell alone; without the camp shall his habitation be.
3100	103	47	The garment also that the plague of leprosy is in, whether it be a woollen garment, or a linen garment;
3101	103	48	Whether it be in the warp, or woof; of linen, or of woollen; whether in a skin, or in any thing made of skin;
3102	103	49	And if the plague be greenish or reddish in the garment, or in the skin, either in the warp, or in the woof, or in any thing of skin; it is a plague of leprosy, and shall be shewed unto the priest:
3103	103	50	And the priest shall look upon the plague, and shut up it that hath the plague seven days:
3104	103	51	And he shall look on the plague on the seventh day: if the plague be spread in the garment, either in the warp, or in the woof, or in a skin, or in any work that is made of skin; the plague is a fretting leprosy; it is unclean.
3105	103	52	He shall therefore burn that garment, whether warp or woof, in woollen or in linen, or any thing of skin, wherein the plague is: for it is a fretting leprosy; it shall be burnt in the fire.
3106	103	53	And if the priest shall look, and, behold, the plague be not spread in the garment, either in the warp, or in the woof, or in any thing of skin;
3107	103	54	Then the priest shall command that they wash the thing wherein the plague is, and he shall shut it up seven days more:
3108	103	55	And the priest shall look on the plague, after that it is washed: and, behold, if the plague have not changed his colour, and the plague be not spread; it is unclean; thou shalt burn it in the fire; it is fret inward, whether it be bare within or without.
3109	103	56	And if the priest look, and, behold, the plague be somewhat dark after the washing of it; then he shall rend it out of the garment, or out of the skin, or out of the warp, or out of the woof:
3110	103	57	And if it appear still in the garment, either in the warp, or in the woof, or in any thing of skin; it is a spreading plague: thou shalt burn that wherein the plague is with fire.
3111	103	58	And the garment, either warp, or woof, or whatsoever thing of skin it be, which thou shalt wash, if the plague be departed from them, then it shall be washed the second time, and shall be clean.
3112	103	59	This is the law of the plague of leprosy in a garment of woollen or linen, either in the warp, or woof, or any thing of skins, to pronounce it clean, or to pronounce it unclean.
3113	104	1	AND the LORD spake unto Moses, saying,
3114	104	2	This shall be the law of the leper in the day of his cleansing: He shall be brought unto the priest:
3115	104	3	And the priest shall go forth out of the camp; and the priest shall look, and, behold, if the plague of leprosy be healed in the leper;
3116	104	4	Then shall the priest command to take for him that is to be cleansed two birds alive and clean, and cedar wood, and scarlet, and hyssop:
3117	104	5	And the priest shall command that one of the birds be killed in an earthen vessel over running water:
3118	104	6	As for the living bird, he shall take it, and the cedar wood, and the scarlet, and the hyssop, and shall dip them and the living bird in the blood of the bird that was killed over the running water:
3119	104	7	And he shall sprinkle upon him that is to be cleansed from the leprosy seven times, and shall pronounce him clean, and shall let the living bird loose into the open field.
3120	104	8	And he that is to be cleansed shall wash his clothes, and shave off all his hair, and wash himself in water, that he may be clean: and after that he shall come into the camp, and shall tarry abroad out of his tent seven days.
3121	104	9	But it shall be on the seventh day, that he shall shave all his hair off his head and his beard and his eyebrows, even all his hair he shall shave off: and he shall wash his clothes, also he shall wash his flesh in water, and he shall be clean.
3122	104	10	And on the eighth day he shall take two he lambs without blemish, and one ewe lamb of the first year without blemish, and three tenth deals of fine flour for a meat offering, mingled with oil, and one log of oil.
3123	104	11	And the priest that maketh him clean shall present the man that is to be made clean, and those things, before the LORD, at the door of the tabernacle of the congregation:
3124	104	12	And the priest shall take one he lamb, and offer him for a trespass offering, and the log of oil, and wave them for a wave offering before the LORD:
3125	104	13	And he shall slay the lamb in the place where he shall kill the sin offering and the burnt offering, in the holy place: for as the sin offering is the priest's, so is the trespass offering: it is most holy:
3126	104	14	And the priest shall take some of the blood of the trespass offering, and the priest shall put it upon the tip of the right ear of him that is to be cleansed, and upon the thumb of his right hand, and upon the great toe of his right foot:
3127	104	15	And the priest shall take some of the log of oil, and pour it into the palm of his own left hand:
3128	104	16	And the priest shall dip his right finger in the oil that is in his left hand, and shall sprinkle of the oil with his finger seven times before the LORD:
3129	104	17	And of the rest of the oil that is in his hand shall the priest put upon the tip of the right ear of him that is to be cleansed, and upon the thumb of his right hand, and upon the great toe of his right foot, upon the blood of the trespass offering:
3130	104	18	And the remnant of the oil that is in the priest's hand he shall pour upon the head of him that is to be cleansed: and the priest shall make an atonement for him before the LORD.
3131	104	19	And the priest shall offer the sin offering, and make an atonement for him that is to be cleansed from his uncleanness; and afterward he shall kill the burnt offering:
3132	104	20	And the priest shall offer the burnt offering and the meat offering upon the altar: and the priest shall make an atonement for him, and he shall be clean.
3133	104	21	And if he be poor, and cannot get so much; then he shall take one lamb for a trespass offering to be waved, to make an atonement for him, and one tenth deal of fine flour mingled with oil for a meat offering, and a log of oil;
3134	104	22	And two turtledoves, or two young pigeons, such as he is able to get; and the one shall be a sin offering, and the other a burnt offering.
3135	104	23	And he shall bring them on the eighth day for his cleansing unto the priest, unto the door of the tabernacle of the congregation, before the LORD.
3136	104	24	And the priest shall take the lamb of the trespass offering, and the log of oil, and the priest shall wave them for a wave offering before the LORD:
3137	104	25	And he shall kill the lamb of the trespass offering, and the priest shall take some of the blood of the trespass offering, and put it upon the tip of the right ear of him that is to be cleansed, and upon the thumb of his right hand, and upon the great toe of his right foot:
3138	104	26	And the priest shall pour of the oil into the palm of his own left hand:
3139	104	27	And the priest shall sprinkle with his right finger some of the oil that is in his left hand seven times before the LORD:
3140	104	28	And the priest shall put of the oil that is in his hand upon the tip of the right ear of him that is to be cleansed, and upon the thumb of his right hand, and upon the great toe of his right foot, upon the place of the blood of the trespass offering:
3141	104	29	And the rest of the oil that is in the priest's hand he shall put upon the head of him that is to be cleansed, to make an atonement for him before the LORD.
3142	104	30	And he shall offer the one of the turtledoves, or of the young pigeons, such as he can get;
3143	104	31	Even such as he is able to get, the one for a sin offering, and the other for a burnt offering, with the meat offering: and the priest shall make an atonement for him that is to be cleansed before the LORD.
3144	104	32	This is the law of him in whom is the plague of leprosy, whose hand is not able to get that which pertaineth to his cleansing.
3145	104	33	And the LORD spake unto Moses and unto Aaron, saying,
3146	104	34	When ye be come into the land of Canaan, which I give to you for a possession, and I put the plague of leprosy in a house of the land of your possession;
3147	104	35	And he that owneth the house shall come and tell the priest, saying, It seemeth to me there is as it were a plague in the house:
3148	104	36	Then the priest shall command that they empty the house, before the priest go into it to see the plague, that all that is in the house be not made unclean: and afterward the priest shall go in to see the house:
3149	104	37	And he shall look on the plague, and, behold, if the plague be in the walls of the house with hollow strakes, greenish or reddish, which in sight are lower than the wall;
3150	104	38	Then the priest shall go out of the house to the door of the house, and shut up the house seven days:
3151	104	39	And the priest shall come again the seventh day, and shall look: and, behold, if the plague be spread in the walls of the house;
3152	104	40	Then the priest shall command that they take away the stones in which the plague is, and they shall cast them into an unclean place without the city:
3153	104	41	And he shall cause the house to be scraped within round about, and they shall pour out the dust that they scrape off without the city into an unclean place:
3154	104	42	And they shall take other stones, and put them in the place of those stones; and he shall take other morter, and shall plaister the house.
3155	104	43	And if the plague come again, and break out in the house, after that he hath taken away the stones, and after he hath scraped the house, and after it is plaistered;
3156	104	44	Then the priest shall come and look, and, behold, if the plague be spread in the house, it is a fretting leprosy in the house: it is unclean.
3157	104	45	And he shall break down the house, the stones of it, and the timber thereof, and all the morter of the house; and he shall carry them forth out of the city into an unclean place.
3158	104	46	Moreover he that goeth into the house all the while that it is shut up shall be unclean until the even.
3159	104	47	And he that lieth in the house shall wash his clothes; and he that eateth in the house shall wash his clothes.
3160	104	48	And if the priest shall come in, and look upon it, and, behold, the plague hath not spread in the house, after the house was plaistered: then the priest shall pronounce the house clean, because the plague is healed.
3161	104	49	And he shall take to cleanse the house two birds, and cedar wood, and scarlet, and hyssop:
3162	104	50	And he shall kill the one of the birds in an earthen vessel over running water:
3163	104	51	And he shall take the cedar wood, and the hyssop, and the scarlet, and the living bird, and dip them in the blood of the slain bird, and in the running water, and sprinkle the house seven times:
3164	104	52	And he shall cleanse the house with the blood of the bird, and with the running water, and with the living bird, and with the cedar wood, and with the hyssop, and with the scarlet:
3165	104	53	But he shall let go the living bird out of the city into the open fields, and make an atonement for the house: and it shall be clean.
3166	104	54	This is the law for all manner of plague of leprosy, and scall,
3167	104	55	And for the leprosy of a garment, and of a house,
3168	104	56	And for a rising, and for a scab, and for a bright spot:
3169	104	57	To teach when it is unclean, and when it is clean: this is the law of leprosy.
3170	105	1	AND the LORD spake unto Moses and to Aaron, saying,
3171	105	2	Speak unto the children of Israel, and say unto them, When any man hath a running issue out of his flesh, because of his issue he is unclean.
3172	105	3	And this shall be his uncleanness in his issue: whether his flesh run with his issue, or his flesh be stopped from his issue, it is his uncleanness.
3173	105	4	Every bed, whereon he lieth that hath the issue, is unclean: and every thing, whereon he sitteth, shall be unclean.
3174	105	5	And whosoever toucheth his bed shall wash his clothes, and bathe himself in water, and be unclean until the even.
3175	105	6	And he that sitteth on any thing whereon he sat that hath the issue shall wash his clothes, and bathe himself in water, and be unclean until the even.
3176	105	7	And he that toucheth the flesh of him that hath the issue shall wash his clothes, and bathe himself in water, and be unclean until the even.
3177	105	8	And if he that hath the issue spit upon him that is clean; then he shall wash his clothes, and bathe himself in water, and be unclean until the even.
3178	105	9	And what saddle soever he rideth upon that hath the issue shall be unclean.
3179	105	10	And whosoever toucheth any thing that was under him shall be unclean until the even: and he that beareth any of those things shall wash his clothes, and bathe himself in water, and be unclean until the even.
3180	105	11	And whomsoever he toucheth that hath the issue, and hath not rinsed his hands in water, he shall wash his clothes, and bathe himself in water, and be unclean until the even.
3181	105	12	And the vessel of earth, that he toucheth which hath the issue, shall be broken: and every vessel of wood shall be rinsed in water.
3182	105	13	And when he that hath an issue is cleansed of his issue; then he shall number to himself seven days for his cleansing, and wash his clothes, and bathe his flesh in running water, and shall be clean.
3183	105	14	And on the eighth day he shall take to him two turtledoves, or two young pigeons, and come before the LORD unto the door of the tabernacle of the congregation, and give them unto the priest:
3184	105	15	And the priest shall offer them, the one for a sin offering, and the other for a burnt offering; and the priest shall make an atonement for him before the LORD for his issue.
3185	105	16	And if any man's seed of copulation go out from him, then he shall wash all his flesh in water, and be unclean until the even.
3186	105	17	And every garment, and every skin, whereon is the seed of copulation, shall be washed with water, and be unclean until the even.
3187	105	18	The woman also with whom man shall lie with seed of copulation, they shall both bathe themselves in water, and be unclean until the even.
3188	105	19	And if a woman have an issue, and her issue in her flesh be blood, she shall be put apart seven days: and whosoever toucheth her shall be unclean until the even.
3189	105	20	And every thing that she lieth upon in her separation shall be unclean: every thing also that she sitteth upon shall be unclean.
3190	105	21	And whosoever toucheth her bed shall wash his clothes, and bathe himself in water, and be unclean until the even.
3191	105	22	And whosoever toucheth any thing that she sat upon shall wash his clothes, and bathe himself in water, and be unclean until the even.
3192	105	23	And if it be on her bed, or on any thing whereon she sitteth, when he toucheth it, he shall be unclean until the even.
3193	105	24	And if any man lie with her at all, and her flowers be upon him, he shall be unclean seven days; and all the bed whereon he lieth shall be unclean.
3194	105	25	And if a woman have an issue of her blood many days out of the time of her separation, or if it run beyond the time of her separation; all the days of the issue of her uncleanness shall be as the days of her separation: she shall be unclean.
3195	105	26	Every bed whereon she lieth all the days of her issue shall be unto her as the bed of her separation: and whatsoever she sitteth upon shall be unclean, as the uncleanness of her separation.
3196	105	27	And whosoever toucheth those things shall be unclean, and shall wash his clothes, and bathe himself in water, and be unclean until the even.
3197	105	28	But if she be cleansed of her issue, then she shall number to herself seven days, and after that she shall be clean.
3198	105	29	And on the eighth day she shall take unto her two turtles, or two young pigeons, and bring them unto the priest, to the door of the tabernacle of the congregation.
3199	105	30	And the priest shall offer the one for a sin offering, and the other for a burnt offering; and the priest shall make an atonement for her before the LORD for the issue of her uncleanness.
3200	105	31	Thus shall ye separate the children of Israel from their uncleanness; that they die not in their uncleanness, when they defile my tabernacle that is among them.
3201	105	32	This is the law of him that hath an issue, and of him whose seed goeth from him, and is defiled therewith;
3202	105	33	And of her that is sick of her flowers, and of him that hath an issue, of the man, and of the woman, and of him that lieth with her that is unclean.
3203	106	1	AND the LORD spake unto Moses after the death of the two sons of Aaron, when they offered before the LORD, and died;
3204	106	2	And the LORD said unto Moses, Speak unto Aaron thy brother, that he come not at all times into the holy place within the vail before the mercy seat, which is upon the ark; that he die not: for I will appear in the cloud upon the mercy seat.
3205	106	3	Thus shall Aaron come into the holy place: with a young bullock for a sin offering, and a ram for a burnt offering.
3206	106	4	He shall put on the holy linen coat, and he shall have the linen breeches upon his flesh, and shall be girded with a linen girdle, and with the linen mitre shall he be attired: these are holy garments; therefore shall he wash his flesh in water, and so put them on.
3207	106	5	And he shall take of the congregation of the children of Israel two kids of the goats for a sin offering, and one ram for a burnt offering.
3208	106	6	And Aaron shall offer his bullock of the sin offering, which is for himself, and make an atonement for himself, and for his house.
3209	106	7	And he shall take the two goats, and present them before the LORD at the door of the tabernacle of the congregation.
3210	106	8	And Aaron shall cast lots upon the two goats; one lot for the LORD, and the other lot for the scapegoat.
3211	106	9	And Aaron shall bring the goat upon which the LORD's lot fell, and offer him for a sin offering.
3212	106	10	But the goat, on which the lot fell to be the scapegoat, shall be presented alive before the LORD, to make an atonement with him, and to let him go for a scapegoat into the wilderness.
3213	106	11	And Aaron shall bring the bullock of the sin offering, which is for himself, and shall make an atonement for himself, and for his house, and shall kill the bullock of the sin offering which is for himself:
3214	106	12	And he shall take a censer full of burning coals of fire from off the altar before the LORD, and his hands full of sweet incense beaten small, and bring it within the vail:
3215	106	13	And he shall put the incense upon the fire before the LORD, that the cloud of the incense may cover the mercy seat that is upon the testimony, that he die not:
3216	106	14	And he shall take of the blood of the bullock, and sprinkle it with his finger upon the mercy seat eastward; and before the mercy seat shall he sprinkle of the blood with his finger seven times.
3217	106	15	Then shall he kill the goat of the sin offering, that is for the people, and bring his blood within the vail, and do with that blood as he did with the blood of the bullock, and sprinkle it upon the mercy seat, and before the mercy seat:
3218	106	16	And he shall make an atonement for the holy place, because of the uncleanness of the children of Israel, and because of their transgressions in all their sins: and so shall he do for the tabernacle of the congregation, that remaineth among them in the midst of their uncleanness.
3219	106	17	And there shall be no man in the tabernacle of the congregation when he goeth in to make an atonement in the holy place, until he come out, and have made an atonement for himself, and for his household, and for all the congregation of Israel.
3220	106	18	And he shall go out unto the altar that is before the LORD, and make an atonement for it; and shall take of the blood of the bullock, and of the blood of the goat, and put it upon the horns of the altar round about.
3221	106	19	And he shall sprinkle of the blood upon it with his finger seven times, and cleanse it, and hallow it from the uncleanness of the children of Israel.
3222	106	20	And when he hath made an end of reconciling the holy place, and the tabernacle of the congregation, and the altar, he shall bring the live goat:
3223	106	21	And Aaron shall lay both his hands upon the head of the live goat, and confess over him all the iniquities of the children of Israel, and all their transgressions in all their sins, putting them upon the head of the goat, and shall send him away by the hand of a fit man into the wilderness:
3224	106	22	And the goat shall bear upon him all their iniquities unto a land not inhabited: and he shall let go the goat in the wilderness.
3225	106	23	And Aaron shall come into the tabernacle of the congregation, and shall put off the linen garments, which he put on when he went into the holy place, and shall leave them there:
3226	106	24	And he shall wash his flesh with water in the holy place, and put on his garments, and come forth, and offer his burnt offering, and the burnt offering of the people, and make an atonement for himself, and for the people.
3227	106	25	And the fat of the sin offering shall he burn upon the altar.
3228	106	26	And he that let go the goat for the scapegoat shall wash his clothes, and bathe his flesh in water, and afterward come into the camp.
3229	106	27	And the bullock for the sin offering, and the goat for the sin offering, whose blood was brought in to make atonement in the holy place, shall one carry forth without the camp; and they shall burn in the fire their skins, and their flesh, and their dung.
3230	106	28	And he that burneth them shall wash his clothes, and bathe his flesh in water, and afterward he shall come into the camp.
3231	106	29	And this shall be a statute for ever unto you: that in the seventh month, on the tenth day of the month, ye shall afflict your souls, and do no work at all, whether it be one of your own country, or a stranger that sojourneth among you:
3232	106	30	For on that day shall the priest make an atonement for you, to cleanse you, that ye may be clean from all your sins before the LORD.
3233	106	31	It shall be a sabbath of rest unto you, and ye shall afflict your souls, by a statute for ever.
3234	106	32	And the priest, whom he shall anoint, and whom he shall consecrate to minister in the priest's office in his father's stead, shall make the atonement, and shall put on the linen clothes, even the holy garments:
3235	106	33	And he shall make an atonement for the holy sanctuary, and he shall make an atonement for the tabernacle of the congregation, and for the altar, and he shall make an atonement for the priests, and for all the people of the congregation.
3236	106	34	And this shall be an everlasting statute unto you, to make an atonement for the children of Israel for all their sins once a year. And he did as the LORD commanded Moses.
3237	107	1	AND the LORD spake unto Moses, saying,
3238	107	2	Speak unto Aaron, and unto his sons, and unto all the children of Israel, and say unto them; This is the thing which the LORD hath commanded, saying,
3239	107	3	What man soever there be of the house of Israel, that killeth an ox, or lamb, or goat, in the camp, or that killeth it out of the camp,
3240	107	4	And bringeth it not unto the door of the tabernacle of the congregation, to offer an offering unto the LORD before the tabernacle of the LORD; blood shall be imputed unto that man; he hath shed blood; and that man shall be cut off from among his people:
3241	107	5	To the end that the children of Israel may bring their sacrifices, which they offer in the open field, even that they may bring them unto the LORD, unto the door of the tabernacle of the congregation, unto the priest, and offer them for peace offerings unto the LORD.
3242	107	6	And the priest shall sprinkle the blood upon the altar of the LORD at the door of the tabernacle of the congregation, and burn the fat for a sweet savour unto the LORD.
3243	107	7	And they shall no more offer their sacrifices unto devils, after whom they have gone a whoring. This shall be a statute for ever unto them throughout their generations.
3244	107	8	And thou shalt say unto them, Whatsoever man there be of the house of Israel, or of the strangers which sojourn among you, that offereth a burnt offering or sacrifice,
3245	107	9	And bringeth it not unto the door of the tabernacle of the congregation, to offer it unto the LORD; even that man shall be cut off from among his people.
3246	107	10	And whatsoever man there be of the house of Israel, or of the strangers that sojourn among you, that eateth any manner of blood; I will even set my face against that soul that eateth blood, and will cut him off from among his people.
3247	107	11	For the life of the flesh is in the blood: and I have given it to you upon the altar to make an atonement for your souls: for it is the blood that maketh an atonement for the soul.
3248	107	12	Therefore I said unto the children of Israel, No soul of you shall eat blood, neither shall any stranger that sojourneth among you eat blood.
3249	107	13	And whatsoever man there be of the children of Israel, or of the strangers that sojourn among you, which hunteth and catcheth any beast or fowl that may be eaten; he shall even pour out the blood thereof, and cover it with dust.
3250	107	14	For it is the life of all flesh; the blood of it is for the life thereof: therefore I said unto the children of Israel, Ye shall eat the blood of no manner of flesh: for the life of all flesh is the blood thereof: whosoever eateth it shall be cut off.
3251	107	15	And every soul that eateth that which died of itself, or that which was torn with beasts, whether it be one of your own country, or a stranger, he shall both wash his clothes, and bathe himself in water, and be unclean until the even: then shall he be clean.
3252	107	16	But if he wash them not, nor bathe his flesh; then he shall bear his iniquity.
3253	108	1	AND the LORD spake unto Moses, saying,
3254	108	2	Speak unto the children of Israel, and say unto them, I am the LORD your God.
3255	108	3	After the doings of the land of Egypt, wherein ye dwelt, shall ye not do: and after the doings of the land of Canaan, whither I bring you, shall ye not do: neither shall ye walk in their ordinances.
3256	108	4	Ye shall do my judgments, and keep mine ordinances, to walk therein: I am the LORD your God.
3257	108	5	Ye shall therefore keep my statutes, and my judgments: which if a man do, he shall live in them: I am the LORD.
3258	108	6	None of you shall approach to any that is near of kin to him, to uncover their nakedness: I am the LORD.
3259	108	7	The nakedness of thy father, or the nakedness of thy mother, shalt thou not uncover: she is thy mother; thou shalt not uncover her nakedness.
3260	108	8	The nakedness of thy father's wife shalt thou not uncover: it is thy father's nakedness.
3261	108	9	The nakedness of thy sister, the daughter of thy father, or daughter of thy mother, whether she be born at home, or born abroad, even their nakedness thou shalt not uncover.
3262	108	10	The nakedness of thy son's daughter, or of thy daughter's daughter, even their nakedness thou shalt not uncover: for theirs is thine own nakedness.
3263	108	11	The nakedness of thy father's wife's daughter, begotten of thy father, she is thy sister, thou shalt not uncover her nakedness.
3264	108	12	Thou shalt not uncover the nakedness of thy father's sister: she is thy father's near kinswoman.
3265	108	13	Thou shalt not uncover the nakedness of thy mother's sister: for she is thy mother's near kinswoman.
3266	108	14	Thou shalt not uncover the nakedness of thy father's brother, thou shalt not approach to his wife: she is thine aunt.
3267	108	15	Thou shalt not uncover the nakedness of thy daughter in law: she is thy son's wife; thou shalt not uncover her nakedness.
3268	108	16	Thou shalt not uncover the nakedness of thy brother's wife: it is thy brother's nakedness.
3269	108	17	Thou shalt not uncover the nakedness of a woman and her daughter, neither shalt thou take her son's daughter, or her daughter's daughter, to uncover her nakedness; for they are her near kinswomen: it is wickedness.
3270	108	18	Neither shalt thou take a wife to her sister, to vex her, to uncover her nakedness, beside the other in her life time.
3271	108	19	Also thou shalt not approach unto a woman to uncover her nakedness, as long as she is put apart for her uncleanness.
3272	108	20	Moreover thou shalt not lie carnally with thy neighbour's wife, to defile thyself with her.
3273	108	21	And thou shalt not let any of thy seed pass through the fire to Molech, neither shalt thou profane the name of thy God: I am the LORD.
3274	108	22	Thou shalt not lie with mankind, as with womankind: it is abomination.
3275	108	23	Neither shalt thou lie with any beast to defile thyself therewith: neither shall any woman stand before a beast to lie down thereto: it is confusion.
3276	108	24	Defile not ye yourselves in any of these things: for in all these the nations are defiled which I cast out before you:
3277	108	25	And the land is defiled: therefore I do visit the iniquity thereof upon it, and the land itself vomiteth out her inhabitants.
3278	108	26	Ye shall therefore keep my statutes and my judgments, and shall not commit any of these abominations; neither any of your own nation, nor any stranger that sojourneth among you:
3279	108	27	(For all these abominations have the men of the land done, which were before you, and the land is defiled;)
3280	108	28	That the land spue not you out also, when ye defile it, as it spued out the nations that were before you.
3281	108	29	For whosoever shall commit any of these abominations, even the souls that commit them shall be cut off from among their people.
3282	108	30	Therefore shall ye keep mine ordinance, that ye commit not any one of these abominable customs, which were committed before you, and that ye defile not yourselves therein: I am the LORD your God.
3283	109	1	AND the LORD spake unto Moses, saying,
3284	109	2	Speak unto all the congregation of the children of Israel, and say unto them, Ye shall be holy: for I the LORD your God am holy.
3285	109	3	Ye shall fear every man his mother, and his father, and keep my sabbaths: I am the LORD your God.
3286	109	4	Turn ye not unto idols, nor make to yourselves molten gods: I am the LORD your God.
3287	109	5	And if ye offer a sacrifice of peace offerings unto the LORD, ye shall offer it at your own will.
3288	109	6	It shall be eaten the same day ye offer it, and on the morrow: and if ought remain until the third day, it shall be burnt in the fire.
3289	109	7	And if it be eaten at all on the third day, it is abominable; it shall not be accepted.
3290	109	8	Therefore every one that eateth it shall bear his iniquity, because he hath profaned the hallowed thing of the LORD: and that soul shall be cut off from among his people.
3291	109	9	And when ye reap the harvest of your land, thou shalt not wholly reap the corners of thy field, neither shalt thou gather the gleanings of thy harvest.
3292	109	10	And thou shalt not glean thy vineyard, neither shalt thou gather every grape of thy vineyard; thou shalt leave them for the poor and stranger: I am the LORD your God.
3293	109	11	Ye shall not steal, neither deal falsely, neither lie one to another.
3294	109	12	And ye shall not swear by my name falsely, neither shalt thou profane the name of thy God: I am the LORD.
3295	109	13	Thou shalt not defraud thy neighbour, neither rob him: the wages of him that is hired shall not abide with thee all night until the morning.
3296	109	14	Thou shalt not curse the deaf, nor put a stumblingblock before the blind, but shalt fear thy God: I am the LORD.
3297	109	15	Ye shall do no unrighteousness in judgment: thou shalt not respect the person of the poor, nor honour the person of the mighty: but in righteousness shalt thou judge thy neighbour.
3298	109	16	Thou shalt not go up and down as a talebearer among thy people: neither shalt thou stand against the blood of thy neighbour: I am the LORD.
3299	109	17	Thou shalt not hate thy brother in thine heart: thou shalt in any wise rebuke thy neighbour, and not suffer sin upon him.
3300	109	18	Thou shalt not avenge, nor bear any grudge against the children of thy people, but thou shalt love thy neighbour as thyself: I am the LORD.
3301	109	19	Ye shall keep my statutes. Thou shalt not let thy cattle gender with a diverse kind: thou shalt not sow thy field with mingled seed: neither shall a garment mingled of linen and woollen come upon thee.
3302	109	20	And whosoever lieth carnally with a woman, that is a bondmaid, betrothed to an husband, and not at all redeemed, nor freedom given her; she shall be scourged; they shall not be put to death, because she was not free.
3303	109	21	And he shall bring his trespass offering unto the LORD, unto the door of the tabernacle of the congregation, even a ram for a trespass offering.
3304	109	22	And the priest shall make an atonement for him with the ram of the trespass offering before the LORD for his sin which he hath done: and the sin which he hath done shall be forgiven him.
3305	109	23	And when ye shall come into the land, and shall have planted all manner of trees for food, then ye shall count the fruit thereof as uncircumcised: three years shall it be as uncircumcised unto you: it shall not be eaten of.
3306	109	24	But in the fourth year all the fruit thereof shall be holy to praise the LORD withal.
3307	109	25	And in the fifth year shall ye eat of the fruit thereof, that it may yield unto you the increase thereof: I am the LORD your God.
3308	109	26	Ye shall not eat any thing with the blood: neither shall ye use enchantment, nor observe times.
3309	109	27	Ye shall not round the corners of your heads, neither shalt thou mar the corners of thy beard.
3310	109	28	Ye shall not make any cuttings in your flesh for the dead, nor print any marks upon you: I am the LORD.
3311	109	29	Do not prostitute thy daughter, to cause her to be a whore; lest the land fall to whoredom, and the land become full of wickedness.
3312	109	30	Ye shall keep my sabbaths, and reverence my sanctuary: I am the LORD.
3313	109	31	Regard not them that have familiar spirits, neither seek after wizards, to be defiled by them: I am the LORD your God.
3314	109	32	Thou shalt rise up before the hoary head, and honour the face of the old man, and fear thy God: I am the LORD.
3315	109	33	And if a stranger sojourn with thee in your land, ye shall not vex him.
3316	109	34	But the stranger that dwelleth with you shall be unto you as one born among you, and thou shalt love him as thyself; for ye were strangers in the land of Egypt: I am the LORD your God.
3317	109	35	Ye shall do no unrighteousness in judgment, in meteyard, in weight, or in measure.
3318	109	36	Just balances, just weights, a just ephah, and a just hin, shall ye have: I am the LORD your God, which brought you out of the land of Egypt.
3319	109	37	Therefore shall ye observe all my statutes, and all my judgments, and do them: I am the LORD.
3320	110	1	AND the LORD spake unto Moses, saying,
3321	110	2	Again, thou shalt say to the children of Israel, Whosoever he be of the children of Israel, or of the strangers that sojourn in Israel, that giveth any of his seed unto Molech; he shall surely be put to death: the people of the land shall stone him with stones.
3322	110	3	And I will set my face against that man, and will cut him off from among his people; because he hath given of his seed unto Molech, to defile my sanctuary, and to profane my holy name.
3323	110	4	And if the people of the land do any ways hide their eyes from the man, when he giveth of his seed unto Molech, and kill him not:
3324	110	5	Then I will set my face against that man, and against his family, and will cut him off, and all that go a whoring after him, to commit whoredom with Molech, from among their people.
3325	110	6	And the soul that turneth after such as have familiar spirits, and after wizards, to go a whoring after them, I will even set my face against that soul, and will cut him off from among his people.
3326	110	7	Sanctify yourselves therefore, and be ye holy: for I am the LORD your God.
3327	110	8	And ye shall keep my statutes, and do them: I am the LORD which sanctify you.
3328	110	9	For every one that curseth his father or his mother shall be surely put to death: he hath cursed his father or his mother; his blood shall be upon him.
3329	110	10	And the man that committeth adultery with another man's wife, even he that committeth adultery with his neighbour's wife, the adulterer and the adulteress shall surely be put to death.
3330	110	11	And the man that lieth with his father's wife hath uncovered his father's nakedness: both of them shall surely be put to death; their blood shall be upon them.
3331	110	12	And if a man lie with his daughter in law, both of them shall surely be put to death: they have wrought confusion; their blood shall be upon them.
3332	110	13	If a man also lie with mankind, as he lieth with a woman, both of them have committed an abomination: they shall surely be put to death; their blood shall be upon them.
3333	110	14	And if a man take a wife and her mother, it is wickedness: they shall be burnt with fire, both he and they; that there be no wickedness among you.
3334	110	15	And if a man lie with a beast, he shall surely be put to death: and ye shall slay the beast.
3335	110	16	And if a woman approach unto any beast, and lie down thereto, thou shalt kill the woman, and the beast: they shall surely be put to death; their blood shall be upon them.
3336	110	17	And if a man shall take his sister, his father's daughter, or his mother's daughter, and see her nakedness, and she see his nakedness; it is a wicked thing; and they shall be cut off in the sight of their people: he hath uncovered his sister's nakedness; he shall bear his iniquity.
3337	110	18	And if a man shall lie with a woman having her sickness, and shall uncover her nakedness; he hath discovered her fountain, and she hath uncovered the fountain of her blood: and both of them shall be cut off from among their people.
3338	110	19	And thou shalt not uncover the nakedness of thy mother's sister, nor of thy father's sister: for he uncovereth his near kin: they shall bear their iniquity.
3339	110	20	And if a man shall lie with his uncle's wife, he hath uncovered his uncle's nakedness: they shall bear their sin; they shall die childless.
3340	110	21	And if a man shall take his brother's wife, it is an unclean thing: he hath uncovered his brother's nakedness; they shall be childless.
3341	110	22	Ye shall therefore keep all my statutes, and all my judgments, and do them: that the land, whither I bring you to dwell therein, spue you not out.
3342	110	23	And ye shall not walk in the manners of the nation, which I cast out before you: for they committed all these things, and therefore I abhorred them.
3343	110	24	But I have said unto you, Ye shall inherit their land, and I will give it unto you to possess it, a land that floweth with milk and honey: I am the LORD your God, which have separated you from other people.
3344	110	25	Ye shall therefore put difference between clean beasts and unclean, and between unclean fowls and clean: and ye shall not make your souls abominable by beast, or by fowl, or by any manner of living thing that creepeth on the ground, which I have separated from you as unclean.
3345	110	26	And ye shall be holy unto me: for I the LORD am holy, and have severed you from other people, that ye should be mine.
3346	110	27	A man also or woman that hath a familiar spirit, or that is a wizard, shall surely be put to death: they shall stone them with stones: their blood shall be upon them.
3347	111	1	AND the LORD said unto Moses, Speak unto the priests the sons of Aaron, and say unto them, There shall none be defiled for the dead among his people:
3348	111	2	But for his kin, that is near unto him, that is, for his mother, and for his father, and for his son, and for his daughter, and for his brother,
3349	111	3	And for his sister a virgin, that is nigh unto him, which hath had no husband; for her may he be defiled.
3350	111	4	But he shall not defile himself, being a chief man among his people, to profane himself.
3351	111	5	They shall not make baldness upon their head, neither shall they shave off the corner of their beard, nor make any cuttings in their flesh.
3352	111	6	They shall be holy unto their God, and not profane the name of their God: for the offerings of the LORD made by fire, and the bread of their God, they do offer: therefore they shall be holy.
3353	111	7	They shall not take a wife that is a whore, or profane; neither shall they take a woman put away from her husband: for he is holy unto his God.
3354	111	8	Thou shalt sanctify him therefore; for he offereth the bread of thy God: he shall be holy unto thee: for I the LORD, which sanctify you, am holy.
3355	111	9	And the daughter of any priest, if she profane herself by playing the whore, she profaneth her father: she shall be burnt with fire.
3356	111	10	And he that is the high priest among his brethren, upon whose head the anointing oil was poured, and that is consecrated to put on the garments, shall not uncover his head, nor rend his clothes;
3357	111	11	Neither shall he go in to any dead body, nor defile himself for his father, or for his mother;
3358	111	12	Neither shall he go out of the sanctuary, nor profane the sanctuary of his God; for the crown of the anointing oil of his God is upon him: I am the LORD.
3359	111	13	And he shall take a wife in her virginity.
3360	111	14	A widow, or a divorced woman, or profane, or an harlot, these shall he not take: but he shall take a virgin of his own people to wife.
3361	111	15	Neither shall he profane his seed among his people: for I the LORD do sanctify him.
3362	111	16	And the LORD spake unto Moses, saying,
3363	111	17	Speak unto Aaron, saying, Whosoever he be of thy seed in their generations that hath any blemish, let him not approach to offer the bread of his God.
3364	111	18	For whatsoever man he be that hath a blemish, he shall not approach: a blind man, or a lame, or he that hath a flat nose, or any thing superfluous,
3365	111	19	Or a man that is brokenfooted, or brokenhanded,
3366	111	20	Or crookbackt, or a dwarf, or that hath a blemish in his eye, or be scurvy, or scabbed, or hath his stones broken;
3367	111	21	No man that hath a blemish of the seed of Aaron the priest shall come nigh to offer the offerings of the LORD made by fire: he hath a blemish; he shall not come nigh to offer the bread of his God.
3368	111	22	He shall eat the bread of his God, both of the most holy, and of the holy.
3369	111	23	Only he shall not go in unto the vail, nor come nigh unto the altar, because he hath a blemish; that he profane not my sanctuaries: for I the LORD do sanctify them.
3370	111	24	And Moses told it unto Aaron, and to his sons, and unto all the children of Israel.
3371	112	1	AND the LORD spake unto Moses, saying,
3372	112	2	Speak unto Aaron and to his sons, that they separate themselves from the holy things of the children of Israel, and that they profane not my holy name in those things which they hallow unto me: I am the LORD.
3373	112	3	Say unto them, Whosoever he be of all your seed among your generations, that goeth unto the holy things, which the children of Israel hallow unto the LORD, having his uncleanness upon him, that soul shall be cut off from my presence: I am the LORD.
3374	112	4	What man soever of the seed of Aaron is a leper, or hath a running issue; he shall not eat of the holy things, until he be clean. And whoso toucheth any thing that is unclean by the dead, or a man whose seed goeth from him;
3375	112	5	Or whosoever toucheth any creeping thing, whereby he may be made unclean, or a man of whom he may take uncleanness, whatsoever uncleanness he hath;
3376	112	6	The soul which hath touched any such shall be unclean until even, and shall not eat of the holy things, unless he wash his flesh with water.
3377	112	7	And when the sun is down, he shall be clean, and shall afterward eat of the holy things; because it is his food.
3378	112	8	That which dieth of itself, or is torn with beasts, he shall not eat to defile himself therewith: I am the LORD.
3379	112	9	They shall therefore keep mine ordinance, lest they bear sin for it, and die therefore, if they profane it: I the LORD do sanctify them.
3380	112	10	There shall no stranger eat of the holy thing: a sojourner of the priest, or an hired servant, shall not eat of the holy thing.
3381	112	11	But if the priest buy any soul with his money, he shall eat of it, and he that is born in his house: they shall eat of his meat.
3382	112	12	If the priest's daughter also be married unto a stranger, she may not eat of an offering of the holy things.
3383	112	13	But if the priest's daughter be a widow, or divorced, and have no child, and is returned unto her father's house, as in her youth, she shall eat of her father's meat: but there shall no stranger eat thereof.
3384	112	14	And if a man eat of the holy thing unwittingly, then he shall put the fifth part thereof unto it, and shall give it unto the priest with the holy thing.
3385	112	15	And they shall not profane the holy things of the children of Israel, which they offer unto the LORD;
3386	112	16	Or suffer them to bear the iniquity of trespass, when they eat their holy things: for I the LORD do sanctify them.
3387	112	17	And the LORD spake unto Moses, saying,
3388	112	18	Speak unto Aaron, and to his sons, and unto all the children of Israel, and say unto them, Whatsoever he be of the house of Israel, or of the strangers in Israel, that will offer his oblation for all his vows, and for all his freewill offerings, which they will offer unto the LORD for a burnt offering;
3389	112	19	Ye shall offer at your own will a male without blemish, of the beeves, of the sheep, or of the goats.
3390	112	20	But whatsoever hath a blemish, that shall ye not offer: for it shall not be acceptable for you.
3391	112	21	And whosoever offereth a sacrifice of peace offerings unto the LORD to accomplish his vow, or a freewill offering in beeves or sheep, it shall be perfect to be accepted; there shall be no blemish therein.
3392	112	22	Blind, or broken, or maimed, or having a wen, or scurvy, or scabbed, ye shall not offer these unto the LORD, nor make an offering by fire of them upon the altar unto the LORD.
3393	112	23	Either a bullock or a lamb that hath any thing superfluous or lacking in his parts, that mayest thou offer for a freewill offering; but for a vow it shall not be accepted.
3394	112	24	Ye shall not offer unto the LORD that which is bruised, or crushed, or broken, or cut; neither shall ye make any offering thereof in your land.
3395	112	25	Neither from a stranger's hand shall ye offer the bread of your God of any of these; because their corruption is in them, and blemishes be in them: they shall not be accepted for you.
3396	112	26	And the LORD spake unto Moses, saying,
3397	112	27	When a bullock, or a sheep, or a goat, is brought forth, then it shall be seven days under the dam; and from the eighth day and thenceforth it shall be accepted for an offering made by fire unto the LORD.
3398	112	28	And whether it be cow or ewe, ye shall not kill it and her young both in one day.
3399	112	29	And when ye will offer a sacrifice of thanksgiving unto the LORD, offer it at your own will.
3400	112	30	On the same day it shall be eaten up; ye shall leave none of it until the morrow: I am the LORD.
3401	112	31	Therefore shall ye keep my commandments, and do them: I am the LORD.
3402	112	32	Neither shall ye profane my holy name; but I will be hallowed among the children of Israel: I am the LORD which hallow you,
3403	112	33	That brought you out of the land of Egypt, to be your God: I am the LORD.
3404	113	1	AND the LORD spake unto Moses, saying,
3405	113	2	Speak unto the children of Israel, and say unto them, Concerning the feasts of the LORD, which ye shall proclaim to be holy convocations, even these are my feasts.
3406	113	3	Six days shall work be done: but the seventh day is the sabbath of rest, an holy convocation; ye shall do no work therein: it is the sabbath of the LORD in all your dwellings.
3407	113	4	These are the feasts of the LORD, even holy convocations, which ye shall proclaim in their seasons.
3408	113	5	In the fourteenth day of the first month at even is the LORD's passover.
3409	113	6	And on the fifteenth day of the same month is the feast of unleavened bread unto the LORD: seven days ye must eat unleavened bread.
3410	113	7	In the first day ye shall have an holy convocation: ye shall do no servile work therein.
3411	113	8	But ye shall offer an offering made by fire unto the LORD seven days: in the seventh day is an holy convocation: ye shall do no servile work therein.
3412	113	9	And the LORD spake unto Moses, saying,
3413	113	10	Speak unto the children of Israel, and say unto them, When ye be come into the land which I give unto you, and shall reap the harvest thereof, then ye shall bring a sheaf of the firstfruits of your harvest unto the priest:
3414	113	11	And he shall wave the sheaf before the LORD, to be accepted for you: on the morrow after the sabbath the priest shall wave it.
3415	113	12	And ye shall offer that day when ye wave the sheaf an he lamb without blemish of the first year for a burnt offering unto the LORD.
3416	113	13	And the meat offering thereof shall be two tenth deals of fine flour mingled with oil, an offering made by fire unto the LORD for a sweet savour: and the drink offering thereof shall be of wine, the fourth part of an hin.
3417	113	14	And ye shall eat neither bread, nor parched corn, nor green ears, until the selfsame day that ye have brought an offering unto your God: it shall be a statute for ever throughout your generations in all your dwellings.
3418	113	15	And ye shall count unto you from the morrow after the sabbath, from the day that ye brought the sheaf of the wave offering; seven sabbaths shall be complete:
3419	113	16	Even unto the morrow after the seventh sabbath shall ye number fifty days; and ye shall offer a new meat offering unto the LORD.
3420	113	17	Ye shall bring out of your habitations two wave loaves of two tenth deals: they shall be of fine flour; they shall be baken with leaven; they are the firstfruits unto the LORD.
3421	113	18	And ye shall offer with the bread seven lambs without blemish of the first year, and one young bullock, and two rams: they shall be for a burnt offering unto the LORD, with their meat offering, and their drink offerings, even an offering made by fire, of sweet savour unto the LORD.
3422	113	19	Then ye shall sacrifice one kid of the goats for a sin offering, and two lambs of the first year for a sacrifice of peace offerings.
3423	113	20	And the priest shall wave them with the bread of the firstfruits for a wave offering before the LORD, with the two lambs: they shall be holy to the LORD for the priest.
3424	113	21	And ye shall proclaim on the selfsame day, that it may be an holy convocation unto you: ye shall do no servile work therein: it shall be a statute for ever in all your dwellings throughout your generations.
3425	113	22	And when ye reap the harvest of your land, thou shalt not make clean riddance of the corners of thy field when thou reapest, neither shalt thou gather any gleaning of thy harvest: thou shalt leave them unto the poor, and to the stranger: I am the LORD your God.
3426	113	23	And the LORD spake unto Moses, saying,
3427	113	24	Speak unto the children of Israel, saying, In the seventh month, in the first day of the month, shall ye have a sabbath, a memorial of blowing of trumpets, an holy convocation.
3428	113	25	Ye shall do no servile work therein: but ye shall offer an offering made by fire unto the LORD.
3429	113	26	And the LORD spake unto Moses, saying,
3430	113	27	Also on the tenth day of this seventh month there shall be a day of atonement: it shall be an holy convocation unto you; and ye shall afflict your souls, and offer an offering made by fire unto the LORD.
3431	113	28	And ye shall do no work in that same day: for it is a day of atonement, to make an atonement for you before the LORD your God.
3432	113	29	For whatsoever soul it be that shall not be afflicted in that same day, he shall be cut off from among his people.
3433	113	30	And whatsoever soul it be that doeth any work in that same day, the same soul will I destroy from among his people.
3434	113	31	Ye shall do no manner of work: it shall be a statute for ever throughout your generations in all your dwellings.
3435	113	32	It shall be unto you a sabbath of rest, and ye shall afflict your souls: in the ninth day of the month at even, from even unto even, shall ye celebrate your sabbath.
3436	113	33	And the LORD spake unto Moses, saying,
3437	113	34	Speak unto the children of Israel, saying, The fifteenth day of this seventh month shall be the feast of tabernacles for seven days unto the LORD.
3438	113	35	On the first day shall be an holy convocation: ye shall do no servile work therein.
3439	113	36	Seven days ye shall offer an offering made by fire unto the LORD: on the eighth day shall be an holy convocation unto you; and ye shall offer an offering made by fire unto the LORD: it is a solemn assembly; and ye shall do no servile work therein.
3440	113	37	These are the feasts of the LORD, which ye shall proclaim to be holy convocations, to offer an offering made by fire unto the LORD, a burnt offering, and a meat offering, a sacrifice, and drink offerings, every thing upon his day:
3441	113	38	Beside the sabbaths of the LORD, and beside your gifts, and beside all your vows, and beside all your freewill offerings, which ye give unto the LORD.
3442	113	39	Also in the fifteenth day of the seventh month, when ye have gathered in the fruit of the land, ye shall keep a feast unto the LORD seven days: on the first day shall be a sabbath, and on the eighth day shall be a sabbath.
3443	113	40	And ye shall take you on the first day the boughs of goodly trees, branches of palm trees, and the boughs of thick trees, and willows of the brook; and ye shall rejoice before the LORD your God seven days.
3444	113	41	And ye shall keep it a feast unto the LORD seven days in the year. It shall be a statute for ever in your generations: ye shall celebrate it in the seventh month.
3445	113	42	Ye shall dwell in booths seven days; all that are Israelites born shall dwell in booths:
3446	113	43	That your generations may know that I made the children of Israel to dwell in booths, when I brought them out of the land of Egypt: I am the LORD your God.
3447	113	44	And Moses declared unto the children of Israel the feasts of the LORD.
3448	114	1	AND the LORD spake unto Moses, saying,
3449	114	2	Command the children of Israel, that they bring unto thee pure oil olive beaten for the light, to cause the lamps to burn continually.
3450	114	3	Without the vail of the testimony, in the tabernacle of the congregation, shall Aaron order it from the evening unto the morning before the LORD continually: it shall be a statute for ever in your generations.
3451	114	4	He shall order the lamps upon the pure candlestick before the LORD continually.
3452	114	5	And thou shalt take fine flour, and bake twelve cakes thereof: two tenth deals shall be in one cake.
3453	114	6	And thou shalt set them in two rows, six on a row, upon the pure table before the LORD.
3454	114	7	And thou shalt put pure frankincense upon each row, that it may be on the bread for a memorial, even an offering made by fire unto the LORD.
3455	114	8	Every sabbath he shall set it in order before the LORD continually, being taken from the children of Israel by an everlasting covenant.
3456	114	9	And it shall be Aaron's and his sons'; and they shall eat it in the holy place: for it is most holy unto him of the offerings of the LORD made by fire by a perpetual statute.
3457	114	10	And the son of an Israelitish woman, whose father was an Egyptian, went out among the children of Israel: and this son of the Israelitish woman and a man of Israel strove together in the camp;
3458	114	11	And the Israelitish woman's son blasphemed the name of the LORD, and cursed. And they brought him unto Moses: (and his mother's name was Shelomith, the daughter of Dibri, of the tribe of Dan:)
3459	114	12	And they put him in ward, that the mind of the LORD might be shewed them.
3460	114	13	And the LORD spake unto Moses, saying,
3461	114	14	Bring forth him that hath cursed without the camp; and let all that heard him lay their hands upon his head, and let all the congregation stone him.
3462	114	15	And thou shalt speak unto the children of Israel, saying, Whosoever curseth his God shall bear his sin.
3463	114	16	And he that blasphemeth the name of the LORD, he shall surely be put to death, and all the congregation shall certainly stone him: as well the stranger, as he that is born in the land, when he blasphemeth the name of the LORD, shall be put to death.
3464	114	17	And he that killeth any man shall surely be put to death.
3465	114	18	And he that killeth a beast shall make it good; beast for beast.
3466	114	19	And if a man cause a blemish in his neighbour; as he hath done, so shall it be done to him;
3467	114	20	Breach for breach, eye for eye, tooth for tooth: as he hath caused a blemish in a man, so shall it be done to him again.
3468	114	21	And he that killeth a beast, he shall restore it: and he that killeth a man, he shall be put to death.
3469	114	22	Ye shall have one manner of law, as well for the stranger, as for one of your own country: for I am the LORD your God.
3470	114	23	And Moses spake to the children of Israel, that they should bring forth him that had cursed out of the camp, and stone him with stones. And the children of Israel did as the LORD commanded Moses.
3471	115	1	AND the LORD spake unto Moses in mount Sinai, saying,
3472	115	2	Speak unto the children of Israel, and say unto them, When ye come into the land which I give you, then shall the land keep a sabbath unto the LORD.
3473	115	3	Six years thou shalt sow thy field, and six years thou shalt prune thy vineyard, and gather in the fruit thereof;
3474	115	4	But in the seventh year shall be a sabbath of rest unto the land, a sabbath for the LORD: thou shalt neither sow thy field, nor prune thy vineyard.
3475	115	5	That which groweth of its own accord of thy harvest thou shalt not reap, neither gather the grapes of thy vine undressed: for it is a year of rest unto the land.
3476	115	6	And the sabbath of the land shall be meat for you; for thee, and for thy servant, and for thy maid, and for thy hired servant, and for thy stranger that sojourneth with thee,
3477	115	7	And for thy cattle, and for the beast that are in thy land, shall all the increase thereof be meat.
3478	115	8	And thou shalt number seven sabbaths of years unto thee, seven times seven years; and the space of the seven sabbaths of years shall be unto thee forty and nine years.
3479	115	9	Then shalt thou cause the trumpet of the jubile to sound on the tenth day of the seventh month, in the day of atonement shall ye make the trumpet sound throughout all your land.
3480	115	10	And ye shall hallow the fiftieth year, and proclaim liberty throughout all the land unto all the inhabitants thereof: it shall be a jubile unto you; and ye shall return every man unto his possession, and ye shall return every man unto his family.
3481	115	11	A jubile shall that fiftieth year be unto you: ye shall not sow, neither reap that which groweth of itself in it, nor gather the grapes in it of thy vine undressed.
3482	115	12	For it is the jubile; it shall be holy unto you: ye shall eat the increase thereof out of the field.
3483	115	13	In the year of this jubile ye shall return every man unto his possession.
3484	115	14	And if thou sell ought unto thy neighbour, or buyest ought of thy neighbour's hand, ye shall not oppress one another:
3485	115	15	According to the number of years after the jubile thou shalt buy of thy neighbour, and according unto the number of years of the fruits he shall sell unto thee:
3486	115	16	According to the multitude of years thou shalt increase the price thereof, and according to the fewness of years thou shalt diminish the price of it: for according to the number of the years of the fruits doth he sell unto thee.
3487	115	17	Ye shall not therefore oppress one another; but thou shalt fear thy God: for I am the LORD your God.
3488	115	18	Wherefore ye shall do my statutes, and keep my judgments, and do them; and ye shall dwell in the land in safety.
3489	115	19	And the land shall yield her fruit, and ye shall eat your fill, and dwell therein in safety.
3490	115	20	And if ye shall say, What shall we eat the seventh year? behold, we shall not sow, nor gather in our increase:
3491	115	21	Then I will command my blessing upon you in the sixth year, and it shall bring forth fruit for three years.
3492	115	22	And ye shall sow the eighth year, and eat yet of old fruit until the ninth year; until her fruits come in ye shall eat of the old store.
3493	115	23	The land shall not be sold for ever: for the land is mine; for ye are strangers and sojourners with me.
3494	115	24	And in all the land of your possession ye shall grant a redemption for the land.
3495	115	25	If thy brother be waxen poor, and hath sold away some of his possession, and if any of his kin come to redeem it, then shall he redeem that which his brother sold.
3496	115	26	And if the man have none to redeem it, and himself be able to redeem it;
3497	115	27	Then let him count the years of the sale thereof, and restore the overplus unto the man to whom he sold it; that he may return unto his possession.
3498	115	28	But if he be not able to restore it to him, then that which is sold shall remain in the hand of him that hath bought it until the year of jubile: and in the jubile it shall go out, and he shall return unto his possession.
3499	115	29	And if a man sell a dwelling house in a walled city, then he may redeem it within a whole year after it is sold; within a full year may he redeem it.
3500	115	30	And if it be not redeemed within the space of a full year, then the house that is in the walled city shall be established for ever to him that bought it throughout his generations: it shall not go out in the jubile.
3501	115	31	But the houses of the villages which have no wall round about them shall be counted as the fields of the country: they may be redeemed, and they shall go out in the jubile.
3502	115	32	Notwithstanding the cities of the Levites, and the houses of the cities of their possession, may the Levites redeem at any time.
3503	115	33	And if a man purchase of the Levites, then the house that was sold, and the city of his possession, shall go out in the year of jubile: for the houses of the cities of the Levites are their possession among the children of Israel.
3504	115	34	But the field of the suburbs of their cities may not be sold; for it is their perpetual possession.
3505	115	35	And if thy brother be waxen poor, and fallen in decay with thee; then thou shalt relieve him: yea, though he be a stranger, or a sojourner; that he may live with thee.
3506	115	36	Take thou no usury of him, or increase: but fear thy God; that thy brother may live with thee.
3507	115	37	Thou shalt not give him thy money upon usury, nor lend him thy victuals for increase.
3508	115	38	I am the LORD your God, which brought you forth out of the land of Egypt, to give you the land of Canaan, and to be your God.
3509	115	39	And if thy brother that dwelleth by thee be waxen poor, and be sold unto thee; thou shalt not compel him to serve as a bondservant:
3510	115	40	But as an hired servant, and as a sojourner, he shall be with thee, and shall serve thee unto the year of jubile:
3511	115	41	And then shall he depart from thee, both he and his children with him, and shall return unto his own family, and unto the possession of his fathers shall he return.
3512	115	42	For they are my servants, which I brought forth out of the land of Egypt: they shall not be sold as bondmen.
3513	115	43	Thou shalt not rule over him with rigour; but shalt fear thy God.
3514	115	44	Both thy bondmen, and thy bondmaids, which thou shalt have, shall be of the heathen that are round about you; of them shall ye buy bondmen and bondmaids.
3515	115	45	Moreover of the children of the strangers that do sojourn among you, of them shall ye buy, and of their families that are with you, which they begat in your land: and they shall be your possession.
3516	115	46	And ye shall take them as an inheritance for your children after you, to inherit them for a possession; they shall be your bondmen for ever: but over your brethren the children of Israel, ye shall not rule one over another with rigour.
3517	115	47	And if a sojourner or stranger wax rich by thee, and thy brother that dwelleth by him wax poor, and sell himself unto the stranger or sojourner by thee, or to the stock of the stranger's family:
3518	115	48	After that he is sold he may be redeemed again; one of his brethren may redeem him:
3519	115	49	Either his uncle, or his uncle's son, may redeem him, or any that is nigh of kin unto him of his family may redeem him; or if he be able, he may redeem himself.
3520	115	50	And he shall reckon with him that bought him from the year that he was sold to him unto the year of jubile: and the price of his sale shall be according unto the number of years, according to the time of an hired servant shall it be with him.
3521	115	51	If there be yet many years behind, according unto them he shall give again the price of his redemption out of the money that he was bought for.
3522	115	52	And if there remain but few years unto the year of jubile, then he shall count with him, and according unto his years shall he give him again the price of his redemption.
3523	115	53	And as a yearly hired servant shall he be with him: and the other shall not rule with rigour over him in thy sight.
3524	115	54	And if he be not redeemed in these years, then he shall go out in the year of jubile, both he, and his children with him.
3525	115	55	For unto me the children of Israel are servants; they are my servants whom I brought forth out of the land of Egypt: I am the LORD your God.
3526	116	1	YE shall make you no idols nor graven image, neither rear you up a standing image, neither shall ye set up any image of stone in your land, to bow down unto it: for I am the LORD your God.
3527	116	2	Ye shall keep my sabbaths, and reverence my sanctuary: I am the LORD.
3528	116	3	If ye walk in my statutes, and keep my commandments, and do them;
3529	116	4	Then I will give you rain in due season, and the land shall yield her increase, and the trees of the field shall yield their fruit.
3530	116	5	And your threshing shall reach unto the vintage, and the vintage shall reach unto the sowing time: and ye shall eat your bread to the full, and dwell in your land safely.
3531	116	6	And I will give peace in the land, and ye shall lie down, and none shall make you afraid: and I will rid evil beasts out of the land, neither shall the sword go through your land.
3532	116	7	And ye shall chase your enemies, and they shall fall before you by the sword.
3533	116	8	And five of you shall chase an hundred, and an hundred of you shall put ten thousand to flight: and your enemies shall fall before you by the sword.
3534	116	9	For I will have respect unto you, and make you fruitful, and multiply you, and establish my covenant with you.
3535	116	10	And ye shall eat old store, and bring forth the old because of the new.
3536	116	11	And I will set my tabernacle among you: and my soul shall not abhor you.
3537	116	12	And I will walk among you, and will be your God, and ye shall be my people.
3538	116	13	I am the LORD your God, which brought you forth out of the land of Egypt, that ye should not be their bondmen; and I have broken the bands of your yoke, and made you go upright.
3539	116	14	But if ye will not hearken unto me, and will not do all these commandments;
3540	116	15	And if ye shall despise my statutes, or if your soul abhor my judgments, so that ye will not do all my commandments, but that ye break my covenant:
3541	116	16	I also will do this unto you; I will even appoint over you terror, consumption, and the burning ague, that shall consume the eyes, and cause sorrow of heart: and ye shall sow your seed in vain, for your enemies shall eat it.
3542	116	17	And I will set my face against you, and ye shall be slain before your enemies: they that hate you shall reign over you; and ye shall flee when none pursueth you.
3543	116	18	And if ye will not yet for all this hearken unto me, then I will punish you seven times more for your sins.
3544	116	19	And I will break the pride of your power; and I will make your heaven as iron, and your earth as brass:
3545	116	20	And your strength shall be spent in vain: for your land shall not yield her increase, neither shall the trees of the land yield their fruits.
3546	116	21	And if ye walk contrary unto me, and will not hearken unto me; I will bring seven times more plagues upon you according to your sins.
3547	116	22	I will also send wild beasts among you, which shall rob you of your children, and destroy your cattle, and make you few in number; and your high ways shall be desolate.
3548	116	23	And if ye will not be reformed by me by these things, but will walk contrary unto me;
3549	116	24	Then will I also walk contrary unto you, and will punish you yet seven times for your sins.
3550	116	25	And I will bring a sword upon you, that shall avenge the quarrel of my covenant: and when ye are gathered together within your cities, I will send the pestilence among you; and ye shall be delivered into the hand of the enemy.
3551	116	26	And when I have broken the staff of your bread, ten women shall bake your bread in one oven, and they shall deliver you your bread again by weight: and ye shall eat, and not be satisfied.
3552	116	27	And if ye will not for all this hearken unto me, but walk contrary unto me;
3553	116	28	Then I will walk contrary unto you also in fury; and I, even I, will chastise you seven times for your sins.
3554	116	29	And ye shall eat the flesh of your sons, and the flesh of your daughters shall ye eat.
3555	116	30	And I will destroy your high places, and cut down your images, and cast your carcases upon the carcases of your idols, and my soul shall abhor you.
3556	116	31	And I will make your cities waste, and bring your sanctuaries unto desolation, and I will not smell the savour of your sweet odours.
3557	116	32	And I will bring the land into desolation: and your enemies which dwell therein shall be astonished at it.
3558	116	33	And I will scatter you among the heathen, and will draw out a sword after you: and your land shall be desolate, and your cities waste.
3559	116	34	Then shall the land enjoy her sabbaths, as long as it lieth desolate, and ye be in your enemies' land; even then shall the land rest, and enjoy her sabbaths.
3560	116	35	As long as it lieth desolate it shall rest; because it did not rest in your sabbaths, when ye dwelt upon it.
3561	116	36	And upon them that are left alive of you I will send a faintness into their hearts in the lands of their enemies; and the sound of a shaken leaf shall chase them; and they shall flee, as fleeing from a sword; and they shall fall when none pursueth.
3562	116	37	And they shall fall one upon another, as it were before a sword, when none pursueth: and ye shall have no power to stand before your enemies.
3563	116	38	And ye shall perish among the heathen, and the land of your enemies shall eat you up.
3564	116	39	And they that are left of you shall pine away in their iniquity in your enemies' lands; and also in the iniquities of their fathers shall they pine away with them.
3565	116	40	If they shall confess their iniquity, and the iniquity of their fathers, with their trespass which they trespassed against me, and that also they have walked contrary unto me;
3566	116	41	And that I also have walked contrary unto them, and have brought them into the land of their enemies; if then their uncircumcised hearts be humbled, and they then accept of the punishment of their iniquity:
3567	116	42	Then will I remember my covenant with Jacob, and also my covenant with Isaac, and also my covenant with Abraham will I remember; and I will remember the land.
3568	116	43	The land also shall be left of them, and shall enjoy her sabbaths, while she lieth desolate without them: and they shall accept of the punishment of their iniquity: because, even because they despised my judgments, and because their soul abhorred my statutes.
3569	116	44	And yet for all that, when they be in the land of their enemies, I will not cast them away, neither will I abhor them, to destroy them utterly, and to break my covenant with them: for I am the LORD their God.
3570	116	45	But I will for their sakes remember the covenant of their ancestors, whom I brought forth out of the land of Egypt in the sight of the heathen, that I might be their God: I am the LORD.
3571	116	46	These are the statutes and judgments and laws, which the LORD made between him and the children of Israel in mount Sinai by the hand of Moses.
3572	117	1	AND the LORD spake unto Moses, saying,
3573	117	2	Speak unto the children of Israel, and say unto them, When a man shall make a singular vow, the persons shall be for the LORD by thy estimation.
3574	117	3	And thy estimation shall be of the male from twenty years old even unto sixty years old, even thy estimation shall be fifty shekels of silver, after the shekel of the sanctuary.
3575	117	4	And if it be a female, then thy estimation shall be thirty shekels.
3576	117	5	And if it be from five years old even unto twenty years old, then thy estimation shall be of the male twenty shekels, and for the female ten shekels.
3577	117	6	And if it be from a month old even unto five years old, then thy estimation shall be of the male five shekels of silver, and for the female thy estimation shall be three shekels of silver.
3578	117	7	And if it be from sixty years old and above; if it be a male, then thy estimation shall be fifteen shekels, and for the female ten shekels.
3579	117	8	But if he be poorer than thy estimation, then he shall present himself before the priest, and the priest shall value him; according to his ability that vowed shall the priest value him.
3580	117	9	And if it be a beast, whereof men bring an offering unto the LORD, all that any man giveth of such unto the LORD shall be holy.
3581	117	10	He shall not alter it, nor change it, a good for a bad, or a bad for a good: and if he shall at all change beast for beast, then it and the exchange thereof shall be holy.
3582	117	11	And if it be any unclean beast, of which they do not offer a sacrifice unto the LORD, then he shall present the beast before the priest:
3583	117	12	And the priest shall value it, whether it be good or bad: as thou valuest it, who art the priest, so shall it be.
3584	117	13	But if he will at all redeem it, then he shall add a fifth part thereof unto thy estimation.
3585	117	14	And when a man shall sanctify his house to be holy unto the LORD, then the priest shall estimate it, whether it be good or bad: as the priest shall estimate it, so shall it stand.
3586	117	15	And if he that sanctified it will redeem his house, then he shall add the fifth part of the money of thy estimation unto it, and it shall be his.
3587	117	16	And if a man shall sanctify unto the LORD some part of a field of his possession, then thy estimation shall be according to the seed thereof: an homer of barley seed shall be valued at fifty shekels of silver.
3588	117	17	If he sanctify his field from the year of jubile, according to thy estimation it shall stand.
3589	117	18	But if he sanctify his field after the jubile, then the priest shall reckon unto him the money according to the years that remain, even unto the year of the jubile, and it shall be abated from thy estimation.
3590	117	19	And if he that sanctified the field will in any wise redeem it, then he shall add the fifth part of the money of thy estimation unto it, and it shall be assured to him.
3591	117	20	And if he will not redeem the field, or if he have sold the field to another man, it shall not be redeemed any more.
3592	117	21	But the field, when it goeth out in the jubile, shall be holy unto the LORD, as a field devoted; the possession thereof shall be the priest's.
3593	117	22	And if a man sanctify unto the LORD a field which he hath bought, which is not of the fields of his possession;
3594	117	23	Then the priest shall reckon unto him the worth of thy estimation, even unto the year of the jubile: and he shall give thine estimation in that day, as a holy thing unto the LORD.
3595	117	24	In the year of the jubile the field shall return unto him of whom it was bought, even to him to whom the possession of the land did belong.
3596	117	25	And all thy estimations shall be according to the shekel of the sanctuary: twenty gerahs shall be the shekel.
3597	117	26	Only the firstling of the beasts, which should be the LORD's firstling, no man shall sanctify it; whether it be ox, or sheep: it is the LORD's.
3598	117	27	And if it be of an unclean beast, then he shall redeem it according to thine estimation, and shall add a fifth part of it thereto: or if it be not redeemed, then it shall be sold according to thy estimation.
3599	117	28	Notwithstanding no devoted thing, that a man shall devote unto the LORD of all that he hath, both of man and beast, and of the field of his possession, shall be sold or redeemed: every devoted thing is most holy unto the LORD.
3600	117	29	None devoted, which shall be devoted of men, shall be redeemed; but shall surely be put to death.
3601	117	30	And all the tithe of the land, whether of the seed of the land, or of the fruit of the tree, is the LORD's: it is holy unto the LORD.
3602	117	31	And if a man will at all redeem ought of his tithes, he shall add thereto the fifth part thereof.
3603	117	32	And concerning the tithe of the herd, or of the flock, even of whatsoever passeth under the rod, the tenth shall be holy unto the LORD.
3604	117	33	He shall not search whether it be good or bad, neither shall he change it: and if he change it at all, then both it and the change thereof shall be holy; it shall not be redeemed.
3605	117	34	These are the commandments, which the LORD commanded Moses for the children of Israel in mount Sinai.
3606	118	1	AND the LORD spake unto Moses in the wilderness of Sinai, in the tabernacle of the congregation, on the first day of the second month, in the second year after they were come out of the land of Egypt, saying,
3607	118	2	Take ye the sum of all the congregation of the children of Israel, after their families, by the house of their fathers, with the number of their names, every male by their polls;
3608	118	3	From twenty years old and upward, all that are able to go forth to war in Israel: thou and Aaron shall number them by their armies.
3609	118	4	And with you there shall be a man of every tribe; every one head of the house of his fathers.
3610	118	5	And these are the names of the men that shall stand with you: of the tribe of Reuben; Elizur the son of Shedeur.
3611	118	6	Of Simeon; Shelumiel the son of Zurishaddai.
3612	118	7	Of Judah; Nahshon the son of Amminadab.
3613	118	8	Of Issachar; Nethaneel the son of Zuar.
3614	118	9	Of Zebulun; Eliab the son of Helon.
3615	118	10	Of the children of Joseph: of Ephraim; Elishama the son of Ammihud: of Manasseh; Gamaliel the son of Pedahzur.
3616	118	11	Of Benjamin; Abidan the son of Gideoni.
3617	118	12	Of Dan; Ahiezer the son of Ammishaddai.
3618	118	13	Of Asher; Pagiel the son of Ocran.
3619	118	14	Of Gad; Eliasaph the son of Deuel.
3620	118	15	Of Naphtali; Ahira the son of Enan.
3621	118	16	These were the renowned of the congregation, princes of the tribes of their fathers, heads of thousands in Israel.
3622	118	17	And Moses and Aaron took these men which are expressed by their names:
3623	118	18	And they assembled all the congregation together on the first day of the second month, and they declared their pedigrees after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, by their polls.
3624	118	19	As the LORD commanded Moses, so he numbered them in the wilderness of Sinai.
3625	118	20	And the children of Reuben, Israel's eldest son, by their generations, after their families, by the house of their fathers, according to the number of the names, by their polls, every male from twenty years old and upward, all that were able to go forth to war;
3626	118	21	Those that were numbered of them, even of the tribe of Reuben, were forty and six thousand and five hundred.
3627	118	22	Of the children of Simeon, by their generations, after their families, by the house of their fathers, those that were numbered of them, according to the number of the names, by their polls, every male from twenty years old and upward, all that were able to go forth to war;
3628	118	23	Those that were numbered of them, even of the tribe of Simeon, were fifty and nine thousand and three hundred.
3629	118	24	Of the children of Gad, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3630	118	25	Those that were numbered of them, even of the tribe of Gad, were forty and five thousand six hundred and fifty.
3631	118	26	Of the children of Judah, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3632	118	27	Those that were numbered of them, even of the tribe of Judah, were threescore and fourteen thousand and six hundred.
3633	118	28	Of the children of Issachar, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3634	118	29	Those that were numbered of them, even of the tribe of Issachar, were fifty and four thousand and four hundred.
3635	118	30	Of the children of Zebulun, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3636	118	31	Those that were numbered of them, even of the tribe of Zebulun, were fifty and seven thousand and four hundred.
3637	118	32	Of the children of Joseph, namely, of the children of Ephraim, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3638	118	33	Those that were numbered of them, even of the tribe of Ephraim, were forty thousand and five hundred.
3639	118	34	Of the children of Manasseh, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3640	118	35	Those that were numbered of them, even of the tribe of Manasseh, were thirty and two thousand and two hundred.
3641	118	36	Of the children of Benjamin, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3642	118	37	Those that were numbered of them, even of the tribe of Benjamin, were thirty and five thousand and four hundred.
3643	118	38	Of the children of Dan, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3644	118	39	Those that were numbered of them, even of the tribe of Dan, were threescore and two thousand and seven hundred.
3645	118	40	Of the children of Asher, by their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3646	118	41	Those that were numbered of them, even of the tribe of Asher, were forty and one thousand and five hundred.
3647	118	42	Of the children of Naphtali, throughout their generations, after their families, by the house of their fathers, according to the number of the names, from twenty years old and upward, all that were able to go forth to war;
3648	118	43	Those that were numbered of them, even of the tribe of Naphtali, were fifty and three thousand and four hundred.
3649	118	44	These are those that were numbered, which Moses and Aaron numbered, and the princes of Israel, being twelve men: each one was for the house of his fathers.
3650	118	45	So were all those that were numbered of the children of Israel, by the house of their fathers, from twenty years old and upward, all that were able to go forth to war in Israel;
3651	118	46	Even all they that were numbered were six hundred thousand and three thousand and five hundred and fifty.
3652	118	47	But the Levites after the tribe of their fathers were not numbered among them.
3653	118	48	For the LORD had spoken unto Moses, saying,
3654	118	49	Only thou shalt not number the tribe of Levi, neither take the sum of them among the children of Israel:
3655	118	50	But thou shalt appoint the Levites over the tabernacle of testimony, and over all the vessels thereof, and over all things that belong to it: they shall bear the tabernacle, and all the vessels thereof; and they shall minister unto it, and shall encamp round about the tabernacle.
3656	118	51	And when the tabernacle setteth forward, the Levites shall take it down: and when the tabernacle is to be pitched, the Levites shall set it up: and the stranger that cometh nigh shall be put to death.
3657	118	52	And the children of Israel shall pitch their tents, every man by his own camp, and every man by his own standard, throughout their hosts.
3658	118	53	But the Levites shall pitch round about the tabernacle of testimony, that there be no wrath upon the congregation of the children of Israel: and the Levites shall keep the charge of the tabernacle of testimony.
3659	118	54	And the children of Israel did according to all that the LORD commanded Moses, so did they.
3660	119	1	AND the LORD spake unto Moses and unto Aaron, saying,
3661	119	2	Every man of the children of Israel shall pitch by his own standard, with the ensign of their father's house: far off about the tabernacle of the congregation shall they pitch.
3662	119	3	And on the east side toward the rising of the sun shall they of the standard of the camp of Judah pitch throughout their armies: and Nahshon the son of Amminadab shall be captain of the children of Judah.
3663	119	4	And his host, and those that were numbered of them, were threescore and fourteen thousand and six hundred.
3664	119	5	And those that do pitch next unto him shall be the tribe of Issachar: and Nethaneel the son of Zuar shall be captain of the children of Issachar.
3665	119	6	And his host, and those that were numbered thereof, were fifty and four thousand and four hundred.
3666	119	7	Then the tribe of Zebulun: and Eliab the son of Helon shall be captain of the children of Zebulun.
3667	119	8	And his host, and those that were numbered thereof, were fifty and seven thousand and four hundred.
3668	119	9	All that were numbered in the camp of Judah were an hundred thousand and fourscore thousand and six thousand and four hundred, throughout their armies. These shall first set forth.
3669	119	10	On the south side shall be the standard of the camp of Reuben according to their armies: and the captain of the children of Reuben shall be Elizur the son of Shedeur.
3670	119	11	And his host, and those that were numbered thereof, were forty and six thousand and five hundred.
3671	119	12	And those which pitch by him shall be the tribe of Simeon: and the captain of the children of Simeon shall be Shelumiel the son of Zurishaddai.
3672	119	13	And his host, and those that were numbered of them, were fifty and nine thousand and three hundred.
3673	119	14	Then the tribe of Gad: and the captain of the sons of Gad shall be Eliasaph the son of Reuel.
3674	119	15	And his host, and those that were numbered of them, were forty and five thousand and six hundred and fifty.
3675	119	16	All that were numbered in the camp of Reuben were an hundred thousand and fifty and one thousand and four hundred and fifty, throughout their armies. And they shall set forth in the second rank.
3676	119	17	Then the tabernacle of the congregation shall set forward with the camp of the Levites in the midst of the camp: as they encamp, so shall they set forward, every man in his place by their standards.
3677	119	18	On the west side shall be the standard of the camp of Ephraim according to their armies: and the captain of the sons of Ephraim shall be Elishama the son of Ammihud.
3678	119	19	And his host, and those that were numbered of them, were forty thousand and five hundred.
3679	119	20	And by him shall be the tribe of Manasseh: and the captain of the children of Manasseh shall be Gamaliel the son of Pedahzur.
3680	119	21	And his host, and those that were numbered of them, were thirty and two thousand and two hundred.
3681	119	22	Then the tribe of Benjamin: and the captain of the sons of Benjamin shall be Abidan the son of Gideoni.
3682	119	23	And his host, and those that were numbered of them, were thirty and five thousand and four hundred.
3683	119	24	All that were numbered of the camp of Ephraim were an hundred thousand and eight thousand and an hundred, throughout their armies. And they shall go forward in the third rank.
3684	119	25	The standard of the camp of Dan shall be on the north side by their armies: and the captain of the children of Dan shall be Ahiezer the son of Ammishaddai.
3685	119	26	And his host, and those that were numbered of them, were threescore and two thousand and seven hundred.
3686	119	27	And those that encamp by him shall be the tribe of Asher: and the captain of the children of Asher shall be Pagiel the son of Ocran.
3687	119	28	And his host, and those that were numbered of them, were forty and one thousand and five hundred.
3688	119	29	Then the tribe of Naphtali: and the captain of the children of Naphtali shall be Ahira the son of Enan.
3689	119	30	And his host, and those that were numbered of them, were fifty and three thousand and four hundred.
3690	119	31	All they that were numbered in the camp of Dan were an hundred thousand and fifty and seven thousand and six hundred. They shall go hindmost with their standards.
3691	119	32	These are those which were numbered of the children of Israel by the house of their fathers: all those that were numbered of the camps throughout their hosts were six hundred thousand and three thousand and five hundred and fifty.
3692	119	33	But the Levites were not numbered among the children of Israel; as the LORD commanded Moses.
3693	119	34	And the children of Israel did according to all that the LORD commanded Moses: so they pitched by their standards, and so they set forward, every one after their families, according to the house of their fathers.
3694	120	1	THESE also are the generations of Aaron and Moses in the day that the LORD spake with Moses in mount Sinai.
3695	120	2	And these are the names of the sons of Aaron; Nadab the firstborn, and Abihu, Eleazar, and Ithamar.
3696	120	3	These are the names of the sons of Aaron, the priests which were anointed, whom he consecrated to minister in the priest's office.
3697	120	4	And Nadab and Abihu died before the LORD, when they offered strange fire before the LORD, in the wilderness of Sinai, and they had no children: and Eleazar and Ithamar ministered in the priest's office in the sight of Aaron their father.
3698	120	5	And the LORD spake unto Moses, saying,
3699	120	6	Bring the tribe of Levi near, and present them before Aaron the priest, that they may minister unto him.
3700	120	7	And they shall keep his charge, and the charge of the whole congregation before the tabernacle of the congregation, to do the service of the tabernacle.
3701	120	8	And they shall keep all the instruments of the tabernacle of the congregation, and the charge of the children of Israel, to do the service of the tabernacle.
3702	120	9	And thou shalt give the Levites unto Aaron and to his sons: they are wholly given unto him out of the children of Israel.
3703	120	10	And thou shalt appoint Aaron and his sons, and they shall wait on their priest's office: and the stranger that cometh nigh shall be put to death.
3704	120	11	And the LORD spake unto Moses, saying,
3705	120	12	And I, behold, I have taken the Levites from among the children of Israel instead of all the firstborn that openeth the matrix among the children of Israel: therefore the Levites shall be mine;
3706	120	13	Because all the firstborn are mine; for on the day that I smote all the firstborn in the land of Egypt I hallowed unto me all the firstborn in Israel, both man and beast: mine shall they be: I am the LORD.
3707	120	14	And the LORD spake unto Moses in the wilderness of Sinai, saying,
3708	120	15	Number the children of Levi after the house of their fathers, by their families: every male from a month old and upward shalt thou number them.
3709	120	16	And Moses numbered them according to the word of the LORD, as he was commanded.
3710	120	17	And these were the sons of Levi by their names; Gershon, and Kohath, and Merari.
3711	120	18	And these are the names of the sons of Gershon by their families; Libni, and Shimei.
3712	120	19	And the sons of Kohath by their families; Amram, and Izehar, Hebron, and Uzziel.
3713	120	20	And the sons of Merari by their families; Mahli, and Mushi. These are the families of the Levites according to the house of their fathers.
3714	120	21	Of Gershon was the family of the Libnites, and the family of the Shimites: these are the families of the Gershonites.
3715	120	22	Those that were numbered of them, according to the number of all the males, from a month old and upward, even those that were numbered of them were seven thousand and five hundred.
3716	120	23	The families of the Gershonites shall pitch behind the tabernacle westward.
3717	120	24	And the chief of the house of the father of the Gershonites shall be Eliasaph the son of Lael.
3718	120	25	And the charge of the sons of Gershon in the tabernacle of the congregation shall be the tabernacle, and the tent, the covering thereof, and the hanging for the door of the tabernacle of the congregation,
3719	120	26	And the hangings of the court, and the curtain for the door of the court, which is by the tabernacle, and by the altar round about, and the cords of it for all the service thereof.
3720	120	27	And of Kohath was the family of the Amramites, and the family of the Izeharites, and the family of the Hebronites, and the family of the Uzzielites: these are the families of the Kohathites.
3721	120	28	In the number of all the males, from a month old and upward, were eight thousand and six hundred, keeping the charge of the sanctuary.
3722	120	29	The families of the sons of Kohath shall pitch on the side of the tabernacle southward.
3723	120	30	And the chief of the house of the father of the families of the Kohathites shall be Elizaphan the son of Uzziel.
3724	120	31	And their charge shall be the ark, and the table, and the candlestick, and the altars, and the vessels of the sanctuary wherewith they minister, and the hanging, and all the service thereof.
3725	120	32	And Eleazar the son of Aaron the priest shall be chief over the chief of the Levites, and have the oversight of them that keep the charge of the sanctuary.
3726	120	33	Of Merari was the family of the Mahlites, and the family of the Mushites: these are the families of Merari.
3727	120	34	And those that were numbered of them, according to the number of all the males, from a month old and upward, were six thousand and two hundred.
3728	120	35	And the chief of the house of the father of the families of Merari was Zuriel the son of Abihail: these shall pitch on the side of the tabernacle northward.
3729	120	36	And under the custody and charge of the sons of Merari shall be the boards of the tabernacle, and the bars thereof, and the pillars thereof, and the sockets thereof, and all the vessels thereof, and all that serveth thereto,
3730	120	37	And the pillars of the court round about, and their sockets, and their pins, and their cords.
3731	120	38	But those that encamp before the tabernacle toward the east, even before the tabernacle of the congregation eastward, shall be Moses, and Aaron and his sons, keeping the charge of the sanctuary for the charge of the children of Israel; and the stranger that cometh nigh shall be put to death.
3732	120	39	All that were numbered of the Levites, which Moses and Aaron numbered at the commandment of the LORD, throughout their families, all the males from a month old and upward, were twenty and two thousand.
3733	120	40	And the LORD said unto Moses, Number all the firstborn of the males of the children of Israel from a month old and upward, and take the number of their names.
3734	120	41	And thou shalt take the Levites for me (I am the LORD) instead of all the firstborn among the children of Israel; and the cattle of the Levites instead of all the firstlings among the cattle of the children of Israel.
3735	120	42	And Moses numbered, as the LORD commanded him, all the firstborn among the children of Israel.
3736	120	43	And all the firstborn males by the number of names, from a month old and upward, of those that were numbered of them, were twenty and two thousand two hundred and threescore and thirteen.
3737	120	44	And the LORD spake unto Moses, saying,
3738	120	45	Take the Levites instead of all the firstborn among the children of Israel, and the cattle of the Levites instead of their cattle; and the Levites shall be mine: I am the LORD.
3739	120	46	And for those that are to be redeemed of the two hundred and threescore and thirteen of the firstborn of the children of Israel, which are more than the Levites;
3740	120	47	Thou shalt even take five shekels apiece by the poll, after the shekel of the sanctuary shalt thou take them: (the shekel is twenty gerahs:)
3741	120	48	And thou shalt give the money, wherewith the odd number of them is to be redeemed, unto Aaron and to his sons.
3742	120	49	And Moses took the redemption money of them that were over and above them that were redeemed by the Levites:
3743	120	50	Of the firstborn of the children of Israel took he the money; a thousand three hundred and threescore and five shekels, after the shekel of the sanctuary:
3744	120	51	And Moses gave the money of them that were redeemed unto Aaron and to his sons, according to the word of the LORD, as the LORD commanded Moses.
3745	121	1	AND the LORD spake unto Moses and unto Aaron, saying,
3746	121	2	Take the sum of the sons of Kohath from among the sons of Levi, after their families, by the house of their fathers,
3747	121	3	From thirty years old and upward even until fifty years old, all that enter into the host, to do the work in the tabernacle of the congregation.
3748	121	4	This shall be the service of the sons of Kohath in the tabernacle of the congregation, about the most holy things:
3749	121	5	And when the camp setteth forward, Aaron shall come, and his sons, and they shall take down the covering vail, and cover the ark of testimony with it:
3750	121	6	And shall put thereon the covering of badgers' skins, and shall spread over it a cloth wholly of blue, and shall put in the staves thereof.
3751	121	7	And upon the table of shewbread they shall spread a cloth of blue, and put thereon the dishes, and the spoons, and the bowls, and covers to cover withal: and the continual bread shall be thereon:
3752	121	8	And they shall spread upon them a cloth of scarlet, and cover the same with a covering of badgers' skins, and shall put in the staves thereof.
3753	121	9	And they shall take a cloth of blue, and cover the candlestick of the light, and his lamps, and his tongs, and his snuffdishes, and all the oil vessels thereof, wherewith they minister unto it:
3754	121	10	And they shall put it and all the vessels thereof within a covering of badgers' skins, and shall put it upon a bar.
3755	121	11	And upon the golden altar they shall spread a cloth of blue, and cover it with a covering of badgers' skins, and shall put to the staves thereof:
3756	121	12	And they shall take all the instruments of ministry, wherewith they minister in the sanctuary, and put them in a cloth of blue, and cover them with a covering of badgers' skins, and shall put them on a bar:
3757	121	13	And they shall take away the ashes from the altar, and spread a purple cloth thereon:
3758	121	14	And they shall put upon it all the vessels thereof, wherewith they minister about it, even the censers, the fleshhooks, and the shovels, and the basons, all the vessels of the altar; and they shall spread upon it a covering of badgers' skins, and put to the staves of it.
3759	121	15	And when Aaron and his sons have made an end of covering the sanctuary, and all the vessels of the sanctuary, as the camp is to set forward; after that, the sons of Kohath shall come to bear it: but they shall not touch any holy thing, lest they die. These things are the burden of the sons of Kohath in the tabernacle of the congregation.
3760	121	16	And to the office of Eleazar the son of Aaron the priest pertaineth the oil for the light, and the sweet incense, and the daily meat offering, and the anointing oil, and the oversight of all the tabernacle, and of all that therein is, in the sanctuary, and in the vessels thereof.
3761	121	17	And the LORD spake unto Moses and unto Aaron, saying,
3762	121	18	Cut ye not off the tribe of the families of the Kohathites from among the Levites:
3763	121	19	But thus do unto them, that they may live, and not die, when they approach unto the most holy things. Aaron and his sons shall go in, and appoint them every one to his service and to his burden:
3764	121	20	But they shall not go in to see when the holy things are covered, lest they die.
3765	121	21	And the LORD spake unto Moses, saying,
3766	121	22	Take also the sum of the sons of Gershon, throughout the houses of their fathers, by their families;
3767	121	23	From thirty years old and upward until fifty years old shalt thou number them; all that enter in to perform the service, to do the work in the tabernacle of the congregation.
3768	121	24	This is the service of the families of the Gershonites, to serve, and for burdens:
3769	121	25	And they shall bear the curtains of the tabernacle, and the tabernacle of the congregation, his covering, and the covering of the badgers' skins that is above upon it, and the hanging for the door of the tabernacle of the congregation,
3770	121	26	And the hangings of the court, and the hanging for the door of the gate of the court, which is by the tabernacle and by the altar round about, and their cords, and all the instruments of their service, and all that is made for them: so shall they serve.
3771	121	27	At the appointment of Aaron and his sons shall be all the service of the sons of the Gershonites, in all their burdens, and in all their service: and ye shall appoint unto them in charge all their burdens.
3772	121	28	This is the service of the families of the sons of Gershon in the tabernacle of the congregation: and their charge shall be under the hand of Ithamar the son of Aaron the priest.
3773	121	29	As for the sons of Merari, thou shalt number them after their families, by the house of their fathers;
3774	121	30	From thirty years old and upward even unto fifty years old shalt thou number them, every one that entereth into the service, to do the work of the tabernacle of the congregation.
3775	121	31	And this is the charge of their burden, according to all their service in the tabernacle of the congregation; the boards of the tabernacle, and the bars thereof, and the pillars thereof, and sockets thereof,
3776	121	32	And the pillars of the court round about, and their sockets, and their pins, and their cords, with all their instruments, and with all their service: and by name ye shall reckon the instruments of the charge of their burden.
3777	121	33	This is the service of the families of the sons of Merari, according to all their service, in the tabernacle of the congregation, under the hand of Ithamar the son of Aaron the priest.
3778	121	34	And Moses and Aaron and the chief of the congregation numbered the sons of the Kohathites after their families, and after the house of their fathers,
3779	121	35	From thirty years old and upward even unto fifty years old, every one that entereth into the service, for the work in the tabernacle of the congregation:
3780	121	36	And those that were numbered of them by their families were two thousand seven hundred and fifty.
3781	121	37	These were they that were numbered of the families of the Kohathites, all that might do service in the tabernacle of the congregation, which Moses and Aaron did number according to the commandment of the LORD by the hand of Moses.
3782	121	38	And those that were numbered of the sons of Gershon, throughout their families, and by the house of their fathers,
3783	121	39	From thirty years old and upward even unto fifty years old, every one that entereth into the service, for the work in the tabernacle of the congregation,
3784	121	40	Even those that were numbered of them, throughout their families, by the house of their fathers, were two thousand and six hundred and thirty.
3785	121	41	These are they that were numbered of the families of the sons of Gershon, of all that might do service in the tabernacle of the congregation, whom Moses and Aaron did number according to the commandment of the LORD.
3786	121	42	And those that were numbered of the families of the sons of Merari, throughout their families, by the house of their fathers,
3787	121	43	From thirty years old and upward even unto fifty years old, every one that entereth into the service, for the work in the tabernacle of the congregation,
3788	121	44	Even those that were numbered of them after their families, were three thousand and two hundred.
3789	121	45	These be those that were numbered of the families of the sons of Merari, whom Moses and Aaron numbered according to the word of the LORD by the hand of Moses.
3790	121	46	All those that were numbered of the Levites, whom Moses and Aaron and the chief of Israel numbered, after their families, and after the house of their fathers,
3791	121	47	From thirty years old and upward even unto fifty years old, every one that came to do the service of the ministry, and the service of the burden in the tabernacle of the congregation,
3792	121	48	Even those that were numbered of them, were eight thousand and five hundred and fourscore.
3793	121	49	According to the commandment of the LORD they were numbered by the hand of Moses, every one according to his service, and according to his burden: thus were they numbered of him, as the LORD commanded Moses.
3794	122	1	AND the LORD spake unto Moses, saying,
3795	122	2	Command the children of Israel, that they put out of the camp every leper, and every one that hath an issue, and whosoever is defiled by the dead:
3796	122	3	Both male and female shall ye put out, without the camp shall ye put them; that they defile not their camps, in the midst whereof I dwell.
3797	122	4	And the children of Israel did so, and put them out without the camp: as the LORD spake unto Moses, so did the children of Israel.
3798	122	5	And the LORD spake unto Moses, saying,
3799	122	6	Speak unto the children of Israel, When a man or woman shall commit any sin that men commit, to do a trespass against the LORD, and that person be guilty;
3800	122	7	Then they shall confess their sin which they have done: and he shall recompense his trespass with the principal thereof, and add unto it the fifth part thereof, and give it unto him against whom he hath trespassed.
3801	122	8	But if the man have no kinsman to recompense the trespass unto, let the trespass be recompensed unto the LORD, even to the priest; beside the ram of the atonement, whereby an atonement shall be made for him.
3802	122	9	And every offering of all the holy things of the children of Israel, which they bring unto the priest, shall be his.
3803	122	10	And every man's hallowed things shall be his: whatsoever any man giveth the priest, it shall be his.
3804	122	11	And the LORD spake unto Moses, saying,
3805	122	12	Speak unto the children of Israel, and say unto them, If any man's wife go aside, and commit a trespass against him,
3806	122	13	And a man lie with her carnally, and it be hid from the eyes of her husband, and be kept close, and she be defiled, and there be no witness against her, neither she be taken with the manner;
3807	122	14	And the spirit of jealousy come upon him, and he be jealous of his wife, and she be defiled: or if the spirit of jealousy come upon him, and he be jealous of his wife, and she be not defiled:
3808	122	15	Then shall the man bring his wife unto the priest, and he shall bring her offering for her, the tenth part of an ephah of barley meal; he shall pour no oil upon it, nor put frankincense thereon; for it is an offering of jealousy, an offering of memorial, bringing iniquity to remembrance.
3809	122	16	And the priest shall bring her near, and set her before the LORD:
3810	122	17	And the priest shall take holy water in an earthen vessel; and of the dust that is in the floor of the tabernacle the priest shall take, and put it into the water:
3811	122	18	And the priest shall set the woman before the LORD, and uncover the woman's head, and put the offering of memorial in her hands, which is the jealousy offering: and the priest shall have in his hand the bitter water that causeth the curse:
3812	122	19	And the priest shall charge her by an oath, and say unto the woman, If no man have lain with thee, and if thou hast not gone aside to uncleanness with another instead of thy husband, be thou free from this bitter water that causeth the curse:
3813	122	20	But if thou hast gone aside to another instead of thy husband, and if thou be defiled, and some man have lain with thee beside thine husband:
3814	122	21	Then the priest shall charge the woman with an oath of cursing, and the priest shall say unto the woman, The LORD make thee a curse and an oath among thy people, when the LORD doth make thy thigh to rot, and thy belly to swell;
3815	122	22	And this water that causeth the curse shall go into thy bowels, to make thy belly to swell, and thy thigh to rot: And the woman shall say, Amen, amen.
3816	122	23	And the priest shall write these curses in a book, and he shall blot them out with the bitter water:
3817	122	24	And he shall cause the woman to drink the bitter water that causeth the curse: and the water that causeth the curse shall enter into her, and become bitter.
3818	122	25	Then the priest shall take the jealousy offering out of the woman's hand, and shall wave the offering before the LORD, and offer it upon the altar:
3819	122	26	And the priest shall take an handful of the offering, even the memorial thereof, and burn it upon the altar, and afterward shall cause the woman to drink the water.
3820	122	27	And when he hath made her to drink the water, then it shall come to pass, that, if she be defiled, and have done trespass against her husband, that the water that causeth the curse shall enter into her, and become bitter, and her belly shall swell, and her thigh shall rot: and the woman shall be a curse among her people.
3821	122	28	And if the woman be not defiled, but be clean; then she shall be free, and shall conceive seed.
3822	122	29	This is the law of jealousies, when a wife goeth aside to another instead of her husband, and is defiled;
3823	122	30	Or when the spirit of jealousy cometh upon him, and he be jealous over his wife, and shall set the woman before the LORD, and the priest shall execute upon her all this law.
3824	122	31	Then shall the man be guiltless from iniquity, and this woman shall bear her iniquity.
3825	123	1	AND the LORD spake unto Moses, saying,
3826	123	2	Speak unto the children of Israel, and say unto them, When either man or woman shall separate themselves to vow a vow of a Nazarite, to separate themselves unto the LORD:
3827	123	3	He shall separate himself from wine and strong drink, and shall drink no vinegar of wine, or vinegar of strong drink, neither shall he drink any liquor of grapes, nor eat moist grapes, or dried.
3828	123	4	All the days of his separation shall he eat nothing that is made of the vine tree, from the kernels even to the husk.
3829	123	5	All the days of the vow of his separation there shall no razor come upon his head: until the days be fulfilled, in the which he separateth himself unto the LORD, he shall be holy, and shall let the locks of the hair of his head grow.
3830	123	6	All the days that he separateth himself unto the LORD he shall come at no dead body.
3831	123	7	He shall not make himself unclean for his father, or for his mother, for his brother, or for his sister, when they die: because the consecration of his God is upon his head.
3832	123	8	All the days of his separation he is holy unto the LORD.
3833	123	9	And if any man die very suddenly by him, and he hath defiled the head of his consecration; then he shall shave his head in the day of his cleansing, on the seventh day shall he shave it.
3834	123	10	And on the eighth day he shall bring two turtles, or two young pigeons, to the priest, to the door of the tabernacle of the congregation:
3835	123	11	And the priest shall offer the one for a sin offering, and the other for a burnt offering, and make an atonement for him, for that he sinned by the dead, and shall hallow his head that same day.
3836	123	12	And he shall consecrate unto the LORD the days of his separation, and shall bring a lamb of the first year for a trespass offering: but the days that were before shall be lost, because his separation was defiled.
3837	123	13	And this is the law of the Nazarite, when the days of his separation are fulfilled: he shall be brought unto the door of the tabernacle of the congregation:
3838	123	14	And he shall offer his offering unto the LORD, one he lamb of the first year without blemish for a burnt offering, and one ewe lamb of the first year without blemish for a sin offering, and one ram without blemish for peace offerings,
3839	123	15	And a basket of unleavened bread, cakes of fine flour mingled with oil, and wafers of unleavened bread anointed with oil, and their meat offering, and their drink offerings.
3840	123	16	And the priest shall bring them before the LORD, and shall offer his sin offering, and his burnt offering:
3841	123	17	And he shall offer the ram for a sacrifice of peace offerings unto the LORD, with the basket of unleavened bread: the priest shall offer also his meat offering, and his drink offering.
3842	123	18	And the Nazarite shall shave the head of his separation at the door of the tabernacle of the congregation, and shall take the hair of the head of his separation, and put it in the fire which is under the sacrifice of the peace offerings.
3843	123	19	And the priest shall take the sodden shoulder of the ram, and one unleavened cake out of the basket, and one unleavened wafer, and shall put them upon the hands of the Nazarite, after the hair of his separation is shaven:
3844	123	20	And the priest shall wave them for a wave offering before the LORD: this is holy for the priest, with the wave breast and heave shoulder: and after that the Nazarite may drink wine.
3845	123	21	This is the law of the Nazarite who hath vowed, and of his offering unto the LORD for his separation, beside that that his hand shall get: according to the vow which he vowed, so he must do after the law of his separation.
3846	123	22	And the LORD spake unto Moses, saying,
3847	123	23	Speak unto Aaron and unto his sons, saying, On this wise ye shall bless the children of Israel, saying unto them,
3848	123	24	The LORD bless thee, and keep thee:
3849	123	25	The LORD make his face shine upon thee, and be gracious unto thee:
3850	123	26	The LORD lift up his countenance upon thee, and give thee peace.
3851	123	27	And they shall put my name upon the children of Israel; and I will bless them.
3852	124	1	AND it came to pass on the day that Moses had fully set up the tabernacle, and had anointed it, and sanctified it, and all the instruments thereof, both the altar and all the vessels thereof, and had anointed them, and sanctified them;
3853	124	2	That the princes of Israel, heads of the house of their fathers, who were the princes of the tribes, and were over them that were numbered, offered:
3854	124	3	And they brought their offering before the LORD, six covered wagons, and twelve oxen; a wagon for two of the princes, and for each one an ox: and they brought them before the tabernacle.
3855	124	4	And the LORD spake unto Moses, saying,
3856	124	5	Take it of them, that they may be to do the service of the tabernacle of the congregation; and thou shalt give them unto the Levites, to every man according to his service.
3857	124	6	And Moses took the wagons and the oxen, and gave them unto the Levites.
3858	124	7	Two wagons and four oxen he gave unto the sons of Gershon, according to their service:
3859	124	8	And four wagons and eight oxen he gave unto the sons of Merari, according unto their service, under the hand of Ithamar the son of Aaron the priest.
3860	124	9	But unto the sons of Kohath he gave none: because the service of the sanctuary belonging unto them was that they should bear upon their shoulders.
3861	124	10	And the princes offered for dedicating of the altar in the day that it was anointed, even the princes offered their offering before the altar.
3862	124	11	And the LORD said unto Moses, They shall offer their offering, each prince on his day, for the dedicating of the altar.
3863	124	12	And he that offered his offering the first day was Nahshon the son of Amminadab, of the tribe of Judah:
3864	124	13	And his offering was one silver charger, the weight thereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them were full of fine flour mingled with oil for a meat offering:
3865	124	14	One spoon of ten shekels of gold, full of incense:
3866	124	15	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3867	124	16	One kid of the goats for a sin offering:
3868	124	17	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Nahshon the son of Amminadab.
3869	124	18	On the second day Nethaneel the son of Zuar, prince of Issachar, did offer:
3870	124	19	He offered for his offering one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3871	124	20	One spoon of gold of ten shekels, full of incense:
3872	124	21	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3873	124	22	One kid of the goats for a sin offering:
3874	124	23	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Nethaneel the son of Zuar.
3875	124	24	On the third day Eliab the son of Helon, prince of the children of Zebulun, did offer:
3876	124	25	His offering was one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3877	124	26	One golden spoon of ten shekels, full of incense:
3878	124	27	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3879	124	28	One kid of the goats for a sin offering:
3880	124	29	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Eliab the son of Helon.
3881	124	30	On the fourth day Elizur the son of Shedeur, prince of the children of Reuben, did offer:
3882	124	31	His offering was one silver charger of the weight of an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3883	124	32	One golden spoon of ten shekels, full of incense:
3884	124	33	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3885	124	34	One kid of the goats for a sin offering:
3886	124	35	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Elizur the son of Shedeur.
3887	124	36	On the fifth day Shelumiel the son of Zurishaddai, prince of the children of Simeon, did offer:
3888	124	37	His offering was one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3889	124	38	One golden spoon of ten shekels, full of incense:
3890	124	39	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3891	124	40	One kid of the goats for a sin offering:
3892	124	41	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Shelumiel the son of Zurishaddai.
3893	124	42	On the sixth day Eliasaph the son of Deuel, prince of the children of Gad, offered:
3894	124	43	His offering was one silver charger of the weight of an hundred and thirty shekels, a silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3895	124	44	One golden spoon of ten shekels, full of incense:
3896	124	45	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3897	124	46	One kid of the goats for a sin offering:
3898	124	47	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Eliasaph the son of Deuel.
3899	124	48	On the seventh day Elishama the son of Ammihud, prince of the children of Ephraim, offered:
3900	124	49	His offering was one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3901	124	50	One golden spoon of ten shekels, full of incense:
3902	124	51	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3903	124	52	One kid of the goats for a sin offering:
3904	124	53	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Elishama the son of Ammihud.
3905	124	54	On the eighth day offered Gamaliel the son of Pedahzur, prince of the children of Manasseh:
3906	124	55	His offering was one silver charger of the weight of an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3907	124	56	One golden spoon of ten shekels, full of incense:
3908	124	57	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3909	124	58	One kid of the goats for a sin offering:
3910	124	59	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Gamaliel the son of Pedahzur.
3911	124	60	On the ninth day Abidan the son of Gideoni, prince of the children of Benjamin, offered:
3912	124	61	His offering was one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3913	124	62	One golden spoon of ten shekels, full of incense:
3914	124	63	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3915	124	64	One kid of the goats for a sin offering:
3916	124	65	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Abidan the son of Gideoni.
3917	124	66	On the tenth day Ahiezer the son of Ammishaddai, prince of the children of Dan, offered:
3918	124	67	His offering was one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3919	124	68	One golden spoon of ten shekels, full of incense:
3920	124	69	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3921	124	70	One kid of the goats for a sin offering:
3922	124	71	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Ahiezer the son of Ammishaddai.
3923	124	72	On the eleventh day Pagiel the son of Ocran, prince of the children of Asher, offered:
3924	124	73	His offering was one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3925	124	74	One golden spoon of ten shekels, full of incense:
3926	124	75	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3927	124	76	One kid of the goats for a sin offering:
3928	124	77	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Pagiel the son of Ocran.
3929	124	78	On the twelfth day Ahira the son of Enan, prince of the children of Naphtali, offered:
3930	124	79	His offering was one silver charger, the weight whereof was an hundred and thirty shekels, one silver bowl of seventy shekels, after the shekel of the sanctuary; both of them full of fine flour mingled with oil for a meat offering:
3931	124	80	One golden spoon of ten shekels, full of incense:
3932	124	81	One young bullock, one ram, one lamb of the first year, for a burnt offering:
3933	124	82	One kid of the goats for a sin offering:
3934	124	83	And for a sacrifice of peace offerings, two oxen, five rams, five he goats, five lambs of the first year: this was the offering of Ahira the son of Enan.
3935	124	84	This was the dedication of the altar, in the day when it was anointed, by the princes of Israel: twelve chargers of silver, twelve silver bowls, twelve spoons of gold:
3936	124	85	Each charger of silver weighing an hundred and thirty shekels, each bowl seventy: all the silver vessels weighed two thousand and four hundred shekels, after the shekel of the sanctuary:
3937	124	86	The golden spoons were twelve, full of incense, weighing ten shekels apiece, after the shekel of the sanctuary: all the gold of the spoons was an hundred and twenty shekels.
3938	124	87	All the oxen for the burnt offering were twelve bullocks, the rams twelve, the lambs of the first year twelve, with their meat offering: and the kids of the goats for sin offering twelve.
3939	124	88	And all the oxen for the sacrifice of the peace offerings were twenty and four bullocks, the rams sixty, the he goats sixty, the lambs of the first year sixty. This was the dedication of the altar, after that it was anointed.
3940	124	89	And when Moses was gone into the tabernacle of the congregation to speak with him, then he heard the voice of one speaking unto him from off the mercy seat that was upon the ark of testimony, from between the two cherubims: and he spake unto him.
3941	125	1	AND the LORD spake unto Moses, saying,
3942	125	2	Speak unto Aaron, and say unto him, When thou lightest the lamps, the seven lamps shall give light over against the candlestick.
3943	125	3	And Aaron did so; he lighted the lamps thereof over against the candlestick, as the LORD commanded Moses.
3944	125	4	And this work of the candlestick was of beaten gold, unto the shaft thereof, unto the flowers thereof, was beaten work: according unto the pattern which the LORD had shewed Moses, so he made the candlestick.
3945	125	5	And the LORD spake unto Moses, saying,
3946	125	6	Take the Levites from among the children of Israel, and cleanse them.
3947	125	7	And thus shalt thou do unto them, to cleanse them: Sprinkle water of purifying upon them, and let them shave all their flesh, and let them wash their clothes, and so make themselves clean.
3948	125	8	Then let them take a young bullock with his meat offering, even fine flour mingled with oil, and another young bullock shalt thou take for a sin offering.
3949	125	9	And thou shalt bring the Levites before the tabernacle of the congregation: and thou shalt gather the whole assembly of the children of Israel together:
3950	125	10	And thou shalt bring the Levites before the LORD: and the children of Israel shall put their hands upon the Levites:
3951	125	11	And Aaron shall offer the Levites before the LORD for an offering of the children of Israel, that they may execute the service of the LORD.
3952	125	12	And the Levites shall lay their hands upon the heads of the bullocks: and thou shalt offer the one for a sin offering, and the other for a burnt offering, unto the LORD, to make an atonement for the Levites.
3953	125	13	And thou shalt set the Levites before Aaron, and before his sons, and offer them for an offering unto the LORD.
3954	125	14	Thus shalt thou separate the Levites from among the children of Israel: and the Levites shall be mine.
3955	125	15	And after that shall the Levites go in to do the service of the tabernacle of the congregation: and thou shalt cleanse them, and offer them for an offering.
3956	125	16	For they are wholly given unto me from among the children of Israel; instead of such as open every womb, even instead of the firstborn of all the children of Israel, have I taken them unto me.
3957	125	17	For all the firstborn of the children of Israel are mine, both man and beast: on the day that I smote every firstborn in the land of Egypt I sanctified them for myself.
3958	125	18	And I have taken the Levites for all the firstborn of the children of Israel.
3959	125	19	And I have given the Levites as a gift to Aaron and to his sons from among the children of Israel, to do the service of the children of Israel in the tabernacle of the congregation, and to make an atonement for the children of Israel: that there be no plague among the children of Israel, when the children of Israel come nigh unto the sanctuary.
3960	125	20	And Moses, and Aaron, and all the congregation of the children of Israel, did to the Levites according unto all that the LORD commanded Moses concerning the Levites, so did the children of Israel unto them.
3961	125	21	And the Levites were purified, and they washed their clothes; and Aaron offered them as an offering before the LORD; and Aaron made an atonement for them to cleanse them.
3962	125	22	And after that went the Levites in to do their service in the tabernacle of the congregation before Aaron, and before his sons: as the LORD had commanded Moses concerning the Levites, so did they unto them.
3963	125	23	And the LORD spake unto Moses, saying,
3964	125	24	This is it that belongeth unto the Levites: from twenty and five years old and upward they shall go in to wait upon the service of the tabernacle of the congregation:
3965	125	25	And from the age of fifty years they shall cease waiting upon the service thereof, and shall serve no more:
3966	125	26	But shall minister with their brethren in the tabernacle of the congregation, to keep the charge, and shall do no service. Thus shalt thou do unto the Levites touching their charge.
3967	126	1	AND the LORD spake unto Moses in the wilderness of Sinai, in the first month of the second year after they were come out of the land of Egypt, saying,
3968	126	2	Let the children of Israel also keep the passover at his appointed season.
3969	126	3	In the fourteenth day of this month, at even, ye shall keep it in his appointed season: according to all the rites of it, and according to all the ceremonies thereof, shall ye keep it.
3970	126	4	And Moses spake unto the children of Israel, that they should keep the passover.
3971	126	5	And they kept the passover on the fourteenth day of the first month at even in the wilderness of Sinai: according to all that the LORD commanded Moses, so did the children of Israel.
3972	126	6	And there were certain men, who were defiled by the dead body of a man, that they could not keep the passover on that day: and they came before Moses and before Aaron on that day:
3973	126	7	And those men said unto him, We are defiled by the dead body of a man: wherefore are we kept back, that we may not offer an offering of the LORD in his appointed season among the children of Israel?
3974	126	8	And Moses said unto them, Stand still, and I will hear what the LORD will command concerning you.
3975	126	9	And the LORD spake unto Moses, saying,
3976	126	10	Speak unto the children of Israel, saying, If any man of you or of your posterity shall be unclean by reason of a dead body, or be in a journey afar off, yet he shall keep the passover unto the LORD.
3977	126	11	The fourteenth day of the second month at even they shall keep it, and eat it with unleavened bread and bitter herbs.
3978	126	12	They shall leave none of it unto the morning, nor break any bone of it: according to all the ordinances of the passover they shall keep it.
3979	126	13	But the man that is clean, and is not in a journey, and forbeareth to keep the passover, even the same soul shall be cut off from among his people: because he brought not the offering of the LORD in his appointed season, that man shall bear his sin.
3980	126	14	And if a stranger shall sojourn among you, and will keep the passover unto the LORD; according to the ordinance of the passover, and according to the manner thereof, so shall he do: ye shall have one ordinance, both for the stranger, and for him that was born in the land.
3981	126	15	And on the day that the tabernacle was reared up the cloud covered the tabernacle, namely, the tent of the testimony: and at even there was upon the tabernacle as it were the appearance of fire, until the morning.
3982	126	16	So it was alway: the cloud covered it by day, and the appearance of fire by night.
3983	126	17	And when the cloud was taken up from the tabernacle, then after that the children of Israel journeyed: and in the place where the cloud abode, there the children of Israel pitched their tents.
3984	126	18	At the commandment of the LORD the children of Israel journeyed, and at the commandment of the LORD they pitched: as long as the cloud abode upon the tabernacle they rested in their tents.
3985	126	19	And when the cloud tarried long upon the tabernacle many days, then the children of Israel kept the charge of the LORD, and journeyed not.
3986	126	20	And so it was, when the cloud was a few days upon the tabernacle; according to the commandment of the LORD they abode in their tents, and according to the commandment of the LORD they journeyed.
3987	126	21	And so it was, when the cloud abode from even unto the morning, and that the cloud was taken up in the morning, then they journeyed: whether it was by day or by night that the cloud was taken up, they journeyed.
3988	126	22	Or whether it were two days, or a month, or a year, that the cloud tarried upon the tabernacle, remaining thereon, the children of Israel abode in their tents, and journeyed not: but when it was taken up, they journeyed.
3989	126	23	At the commandment of the LORD they rested in the tents, and at the commandment of the LORD they journeyed: they kept the charge of the LORD, at the commandment of the LORD by the hand of Moses.
3990	127	1	AND the LORD spake unto Moses, saying,
3991	127	2	Make thee two trumpets of silver; of a whole piece shalt thou make them: that thou mayest use them for the calling of the assembly, and for the journeying of the camps.
3992	127	3	And when they shall blow with them, all the assembly shall assemble themselves to thee at the door of the tabernacle of the congregation.
3993	127	4	And if they blow but with one trumpet, then the princes, which are heads of the thousands of Israel, shall gather themselves unto thee.
3994	127	5	When ye blow an alarm, then the camps that lie on the east parts shall go forward.
3995	127	6	When ye blow an alarm the second time, then the camps that lie on the south side shall take their journey: they shall blow an alarm for their journeys.
3996	127	7	But when the congregation is to be gathered together, ye shall blow, but ye shall not sound an alarm.
3997	127	8	And the sons of Aaron, the priests, shall blow with the trumpets; and they shall be to you for an ordinance for ever throughout your generations.
3998	127	9	And if ye go to war in your land against the enemy that oppresseth you, then ye shall blow an alarm with the trumpets; and ye shall be remembered before the LORD your God, and ye shall be saved from your enemies.
3999	127	10	Also in the day of your gladness, and in your solemn days, and in the beginnings of your months, ye shall blow with the trumpets over your burnt offerings, and over the sacrifices of your peace offerings; that they may be to you for a memorial before your God: I am the LORD your God.
4000	127	11	And it came to pass on the twentieth day of the second month, in the second year, that the cloud was taken up from off the tabernacle of the testimony.
4001	127	12	And the children of Israel took their journeys out of the wilderness of Sinai; and the cloud rested in the wilderness of Paran.
4002	127	13	And they first took their journey according to the commandment of the LORD by the hand of Moses.
4003	127	14	In the first place went the standard of the camp of the children of Judah according to their armies: and over his host was Nahshon the son of Amminadab.
4004	127	15	And over the host of the tribe of the children of Issachar was Nethaneel the son of Zuar.
4005	127	16	And over the host of the tribe of the children of Zebulun was Eliab the son of Helon.
4006	127	17	And the tabernacle was taken down; and the sons of Gershon and the sons of Merari set forward, bearing the tabernacle.
4007	127	18	And the standard of the camp of Reuben set forward according to their armies: and over his host was Elizur the son of Shedeur.
4008	127	19	And over the host of the tribe of the children of Simeon was Shelumiel the son of Zurishaddai.
4009	127	20	And over the host of the tribe of the children of Gad was Eliasaph the son of Deuel.
4010	127	21	And the Kohathites set forward, bearing the sanctuary: and the other did set up the tabernacle against they came.
4011	127	22	And the standard of the camp of the children of Ephraim set forward according to their armies: and over his host was Elishama the son of Ammihud.
4012	127	23	And over the host of the tribe of the children of Manasseh was Gamaliel the son of Pedahzur.
4013	127	24	And over the host of the tribe of the children of Benjamin was Abidan the son of Gideoni.
4014	127	25	And the standard of the camp of the children of Dan set forward, which was the rereward of all the camps throughout their hosts: and over his host was Ahiezer the son of Ammishaddai.
4015	127	26	And over the host of the tribe of the children of Asher was Pagiel the son of Ocran.
4016	127	27	And over the host of the tribe of the children of Naphtali was Ahira the son of Enan.
4017	127	28	Thus were the journeyings of the children of Israel according to their armies, when they set forward.
4018	127	29	And Moses said unto Hobab, the son of Raguel the Midianite, Moses' father in law, We are journeying unto the place of which the LORD said, I will give it you: come thou with us, and we will do thee good: for the LORD hath spoken good concerning Israel.
4019	127	30	And he said unto him, I will not go; but I will depart to mine own land, and to my kindred.
4020	127	31	And he said, Leave us not, I pray thee; forasmuch as thou knowest how we are to encamp in the wilderness, and thou mayest be to us instead of eyes.
4021	127	32	And it shall be, if thou go with us, yea, it shall be, that what goodness the LORD shall do unto us, the same will we do unto thee.
4022	127	33	And they departed from the mount of the LORD three days' journey: and the ark of the covenant of the LORD went before them in the three days' journey, to search out a resting place for them.
4023	127	34	And the cloud of the LORD was upon them by day, when they went out of the camp.
4024	127	35	And it came to pass, when the ark set forward, that Moses said, Rise up, LORD, and let thine enemies be scattered; and let them that hate thee flee before thee.
4025	127	36	And when it rested, he said, Return, O LORD, unto the many thousands of Israel.
4026	128	1	AND when the people complained, it displeased the LORD: and the LORD heard it; and his anger was kindled; and the fire of the LORD burnt among them, and consumed them that were in the uttermost parts of the camp.
4027	128	2	And the people cried unto Moses; and when Moses prayed unto the LORD, the fire was quenched.
4028	128	3	And he called the name of the place Taberah: because the fire of the LORD burnt among them.
4029	128	4	And the mixt multitude that was among them fell a lusting: and the children of Israel also wept again, and said, Who shall give us flesh to eat?
4030	128	5	We remember the fish, which we did eat in Egypt freely; the cucumbers, and the melons, and the leeks, and the onions, and the garlick:
4031	128	6	But now our soul is dried away: there is nothing at all, beside this manna, before our eyes.
4032	128	7	And the manna was as coriander seed, and the colour thereof as the colour of bdellium.
4033	128	8	And the people went about, and gathered it, and ground it in mills, or beat it in a mortar, and baked it in pans, and made cakes of it: and the taste of it was as the taste of fresh oil.
4034	128	9	And when the dew fell upon the camp in the night, the manna fell upon it.
4035	128	10	Then Moses heard the people weep throughout their families, every man in the door of his tent: and the anger of the LORD was kindled greatly; Moses also was displeased.
4036	128	11	And Moses said unto the LORD, Wherefore hast thou afflicted thy servant? and wherefore have I not found favour in thy sight, that thou layest the burden of all this people upon me?
4037	128	12	Have I conceived all this people? have I begotten them, that thou shouldest say unto me, Carry them in thy bosom, as a nursing father beareth the sucking child, unto the land which thou swarest unto their fathers?
4038	128	13	Whence should I have flesh to give unto all this people? for they weep unto me, saying, Give us flesh, that we may eat.
4039	128	14	I am not able to bear all this people alone, because it is too heavy for me.
4040	128	15	And if thou deal thus with me, kill me, I pray thee, out of hand, if I have found favour in thy sight; and let me not see my wretchedness.
4041	128	16	And the LORD said unto Moses, Gather unto me seventy men of the elders of Israel, whom thou knowest to be the elders of the people, and officers over them; and bring them unto the tabernacle of the congregation, that they may stand there with thee.
4042	128	17	And I will come down and talk with thee there: and I will take of the spirit which is upon thee, and will put it upon them; and they shall bear the burden of the people with thee, that thou bear it not thyself alone.
4043	128	18	And say thou unto the people, Sanctify yourselves against to morrow, and ye shall eat flesh: for ye have wept in the ears of the LORD, saying, Who shall give us flesh to eat? for it was well with us in Egypt: therefore the LORD will give you flesh, and ye shall eat.
4044	128	19	Ye shall not eat one day, nor two days, nor five days, neither ten days, nor twenty days;
4045	128	20	But even a whole month, until it come out at your nostrils, and it be loathsome unto you: because that ye have despised the LORD which is among you, and have wept before him, saying, Why came we forth out of Egypt?
4046	128	21	And Moses said, The people, among whom I am, are six hundred thousand footmen; and thou hast said, I will give them flesh, that they may eat a whole month.
4047	128	22	Shall the flocks and the herds be slain for them, to suffice them? or shall all the fish of the sea be gathered together for them, to suffice them?
4048	128	23	And the LORD said unto Moses, Is the LORD's hand waxed short? thou shalt see now whether my word shall come to pass unto thee or not.
4049	128	24	And Moses went out, and told the people the words of the LORD, and gathered the seventy men of the elders of the people, and set them round about the tabernacle.
4050	128	25	And the LORD came down in a cloud, and spake unto him, and took of the spirit that was upon him, and gave it unto the seventy elders: and it came to pass, that, when the spirit rested upon them, they prophesied, and did not cease.
4051	128	26	But there remained two of the men in the camp, the name of the one was Eldad, and the name of the other Medad: and the spirit rested upon them; and they were of them that were written, but went not out unto the tabernacle: and they prophesied in the camp.
4052	128	27	And there ran a young man, and told Moses, and said, Eldad and Medad do prophesy in the camp.
4053	128	28	And Joshua the son of Nun, the servant of Moses, one of his young men, answered and said, My lord Moses, forbid them.
4054	128	29	And Moses said unto him, Enviest thou for my sake? would God that all the LORD's people were prophets, and that the LORD would put his spirit upon them!
4055	128	30	And Moses gat him into the camp, he and the elders of Israel.
4056	128	31	And there went forth a wind from the LORD, and brought quails from the sea, and let them fall by the camp, as it were a day's journey on this side, and as it were a day's journey on the other side, round about the camp, and as it were two cubits high upon the face of the earth.
4057	128	32	And the people stood up all that day, and all that night, and all the next day, and they gathered the quails: he that gathered least gathered ten homers: and they spread them all abroad for themselves round about the camp.
4058	128	33	And while the flesh was yet between their teeth, ere it was chewed, the wrath of the LORD was kindled against the people, and the LORD smote the people with a very great plague.
4059	128	34	And he called the name of that place Kibroth-hattaavah: because there they buried the people that lusted.
4060	128	35	And the people journeyed from Kibroth-hattaavah unto Hazeroth; and abode at Hazeroth.
4061	129	1	AND Miriam and Aaron spake against Moses because of the Ethiopian woman whom he had married: for he had married an Ethiopian woman.
4062	129	2	And they said, Hath the LORD indeed spoken only by Moses? hath he not spoken also by us? And the LORD heard it.
4063	129	3	(Now the man Moses was very meek, above all the men which were upon the face of the earth.)
4064	129	4	And the LORD spake suddenly unto Moses, and unto Aaron, and unto Miriam, Come out ye three unto the tabernacle of the congregation. And they three came out.
4065	129	5	And the LORD came down in the pillar of the cloud, and stood in the door of the tabernacle, and called Aaron and Miriam: and they both came forth.
4066	129	6	And he said, Hear now my words: If there be a prophet among you, I the LORD will make myself known unto him in a vision, and will speak unto him in a dream.
4067	129	7	My servant Moses is not so, who is faithful in all mine house.
4068	129	8	With him will I speak mouth to mouth, even apparently, and not in dark speeches; and the similitude of the LORD shall he behold: wherefore then were ye not afraid to speak against my servant Moses?
4069	129	9	And the anger of the LORD was kindled against them; and he departed.
4070	129	10	And the cloud departed from off the tabernacle; and, behold, Miriam became leprous, white as snow: and Aaron looked upon Miriam, and, behold, she was leprous.
4071	129	11	And Aaron said unto Moses, Alas, my lord, I beseech thee, lay not the sin upon us, wherein we have done foolishly, and wherein we have sinned.
4072	129	12	Let her not be as one dead, of whom the flesh is half consumed when he cometh out of his mother's womb.
4073	129	13	And Moses cried unto the LORD, saying, Heal her now, O God, I beseech thee.
4074	129	14	And the LORD said unto Moses, If her father had but spit in her face, should she not be ashamed seven days? let her be shut out from the camp seven days, and after that let her be received in again.
4075	129	15	And Miriam was shut out from the camp seven days: and the people journeyed not till Miriam was brought in again.
4076	129	16	And afterward the people removed from Hazeroth, and pitched in the wilderness of Paran.
4077	130	1	AND the LORD spake unto Moses, saying,
4078	130	2	Send thou men, that they may search the land of Canaan, which I give unto the children of Israel: of every tribe of their fathers shall ye send a man, every one a ruler among them.
4079	130	3	And Moses by the commandment of the LORD sent them from the wilderness of Paran: all those men were heads of the children of Israel.
4080	130	4	And these were their names: of the tribe of Reuben, Shammua the son of Zaccur.
4081	130	5	Of the tribe of Simeon, Shaphat the son of Hori.
4082	130	6	Of the tribe of Judah, Caleb the son of Jephunneh.
4083	130	7	Of the tribe of Issachar, Igal the son of Joseph.
4084	130	8	Of the tribe of Ephraim, Oshea the son of Nun.
4085	130	9	Of the tribe of Benjamin, Palti the son of Raphu.
4086	130	10	Of the tribe of Zebulun, Gaddiel the son of Sodi.
4087	130	11	Of the tribe of Joseph, namely, of the tribe of Manasseh, Gaddi the son of Susi.
4088	130	12	Of the tribe of Dan, Ammiel the son of Gemalli.
4089	130	13	Of the tribe of Asher, Sethur the son of Michael.
4090	130	14	Of the tribe of Naphtali, Nahbi the son of Vophsi.
4091	130	15	Of the tribe of Gad, Geuel the son of Machi.
4092	130	16	These are the names of the men which Moses sent to spy out the land. And Moses called Oshea the son of Nun Jehoshua.
4093	130	17	And Moses sent them to spy out the land of Canaan, and said unto them, Get you up this way southward, and go up into the mountain:
4094	130	18	And see the land, what it is; and the people that dwelleth therein, whether they be strong or weak, few or many;
4095	130	19	And what the land is that they dwell in, whether it be good or bad; and what cities they be that they dwell in, whether in tents, or in strong holds;
4096	130	20	And what the land is, whether it be fat or lean, whether there be wood therein, or not. And be ye of good courage, and bring of the fruit of the land. Now the time was the time of the firstripe grapes.
4097	130	21	So they went up, and searched the land from the wilderness of Zin unto Rehob, as men come to Hamath.
4098	130	22	And they ascended by the south, and came unto Hebron; where Ahiman, Sheshai, and Talmai, the children of Anak, were. (Now Hebron was built seven years before Zoan in Egypt.)
4099	130	23	And they came unto the brook of Eshcol, and cut down from thence a branch with one cluster of grapes, and they bare it between two upon a staff; and they brought of the pomegranates, and of the figs.
4100	130	24	The place was called the brook Eshcol, because of the cluster of grapes which the children of Israel cut down from thence.
4101	130	25	And they returned from searching of the land after forty days.
4102	130	26	And they went and came to Moses, and to Aaron, and to all the congregation of the children of Israel, unto the wilderness of Paran, to Kadesh; and brought back word unto them, and unto all the congregation, and shewed them the fruit of the land.
4103	130	27	And they told him, and said, We came unto the land whither thou sentest us, and surely it floweth with milk and honey; and this is the fruit of it.
4104	130	28	Nevertheless the people be strong that dwell in the land, and the cities are walled, and very great: and moreover we saw the children of Anak there.
4105	130	29	The Amalekites dwell in the land of the south: and the Hittites, and the Jebusites, and the Amorites, dwell in the mountains: and the Canaanites dwell by the sea, and by the coast of Jordan.
4106	130	30	And Caleb stilled the people before Moses, and said, Let us go up at once, and possess it; for we are well able to overcome it.
4107	130	31	But the men that went up with him said, We be not able to go up against the people; for they are stronger than we.
4108	130	32	And they brought up an evil report of the land which they had searched unto the children of Israel, saying, The land, through which we have gone to search it, is a land that eateth up the inhabitants thereof; and all the people that we saw in it are men of a great stature.
4109	130	33	And there we saw the giants, the sons of Anak, which come of the giants: and we were in our own sight as grasshoppers, and so we were in their sight.
4110	131	1	AND all the congregation lifted up their voice, and cried; and the people wept that night.
4111	131	2	And all the children of Israel murmured against Moses and against Aaron: and the whole congregation said unto them, Would God that we had died in the land of Egypt! or would God we had died in this wilderness!
4112	131	3	And wherefore hath the LORD brought us unto this land, to fall by the sword, that our wives and our children should be a prey? were it not better for us to return into Egypt?
4113	131	4	And they said one to another, Let us make a captain, and let us return into Egypt.
4114	131	5	Then Moses and Aaron fell on their faces before all the assembly of the congregation of the children of Israel.
4115	131	6	And Joshua the son of Nun, and Caleb the son of Jephunneh, which were of them that searched the land, rent their clothes:
4116	131	7	And they spake unto all the company of the children of Israel, saying, The land, which we passed through to search it, is an exceeding good land.
4117	131	8	If the LORD delight in us, then he will bring us into this land, and give it us; a land which floweth with milk and honey.
4118	131	9	Only rebel not ye against the LORD, neither fear ye the people of the land; for they are bread for us: their defence is departed from them, and the LORD is with us: fear them not.
4119	131	10	But all the congregation bade stone them with stones. And the glory of the LORD appeared in the tabernacle of the congregation before all the children of Israel.
4120	131	11	And the LORD said unto Moses, How long will this people provoke me? and how long will it be ere they believe me, for all the signs which I have shewed among them?
4121	131	12	I will smite them with the pestilence, and disinherit them, and will make of thee a greater nation and mightier than they.
4122	131	13	And Moses said unto the LORD, Then the Egyptians shall hear it, (for thou broughtest up this people in thy might from among them;)
4123	131	14	And they will tell it to the inhabitants of this land: for they have heard that thou LORD art among this people, that thou LORD art seen face to face, and that thy cloud standeth over them, and that thou goest before them, by day time in a pillar of a cloud, and in a pillar of fire by night.
4124	131	15	Now if thou shalt kill all this people as one man, then the nations which have heard the fame of thee will speak, saying,
4125	131	16	Because the LORD was not able to bring this people into the land which he sware unto them, therefore he hath slain them in the wilderness.
4126	131	17	And now, I beseech thee, let the power of my LORD be great, according as thou hast spoken, saying,
4127	131	18	The LORD is longsuffering, and of great mercy, forgiving iniquity and transgression, and by no means clearing the guilty, visiting the iniquity of the fathers upon the children unto the third and fourth generation.
4128	131	19	Pardon, I beseech thee, the iniquity of this people according unto the greatness of thy mercy, and as thou hast forgiven this people, from Egypt even until now.
4129	131	20	And the LORD said, I have pardoned according to thy word:
4130	131	21	But as truly as I live, all the earth shall be filled with the glory of the LORD.
4131	131	22	Because all those men which have seen my glory, and my miracles, which I did in Egypt and in the wilderness, and have tempted me now these ten times, and have not hearkened to my voice;
4132	131	23	Surely they shall not see the land which I sware unto their fathers, neither shall any of them that provoked me see it:
4133	131	24	But my servant Caleb, because he had another spirit with him, and hath followed me fully, him will I bring into the land whereinto he went; and his seed shall possess it.
4134	131	25	(Now the Amalekites and the Canaanites dwelt in the valley.) To morrow turn you, and get you into the wilderness by the way of the Red sea.
4135	131	26	And the LORD spake unto Moses and unto Aaron, saying,
4136	131	27	How long shall I bear with this evil congregation, which murmur against me? I have heard the murmurings of the children of Israel, which they murmur against me.
4137	131	28	Say unto them, As truly as I live, saith the LORD, as ye have spoken in mine ears, so will I do to you:
4138	131	29	Your carcases shall fall in this wilderness; and all that were numbered of you, according to your whole number, from twenty years old and upward, which have murmured against me,
4139	131	30	Doubtless ye shall not come into the land, concerning which I sware to make you dwell therein, save Caleb the son of Jephunneh, and Joshua the son of Nun.
4140	131	31	But your little ones, which ye said should be a prey, them will I bring in, and they shall know the land which ye have despised.
4141	131	32	But as for you, your carcases, they shall fall in this wilderness.
4142	131	33	And your children shall wander in the wilderness forty years, and bear your whoredoms, until your carcases be wasted in the wilderness.
4143	131	34	After the number of the days in which ye searched the land, even forty days, each day for a year, shall ye bear your iniquities, even forty years, and ye shall know my breach of promise.
4144	131	35	I the LORD have said, I will surely do it unto all this evil congregation, that are gathered together against me: in this wilderness they shall be consumed, and there they shall die.
4145	131	36	And the men, which Moses sent to search the land, who returned, and made all the congregation to murmur against him, by bringing up a slander upon the land,
4146	131	37	Even those men that did bring up the evil report upon the land, died by the plague before the LORD.
4147	131	38	But Joshua the son of Nun, and Caleb the son of Jephunneh, which were of the men that went to search the land, lived still.
4148	131	39	And Moses told these sayings unto all the children of Israel: and the people mourned greatly.
4149	131	40	And they rose up early in the morning, and gat them up into the top of the mountain, saying, Lo, we be here, and will go up unto the place which the LORD hath promised: for we have sinned.
4150	131	41	And Moses said, Wherefore now do ye transgress the commandment of the LORD? but it shall not prosper.
4151	131	42	Go not up, for the LORD is not among you; that ye be not smitten before your enemies.
4152	131	43	For the Amalekites and the Canaanites are there before you, and ye shall fall by the sword: because ye are turned away from the LORD, therefore the LORD will not be with you.
4153	131	44	But they presumed to go up unto the hill top: nevertheless the ark of the covenant of the LORD, and Moses, departed not out of the camp.
4154	131	45	Then the Amalekites came down, and the Canaanites which dwelt in that hill, and smote them, and discomfited them, even unto Hormah.
4155	132	1	AND the LORD spake unto Moses, saying,
4156	132	2	Speak unto the children of Israel, and say unto them, When ye be come into the land of your habitations, which I give unto you,
4157	132	3	And will make an offering by fire unto the LORD, a burnt offering, or a sacrifice in performing a vow, or in a freewill offering, or in your solemn feasts, to make a sweet savour unto the LORD, of the herd, or of the flock:
4158	132	4	Then shall he that offereth his offering unto the LORD bring a meat offering of a tenth deal of flour mingled with the fourth part of an hin of oil.
4159	132	5	And the fourth part of an hin of wine for a drink offering shalt thou prepare with the burnt offering or sacrifice, for one lamb.
4160	132	6	Or for a ram, thou shalt prepare for a meat offering two tenth deals of flour mingled with the third part of an hin of oil.
4161	132	7	And for a drink offering thou shalt offer the third part of an hin of wine, for a sweet savour unto the LORD.
4162	132	8	And when thou preparest a bullock for a burnt offering, or for a sacrifice in performing a vow, or peace offerings unto the LORD:
4163	132	9	Then shall he bring with a bullock a meat offering of three tenth deals of flour mingled with half an hin of oil.
4164	132	10	And thou shalt bring for a drink offering half an hin of wine, for an offering made by fire, of a sweet savour unto the LORD.
4165	132	11	Thus shall it be done for one bullock, or for one ram, or for a lamb, or a kid.
4166	132	12	According to the number that ye shall prepare, so shall ye do to every one according to their number.
4167	132	13	All that are born of the country shall do these things after this manner, in offering an offering made by fire, of a sweet savour unto the LORD.
4168	132	14	And if a stranger sojourn with you, or whosoever be among you in your generations, and will offer an offering made by fire, of a sweet savour unto the LORD; as ye do, so he shall do.
4169	132	15	One ordinance shall be both for you of the congregation, and also for the stranger that sojourneth with you, an ordinance for ever in your generations: as ye are, so shall the stranger be before the LORD.
4170	132	16	One law and one manner shall be for you, and for the stranger that sojourneth with you.
4171	132	17	And the LORD spake unto Moses, saying,
4172	132	18	Speak unto the children of Israel, and say unto them, When ye come into the land whither I bring you,
4173	132	19	Then it shall be, that, when ye eat of the bread of the land, ye shall offer up an heave offering unto the LORD.
4174	132	20	Ye shall offer up a cake of the first of your dough for an heave offering: as ye do the heave offering of the threshingfloor, so shall ye heave it.
4175	132	21	Of the first of your dough ye shall give unto the LORD an heave offering in your generations.
4176	132	22	And if ye have erred, and not observed all these commandments, which the LORD hath spoken unto Moses,
4177	132	23	Even all that the LORD hath commanded you by the hand of Moses, from the day that the LORD commanded Moses, and henceforward among your generations;
4178	132	24	Then it shall be, if ought be committed by ignorance without the knowledge of the congregation, that all the congregation shall offer one young bullock for a burnt offering, for a sweet savour unto the LORD, with his meat offering, and his drink offering, according to the manner, and one kid of the goats for a sin offering.
4179	132	25	And the priest shall make an atonement for all the congregation of the children of Israel, and it shall be forgiven them; for it is ignorance: and they shall bring their offering, a sacrifice made by fire unto the LORD, and their sin offering before the LORD, for their ignorance:
4180	132	26	And it shall be forgiven all the congregation of the children of Israel, and the stranger that sojourneth among them; seeing all the people were in ignorance.
4181	132	27	And if any soul sin through ignorance, then he shall bring a she goat of the first year for a sin offering.
4182	132	28	And the priest shall make an atonement for the soul that sinneth ignorantly, when he sinneth by ignorance before the LORD, to make an atonement for him; and it shall be forgiven him.
4183	132	29	Ye shall have one law for him that sinneth through ignorance, both for him that is born among the children of Israel, and for the stranger that sojourneth among them.
4184	132	30	But the soul that doeth ought presumptuously, whether he be born in the land, or a stranger, the same reproacheth the LORD; and that soul shall be cut off from among his people.
4185	132	31	Because he hath despised the word of the LORD, and hath broken his commandment, that soul shall utterly be cut off; his iniquity shall be upon him.
4186	132	32	And while the children of Israel were in the wilderness, they found a man that gathered sticks upon the sabbath day.
4187	132	33	And they that found him gathering sticks brought him unto Moses and Aaron, and unto all the congregation.
4188	132	34	And they put him in ward, because it was not declared what should be done to him.
4189	132	35	And the LORD said unto Moses, The man shall be surely put to death: all the congregation shall stone him with stones without the camp.
4190	132	36	And all the congregation brought him without the camp, and stoned him with stones, and he died; as the LORD commanded Moses.
4191	132	37	And the LORD spake unto Moses, saying,
4192	132	38	Speak unto the children of Israel, and bid them that they make them fringes in the borders of their garments throughout their generations, and that they put upon the fringe of the borders a ribband of blue:
4193	132	39	And it shall be unto you for a fringe, that ye may look upon it, and remember all the commandments of the LORD, and do them; and that ye seek not after your own heart and your own eyes, after which ye use to go a whoring:
4194	132	40	That ye may remember, and do all my commandments, and be holy unto your God.
4195	132	41	I am the LORD your God, which brought you out of the land of Egypt, to be your God: I am the LORD your God.
4196	133	1	NOW Korah, the son of Izhar, the son of Kohath, the son of Levi, and Dathan and Abiram, the sons of Eliab, and On, the son of Peleth, sons of Reuben, took men:
4197	133	2	And they rose up before Moses, with certain of the children of Israel, two hundred and fifty princes of the assembly, famous in the congregation, men of renown:
4198	133	3	And they gathered themselves together against Moses and against Aaron, and said unto them, Ye take too much upon you, seeing all the congregation are holy, every one of them, and the LORD is among them: wherefore then lift ye up yourselves above the congregation of the LORD?
4199	133	4	And when Moses heard it, he fell upon his face:
4200	133	5	And he spake unto Korah and unto all his company, saying, Even to morrow the LORD will shew who are his, and who is holy; and will cause him to come near unto him: even him whom he hath chosen will he cause to come near unto him.
4201	133	6	This do; Take you censers, Korah, and all his company;
4202	133	7	And put fire therein, and put incense in them before the LORD to morrow: and it shall be that the man whom the LORD doth choose, he shall be holy: ye take too much upon you, ye sons of Levi.
4203	133	8	And Moses said unto Korah, Hear, I pray you, ye sons of Levi:
4204	133	9	Seemeth it but a small thing unto you, that the God of Israel hath separated you from the congregation of Israel, to bring you near to himself to do the service of the tabernacle of the LORD, and to stand before the congregation to minister unto them?
4205	133	10	And he hath brought thee near to him, and all thy brethren the sons of Levi with thee: and seek ye the priesthood also?
4206	133	11	For which cause both thou and all thy company are gathered together against the LORD: and what is Aaron, that ye murmur against him?
4207	133	12	And Moses sent to call Dathan and Abiram, the sons of Eliab: which said, We will not come up:
4208	133	13	Is it a small thing that thou hast brought us up out of a land that floweth with milk and honey, to kill us in the wilderness, except thou make thyself altogether a prince over us?
4209	133	14	Moreover thou hast not brought us into a land that floweth with milk and honey, or given us inheritance of fields and vineyards: wilt thou put out the eyes of these men? we will not come up.
4210	133	15	And Moses was very wroth, and said unto the LORD, Respect not thou their offering: I have not taken one ass from them, neither have I hurt one of them.
4211	133	16	And Moses said unto Korah, Be thou and all thy company before the LORD, thou, and they, and Aaron, to morrow:
4212	133	17	And take every man his censer, and put incense in them, and bring ye before the LORD every man his censer, two hundred and fifty censers; thou also, and Aaron, each of you his censer.
4213	133	18	And they took every man his censer, and put fire in them, and laid incense thereon, and stood in the door of the tabernacle of the congregation with Moses and Aaron.
4214	133	19	And Korah gathered all the congregation against them unto the door of the tabernacle of the congregation: and the glory of the LORD appeared unto all the congregation.
4215	133	20	And the LORD spake unto Moses and unto Aaron, saying,
4216	133	21	Separate yourselves from among this congregation, that I may consume them in a moment.
4217	133	22	And they fell upon their faces, and said, O God, the God of the spirits of all flesh, shall one man sin, and wilt thou be wroth with all the congregation?
4218	133	23	And the LORD spake unto Moses, saying,
4219	133	24	Speak unto the congregation, saying, Get you up from about the tabernacle of Korah, Dathan, and Abiram.
4220	133	25	And Moses rose up and went unto Dathan and Abiram; and the elders of Israel followed him.
4221	133	26	And he spake unto the congregation, saying, Depart, I pray you, from the tents of these wicked men, and touch nothing of theirs, lest ye be consumed in all their sins.
4222	133	27	So they gat up from the tabernacle of Korah, Dathan, and Abiram, on every side: and Dathan and Abiram came out, and stood in the door of their tents, and their wives, and their sons, and their little children.
4223	133	28	And Moses said, Hereby ye shall know that the LORD hath sent me to do all these works; for I have not done them of mine own mind.
4224	133	29	If these men die the common death of all men, or if they be visited after the visitation of all men; then the LORD hath not sent me.
4225	133	30	But if the LORD make a new thing, and the earth open her mouth, and swallow them up, with all that appertain unto them, and they go down quick into the pit; then ye shall understand that these men have provoked the LORD.
4226	133	31	And it came to pass, as he had made an end of speaking all these words, that the ground clave asunder that was under them:
4227	133	32	And the earth opened her mouth, and swallowed them up, and their houses, and all the men that appertained unto Korah, and all their goods.
4228	133	33	They, and all that appertained to them, went down alive into the pit, and the earth closed upon them: and they perished from among the congregation.
4229	133	34	And all Israel that were round about them fled at the cry of them: for they said, Lest the earth swallow us up also.
4230	133	35	And there came out a fire from the LORD, and consumed the two hundred and fifty men that offered incense.
4231	133	36	And the LORD spake unto Moses, saying,
4232	133	37	Speak unto Eleazar the son of Aaron the priest, that he take up the censers out of the burning, and scatter thou the fire yonder; for they are hallowed.
4233	133	38	The censers of these sinners against their own souls, let them make them broad plates for a covering of the altar: for they offered them before the LORD, therefore they are hallowed: and they shall be a sign unto the children of Israel.
4234	133	39	And Eleazar the priest took the brasen censers, wherewith they that were burnt had offered; and they were made broad plates for a covering of the altar:
4235	133	40	To be a memorial unto the children of Israel, that no stranger, which is not of the seed of Aaron, come near to offer incense before the LORD; that he be not as Korah, and as his company: as the LORD said to him by the hand of Moses.
4236	133	41	But on the morrow all the congregation of the children of Israel murmured against Moses and against Aaron, saying, Ye have killed the people of the LORD.
4237	133	42	And it came to pass, when the congregation was gathered against Moses and against Aaron, that they looked toward the tabernacle of the congregation: and, behold, the cloud covered it, and the glory of the LORD appeared.
4238	133	43	And Moses and Aaron came before the tabernacle of the congregation.
4239	133	44	And the LORD spake unto Moses, saying,
4240	133	45	Get you up from among this congregation, that I may consume them as in a moment. And they fell upon their faces.
4241	133	46	And Moses said unto Aaron, Take a censer, and put fire therein from off the altar, and put on incense, and go quickly unto the congregation, and make an atonement for them: for there is wrath gone out from the LORD; the plague is begun.
4242	133	47	And Aaron took as Moses commanded, and ran into the midst of the congregation; and, behold, the plague was begun among the people: and he put on incense, and made an atonement for the people.
4243	133	48	And he stood between the dead and the living; and the plague was stayed.
4244	133	49	Now they that died in the plague were fourteen thousand and seven hundred, beside them that died about the matter of Korah.
4245	133	50	And Aaron returned unto Moses unto the door of the tabernacle of the congregation: and the plague was stayed.
4246	134	1	AND the LORD spake unto Moses, saying,
4247	134	2	Speak unto the children of Israel, and take of every one of them a rod according to the house of their fathers, of all their princes according to the house of their fathers twelve rods: write thou every man's name upon his rod.
4248	134	3	And thou shalt write Aaron's name upon the rod of Levi: for one rod shall be for the head of the house of their fathers.
4249	134	4	And thou shalt lay them up in the tabernacle of the congregation before the testimony, where I will meet with you.
4250	134	5	And it shall come to pass, that the man's rod, whom I shall choose, shall blossom: and I will make to cease from me the murmurings of the children of Israel, whereby they murmur against you.
4251	134	6	And Moses spake unto the children of Israel, and every one of their princes gave him a rod apiece, for each prince one, according to their fathers' houses, even twelve rods: and the rod of Aaron was among their rods.
4252	134	7	And Moses laid up the rods before the LORD in the tabernacle of witness.
4253	134	8	And it came to pass, that on the morrow Moses went into the tabernacle of witness; and, behold, the rod of Aaron for the house of Levi was budded, and brought forth buds, and bloomed blossoms, and yielded almonds.
4254	134	9	And Moses brought out all the rods from before the LORD unto all the children of Israel: and they looked, and took every man his rod.
4255	134	10	And the LORD said unto Moses, Bring Aaron's rod again before the testimony, to be kept for a token against the rebels; and thou shalt quite take away their murmurings from me, that they die not.
4256	134	11	And Moses did so: as the LORD commanded him, so did he.
4257	134	12	And the children of Israel spake unto Moses, saying, Behold, we die, we perish, we all perish.
4258	134	13	Whosoever cometh any thing near unto the tabernacle of the LORD shall die: shall we be consumed with dying?
4259	135	1	AND the LORD said unto Aaron, Thou and thy sons and thy father's house with thee shall bear the iniquity of the sanctuary: and thou and thy sons with thee shall bear the iniquity of your priesthood.
4260	135	2	And thy brethren also of the tribe of Levi, the tribe of thy father, bring thou with thee, that they may be joined unto thee, and minister unto thee: but thou and thy sons with thee shall minister before the tabernacle of witness.
4261	135	3	And they shall keep thy charge, and the charge of all the tabernacle: only they shall not come nigh the vessels of the sanctuary and the altar, that neither they, nor ye also, die.
4262	135	4	And they shall be joined unto thee, and keep the charge of the tabernacle of the congregation, for all the service of the tabernacle: and a stranger shall not come nigh unto you.
4263	135	5	And ye shall keep the charge of the sanctuary, and the charge of the altar: that there be no wrath any more upon the children of Israel.
4264	135	6	And I, behold, I have taken your brethren the Levites from among the children of Israel: to you they are given as a gift for the LORD, to do the service of the tabernacle of the congregation.
4265	135	7	Therefore thou and thy sons with thee shall keep your priest's office for every thing of the altar, and within the vail; and ye shall serve: I have given your priest's office unto you as a service of gift: and the stranger that cometh nigh shall be put to death.
4266	135	8	And the LORD spake unto Aaron, Behold, I also have given thee the charge of mine heave offerings of all the hallowed things of the children of Israel; unto thee have I given them by reason of the anointing, and to thy sons, by an ordinance for ever.
4267	135	9	This shall be thine of the most holy things, reserved from the fire: every oblation of theirs, every meat offering of theirs, and every sin offering of theirs, and every trespass offering of theirs, which they shall render unto me, shall be most holy for thee and for thy sons.
4268	135	10	In the most holy place shalt thou eat it; every male shall eat it: it shall be holy unto thee.
4269	135	11	And this is thine; the heave offering of their gift, with all the wave offerings of the children of Israel: I have given them unto thee, and to thy sons and to thy daughters with thee, by a statute for ever: every one that is clean in thy house shall eat of it.
4270	135	12	All the best of the oil, and all the best of the wine, and of the wheat, the firstfruits of them which they shall offer unto the LORD, them have I given thee.
4271	135	13	And whatsoever is first ripe in the land, which they shall bring unto the LORD, shall be thine; every one that is clean in thine house shall eat of it.
4272	135	14	Every thing devoted in Israel shall be thine.
4273	135	15	Every thing that openeth the matrix in all flesh, which they bring unto the LORD, whether it be of men or beasts, shall be thine: nevertheless the firstborn of man shalt thou surely redeem, and the firstling of unclean beasts shalt thou redeem.
4274	135	16	And those that are to be redeemed from a month old shalt thou redeem, according to thine estimation, for the money of five shekels, after the shekel of the sanctuary, which is twenty gerahs.
4275	135	17	But the firstling of a cow, or the firstling of a sheep, or the firstling of a goat, thou shalt not redeem; they are holy: thou shalt sprinkle their blood upon the altar, and shalt burn their fat for an offering made by fire, for a sweet savour unto the LORD.
4276	135	18	And the flesh of them shall be thine, as the wave breast and as the right shoulder are thine.
4277	135	19	All the heave offerings of the holy things, which the children of Israel offer unto the LORD, have I given thee, and thy sons and thy daughters with thee, by a statute for ever: it is a covenant of salt for ever before the LORD unto thee and to thy seed with thee.
4278	135	20	And the LORD spake unto Aaron, Thou shalt have no inheritance in their land, neither shalt thou have any part among them: I am thy part and thine inheritance among the children of Israel.
4279	135	21	And, behold, I have given the children of Levi all the tenth in Israel for an inheritance, for their service which they serve, even the service of the tabernacle of the congregation.
4280	135	22	Neither must the children of Israel henceforth come nigh the tabernacle of the congregation, lest they bear sin, and die.
4281	135	23	But the Levites shall do the service of the tabernacle of the congregation, and they shall bear their iniquity: it shall be a statute for ever throughout your generations, that among the children of Israel they have no inheritance.
4282	135	24	But the tithes of the children of Israel, which they offer as an heave offering unto the LORD, I have given to the Levites to inherit: therefore I have said unto them, Among the children of Israel they shall have no inheritance.
4283	135	25	And the LORD spake unto Moses, saying,
4284	135	26	Thus speak unto the Levites, and say unto them, When ye take of the children of Israel the tithes which I have given you from them for your inheritance, then ye shall offer up an heave offering of it for the LORD, even a tenth part of the tithe.
4285	135	27	And this your heave offering shall be reckoned unto you, as though it were the corn of the threshingfloor, and as the fulness of the winepress.
4286	135	28	Thus ye also shall offer an heave offering unto the LORD of all your tithes, which ye receive of the children of Israel; and ye shall give thereof the LORD's heave offering to Aaron the priest.
4287	135	29	Out of all your gifts ye shall offer every heave offering of the LORD, of all the best thereof, even the hallowed part thereof out of it.
4288	135	30	Therefore thou shalt say unto them, When ye have heaved the best thereof from it, then it shall be counted unto the Levites as the increase of the threshingfloor, and as the increase of the winepress.
4289	135	31	And ye shall eat it in every place, ye and your households: for it is your reward for your service in the tabernacle of the congregation.
4290	135	32	And ye shall bear no sin by reason of it, when ye have heaved from it the best of it: neither shall ye pollute the holy things of the children of Israel, lest ye die.
4291	136	1	AND the LORD spake unto Moses and unto Aaron, saying,
4292	136	2	This is the ordinance of the law which the LORD hath commanded, saying, Speak unto the children of Israel, that they bring thee a red heifer without spot, wherein is no blemish, and upon which never came yoke:
4293	136	3	And ye shall give her unto Eleazar the priest, that he may bring her forth without the camp, and one shall slay her before his face:
4294	136	4	And Eleazar the priest shall take of her blood with his finger, and sprinkle of her blood directly before the tabernacle of the congregation seven times:
4295	136	5	And one shall burn the heifer in his sight; her skin, and her flesh, and her blood, with her dung, shall he burn:
4296	136	6	And the priest shall take cedar wood, and hyssop, and scarlet, and cast it into the midst of the burning of the heifer.
4297	136	7	Then the priest shall wash his clothes, and he shall bathe his flesh in water, and afterward he shall come into the camp, and the priest shall be unclean until the even.
4298	136	8	And he that burneth her shall wash his clothes in water, and bathe his flesh in water, and shall be unclean until the even.
4299	136	9	And a man that is clean shall gather up the ashes of the heifer, and lay them up without the camp in a clean place, and it shall be kept for the congregation of the children of Israel for a water of separation: it is a purification for sin.
4300	136	10	And he that gathereth the ashes of the heifer shall wash his clothes, and be unclean until the even: and it shall be unto the children of Israel, and unto the stranger that sojourneth among them, for a statute for ever.
4301	136	11	He that toucheth the dead body of any man shall be unclean seven days.
4302	136	12	He shall purify himself with it on the third day, and on the seventh day he shall be clean: but if he purify not himself the third day, then the seventh day he shall not be clean.
4303	136	13	Whosoever toucheth the dead body of any man that is dead, and purifieth not himself, defileth the tabernacle of the LORD; and that soul shall be cut off from Israel: because the water of separation was not sprinkled upon him, he shall be unclean; his uncleanness is yet upon him.
4304	136	14	This is the law, when a man dieth in a tent: all that come into the tent, and all that is in the tent, shall be unclean seven days.
4305	136	15	And every open vessel, which hath no covering bound upon it, is unclean.
4306	136	16	And whosoever toucheth one that is slain with a sword in the open fields, or a dead body, or a bone of a man, or a grave, shall be unclean seven days.
4307	136	17	And for an unclean person they shall take of the ashes of the burnt heifer of purification for sin, and running water shall be put thereto in a vessel:
4308	136	18	And a clean person shall take hyssop, and dip it in the water, and sprinkle it upon the tent, and upon all the vessels, and upon the persons that were there, and upon him that touched a bone, or one slain, or one dead, or a grave:
4309	136	19	And the clean person shall sprinkle upon the unclean on the third day, and on the seventh day: and on the seventh day he shall purify himself, and wash his clothes, and bathe himself in water, and shall be clean at even.
4310	136	20	But the man that shall be unclean, and shall not purify himself, that soul shall be cut off from among the congregation, because he hath defiled the sanctuary of the LORD: the water of separation hath not been sprinkled upon him; he is unclean.
4311	136	21	And it shall be a perpetual statute unto them, that he that sprinkleth the water of separation shall wash his clothes; and he that toucheth the water of separation shall be unclean until even.
4312	136	22	And whatsoever the unclean person toucheth shall be unclean; and the soul that toucheth it shall be unclean until even.
4313	137	1	THEN came the children of Israel, even the whole congregation, into the desert of Zin in the first month: and the people abode in Kadesh; and Miriam died there, and was buried there.
4314	137	2	And there was no water for the congregation: and they gathered themselves together against Moses and against Aaron.
4315	137	3	And the people chode with Moses, and spake, saying, Would God that we had died when our brethren died before the LORD!
4316	137	4	And why have ye brought up the congregation of the LORD into this wilderness, that we and our cattle should die there?
4317	137	5	And wherefore have ye made us to come up out of Egypt, to bring us in unto this evil place? it is no place of seed, or of figs, or of vines, or of pomegranates; neither is there any water to drink.
4318	137	6	And Moses and Aaron went from the presence of the assembly unto the door of the tabernacle of the congregation, and they fell upon their faces: and the glory of the LORD appeared unto them.
4319	137	7	And the LORD spake unto Moses, saying,
4320	137	8	Take the rod, and gather thou the assembly together, thou, and Aaron thy brother, and speak ye unto the rock before their eyes; and it shall give forth his water, and thou shalt bring forth to them water out of the rock: so thou shalt give the congregation and their beasts drink.
4321	137	9	And Moses took the rod from before the LORD, as he commanded him.
4322	137	10	And Moses and Aaron gathered the congregation together before the rock, and he said unto them, Hear now, ye rebels; must we fetch you water out of this rock?
4323	137	11	And Moses lifted up his hand, and with his rod he smote the rock twice: and the water came out abundantly, and the congregation drank, and their beasts also.
4324	137	12	And the LORD spake unto Moses and Aaron, Because ye believed me not, to sanctify me in the eyes of the children of Israel, therefore ye shall not bring this congregation into the land which I have given them.
4325	137	13	This is the water of Meribah; because the children of Israel strove with the LORD, and he was sanctified in them.
4326	137	14	And Moses sent messengers from Kadesh unto the king of Edom, Thus saith thy brother Israel, Thou knowest all the travail that hath befallen us:
4327	137	15	How our fathers went down into Egypt, and we have dwelt in Egypt a long time; and the Egyptians vexed us, and our fathers:
4328	137	16	And when we cried unto the LORD, he heard our voice, and sent an angel, and hath brought us forth out of Egypt: and, behold, we are in Kadesh, a city in the uttermost of thy border:
4329	137	17	Let us pass, I pray thee, through thy country: we will not pass through the fields, or through the vineyards, neither will we drink of the water of the wells: we will go by the king's high way, we will not turn to the right hand nor to the left, until we have passed thy borders.
4330	137	18	And Edom said unto him, Thou shalt not pass by me, lest I come out against thee with the sword.
4331	137	19	And the children of Israel said unto him, We will go by the high way: and if I and my cattle drink of thy water, then I will pay for it: I will only, without doing any thing else, go through on my feet.
4332	137	20	And he said, Thou shalt not go through. And Edom came out against him with much people, and with a strong hand.
4333	137	21	Thus Edom refused to give Israel passage through his border: wherefore Israel turned away from him.
4334	137	22	And the children of Israel, even the whole congregation, journeyed from Kadesh, and came unto mount Hor.
4335	137	23	And the LORD spake unto Moses and Aaron in mount Hor, by the coast of the land of Edom, saying,
4336	137	24	Aaron shall be gathered unto his people: for he shall not enter into the land which I have given unto the children of Israel, because ye rebelled against my word at the water of Meribah.
4337	137	25	Take Aaron and Eleazar his son, and bring them up unto mount Hor:
4338	137	26	And strip Aaron of his garments, and put them upon Eleazar his son: and Aaron shall be gathered unto his people, and shall die there.
4339	137	27	And Moses did as the LORD commanded: and they went up into mount Hor in the sight of all the congregation.
4340	137	28	And Moses stripped Aaron of his garments, and put them upon Eleazar his son; and Aaron died there in the top of the mount: and Moses and Eleazar came down from the mount.
4341	137	29	And when all the congregation saw that Aaron was dead, they mourned for Aaron thirty days, even all the house of Israel.
4342	138	1	AND when king Arad the Canaanite, which dwelt in the south, heard tell that Israel came by the way of the spies; then he fought against Israel, and took some of them prisoners.
4343	138	2	And Israel vowed a vow unto the LORD, and said, If thou wilt indeed deliver this people into my hand, then I will utterly destroy their cities.
4344	138	3	And the LORD hearkened to the voice of Israel, and delivered up the Canaanites; and they utterly destroyed them and their cities: and he called the name of the place Hormah.
4345	138	4	And they journeyed from mount Hor by the way of the Red sea, to compass the land of Edom: and the soul of the people was much discouraged because of the way.
4346	138	5	And the people spake against God, and against Moses, Wherefore have ye brought us up out of Egypt to die in the wilderness? for there is no bread, neither is there any water; and our soul loatheth this light bread.
4347	138	6	And the LORD sent fiery serpents among the people, and they bit the people; and much people of Israel died.
4348	138	7	Therefore the people came to Moses, and said, We have sinned, for we have spoken against the LORD, and against thee; pray unto the LORD, that he take away the serpents from us. And Moses prayed for the people.
4349	138	8	And the LORD said unto Moses, Make thee a fiery serpent, and set it upon a pole: and it shall come to pass, that every one that is bitten, when he looketh upon it, shall live.
4350	138	9	And Moses made a serpent of brass, and put it upon a pole, and it came to pass, that if a serpent had bitten any man, when he beheld the serpent of brass, he lived.
4351	138	10	And the children of Israel set forward, and pitched in Oboth.
4352	138	11	And they journeyed from Oboth, and pitched at Ije-abarim, in the wilderness which is before Moab, toward the sunrising.
4353	138	12	From thence they removed, and pitched in the valley of Zared.
4354	138	13	From thence they removed, and pitched on the other side of Arnon, which is in the wilderness that cometh out of the coasts of the Amorites: for Arnon is the border of Moab, between Moab and the Amorites.
4355	138	14	Wherefore it is said in the book of the wars of the LORD, What he did in the Red sea, and in the brooks of Arnon,
4356	138	15	And at the stream of the brooks that goeth down to the dwelling of Ar, and lieth upon the border of Moab.
4357	138	16	And from thence they went to Beer: that is the well whereof the LORD spake unto Moses, Gather the people together, and I will give them water.
4358	138	17	Then Israel sang this song, Spring up, O well; sing ye unto it:
4359	138	18	The princes digged the well, the nobles of the people digged it, by the direction of the lawgiver, with their staves. And from the wilderness they went to Mattanah:
4360	138	19	And from Mattanah to Nahaliel: and from Nahaliel to Bamoth:
4361	138	20	And from Bamoth in the valley, that is in the country of Moab, to the top of Pisgah, which looketh toward Jeshimon.
4362	138	21	And Israel sent messengers unto Sihon king of the Amorites, saying,
4363	138	22	Let me pass through thy land: we will not turn into the fields, or into the vineyards; we will not drink of the waters of the well: but we will go along by the king's high way, until we be past thy borders.
4364	138	23	And Sihon would not suffer Israel to pass through his border: but Sihon gathered all his people together, and went out against Israel into the wilderness: and he came to Jahaz, and fought against Israel.
4365	138	24	And Israel smote him with the edge of the sword, and possessed his land from Arnon unto Jabbok, even unto the children of Ammon: for the border of the children of Ammon was strong.
4366	138	25	And Israel took all these cities: and Israel dwelt in all the cities of the Amorites, in Heshbon, and in all the villages thereof.
4367	138	26	For Heshbon was the city of Sihon the king of the Amorites, who had fought against the former king of Moab, and taken all his land out of his hand, even unto Arnon.
4368	138	27	Wherefore they that speak in proverbs say, Come into Heshbon, let the city of Sihon be built and prepared:
4369	138	28	For there is a fire gone out of Heshbon, a flame from the city of Sihon: it hath consumed Ar of Moab, and the lords of the high places of Arnon.
4370	138	29	Woe to thee, Moab! thou art undone, O people of Chemosh: he hath given his sons that escaped, and his daughters, into captivity unto Sihon king of the Amorites.
4371	138	30	We have shot at them; Heshbon is perished even unto Dibon, and we have laid them waste even unto Nophah, which reacheth unto Medeba.
4372	138	31	Thus Israel dwelt in the land of the Amorites.
4373	138	32	And Moses sent to spy out Jaazer, and they took the villages thereof, and drove out the Amorites that were there.
4374	138	33	And they turned and went up by the way of Bashan: and Og the king of Bashan went out against them, he, and all his people, to the battle at Edrei.
4375	138	34	And the LORD said unto Moses, Fear him not: for I have delivered him into thy hand, and all his people, and his land; and thou shalt do to him as thou didst unto Sihon king of the Amorites, which dwelt at Heshbon.
4376	138	35	So they smote him, and his sons, and all his people, until there was none left him alive: and they possessed his land.
4377	139	1	AND the children of Israel set forward, and pitched in the plains of Moab on this side Jordan by Jericho.
4378	139	2	And Balak the son of Zippor saw all that Israel had done to the Amorites.
4379	139	3	And Moab was sore afraid of the people, because they were many: and Moab was distressed because of the children of Israel.
4380	139	4	And Moab said unto the elders of Midian, Now shall this company lick up all that are round about us, as the ox licketh up the grass of the field. And Balak the son of Zippor was king of the Moabites at that time.
4381	139	5	He sent messengers therefore unto Balaam the son of Beor to Pethor, which is by the river of the land of the children of his people, to call him, saying, Behold, there is a people come out from Egypt: behold, they cover the face of the earth, and they abide over against me:
4382	139	6	Come now therefore, I pray thee, curse me this people; for they are too mighty for me: peradventure I shall prevail, that we may smite them, and that I may drive them out of the land: for I wot that he whom thou blessest is blessed, and he whom thou cursest is cursed.
4383	139	7	And the elders of Moab and the elders of Midian departed with the rewards of divination in their hand; and they came unto Balaam, and spake unto him the words of Balak.
4384	139	8	And he said unto them, Lodge here this night, and I will bring you word again, as the LORD shall speak unto me: and the princes of Moab abode with Balaam.
4385	139	9	And God came unto Balaam, and said, What men are these with thee?
4386	139	10	And Balaam said unto God, Balak the son of Zippor, king of Moab, hath sent unto me, saying,
4387	139	11	Behold, there is a people come out of Egypt, which covereth the face of the earth: come now, curse me them; peradventure I shall be able to overcome them, and drive them out.
4388	139	12	And God said unto Balaam, Thou shalt not go with them; thou shalt not curse the people: for they are blessed.
4389	139	13	And Balaam rose up in the morning, and said unto the princes of Balak, Get you into your land: for the LORD refuseth to give me leave to go with you.
4390	139	14	And the princes of Moab rose up, and they went unto Balak, and said, Balaam refuseth to come with us.
4391	139	15	And Balak sent yet again princes, more, and more honourable than they.
4392	139	16	And they came to Balaam, and said to him, Thus saith Balak the son of Zippor, Let nothing, I pray thee, hinder thee from coming unto me:
4393	139	17	For I will promote thee unto very great honour, and I will do whatsoever thou sayest unto me: come therefore, I pray thee, curse me this people.
4394	139	18	And Balaam answered and said unto the servants of Balak, If Balak would give me his house full of silver and gold, I cannot go beyond the word of the LORD my God, to do less or more.
4395	139	19	Now therefore, I pray you, tarry ye also here this night, that I may know what the LORD will say unto me more.
4396	139	20	And God came unto Balaam at night, and said unto him, If the men come to call thee, rise up, and go with them; but yet the word which I shall say unto thee, that shalt thou do.
4397	139	21	And Balaam rose up in the morning, and saddled his ass, and went with the princes of Moab.
4398	139	22	And God's anger was kindled because he went: and the angel of the LORD stood in the way for an adversary against him. Now he was riding upon his ass, and his two servants were with him.
4399	139	23	And the ass saw the angel of the LORD standing in the way, and his sword drawn in his hand: and the ass turned aside out of the way, and went into the field: and Balaam smote the ass, to turn her into the way.
4400	139	24	But the angel of the LORD stood in a path of the vineyards, a wall being on this side, and a wall on that side.
4401	139	25	And when the ass saw the angel of the LORD, she thrust herself unto the wall, and crushed Balaam's foot against the wall: and he smote her again.
4402	139	26	And the angel of the LORD went further, and stood in a narrow place, where was no way to turn either to the right hand or to the left.
4403	139	27	And when the ass saw the angel of the LORD, she fell down under Balaam: and Balaam's anger was kindled, and he smote the ass with a staff.
4404	139	28	And the LORD opened the mouth of the ass, and she said unto Balaam, What have I done unto thee, that thou hast smitten me these three times?
4405	139	29	And Balaam said unto the ass, Because thou hast mocked me: I would there were a sword in mine hand, for now would I kill thee.
4406	139	30	And the ass said unto Balaam, Am not I thine ass, upon which thou hast ridden ever since I was thine unto this day? was I ever wont to do so unto thee? And he said, Nay.
4407	139	31	Then the LORD opened the eyes of Balaam, and he saw the angel of the LORD standing in the way, and his sword drawn in his hand: and he bowed down his head, and fell flat on his face.
4408	139	32	And the angel of the LORD said unto him, Wherefore hast thou smitten thine ass these three times? behold, I went out to withstand thee, because thy way is perverse before me:
4409	139	33	And the ass saw me, and turned from me these three times: unless she had turned from me, surely now also I had slain thee, and saved her alive.
4410	139	34	And Balaam said unto the angel of the LORD, I have sinned; for I knew not that thou stoodest in the way against me: now therefore, if it displease thee, I will get me back again.
4411	139	35	And the angel of the LORD said unto Balaam, Go with the men: but only the word that I shall speak unto thee, that thou shalt speak. So Balaam went with the princes of Balak.
4412	139	36	And when Balak heard that Balaam was come, he went out to meet him unto a city of Moab, which is in the border of Arnon, which is in the utmost coast.
4413	139	37	And Balak said unto Balaam, Did I not earnestly send unto thee to call thee? wherefore camest thou not unto me? am I not able indeed to promote thee to honour?
4414	139	38	And Balaam said unto Balak, Lo, I am come unto thee: have I now any power at all to say any thing? the word that God putteth in my mouth, that shall I speak.
4415	139	39	And Balaam went with Balak, and they came unto Kirjath-huzoth.
4416	139	40	And Balak offered oxen and sheep, and sent to Balaam, and to the princes that were with him.
4417	139	41	And it came to pass on the morrow, that Balak took Balaam, and brought him up into the high places of Baal, that thence he might see the utmost part of the people.
4418	140	1	AND Balaam said unto Balak, Build me here seven altars, and prepare me here seven oxen and seven rams.
4419	140	2	And Balak did as Balaam had spoken; and Balak and Balaam offered on every altar a bullock and a ram.
4420	140	3	And Balaam said unto Balak, Stand by thy burnt offering, and I will go: peradventure the LORD will come to meet me: and whatsoever he sheweth me I will tell thee. And he went to an high place.
4421	140	4	And God met Balaam: and he said unto him, I have prepared seven altars, and I have offered upon every altar a bullock and a ram.
4422	140	5	And the LORD put a word in Balaam's mouth, and said, Return unto Balak, and thus thou shalt speak.
4423	140	6	And he returned unto him, and, lo, he stood by his burnt sacrifice, he, and all the princes of Moab.
4424	140	7	And he took up his parable, and said, Balak the king of Moab hath brought me from Aram, out of the mountains of the east, saying, Come, curse me Jacob, and come, defy Israel.
4425	140	8	How shall I curse, whom God hath not cursed? or how shall I defy, whom the LORD hath not defied?
4426	140	9	For from the top of the rocks I see him, and from the hills I behold him: lo, the people shall dwell alone, and shall not be reckoned among the nations.
4427	140	10	Who can count the dust of Jacob, and the number of the fourth part of Israel? Let me die the death of the righteous, and let my last end be like his!
4428	140	11	And Balak said unto Balaam, What hast thou done unto me? I took thee to curse mine enemies, and, behold, thou hast blessed them altogether.
4429	140	12	And he answered and said, Must I not take heed to speak that which the LORD hath put in my mouth?
4430	140	13	And Balak said unto him, Come, I pray thee, with me unto another place, from whence thou mayest see them: thou shalt see but the utmost part of them, and shalt not see them all: and curse me them from thence.
4431	140	14	And he brought him into the field of Zophim, to the top of Pisgah, and built seven altars, and offered a bullock and a ram on every altar.
4432	140	15	And he said unto Balak, Stand here by thy burnt offering, while I meet the LORD yonder.
4433	140	16	And the LORD met Balaam, and put a word in his mouth, and said, Go again unto Balak, and say thus.
4434	140	17	And when he came to him, behold, he stood by his burnt offering, and the princes of Moab with him. And Balak said unto him, What hath the LORD spoken?
4435	140	18	And he took up his parable, and said, Rise up, Balak, and hear; hearken unto me, thou son of Zippor:
4436	140	19	God is not a man, that he should lie; neither the son of man, that he should repent: hath he said, and shall he not do it? or hath he spoken, and shall he not make it good?
4437	140	20	Behold, I have received commandment to bless: and he hath blessed; and I cannot reverse it.
4438	140	21	He hath not beheld iniquity in Jacob, neither hath he seen perverseness in Israel: the LORD his God is with him, and the shout of a king is among them.
4439	140	22	God brought them out of Egypt; he hath as it were the strength of an unicorn.
4440	140	23	Surely there is no enchantment against Jacob, neither is there any divination against Israel: according to this time it shall be said of Jacob and of Israel, What hath God wrought!
4441	140	24	Behold, the people shall rise up as a great lion, and lift up himself as a young lion: he shall not lie down until he eat of the prey, and drink the blood of the slain.
4442	140	25	And Balak said unto Balaam, Neither curse them at all, nor bless them at all.
4443	140	26	But Balaam answered and said unto Balak, Told not I thee, saying, All that the LORD speaketh, that I must do?
4444	140	27	And Balak said unto Balaam, Come, I pray thee, I will bring thee unto another place; peradventure it will please God that thou mayest curse me them from thence.
4445	140	28	And Balak brought Balaam unto the top of Peor, that looketh toward Jeshimon.
4446	140	29	And Balaam said unto Balak, Build me here seven altars, and prepare me here seven bullocks and seven rams.
4447	140	30	And Balak did as Balaam had said, and offered a bullock and a ram on every altar.
4448	141	1	AND when Balaam saw that it pleased the LORD to bless Israel, he went not, as at other times, to seek for enchantments, but he set his face toward the wilderness.
4449	141	2	And Balaam lifted up his eyes, and he saw Israel abiding in his tents according to their tribes; and the spirit of God came upon him.
4450	141	3	And he took up his parable, and said, Balaam the son of Beor hath said, and the man whose eyes are open hath said:
4451	141	4	He hath said, which heard the words of God, which saw the vision of the Almighty, falling into a trance, but having his eyes open:
4452	141	5	How goodly are thy tents, O Jacob, and thy tabernacles, O Israel!
4453	141	6	As the valleys are they spread forth, as gardens by the river's side, as the trees of lign aloes which the LORD hath planted, and as cedar trees beside the waters.
4454	141	7	He shall pour the water out of his buckets, and his seed shall be in many waters, and his king shall be higher than Agag, and his kingdom shall be exalted.
4455	141	8	God brought him forth out of Egypt; he hath as it were the strength of an unicorn: he shall eat up the nations his enemies, and shall break their bones, and pierce them through with his arrows.
4456	141	9	He couched, he lay down as a lion, and as a great lion: who shall stir him up? Blessed is he that blesseth thee, and cursed is he that curseth thee.
4457	141	10	And Balak's anger was kindled against Balaam, and he smote his hands together: and Balak said unto Balaam, I called thee to curse mine enemies, and, behold, thou hast altogether blessed them these three times.
4458	141	11	Therefore now flee thou to thy place: I thought to promote thee unto great honour; but, lo, the LORD hath kept thee back from honour.
4459	141	12	And Balaam said unto Balak, Spake I not also to thy messengers which thou sentest unto me, saying,
4460	141	13	If Balak would give me his house full of silver and gold, I cannot go beyond the commandment of the LORD, to do either good or bad of mine own mind; but what the LORD saith, that will I speak?
4461	141	14	And now, behold, I go unto my people: come therefore, and I will advertise thee what this people shall do to thy people in the latter days.
4462	141	15	And he took up his parable, and said, Balaam the son of Beor hath said, and the man whose eyes are open hath said:
4463	141	16	He hath said, which heard the words of God, and knew the knowledge of the most High, which saw the vision of the Almighty, falling into a trance, but having his eyes open:
4464	141	17	I shall see him, but not now: I shall behold him, but not nigh: there shall come a Star out of Jacob, and a Sceptre shall rise out of Israel, and shall smite the corners of Moab, and destroy all the children of Sheth.
4465	141	18	And Edom shall be a possession, Seir also shall be a possession for his enemies; and Israel shall do valiantly.
4466	141	19	Out of Jacob shall come he that shall have dominion, and shall destroy him that remaineth of the city.
4467	141	20	And when he looked on Amalek, he took up his parable, and said, Amalek was the first of the nations; but his latter end shall be that he perish for ever.
4468	141	21	And he looked on the Kenites, and took up his parable, and said, Strong is thy dwellingplace, and thou puttest thy nest in a rock.
4469	141	22	Nevertheless the Kenite shall be wasted, until Asshur shall carry thee away captive.
4470	141	23	And he took up his parable, and said, Alas, who shall live when God doeth this!
4471	141	24	And ships shall come from the coast of Chittim, and shall afflict Asshur, and shall afflict Eber, and he also shall perish for ever.
4472	141	25	And Balaam rose up, and went and returned to his place: and Balak also went his way.
4473	142	1	AND Israel abode in Shittim, and the people began to commit whoredom with the daughters of Moab.
4474	142	2	And they called the people unto the sacrifices of their gods: and the people did eat, and bowed down to their gods.
4475	142	3	And Israel joined himself unto Baal-peor: and the anger of the LORD was kindled against Israel.
4476	142	4	And the LORD said unto Moses, Take all the heads of the people, and hang them up before the LORD against the sun, that the fierce anger of the LORD may be turned away from Israel.
4477	142	5	And Moses said unto the judges of Israel, Slay ye every one his men that were joined unto Baal-peor.
4478	142	6	And, behold, one of the children of Israel came and brought unto his brethren a Midianitish woman in the sight of Moses, and in the sight of all the congregation of the children of Israel, who were weeping before the door of the tabernacle of the congregation.
4479	142	7	And when Phinehas, the son of Eleazar, the son of Aaron the priest, saw it, he rose up from among the congregation, and took a javelin in his hand;
4480	142	8	And he went after the man of Israel into the tent, and thrust both of them through, the man of Israel, and the woman through her belly. So the plague was stayed from the children of Israel.
4481	142	9	And those that died in the plague were twenty and four thousand.
4482	142	10	And the LORD spake unto Moses, saying,
4483	142	11	Phinehas, the son of Eleazar, the son of Aaron the priest, hath turned my wrath away from the children of Israel, while he was zealous for my sake among them, that I consumed not the children of Israel in my jealousy.
4484	142	12	Wherefore say, Behold, I give unto him my covenant of peace:
4485	142	13	And he shall have it, and his seed after him, even the covenant of an everlasting priesthood; because he was zealous for his God, and made an atonement for the children of Israel.
4486	142	14	Now the name of the Israelite that was slain, even that was slain with the Midianitish woman, was Zimri, the son of Salu, a prince of a chief house among the Simeonites.
4487	142	15	And the name of the Midianitish woman that was slain was Cozbi, the daughter of Zur; he was head over a people, and of a chief house in Midian.
4488	142	16	And the LORD spake unto Moses, saying,
4489	142	17	Vex the Midianites, and smite them:
4490	142	18	For they vex you with their wiles, wherewith they have beguiled you in the matter of Peor, and in the matter of Cozbi, the daughter of a prince of Midian, their sister, which was slain in the day of the plague for Peor's sake.
4491	143	1	AND it came to pass after the plague, that the LORD spake unto Moses and unto Eleazar the son of Aaron the priest, saying,
4492	143	2	Take the sum of all the congregation of the children of Israel, from twenty years old and upward, throughout their fathers' house, all that are able to go to war in Israel.
4493	143	3	And Moses and Eleazar the priest spake with them in the plains of Moab by Jordan near Jericho, saying,
4494	143	4	Take the sum of the people, from twenty years old and upward; as the LORD commanded Moses and the children of Israel, which went forth out of the land of Egypt.
4495	143	5	Reuben, the eldest son of Israel: the children of Reuben; Hanoch, of whom cometh the family of the Hanochites: of Pallu, the family of the Palluites:
4496	143	6	Of Hezron, the family of the Hezronites: of Carmi, the family of the Carmites.
4497	143	7	These are the families of the Reubenites: and they that were numbered of them were forty and three thousand and seven hundred and thirty.
4498	143	8	And the sons of Pallu; Eliab.
4499	143	9	And the sons of Eliab; Nemuel, and Dathan, and Abiram. This is that Dathan and Abiram, which were famous in the congregation, who strove against Moses and against Aaron in the company of Korah, when they strove against the LORD:
4500	143	10	And the earth opened her mouth, and swallowed them up together with Korah, when that company died, what time the fire devoured two hundred and fifty men: and they became a sign.
4501	143	11	Notwithstanding the children of Korah died not.
4502	143	12	The sons of Simeon after their families: of Nemuel, the family of the Nemuelites: of Jamin, the family of the Jaminites: of Jachin, the family of the Jachinites:
4503	143	13	Of Zerah, the family of the Zarhites: of Shaul, the family of the Shaulites.
4504	143	14	These are the families of the Simeonites, twenty and two thousand and two hundred.
4505	143	15	The children of Gad after their families: of Zephon, the family of the Zephonites: of Haggi, the family of the Haggites: of Shuni, the family of the Shunites:
4506	143	16	Of Ozni, the family of the Oznites: of Eri, the family of the Erites:
4507	143	17	Of Arod, the family of the Arodites: of Areli, the family of the Arelites.
4508	143	18	These are the families of the children of Gad according to those that were numbered of them, forty thousand and five hundred.
4509	143	19	The sons of Judah were Er and Onan: and Er and Onan died in the land of Canaan.
4510	143	20	And the sons of Judah after their families were; of Shelah, the family of the Shelanites: of Pharez, the family of the Pharzites: of Zerah, the family of the Zarhites.
4511	143	21	And the sons of Pharez were; of Hezron, the family of the Hezronites: of Hamul, the family of the Hamulites.
4512	143	22	These are the families of Judah according to those that were numbered of them, threescore and sixteen thousand and five hundred.
4513	143	23	Of the sons of Issachar after their families: of Tola, the family of the Tolaites: of Pua, the family of the Punites:
4514	143	24	Of Jashub, the family of the Jashubites: of Shimron, the family of the Shimronites.
4515	143	25	These are the families of Issachar according to those that were numbered of them, threescore and four thousand and three hundred.
4516	143	26	Of the sons of Zebulun after their families: of Sered, the family of the Sardites: of Elon, the family of the Elonites: of Jahleel, the family of the Jahleelites.
4517	143	27	These are the families of the Zebulunites according to those that were numbered of them, threescore thousand and five hundred.
4518	143	28	The sons of Joseph after their families were Manasseh and Ephraim.
4519	143	29	Of the sons of Manasseh: of Machir, the family of the Machirites: and Machir begat Gilead: of Gilead come the family of the Gileadites.
4520	143	30	These are the sons of Gilead: of Jeezer, the family of the Jeezerites: of Helek, the family of the Helekites:
4521	143	31	And of Asriel, the family of the Asrielites: and of Shechem, the family of the Shechemites:
4522	143	32	And of Shemida, the family of the Shemidaites: and of Hepher, the family of the Hepherites.
4523	143	33	And Zelophehad the son of Hepher had no sons, but daughters: and the names of the daughters of Zelophehad were Mahlah, and Noah, Hoglah, Milcah, and Tirzah.
4524	143	34	These are the families of Manasseh, and those that were numbered of them, fifty and two thousand and seven hundred.
4525	143	35	These are the sons of Ephraim after their families: of Shuthelah, the family of the Shuthalhites: of Becher, the family of the Bachrites: of Tahan, the family of the Tahanites.
4526	143	36	And these are the sons of Shuthelah: of Eran, the family of the Eranites.
4527	143	37	These are the families of the sons of Ephraim according to those that were numbered of them, thirty and two thousand and five hundred. These are the sons of Joseph after their families.
4528	143	38	The sons of Benjamin after their families: of Bela, the family of the Belaites: of Ashbel, the family of the Ashbelites: of Ahiram, the family of the Ahiramites:
4529	143	39	Of Shupham, the family of the Shuphamites: of Hupham, the family of the Huphamites.
4530	143	40	And the sons of Bela were Ard and Naaman: of Ard, the family of the Ardites: and of Naaman, the family of the Naamites.
4531	143	41	These are the sons of Benjamin after their families: and they that were numbered of them were forty and five thousand and six hundred.
4532	143	42	These are the sons of Dan after their families: of Shuham, the family of the Shuhamites. These are the families of Dan after their families.
4533	143	43	All the families of the Shuhamites, according to those that were numbered of them, were threescore and four thousand and four hundred.
4534	143	44	Of the children of Asher after their families: of Jimna, the family of the Jimnites: of Jesui, the family of the Jesuites: of Beriah, the family of the Beriites.
4535	143	45	Of the sons of Beriah: of Heber, the family of the Heberites: of Malchiel, the family of the Malchielites.
4536	143	46	And the name of the daughter of Asher was Sarah.
4537	143	47	These are the families of the sons of Asher according to those that were numbered of them; who were fifty and three thousand and four hundred.
4538	143	48	Of the sons of Naphtali after their families: of Jahzeel, the family of the Jahzeelites: of Guni, the family of the Gunites:
4539	143	49	Of Jezer, the family of the Jezerites: of Shillem, the family of the Shillemites.
4540	143	50	These are the families of Naphtali according to their families: and they that were numbered of them were forty and five thousand and four hundred.
4541	143	51	These were the numbered of the children of Israel, six hundred thousand and a thousand seven hundred and thirty.
4542	143	52	And the LORD spake unto Moses, saying,
4543	143	53	Unto these the land shall be divided for an inheritance according to the number of names.
4544	143	54	To many thou shalt give the more inheritance, and to few thou shalt give the less inheritance: to every one shall his inheritance be given according to those that were numbered of him.
4545	143	55	Notwithstanding the land shall be divided by lot: according to the names of the tribes of their fathers they shall inherit.
4546	143	56	According to the lot shall the possession thereof be divided between many and few.
4547	143	57	And these are they that were numbered of the Levites after their families: of Gershon, the family of the Gershonites: of Kohath, the family of the Kohathites: of Merari, the family of the Merarites.
4548	143	58	These are the families of the Levites: the family of the Libnites, the family of the Hebronites, the family of the Mahlites, the family of the Mushites, the family of the Korathites. And Kohath begat Amram.
4549	143	59	And the name of Amram's wife was Jochebed, the daughter of Levi, whom her mother bare to Levi in Egypt: and she bare unto Amram Aaron and Moses, and Miriam their sister.
4550	143	60	And unto Aaron was born Nadab, and Abihu, Eleazar, and Ithamar.
4551	143	61	And Nadab and Abihu died, when they offered strange fire before the LORD.
4552	143	62	And those that were numbered of them were twenty and three thousand, all males from a month old and upward: for they were not numbered among the children of Israel, because there was no inheritance given them among the children of Israel.
4553	143	63	These are they that were numbered by Moses and Eleazar the priest, who numbered the children of Israel in the plains of Moab by Jordan near Jericho.
4554	143	64	But among these there was not a man of them whom Moses and Aaron the priest numbered, when they numbered the children of Israel in the wilderness of Sinai.
4555	143	65	For the LORD had said of them, They shall surely die in the wilderness. And there was not left a man of them, save Caleb the son of Jephunneh, and Joshua the son of Nun.
4556	144	1	THEN came the daughters of Zelophehad, the son of Hepher, the son of Gilead, the son of Machir, the son of Manasseh, of the families of Manasseh the son of Joseph: and these are the names of his daughters; Mahlah, Noah, and Hoglah, and Milcah, and Tirzah.
4557	144	2	And they stood before Moses, and before Eleazar the priest, and before the princes and all the congregation, by the door of the tabernacle of the congregation, saying,
4558	144	3	Our father died in the wilderness, and he was not in the company of them that gathered themselves together against the LORD in the company of Korah; but died in his own sin, and had no sons.
4559	144	4	Why should the name of our father be done away from among his family, because he hath no son? Give unto us therefore a possession among the brethren of our father.
4560	144	5	And Moses brought their cause before the LORD.
4561	144	6	And the LORD spake unto Moses, saying,
4562	144	7	The daughters of Zelophehad speak right: thou shalt surely give them a possession of an inheritance among their father's brethren; and thou shalt cause the inheritance of their father to pass unto them.
4563	144	8	And thou shalt speak unto the children of Israel, saying, If a man die, and have no son, then ye shall cause his inheritance to pass unto his daughter.
4564	144	9	And if he have no daughter, then ye shall give his inheritance unto his brethren.
4565	144	10	And if he have no brethren, then ye shall give his inheritance unto his father's brethren.
4566	144	11	And if his father have no brethren, then ye shall give his inheritance unto his kinsman that is next to him of his family, and he shall possess it: and it shall be unto the children of Israel a statute of judgment, as the LORD commanded Moses.
4567	144	12	And the LORD said unto Moses, Get thee up into this mount Abarim, and see the land which I have given unto the children of Israel.
4568	144	13	And when thou hast seen it, thou also shalt be gathered unto thy people, as Aaron thy brother was gathered.
4569	144	14	For ye rebelled against my commandment in the desert of Zin, in the strife of the congregation, to sanctify me at the water before their eyes: that is the water of Meribah in Kadesh in the wilderness of Zin.
4570	144	15	And Moses spake unto the LORD, saying,
4571	144	16	Let the LORD, the God of the spirits of all flesh, set a man over the congregation,
4572	144	17	Which may go out before them, and which may go in before them, and which may lead them out, and which may bring them in; that the congregation of the LORD be not as sheep which have no shepherd.
4573	144	18	And the LORD said unto Moses, Take thee Joshua the son of Nun, a man in whom is the spirit, and lay thine hand upon him;
4574	144	19	And set him before Eleazar the priest, and before all the congregation; and give him a charge in their sight.
4575	144	20	And thou shalt put some of thine honour upon him, that all the congregation of the children of Israel may be obedient.
4576	144	21	And he shall stand before Eleazar the priest, who shall ask counsel for him after the judgment of Urim before the LORD: at his word shall they go out, and at his word they shall come in, both he, and all the children of Israel with him, even all the congregation.
4577	144	22	And Moses did as the LORD commanded him: and he took Joshua, and set him before Eleazar the priest, and before all the congregation:
4578	144	23	And he laid his hands upon him, and gave him a charge, as the LORD commanded by the hand of Moses.
4579	145	1	AND the LORD spake unto Moses, saying,
4580	145	2	Command the children of Israel, and say unto them, My offering, and my bread for my sacrifices made by fire, for a sweet savour unto me, shall ye observe to offer unto me in their due season.
4581	145	3	And thou shalt say unto them, This is the offering made by fire which ye shall offer unto the LORD; two lambs of the first year without spot day by day, for a continual burnt offering.
4582	145	4	The one lamb shalt thou offer in the morning, and the other lamb shalt thou offer at even;
4583	145	5	And a tenth part of an ephah of flour for a meat offering, mingled with the fourth part of an hin of beaten oil.
4584	145	6	It is a continual burnt offering, which was ordained in mount Sinai for a sweet savour, a sacrifice made by fire unto the LORD.
4585	145	7	And the drink offering thereof shall be the fourth part of an hin for the one lamb: in the holy place shalt thou cause the strong wine to be poured unto the LORD for a drink offering.
4586	145	8	And the other lamb shalt thou offer at even: as the meat offering of the morning, and as the drink offering thereof, thou shalt offer it, a sacrifice made by fire, of a sweet savour unto the LORD.
4587	145	9	And on the sabbath day two lambs of the first year without spot, and two tenth deals of flour for a meat offering, mingled with oil, and the drink offering thereof:
4588	145	10	This is the burnt offering of every sabbath, beside the continual burnt offering, and his drink offering.
4589	145	11	And in the beginnings of your months ye shall offer a burnt offering unto the LORD; two young bullocks, and one ram, seven lambs of the first year without spot;
4590	145	12	And three tenth deals of flour for a meat offering, mingled with oil, for one bullock; and two tenth deals of flour for a meat offering, mingled with oil, for one ram;
4591	145	13	And a several tenth deal of flour mingled with oil for a meat offering unto one lamb; for a burnt offering of a sweet savour, a sacrifice made by fire unto the LORD.
4592	145	14	And their drink offerings shall be half an hin of wine unto a bullock, and the third part of an hin unto a ram, and a fourth part of an hin unto a lamb: this is the burnt offering of every month throughout the months of the year.
4593	145	15	And one kid of the goats for a sin offering unto the LORD shall be offered, beside the continual burnt offering, and his drink offering.
4594	145	16	And in the fourteenth day of the first month is the passover of the LORD.
4595	145	17	And in the fifteenth day of this month is the feast: seven days shall unleavened bread be eaten.
4596	145	18	In the first day shall be an holy convocation; ye shall do no manner of servile work therein:
4597	145	19	But ye shall offer a sacrifice made by fire for a burnt offering unto the LORD; two young bullocks, and one ram, and seven lambs of the first year: they shall be unto you without blemish:
4598	145	20	And their meat offering shall be of flour mingled with oil: three tenth deals shall ye offer for a bullock, and two tenth deals for a ram;
4599	145	21	A several tenth deal shalt thou offer for every lamb, throughout the seven lambs:
4600	145	22	And one goat for a sin offering, to make an atonement for you.
4601	145	23	Ye shall offer these beside the burnt offering in the morning, which is for a continual burnt offering.
4602	145	24	After this manner ye shall offer daily, throughout the seven days, the meat of the sacrifice made by fire, of a sweet savour unto the LORD: it shall be offered beside the continual burnt offering, and his drink offering.
4603	145	25	And on the seventh day ye shall have an holy convocation; ye shall do no servile work.
4604	145	26	Also in the day of the firstfruits, when ye bring a new meat offering unto the LORD, after your weeks be out, ye shall have an holy convocation; ye shall do no servile work:
4605	145	27	But ye shall offer the burnt offering for a sweet savour unto the LORD; two young bullocks, one ram, seven lambs of the first year;
4606	145	28	And their meat offering of flour mingled with oil, three tenth deals unto one bullock, two tenth deals unto one ram,
4607	145	29	A several tenth deal unto one lamb, throughout the seven lambs;
4608	145	30	And one kid of the goats, to make an atonement for you.
4609	145	31	Ye shall offer them beside the continual burnt offering, and his meat offering, (they shall be unto you without blemish) and their drink offerings.
4610	146	1	AND in the seventh month, on the first day of the month, ye shall have an holy convocation; ye shall do no servile work: it is a day of blowing the trumpets unto you.
4611	146	2	And ye shall offer a burnt offering for a sweet savour unto the LORD; one young bullock, one ram, and seven lambs of the first year without blemish:
4612	146	3	And their meat offering shall be of flour mingled with oil, three tenth deals for a bullock, and two tenth deals for a ram,
4613	146	4	And one tenth deal for one lamb, throughout the seven lambs:
4614	146	5	And one kid of the goats for a sin offering, to make an atonement for you:
4615	146	6	Beside the burnt offering of the month, and his meat offering, and the daily burnt offering, and his meat offering, and their drink offerings, according unto their manner, for a sweet savour, a sacrifice made by fire unto the LORD.
4616	146	7	And ye shall have on the tenth day of this seventh month an holy convocation; and ye shall afflict your souls: ye shall not do any work therein:
4617	146	8	But ye shall offer a burnt offering unto the LORD for a sweet savour; one young bullock, one ram, and seven lambs of the first year; they shall be unto you without blemish:
4618	146	9	And their meat offering shall be of flour mingled with oil, three tenth deals to a bullock, and two tenth deals to one ram,
4619	146	10	A several tenth deal for one lamb, throughout the seven lambs:
4620	146	11	One kid of the goats for a sin offering; beside the sin offering of atonement, and the continual burnt offering, and the meat offering of it, and their drink offerings.
4621	146	12	And on the fifteenth day of the seventh month ye shall have an holy convocation; ye shall do no servile work, and ye shall keep a feast unto the LORD seven days:
4622	146	13	And ye shall offer a burnt offering, a sacrifice made by fire, of a sweet savour unto the LORD; thirteen young bullocks, two rams, and fourteen lambs of the first year; they shall be without blemish:
4623	146	14	And their meat offering shall be of flour mingled with oil, three tenth deals unto every bullock of the thirteen bullocks, two tenth deals to each ram of the two rams,
4624	146	15	And a several tenth deal to each lamb of the fourteen lambs:
4625	146	16	And one kid of the goats for a sin offering; beside the continual burnt offering, his meat offering, and his drink offering.
4626	146	17	And on the second day ye shall offer twelve young bullocks, two rams, fourteen lambs of the first year without spot:
4627	146	18	And their meat offering and their drink offerings for the bullocks, for the rams, and for the lambs, shall be according to their number, after the manner:
4628	146	19	And one kid of the goats for a sin offering; beside the continual burnt offering, and the meat offering thereof, and their drink offerings.
4629	146	20	And on the third day eleven bullocks, two rams, fourteen lambs of the first year without blemish;
4630	146	21	And their meat offering and their drink offerings for the bullocks, for the rams, and for the lambs, shall be according to their number, after the manner:
4631	146	22	And one goat for a sin offering; beside the continual burnt offering, and his meat offering, and his drink offering.
4632	146	23	And on the fourth day ten bullocks, two rams, and fourteen lambs of the first year without blemish:
4633	146	24	Their meat offering and their drink offerings for the bullocks, for the rams, and for the lambs, shall be according to their number, after the manner:
4634	146	25	And one kid of the goats for a sin offering; beside the continual burnt offering, his meat offering, and his drink offering.
4635	146	26	And on the fifth day nine bullocks, two rams, and fourteen lambs of the first year without spot:
4636	146	27	And their meat offering and their drink offerings for the bullocks, for the rams, and for the lambs, shall be according to their number, after the manner:
4637	146	28	And one goat for a sin offering; beside the continual burnt offering, and his meat offering, and his drink offering.
4638	146	29	And on the sixth day eight bullocks, two rams, and fourteen lambs of the first year without blemish:
4639	146	30	And their meat offering and their drink offerings for the bullocks, for the rams, and for the lambs, shall be according to their number, after the manner:
4640	146	31	And one goat for a sin offering; beside the continual burnt offering, his meat offering, and his drink offering.
4641	146	32	And on the seventh day seven bullocks, two rams, and fourteen lambs of the first year without blemish:
4642	146	33	And their meat offering and their drink offerings for the bullocks, for the rams, and for the lambs, shall be according to their number, after the manner:
4643	146	34	And one goat for a sin offering; beside the continual burnt offering, his meat offering, and his drink offering.
4644	146	35	On the eighth day ye shall have a solemn assembly: ye shall do no servile work therein:
4645	146	36	But ye shall offer a burnt offering, a sacrifice made by fire, of a sweet savour unto the LORD: one bullock, one ram, seven lambs of the first year without blemish:
4646	146	37	Their meat offering and their drink offerings for the bullock, for the ram, and for the lambs, shall be according to their number, after the manner:
4647	146	38	And one goat for a sin offering; beside the continual burnt offering, and his meat offering, and his drink offering.
4648	146	39	These things ye shall do unto the LORD in your set feasts, beside your vows, and your freewill offerings, for your burnt offerings, and for your meat offerings, and for your drink offerings, and for your peace offerings.
4649	146	40	And Moses told the children of Israel according to all that the LORD commanded Moses.
4650	147	1	AND Moses spake unto the heads of the tribes concerning the children of Israel, saying, This is the thing which the LORD hath commanded.
4651	147	2	If a man vow a vow unto the LORD, or swear an oath to bind his soul with a bond; he shall not break his word, he shall do according to all that proceedeth out of his mouth.
4652	147	3	If a woman also vow a vow unto the LORD, and bind herself by a bond, being in her father's house in her youth;
4653	147	4	And her father hear her vow, and her bond wherewith she hath bound her soul, and her father shall hold his peace at her: then all her vows shall stand, and every bond wherewith she hath bound her soul shall stand.
4654	147	5	But if her father disallow her in the day that he heareth; not any of her vows, or of her bonds wherewith she hath bound her soul, shall stand: and the LORD shall forgive her, because her father disallowed her.
4655	147	6	And if she had at all an husband, when she vowed, or uttered ought out of her lips, wherewith she bound her soul;
4656	147	7	And her husband heard it, and held his peace at her in the day that he heard it: then her vows shall stand, and her bonds wherewith she bound her soul shall stand.
4657	147	8	But if her husband disallowed her on the day that he heard it; then he shall make her vow which she vowed, and that which she uttered with her lips, wherewith she bound her soul, of none effect: and the LORD shall forgive her.
4658	147	9	But every vow of a widow, and of her that is divorced, wherewith they have bound their souls, shall stand against her.
4659	147	10	And if she vowed in her husband's house, or bound her soul by a bond with an oath;
4660	147	11	And her husband heard it, and held his peace at her, and disallowed her not: then all her vows shall stand, and every bond wherewith she bound her soul shall stand.
4661	147	12	But if her husband hath utterly made them void on the day he heard them; then whatsoever proceeded out of her lips concerning her vows, or concerning the bond of her soul, shall not stand: her husband hath made them void; and the LORD shall forgive her.
4662	147	13	Every vow, and every binding oath to afflict the soul, her husband may establish it, or her husband may make it void.
4663	147	14	But if her husband altogether hold his peace at her from day to day; then he establisheth all her vows, or all her bonds, which are upon her: he confirmeth them, because he held his peace at her in the day that he heard them.
4664	147	15	But if he shall any ways make them void after that he hath heard them; then he shall bear her iniquity.
4665	147	16	These are the statutes, which the LORD commanded Moses, between a man and his wife, between the father and his daughter, being yet in her youth in her father's house.
4666	148	1	AND the LORD spake unto Moses, saying,
4667	148	2	Avenge the children of Israel of the Midianites: afterward shalt thou be gathered unto thy people.
4668	148	3	And Moses spake unto the people, saying, Arm some of yourselves unto the war, and let them go against the Midianites, and avenge the LORD of Midian.
4669	148	4	Of every tribe a thousand, throughout all the tribes of Israel, shall ye send to the war.
4670	148	5	So there were delivered out of the thousands of Israel, a thousand of every tribe, twelve thousand armed for war.
4671	148	6	And Moses sent them to the war, a thousand of every tribe, them and Phinehas the son of Eleazar the priest, to the war, with the holy instruments, and the trumpets to blow in his hand.
4672	148	7	And they warred against the Midianites, as the LORD commanded Moses; and they slew all the males.
4673	148	8	And they slew the kings of Midian, beside the rest of them that were slain; namely, Evi, and Rekem, and Zur, and Hur, and Reba, five kings of Midian: Balaam also the son of Beor they slew with the sword.
4674	148	9	And the children of Israel took all the women of Midian captives, and their little ones, and took the spoil of all their cattle, and all their flocks, and all their goods.
4675	148	10	And they burnt all their cities wherein they dwelt, and all their goodly castles, with fire.
4676	148	11	And they took all the spoil, and all the prey, both of men and of beasts.
4677	148	12	And they brought the captives, and the prey, and the spoil, unto Moses, and Eleazar the priest, and unto the congregation of the children of Israel, unto the camp at the plains of Moab, which are by Jordan near Jericho.
4678	148	13	And Moses, and Eleazar the priest, and all the princes of the congregation, went forth to meet them without the camp.
4679	148	14	And Moses was wroth with the officers of the host, with the captains over thousands, and captains over hundreds, which came from the battle.
4680	148	15	And Moses said unto them, Have ye saved all the women alive?
4681	148	16	Behold, these caused the children of Israel, through the counsel of Balaam, to commit trespass against the LORD in the matter of Peor, and there was a plague among the congregation of the LORD.
4682	148	17	Now therefore kill every male among the little ones, and kill every woman that hath known man by lying with him.
4683	148	18	But all the women children, that have not known a man by lying with him, keep alive for yourselves.
4684	148	19	And do ye abide without the camp seven days: whosoever hath killed any person, and whosoever hath touched any slain, purify both yourselves and your captives on the third day, and on the seventh day.
4685	148	20	And purify all your raiment, and all that is made of skins, and all work of goats' hair, and all things made of wood.
4686	148	21	And Eleazar the priest said unto the men of war which went to the battle, This is the ordinance of the law which the LORD commanded Moses;
4687	148	22	Only the gold, and the silver, the brass, the iron, the tin, and the lead,
4688	148	23	Every thing that may abide the fire, ye shall make it go through the fire, and it shall be clean: nevertheless it shall be purified with the water of separation: and all that abideth not the fire ye shall make go through the water.
4689	148	24	And ye shall wash your clothes on the seventh day, and ye shall be clean, and afterward ye shall come into the camp.
4690	148	25	And the LORD spake unto Moses, saying,
4691	148	26	Take the sum of the prey that was taken, both of man and of beast, thou, and Eleazar the priest, and the chief fathers of the congregation:
4692	148	27	And divide the prey into two parts; between them that took the war upon them, who went out to battle, and between all the congregation:
4693	148	28	And levy a tribute unto the LORD of the men of war which went out to battle: one soul of five hundred, both of the persons, and of the beeves, and of the asses, and of the sheep:
4694	148	29	Take it of their half, and give it unto Eleazar the priest, for an heave offering of the LORD.
4695	148	30	And of the children of Israel's half, thou shalt take one portion of fifty, of the persons, of the beeves, of the asses, and of the flocks, of all manner of beasts, and give them unto the Levites, which keep the charge of the tabernacle of the LORD.
4696	148	31	And Moses and Eleazar the priest did as the LORD commanded Moses.
4697	148	32	And the booty, being the rest of the prey which the men of war had caught, was six hundred thousand and seventy thousand and five thousand sheep,
4698	148	33	And threescore and twelve thousand beeves,
4699	148	34	And threescore and one thousand asses,
4700	148	35	And thirty and two thousand persons in all, of woman that had not known man by lying with him.
4701	148	36	And the half, which was the portion of them that went out to war, was in number three hundred thousand and seven and thirty thousand and five hundred sheep:
4702	148	37	And the LORD's tribute of the sheep was six hundred and threescore and fifteen.
4703	148	38	And the beeves were thirty and six thousand; of which the LORD's tribute was threescore and twelve.
4704	148	39	And the asses were thirty thousand and five hundred; of which the LORD's tribute was threescore and one.
4705	148	40	And the persons were sixteen thousand; of which the LORD's tribute was thirty and two persons.
4706	148	41	And Moses gave the tribute, which was the LORD's heave offering, unto Eleazar the priest, as the LORD commanded Moses.
4707	148	42	And of the children of Israel's half, which Moses divided from the men that warred,
4708	148	43	(Now the half that pertained unto the congregation was three hundred thousand and thirty thousand and seven thousand and five hundred sheep,
4709	148	44	And thirty and six thousand beeves,
4710	148	45	And thirty thousand asses and five hundred,
4711	148	46	And sixteen thousand persons;)
4712	148	47	Even of the children of Israel's half, Moses took one portion of fifty, both of man and of beast, and gave them unto the Levites, which kept the charge of the tabernacle of the LORD; as the LORD commanded Moses.
4713	148	48	And the officers which were over thousands of the host, the captains of thousands, and captains of hundreds, came near unto Moses:
4714	148	49	And they said unto Moses, Thy servants have taken the sum of the men of war which are under our charge, and there lacketh not one man of us.
4715	148	50	We have therefore brought an oblation for the LORD, what every man hath gotten, of jewels of gold, chains, and bracelets, rings, earrings, and tablets, to make an atonement for our souls before the LORD.
4716	148	51	And Moses and Eleazar the priest took the gold of them, even all wrought jewels.
4717	148	52	And all the gold of the offering that they offered up to the LORD, of the captains of thousands, and of the captains of hundreds, was sixteen thousand seven hundred and fifty shekels.
4718	148	53	(For the men of war had taken spoil, every man for himself.)
4719	148	54	And Moses and Eleazar the priest took the gold of the captains of thousands and of hundreds, and brought it into the tabernacle of the congregation, for a memorial for the children of Israel before the LORD.
4720	149	1	NOW the children of Reuben and the children of Gad had a very great multitude of cattle: and when they saw the land of Jazer, and the land of Gilead, that, behold, the place was a place for cattle;
4721	149	2	The children of Gad and the children of Reuben came and spake unto Moses, and to Eleazar the priest, and unto the princes of the congregation, saying,
4722	149	3	Ataroth, and Dibon, and Jazer, and Nimrah, and Heshbon, and Elealeh, and Shebam, and Nebo, and Beon,
4723	149	4	Even the country which the LORD smote before the congregation of Israel, is a land for cattle, and thy servants have cattle:
4724	149	5	Wherefore, said they, if we have found grace in thy sight, let this land be given unto thy servants for a possession, and bring us not over Jordan.
4725	149	6	And Moses said unto the children of Gad and to the children of Reuben, Shall your brethren go to war, and shall ye sit here?
4726	149	7	And wherefore discourage ye the heart of the children of Israel from going over into the land which the LORD hath given them?
4727	149	8	Thus did your fathers, when I sent them from Kadesh-barnea to see the land.
4728	149	9	For when they went up unto the valley of Eshcol, and saw the land, they discouraged the heart of the children of Israel, that they should not go into the land which the LORD had given them.
4729	149	10	And the LORD's anger was kindled the same time, and he sware, saying,
4730	149	11	Surely none of the men that came up out of Egypt, from twenty years old and upward, shall see the land which I sware unto Abraham, unto Isaac, and unto Jacob; because they have not wholly followed me:
4731	149	12	Save Caleb the son of Jephunneh the Kenezite, and Joshua the son of Nun: for they have wholly followed the LORD.
4732	149	13	And the LORD's anger was kindled against Israel, and he made them wander in the wilderness forty years, until all the generation, that had done evil in the sight of the LORD, was consumed.
4733	149	14	And, behold, ye are risen up in your fathers' stead, an increase of sinful men, to augment yet the fierce anger of the LORD toward Israel.
4734	149	15	For if ye turn away from after him, he will yet again leave them in the wilderness; and ye shall destroy all this people.
4735	149	16	And they came near unto him, and said, We will build sheepfolds here for our cattle, and cities for our little ones:
4736	149	17	But we ourselves will go ready armed before the children of Israel, until we have brought them unto their place: and our little ones shall dwell in the fenced cities because of the inhabitants of the land.
4737	149	18	We will not return unto our houses, until the children of Israel have inherited every man his inheritance.
4738	149	19	For we will not inherit with them on yonder side Jordan, or forward; because our inheritance is fallen to us on this side Jordan eastward.
4739	149	20	And Moses said unto them, If ye will do this thing, if ye will go armed before the LORD to war,
4740	149	21	And will go all of you armed over Jordan before the LORD, until he hath driven out his enemies from before him,
4741	149	22	And the land be subdued before the LORD: then afterward ye shall return, and be guiltless before the LORD, and before Israel; and this land shall be your possession before the LORD.
4742	149	23	But if ye will not do so, behold, ye have sinned against the LORD: and be sure your sin will find you out.
4743	149	24	Build you cities for your little ones, and folds for your sheep; and do that which hath proceeded out of your mouth.
4744	149	25	And the children of Gad and the children of Reuben spake unto Moses, saying, Thy servants will do as my lord commandeth.
4745	149	26	Our little ones, our wives, our flocks, and all our cattle, shall be there in the cities of Gilead:
4746	149	27	But thy servants will pass over, every man armed for war, before the LORD to battle, as my lord saith.
4747	149	28	So concerning them Moses commanded Eleazar the priest, and Joshua the son of Nun, and the chief fathers of the tribes of the children of Israel:
4748	149	29	And Moses said unto them, If the children of Gad and the children of Reuben will pass with you over Jordan, every man armed to battle, before the LORD, and the land shall be subdued before you; then ye shall give them the land of Gilead for a possession:
4749	149	30	But if they will not pass over with you armed, they shall have possessions among you in the land of Canaan.
4750	149	31	And the children of Gad and the children of Reuben answered, saying, As the LORD hath said unto thy servants, so will we do.
4751	149	32	We will pass over armed before the LORD into the land of Canaan, that the possession of our inheritance on this side Jordan may be ours.
4752	149	33	And Moses gave unto them, even to the children of Gad, and to the children of Reuben, and unto half the tribe of Manasseh the son of Joseph, the kingdom of Sihon king of the Amorites, and the kingdom of Og king of Bashan, the land, with the cities thereof in the coasts, even the cities of the country round about.
4753	149	34	And the children of Gad built Dibon, and Ataroth, and Aroer,
4754	149	35	And Atroth, Shophan, and Jaazer, and Jogbehah,
4755	149	36	And Beth-nimrah, and Beth-haran, fenced cities: and folds for sheep.
4756	149	37	And the children of Reuben built Heshbon, and Elealeh, and Kirjathaim,
4757	149	38	And Nebo, and Baal-meon, (their names being changed,) and Shibmah: and gave other names unto the cities which they builded.
4758	149	39	And the children of Machir the son of Manasseh went to Gilead, and took it, and dispossessed the Amorite which was in it.
4759	149	40	And Moses gave Gilead unto Machir the son of Manasseh; and he dwelt therein.
4760	149	41	And Jair the son of Manasseh went and took the small towns thereof, and called them Havoth-jair.
4761	149	42	And Nobah went and took Kenath, and the villages thereof, and called it Nobah, after his own name.
4762	150	1	THESE are the journeys of the children of Israel, which went forth out of the land of Egypt with their armies under the hand of Moses and Aaron.
4763	150	2	And Moses wrote their goings out according to their journeys by the commandment of the LORD: and these are their journeys according to their goings out.
4764	150	3	And they departed from Rameses in the first month, on the fifteenth day of the first month; on the morrow after the passover the children of Israel went out with an high hand in the sight of all the Egyptians.
4765	150	4	For the Egyptians buried all their firstborn, which the LORD had smitten among them: upon their gods also the LORD executed judgments.
4766	150	5	And the children of Israel removed from Rameses, and pitched in Succoth.
4767	150	6	And they departed from Succoth, and pitched in Etham, which is in the edge of the wilderness.
4768	150	7	And they removed from Etham, and turned again unto Pi-hahiroth, which is before Baal-zephon: and they pitched before Migdol.
4769	150	8	And they departed from before Pi-hahiroth, and passed through the midst of the sea into the wilderness, and went three days' journey in the wilderness of Etham, and pitched in Marah.
4770	150	9	And they removed from Marah, and came unto Elim: and in Elim were twelve fountains of water, and threescore and ten palm trees; and they pitched there.
4771	150	10	And they removed from Elim, and encamped by the Red sea.
4772	150	11	And they removed from the Red sea, and encamped in the wilderness of Sin.
4773	150	12	And they took their journey out of the wilderness of Sin, and encamped in Dophkah.
4774	150	13	And they departed from Dophkah, and encamped in Alush.
4775	150	14	And they removed from Alush, and encamped at Rephidim, where was no water for the people to drink.
4776	150	15	And they departed from Rephidim, and pitched in the wilderness of Sinai.
4777	150	16	And they removed from the desert of Sinai, and pitched at Kibroth-hattaavah.
4778	150	17	And they departed from Kibroth-hattaavah, and encamped at Hazeroth.
4779	150	18	And they departed from Hazeroth, and pitched in Rithmah.
4780	150	19	And they departed from Rithmah, and pitched at Rimmon-parez.
4781	150	20	And they departed from Rimmon-parez, and pitched in Libnah.
4782	150	21	And they removed from Libnah, and pitched at Rissah.
4783	150	22	And they journeyed from Rissah, and pitched in Kehelathah.
4784	150	23	And they went from Kehelathah, and pitched in mount Shapher.
4785	150	24	And they removed from mount Shapher, and encamped in Haradah.
4786	150	25	And they removed from Haradah, and pitched in Makheloth.
4787	150	26	And they removed from Makheloth, and encamped at Tahath.
4788	150	27	And they departed from Tahath, and pitched at Tarah.
4789	150	28	And they removed from Tarah, and pitched in Mithcah.
4790	150	29	And they went from Mithcah, and pitched in Hashmonah.
4791	150	30	And they departed from Hashmonah, and encamped at Moseroth.
4792	150	31	And they departed from Moseroth, and pitched in Bene-jaakan.
4793	150	32	And they removed from Bene-jaakan, and encamped at Hor-hagidgad.
4794	150	33	And they went from Hor-hagidgad, and pitched in Jotbathah.
4795	150	34	And they removed from Jotbathah, and encamped at Ebronah.
4796	150	35	And they departed from Ebronah, and encamped at Ezion-gaber.
4797	150	36	And they removed from Ezion-gaber, and pitched in the wilderness of Zin, which is Kadesh.
4798	150	37	And they removed from Kadesh, and pitched in mount Hor, in the edge of the land of Edom.
4799	150	38	And Aaron the priest went up into mount Hor at the commandment of the LORD, and died there, in the fortieth year after the children of Israel were come out of the land of Egypt, in the first day of the fifth month.
4800	150	39	And Aaron was an hundred and twenty and three years old when he died in mount Hor.
4801	150	40	And king Arad the Canaanite, which dwelt in the south in the land of Canaan, heard of the coming of the children of Israel.
4802	150	41	And they departed from mount Hor, and pitched in Zalmonah.
4803	150	42	And they departed from Zalmonah, and pitched in Punon.
4804	150	43	And they departed from Punon, and pitched in Oboth.
4805	150	44	And they departed from Oboth, and pitched in Ije-abarim, in the border of Moab.
4806	150	45	And they departed from Iim, and pitched in Dibon-gad.
4807	150	46	And they removed from Dibon-gad, and encamped in Almon-diblathaim.
4808	150	47	And they removed from Almon-diblathaim, and pitched in the mountains of Abarim, before Nebo.
4809	150	48	And they departed from the mountains of Abarim, and pitched in the plains of Moab by Jordan near Jericho.
4810	150	49	And they pitched by Jordan, from Beth-jesimoth even unto Abel-shittim in the plains of Moab.
4811	150	50	And the LORD spake unto Moses in the plains of Moab by Jordan near Jericho, saying,
4812	150	51	Speak unto the children of Israel, and say unto them, When ye are passed over Jordan into the land of Canaan;
4813	150	52	Then ye shall drive out all the inhabitants of the land from before you, and destroy all their pictures, and destroy all their molten images, and quite pluck down all their high places:
4814	150	53	And ye shall dispossess the inhabitants of the land, and dwell therein: for I have given you the land to possess it.
4815	150	54	And ye shall divide the land by lot for an inheritance among your families: and to the more ye shall give the more inheritance, and to the fewer ye shall give the less inheritance: every man's inheritance shall be in the place where his lot falleth; according to the tribes of your fathers ye shall inherit.
4816	150	55	But if ye will not drive out the inhabitants of the land from before you; then it shall come to pass, that those which ye let remain of them shall be pricks in your eyes, and thorns in your sides, and shall vex you in the land wherein ye dwell.
4817	150	56	Moreover it shall come to pass, that I shall do unto you, as I thought to do unto them.
4818	151	1	AND the LORD spake unto Moses, saying,
4819	151	2	Command the children of Israel, and say unto them, When ye come into the land of Canaan; (this is the land that shall fall unto you for an inheritance, even the land of Canaan with the coasts thereof:)
4820	151	3	Then your south quarter shall be from the wilderness of Zin along by the coast of Edom, and your south border shall be the outmost coast of the salt sea eastward:
4821	151	4	And your border shall turn from the south to the ascent of Akrabbim, and pass on to Zin: and the going forth thereof shall be from the south to Kadesh-barnea, and shall go on to Hazar-addar, and pass on to Azmon:
4822	151	5	And the border shall fetch a compass from Azmon unto the river of Egypt, and the goings out of it shall be at the sea.
4823	151	6	And as for the western border, ye shall even have the great sea for a border: this shall be your west border.
4824	151	7	And this shall be your north border: from the great sea ye shall point out for you mount Hor:
4825	151	8	From mount Hor ye shall point out your border unto the entrance of Hamath; and the goings forth of the border shall be to Zedad:
4826	151	9	And the border shall go on to Ziphron, and the goings out of it shall be at Hazar-enan: this shall be your north border.
4827	151	10	And ye shall point out your east border from Hazar-enan to Shepham:
4828	151	11	And the coast shall go down from Shepham to Riblah, on the east side of Ain; and the border shall descend, and shall reach unto the side of the sea of Chinnereth eastward:
4829	151	12	And the border shall go down to Jordan, and the goings out of it shall be at the salt sea: this shall be your land with the coasts thereof round about.
4830	151	13	And Moses commanded the children of Israel, saying, This is the land which ye shall inherit by lot, which the LORD commanded to give unto the nine tribes, and to the half tribe:
4831	151	14	For the tribe of the children of Reuben according to the house of their fathers, and the tribe of the children of Gad according to the house of their fathers, have received their inheritance; and half the tribe of Manasseh have received their inheritance:
4832	151	15	The two tribes and the half tribe have received their inheritance on this side Jordan near Jericho eastward, toward the sunrising.
4833	151	16	And the LORD spake unto Moses, saying,
4834	151	17	These are the names of the men which shall divide the land unto you: Eleazar the priest, and Joshua the son of Nun.
4835	151	18	And ye shall take one prince of every tribe, to divide the land by inheritance.
4836	151	19	And the names of the men are these: Of the tribe of Judah, Caleb the son of Jephunneh.
4837	151	20	And of the tribe of the children of Simeon, Shemuel the son of Ammihud.
4838	151	21	Of the tribe of Benjamin, Elidad the son of Chislon.
4839	151	22	And the prince of the tribe of the children of Dan, Bukki the son of Jogli.
4840	151	23	The prince of the children of Joseph, for the tribe of the children of Manasseh, Hanniel the son of Ephod.
4841	151	24	And the prince of the tribe of the children of Ephraim, Kemuel the son of Shiphtan.
4842	151	25	And the prince of the tribe of the children of Zebulun, Elizaphan the son of Parnach.
4843	151	26	And the prince of the tribe of the children of Issachar, Paltiel the son of Azzan.
4844	151	27	And the prince of the tribe of the children of Asher, Ahihud the son of Shelomi.
4845	151	28	And the prince of the tribe of the children of Naphtali, Pedahel the son of Ammihud.
4846	151	29	These are they whom the LORD commanded to divide the inheritance unto the children of Israel in the land of Canaan.
4847	152	1	AND the LORD spake unto Moses in the plains of Moab by Jordan near Jericho, saying,
4848	152	2	Command the children of Israel, that they give unto the Levites of the inheritance of their possession cities to dwell in; and ye shall give also unto the Levites suburbs for the cities round about them.
4849	152	3	And the cities shall they have to dwell in; and the suburbs of them shall be for their cattle, and for their goods, and for all their beasts.
4850	152	4	And the suburbs of the cities, which ye shall give unto the Levites, shall reach from the wall of the city and outward a thousand cubits round about.
4851	152	5	And ye shall measure from without the city on the east side two thousand cubits, and on the south side two thousand cubits, and on the west side two thousand cubits, and on the north side two thousand cubits; and the city shall be in the midst: this shall be to them the suburbs of the cities.
4852	152	6	And among the cities which ye shall give unto the Levites there shall be six cities for refuge, which ye shall appoint for the manslayer, that he may flee thither: and to them ye shall add forty and two cities.
4853	152	7	So all the cities which ye shall give to the Levites shall be forty and eight cities: them shall ye give with their suburbs.
4854	152	8	And the cities which ye shall give shall be of the possession of the children of Israel: from them that have many ye shall give many; but from them that have few ye shall give few: every one shall give of his cities unto the Levites according to his inheritance which he inheriteth.
4855	152	9	And the LORD spake unto Moses, saying,
4856	152	10	Speak unto the children of Israel, and say unto them, When ye be come over Jordan into the land of Canaan;
4857	152	11	Then ye shall appoint you cities to be cities of refuge for you; that the slayer may flee thither, which killeth any person at unawares.
4858	152	12	And they shall be unto you cities for refuge from the avenger; that the manslayer die not, until he stand before the congregation in judgment.
4859	152	13	And of these cities which ye shall give six cities shall ye have for refuge.
4860	152	14	Ye shall give three cities on this side Jordan, and three cities shall ye give in the land of Canaan, which shall be cities of refuge.
4861	152	15	These six cities shall be a refuge, both for the children of Israel, and for the stranger, and for the sojourner among them: that every one that killeth any person unawares may flee thither.
4862	152	16	And if he smite him with an instrument of iron, so that he die, he is a murderer: the murderer shall surely be put to death.
4863	152	17	And if he smite him with throwing a stone, wherewith he may die, and he die, he is a murderer: the murderer shall surely be put to death.
4864	152	18	Or if he smite him with an hand weapon of wood, wherewith he may die, and he die, he is a murderer: the murderer shall surely be put to death.
4865	152	19	The revenger of blood himself shall slay the murderer: when he meeteth him, he shall slay him.
4866	152	20	But if he thrust him of hatred, or hurl at him by laying of wait, that he die;
4867	152	21	Or in enmity smite him with his hand, that he die: he that smote him shall surely be put to death; for he is a murderer: the revenger of blood shall slay the murderer, when he meeteth him.
4868	152	22	But if he thrust him suddenly without enmity, or have cast upon him any thing without laying of wait,
4869	152	23	Or with any stone, wherewith a man may die, seeing him not, and cast it upon him, that he die, and was not his enemy, neither sought his harm:
4870	152	24	Then the congregation shall judge between the slayer and the revenger of blood according to these judgments:
4871	152	25	And the congregation shall deliver the slayer out of the hand of the revenger of blood, and the congregation shall restore him to the city of his refuge, whither he was fled: and he shall abide in it unto the death of the high priest, which was anointed with the holy oil.
4872	152	26	But if the slayer shall at any time come without the border of the city of his refuge, whither he was fled;
4873	152	27	And the revenger of blood find him without the borders of the city of his refuge, and the revenger of blood kill the slayer; he shall not be guilty of blood:
4874	152	28	Because he should have remained in the city of his refuge until the death of the high priest: but after the death of the high priest the slayer shall return into the land of his possession.
4875	152	29	So these things shall be for a statute of judgment unto you throughout your generations in all your dwellings.
4876	152	30	Whoso killeth any person, the murderer shall be put to death by the mouth of witnesses: but one witness shall not testify against any person to cause him to die.
4877	152	31	Moreover ye shall take no satisfaction for the life of a murderer, which is guilty of death: but he shall be surely put to death.
4878	152	32	And ye shall take no satisfaction for him that is fled to the city of his refuge, that he should come again to dwell in the land, until the death of the priest.
4879	152	33	So ye shall not pollute the land wherein ye are: for blood it defileth the land: and the land cannot be cleansed of the blood that is shed therein, but by the blood of him that shed it.
4880	152	34	Defile not therefore the land which ye shall inhabit, wherein I dwell: for I the LORD dwell among the children of Israel.
4881	153	1	AND the chief fathers of the families of the children of Gilead, the son of Machir, the son of Manasseh, of the families of the sons of Joseph, came near, and spake before Moses, and before the princes, the chief fathers of the children of Israel:
4882	153	2	And they said, The LORD commanded my lord to give the land for an inheritance by lot to the children of Israel: and my lord was commanded by the LORD to give the inheritance of Zelophehad our brother unto his daughters.
4883	153	3	And if they be married to any of the sons of the other tribes of the children of Israel, then shall their inheritance be taken from the inheritance of our fathers, and shall be put to the inheritance of the tribe whereunto they are received: so shall it be taken from the lot of our inheritance.
4884	153	4	And when the jubile of the children of Israel shall be, then shall their inheritance be put unto the inheritance of the tribe whereunto they are received: so shall their inheritance be taken away from the inheritance of the tribe of our fathers.
4885	153	5	And Moses commanded the children of Israel according to the word of the LORD, saying, The tribe of the sons of Joseph hath said well.
4886	153	6	This is the thing which the LORD doth command concerning the daughters of Zelophehad, saying, Let them marry to whom they think best; only to the family of the tribe of their father shall they marry.
4887	153	7	So shall not the inheritance of the children of Israel remove from tribe to tribe: for every one of the children of Israel shall keep himself to the inheritance of the tribe of his fathers.
4888	153	8	And every daughter, that possesseth an inheritance in any tribe of the children of Israel, shall be wife unto one of the family of the tribe of her father, that the children of Israel may enjoy every man the inheritance of his fathers.
4889	153	9	Neither shall the inheritance remove from one tribe to another tribe; but every one of the tribes of the children of Israel shall keep himself to his own inheritance.
4890	153	10	Even as the LORD commanded Moses, so did the daughters of Zelophehad:
4891	153	11	For Mahlah, Tirzah, and Hoglah, and Milcah, and Noah, the daughters of Zelophehad, were married unto their father's brothers' sons:
4892	153	12	And they were married into the families of the sons of Manasseh the son of Joseph, and their inheritance remained in the tribe of the family of their father.
4893	153	13	These are the commandments and the judgments, which the LORD commanded by the hand of Moses unto the children of Israel in the plains of Moab by Jordan near Jericho.
4894	154	1	THESE be the words which Moses spake unto all Israel on this side Jordan in the wilderness, in the plain over against the Red sea, between Paran, and Tophel, and Laban, and Hazeroth, and Dizahab.
4895	154	2	(There are eleven days' journey from Horeb by the way of mount Seir unto Kadesh-barnea.)
4896	154	3	And it came to pass in the fortieth year, in the eleventh month, on the first day of the month, that Moses spake unto the children of Israel, according unto all that the LORD had given him in commandment unto them;
4897	154	4	After he had slain Sihon the king of the Amorites, which dwelt in Heshbon, and Og the king of Bashan, which dwelt at Astaroth in Edrei:
4898	154	5	On this side Jordan, in the land of Moab, began Moses to declare this law, saying,
4899	154	6	The LORD our God spake unto us in Horeb, saying, Ye have dwelt long enough in this mount:
4900	154	7	Turn you, and take your journey, and go to the mount of the Amorites, and unto all the places nigh thereunto, in the plain, in the hills, and in the vale, and in the south, and by the sea side, to the land of the Canaanites, and unto Lebanon, unto the great river, the river Euphrates.
4901	154	8	Behold, I have set the land before you: go in and possess the land which the LORD sware unto your fathers, Abraham, Isaac, and Jacob, to give unto them and to their seed after them.
4902	154	9	And I spake unto you at that time, saying, I am not able to bear you myself alone:
4903	154	10	The LORD your God hath multiplied you, and, behold, ye are this day as the stars of heaven for multitude.
4904	154	11	(The LORD God of your fathers make you a thousand times so many more as ye are, and bless you, as he hath promised you!)
4905	154	12	How can I myself alone bear your cumbrance, and your burden, and your strife?
4906	154	13	Take you wise men, and understanding, and known among your tribes, and I will make them rulers over you.
4907	154	14	And ye answered me, and said, The thing which thou hast spoken is good for us to do.
4908	154	15	So I took the chief of your tribes, wise men, and known, and made them heads over you, captains over thousands, and captains over hundreds, and captains over fifties, and captains over tens, and officers among your tribes.
4909	154	16	And I charged your judges at that time, saying, Hear the causes between your brethren, and judge righteously between every man and his brother, and the stranger that is with him.
4910	154	17	Ye shall not respect persons in judgment; but ye shall hear the small as well as the great; ye shall not be afraid of the face of man; for the judgment is God's: and the cause that is too hard for you, bring it unto me, and I will hear it.
4911	154	18	And I commanded you at that time all the things which ye should do.
4912	154	19	And when we departed from Horeb, we went through all that great and terrible wilderness, which ye saw by the way of the mountain of the Amorites, as the LORD our God commanded us; and we came to Kadesh-barnea.
4913	154	20	And I said unto you, Ye are come unto the mountain of the Amorites, which the LORD our God doth give unto us.
4914	154	21	Behold, the LORD thy God hath set the land before thee: go up and possess it, as the LORD God of thy fathers hath said unto thee; fear not, neither be discouraged.
4915	154	22	And ye came near unto me every one of you, and said, We will send men before us, and they shall search us out the land, and bring us word again by what way we must go up, and into what cities we shall come.
4916	154	23	And the saying pleased me well: and I took twelve men of you, one of a tribe:
4917	154	24	And they turned and went up into the mountain, and came unto the valley of Eshcol, and searched it out.
4918	154	25	And they took of the fruit of the land in their hands, and brought it down unto us, and brought us word again, and said, It is a good land which the LORD our God doth give us.
4919	154	26	Notwithstanding ye would not go up, but rebelled against the commandment of the LORD your God:
4920	154	27	And ye murmured in your tents, and said, Because the LORD hated us, he hath brought us forth out of the land of Egypt, to deliver us into the hand of the Amorites, to destroy us.
4921	154	28	Whither shall we go up? our brethren have discouraged our heart, saying, The people is greater and taller than we; the cities are great and walled up to heaven; and moreover we have seen the sons of the Anakims there.
4922	154	29	Then I said unto you, Dread not, neither be afraid of them.
4923	154	30	The LORD your God which goeth before you, he shall fight for you, according to all that he did for you in Egypt before your eyes;
4924	154	31	And in the wilderness, where thou hast seen how that the LORD thy God bare thee, as a man doth bear his son, in all the way that ye went, until ye came into this place.
4925	154	32	Yet in this thing ye did not believe the LORD your God,
4926	154	33	Who went in the way before you, to search you out a place to pitch your tents in, in fire by night, to shew you by what way ye should go, and in a cloud by day.
4927	154	34	And the LORD heard the voice of your words, and was wroth, and sware, saying,
4928	154	35	Surely there shall not one of these men of this evil generation see that good land, which I sware to give unto your fathers,
4929	154	36	Save Caleb the son of Jephunneh; he shall see it, and to him will I give the land that he hath trodden upon, and to his children, because he hath wholly followed the LORD.
4930	154	37	Also the LORD was angry with me for your sakes, saying, Thou also shalt not go in thither.
4931	154	38	But Joshua the son of Nun, which standeth before thee, he shall go in thither: encourage him: for he shall cause Israel to inherit it.
4932	154	39	Moreover your little ones, which ye said should be a prey, and your children, which in that day had no knowledge between good and evil, they shall go in thither, and unto them will I give it, and they shall possess it.
4933	154	40	But as for you, turn you, and take your journey into the wilderness by the way of the Red sea.
4934	154	41	Then ye answered and said unto me, We have sinned against the LORD, we will go up and fight, according to all that the LORD our God commanded us. And when ye had girded on every man his weapons of war, ye were ready to go up into the hill.
4935	154	42	And the LORD said unto me, Say unto them, Go not up, neither fight; for I am not among you; lest ye be smitten before your enemies.
4936	154	43	So I spake unto you; and ye would not hear, but rebelled against the commandment of the LORD, and went presumptuously up into the hill.
4937	154	44	And the Amorites, which dwelt in that mountain, came out against you, and chased you, as bees do, and destroyed you in Seir, even unto Hormah.
4938	154	45	And ye returned and wept before the LORD; but the LORD would not hearken to your voice, nor give ear unto you.
4939	154	46	So ye abode in Kadesh many days, according unto the days that ye abode there.
4940	155	1	THEN we turned, and took our journey into the wilderness by the way of the Red sea, as the LORD spake unto me: and we compassed mount Seir many days.
4941	155	2	And the LORD spake unto me, saying,
4942	155	3	Ye have compassed this mountain long enough: turn you northward.
4943	155	4	And command thou the people, saying, Ye are to pass through the coast of your brethren the children of Esau, which dwell in Seir; and they shall be afraid of you: take ye good heed unto yourselves therefore:
4944	155	5	Meddle not with them; for I will not give you of their land, no, not so much as a foot breadth; because I have given mount Seir unto Esau for a possession.
4945	155	6	Ye shall buy meat of them for money, that ye may eat; and ye shall also buy water of them for money, that ye may drink.
4946	155	7	For the LORD thy God hath blessed thee in all the works of thy hand: he knoweth thy walking through this great wilderness: these forty years the LORD thy God hath been with thee; thou hast lacked nothing.
4947	155	8	And when we passed by from our brethren the children of Esau, which dwelt in Seir, through the way of the plain from Elath, and from Ezion-gaber, we turned and passed by the way of the wilderness of Moab.
4948	155	9	And the LORD said unto me, Distress not the Moabites, neither contend with them in battle: for I will not give thee of their land for a possession; because I have given Ar unto the children of Lot for a possession.
4949	155	10	The Emims dwelt therein in times past, a people great, and many, and tall, as the Anakims;
4950	155	11	Which also were accounted giants, as the Anakims; but the Moabites call them Emims.
4951	155	12	The Horims also dwelt in Seir beforetime; but the children of Esau succeeded them, when they had destroyed them from before them, and dwelt in their stead; as Israel did unto the land of his possession, which the LORD gave unto them.
4952	155	13	Now rise up, said I, and get you over the brook Zered. And we went over the brook Zered.
4953	155	14	And the space in which we came from Kadesh-barnea, until we were come over the brook Zered, was thirty and eight years; until all the generation of the men of war were wasted out from among the host, as the LORD sware unto them.
4954	155	15	For indeed the hand of the LORD was against them, to destroy them from among the host, until they were consumed.
4955	155	16	So it came to pass, when all the men of war were consumed and dead from among the people,
4956	155	17	That the LORD spake unto me, saying,
4957	155	18	Thou art to pass over through Ar, the coast of Moab, this day:
4958	155	19	And when thou comest nigh over against the children of Ammon, distress them not, nor meddle with them: for I will not give thee of the land of the children of Ammon any possession; because I have given it unto the children of Lot for a possession.
4959	155	20	(That also was accounted a land of giants: giants dwelt therein in old time; and the Ammonites call them Zamzummims;
4960	155	21	A people great, and many, and tall, as the Anakims; but the LORD destroyed them before them; and they succeeded them, and dwelt in their stead:
4961	155	22	As he did to the children of Esau, which dwelt in Seir, when he destroyed the Horims from before them; and they succeeded them, and dwelt in their stead even unto this day:
4962	155	23	And the Avims which dwelt in Hazerim, even unto Azzah, the Caphtorims, which came forth out of Caphtor, destroyed them, and dwelt in their stead.)
4963	155	24	Rise ye up, take your journey, and pass over the river Arnon: behold, I have given into thine hand Sihon the Amorite, king of Heshbon, and his land: begin to possess it, and contend with him in battle.
4964	155	25	This day will I begin to put the dread of thee and the fear of thee upon the nations that are under the whole heaven, who shall hear report of thee, and shall tremble, and be in anguish because of thee.
4965	155	26	And I sent messengers out of the wilderness of Kedemoth unto Sihon king of Heshbon with words of peace, saying,
4966	155	27	Let me pass through thy land: I will go along by the high way, I will neither turn unto the right hand nor to the left.
4967	155	28	Thou shalt sell me meat for money, that I may eat; and give me water for money, that I may drink: only I will pass through on my feet;
4968	155	29	(As the children of Esau which dwell in Seir, and the Moabites which dwell in Ar, did unto me;) until I shall pass over Jordan into the land which the LORD our God giveth us.
4969	155	30	But Sihon king of Heshbon would not let us pass by him: for the LORD thy God hardened his spirit, and made his heart obstinate, that he might deliver him into thy hand, as appeareth this day.
4970	155	31	And the LORD said unto me, Behold, I have begun to give Sihon and his land before thee: begin to possess, that thou mayest inherit his land.
4971	155	32	Then Sihon came out against us, he and all his people, to fight at Jahaz.
4972	155	33	And the LORD our God delivered him before us; and we smote him, and his sons, and all his people.
4973	155	34	And we took all his cities at that time, and utterly destroyed the men, and the women, and the little ones, of every city, we left none to remain:
4974	155	35	Only the cattle we took for a prey unto ourselves, and the spoil of the cities which we took.
4975	155	36	From Aroer, which is by the brink of the river of Arnon, and from the city that is by the river, even unto Gilead, there was not one city too strong for us: the LORD our God delivered all unto us:
4976	155	37	Only unto the land of the children of Ammon thou camest not, nor unto any place of the river Jabbok, nor unto the cities in the mountains, nor unto whatsoever the LORD our God forbad us.
4977	156	1	THEN we turned, and went up the way to Bashan: and Og the king of Bashan came out against us, he and all his people, to battle at Edrei.
4978	156	2	And the LORD said unto me, Fear him not: for I will deliver him, and all his people, and his land, into thy hand; and thou shalt do unto him as thou didst unto Sihon king of the Amorites, which dwelt at Heshbon.
4979	156	3	So the LORD our God delivered into our hands Og also, the king of Bashan, and all his people: and we smote him until none was left to him remaining.
4980	156	4	And we took all his cities at that time, there was not a city which we took not from them, threescore cities, all the region of Argob, the kingdom of Og in Bashan.
4981	156	5	All these cities were fenced with high walls, gates, and bars; beside unwalled towns a great many.
4982	156	6	And we utterly destroyed them, as we did unto Sihon king of Heshbon, utterly destroying the men, women, and children, of every city.
4983	156	7	But all the cattle, and the spoil of the cities, we took for a prey to ourselves.
4984	156	8	And we took at that time out of the hand of the two kings of the Amorites the land that was on this side Jordan, from the river of Arnon unto mount Hermon;
4985	156	9	(Which Hermon the Sidonians call Sirion; and the Amorites call it Shenir;)
4986	156	10	All the cities of the plain, and all Gilead, and all Bashan, unto Salchah and Edrei, cities of the kingdom of Og in Bashan.
4987	156	11	For only Og king of Bashan remained of the remnant of giants; behold, his bedstead was a bedstead of iron; is it not in Rabbath of the children of Ammon? nine cubits was the length thereof, and four cubits the breadth of it, after the cubit of a man.
4988	156	12	And this land, which we possessed at that time, from Aroer, which is by the river Arnon, and half mount Gilead, and the cities thereof, gave I unto the Reubenites and to the Gadites.
4989	156	13	And the rest of Gilead, and all Bashan, being the kingdom of Og, gave I unto the half tribe of Manasseh; all the region of Argob, with all Bashan, which was called the land of giants.
4990	156	14	Jair the son of Manasseh took all the country of Argob unto the coasts of Geshuri and Maachathi; and called them after his own name, Bashan-havoth-jair, unto this day.
4991	156	15	And I gave Gilead unto Machir.
4992	156	16	And unto the Reubenites and unto the Gadites I gave from Gilead even unto the river Arnon half the valley, and the border even unto the river Jabbok, which is the border of the children of Ammon;
4993	156	17	The plain also, and Jordan, and the coast thereof, from Chinnereth even unto the sea of the plain, even the salt sea, under Ashdoth-pisgah eastward.
4994	156	18	And I commanded you at that time, saying, The LORD your God hath given you this land to possess it: ye shall pass over armed before your brethren the children of Israel, all that are meet for the war.
4995	156	19	But your wives, and your little ones, and your cattle, (for I know that ye have much cattle,) shall abide in your cities which I have given you;
4996	156	20	Until the LORD have given rest unto your brethren, as well as unto you, and until they also possess the land which the LORD your God hath given them beyond Jordan: and then shall ye return every man unto his possession, which I have given you.
4997	156	21	And I commanded Joshua at that time, saying, Thine eyes have seen all that the LORD your God hath done unto these two kings: so shall the LORD do unto all the kingdoms whither thou passest.
4998	156	22	Ye shall not fear them: for the LORD your God he shall fight for you.
4999	156	23	And I besought the LORD at that time, saying,
5000	156	24	O Lord GOD, thou hast begun to shew thy servant thy greatness, and thy mighty hand: for what God is there in heaven or in earth, that can do according to thy works, and according to thy might?
5001	156	25	I pray thee, let me go over, and see the good land that is beyond Jordan, that goodly mountain, and Lebanon.
5002	156	26	But the LORD was wroth with me for your sakes, and would not hear me: and the LORD said unto me, Let it suffice thee; speak no more unto me of this matter.
5003	156	27	Get thee up into the top of Pisgah, and lift up thine eyes westward, and northward, and southward, and eastward, and behold it with thine eyes: for thou shalt not go over this Jordan.
5004	156	28	But charge Joshua, and encourage him, and strengthen him: for he shall go over before this people, and he shall cause them to inherit the land which thou shalt see.
5005	156	29	So we abode in the valley over against Beth-peor.
5006	157	1	NOW therefore hearken, O Israel, unto the statutes and unto the judgments, which I teach you, for to do them, that ye may live, and go in and possess the land which the LORD God of your fathers giveth you.
5007	157	2	Ye shall not add unto the word which I command you, neither shall ye diminish ought from it, that ye may keep the commandments of the LORD your God which I command you.
5008	157	3	Your eyes have seen what the LORD did because of Baal-peor: for all the men that followed Baal-peor, the LORD thy God hath destroyed them from among you.
5009	157	4	But ye that did cleave unto the LORD your God are alive every one of you this day.
5010	157	5	Behold, I have taught you statutes and judgments, even as the LORD my God commanded me, that ye should do so in the land whither ye go to possess it.
5011	157	6	Keep therefore and do them; for this is your wisdom and your understanding in the sight of the nations, which shall hear all these statutes, and say, Surely this great nation is a wise and understanding people.
5012	157	7	For what nation is there so great, who hath God so nigh unto them, as the LORD our God is in all things that we call upon him for?
5013	157	8	And what nation is there so great, that hath statutes and judgments so righteous as all this law, which I set before you this day?
5014	157	9	Only take heed to thyself, and keep thy soul diligently, lest thou forget the things which thine eyes have seen, and lest they depart from thy heart all the days of thy life: but teach them thy sons, and thy sons' sons;
5015	157	10	Specially the day that thou stoodest before the LORD thy God in Horeb, when the LORD said unto me, Gather me the people together, and I will make them hear my words, that they may learn to fear me all the days that they shall live upon the earth, and that they may teach their children.
5016	157	11	And ye came near and stood under the mountain; and the mountain burned with fire unto the midst of heaven, with darkness, clouds, and thick darkness.
5017	157	12	And the LORD spake unto you out of the midst of the fire: ye heard the voice of the words, but saw no similitude; only ye heard a voice.
5018	157	13	And he declared unto you his covenant, which he commanded you to perform, even ten commandments; and he wrote them upon two tables of stone.
5019	157	14	And the LORD commanded me at that time to teach you statutes and judgments, that ye might do them in the land whither ye go over to possess it.
5020	157	15	Take ye therefore good heed unto yourselves; for ye saw no manner of similitude on the day that the LORD spake unto you in Horeb out of the midst of the fire:
5021	157	16	Lest ye corrupt yourselves, and make you a graven image, the similitude of any figure, the likeness of male or female,
5022	157	17	The likeness of any beast that is on the earth, the likeness of any winged fowl that flieth in the air,
5023	157	18	The likeness of any thing that creepeth on the ground, the likeness of any fish that is in the waters beneath the earth:
5024	157	19	And lest thou lift up thine eyes unto heaven, and when thou seest the sun, and the moon, and the stars, even all the host of heaven, shouldest be driven to worship them, and serve them, which the LORD thy God hath divided unto all nations under the whole heaven.
5025	157	20	But the LORD hath taken you, and brought you forth out of the iron furnace, even out of Egypt, to be unto him a people of inheritance, as ye are this day.
5026	157	21	Furthermore the LORD was angry with me for your sakes, and sware that I should not go over Jordan, and that I should not go in unto that good land, which the LORD thy God giveth thee for an inheritance:
5027	157	22	But I must die in this land, I must not go over Jordan: but ye shall go over, and possess that good land.
5028	157	23	Take heed unto yourselves, lest ye forget the covenant of the LORD your God, which he made with you, and make you a graven image, or the likeness of any thing, which the LORD thy God hath forbidden thee.
5029	157	24	For the LORD thy God is a consuming fire, even a jealous God.
5030	157	25	When thou shalt beget children, and children's children, and ye shall have remained long in the land, and shall corrupt yourselves, and make a graven image, or the likeness of any thing, and shall do evil in the sight of the LORD thy God, to provoke him to anger:
5031	157	26	I call heaven and earth to witness against you this day, that ye shall soon utterly perish from off the land whereunto ye go over Jordan to possess it; ye shall not prolong your days upon it, but shall utterly be destroyed.
5032	157	27	And the LORD shall scatter you among the nations, and ye shall be left few in number among the heathen, whither the LORD shall lead you.
5033	157	28	And there ye shall serve gods, the work of men's hands, wood and stone, which neither see, nor hear, nor eat, nor smell.
5034	157	29	But if from thence thou shalt seek the LORD thy God, thou shalt find him, if thou seek him with all thy heart and with all thy soul.
5035	157	30	When thou art in tribulation, and all these things are come upon thee, even in the latter days, if thou turn to the LORD thy God, and shalt be obedient unto his voice;
5036	157	31	(For the LORD thy God is a merciful God;) he will not forsake thee, neither destroy thee, nor forget the covenant of thy fathers which he sware unto them.
5037	157	32	For ask now of the days that are past, which were before thee, since the day that God created man upon the earth, and ask from the one side of heaven unto the other, whether there hath been any such thing as this great thing is, or hath been heard like it?
5038	157	33	Did ever people hear the voice of God speaking out of the midst of the fire, as thou hast heard, and live?
5039	157	34	Or hath God assayed to go and take him a nation from the midst of another nation, by temptations, by signs, and by wonders, and by war, and by a mighty hand, and by a stretched out arm, and by great terrors, according to all that the LORD your God did for you in Egypt before your eyes?
5040	157	35	Unto thee it was shewed, that thou mightest know that the LORD he is God; there is none else beside him.
5041	157	36	Out of heaven he made thee to hear his voice, that he might instruct thee: and upon earth he shewed thee his great fire; and thou heardest his words out of the midst of the fire.
5042	157	37	And because he loved thy fathers, therefore he chose their seed after them, and brought thee out in his sight with his mighty power out of Egypt;
5043	157	38	To drive out nations from before thee greater and mightier than thou art, to bring thee in, to give thee their land for an inheritance, as it is this day.
5044	157	39	Know therefore this day, and consider it in thine heart, that the LORD he is God in heaven above, and upon the earth beneath: there is none else.
5045	157	40	Thou shalt keep therefore his statutes, and his commandments, which I command thee this day, that it may go well with thee, and with thy children after thee, and that thou mayest prolong thy days upon the earth, which the LORD thy God giveth thee, for ever.
5046	157	41	Then Moses severed three cities on this side Jordan toward the sunrising;
5047	157	42	That the slayer might flee thither, which should kill his neighbour unawares, and hated him not in times past; and that fleeing unto one of these cities he might live:
5048	157	43	Namely, Bezer in the wilderness, in the plain country, of the Reubenites; and Ramoth in Gilead, of the Gadites; and Golan in Bashan, of the Manassites.
5049	157	44	And this is the law which Moses set before the children of Israel:
5050	157	45	These are the testimonies, and the statutes, and the judgments, which Moses spake unto the children of Israel, after they came forth out of Egypt,
5051	157	46	On this side Jordan, in the valley over against Beth-peor, in the land of Sihon king of the Amorites, who dwelt at Heshbon, whom Moses and the children of Israel smote, after they were come forth out of Egypt:
5052	157	47	And they possessed his land, and the land of Og king of Bashan, two kings of the Amorites, which were on this side Jordan toward the sunrising;
5053	157	48	From Aroer, which is by the bank of the river Arnon, even unto mount Sion, which is Hermon,
5054	157	49	And all the plain on this side Jordan eastward, even unto the sea of the plain, under the springs of Pisgah.
5055	158	1	AND Moses called all Israel, and said unto them, Hear, O Israel, the statutes and judgments which I speak in your ears this day, that ye may learn them, and keep, and do them.
5056	158	2	The LORD our God made a covenant with us in Horeb.
5057	158	3	The LORD made not this covenant with our fathers, but with us, even us, who are all of us here alive this day.
5058	158	4	The LORD talked with you face to face in the mount out of the midst of the fire,
5059	158	5	(I stood between the LORD and you at that time, to shew you the work of the LORD: for ye were afraid by reason of the fire, and went not up into the mount;) saying,
5060	158	6	I am the LORD thy God, which brought thee out of the land of Egypt, from the house of bondage.
5061	158	7	Thou shalt have none other gods before me.
5062	158	8	Thou shalt not make thee any graven image, or any likeness of any thing that is in heaven above, or that is in the earth beneath, or that is in the waters beneath the earth:
5063	158	9	Thou shalt not bow down thyself unto them, nor serve them: for I the LORD thy God am a jealous God, visiting the iniquity of the fathers upon the children unto the third and fourth generation of them that hate me,
5064	158	10	And shewing mercy unto thousands of them that love me and keep my commandments.
5065	158	11	Thou shalt not take the name of the LORD thy God in vain: for the LORD will not hold him guiltless that taketh his name in vain.
5066	158	12	Keep the sabbath day to sanctify it, as the LORD thy God hath commanded thee.
5067	158	13	Six days thou shalt labour, and do all thy work:
5068	158	14	But the seventh day is the sabbath of the LORD thy God: in it thou shalt not do any work, thou, nor thy son, nor thy daughter, nor thy manservant, nor thy maidservant, nor thine ox, nor thine ass, nor any of thy cattle, nor thy stranger that is within thy gates; that thy manservant and thy maidservant may rest as well as thou.
5069	158	15	And remember that thou wast a servant in the land of Egypt, and that the LORD thy God brought thee out thence through a mighty hand and by a stretched out arm: therefore the LORD thy God commanded thee to keep the sabbath day.
5070	158	16	Honour thy father and thy mother, as the LORD thy God hath commanded thee; that thy days may be prolonged, and that it may go well with thee, in the land which the LORD thy God giveth thee.
5071	158	17	Thou shalt not kill.
5072	158	18	Neither shalt thou commit adultery.
5073	158	19	Neither shalt thou steal.
5074	158	20	Neither shalt thou bear false witness against thy neighbour.
5075	158	21	Neither shalt thou desire thy neighbour's wife, neither shalt thou covet thy neighbour's house, his field, or his manservant, or his maidservant, his ox, or his ass, or any thing that is thy neighbour's.
5076	158	22	These words the LORD spake unto all your assembly in the mount out of the midst of the fire, of the cloud, and of the thick darkness, with a great voice: and he added no more. And he wrote them in two tables of stone, and delivered them unto me.
5077	158	23	And it came to pass, when ye heard the voice out of the midst of the darkness, (for the mountain did burn with fire,) that ye came near unto me, even all the heads of your tribes, and your elders;
5078	158	24	And ye said, Behold, the LORD our God hath shewed us his glory and his greatness, and we have heard his voice out of the midst of the fire: we have seen this day that God doth talk with man, and he liveth.
5079	158	25	Now therefore why should we die? for this great fire will consume us: if we hear the voice of the LORD our God any more, then we shall die.
5080	158	26	For who is there of all flesh, that hath heard the voice of the living God speaking out of the midst of the fire, as we have, and lived?
5081	158	27	Go thou near, and hear all that the LORD our God shall say: and speak thou unto us all that the LORD our God shall speak unto thee; and we will hear it, and do it.
5082	158	28	And the LORD heard the voice of your words, when ye spake unto me; and the LORD said unto me, I have heard the voice of the words of this people, which they have spoken unto thee: they have well said all that they have spoken.
5083	158	29	O that there were such an heart in them, that they would fear me, and keep all my commandments always, that it might be well with them, and with their children for ever!
5084	158	30	Go say to them, Get you into your tents again.
5085	158	31	But as for thee, stand thou here by me, and I will speak unto thee all the commandments, and the statutes, and the judgments, which thou shalt teach them, that they may do them in the land which I give them to possess it.
5086	158	32	Ye shall observe to do therefore as the LORD your God hath commanded you: ye shall not turn aside to the right hand or to the left.
5087	158	33	Ye shall walk in all the ways which the LORD your God hath commanded you, that ye may live, and that it may be well with you, and that ye may prolong your days in the land which ye shall possess.
5088	159	1	NOW these are the commandments, the statutes, and the judgments, which the LORD your God commanded to teach you, that ye might do them in the land whither ye go to possess it:
5089	159	2	That thou mightest fear the LORD thy God, to keep all his statutes and his commandments, which I command thee, thou, and thy son, and thy son's son, all the days of thy life; and that thy days may be prolonged.
5090	159	3	Hear therefore, O Israel, and observe to do it; that it may be well with thee, and that ye may increase mightily, as the LORD God of thy fathers hath promised thee, in the land that floweth with milk and honey.
5091	159	4	Hear, O Israel: The LORD our God is one LORD:
5092	159	5	And thou shalt love the LORD thy God with all thine heart, and with all thy soul, and with all thy might.
5093	159	6	And these words, which I command thee this day, shall be in thine heart:
5094	159	7	And thou shalt teach them diligently unto thy children, and shalt talk of them when thou sittest in thine house, and when thou walkest by the way, and when thou liest down, and when thou risest up.
5095	159	8	And thou shalt bind them for a sign upon thine hand, and they shall be as frontlets between thine eyes.
5096	159	9	And thou shalt write them upon the posts of thy house, and on thy gates.
5097	159	10	And it shall be, when the LORD thy God shall have brought thee into the land which he sware unto thy fathers, to Abraham, to Isaac, and to Jacob, to give thee great and goodly cities, which thou buildedst not,
5098	159	11	And houses full of all good things, which thou filledst not, and wells digged, which thou diggedst not, vineyards and olive trees, which thou plantedst not; when thou shalt have eaten and be full;
5099	159	12	Then beware lest thou forget the LORD, which brought thee forth out of the land of Egypt, from the house of bondage.
5100	159	13	Thou shalt fear the LORD thy God, and serve him, and shalt swear by his name.
5101	159	14	Ye shall not go after other gods, of the gods of the people which are round about you;
5102	159	15	(For the LORD thy God is a jealous God among you) lest the anger of the LORD thy God be kindled against thee, and destroy thee from off the face of the earth.
5103	159	16	Ye shall not tempt the LORD your God, as ye tempted him in Massah.
5104	159	17	Ye shall diligently keep the commandments of the LORD your God, and his testimonies, and his statutes, which he hath commanded thee.
5105	159	18	And thou shalt do that which is right and good in the sight of the LORD: that it may be well with thee, and that thou mayest go in and possess the good land which the LORD sware unto thy fathers,
5106	159	19	To cast out all thine enemies from before thee, as the LORD hath spoken.
5107	159	20	And when thy son asketh thee in time to come, saying, What mean the testimonies, and the statutes, and the judgments, which the LORD our God hath commanded you?
5108	159	21	Then thou shalt say unto thy son, We were Pharaoh's bondmen in Egypt; and the LORD brought us out of Egypt with a mighty hand:
5109	159	22	And the LORD shewed signs and wonders, great and sore, upon Egypt, upon Pharaoh, and upon all his household, before our eyes:
5110	159	23	And he brought us out from thence, that he might bring us in, to give us the land which he sware unto our fathers.
5111	159	24	And the LORD commanded us to do all these statutes, to fear the LORD our God, for our good always, that he might preserve us alive, as it is at this day.
5112	159	25	And it shall be our righteousness, if we observe to do all these commandments before the LORD our God, as he hath commanded us.
5113	160	1	WHEN the LORD thy God shall bring thee into the land whither thou goest to possess it, and hath cast out many nations before thee, the Hittites, and the Girgashites, and the Amorites, and the Canaanites, and the Perizzites, and the Hivites, and the Jebusites, seven nations greater and mightier than thou;
5114	160	2	And when the LORD thy God shall deliver them before thee; thou shalt smite them, and utterly destroy them; thou shalt make no covenant with them, nor shew mercy unto them:
5115	160	3	Neither shalt thou make marriages with them; thy daughter thou shalt not give unto his son, nor his daughter shalt thou take unto thy son.
5116	160	4	For they will turn away thy son from following me, that they may serve other gods: so will the anger of the LORD be kindled against you, and destroy thee suddenly.
5117	160	5	But thus shall ye deal with them; ye shall destroy their altars, and break down their images, and cut down their groves, and burn their graven images with fire.
5118	160	6	For thou art an holy people unto the LORD thy God: the LORD thy God hath chosen thee to be a special people unto himself, above all people that are upon the face of the earth.
5119	160	7	The LORD did not set his love upon you, nor choose you, because ye were more in number than any people; for ye were the fewest of all people:
5120	160	8	But because the LORD loved you, and because he would keep the oath which he had sworn unto your fathers, hath the LORD brought you out with a mighty hand, and redeemed you out of the house of bondmen, from the hand of Pharaoh king of Egypt.
5121	160	9	Know therefore that the LORD thy God, he is God, the faithful God, which keepeth covenant and mercy with them that love him and keep his commandments to a thousand generations;
5122	160	10	And repayeth them that hate him to their face, to destroy them: he will not be slack to him that hateth him, he will repay him to his face.
5123	160	11	Thou shalt therefore keep the commandments, and the statutes, and the judgments, which I command thee this day, to do them.
5124	160	12	Wherefore it shall come to pass, if ye hearken to these judgments, and keep, and do them, that the LORD thy God shall keep unto thee the covenant and the mercy which he sware unto thy fathers:
5125	160	13	And he will love thee, and bless thee, and multiply thee: he will also bless the fruit of thy womb, and the fruit of thy land, thy corn, and thy wine, and thine oil, the increase of thy kine, and the flocks of thy sheep, in the land which he sware unto thy fathers to give thee.
5126	160	14	Thou shalt be blessed above all people: there shall not be male or female barren among you, or among your cattle.
5127	160	15	And the LORD will take away from thee all sickness, and will put none of the evil diseases of Egypt, which thou knowest, upon thee; but will lay them upon all them that hate thee.
5128	160	16	And thou shalt consume all the people which the LORD thy God shall deliver thee; thine eye shall have no pity upon them: neither shalt thou serve their gods; for that will be a snare unto thee.
5129	160	17	If thou shalt say in thine heart, These nations are more than I; how can I dispossess them?
5130	160	18	Thou shalt not be afraid of them: but shalt well remember what the LORD thy God did unto Pharaoh, and unto all Egypt;
5131	160	19	The great temptations which thine eyes saw, and the signs, and the wonders, and the mighty hand, and the stretched out arm, whereby the LORD thy God brought thee out: so shall the LORD thy God do unto all the people of whom thou art afraid.
5132	160	20	Moreover the LORD thy God will send the hornet among them, until they that are left, and hide themselves from thee, be destroyed.
5133	160	21	Thou shalt not be affrighted at them: for the LORD thy God is among you, a mighty God and terrible.
5134	160	22	And the LORD thy God will put out those nations before thee by little and little: thou mayest not consume them at once, lest the beasts of the field increase upon thee.
5135	160	23	But the LORD thy God shall deliver them unto thee, and shall destroy them with a mighty destruction, until they be destroyed.
5136	160	24	And he shall deliver their kings into thine hand, and thou shalt destroy their name from under heaven: there shall no man be able to stand before thee, until thou have destroyed them.
5137	160	25	The graven images of their gods shall ye burn with fire: thou shalt not desire the silver or gold that is on them, nor take it unto thee, lest thou be snared therein: for it is an abomination to the LORD thy God.
5138	160	26	Neither shalt thou bring an abomination into thine house, lest thou be a cursed thing like it: but thou shalt utterly detest it, and thou shalt utterly abhor it; for it is a cursed thing.
5139	161	1	ALL the commandments which I command thee this day shall ye observe to do, that ye may live, and multiply, and go in and possess the land which the LORD sware unto your fathers.
5140	161	2	And thou shalt remember all the way which the LORD thy God led thee these forty years in the wilderness, to humble thee, and to prove thee, to know what was in thine heart, whether thou wouldest keep his commandments, or no.
5141	161	3	And he humbled thee, and suffered thee to hunger, and fed thee with manna, which thou knewest not, neither did thy fathers know; that he might make thee know that man doth not live by bread only, but by every word that proceedeth out of the mouth of the LORD doth man live.
5142	161	4	Thy raiment waxed not old upon thee, neither did thy foot swell, these forty years.
5143	161	5	Thou shalt also consider in thine heart, that, as a man chasteneth his son, so the LORD thy God chasteneth thee.
5144	161	6	Therefore thou shalt keep the commandments of the LORD thy God, to walk in his ways, and to fear him.
5145	161	7	For the LORD thy God bringeth thee into a good land, a land of brooks of water, of fountains and depths that spring out of valleys and hills;
5146	161	8	A land of wheat, and barley, and vines, and fig trees, and pomegranates; a land of oil olive, and honey;
5147	161	9	A land wherein thou shalt eat bread without scarceness, thou shalt not lack any thing in it; a land whose stones are iron, and out of whose hills thou mayest dig brass.
5148	161	10	When thou hast eaten and art full, then thou shalt bless the LORD thy God for the good land which he hath given thee.
5149	161	11	Beware that thou forget not the LORD thy God, in not keeping his commandments, and his judgments, and his statutes, which I command thee this day:
5150	161	12	Lest when thou hast eaten and art full, and hast built goodly houses, and dwelt therein;
5151	161	13	And when thy herds and thy flocks multiply, and thy silver and thy gold is multiplied, and all that thou hast is multiplied;
5152	161	14	Then thine heart be lifted up, and thou forget the LORD thy God, which brought thee forth out of the land of Egypt, from the house of bondage;
5153	161	15	Who led thee through that great and terrible wilderness, wherein were fiery serpents, and scorpions, and drought, where there was no water; who brought thee forth water out of the rock of flint;
5154	161	16	Who fed thee in the wilderness with manna, which thy fathers knew not, that he might humble thee, and that he might prove thee, to do thee good at thy latter end;
5155	161	17	And thou say in thine heart, My power and the might of mine hand hath gotten me this wealth.
5156	161	18	But thou shalt remember the LORD thy God: for it is he that giveth thee power to get wealth, that he may establish his covenant which he sware unto thy fathers, as it is this day.
5157	161	19	And it shall be, if thou do at all forget the LORD thy God, and walk after other gods, and serve them, and worship them, I testify against you this day that ye shall surely perish.
5158	161	20	As the nations which the LORD destroyeth before your face, so shall ye perish; because ye would not be obedient unto the voice of the LORD your God.
5159	162	1	HEAR, O Israel: Thou art to pass over Jordan this day, to go in to possess nations greater and mightier than thyself, cities great and fenced up to heaven,
5160	162	2	A people great and tall, the children of the Anakims, whom thou knowest, and of whom thou hast heard say, Who can stand before the children of Anak!
5161	162	3	Understand therefore this day, that the LORD thy God is he which goeth over before thee; as a consuming fire he shall destroy them, and he shall bring them down before thy face: so shalt thou drive them out, and destroy them quickly, as the LORD hath said unto thee.
5162	162	4	Speak not thou in thine heart, after that the LORD thy God hath cast them out from before thee, saying, For my righteousness the LORD hath brought me in to possess this land: but for the wickedness of these nations the LORD doth drive them out from before thee.
5163	162	5	Not for thy righteousness, or for the uprightness of thine heart, dost thou go to possess their land: but for the wickedness of these nations the LORD thy God doth drive them out from before thee, and that he may perform the word which the LORD sware unto thy fathers, Abraham, Isaac, and Jacob.
5164	162	6	Understand therefore, that the LORD thy God giveth thee not this good land to possess it for thy righteousness; for thou art a stiffnecked people.
5165	162	7	Remember, and forget not, how thou provokedst the LORD thy God to wrath in the wilderness: from the day that thou didst depart out of the land of Egypt, until ye came unto this place, ye have been rebellious against the LORD.
5166	162	8	Also in Horeb ye provoked the LORD to wrath, so that the LORD was angry with you to have destroyed you.
5167	162	9	When I was gone up into the mount to receive the tables of stone, even the tables of the covenant which the LORD made with you, then I abode in the mount forty days and forty nights, I neither did eat bread nor drink water:
5168	162	10	And the LORD delivered unto me two tables of stone written with the finger of God; and on them was written according to all the words, which the LORD spake with you in the mount out of the midst of the fire in the day of the assembly.
5169	162	11	And it came to pass at the end of forty days and forty nights, that the LORD gave me the two tables of stone, even the tables of the covenant.
5170	162	12	And the LORD said unto me, Arise, get thee down quickly from hence; for thy people which thou hast brought forth out of Egypt have corrupted themselves; they are quickly turned aside out of the way which I commanded them; they have made them a molten image.
5171	162	13	Furthermore the LORD spake unto me, saying, I have seen this people, and, behold, it is a stiffnecked people:
5172	162	14	Let me alone, that I may destroy them, and blot out their name from under heaven: and I will make of thee a nation mightier and greater than they.
5173	162	15	So I turned and came down from the mount, and the mount burned with fire: and the two tables of the covenant were in my two hands.
5174	162	16	And I looked, and, behold, ye had sinned against the LORD your God, and had made you a molten calf: ye had turned aside quickly out of the way which the LORD had commanded you.
5175	162	17	And I took the two tables, and cast them out of my two hands, and brake them before your eyes.
5176	162	18	And I fell down before the LORD, as at the first, forty days and forty nights: I did neither eat bread, nor drink water, because of all your sins which ye sinned, in doing wickedly in the sight of the LORD, to provoke him to anger.
5177	162	19	For I was afraid of the anger and hot displeasure, wherewith the LORD was wroth against you to destroy you. But the LORD hearkened unto me at that time also.
5178	162	20	And the LORD was very angry with Aaron to have destroyed him: and I prayed for Aaron also the same time.
5179	162	21	And I took your sin, the calf which ye had made, and burnt it with fire, and stamped it, and ground it very small, even until it was as small as dust: and I cast the dust thereof into the brook that descended out of the mount.
5180	162	22	And at Taberah, and at Massah, and at Kibroth-hattaavah, ye provoked the LORD to wrath.
5181	162	23	Likewise when the LORD sent you from Kadesh-barnea, saying, Go up and possess the land which I have given you; then ye rebelled against the commandment of the LORD your God, and ye believed him not, nor hearkened to his voice.
5182	162	24	Ye have been rebellious against the LORD from the day that I knew you.
5183	162	25	Thus I fell down before the LORD forty days and forty nights, as I fell down at the first; because the LORD had said he would destroy you.
5184	162	26	I prayed therefore unto the LORD, and said, O Lord GOD, destroy not thy people and thine inheritance, which thou hast redeemed through thy greatness, which thou hast brought forth out of Egypt with a mighty hand.
5185	162	27	Remember thy servants, Abraham, Isaac, and Jacob; look not unto the stubbornness of this people, nor to their wickedness, nor to their sin:
5186	162	28	Lest the land whence thou broughtest us out say, Because the LORD was not able to bring them into the land which he promised them, and because he hated them, he hath brought them out to slay them in the wilderness.
5187	162	29	Yet they are thy people and thine inheritance, which thou broughtest out by thy mighty power and by thy stretched out arm.
5188	163	1	AT that time the LORD said unto me, Hew thee two tables of stone like unto the first, and come up unto me into the mount, and make thee an ark of wood.
5189	163	2	And I will write on the tables the words that were in the first tables which thou brakest, and thou shalt put them in the ark.
5190	163	3	And I made an ark of shittim wood, and hewed two tables of stone like unto the first, and went up into the mount, having the two tables in mine hand.
5191	163	4	And he wrote on the tables, according to the first writing, the ten commandments, which the LORD spake unto you in the mount out of the midst of the fire in the day of the assembly: and the LORD gave them unto me.
5192	163	5	And I turned myself and came down from the mount, and put the tables in the ark which I had made; and there they be, as the LORD commanded me.
5193	163	6	And the children of Israel took their journey from Beeroth of the children of Jaakan to Mosera: there Aaron died, and there he was buried; and Eleazar his son ministered in the priest's office in his stead.
5194	163	7	From thence they journeyed unto Gudgodah; and from Gudgodah to Jotbath, a land of rivers of waters.
5195	163	8	At that time the LORD separated the tribe of Levi, to bear the ark of the covenant of the LORD, to stand before the LORD to minister unto him, and to bless in his name, unto this day.
5196	163	9	Wherefore Levi hath no part nor inheritance with his brethren; the LORD is his inheritance, according as the LORD thy God promised him.
5197	163	10	And I stayed in the mount, according to the first time, forty days and forty nights; and the LORD hearkened unto me at that time also, and the LORD would not destroy thee.
5198	163	11	And the LORD said unto me, Arise, take thy journey before the people, that they may go in and possess the land, which I sware unto their fathers to give unto them.
5199	163	12	And now, Israel, what doth the LORD thy God require of thee, but to fear the LORD thy God, to walk in all his ways, and to love him, and to serve the LORD thy God with all thy heart and with all thy soul,
5200	163	13	To keep the commandments of the LORD, and his statutes, which I command thee this day for thy good?
5201	163	14	Behold, the heaven and the heaven of heavens is the LORD's thy God, the earth also, with all that therein is.
5202	163	15	Only the LORD had a delight in thy fathers to love them, and he chose their seed after them, even you above all people, as it is this day.
5203	163	16	Circumcise therefore the foreskin of your heart, and be no more stiffnecked.
5204	163	17	For the LORD your God is God of gods, and Lord of lords, a great God, a mighty, and a terrible, which regardeth not persons, nor taketh reward:
5205	163	18	He doth execute the judgment of the fatherless and widow, and loveth the stranger, in giving him food and raiment.
5206	163	19	Love ye therefore the stranger: for ye were strangers in the land of Egypt.
5207	163	20	Thou shalt fear the LORD thy God; him shalt thou serve, and to him shalt thou cleave, and swear by his name.
5208	163	21	He is thy praise, and he is thy God, that hath done for thee these great and terrible things, which thine eyes have seen.
5209	163	22	Thy fathers went down into Egypt with threescore and ten persons; and now the LORD thy God hath made thee as the stars of heaven for multitude.
5210	164	1	THEREFORE thou shalt love the LORD thy God, and keep his charge, and his statutes, and his judgments, and his commandments, alway.
5211	164	2	And know ye this day: for I speak not with your children which have not known, and which have not seen the chastisement of the LORD your God, his greatness, his mighty hand, and his stretched out arm,
5212	164	3	And his miracles, and his acts, which he did in the midst of Egypt unto Pharaoh the king of Egypt, and unto all his land;
5213	164	4	And what he did unto the army of Egypt, unto their horses, and to their chariots; how he made the water of the Red sea to overflow them as they pursued after you, and how the LORD hath destroyed them unto this day;
5214	164	5	And what he did unto you in the wilderness, until ye came into this place;
5215	164	6	And what he did unto Dathan and Abiram, the sons of Eliab, the son of Reuben: how the earth opened her mouth, and swallowed them up, and their households, and their tents, and all the substance that was in their possession, in the midst of all Israel:
5216	164	7	But your eyes have seen all the great acts of the LORD which he did.
5217	164	8	Therefore shall ye keep all the commandments which I command you this day, that ye may be strong, and go in and possess the land, whither ye go to possess it;
5218	164	9	And that ye may prolong your days in the land, which the LORD sware unto your fathers to give unto them and to their seed, a land that floweth with milk and honey.
5219	164	10	For the land, whither thou goest in to possess it, is not as the land of Egypt, from whence ye came out, where thou sowedst thy seed, and wateredst it with thy foot, as a garden of herbs:
5220	164	11	But the land, whither ye go to possess it, is a land of hills and valleys, and drinketh water of the rain of heaven:
5221	164	12	A land which the LORD thy God careth for: the eyes of the LORD thy God are always upon it, from the beginning of the year even unto the end of the year.
5222	164	13	And it shall come to pass, if ye shall hearken diligently unto my commandments which I command you this day, to love the LORD your God, and to serve him with all your heart and with all your soul,
5223	164	14	That I will give you the rain of your land in his due season, the first rain and the latter rain, that thou mayest gather in thy corn, and thy wine, and thine oil.
5224	164	15	And I will send grass in thy fields for thy cattle, that thou mayest eat and be full.
5225	164	16	Take heed to yourselves, that your heart be not deceived, and ye turn aside, and serve other gods, and worship them;
5226	164	17	And then the LORD's wrath be kindled against you, and he shut up the heaven, that there be no rain, and that the land yield not her fruit; and lest ye perish quickly from off the good land which the LORD giveth you.
5227	164	18	Therefore shall ye lay up these my words in your heart and in your soul, and bind them for a sign upon your hand, that they may be as frontlets between your eyes.
5228	164	19	And ye shall teach them your children, speaking of them when thou sittest in thine house, and when thou walkest by the way, when thou liest down, and when thou risest up.
5229	164	20	And thou shalt write them upon the door posts of thine house, and upon thy gates:
5230	164	21	That your days may be multiplied, and the days of your children, in the land which the LORD sware unto your fathers to give them, as the days of heaven upon the earth.
5231	164	22	For if ye shall diligently keep all these commandments which I command you, to do them, to love the LORD your God, to walk in all his ways, and to cleave unto him;
5232	164	23	Then will the LORD drive out all these nations from before you, and ye shall possess greater nations and mightier than yourselves.
5233	164	24	Every place whereon the soles of your feet shall tread shall be yours: from the wilderness and Lebanon, from the river, the river Euphrates, even unto the uttermost sea shall your coast be.
5234	164	25	There shall no man be able to stand before you: for the LORD your God shall lay the fear of you and the dread of you upon all the land that ye shall tread upon, as he hath said unto you.
5235	164	26	Behold, I set before you this day a blessing and a curse;
5236	164	27	A blessing, if ye obey the commandments of the LORD your God, which I command you this day:
5237	164	28	And a curse, if ye will not obey the commandments of the LORD your God, but turn aside out of the way which I command you this day, to go after other gods, which ye have not known.
5238	164	29	And it shall come to pass, when the LORD thy God hath brought thee in unto the land whither thou goest to possess it, that thou shalt put the blessing upon mount Gerizim, and the curse upon mount Ebal.
5239	164	30	Are they not on the other side Jordan, by the way where the sun goeth down, in the land of the Canaanites, which dwell in the champaign over against Gilgal, beside the plains of Moreh?
5240	164	31	For ye shall pass over Jordan to go in to possess the land which the LORD your God giveth you, and ye shall possess it, and dwell therein.
5241	164	32	And ye shall observe to do all the statutes and judgments which I set before you this day.
5242	165	1	THESE are the statutes and judgments, which ye shall observe to do in the land, which the LORD God of thy fathers giveth thee to possess it, all the days that ye live upon the earth.
5243	165	2	Ye shall utterly destroy all the places, wherein the nations which ye shall possess served their gods, upon the high mountains, and upon the hills, and under every green tree:
5244	165	3	And ye shall overthrow their altars, and break their pillars, and burn their groves with fire; and ye shall hew down the graven images of their gods, and destroy the names of them out of that place.
5245	165	4	Ye shall not do so unto the LORD your God.
5246	165	5	But unto the place which the LORD your God shall choose out of all your tribes to put his name there, even unto his habitation shall ye seek, and thither thou shalt come:
5247	165	6	And thither ye shall bring your burnt offerings, and your sacrifices, and your tithes, and heave offerings of your hand, and your vows, and your freewill offerings, and the firstlings of your herds and of your flocks:
5248	165	7	And there ye shall eat before the LORD your God, and ye shall rejoice in all that ye put your hand unto, ye and your households, wherein the LORD thy God hath blessed thee.
5249	165	8	Ye shall not do after all the things that we do here this day, every man whatsoever is right in his own eyes.
5250	165	9	For ye are not as yet come to the rest and to the inheritance, which the LORD your God giveth you.
5251	165	10	But when ye go over Jordan, and dwell in the land which the LORD your God giveth you to inherit, and when he giveth you rest from all your enemies round about, so that ye dwell in safety;
5252	165	11	Then there shall be a place which the LORD your God shall choose to cause his name to dwell there; thither shall ye bring all that I command you; your burnt offerings, and your sacrifices, your tithes, and the heave offering of your hand, and all your choice vows which ye vow unto the LORD:
5253	165	12	And ye shall rejoice before the LORD your God, ye, and your sons, and your daughters, and your menservants, and your maidservants, and the Levite that is within your gates; forasmuch as he hath no part nor inheritance with you.
5254	165	13	Take heed to thyself that thou offer not thy burnt offerings in every place that thou seest:
5255	165	14	But in the place which the LORD shall choose in one of thy tribes, there thou shalt offer thy burnt offerings, and there thou shalt do all that I command thee.
5256	165	15	Notwithstanding thou mayest kill and eat flesh in all thy gates, whatsoever thy soul lusteth after, according to the blessing of the LORD thy God which he hath given thee: the unclean and the clean may eat thereof, as of the roebuck, and as of the hart.
5257	165	16	Only ye shall not eat the blood; ye shall pour it upon the earth as water.
5258	165	17	Thou mayest not eat within thy gates the tithe of thy corn, or of thy wine, or of thy oil, or the firstlings of thy herds or of thy flock, nor any of thy vows which thou vowest, nor thy freewill offerings, or heave offering of thine hand:
5259	165	18	But thou must eat them before the LORD thy God in the place which the LORD thy God shall choose, thou, and thy son, and thy daughter, and thy manservant, and thy maidservant, and the Levite that is within thy gates: and thou shalt rejoice before the LORD thy God in all that thou puttest thine hands unto.
5260	165	19	Take heed to thyself that thou forsake not the Levite as long as thou livest upon the earth.
5261	165	20	When the LORD thy God shall enlarge thy border, as he hath promised thee, and thou shalt say, I will eat flesh, because thy soul longeth to eat flesh; thou mayest eat flesh, whatsoever thy soul lusteth after.
5262	165	21	If the place which the LORD thy God hath chosen to put his name there be too far from thee, then thou shalt kill of thy herd and of thy flock, which the LORD hath given thee, as I have commanded thee, and thou shalt eat in thy gates whatsoever thy soul lusteth after.
5263	165	22	Even as the roebuck and the hart is eaten, so thou shalt eat them: the unclean and the clean shall eat of them alike.
5264	165	23	Only be sure that thou eat not the blood: for the blood is the life; and thou mayest not eat the life with the flesh.
5265	165	24	Thou shalt not eat it; thou shalt pour it upon the earth as water.
5266	165	25	Thou shalt not eat it; that it may go well with thee, and with thy children after thee, when thou shalt do that which is right in the sight of the LORD.
5267	165	26	Only thy holy things which thou hast, and thy vows, thou shalt take, and go unto the place which the LORD shall choose:
5268	165	27	And thou shalt offer thy burnt offerings, the flesh and the blood, upon the altar of the LORD thy God: and the blood of thy sacrifices shall be poured out upon the altar of the LORD thy God, and thou shalt eat the flesh.
5269	165	28	Observe and hear all these words which I command thee, that it may go well with thee, and with thy children after thee for ever, when thou doest that which is good and right in the sight of the LORD thy God.
5270	165	29	When the LORD thy God shall cut off the nations from before thee, whither thou goest to possess them, and thou succeedest them, and dwellest in their land;
5271	165	30	Take heed to thyself that thou be not snared by following them, after that they be destroyed from before thee; and that thou inquire not after their gods, saying, How did these nations serve their gods? even so will I do likewise.
5272	165	31	Thou shalt not do so unto the LORD thy God: for every abomination to the LORD, which he hateth, have they done unto their gods; for even their sons and their daughters they have burnt in the fire to their gods.
5273	165	32	What thing soever I command you, observe to do it: thou shalt not add thereto, nor diminish from it.
5274	166	1	IF there arise among you a prophet, or a dreamer of dreams, and giveth thee a sign or a wonder,
5275	166	2	And the sign or the wonder come to pass, whereof he spake unto thee, saying, Let us go after other gods, which thou hast not known, and let us serve them;
5276	166	3	Thou shalt not hearken unto the words of that prophet, or that dreamer of dreams: for the LORD your God proveth you, to know whether ye love the LORD your God with all your heart and with all your soul.
5277	166	4	Ye shall walk after the LORD your God, and fear him, and keep his commandments, and obey his voice, and ye shall serve him, and cleave unto him.
5278	166	5	And that prophet, or that dreamer of dreams, shall be put to death; because he hath spoken to turn you away from the LORD your God, which brought you out of the land of Egypt, and redeemed you out of the house of bondage, to thrust thee out of the way which the LORD thy God commanded thee to walk in. So shalt thou put the evil away from the midst of thee.
5279	166	6	If thy brother, the son of thy mother, or thy son, or thy daughter, or the wife of thy bosom, or thy friend, which is as thine own soul, entice thee secretly, saying, Let us go and serve other gods, which thou hast not known, thou, nor thy fathers;
5280	166	7	Namely, of the gods of the people which are round about you, nigh unto thee, or far off from thee, from the one end of the earth even unto the other end of the earth;
5281	166	8	Thou shalt not consent unto him, nor hearken unto him; neither shall thine eye pity him, neither shalt thou spare, neither shalt thou conceal him:
5282	166	9	But thou shalt surely kill him; thine hand shall be first upon him to put him to death, and afterwards the hand of all the people.
5283	166	10	And thou shalt stone him with stones, that he die; because he hath sought to thrust thee away from the LORD thy God, which brought thee out of the land of Egypt, from the house of bondage.
5284	166	11	And all Israel shall hear, and fear, and shall do no more any such wickedness as this is among you.
5285	166	12	If thou shalt hear say in one of thy cities, which the LORD thy God hath given thee to dwell there, saying,
5286	166	13	Certain men, the children of Belial, are gone out from among you, and have withdrawn the inhabitants of their city, saying, Let us go and serve other gods, which ye have not known;
5287	166	14	Then shalt thou inquire, and make search, and ask diligently; and, behold, if it be truth, and the thing certain, that such abomination is wrought among you;
5288	166	15	Thou shalt surely smite the inhabitants of that city with the edge of the sword, destroying it utterly, and all that is therein, and the cattle thereof, with the edge of the sword.
5289	166	16	And thou shalt gather all the spoil of it into the midst of the street thereof, and shalt burn with fire the city, and all the spoil thereof every whit, for the LORD thy God: and it shall be an heap for ever; it shall not be built again.
5290	166	17	And there shall cleave nought of the cursed thing to thine hand: that the LORD may turn from the fierceness of his anger, and shew thee mercy, and have compassion upon thee, and multiply thee, as he hath sworn unto thy fathers;
5291	166	18	When thou shalt hearken to the voice of the LORD thy God, to keep all his commandments which I command thee this day, to do that which is right in the eyes of the LORD thy God.
5292	167	1	YE are the children of the LORD your God: ye shall not cut yourselves, nor make any baldness between your eyes for the dead.
5293	167	2	For thou art an holy people unto the LORD thy God, and the LORD hath chosen thee to be a peculiar people unto himself, above all the nations that are upon the earth.
5294	167	3	Thou shalt not eat any abominable thing.
5295	167	4	These are the beasts which ye shall eat: the ox, the sheep, and the goat,
5296	167	5	The hart, and the roebuck, and the fallow deer, and the wild goat, and the pygarg, and the wild ox, and the chamois.
5297	167	6	And every beast that parteth the hoof, and cleaveth the cleft into two claws, and cheweth the cud among the beasts, that ye shall eat.
5298	167	7	Nevertheless these ye shall not eat of them that chew the cud, or of them that divide the cloven hoof; as the camel, and the hare, and the coney: for they chew the cud, but divide not the hoof; therefore they are unclean unto you.
5299	167	8	And the swine, because it divideth the hoof, yet cheweth not the cud, it is unclean unto you: ye shall not eat of their flesh, nor touch their dead carcase.
5300	167	9	These ye shall eat of all that are in the waters: all that have fins and scales shall ye eat:
5301	167	10	And whatsoever hath not fins and scales ye may not eat; it is unclean unto you.
5302	167	11	Of all clean birds ye shall eat.
5303	167	12	But these are they of which ye shall not eat: the eagle, and the ossifrage, and the ospray,
5304	167	13	And the glede, and the kite, and the vulture after his kind,
5305	167	14	And every raven after his kind,
5306	167	15	And the owl, and the night hawk, and the cuckow, and the hawk after his kind,
5307	167	16	The little owl, and the great owl, and the swan,
5308	167	17	And the pelican, and the gier eagle, and the cormorant,
5309	167	18	And the stork, and the heron after her kind, and the lapwing, and the bat.
5310	167	19	And every creeping thing that flieth is unclean unto you: they shall not be eaten.
5311	167	20	But of all clean fowls ye may eat.
5312	167	21	Ye shall not eat of any thing that dieth of itself: thou shalt give it unto the stranger that is in thy gates, that he may eat it; or thou mayest sell it unto an alien: for thou art an holy people unto the LORD thy God. Thou shalt not seethe a kid in his mother's milk.
5313	167	22	Thou shalt truly tithe all the increase of thy seed, that the field bringeth forth year by year.
5314	167	23	And thou shalt eat before the LORD thy God, in the place which he shall choose to place his name there, the tithe of thy corn, of thy wine, and of thine oil, and the firstlings of thy herds and of thy flocks; that thou mayest learn to fear the LORD thy God always.
5315	167	24	And if the way be too long for thee, so that thou art not able to carry it; or if the place be too far from thee, which the LORD thy God shall choose to set his name there, when the LORD thy God hath blessed thee:
5316	167	25	Then shalt thou turn it into money, and bind up the money in thine hand, and shalt go unto the place which the LORD thy God shall choose:
5317	167	26	And thou shalt bestow that money for whatsoever thy soul lusteth after, for oxen, or for sheep, or for wine, or for strong drink, or for whatsoever thy soul desireth: and thou shalt eat there before the LORD thy God, and thou shalt rejoice, thou, and thine household,
5318	167	27	And the Levite that is within thy gates; thou shalt not forsake him; for he hath no part nor inheritance with thee.
5319	167	28	At the end of three years thou shalt bring forth all the tithe of thine increase the same year, and shalt lay it up within thy gates:
5320	167	29	And the Levite, (because he hath no part nor inheritance with thee,) and the stranger, and the fatherless, and the widow, which are within thy gates, shall come, and shall eat and be satisfied; that the LORD thy God may bless thee in all the work of thine hand which thou doest.
5321	168	1	AT the end of every seven years thou shalt make a release.
5322	168	2	And this is the manner of the release: Every creditor that lendeth ought unto his neighbour shall release it; he shall not exact it of his neighbour, or of his brother; because it is called the LORD's release.
5323	168	3	Of a foreigner thou mayest exact it again: but that which is thine with thy brother thine hand shall release;
5324	168	4	Save when there shall be no poor among you; for the LORD shall greatly bless thee in the land which the LORD thy God giveth thee for an inheritance to possess it:
5325	168	5	Only if thou carefully hearken unto the voice of the LORD thy God, to observe to do all these commandments which I command thee this day.
5326	168	6	For the LORD thy God blesseth thee, as he promised thee: and thou shalt lend unto many nations, but thou shalt not borrow; and thou shalt reign over many nations, but they shall not reign over thee.
5327	168	7	If there be among you a poor man of one of thy brethren within any of thy gates in thy land which the LORD thy God giveth thee, thou shalt not harden thine heart, nor shut thine hand from thy poor brother:
5328	168	8	But thou shalt open thine hand wide unto him, and shalt surely lend him sufficient for his need, in that which he wanteth.
5329	168	9	Beware that there be not a thought in thy wicked heart, saying, The seventh year, the year of release, is at hand; and thine eye be evil against thy poor brother, and thou givest him nought; and he cry unto the LORD against thee, and it be sin unto thee.
5330	168	10	Thou shalt surely give him, and thine heart shall not be grieved when thou givest unto him: because that for this thing the LORD thy God shall bless thee in all thy works, and in all that thou puttest thine hand unto.
5331	168	11	For the poor shall never cease out of the land: therefore I command thee, saying, Thou shalt open thine hand wide unto thy brother, to thy poor, and to thy needy, in thy land.
5332	168	12	And if thy brother, an Hebrew man, or an Hebrew woman, be sold unto thee, and serve thee six years; then in the seventh year thou shalt let him go free from thee.
5333	168	13	And when thou sendest him out free from thee, thou shalt not let him go away empty:
5334	168	14	Thou shalt furnish him liberally out of thy flock, and out of thy floor, and out of thy winepress: of that wherewith the LORD thy God hath blessed thee thou shalt give unto him.
5335	168	15	And thou shalt remember that thou wast a bondman in the land of Egypt, and the LORD thy God redeemed thee: therefore I command thee this thing to day.
5336	168	16	And it shall be, if he say unto thee, I will not go away from thee; because he loveth thee and thine house, because he is well with thee;
5337	168	17	Then thou shalt take an aul, and thrust it through his ear unto the door, and he shall be thy servant for ever. And also unto thy maidservant thou shalt do likewise.
5338	168	18	It shall not seem hard unto thee, when thou sendest him away free from thee; for he hath been worth a double hired servant to thee, in serving thee six years: and the LORD thy God shall bless thee in all that thou doest.
5339	168	19	All the firstling males that come of thy herd and of thy flock thou shalt sanctify unto the LORD thy God: thou shalt do no work with the firstling of thy bullock, nor shear the firstling of thy sheep.
5340	168	20	Thou shalt eat it before the LORD thy God year by year in the place which the LORD shall choose, thou and thy household.
5341	168	21	And if there be any blemish therein, as if it be lame, or blind, or have any ill blemish, thou shalt not sacrifice it unto the LORD thy God.
5342	168	22	Thou shalt eat it within thy gates: the unclean and the clean person shall eat it alike, as the roebuck, and as the hart.
5343	168	23	Only thou shalt not eat the blood thereof; thou shalt pour it upon the ground as water.
5344	169	1	OBSERVE the month of Abib, and keep the passover unto the LORD thy God: for in the month of Abib the LORD thy God brought thee forth out of Egypt by night.
5345	169	2	Thou shalt therefore sacrifice the passover unto the LORD thy God, of the flock and the herd, in the place which the LORD shall choose to place his name there.
5346	169	3	Thou shalt eat no leavened bread with it; seven days shalt thou eat unleavened bread therewith, even the bread of affliction; for thou camest forth out of the land of Egypt in haste: that thou mayest remember the day when thou camest forth out of the land of Egypt all the days of thy life.
5347	169	4	And there shall be no leavened bread seen with thee in all thy coast seven days; neither shall there any thing of the flesh, which thou sacrificedst the first day at even, remain all night until the morning.
5348	169	5	Thou mayest not sacrifice the passover within any of thy gates, which the LORD thy God giveth thee:
5349	169	6	But at the place which the LORD thy God shall choose to place his name in, there thou shalt sacrifice the passover at even, at the going down of the sun, at the season that thou camest forth out of Egypt.
5350	169	7	And thou shalt roast and eat it in the place which the LORD thy God shall choose: and thou shalt turn in the morning, and go unto thy tents.
5351	169	8	Six days thou shalt eat unleavened bread: and on the seventh day shall be a solemn assembly to the LORD thy God: thou shalt do no work therein.
5352	169	9	Seven weeks shalt thou number unto thee: begin to number the seven weeks from such time as thou beginnest to put the sickle to the corn.
5353	169	10	And thou shalt keep the feast of weeks unto the LORD thy God with a tribute of a freewill offering of thine hand, which thou shalt give unto the LORD thy God, according as the LORD thy God hath blessed thee:
5354	169	11	And thou shalt rejoice before the LORD thy God, thou, and thy son, and thy daughter, and thy manservant, and thy maidservant, and the Levite that is within thy gates, and the stranger, and the fatherless, and the widow, that are among you, in the place which the LORD thy God hath chosen to place his name there.
5355	169	12	And thou shalt remember that thou wast a bondman in Egypt: and thou shalt observe and do these statutes.
5356	169	13	Thou shalt observe the feast of tabernacles seven days, after that thou hast gathered in thy corn and thy wine:
5357	169	14	And thou shalt rejoice in thy feast, thou, and thy son, and thy daughter, and thy manservant, and thy maidservant, and the Levite, the stranger, and the fatherless, and the widow, that are within thy gates.
5358	169	15	Seven days shalt thou keep a solemn feast unto the LORD thy God in the place which the LORD shall choose: because the LORD thy God shall bless thee in all thine increase, and in all the works of thine hands, therefore thou shalt surely rejoice.
5359	169	16	Three times in a year shall all thy males appear before the LORD thy God in the place which he shall choose; in the feast of unleavened bread, and in the feast of weeks, and in the feast of tabernacles: and they shall not appear before the LORD empty:
5360	169	17	Every man shall give as he is able, according to the blessing of the LORD thy God which he hath given thee.
5361	169	18	Judges and officers shalt thou make thee in all thy gates, which the LORD thy God giveth thee, throughout thy tribes: and they shall judge the people with just judgment.
5362	169	19	Thou shalt not wrest judgment; thou shalt not respect persons, neither take a gift: for a gift doth blind the eyes of the wise, and pervert the words of the righteous.
5363	169	20	That which is altogether just shalt thou follow, that thou mayest live, and inherit the land which the LORD thy God giveth thee.
5364	169	21	Thou shalt not plant thee a grove of any trees near unto the altar of the LORD thy God, which thou shalt make thee.
5365	169	22	Neither shalt thou set thee up any image; which the LORD thy God hateth.
5366	170	1	THOU shalt not sacrifice unto the LORD thy God any bullock, or sheep, wherein is blemish, or any evilfavouredness: for that is an abomination unto the LORD thy God.
5367	170	2	If there be found among you, within any of thy gates which the LORD thy God giveth thee, man or woman, that hath wrought wickedness in the sight of the LORD thy God, in transgressing his covenant,
5368	170	3	And hath gone and served other gods, and worshipped them, either the sun, or moon, or any of the host of heaven, which I have not commanded;
5369	170	4	And it be told thee, and thou hast heard of it, and inquired diligently, and, behold, it be true, and the thing certain, that such abomination is wrought in Israel:
5370	170	5	Then shalt thou bring forth that man or that woman, which have committed that wicked thing, unto thy gates, even that man or that woman, and shalt stone them with stones, till they die.
5371	170	6	At the mouth of two witnesses, or three witnesses, shall he that is worthy of death be put to death; but at the mouth of one witness he shall not be put to death.
5372	170	7	The hands of the witnesses shall be first upon him to put him to death, and afterward the hands of all the people. So thou shalt put the evil away from among you.
5373	170	8	If there arise a matter too hard for thee in judgment, between blood and blood, between plea and plea, and between stroke and stroke, being matters of controversy within thy gates: then shalt thou arise, and get thee up into the place which the LORD thy God shall choose;
5374	170	9	And thou shalt come unto the priests the Levites, and unto the judge that shall be in those days, and inquire; and they shall shew thee the sentence of judgment:
5375	170	10	And thou shalt do according to the sentence, which they of that place which the LORD shall choose shall shew thee; and thou shalt observe to do according to all that they inform thee;
5376	170	11	According to the sentence of the law which they shall teach thee, and according to the judgment which they shall tell thee, thou shalt do: thou shalt not decline from the sentence which they shall shew thee, to the right hand, nor to the left.
5377	170	12	And the man that will do presumptuously, and will not hearken unto the priest that standeth to minister there before the LORD thy God, or unto the judge, even that man shall die: and thou shalt put away the evil from Israel.
5378	170	13	And all the people shall hear, and fear, and do no more presumptuously.
5379	170	14	When thou art come unto the land which the LORD thy God giveth thee, and shalt possess it, and shalt dwell therein, and shalt say, I will set a king over me, like as all the nations that are about me;
5380	170	15	Thou shalt in any wise set him king over thee, whom the LORD thy God shall choose: one from among thy brethren shalt thou set king over thee: thou mayest not set a stranger over thee, which is not thy brother.
5381	170	16	But he shall not multiply horses to himself, nor cause the people to return to Egypt, to the end that he should multiply horses: forasmuch as the LORD hath said unto you, Ye shall henceforth return no more that way.
5382	170	17	Neither shall he multiply wives to himself, that his heart turn not away: neither shall he greatly multiply to himself silver and gold.
5383	170	18	And it shall be, when he sitteth upon the throne of his kingdom, that he shall write him a copy of this law in a book out of that which is before the priests the Levites:
5384	170	19	And it shall be with him, and he shall read therein all the days of his life: that he may learn to fear the LORD his God, to keep all the words of this law and these statutes, to do them:
5385	170	20	That his heart be not lifted up above his brethren, and that he turn not aside from the commandment, to the right hand, or to the left: to the end that he may prolong his days in his kingdom, he, and his children, in the midst of Israel.
5386	171	1	THE priests the Levites, and all the tribe of Levi, shall have no part nor inheritance with Israel: they shall eat the offerings of the LORD made by fire, and his inheritance.
5387	171	2	Therefore shall they have no inheritance among their brethren: the LORD is their inheritance, as he hath said unto them.
5388	171	3	And this shall be the priest's due from the people, from them that offer a sacrifice, whether it be ox or sheep; and they shall give unto the priest the shoulder, and the two cheeks, and the maw.
5389	171	4	The firstfruit also of thy corn, of thy wine, and of thine oil, and the first of the fleece of thy sheep, shalt thou give him.
5390	171	5	For the LORD thy God hath chosen him out of all thy tribes, to stand to minister in the name of the LORD, him and his sons for ever.
5391	171	6	And if a Levite come from any of thy gates out of all Israel, where he sojourned, and come with all the desire of his mind unto the place which the LORD shall choose;
5392	171	7	Then he shall minister in the name of the LORD his God, as all his brethren the Levites do, which stand there before the LORD.
5393	171	8	They shall have like portions to eat, beside that which cometh of the sale of his patrimony.
5394	171	9	When thou art come into the land which the LORD thy God giveth thee, thou shalt not learn to do after the abominations of those nations.
5395	171	10	There shall not be found among you any one that maketh his son or his daughter to pass through the fire, or that useth divination, or an observer of times, or an enchanter, or a witch,
5396	171	11	Or a charmer, or a consulter with familiar spirits, or a wizard, or a necromancer.
5397	171	12	For all that do these things are an abomination unto the LORD: and because of these abominations the LORD thy God doth drive them out from before thee.
5398	171	13	Thou shalt be perfect with the LORD thy God.
5399	171	14	For these nations, which thou shalt possess, hearkened unto observers of times, and unto diviners: but as for thee, the LORD thy God hath not suffered thee so to do.
5400	171	15	The LORD thy God will raise up unto thee a Prophet from the midst of thee, of thy brethren, like unto me; unto him ye shall hearken;
5401	171	16	According to all that thou desiredst of the LORD thy God in Horeb in the day of the assembly, saying, Let me not hear again the voice of the LORD my God, neither let me see this great fire any more, that I die not.
5402	171	17	And the LORD said unto me, They have well spoken that which they have spoken.
5403	171	18	I will raise them up a Prophet from among their brethren, like unto thee, and will put my words in his mouth; and he shall speak unto them all that I shall command him.
5404	171	19	And it shall come to pass, that whosoever will not hearken unto my words which he shall speak in my name, I will require it of him.
5405	171	20	But the prophet, which shall presume to speak a word in my name, which I have not commanded him to speak, or that shall speak in the name of other gods, even that prophet shall die.
5406	171	21	And if thou say in thine heart, How shall we know the word which the LORD hath not spoken?
5407	171	22	When a prophet speaketh in the name of the LORD, if the thing follow not, nor come to pass, that is the thing which the LORD hath not spoken, but the prophet hath spoken it presumptuously: thou shalt not be afraid of him.
5408	172	1	WHEN the LORD thy God hath cut off the nations, whose land the LORD thy God giveth thee, and thou succeedest them, and dwellest in their cities, and in their houses;
5409	172	2	Thou shalt separate three cities for thee in the midst of thy land, which the LORD thy God giveth thee to possess it.
5410	172	3	Thou shalt prepare thee a way, and divide the coasts of thy land, which the LORD thy God giveth thee to inherit, into three parts, that every slayer may flee thither.
5411	172	4	And this is the case of the slayer, which shall flee thither, that he may live: Whoso killeth his neighbour ignorantly, whom he hated not in time past;
5412	172	5	As when a man goeth into the wood with his neighbour to hew wood, and his hand fetcheth a stroke with the axe to cut down the tree, and the head slippeth from the helve, and lighteth upon his neighbour, that he die; he shall flee unto one of those cities, and live:
5413	172	6	Lest the avenger of the blood pursue the slayer, while his heart is hot, and overtake him, because the way is long, and slay him; whereas he was not worthy of death, inasmuch as he hated him not in time past.
5414	172	7	Wherefore I command thee, saying, Thou shalt separate three cities for thee.
5415	172	8	And if the LORD thy God enlarge thy coast, as he hath sworn unto thy fathers, and give thee all the land which he promised to give unto thy fathers;
5416	172	9	If thou shalt keep all these commandments to do them, which I command thee this day, to love the LORD thy God, and to walk ever in his ways; then shalt thou add three cities more for thee, beside these three:
5417	172	10	That innocent blood be not shed in thy land, which the LORD thy God giveth thee for an inheritance, and so blood be upon thee.
5418	172	11	But if any man hate his neighbour, and lie in wait for him, and rise up against him, and smite him mortally that he die, and fleeth into one of these cities:
5419	172	12	Then the elders of his city shall send and fetch him thence, and deliver him into the hand of the avenger of blood, that he may die.
5420	172	13	Thine eye shall not pity him, but thou shalt put away the guilt of innocent blood from Israel, that it may go well with thee.
5421	172	14	Thou shalt not remove thy neighbour's landmark, which they of old time have set in thine inheritance, which thou shalt inherit in the land that the LORD thy God giveth thee to possess it.
5422	172	15	One witness shall not rise up against a man for any iniquity, or for any sin, in any sin that he sinneth: at the mouth of two witnesses, or at the mouth of three witnesses, shall the matter be established.
5423	172	16	If a false witness rise up against any man to testify against him that which is wrong;
5424	172	17	Then both the men, between whom the controversy is, shall stand before the LORD, before the priests and the judges, which shall be in those days;
5425	172	18	And the judges shall make diligent inquisition: and, behold, if the witness be a false witness, and hath testified falsely against his brother;
5426	172	19	Then shall ye do unto him, as he had thought to have done unto his brother: so shalt thou put the evil away from among you.
5427	172	20	And those which remain shall hear, and fear, and shall henceforth commit no more any such evil among you.
5428	172	21	And thine eye shall not pity; but life shall go for life, eye for eye, tooth for tooth, hand for hand, foot for foot.
5429	173	1	WHEN thou goest out to battle against thine enemies, and seest horses, and chariots, and a people more than thou, be not afraid of them: for the LORD thy God is with thee, which brought thee up out of the land of Egypt.
5430	173	2	And it shall be, when ye are come nigh unto the battle, that the priest shall approach and speak unto the people.
5431	173	3	And shall say unto them, Hear, O Israel, ye approach this day unto battle against your enemies: let not your hearts faint, fear not, and do not tremble, neither be ye terrified because of them;
5432	173	4	For the LORD your God is he that goeth with you, to fight for you against your enemies, to save you.
5433	173	5	And the officers shall speak unto the people, saying, What man is there that hath built a new house, and hath not dedicated it? let him go and return to his house, lest he die in the battle, and another man dedicate it.
5434	173	6	And what man is he that hath planted a vineyard, and hath not yet eaten of it? let him also go and return unto his house, lest he die in the battle, and another man eat of it.
5435	173	7	And what man is there that hath betrothed a wife, and hath not taken her? let him go and return unto his house, lest he die in the battle, and another man take her.
5436	173	8	And the officers shall speak further unto the people, and they shall say, What man is there that is fearful and fainthearted? let him go and return unto his house, lest his brethren's heart faint as well as his heart.
5437	173	9	And it shall be, when the officers have made an end of speaking unto the people, that they shall make captains of the armies to lead the people.
5438	173	10	When thou comest nigh unto a city to fight against it, then proclaim peace unto it.
5439	173	11	And it shall be, if it make thee answer of peace, and open unto thee, then it shall be, that all the people that is found therein shall be tributaries unto thee, and they shall serve thee.
5440	173	12	And if it will make no peace with thee, but will make war against thee, then thou shalt besiege it:
5441	173	13	And when the LORD thy God hath delivered it into thine hands, thou shalt smite every male thereof with the edge of the sword:
5442	173	14	But the women, and the little ones, and the cattle, and all that is in the city, even all the spoil thereof, shalt thou take unto thyself; and thou shalt eat the spoil of thine enemies, which the LORD thy God hath given thee.
5443	173	15	Thus shalt thou do unto all the cities which are very far off from thee, which are not of the cities of these nations.
5444	173	16	But of the cities of these people, which the LORD thy God doth give thee for an inheritance, thou shalt save alive nothing that breatheth:
5445	173	17	But thou shalt utterly destroy them; namely, the Hittites, and the Amorites, the Canaanites, and the Perizzites, the Hivites, and the Jebusites; as the LORD thy God hath commanded thee:
5446	173	18	That they teach you not to do after all their abominations, which they have done unto their gods; so should ye sin against the LORD your God.
5447	173	19	When thou shalt besiege a city a long time, in making war against it to take it, thou shalt not destroy the trees thereof by forcing an axe against them: for thou mayest eat of them, and thou shalt not cut them down (for the tree of the field is man's life) to employ them in the siege:
5448	173	20	Only the trees which thou knowest that they be not trees for meat, thou shalt destroy and cut them down; and thou shalt build bulwarks against the city that maketh war with thee, until it be subdued.
5449	174	1	IF one be found slain in the land which the LORD thy God giveth thee to possess it, lying in the field, and it be not known who hath slain him:
5450	174	2	Then thy elders and thy judges shall come forth, and they shall measure unto the cities which are round about him that is slain:
5451	174	3	And it shall be, that the city which is next unto the slain man, even the elders of that city shall take an heifer, which hath not been wrought with, and which hath not drawn in the yoke;
5452	174	4	And the elders of that city shall bring down the heifer unto a rough valley, which is neither eared nor sown, and shall strike off the heifer's neck there in the valley:
5453	174	5	And the priests the sons of Levi shall come near; for them the LORD thy God hath chosen to minister unto him, and to bless in the name of the LORD; and by their word shall every controversy and every stroke be tried:
5454	174	6	And all the elders of that city, that are next unto the slain man, shall wash their hands over the heifer that is beheaded in the valley:
5455	174	7	And they shall answer and say, Our hands have not shed this blood, neither have our eyes seen it.
5456	174	8	Be merciful, O LORD, unto thy people Israel, whom thou hast redeemed, and lay not innocent blood unto thy people of Israel's charge. And the blood shall be forgiven them.
5457	174	9	So shalt thou put away the guilt of innocent blood from among you, when thou shalt do that which is right in the sight of the LORD.
5458	174	10	When thou goest forth to war against thine enemies, and the LORD thy God hath delivered them into thine hands, and thou hast taken them captive,
5459	174	11	And seest among the captives a beautiful woman, and hast a desire unto her, that thou wouldest have her to thy wife;
5460	174	12	Then thou shalt bring her home to thine house; and she shall shave her head, and pare her nails;
5461	174	13	And she shall put the raiment of her captivity from off her, and shall remain in thine house, and bewail her father and her mother a full month: and after that thou shalt go in unto her, and be her husband, and she shall be thy wife.
5462	174	14	And it shall be, if thou have no delight in her, then thou shalt let her go whither she will; but thou shalt not sell her at all for money, thou shalt not make merchandise of her, because thou hast humbled her.
5463	174	15	If a man have two wives, one beloved, and another hated, and they have born him children, both the beloved and the hated; and if the firstborn son be hers that was hated:
5464	174	16	Then it shall be, when he maketh his sons to inherit that which he hath, that he may not make the son of the beloved firstborn before the son of the hated, which is indeed the firstborn:
5465	174	17	But he shall acknowledge the son of the hated for the firstborn, by giving him a double portion of all that he hath: for he is the beginning of his strength; the right of the firstborn is his.
5466	174	18	If a man have a stubborn and rebellious son, which will not obey the voice of his father, or the voice of his mother, and that, when they have chastened him, will not hearken unto them:
5467	174	19	Then shall his father and his mother lay hold on him, and bring him out unto the elders of his city, and unto the gate of his place;
5468	174	20	And they shall say unto the elders of his city, This our son is stubborn and rebellious, he will not obey our voice; he is a glutton, and a drunkard.
5469	174	21	And all the men of his city shall stone him with stones, that he die: so shalt thou put evil away from among you; and all Israel shall hear, and fear.
5470	174	22	And if a man have committed a sin worthy of death, and he be to be put to death, and thou hang him on a tree:
5471	174	23	His body shall not remain all night upon the tree, but thou shalt in any wise bury him that day; (for he that is hanged is accursed of God;) that thy land be not defiled, which the LORD thy God giveth thee for an inheritance.
5472	175	1	THOU shalt not see thy brother's ox or his sheep go astray, and hide thyself from them: thou shalt in any case bring them again unto thy brother.
5473	175	2	And if thy brother be not nigh unto thee, or if thou know him not, then thou shalt bring it unto thine own house, and it shall be with thee until thy brother seek after it, and thou shalt restore it to him again.
5474	175	3	In like manner shalt thou do with his ass; and so shalt thou do with his raiment; and with all lost thing of thy brother's, which he hath lost, and thou hast found, shalt thou do likewise: thou mayest not hide thyself.
5475	175	4	Thou shalt not see thy brother's ass or his ox fall down by the way, and hide thyself from them: thou shalt surely help him to lift them up again.
5476	175	5	The woman shall not wear that which pertaineth unto a man, neither shall a man put on a woman's garment: for all that do so are abomination unto the LORD thy God.
5477	175	6	If a bird's nest chance to be before thee in the way in any tree, or on the ground, whether they be young ones, or eggs, and the dam sitting upon the young, or upon the eggs, thou shalt not take the dam with the young:
5478	175	7	But thou shalt in any wise let the dam go, and take the young to thee; that it may be well with thee, and that thou mayest prolong thy days.
5479	175	8	When thou buildest a new house, then thou shalt make a battlement for thy roof, that thou bring not blood upon thine house, if any man fall from thence.
5480	175	9	Thou shalt not sow thy vineyard with divers seeds: lest the fruit of thy seed which thou hast sown, and the fruit of thy vineyard, be defiled.
5481	175	10	Thou shalt not plow with an ox and an ass together.
5482	175	11	Thou shalt not wear a garment of divers sorts, as of woollen and linen together.
5483	175	12	Thou shalt make thee fringes upon the four quarters of thy vesture, wherewith thou coverest thyself.
5484	175	13	If any man take a wife, and go in unto her, and hate her,
5485	175	14	And give occasions of speech against her, and bring up an evil name upon her, and say, I took this woman, and when I came to her, I found her not a maid:
5486	175	15	Then shall the father of the damsel, and her mother, take and bring forth the tokens of the damsel's virginity unto the elders of the city in the gate:
5487	175	16	And the damsel's father shall say unto the elders, I gave my daughter unto this man to wife, and he hateth her;
5488	175	17	And, lo, he hath given occasions of speech against her, saying, I found not thy daughter a maid; and yet these are the tokens of my daughter's virginity. And they shall spread the cloth before the elders of the city.
5489	175	18	And the elders of that city shall take that man and chastise him;
5490	175	19	And they shall amerce him in an hundred shekels of silver, and give them unto the father of the damsel, because he hath brought up an evil name upon a virgin of Israel: and she shall be his wife; he may not put her away all his days.
5491	175	20	But if this thing be true, and the tokens of virginity be not found for the damsel:
5492	175	21	Then they shall bring out the damsel to the door of her father's house, and the men of her city shall stone her with stones that she die: because she hath wrought folly in Israel, to play the whore in her father's house: so shalt thou put evil away from among you.
5493	175	22	If a man be found lying with a woman married to an husband, then they shall both of them die, both the man that lay with the woman, and the woman: so shalt thou put away evil from Israel.
5494	175	23	If a damsel that is a virgin be betrothed unto an husband, and a man find her in the city, and lie with her;
5495	175	24	Then ye shall bring them both out unto the gate of that city, and ye shall stone them with stones that they die; the damsel, because she cried not, being in the city; and the man, because he hath humbled his neighbour's wife: so thou shalt put away evil from among you.
5496	175	25	But if a man find a betrothed damsel in the field, and the man force her, and lie with her: then the man only that lay with her shall die:
5497	175	26	But unto the damsel thou shalt do nothing; there is in the damsel no sin worthy of death: for as when a man riseth against his neighbour, and slayeth him, even so is this matter:
5498	175	27	For he found her in the field, and the betrothed damsel cried, and there was none to save her.
5499	175	28	If a man find a damsel that is a virgin, which is not betrothed, and lay hold on her, and lie with her, and they be found;
5500	175	29	Then the man that lay with her shall give unto the damsel's father fifty shekels of silver, and she shall be his wife; because he hath humbled her, he may not put her away all his days.
5501	175	30	A man shall not take his father's wife, nor discover his father's skirt.
5502	176	1	HE that is wounded in the stones, or hath his privy member cut off, shall not enter into the congregation of the LORD.
5503	176	2	A bastard shall not enter into the congregation of the LORD; even to his tenth generation shall he not enter into the congregation of the LORD.
5504	176	3	An Ammonite or Moabite shall not enter into the congregation of the LORD; even to their tenth generation shall they not enter into the congregation of the LORD for ever:
5505	176	4	Because they met you not with bread and with water in the way, when ye came forth out of Egypt; and because they hired against thee Balaam the son of Beor of Pethor of Mesopotamia, to curse thee.
5506	176	5	Nevertheless the LORD thy God would not hearken unto Balaam; but the LORD thy God turned the curse into a blessing unto thee, because the LORD thy God loved thee.
5507	176	6	Thou shalt not seek their peace nor their prosperity all thy days for ever.
5508	176	7	Thou shalt not abhor an Edomite; for he is thy brother: thou shalt not abhor an Egyptian; because thou wast a stranger in his land.
5509	176	8	The children that are begotten of them shall enter into the congregation of the LORD in their third generation.
5510	176	9	When the host goeth forth against thine enemies, then keep thee from every wicked thing.
5511	176	10	If there be among you any man, that is not clean by reason of uncleanness that chanceth him by night, then shall he go abroad out of the camp, he shall not come within the camp:
5512	176	11	But it shall be, when evening cometh on, he shall wash himself with water: and when the sun is down, he shall come into the camp again.
5513	176	12	Thou shalt have a place also without the camp, whither thou shalt go forth abroad:
5514	176	13	And thou shalt have a paddle upon thy weapon; and it shall be, when thou wilt ease thyself abroad, thou shalt dig therewith, and shalt turn back and cover that which cometh from thee:
5515	176	14	For the LORD thy God walketh in the midst of thy camp, to deliver thee, and to give up thine enemies before thee; therefore shall thy camp be holy: that he see no unclean thing in thee, and turn away from thee.
5516	176	15	Thou shalt not deliver unto his master the servant which is escaped from his master unto thee:
5517	176	16	He shall dwell with thee, even among you, in that place which he shall choose in one of thy gates, where it liketh him best: thou shalt not oppress him.
5518	176	17	There shall be no whore of the daughters of Israel, nor a sodomite of the sons of Israel.
5519	176	18	Thou shalt not bring the hire of a whore, or the price of a dog, into the house of the LORD thy God for any vow: for even both these are abomination unto the LORD thy God.
5520	176	19	Thou shalt not lend upon usury to thy brother; usury of money, usury of victuals, usury of any thing that is lent upon usury:
5521	176	20	Unto a stranger thou mayest lend upon usury; but unto thy brother thou shalt not lend upon usury: that the LORD thy God may bless thee in all that thou settest thine hand to in the land whither thou goest to possess it.
5522	176	21	When thou shalt vow a vow unto the LORD thy God, thou shalt not slack to pay it: for the LORD thy God will surely require it of thee; and it would be sin in thee.
5523	176	22	But if thou shalt forbear to vow, it shall be no sin in thee.
5524	176	23	That which is gone out of thy lips thou shalt keep and perform; even a freewill offering, according as thou hast vowed unto the LORD thy God, which thou hast promised with thy mouth.
5525	176	24	When thou comest into thy neighbour's vineyard, then thou mayest eat grapes thy fill at thine own pleasure; but thou shalt not put any in thy vessel.
5526	176	25	When thou comest into the standing corn of thy neighbour, then thou mayest pluck the ears with thine hand; but thou shalt not move a sickle unto thy neighbour's standing corn.
5527	177	1	WHEN a man hath taken a wife, and married her, and it come to pass that she find no favour in his eyes, because he hath found some uncleanness in her: then let him write her a bill of divorcement, and give it in her hand, and send her out of his house.
5528	177	2	And when she is departed out of his house, she may go and be another man's wife.
5529	177	3	And if the latter husband hate her, and write her a bill of divorcement, and giveth it in her hand, and sendeth her out of his house; or if the latter husband die, which took her to be his wife;
5530	177	4	Her former husband, which sent her away, may not take her again to be his wife, after that she is defiled; for that is abomination before the LORD: and thou shalt not cause the land to sin, which the LORD thy God giveth thee for an inheritance.
5531	177	5	When a man hath taken a new wife, he shall not go out to war, neither shall he be charged with any business: but he shall be free at home one year, and shall cheer up his wife which he hath taken.
5532	177	6	No man shall take the nether or the upper millstone to pledge: for he taketh a man's life to pledge.
5533	177	7	If a man be found stealing any of his brethren of the children of Israel, and maketh merchandise of him, or selleth him; then that thief shall die; and thou shalt put evil away from among you.
5534	177	8	Take heed in the plague of leprosy, that thou observe diligently, and do according to all that the priests the Levites shall teach you: as I commanded them, so ye shall observe to do.
5535	177	9	Remember what the LORD thy God did unto Miriam by the way, after that ye were come forth out of Egypt.
5536	177	10	When thou dost lend thy brother any thing, thou shalt not go into his house to fetch his pledge.
5537	177	11	Thou shalt stand abroad, and the man to whom thou dost lend shall bring out the pledge abroad unto thee.
5538	177	12	And if the man be poor, thou shalt not sleep with his pledge:
5539	177	13	In any case thou shalt deliver him the pledge again when the sun goeth down, that he may sleep in his own raiment, and bless thee: and it shall be righteousness unto thee before the LORD thy God.
5540	177	14	Thou shalt not oppress an hired servant that is poor and needy, whether he be of thy brethren, or of thy strangers that are in thy land within thy gates:
5541	177	15	At his day thou shalt give him his hire, neither shall the sun go down upon it; for he is poor, and setteth his heart upon it: lest he cry against thee unto the LORD, and it be sin unto thee.
5542	177	16	The fathers shall not be put to death for the children, neither shall the children be put to death for the fathers: every man shall be put to death for his own sin.
5543	177	17	Thou shalt not pervert the judgment of the stranger, nor of the fatherless; nor take a widow's raiment to pledge:
5544	177	18	But thou shalt remember that thou wast a bondman in Egypt, and the LORD thy God redeemed thee thence: therefore I command thee to do this thing.
5545	177	19	When thou cuttest down thine harvest in thy field, and hast forgot a sheaf in the field, thou shalt not go again to fetch it: it shall be for the stranger, for the fatherless, and for the widow: that the LORD thy God may bless thee in all the work of thine hands.
5546	177	20	When thou beatest thine olive tree, thou shalt not go over the boughs again: it shall be for the stranger, for the fatherless, and for the widow.
5547	177	21	When thou gatherest the grapes of thy vineyard, thou shalt not glean it afterward: it shall be for the stranger, for the fatherless, and for the widow.
5548	177	22	And thou shalt remember that thou wast a bondman in the land of Egypt: therefore I command thee to do this thing.
5549	178	1	IF there be a controversy between men, and they come unto judgment, that the judges may judge them; then they shall justify the righteous, and condemn the wicked.
5550	178	2	And it shall be, if the wicked man be worthy to be beaten, that the judge shall cause him to lie down, and to be beaten before his face, according to his fault, by a certain number.
5551	178	3	Forty stripes he may give him, and not exceed: lest, if he should exceed, and beat him above these with many stripes, then thy brother should seem vile unto thee.
5552	178	4	Thou shalt not muzzle the ox when he treadeth out the corn.
5553	178	5	If brethren dwell together, and one of them die, and have no child, the wife of the dead shall not marry without unto a stranger: her husband's brother shall go in unto her, and take her to him to wife, and perform the duty of an husband's brother unto her.
5554	178	6	And it shall be, that the firstborn which she beareth shall succeed in the name of his brother which is dead, that his name be not put out of Israel.
5555	178	7	And if the man like not to take his brother's wife, then let his brother's wife go up to the gate unto the elders, and say, My husband's brother refuseth to raise up unto his brother a name in Israel, he will not perform the duty of my husband's brother.
5556	178	8	Then the elders of his city shall call him, and speak unto him: and if he stand to it, and say, I like not to take her;
5557	178	9	Then shall his brother's wife come unto him in the presence of the elders, and loose his shoe from off his foot, and spit in his face, and shall answer and say, So shall it be done unto that man that will not build up his brother's house.
5558	178	10	And his name shall be called in Israel, The house of him that hath his shoe loosed.
5559	178	11	When men strive together one with another, and the wife of the one draweth near for to deliver her husband out of the hand of him that smiteth him, and putteth forth her hand, and taketh him by the secrets:
5560	178	12	Then thou shalt cut off her hand, thine eye shall not pity her.
5561	178	13	Thou shalt not have in thy bag divers weights, a great and a small.
5562	178	14	Thou shalt not have in thine house divers measures, a great and a small.
5563	178	15	But thou shalt have a perfect and just weight, a perfect and just measure shalt thou have: that thy days may be lengthened in the land which the LORD thy God giveth thee.
5564	178	16	For all that do such things, and all that do unrighteously, are an abomination unto the LORD thy God.
5565	178	17	Remember what Amalek did unto thee by the way, when ye were come forth out of Egypt;
5566	178	18	How he met thee by the way, and smote the hindmost of thee, even all that were feeble behind thee, when thou wast faint and weary; and he feared not God.
5567	178	19	Therefore it shall be, when the LORD thy God hath given thee rest from all thine enemies round about, in the land which the LORD thy God giveth thee for an inheritance to possess it, that thou shalt blot out the remembrance of Amalek from under heaven; thou shalt not forget it.
5568	179	1	AND it shall be, when thou art come in unto the land which the LORD thy God giveth thee for an inheritance, and possessest it, and dwellest therein;
5569	179	2	That thou shalt take of the first of all the fruit of the earth, which thou shalt bring of thy land that the LORD thy God giveth thee, and shalt put it in a basket, and shalt go unto the place which the LORD thy God shall choose to place his name there.
5570	179	3	And thou shalt go unto the priest that shall be in those days, and say unto him, I profess this day unto the LORD thy God, that I am come unto the country which the LORD sware unto our fathers for to give us.
5571	179	4	And the priest shall take the basket out of thine hand, and set it down before the altar of the LORD thy God.
5572	179	5	And thou shalt speak and say before the LORD thy God, A Syrian ready to perish was my father, and he went down into Egypt, and sojourned there with a few, and became there a nation, great, mighty, and populous:
5573	179	6	And the Egyptians evil entreated us, and afflicted us, and laid upon us hard bondage:
5574	179	7	And when we cried unto the LORD God of our fathers, the LORD heard our voice, and looked on our affliction, and our labour, and our oppression:
5575	179	8	And the LORD brought us forth out of Egypt with a mighty hand, and with an outstretched arm, and with great terribleness, and with signs, and with wonders:
5576	179	9	And he hath brought us into this place, and hath given us this land, even a land that floweth with milk and honey.
5577	179	10	And now, behold, I have brought the firstfruits of the land, which thou, O LORD, hast given me. And thou shalt set it before the LORD thy God, and worship before the LORD thy God:
5578	179	11	And thou shalt rejoice in every good thing which the LORD thy God hath given unto thee, and unto thine house, thou, and the Levite, and the stranger that is among you.
5579	179	12	When thou hast made an end of tithing all the tithes of thine increase the third year, which is the year of tithing, and hast given it unto the Levite, the stranger, the fatherless, and the widow, that they may eat within thy gates, and be filled;
5580	179	13	Then thou shalt say before the LORD thy God, I have brought away the hallowed things out of mine house, and also have given them unto the Levite, and unto the stranger, to the fatherless, and to the widow, according to all thy commandments which thou hast commanded me: I have not transgressed thy commandments, neither have I forgotten them:
5581	179	14	I have not eaten thereof in my mourning, neither have I taken away ought thereof for any unclean use, nor given ought thereof for the dead: but I have hearkened to the voice of the LORD my God, and have done according to all that thou hast commanded me.
5582	179	15	Look down from thy holy habitation, from heaven, and bless thy people Israel, and the land which thou hast given us, as thou swarest unto our fathers, a land that floweth with milk and honey.
5583	179	16	This day the LORD thy God hath commanded thee to do these statutes and judgments: thou shalt therefore keep and do them with all thine heart, and with all thy soul.
5584	179	17	Thou hast avouched the LORD this day to be thy God, and to walk in his ways, and to keep his statutes, and his commandments, and his judgments, and to hearken unto his voice:
5585	179	18	And the LORD hath avouched thee this day to be his peculiar people, as he hath promised thee, and that thou shouldest keep all his commandments;
5586	179	19	And to make thee high above all nations which he hath made, in praise, and in name, and in honour; and that thou mayest be an holy people unto the LORD thy God, as he hath spoken.
5587	180	1	AND Moses with the elders of Israel commanded the people, saying, Keep all the commandments which I command you this day.
5588	180	2	And it shall be on the day when ye shall pass over Jordan unto the land which the LORD thy God giveth thee, that thou shalt set thee up great stones, and plaister them with plaister:
5589	180	3	And thou shalt write upon them all the words of this law, when thou art passed over, that thou mayest go in unto the land which the LORD thy God giveth thee, a land that floweth with milk and honey; as the LORD God of thy fathers hath promised thee.
5590	180	4	Therefore it shall be when ye be gone over Jordan, that ye shall set up these stones, which I command you this day, in mount Ebal, and thou shalt plaister them with plaister.
5591	180	5	And there shalt thou build an altar unto the LORD thy God, an altar of stones: thou shalt not lift up any iron tool upon them.
5592	180	6	Thou shalt build the altar of the LORD thy God of whole stones: and thou shalt offer burnt offerings thereon unto the LORD thy God:
5593	180	7	And thou shalt offer peace offerings, and shalt eat there, and rejoice before the LORD thy God.
5594	180	8	And thou shalt write upon the stones all the words of this law very plainly.
5595	180	9	And Moses and the priests the Levites spake unto all Israel, saying, Take heed, and hearken, O Israel; this day thou art become the people of the LORD thy God.
5596	180	10	Thou shalt therefore obey the voice of the LORD thy God, and do his commandments and his statutes, which I command thee this day.
5597	180	11	And Moses charged the people the same day, saying,
5598	180	12	These shall stand upon mount Gerizim to bless the people, when ye are come over Jordan; Simeon, and Levi, and Judah, and Issachar, and Joseph, and Benjamin:
5599	180	13	And these shall stand upon mount Ebal to curse; Reuben, Gad, and Asher, and Zebulun, Dan, and Naphtali.
5600	180	14	And the Levites shall speak, and say unto all the men of Israel with a loud voice,
5601	180	15	Cursed be the man that maketh any graven or molten image, an abomination unto the LORD, the work of the hands of the craftsman, and putteth it in a secret place. And all the people shall answer and say, Amen.
5602	180	16	Cursed be he that setteth light by his father or his mother. And all the people shall say, Amen.
5603	180	17	Cursed be he that removeth his neighbour's landmark. And all the people shall say, Amen.
5604	180	18	Cursed be he that maketh the blind to wander out of the way. And all the people shall say, Amen.
5605	180	19	Cursed be he that perverteth the judgment of the stranger, fatherless, and widow. And all the people shall say, Amen.
5606	180	20	Cursed be he that lieth with his father's wife; because he uncovereth his father's skirt. And all the people shall say, Amen.
5607	180	21	Cursed be he that lieth with any manner of beast. And all the people shall say, Amen.
5608	180	22	Cursed be he that lieth with his sister, the daughter of his father, or the daughter of his mother. And all the people shall say, Amen.
5609	180	23	Cursed be he that lieth with his mother in law. And all the people shall say, Amen.
5610	180	24	Cursed be he that smiteth his neighbour secretly. And all the people shall say, Amen.
5611	180	25	Cursed be he that taketh reward to slay an innocent person. And all the people shall say, Amen.
5612	180	26	Cursed be he that confirmeth not all the words of this law to do them. And all the people shall say, Amen.
5613	181	1	AND it shall come to pass, if thou shalt hearken diligently unto the voice of the LORD thy God, to observe and to do all his commandments which I command thee this day, that the LORD thy God will set thee on high above all nations of the earth:
5614	181	2	And all these blessings shall come on thee, and overtake thee, if thou shalt hearken unto the voice of the LORD thy God.
5615	181	3	Blessed shalt thou be in the city, and blessed shalt thou be in the field.
5616	181	4	Blessed shall be the fruit of thy body, and the fruit of thy ground, and the fruit of thy cattle, the increase of thy kine, and the flocks of thy sheep.
5617	181	5	Blessed shall be thy basket and thy store.
5618	181	6	Blessed shalt thou be when thou comest in, and blessed shalt thou be when thou goest out.
5619	181	7	The LORD shall cause thine enemies that rise up against thee to be smitten before thy face: they shall come out against thee one way, and flee before thee seven ways.
5620	181	8	The LORD shall command the blessing upon thee in thy storehouses, and in all that thou settest thine hand unto; and he shall bless thee in the land which the LORD thy God giveth thee.
5621	181	9	The LORD shall establish thee an holy people unto himself, as he hath sworn unto thee, if thou shalt keep the commandments of the LORD thy God, and walk in his ways.
5622	181	10	And all people of the earth shall see that thou art called by the name of the LORD; and they shall be afraid of thee.
5623	181	11	And the LORD shall make thee plenteous in goods, in the fruit of thy body, and in the fruit of thy cattle, and in the fruit of thy ground, in the land which the LORD sware unto thy fathers to give thee.
5624	181	12	The LORD shall open unto thee his good treasure, the heaven to give the rain unto thy land in his season, and to bless all the work of thine hand: and thou shalt lend unto many nations, and thou shalt not borrow.
5625	181	13	And the LORD shall make thee the head, and not the tail; and thou shalt be above only, and thou shalt not be beneath; if that thou hearken unto the commandments of the LORD thy God, which I command thee this day, to observe and to do them:
5626	181	14	And thou shalt not go aside from any of the words which I command thee this day, to the right hand, or to the left, to go after other gods to serve them.
5627	181	15	But it shall come to pass, if thou wilt not hearken unto the voice of the LORD thy God, to observe to do all his commandments and his statutes which I command thee this day; that all these curses shall come upon thee, and overtake thee:
5628	181	16	Cursed shalt thou be in the city, and cursed shalt thou be in the field.
5629	181	17	Cursed shall be thy basket and thy store.
5630	181	18	Cursed shall be the fruit of thy body, and the fruit of thy land, the increase of thy kine, and the flocks of thy sheep.
5631	181	19	Cursed shalt thou be when thou comest in, and cursed shalt thou be when thou goest out.
5632	181	20	The LORD shall send upon thee cursing, vexation, and rebuke, in all that thou settest thine hand unto for to do, until thou be destroyed, and until thou perish quickly; because of the wickedness of thy doings, whereby thou hast forsaken me.
5633	181	21	The LORD shall make the pestilence cleave unto thee, until he have consumed thee from off the land, whither thou goest to possess it.
5634	181	22	The LORD shall smite thee with a consumption, and with a fever, and with an inflammation, and with an extreme burning, and with the sword, and with blasting, and with mildew; and they shall pursue thee until thou perish.
5635	181	23	And thy heaven that is over thy head shall be brass, and the earth that is under thee shall be iron.
5636	181	24	The LORD shall make the rain of thy land powder and dust: from heaven shall it come down upon thee, until thou be destroyed.
5637	181	25	The LORD shall cause thee to be smitten before thine enemies: thou shalt go out one way against them, and flee seven ways before them: and shalt be removed into all the kingdoms of the earth.
5638	181	26	And thy carcase shall be meat unto all fowls of the air, and unto the beasts of the earth, and no man shall fray them away.
5639	181	27	The LORD will smite thee with the botch of Egypt, and with the emerods, and with the scab, and with the itch, whereof thou canst not be healed.
5640	181	28	The LORD shall smite thee with madness, and blindness, and astonishment of heart:
5641	181	29	And thou shalt grope at noonday, as the blind gropeth in darkness, and thou shalt not prosper in thy ways: and thou shalt be only oppressed and spoiled evermore, and no man shall save thee.
5642	181	30	Thou shalt betroth a wife, and another man shall lie with her: thou shalt build an house, and thou shalt not dwell therein: thou shalt plant a vineyard, and shalt not gather the grapes thereof.
5643	181	31	Thine ox shall be slain before thine eyes, and thou shalt not eat thereof: thine ass shall be violently taken away from before thy face, and shall not be restored to thee: thy sheep shall be given unto thine enemies, and thou shalt have none to rescue them.
5644	181	32	Thy sons and thy daughters shall be given unto another people, and thine eyes shall look, and fail with longing for them all the day long: and there shall be no might in thine hand.
5645	181	33	The fruit of thy land, and all thy labours, shall a nation which thou knowest not eat up; and thou shalt be only oppressed and crushed alway:
5646	181	34	So that thou shalt be mad for the sight of thine eyes which thou shalt see.
5647	181	35	The LORD shall smite thee in the knees, and in the legs, with a sore botch that cannot be healed, from the sole of thy foot unto the top of thy head.
5648	181	36	The LORD shall bring thee, and thy king which thou shalt set over thee, unto a nation which neither thou nor thy fathers have known; and there shalt thou serve other gods, wood and stone.
5649	181	37	And thou shalt become an astonishment, a proverb, and a byword, among all nations whither the LORD shall lead thee.
5650	181	38	Thou shalt carry much seed out into the field, and shalt gather but little in; for the locust shall consume it.
5651	181	39	Thou shalt plant vineyards, and dress them, but shalt neither drink of the wine, nor gather the grapes; for the worms shall eat them.
5652	181	40	Thou shalt have olive trees throughout all thy coasts, but thou shalt not anoint thyself with the oil; for thine olive shall cast his fruit.
5653	181	41	Thou shalt beget sons and daughters, but thou shalt not enjoy them; for they shall go into captivity.
5654	181	42	All thy trees and fruit of thy land shall the locust consume.
5655	181	43	The stranger that is within thee shall get up above thee very high; and thou shalt come down very low.
5656	181	44	He shall lend to thee, and thou shalt not lend to him: he shall be the head, and thou shalt be the tail.
5657	181	45	Moreover all these curses shall come upon thee, and shall pursue thee, and overtake thee, till thou be destroyed; because thou hearkenedst not unto the voice of the LORD thy God, to keep his commandments and his statutes which he commanded thee:
5658	181	46	And they shall be upon thee for a sign and for a wonder, and upon thy seed for ever.
5659	181	47	Because thou servedst not the LORD thy God with joyfulness, and with gladness of heart, for the abundance of all things;
5660	181	48	Therefore shalt thou serve thine enemies which the LORD shall send against thee, in hunger, and in thirst, and in nakedness, and in want of all things: and he shall put a yoke of iron upon thy neck, until he have destroyed thee.
5661	181	49	The LORD shall bring a nation against thee from far, from the end of the earth, as swift as the eagle flieth; a nation whose tongue thou shalt not understand;
5662	181	50	A nation of fierce countenance, which shall not regard the person of the old, nor shew favour to the young:
5663	181	51	And he shall eat the fruit of thy cattle, and the fruit of thy land, until thou be destroyed: which also shall not leave thee either corn, wine, or oil, or the increase of thy kine, or flocks of thy sheep, until he have destroyed thee.
5664	181	52	And he shall besiege thee in all thy gates, until thy high and fenced walls come down, wherein thou trustedst, throughout all thy land: and he shall besiege thee in all thy gates throughout all thy land, which the LORD thy God hath given thee.
5665	181	53	And thou shalt eat the fruit of thine own body, the flesh of thy sons and of thy daughters, which the LORD thy God hath given thee, in the siege, and in the straitness, wherewith thine enemies shall distress thee:
5666	181	54	So that the man that is tender among you, and very delicate, his eye shall be evil toward his brother, and toward the wife of his bosom, and toward the remnant of his children which he shall leave:
5667	181	55	So that he will not give to any of them of the flesh of his children whom he shall eat: because he hath nothing left him in the siege, and in the straitness, wherewith thine enemies shall distress thee in all thy gates.
5668	181	56	The tender and delicate woman among you, which would not adventure to set the sole of her foot upon the ground for delicateness and tenderness, her eye shall be evil toward the husband of her bosom, and toward her son, and toward her daughter,
5669	181	57	And toward her young one that cometh out from between her feet, and toward her children which she shall bear: for she shall eat them for want of all things secretly in the siege and straitness, wherewith thine enemy shall distress thee in thy gates.
5670	181	58	If thou wilt not observe to do all the words of this law that are written in this book, that thou mayest fear this glorious and fearful name, THE LORD THY GOD;
5671	181	59	Then the LORD will make thy plagues wonderful, and the plagues of thy seed, even great plagues, and of long continuance, and sore sicknesses, and of long continuance.
5672	181	60	Moreover he will bring upon thee all the diseases of Egypt, which thou wast afraid of; and they shall cleave unto thee.
5673	181	61	Also every sickness, and every plague, which is not written in the book of this law, them will the LORD bring upon thee, until thou be destroyed.
5674	181	62	And ye shall be left few in number, whereas ye were as the stars of heaven for multitude; because thou wouldest not obey the voice of the LORD thy God.
5675	181	63	And it shall come to pass, that as the LORD rejoiced over you to do you good, and to multiply you; so the LORD will rejoice over you to destroy you, and to bring you to nought; and ye shall be plucked from off the land whither thou goest to possess it.
5676	181	64	And the LORD shall scatter thee among all people, from the one end of the earth even unto the other; and there thou shalt serve other gods, which neither thou nor thy fathers have known, even wood and stone.
5677	181	65	And among these nations shalt thou find no ease, neither shall the sole of thy foot have rest: but the LORD shall give thee there a trembling heart, and failing of eyes, and sorrow of mind:
5678	181	66	And thy life shall hang in doubt before thee; and thou shalt fear day and night, and shalt have none assurance of thy life:
5679	181	67	In the morning thou shalt say, Would God it were even! and at even thou shalt say, Would God it were morning! for the fear of thine heart wherewith thou shalt fear, and for the sight of thine eyes which thou shalt see.
5680	181	68	And the LORD shall bring thee into Egypt again with ships, by the way whereof I spake unto thee, Thou shalt see it no more again: and there ye shall be sold unto your enemies for bondmen and bondwomen, and no man shall buy you.
5681	182	1	THESE are the words of the covenant, which the LORD commanded Moses to make with the children of Israel in the land of Moab, beside the covenant which he made with them in Horeb.
5682	182	2	And Moses called unto all Israel, and said unto them, Ye have seen all that the LORD did before your eyes in the land of Egypt unto Pharaoh, and unto all his servants, and unto all his land;
5683	182	3	The great temptations which thine eyes have seen, the signs, and those great miracles:
5684	182	4	Yet the LORD hath not given you an heart to perceive, and eyes to see, and ears to hear, unto this day.
5685	182	5	And I have led you forty years in the wilderness: your clothes are not waxen old upon you, and thy shoe is not waxen old upon thy foot.
5686	182	6	Ye have not eaten bread, neither have ye drunk wine or strong drink: that ye might know that I am the LORD your God.
5687	182	7	And when ye came unto this place, Sihon the king of Heshbon, and Og the king of Bashan, came out against us unto battle, and we smote them:
5688	182	8	And we took their land, and gave it for an inheritance unto the Reubenites, and to the Gadites, and to the half tribe of Manasseh.
5689	182	9	Keep therefore the words of this covenant, and do them, that ye may prosper in all that ye do.
5690	182	10	Ye stand this day all of you before the LORD your God; your captains of your tribes, your elders, and your officers, with all the men of Israel,
5691	182	11	Your little ones, your wives, and thy stranger that is in thy camp, from the hewer of thy wood unto the drawer of thy water:
5692	182	12	That thou shouldest enter into covenant with the LORD thy God, and into his oath, which the LORD thy God maketh with thee this day:
5693	182	13	That he may establish thee to day for a people unto himself, and that he may be unto thee a God, as he hath said unto thee, and as he hath sworn unto thy fathers, to Abraham, to Isaac, and to Jacob.
5694	182	14	Neither with you only do I make this covenant and this oath;
5695	182	15	But with him that standeth here with us this day before the LORD our God, and also with him that is not here with us this day:
5696	182	16	(For ye know how we have dwelt in the land of Egypt; and how we came through the nations which ye passed by;
5697	182	17	And ye have seen their abominations, and their idols, wood and stone, silver and gold, which were among them:)
5698	182	18	Lest there should be among you man, or woman, or family, or tribe, whose heart turneth away this day from the LORD our God, to go and serve the gods of these nations; lest there should be among you a root that beareth gall and wormwood;
5699	182	19	And it come to pass, when he heareth the words of this curse, that he bless himself in his heart, saying, I shall have peace, though I walk in the imagination of mine heart, to add drunkenness to thirst:
5700	182	20	The LORD will not spare him, but then the anger of the LORD and his jealousy shall smoke against that man, and all the curses that are written in this book shall lie upon him, and the LORD shall blot out his name from under heaven.
5701	182	21	And the LORD shall separate him unto evil out of all the tribes of Israel, according to all the curses of the covenant that are written in this book of the law:
5702	182	22	So that the generation to come of your children that shall rise up after you, and the stranger that shall come from a far land, shall say, when they see the plagues of that land, and the sicknesses which the LORD hath laid upon it;
5703	182	23	And that the whole land thereof is brimstone, and salt, and burning, that it is not sown, nor beareth, nor any grass groweth therein, like the overthrow of Sodom, and Gomorrah, Admah, and Zeboim, which the LORD overthrew in his anger, and in his wrath:
5704	182	24	Even all nations shall say, Wherefore hath the LORD done thus unto this land? what meaneth the heat of this great anger?
5705	182	25	Then men shall say, Because they have forsaken the covenant of the LORD God of their fathers, which he made with them when he brought them forth out of the land of Egypt:
5706	182	26	For they went and served other gods, and worshipped them, gods whom they knew not, and whom he had not given unto them:
5707	182	27	And the anger of the LORD was kindled against this land, to bring upon it all the curses that are written in this book:
5708	182	28	And the LORD rooted them out of their land in anger, and in wrath, and in great indignation, and cast them into another land, as it is this day.
5709	182	29	The secret things belong unto the LORD our God: but those things which are revealed belong unto us and to our children for ever, that we may do all the words of this law.
5710	183	1	AND it shall come to pass, when all these things are come upon thee, the blessing and the curse, which I have set before thee, and thou shalt call them to mind among all the nations, whither the LORD thy God hath driven thee,
5711	183	2	And shalt return unto the LORD thy God, and shalt obey his voice according to all that I command thee this day, thou and thy children, with all thine heart, and with all thy soul;
5712	183	3	That then the LORD thy God will turn thy captivity, and have compassion upon thee, and will return and gather thee from all the nations, whither the LORD thy God hath scattered thee.
5713	183	4	If any of thine be driven out unto the outmost parts of heaven, from thence will the LORD thy God gather thee, and from thence will he fetch thee:
5714	183	5	And the LORD thy God will bring thee into the land which thy fathers possessed, and thou shalt possess it; and he will do thee good, and multiply thee above thy fathers.
5715	183	6	And the LORD thy God will circumcise thine heart, and the heart of thy seed, to love the LORD thy God with all thine heart, and with all thy soul, that thou mayest live.
5716	183	7	And the LORD thy God will put all these curses upon thine enemies, and on them that hate thee, which persecuted thee.
5717	183	8	And thou shalt return and obey the voice of the LORD, and do all his commandments which I command thee this day.
5718	183	9	And the LORD thy God will make thee plenteous in every work of thine hand, in the fruit of thy body, and in the fruit of thy cattle, and in the fruit of thy land, for good: for the LORD will again rejoice over thee for good, as he rejoiced over thy fathers:
5719	183	10	If thou shalt hearken unto the voice of the LORD thy God, to keep his commandments and his statutes which are written in this book of the law, and if thou turn unto the LORD thy God with all thine heart, and with all thy soul.
5720	183	11	For this commandment which I command thee this day, it is not hidden from thee, neither is it far off.
5721	183	12	It is not in heaven, that thou shouldest say, Who shall go up for us to heaven, and bring it unto us, that we may hear it, and do it?
5722	183	13	Neither is it beyond the sea, that thou shouldest say, Who shall go over the sea for us, and bring it unto us, that we may hear it, and do it?
5723	183	14	But the word is very nigh unto thee, in thy mouth, and in thy heart, that thou mayest do it.
5724	183	15	See, I have set before thee this day life and good, and death and evil;
5725	183	16	In that I command thee this day to love the LORD thy God, to walk in his ways, and to keep his commandments and his statutes and his judgments, that thou mayest live and multiply: and the LORD thy God shall bless thee in the land whither thou goest to possess it.
5726	183	17	But if thine heart turn away, so that thou wilt not hear, but shalt be drawn away, and worship other gods, and serve them;
5727	183	18	I denounce unto you this day, that ye shall surely perish, and that ye shall not prolong your days upon the land, whither thou passest over Jordan to go to possess it.
5728	183	19	I call heaven and earth to record this day against you, that I have set before you life and death, blessing and cursing: therefore choose life, that both thou and thy seed may live:
5729	183	20	That thou mayest love the LORD thy God, and that thou mayest obey his voice, and that thou mayest cleave unto him: for he is thy life, and the length of thy days: that thou mayest dwell in the land which the LORD sware unto thy fathers, to Abraham, to Isaac, and to Jacob, to give them.
5730	184	1	AND Moses went and spake these words unto all Israel.
5731	184	2	And he said unto them, I am an hundred and twenty years old this day; I can no more go out and come in: also the LORD hath said unto me, Thou shalt not go over this Jordan.
5732	184	3	The LORD thy God, he will go over before thee, and he will destroy these nations from before thee, and thou shalt possess them: and Joshua, he shall go over before thee, as the LORD hath said.
5733	184	4	And the LORD shall do unto them as he did to Sihon and to Og, kings of the Amorites, and unto the land of them, whom he destroyed.
5734	184	5	And the LORD shall give them up before your face, that ye may do unto them according unto all the commandments which I have commanded you.
5735	184	6	Be strong and of a good courage, fear not, nor be afraid of them: for the LORD thy God, he it is that doth go with thee; he will not fail thee, nor forsake thee.
5736	184	7	And Moses called unto Joshua, and said unto him in the sight of all Israel, Be strong and of a good courage: for thou must go with this people unto the land which the LORD hath sworn unto their fathers to give them; and thou shalt cause them to inherit it.
5737	184	8	And the LORD, he it is that doth go before thee; he will be with thee, he will not fail thee, neither forsake thee: fear not, neither be dismayed.
5738	184	9	And Moses wrote this law, and delivered it unto the priests the sons of Levi, which bare the ark of the covenant of the LORD, and unto all the elders of Israel.
5739	184	10	And Moses commanded them, saying, At the end of every seven years, in the solemnity of the year of release, in the feast of tabernacles,
5740	184	11	When all Israel is come to appear before the LORD thy God in the place which he shall choose, thou shalt read this law before all Israel in their hearing.
5741	184	12	Gather the people together, men, and women, and children, and thy stranger that is within thy gates, that they may hear, and that they may learn, and fear the LORD your God, and observe to do all the words of this law:
5742	184	13	And that their children, which have not known any thing, may hear, and learn to fear the LORD your God, as long as ye live in the land whither ye go over Jordan to possess it.
5743	184	14	And the LORD said unto Moses, Behold, thy days approach that thou must die: call Joshua, and present yourselves in the tabernacle of the congregation, that I may give him a charge. And Moses and Joshua went, and presented themselves in the tabernacle of the congregation.
5744	184	15	And the LORD appeared in the tabernacle in a pillar of a cloud: and the pillar of the cloud stood over the door of the tabernacle.
5745	184	16	And the LORD said unto Moses, Behold, thou shalt sleep with thy fathers; and this people will rise up, and go a whoring after the gods of the strangers of the land, whither they go to be among them, and will forsake me, and break my covenant which I have made with them.
5746	184	17	Then my anger shall be kindled against them in that day, and I will forsake them, and I will hide my face from them, and they shall be devoured, and many evils and troubles shall befall them; so that they will say in that day, Are not these evils come upon us, because our God is not among us?
5747	184	18	And I will surely hide my face in that day for all the evils which they shall have wrought, in that they are turned unto other gods.
5748	184	19	Now therefore write ye this song for you, and teach it the children of Israel: put it in their mouths, that this song may be a witness for me against the children of Israel.
5749	184	20	For when I shall have brought them into the land which I sware unto their fathers, that floweth with milk and honey; and they shall have eaten and filled themselves, and waxen fat; then will they turn unto other gods, and serve them, and provoke me, and break my covenant.
5750	184	21	And it shall come to pass, when many evils and troubles are befallen them, that this song shall testify against them as a witness; for it shall not be forgotten out of the mouths of their seed: for I know their imagination which they go about, even now, before I have brought them into the land which I sware.
5751	184	22	Moses therefore wrote this song the same day, and taught it the children of Israel.
5752	184	23	And he gave Joshua the son of Nun a charge, and said, Be strong and of a good courage: for thou shalt bring the children of Israel into the land which I sware unto them: and I will be with thee.
5753	184	24	And it came to pass, when Moses had made an end of writing the words of this law in a book, until they were finished,
5754	184	25	That Moses commanded the Levites, which bare the ark of the covenant of the LORD, saying,
5755	184	26	Take this book of the law, and put it in the side of the ark of the covenant of the LORD your God, that it may be there for a witness against thee.
5756	184	27	For I know thy rebellion, and thy stiff neck: behold, while I am yet alive with you this day, ye have been rebellious against the LORD; and how much more after my death?
5757	184	28	Gather unto me all the elders of your tribes, and your officers, that I may speak these words in their ears, and call heaven and earth to record against them.
5758	184	29	For I know that after my death ye will utterly corrupt yourselves, and turn aside from the way which I have commanded you; and evil will befall you in the latter days; because ye will do evil in the sight of the LORD, to provoke him to anger through the work of your hands.
5759	184	30	And Moses spake in the ears of all the congregation of Israel the words of this song, until they were ended.
5760	185	1	GIVE ear, O ye heavens, and I will speak; and hear, O earth, the words of my mouth.
5761	185	2	My doctrine shall drop as the rain, my speech shall distil as the dew, as the small rain upon the tender herb, and as the showers upon the grass:
5762	185	3	Because I will publish the name of the LORD: ascribe ye greatness unto our God.
5763	185	4	He is the Rock, his work is perfect: for all his ways are judgment: a God of truth and without iniquity, just and right is he.
5764	185	5	They have corrupted themselves, their spot is not the spot of his children: they are a perverse and crooked generation.
5765	185	6	Do ye thus requite the LORD, O foolish people and unwise? is not he thy father that hath bought thee? hath he not made thee, and established thee?
5766	185	7	Remember the days of old, consider the years of many generations: ask thy father, and he will shew thee; thy elders, and they will tell thee.
5767	185	8	When the most High divided to the nations their inheritance, when he separated the sons of Adam, he set the bounds of the people according to the number of the children of Israel.
5768	185	9	For the LORD'S portion is his people; Jacob is the lot of his inheritance.
5769	185	10	He found him in a desert land, and in the waste howling wilderness; he led him about, he instructed him, he kept him as the apple of his eye.
5770	185	11	As an eagle stirreth up her nest, fluttereth over her young, spreadeth abroad her wings, taketh them, beareth them on her wings:
5771	185	12	So the LORD alone did lead him, and there was no strange god with him.
5772	185	13	He made him ride on the high places of the earth, that he might eat the increase of the fields; and he made him to suck honey out of the rock, and oil out of the flinty rock;
5773	185	14	Butter of kine, and milk of sheep, with fat of lambs, and rams of the breed of Bashan, and goats, with the fat of kidneys of wheat; and thou didst drink the pure blood of the grape.
5774	185	15	But Jeshurun waxed fat, and kicked: thou art waxen fat, thou art grown thick, thou art covered with fatness; then he forsook God which made him, and lightly esteemed the Rock of his salvation.
5775	185	16	They provoked him to jealousy with strange gods, with abominations provoked they him to anger.
5776	185	17	They sacrificed unto devils, not to God; to gods whom they knew not, to new gods that came newly up, whom your fathers feared not.
5777	185	18	Of the Rock that begat thee thou art unmindful, and hast forgotten God that formed thee.
5778	185	19	And when the LORD saw it, he abhorred them, because of the provoking of his sons, and of his daughters.
5779	185	20	And he said, I will hide my face from them, I will see what their end shall be: for they are a very froward generation, children in whom is no faith.
5780	185	21	They have moved me to jealousy with that which is not God; they have provoked me to anger with their vanities: and I will move them to jealousy with those which are not a people; I will provoke them to anger with a foolish nation.
5781	185	22	For a fire is kindled in mine anger, and shall burn unto the lowest hell, and shall consume the earth with her increase, and set on fire the foundations of the mountains.
5782	185	23	I will heap mischiefs upon them; I will spend mine arrows upon them.
5783	185	24	They shall be burnt with hunger, and devoured with burning heat, and with bitter destruction: I will also send the teeth of beasts upon them, with the poison of serpents of the dust.
5784	185	25	The sword without, and terror within, shall destroy both the young man and the virgin, the suckling also with the man of gray hairs.
5785	185	26	I said, I would scatter them into corners, I would make the remembrance of them to cease from among men:
5786	185	27	Were it not that I feared the wrath of the enemy, lest their adversaries should behave themselves strangely, and lest they should say, Our hand is high, and the LORD hath not done all this.
5787	185	28	For they are a nation void of counsel, neither is there any understanding in them.
5788	185	29	O that they were wise, that they understood this, that they would consider their latter end!
5789	185	30	How should one chase a thousand, and two put ten thousand to flight, except their Rock had sold them, and the LORD had shut them up?
5790	185	31	For their rock is not as our Rock, even our enemies themselves being judges.
5791	185	32	For their vine is of the vine of Sodom, and of the fields of Gomorrah: their grapes are grapes of gall, their clusters are bitter:
5792	185	33	Their wine is the poison of dragons, and the cruel venom of asps.
5793	185	34	Is not this laid up in store with me, and sealed up among my treasures?
5794	185	35	To me belongeth vengeance, and recompence; their foot shall slide in due time: for the day of their calamity is at hand, and the things that shall come upon them make haste.
5795	185	36	For the LORD shall judge his people, and repent himself for his servants, when he seeth that their power is gone, and there is none shut up, or left.
5796	185	37	And he shall say, Where are their gods, their rock in whom they trusted,
5797	185	38	Which did eat the fat of their sacrifices, and drank the wine of their drink offerings? let them rise up and help you, and be your protection.
5798	185	39	See now that I, even I, am he, and there is no god with me: I kill, and I make alive; I wound, and I heal: neither is there any that can deliver out of my hand.
5799	185	40	For I lift up my hand to heaven, and say, I live for ever.
5800	185	41	If I whet my glittering sword, and mine hand take hold on judgment; I will render vengeance to mine enemies, and will reward them that hate me.
5801	185	42	I will make mine arrows drunk with blood, and my sword shall devour flesh; and that with the blood of the slain and of the captives, from the beginning of revenges upon the enemy.
5802	185	43	Rejoice, O ye nations, with his people: for he will avenge the blood of his servants, and will render vengeance to his adversaries, and will be merciful unto his land, and to his people.
5803	185	44	And Moses came and spake all the words of this song in the ears of the people, he, and Hoshea the son of Nun.
5804	185	45	And Moses made an end of speaking all these words to all Israel:
5805	185	46	And he said unto them, Set your hearts unto all the words which I testify among you this day, which ye shall command your children to observe to do, all the words of this law.
5806	185	47	For it is not a vain thing for you; because it is your life: and through this thing ye shall prolong your days in the land, whither ye go over Jordan to possess it.
5807	185	48	And the LORD spake unto Moses that selfsame day, saying,
5808	185	49	Get thee up into this mountain Abarim, unto mount Nebo, which is in the land of Moab, that is over against Jericho; and behold the land of Canaan, which I give unto the children of Israel for a possession:
5809	185	50	And die in the mount whither thou goest up, and be gathered unto thy people; as Aaron thy brother died in mount Hor, and was gathered unto his people:
5810	185	51	Because ye trespassed against me among the children of Israel at the waters of Meribah-Kadesh, in the wilderness of Zin; because ye sanctified me not in the midst of the children of Israel.
5811	185	52	Yet thou shalt see the land before thee; but thou shalt not go thither unto the land which I give the children of Israel.
5812	186	1	AND this is the blessing, wherewith Moses the man of God blessed the children of Israel before his death.
5813	186	2	And he said, The LORD came from Sinai, and rose up from Seir unto them; he shined forth from mount Paran, and he came with ten thousands of saints: from his right hand went a fiery law for them.
5814	186	3	Yea, he loved the people; all his saints are in thy hand: and they sat down at thy feet; every one shall receive of thy words.
5815	186	4	Moses commanded us a law, even the inheritance of the congregation of Jacob.
5816	186	5	And he was king in Jeshurun, when the heads of the people and the tribes of Israel were gathered together.
5817	186	6	Let Reuben live, and not die; and let not his men be few.
5818	186	7	And this is the blessing of Judah: and he said, Hear, LORD, the voice of Judah, and bring him unto his people: let his hands be sufficient for him; and be thou an help to him from his enemies.
5819	186	8	And of Levi he said, Let thy Thummim and thy Urim be with thy holy one, whom thou didst prove at Massah, and with whom thou didst strive at the waters of Meribah;
5820	186	9	Who said unto his father and to his mother, I have not seen him; neither did he acknowledge his brethren, nor knew his own children: for they have observed thy word, and kept thy covenant.
5821	186	10	They shall teach Jacob thy judgments, and Israel thy law: they shall put incense before thee, and whole burnt sacrifice upon thine altar.
5822	186	11	Bless, LORD, his substance, and accept the work of his hands: smite through the loins of them that rise against him, and of them that hate him, that they rise not again.
5823	186	12	And of Benjamin he said, The beloved of the LORD shall dwell in safety by him; and the LORD shall cover him all the day long, and he shall dwell between his shoulders.
5824	186	13	And of Joseph he said, Blessed of the LORD be his land, for the precious things of heaven, for the dew, and for the deep that coucheth beneath,
5825	186	14	And for the precious fruits brought forth by the sun, and for the precious things put forth by the moon,
5826	186	15	And for the chief things of the ancient mountains, and for the precious things of the lasting hills,
5827	186	16	And for the precious things of the earth and fulness thereof, and for the good will of him that dwelt in the bush: let the blessing come upon the head of Joseph, and upon the top of the head of him that was separated from his brethren.
5828	186	17	His glory is like the firstling of his bullock, and his horns are like the horns of unicorns: with them he shall push the people together to the ends of the earth: and they are the ten thousands of Ephraim, and they are the thousands of Manasseh.
5829	186	18	And of Zebulun he said, Rejoice, Zebulun, in thy going out; and, Issachar, in thy tents.
5830	186	19	They shall call the people unto the mountain; there they shall offer sacrifices of righteousness: for they shall suck of the abundance of the seas, and of treasures hid in the sand.
5831	186	20	And of Gad he said, Blessed be he that enlargeth Gad: he dwelleth as a lion, and teareth the arm with the crown of the head.
5832	186	21	And he provided the first part for himself, because there, in a portion of the lawgiver, was he seated; and he came with the heads of the people, he executed the justice of the LORD, and his judgments with Israel.
5833	186	22	And of Dan he said, Dan is a lion's whelp: he shall leap from Bashan.
5834	186	23	And of Naphtali he said, O Naphtali, satisfied with favour, and full with the blessing of the LORD: possess thou the west and the south.
5835	186	24	And of Asher he said, Let Asher be blessed with children; let him be acceptable to his brethren, and let him dip his foot in oil.
5836	186	25	Thy shoes shall be iron and brass; and as thy days, so shall thy strength be.
5837	186	26	There is none like unto the God of Jeshurun, who rideth upon the heaven in thy help, and in his excellency on the sky.
5838	186	27	The eternal God is thy refuge, and underneath are the everlasting arms: and he shall thrust out the enemy from before thee; and shall say, Destroy them.
5839	186	28	Israel then shall dwell in safety alone: the fountain of Jacob shall be upon a land of corn and wine; also his heavens shall drop down dew.
5840	186	29	Happy art thou, O Israel: who is like unto thee, O people saved by the LORD, the shield of thy help, and who is the sword of thy excellency! and thine enemies shall be found liars unto thee; and thou shalt tread upon their high places.
5841	187	1	AND Moses went up from the plains of Moab unto the mountain of Nebo, to the top of Pisgah, that is over against Jericho. And the LORD shewed him all the land of Gilead, unto Dan,
5842	187	2	And all Naphtali, and the land of Ephraim, and Manasseh, and all the land of Judah, unto the utmost sea,
5843	187	3	And the south, and the plain of the valley of Jericho, the city of palm trees, unto Zoar.
5844	187	4	And the LORD said unto him, This is the land which I sware unto Abraham, unto Isaac, and unto Jacob, saying, I will give it unto thy seed: I have caused thee to see it with thine eyes, but thou shalt not go over thither.
5845	187	5	So Moses the servant of the LORD died there in the land of Moab, according to the word of the LORD.
5846	187	6	And he buried him in a valley in the land of Moab, over against Beth-peor: but no man knoweth of his sepulchre unto this day.
5847	187	7	And Moses was an hundred and twenty years old when he died: his eye was not dim, nor his natural force abated.
5848	187	8	And the children of Israel wept for Moses in the plains of Moab thirty days: so the days of weeping and mourning for Moses were ended.
5849	187	9	And Joshua the son of Nun was full of the spirit of wisdom; for Moses had laid his hands upon him: and the children of Israel hearkened unto him, and did as the LORD commanded Moses.
5850	187	10	And there arose not a prophet since in Israel like unto Moses, whom the LORD knew face to face,
5851	187	11	In all the signs and the wonders, which the LORD sent him to do in the land of Egypt to Pharaoh, and to all his servants, and to all his land,
5852	187	12	And in all that mighty hand, and in all the great terror which Moses shewed in the sight of all Israel.
5853	188	1	NOW after the death of Moses the servant of the LORD it came to pass, that the LORD spake unto Joshua the son of Nun, Moses' minister, saying,
5854	188	2	Moses my servant is dead; now therefore arise, go over this Jordan, thou, and all this people, unto the land which I do give to them, even to the children of Israel.
5855	188	3	Every place that the sole of your foot shall tread upon, that have I given unto you, as I said unto Moses.
5856	188	4	From the wilderness and this Lebanon even unto the great river, the river Euphrates, all the land of the Hittites, and unto the great sea toward the going down of the sun, shall be your coast.
5857	188	5	There shall not any man be able to stand before thee all the days of thy life: as I was with Moses, so I will be with thee: I will not fail thee, nor forsake thee.
5858	188	6	Be strong and of a good courage: for unto this people shalt thou divide for an inheritance the land, which I sware unto their fathers to give them.
5859	188	7	Only be thou strong and very courageous, that thou mayest observe to do according to all the law, which Moses my servant commanded thee: turn not from it to the right hand or to the left, that thou mayest prosper whithersoever thou goest.
5860	188	8	This book of the law shall not depart out of thy mouth; but thou shalt meditate therein day and night, that thou mayest observe to do according to all that is written therein: for then thou shalt make thy way prosperous, and then thou shalt have good success.
5861	188	9	Have not I commanded thee? Be strong and of a good courage; be not afraid, neither be thou dismayed: for the LORD thy God is with thee whithersoever thou goest.
5862	188	10	Then Joshua commanded the officers of the people, saying,
5863	188	11	Pass through the host, and command the people, saying, Prepare you victuals; for within three days ye shall pass over this Jordan, to go in to possess the land, which the LORD your God giveth you to possess it.
5864	188	12	And to the Reubenites, and to the Gadites, and to half the tribe of Manasseh, spake Joshua, saying,
5865	188	13	Remember the word which Moses the servant of the LORD commanded you, saying, The LORD your God hath given you rest, and hath given you this land.
5866	188	14	Your wives, your little ones, and your cattle, shall remain in the land which Moses gave you on this side Jordan; but ye shall pass before your brethren armed, all the mighty men of valour, and help them;
5867	188	15	Until the LORD have given your brethren rest, as he hath given you, and they also have possessed the land which the LORD your God giveth them: then ye shall return unto the land of your possession, and enjoy it, which Moses the LORD's servant gave you on this side Jordan toward the sunrising.
5868	188	16	And they answered Joshua, saying, All that thou commandest us we will do, and whithersoever thou sendest us, we will go.
5869	188	17	According as we hearkened unto Moses in all things, so will we hearken unto thee: only the LORD thy God be with thee, as he was with Moses.
5870	188	18	Whosoever he be that doth rebel against thy commandment, and will not hearken unto thy words in all that thou commandest him, he shall be put to death: only be strong and of a good courage.
5871	189	1	AND Joshua the son of Nun sent out of Shittim two men to spy secretly, saying, Go view the land, even Jericho. And they went, and came into an harlot's house, named Rahab, and lodged there.
5872	189	2	And it was told the king of Jericho, saying, Behold, there came men in hither to night of the children of Israel to search out the country.
5873	189	3	And the king of Jericho sent unto Rahab, saying, Bring forth the men that are come to thee, which are entered into thine house: for they be come to search out all the country.
5874	189	4	And the woman took the two men, and hid them, and said thus, There came men unto me, but I wist not whence they were:
5875	189	5	And it came to pass about the time of shutting of the gate, when it was dark, that the men went out: whither the men went I wot not: pursue after them quickly; for ye shall overtake them.
5876	189	6	But she had brought them up to the roof of the house, and hid them with the stalks of flax, which she had laid in order upon the roof.
5877	189	7	And the men pursued after them the way to Jordan unto the fords: and as soon as they which pursued after them were gone out, they shut the gate.
5878	189	8	And before they were laid down, she came up unto them upon the roof;
5879	189	9	And she said unto the men, I know that the LORD hath given you the land, and that your terror is fallen upon us, and that all the inhabitants of the land faint because of you.
5880	189	10	For we have heard how the LORD dried up the water of the Red sea for you, when ye came out of Egypt; and what ye did unto the two kings of the Amorites, that were on the other side Jordan, Sihon and Og, whom ye utterly destroyed.
5881	189	11	And as soon as we had heard these things, our hearts did melt, neither did there remain any more courage in any man, because of you: for the LORD your God, he is God in heaven above, and in earth beneath.
5882	189	12	Now therefore, I pray you, swear unto me by the LORD, since I have shewed you kindness, that ye will also shew kindness unto my father's house, and give me a true token:
5883	189	13	And that ye will save alive my father, and my mother, and my brethren, and my sisters, and all that they have, and deliver our lives from death.
5884	189	14	And the men answered her, Our life for yours, if ye utter not this our business. And it shall be, when the LORD hath given us the land, that we will deal kindly and truly with thee.
5885	189	15	Then she let them down by a cord through the window: for her house was upon the town wall, and she dwelt upon the wall.
5886	189	16	And she said unto them, Get you to the mountain, lest the pursuers meet you; and hide yourselves there three days, until the pursuers be returned: and afterward may ye go your way.
5887	189	17	And the men said unto her, We will be blameless of this thine oath which thou hast made us swear.
5888	189	18	Behold, when we come into the land, thou shalt bind this line of scarlet thread in the window which thou didst let us down by: and thou shalt bring thy father, and thy mother, and thy brethren, and all thy father's household, home unto thee.
5889	189	19	And it shall be, that whosoever shall go out of the doors of thy house into the street, his blood shall be upon his head, and we will be guiltless: and whosoever shall be with thee in the house, his blood shall be on our head, if any hand be upon him.
5890	189	20	And if thou utter this our business, then we will be quit of thine oath which thou hast made us to swear.
5891	189	21	And she said, According unto your words, so be it. And she sent them away, and they departed: and she bound the scarlet line in the window.
5892	189	22	And they went, and came unto the mountain, and abode there three days, until the pursuers were returned: and the pursuers sought them throughout all the way, but found them not.
5893	189	23	So the two men returned, and descended from the mountain, and passed over, and came to Joshua the son of Nun, and told him all things that befell them:
5894	189	24	And they said unto Joshua, Truly the LORD hath delivered into our hands all the land; for even all the inhabitants of the country do faint because of us.
5895	190	1	AND Joshua rose early in the morning; and they removed from Shittim, and came to Jordan, he and all the children of Israel, and lodged there before they passed over.
5896	190	2	And it came to pass after three days, that the officers went through the host;
5897	190	3	And they commanded the people, saying, When ye see the ark of the covenant of the LORD your God, and the priests the Levites bearing it, then ye shall remove from your place, and go after it.
5898	190	4	Yet there shall be a space between you and it, about two thousand cubits by measure: come not near unto it, that ye may know the way by which ye must go: for ye have not passed this way heretofore.
5899	190	5	And Joshua said unto the people, Sanctify yourselves: for to morrow the LORD will do wonders among you.
5900	190	6	And Joshua spake unto the priests, saying, Take up the ark of the covenant, and pass over before the people. And they took up the ark of the covenant, and went before the people.
5901	190	7	And the LORD said unto Joshua, This day will I begin to magnify thee in the sight of all Israel, that they may know that, as I was with Moses, so I will be with thee.
5902	190	8	And thou shalt command the priests that bear the ark of the covenant, saying, When ye are come to the brink of the water of Jordan, ye shall stand still in Jordan.
5903	190	9	And Joshua said unto the children of Israel, Come hither, and hear the words of the LORD your God.
5904	190	10	And Joshua said, Hereby ye shall know that the living God is among you, and that he will without fail drive out from before you the Canaanites, and the Hittites, and the Hivites, and the Perizzites, and the Girgashites, and the Amorites, and the Jebusites.
5905	190	11	Behold, the ark of the covenant of the LORD of all the earth passeth over before you into Jordan.
5906	190	12	Now therefore take you twelve men out of the tribes of Israel, out of every tribe a man.
5907	190	13	And it shall come to pass, as soon as the soles of the feet of the priests that bear the ark of the LORD, the Lord of all the earth, shall rest in the waters of Jordan, that the waters of Jordan shall be cut off from the waters that come down from above; and they shall stand upon an heap.
5908	190	14	And it came to pass, when the people removed from their tents, to pass over Jordan, and the priests bearing the ark of the covenant before the people;
5909	190	15	And as they that bare the ark were come unto Jordan, and the feet of the priests that bare the ark were dipped in the brim of the water, (for Jordan overfloweth all his banks all the time of harvest,)
5910	190	16	That the waters which came down from above stood and rose up upon an heap very far from the city Adam, that is beside Zaretan: and those that came down toward the sea of the plain, even the salt sea, failed, and were cut off: and the people passed over right against Jericho.
5911	190	17	And the priests that bare the ark of the covenant of the LORD stood firm on dry ground in the midst of Jordan, and all the Israelites passed over on dry ground, until all the people were passed clean over Jordan.
5912	191	1	AND it came to pass, when all the people were clean passed over Jordan, that the LORD spake unto Joshua, saying,
5913	191	2	Take you twelve men out of the people, out of every tribe a man,
5914	191	3	And command ye them, saying, Take you hence out of the midst of Jordan, out of the place where the priests' feet stood firm, twelve stones, and ye shall carry them over with you, and leave them in the lodging place, where ye shall lodge this night.
5915	191	4	Then Joshua called the twelve men, whom he had prepared of the children of Israel, out of every tribe a man:
5916	191	5	And Joshua said unto them, Pass over before the ark of the LORD your God into the midst of Jordan, and take ye up every man of you a stone upon his shoulder, according unto the number of the tribes of the children of Israel:
5917	191	6	That this may be a sign among you, that when your children ask their fathers in time to come, saying, What mean ye by these stones?
5918	191	7	Then ye shall answer them, That the waters of Jordan were cut off before the ark of the covenant of the LORD; when it passed over Jordan, the waters of Jordan were cut off: and these stones shall be for a memorial unto the children of Israel for ever.
5919	191	8	And the children of Israel did so as Joshua commanded, and took up twelve stones out of the midst of Jordan, as the LORD spake unto Joshua, according to the number of the tribes of the children of Israel, and carried them over with them unto the place where they lodged, and laid them down there.
5920	191	9	And Joshua set up twelve stones in the midst of Jordan, in the place where the feet of the priests which bare the ark of the covenant stood: and they are there unto this day.
5921	191	10	For the priests which bare the ark stood in the midst of Jordan, until every thing was finished that the LORD commanded Joshua to speak unto the people, according to all that Moses commanded Joshua: and the people hasted and passed over.
5922	191	11	And it came to pass, when all the people were clean passed over, that the ark of the LORD passed over, and the priests, in the presence of the people.
5923	191	12	And the children of Reuben, and the children of Gad, and half the tribe of Manasseh, passed over armed before the children of Israel, as Moses spake unto them:
5924	191	13	About forty thousand prepared for war passed over before the LORD unto battle, to the plains of Jericho.
5925	191	14	On that day the LORD magnified Joshua in the sight of all Israel; and they feared him, as they feared Moses, all the days of his life.
5926	191	15	And the LORD spake unto Joshua, saying,
5927	191	16	Command the priests that bear the ark of the testimony, that they come up out of Jordan.
5928	191	17	Joshua therefore commanded the priests, saying, Come ye up out of Jordan.
5929	191	18	And it came to pass, when the priests that bare the ark of the covenant of the LORD were come up out of the midst of Jordan, and the soles of the priests' feet were lifted up unto the dry land, that the waters of Jordan returned unto their place, and flowed over all his banks, as they did before.
5930	191	19	And the people came up out of Jordan on the tenth day of the first month, and encamped in Gilgal, in the east border of Jericho.
5931	191	20	And those twelve stones, which they took out of Jordan, did Joshua pitch in Gilgal.
5932	191	21	And he spake unto the children of Israel, saying, When your children shall ask their fathers in time to come, saying, What mean these stones?
5933	191	22	Then ye shall let your children know, saying, Israel came over this Jordan on dry land.
5934	191	23	For the LORD your God dried up the waters of Jordan from before you, until ye were passed over, as the LORD your God did to the Red sea, which he dried up from before us, until we were gone over:
5935	191	24	That all the people of the earth might know the hand of the LORD, that it is mighty: that ye might fear the LORD your God for ever.
5936	192	1	AND it came to pass, when all the kings of the Amorites, which were on the side of Jordan westward, and all the kings of the Canaanites, which were by the sea, heard that the LORD had dried up the waters of Jordan from before the children of Israel, until we were passed over, that their heart melted, neither was there spirit in them any more, because of the children of Israel.
5937	192	2	At that time the LORD said unto Joshua, Make thee sharp knives, and circumcise again the children of Israel the second time.
5938	192	3	And Joshua made him sharp knives, and circumcised the children of Israel at the hill of the foreskins.
5939	192	4	And this is the cause why Joshua did circumcise: All the people that came out of Egypt, that were males, even all the men of war, died in the wilderness by the way, after they came out of Egypt.
5940	192	5	Now all the people that came out were circumcised: but all the people that were born in the wilderness by the way as they came forth out of Egypt, them they had not circumcised.
5941	192	6	For the children of Israel walked forty years in the wilderness, till all the people that were men of war, which came out of Egypt, were consumed, because they obeyed not the voice of the LORD: unto whom the LORD sware that he would not shew them the land, which the LORD sware unto their fathers that he would give us, a land that floweth with milk and honey.
5942	192	7	And their children, whom he raised up in their stead, them Joshua circumcised: for they were uncircumcised, because they had not circumcised them by the way.
5943	192	8	And it came to pass, when they had done circumcising all the people, that they abode in their places in the camp, till they were whole.
5944	192	9	And the LORD said unto Joshua, This day have I rolled away the reproach of Egypt from off you. Wherefore the name of the place is called Gilgal unto this day.
5945	192	10	And the children of Israel encamped in Gilgal, and kept the passover on the fourteenth day of the month at even in the plains of Jericho.
5946	192	11	And they did eat of the old corn of the land on the morrow after the passover, unleavened cakes, and parched corn in the selfsame day.
5947	192	12	And the manna ceased on the morrow after they had eaten of the old corn of the land; neither had the children of Israel manna any more; but they did eat of the fruit of the land of Canaan that year.
5948	192	13	And it came to pass, when Joshua was by Jericho, that he lifted up his eyes and looked, and, behold, there stood a man over against him with his sword drawn in his hand: and Joshua went unto him, and said unto him, Art thou for us, or for our adversaries?
5949	192	14	And he said, Nay; but as captain of the host of the LORD am I now come. And Joshua fell on his face to the earth, and did worship, and said unto him, What saith my lord unto his servant?
5950	192	15	And the captain of the LORD's host said unto Joshua, Loose thy shoe from off thy foot; for the place whereon thou standest is holy. And Joshua did so.
5951	193	1	NOW Jericho was straitly shut up because of the children of Israel: none went out, and none came in.
5952	193	2	And the LORD said unto Joshua, See, I have given into thine hand Jericho, and the king thereof, and the mighty men of valour.
5953	193	3	And ye shall compass the city, all ye men of war, and go round about the city once. Thus shalt thou do six days.
5954	193	4	And seven priests shall bear before the ark seven trumpets of rams' horns: and the seventh day ye shall compass the city seven times, and the priests shall blow with the trumpets.
5955	193	5	And it shall come to pass, that when they make a long blast with the ram's horn, and when ye hear the sound of the trumpet, all the people shall shout with a great shout; and the wall of the city shall fall down flat, and the people shall ascend up every man straight before him.
5956	193	6	And Joshua the son of Nun called the priests, and said unto them, Take up the ark of the covenant, and let seven priests bear seven trumpets of rams' horns before the ark of the LORD.
5957	193	7	And he said unto the people, Pass on, and compass the city, and let him that is armed pass on before the ark of the LORD.
5958	193	8	And it came to pass, when Joshua had spoken unto the people, that the seven priests bearing the seven trumpets of rams' horns passed on before the LORD, and blew with the trumpets: and the ark of the covenant of the LORD followed them.
5959	193	9	And the armed men went before the priests that blew with the trumpets, and the rereward came after the ark, the priests going on, and blowing with the trumpets.
5960	193	10	And Joshua had commanded the people, saying, Ye shall not shout, nor make any noise with your voice, neither shall any word proceed out of your mouth, until the day I bid you shout; then shall ye shout.
5961	193	11	So the ark of the LORD compassed the city, going about it once: and they came into the camp, and lodged in the camp.
5962	193	12	And Joshua rose early in the morning, and the priests took up the ark of the LORD.
5963	193	13	And seven priests bearing seven trumpets of rams' horns before the ark of the LORD went on continually, and blew with the trumpets: and the armed men went before them; but the rereward came after the ark of the LORD, the priests going on, and blowing with the trumpets.
5964	193	14	And the second day they compassed the city once, and returned into the camp: so they did six days.
5965	193	15	And it came to pass on the seventh day, that they rose early about the dawning of the day, and compassed the city after the same manner seven times: only on that day they compassed the city seven times.
5966	193	16	And it came to pass at the seventh time, when the priests blew with the trumpets, Joshua said unto the people, Shout; for the LORD hath given you the city.
5967	193	17	And the city shall be accursed, even it, and all that are therein, to the LORD: only Rahab the harlot shall live, she and all that are with her in the house, because she hid the messengers that we sent.
5968	193	18	And ye, in any wise keep yourselves from the accursed thing, lest ye make yourselves accursed, when ye take of the accursed thing, and make the camp of Israel a curse, and trouble it.
5969	193	19	But all the silver, and gold, and vessels of brass and iron, are consecrated unto the LORD: they shall come into the treasury of the LORD.
5970	193	20	So the people shouted when the priests blew with the trumpets: and it came to pass, when the people heard the sound of the trumpet, and the people shouted with a great shout, that the wall fell down flat, so that the people went up into the city, every man straight before him, and they took the city.
5971	193	21	And they utterly destroyed all that was in the city, both man and woman, young and old, and ox, and sheep, and ass, with the edge of the sword.
5972	193	22	But Joshua had said unto the two men that had spied out the country, Go into the harlot's house, and bring out thence the woman, and all that she hath, as ye sware unto her.
5973	193	23	And the young men that were spies went in, and brought out Rahab, and her father, and her mother, and her brethren, and all that she had; and they brought out all her kindred, and left them without the camp of Israel.
5974	193	24	And they burnt the city with fire, and all that was therein: only the silver, and the gold, and the vessels of brass and of iron, they put into the treasury of the house of the LORD.
5975	193	25	And Joshua saved Rahab the harlot alive, and her father's household, and all that she had; and she dwelleth in Israel even unto this day; because she hid the messengers, which Joshua sent to spy out Jericho.
5976	193	26	And Joshua adjured them at that time, saying, Cursed be the man before the LORD, that riseth up and buildeth this city Jericho: he shall lay the foundation thereof in his firstborn, and in his youngest son shall he set up the gates of it.
5977	193	27	So the LORD was with Joshua; and his fame was noised throughout all the country.
5978	194	1	BUT the children of Israel committed a trespass in the accursed thing: for Achan, the son of Carmi, the son of Zabdi, the son of Zerah, of the tribe of Judah, took of the accursed thing: and the anger of the LORD was kindled against the children of Israel.
5979	194	2	And Joshua sent men from Jericho to Ai, which is beside Beth-aven, on the east side of Beth-el, and spake unto them, saying, Go up and view the country. And the men went up and viewed Ai.
5980	194	3	And they returned to Joshua, and said unto him, Let not all the people go up; but let about two or three thousand men go up and smite Ai; and make not all the people to labour thither; for they are but few.
5981	194	4	So there went up thither of the people about three thousand men: and they fled before the men of Ai.
5982	194	5	And the men of Ai smote of them about thirty and six men: for they chased them from before the gate even unto Shebarim, and smote them in the going down: wherefore the hearts of the people melted, and became as water.
5983	194	6	And Joshua rent his clothes, and fell to the earth upon his face before the ark of the LORD until the eventide, he and the elders of Israel, and put dust upon their heads.
5984	194	7	And Joshua said, Alas, O Lord GOD, wherefore hast thou at all brought this people over Jordan, to deliver us into the hand of the Amorites, to destroy us? would to God we had been content, and dwelt on the other side Jordan!
5985	194	8	O Lord, what shall I say, when Israel turneth their backs before their enemies!
5986	194	9	For the Canaanites and all the inhabitants of the land shall hear of it, and shall environ us round, and cut off our name from the earth: and what wilt thou do unto thy great name?
5987	194	10	And the LORD said unto Joshua, Get thee up; wherefore liest thou thus upon thy face?
5988	194	11	Israel hath sinned, and they have also transgressed my covenant which I commanded them: for they have even taken of the accursed thing, and have also stolen, and dissembled also, and they have put it even among their own stuff.
5989	194	12	Therefore the children of Israel could not stand before their enemies, but turned their backs before their enemies, because they were accursed: neither will I be with you any more, except ye destroy the accursed from among you.
5990	194	13	Up, sanctify the people, and say, Sanctify yourselves against to morrow: for thus saith the LORD God of Israel, There is an accursed thing in the midst of thee, O Israel: thou canst not stand before thine enemies, until ye take away the accursed thing from among you.
5991	194	14	In the morning therefore ye shall be brought according to your tribes: and it shall be, that the tribe which the LORD taketh shall come according to the families thereof; and the family which the LORD shall take shall come by households; and the household which the LORD shall take shall come man by man.
5992	194	15	And it shall be, that he that is taken with the accursed thing shall be burnt with fire, he and all that he hath: because he hath transgressed the covenant of the LORD, and because he hath wrought folly in Israel.
5993	194	16	So Joshua rose up early in the morning, and brought Israel by their tribes; and the tribe of Judah was taken:
5994	194	17	And he brought the family of Judah; and he took the family of the Zarhites: and he brought the family of the Zarhites man by man; and Zabdi was taken:
5995	194	18	And he brought his household man by man; and Achan, the son of Carmi, the son of Zabdi, the son of Zerah, of the tribe of Judah, was taken.
5996	194	19	And Joshua said unto Achan, My son, give, I pray thee, glory to the LORD God of Israel, and make confession unto him; and tell me now what thou hast done; hide it not from me.
5997	194	20	And Achan answered Joshua, and said, Indeed I have sinned against the LORD God of Israel, and thus and thus have I done:
5998	194	21	When I saw among the spoils a goodly Babylonish garment, and two hundred shekels of silver, and a wedge of gold of fifty shekels weight, then I coveted them, and took them; and, behold, they are hid in the earth in the midst of my tent, and the silver under it.
5999	194	22	So Joshua sent messengers, and they ran unto the tent; and, behold, it was hid in his tent, and the silver under it.
6000	194	23	And they took them out of the midst of the tent, and brought them unto Joshua, and unto all the children of Israel, and laid them out before the LORD.
6001	194	24	And Joshua, and all Israel with him, took Achan the son of Zerah, and the silver, and the garment, and the wedge of gold, and his sons, and his daughters, and his oxen, and his asses, and his sheep, and his tent, and all that he had: and they brought them unto the valley of Achor.
6002	194	25	And Joshua said, Why hast thou troubled us? the LORD shall trouble thee this day. And all Israel stoned him with stones, and burned them with fire, after they had stoned them with stones.
6003	194	26	And they raised over him a great heap of stones unto this day. So the LORD turned from the fierceness of his anger. Wherefore the name of that place was called, The valley of Achor, unto this day.
6004	195	1	AND the LORD said unto Joshua, Fear not, neither be thou dismayed: take all the people of war with thee, and arise, go up to Ai: see, I have given into thy hand the king of Ai, and his people, and his city, and his land:
6005	195	2	And thou shalt do to Ai and her king as thou didst unto Jericho and her king: only the spoil thereof, and the cattle thereof, shall ye take for a prey unto yourselves: lay thee an ambush for the city behind it.
6006	195	3	So Joshua arose, and all the people of war, to go up against Ai: and Joshua chose out thirty thousand mighty men of valour, and sent them away by night.
6007	195	4	And he commanded them, saying, Behold, ye shall lie in wait against the city, even behind the city: go not very far from the city, but be ye all ready:
6008	195	5	And I, and all the people that are with me, will approach unto the city: and it shall come to pass, when they come out against us, as at the first, that we will flee before them,
6009	195	6	(For they will come out after us) till we have drawn them from the city; for they will say, They flee before us, as at the first: therefore we will flee before them.
6010	195	7	Then ye shall rise up from the ambush, and seize upon the city: for the LORD your God will deliver it into your hand.
6011	195	8	And it shall be, when ye have taken the city, that ye shall set the city on fire: according to the commandment of the LORD shall ye do. See, I have commanded you.
6012	195	9	Joshua therefore sent them forth: and they went to lie in ambush, and abode between Beth-el and Ai, on the west side of Ai: but Joshua lodged that night among the people.
6013	195	10	And Joshua rose up early in the morning, and numbered the people, and went up, he and the elders of Israel, before the people to Ai.
6014	195	11	And all the people, even the people of war that were with him, went up, and drew nigh, and came before the city, and pitched on the north side of Ai: now there was a valley between them and Ai.
6015	195	12	And he took about five thousand men, and set them to lie in ambush between Beth-el and Ai, on the west side of the city.
6016	195	13	And when they had set the people, even all the host that was on the north of the city, and their liers in wait on the west of the city, Joshua went that night into the midst of the valley.
6017	195	14	And it came to pass, when the king of Ai saw it, that they hasted and rose up early, and the men of the city went out against Israel to battle, he and all his people, at a time appointed, before the plain; but he wist not that there were liers in ambush against him behind the city.
6018	195	15	And Joshua and all Israel made as if they were beaten before them, and fled by the way of the wilderness.
6019	195	16	And all the people that were in Ai were called together to pursue after them: and they pursued after Joshua, and were drawn away from the city.
6020	195	17	And there was not a man left in Ai or Beth-el, that went not out after Israel: and they left the city open, and pursued after Israel.
6021	195	18	And the LORD said unto Joshua, Stretch out the spear that is in thy hand toward Ai; for I will give it into thine hand. And Joshua stretched out the spear that he had in his hand toward the city.
6022	195	19	And the ambush arose quickly out of their place, and they ran as soon as he had stretched out his hand: and they entered into the city, and took it, and hasted and set the city on fire.
6023	195	20	And when the men of Ai looked behind them, they saw, and, behold, the smoke of the city ascended up to heaven, and they had no power to flee this way or that way: and the people that fled to the wilderness turned back upon the pursuers.
6024	195	21	And when Joshua and all Israel saw that the ambush had taken the city, and that the smoke of the city ascended, then they turned again, and slew the men of Ai.
6025	195	22	And the other issued out of the city against them; so they were in the midst of Israel, some on this side, and some on that side: and they smote them, so that they let none of them remain or escape.
6026	195	23	And the king of Ai they took alive, and brought him to Joshua.
6027	195	24	And it came to pass, when Israel had made an end of slaying all the inhabitants of Ai in the field, in the wilderness wherein they chased them, and when they were all fallen on the edge of the sword, until they were consumed, that all the Israelites returned unto Ai, and smote it with the edge of the sword.
6028	195	25	And so it was, that all that fell that day, both of men and women, were twelve thousand, even all the men of Ai.
6029	195	26	For Joshua drew not his hand back, wherewith he stretched out the spear, until he had utterly destroyed all the inhabitants of Ai.
6030	195	27	Only the cattle and the spoil of that city Israel took for a prey unto themselves, according unto the word of the LORD which he commanded Joshua.
6031	195	28	And Joshua burnt Ai, and made it an heap for ever, even a desolation unto this day.
6032	195	29	And the king of Ai he hanged on a tree until eventide: and as soon as the sun was down, Joshua commanded that they should take his carcase down from the tree, and cast it at the entering of the gate of the city, and raise thereon a great heap of stones, that remaineth unto this day.
6033	195	30	Then Joshua built an altar unto the LORD God of Israel in mount Ebal,
6034	195	31	As Moses the servant of the LORD commanded the children of Israel, as it is written in the book of the law of Moses, an altar of whole stones, over which no man hath lift up any iron: and they offered thereon burnt offerings unto the LORD, and sacrificed peace offerings.
6035	195	32	And he wrote there upon the stones a copy of the law of Moses, which he wrote in the presence of the children of Israel.
6036	195	33	And all Israel, and their elders, and officers, and their judges, stood on this side the ark and on that side before the priests the Levites, which bare the ark of the covenant of the LORD, as well as the stranger, as he that was born among them; half of them over against mount Gerizim, and half of them over against mount Ebal; as Moses the servant of the LORD had commanded before, that they should bless the people of Israel.
6037	195	34	And afterward he read all the words of the law, the blessings and cursings, according to all that is written in the book of the law.
6038	195	35	There was not a word of all that Moses commanded, which Joshua read not before all the congregation of Israel, with the women, and the little ones, and the strangers that were conversant among them.
6039	196	1	AND it came to pass, when all the kings which were on this side Jordan, in the hills, and in the valleys, and in all the coasts of the great sea over against Lebanon, the Hittite, and the Amorite, the Canaanite, the Perizzite, the Hivite, and the Jebusite, heard thereof;
6040	196	2	That they gathered themselves together, to fight with Joshua and with Israel, with one accord.
6041	196	3	And when the inhabitants of Gibeon heard what Joshua had done unto Jericho and to Ai,
6042	196	4	They did work wilily, and went and made as if they had been ambassadors, and took old sacks upon their asses, and wine bottles, old, and rent, and bound up;
6043	196	5	And old shoes and clouted upon their feet, and old garments upon them; and all the bread of their provision was dry and mouldy.
6044	196	6	And they went to Joshua unto the camp at Gilgal, and said unto him, and to the men of Israel, We be come from a far country: now therefore make ye a league with us.
6045	196	7	And the men of Israel said unto the Hivites, Peradventure ye dwell among us; and how shall we make a league with you?
6046	196	8	And they said unto Joshua, We are thy servants. And Joshua said unto them, Who are ye? and from whence come ye?
6047	196	9	And they said unto him, From a very far country thy servants are come because of the name of the LORD thy God: for we have heard the fame of him, and all that he did in Egypt,
6048	196	10	And all that he did to the two kings of the Amorites, that were beyond Jordan, to Sihon king of Heshbon, and to Og king of Bashan, which was at Ashtaroth.
6049	196	11	Wherefore our elders and all the inhabitants of our country spake to us, saying, Take victuals with you for the journey, and go to meet them, and say unto them, We are your servants: therefore now make ye a league with us.
6050	196	12	This our bread we took hot for our provision out of our houses on the day we came forth to go unto you; but now, behold, it is dry, and it is mouldy:
6051	196	13	And these bottles of wine, which we filled, were new; and, behold, they be rent: and these our garments and our shoes are become old by reason of the very long journey.
6052	196	14	And the men took of their victuals, and asked not counsel at the mouth of the LORD.
6053	196	15	And Joshua made peace with them, and made a league with them, to let them live: and the princes of the congregation sware unto them.
6054	196	16	And it came to pass at the end of three days after they had made a league with them, that they heard that they were their neighbours, and that they dwelt among them.
6055	196	17	And the children of Israel journeyed, and came unto their cities on the third day. Now their cities were Gibeon, and Chephirah, and Beeroth, and Kirjath-jearim.
6056	196	18	And the children of Israel smote them not, because the princes of the congregation had sworn unto them by the LORD God of Israel. And all the congregation murmured against the princes.
6057	196	19	But all the princes said unto all the congregation, We have sworn unto them by the LORD God of Israel: now therefore we may not touch them.
6058	196	20	This we will do to them; we will even let them live, lest wrath be upon us, because of the oath which we sware unto them.
6059	196	21	And the princes said unto them, Let them live; but let them be hewers of wood and drawers of water unto all the congregation; as the princes had promised them.
6060	196	22	And Joshua called for them, and he spake unto them, saying, Wherefore have ye beguiled us, saying, We are very far from you; when ye dwell among us?
6061	196	23	Now therefore ye are cursed, and there shall none of you be freed from being bondmen, and hewers of wood and drawers of water for the house of my God.
6062	196	24	And they answered Joshua, and said, Because it was certainly told thy servants, how that the LORD thy God commanded his servant Moses to give you all the land, and to destroy all the inhabitants of the land from before you, therefore we were sore afraid of our lives because of you, and have done this thing.
6063	196	25	And now, behold, we are in thine hand: as it seemeth good and right unto thee to do unto us, do.
6064	196	26	And so did he unto them, and delivered them out of the hand of the children of Israel, that they slew them not.
6065	196	27	And Joshua made them that day hewers of wood and drawers of water for the congregation, and for the altar of the LORD, even unto this day, in the place which he should choose.
6066	197	1	NOW it came to pass, when Adoni-zedek king of Jerusalem had heard how Joshua had taken Ai, and had utterly destroyed it; as he had done to Jericho and her king, so he had done to Ai and her king; and how the inhabitants of Gibeon had made peace with Israel, and were among them;
6067	197	2	That they feared greatly, because Gibeon was a great city, as one of the royal cities, and because it was greater than Ai, and all the men thereof were mighty.
6068	197	3	Wherefore Adoni-zedek king of Jerusalem sent unto Hoham king of Hebron, and unto Piram king of Jarmuth, and unto Japhia king of Lachish, and unto Debir king of Eglon, saying,
6069	197	4	Come up unto me, and help me, that we may smite Gibeon: for it hath made peace with Joshua and with the children of Israel.
6070	197	5	Therefore the five kings of the Amorites, the king of Jerusalem, the king of Hebron, the king of Jarmuth, the king of Lachish, the king of Eglon, gathered themselves together, and went up, they and all their hosts, and encamped before Gibeon, and made war against it.
6071	197	6	And the men of Gibeon sent unto Joshua to the camp to Gilgal, saying, Slack not thy hand from thy servants; come up to us quickly, and save us, and help us: for all the kings of the Amorites that dwell in the mountains are gathered together against us.
6072	197	7	So Joshua ascended from Gilgal, he, and all the people of war with him, and all the mighty men of valour.
6073	197	8	And the LORD said unto Joshua, Fear them not: for I have delivered them into thine hand; there shall not a man of them stand before thee.
6074	197	9	Joshua therefore came unto them suddenly, and went up from Gilgal all night.
6075	197	10	And the LORD discomfited them before Israel, and slew them with a great slaughter at Gibeon, and chased them along the way that goeth up to Beth-horon, and smote them to Azekah, and unto Makkedah.
6076	197	11	And it came to pass, as they fled from before Israel, and were in the going down to Beth-horon, that the LORD cast down great stones from heaven upon them unto Azekah, and they died: they were more which died with hailstones than they whom the children of Israel slew with the sword.
6077	197	12	Then spake Joshua to the LORD in the day when the LORD delivered up the Amorites before the children of Israel, and he said in the sight of Israel, Sun, stand thou still upon Gibeon; and thou, Moon, in the valley of Ajalon.
6078	197	13	And the sun stood still, and the moon stayed, until the people had avenged themselves upon their enemies. Is not this written in the book of Jasher? So the sun stood still in the midst of heaven, and hasted not to go down about a whole day.
6079	197	14	And there was no day like that before it or after it, that the LORD hearkened unto the voice of a man: for the LORD fought for Israel.
6080	197	15	And Joshua returned, and all Israel with him, unto the camp to Gilgal.
6081	197	16	But these five kings fled, and hid themselves in a cave at Makkedah.
6082	197	17	And it was told Joshua, saying, The five kings are found hid in a cave at Makkedah.
6083	197	18	And Joshua said, Roll great stones upon the mouth of the cave, and set men by it for to keep them:
6084	197	19	And stay ye not, but pursue after your enemies, and smite the hindmost of them; suffer them not to enter into their cities: for the LORD your God hath delivered them into your hand.
6085	197	20	And it came to pass, when Joshua and the children of Israel had made an end of slaying them with a very great slaughter, till they were consumed, that the rest which remained of them entered into fenced cities.
6086	197	21	And all the people returned to the camp to Joshua at Makkedah in peace: none moved his tongue against any of the children of Israel.
6087	197	22	Then said Joshua, Open the mouth of the cave, and bring out those five kings unto me out of the cave.
6088	197	23	And they did so, and brought forth those five kings unto him out of the cave, the king of Jerusalem, the king of Hebron, the king of Jarmuth, the king of Lachish, and the king of Eglon.
6089	197	24	And it came to pass, when they brought out those kings unto Joshua, that Joshua called for all the men of Israel, and said unto the captains of the men of war which went with him, Come near, put your feet upon the necks of these kings. And they came near, and put their feet upon the necks of them.
6090	197	25	And Joshua said unto them, Fear not, nor be dismayed, be strong and of good courage: for thus shall the LORD do to all your enemies against whom ye fight.
6091	197	26	And afterward Joshua smote them, and slew them, and hanged them on five trees: and they were hanging upon the trees until the evening.
6092	197	27	And it came to pass at the time of the going down of the sun, that Joshua commanded, and they took them down off the trees, and cast them into the cave wherein they had been hid, and laid great stones in the cave's mouth, which remain until this very day.
6093	197	28	And that day Joshua took Makkedah, and smote it with the edge of the sword, and the king thereof he utterly destroyed, them, and all the souls that were therein; he let none remain: and he did to the king of Makkedah as he did unto the king of Jericho.
6094	197	29	Then Joshua passed from Makkedah, and all Israel with him, unto Libnah, and fought against Libnah:
6095	197	30	And the LORD delivered it also, and the king thereof, into the hand of Israel; and he smote it with the edge of the sword, and all the souls that were therein; he let none remain in it; but did unto the king thereof as he did unto the king of Jericho.
6096	197	31	And Joshua passed from Libnah, and all Israel with him, unto Lachish, and encamped against it, and fought against it:
6097	197	32	And the LORD delivered Lachish into the hand of Israel, which took it on the second day, and smote it with the edge of the sword, and all the souls that were therein, according to all that he had done to Libnah.
6098	197	33	Then Horam king of Gezer came up to help Lachish; and Joshua smote him and his people, until he had left him none remaining.
6099	197	34	And from Lachish Joshua passed unto Eglon, and all Israel with him; and they encamped against it, and fought against it:
6100	197	35	And they took it on that day, and smote it with the edge of the sword, and all the souls that were therein he utterly destroyed that day, according to all that he had done to Lachish.
6101	197	36	And Joshua went up from Eglon, and all Israel with him, unto Hebron; and they fought against it:
6102	197	37	And they took it, and smote it with the edge of the sword, and the king thereof, and all the cities thereof, and all the souls that were therein; he left none remaining, according to all that he had done to Eglon; but destroyed it utterly, and all the souls that were therein.
6103	197	38	And Joshua returned, and all Israel with him, to Debir; and fought against it:
6104	197	39	And he took it, and the king thereof, and all the cities thereof; and they smote them with the edge of the sword, and utterly destroyed all the souls that were therein; he left none remaining: as he had done to Hebron, so he did to Debir, and to the king thereof; as he had done also to Libnah, and to her king.
6105	197	40	So Joshua smote all the country of the hills, and of the south, and of the vale, and of the springs, and all their kings: he left none remaining, but utterly destroyed all that breathed, as the LORD God of Israel commanded.
6106	197	41	And Joshua smote them from Kadesh-barnea even unto Gaza, and all the country of Goshen, even unto Gibeon.
6107	197	42	And all these kings and their land did Joshua take at one time, because the LORD God of Israel fought for Israel.
6108	197	43	And Joshua returned, and all Israel with him, unto the camp to Gilgal.
6109	198	1	AND it came to pass, when Jabin king of Hazor had heard those things, that he sent to Jobab king of Madon, and to the king of Shimron, and to the king of Achshaph,
6110	198	2	And to the kings that were on the north of the mountains, and of the plains south of Chinneroth, and in the valley, and in the borders of Dor on the west,
6111	198	3	And to the Canaanite on the east and on the west, and to the Amorite, and the Hittite, and the Perizzite, and the Jebusite in the mountains, and to the Hivite under Hermon in the land of Mizpeh.
6112	198	4	And they went out, they and all their hosts with them, much people, even as the sand that is upon the sea shore in multitude, with horses and chariots very many.
6113	198	5	And when all these kings were met together, they came and pitched together at the waters of Merom, to fight against Israel.
6114	198	6	And the LORD said unto Joshua, Be not afraid because of them: for to morrow about this time will I deliver them up all slain before Israel: thou shalt hough their horses, and burn their chariots with fire.
6115	198	7	So Joshua came, and all the people of war with him, against them by the waters of Merom suddenly; and they fell upon them.
6116	198	8	And the LORD delivered them into the hand of Israel, who smote them, and chased them unto great Zidon, and unto Misrephoth-maim, and unto the valley of Mizpeh eastward; and they smote them, until they left them none remaining.
6117	198	9	And Joshua did unto them as the LORD bade him: he houghed their horses, and burnt their chariots with fire.
6118	198	10	And Joshua at that time turned back, and took Hazor, and smote the king thereof with the sword: for Hazor beforetime was the head of all those kingdoms.
6119	198	11	And they smote all the souls that were therein with the edge of the sword, utterly destroying them: there was not any left to breathe: and he burnt Hazor with fire.
6120	198	12	And all the cities of those kings, and all the kings of them, did Joshua take, and smote them with the edge of the sword, and he utterly destroyed them, as Moses the servant of the LORD commanded.
6121	198	13	But as for the cities that stood still in their strength, Israel burned none of them, save Hazor only; that did Joshua burn.
6122	198	14	And all the spoil of these cities, and the cattle, the children of Israel took for a prey unto themselves; but every man they smote with the edge of the sword, until they had destroyed them, neither left they any to breathe.
6123	198	15	As the LORD commanded Moses his servant, so did Moses command Joshua, and so did Joshua; he left nothing undone of all that the LORD commanded Moses.
6124	198	16	So Joshua took all that land, the hills, and all the south country, and all the land of Goshen, and the valley, and the plain, and the mountain of Israel, and the valley of the same;
6125	198	17	Even from the mount Halak, that goeth up to Seir, even unto Baal-gad in the valley of Lebanon under mount Hermon: and all their kings he took, and smote them, and slew them.
6126	198	18	Joshua made war a long time with all those kings.
6127	198	19	There was not a city that made peace with the children of Israel, save the Hivites the inhabitants of Gibeon: all other they took in battle.
6128	198	20	For it was of the LORD to harden their hearts, that they should come against Israel in battle, that he might destroy them utterly, and that they might have no favour, but that he might destroy them, as the LORD commanded Moses.
6129	198	21	And at that time came Joshua, and cut off the Anakims from the mountains, from Hebron, from Debir, from Anab, and from all the mountains of Judah, and from all the mountains of Israel: Joshua destroyed them utterly with their cities.
6130	198	22	There was none of the Anakims left in the land of the children of Israel: only in Gaza, in Gath, and in Ashdod, there remained.
6131	198	23	So Joshua took the whole land, according to all that the LORD said unto Moses; and Joshua gave it for an inheritance unto Israel according to their divisions by their tribes. And the land rested from war.
6132	199	1	NOW these are the kings of the land, which the children of Israel smote, and possessed their land on the other side Jordan toward the rising of the sun, from the river Arnon unto mount Hermon, and all the plain on the east:
6133	199	2	Sihon king of the Amorites, who dwelt in Heshbon, and ruled from Aroer, which is upon the bank of the river Arnon, and from the middle of the river, and from half Gilead, even unto the river Jabbok, which is the border of the children of Ammon;
6134	199	3	And from the plain to the sea of Chinneroth on the east, and unto the sea of the plain, even the salt sea on the east, the way to Beth-jeshimoth; and from the south, under Ashdoth-pisgah:
6135	199	4	And the coast of Og king of Bashan, which was of the remnant of the giants, that dwelt at Ashtaroth and at Edrei,
6136	199	5	And reigned in mount Hermon, and in Salcah, and in all Bashan, unto the border of the Geshurites and the Maachathites, and half Gilead, the border of Sihon king of Heshbon.
6137	199	6	Them did Moses the servant of the LORD and the children of Israel smite: and Moses the servant of the LORD gave it for a possession unto the Reubenites, and the Gadites, and the half tribe of Manasseh.
6138	199	7	And these are the kings of the country which Joshua and the children of Israel smote on this side Jordan on the west, from Baal-gad in the valley of Lebanon even unto the mount Halak, that goeth up to Seir; which Joshua gave unto the tribes of Israel for a possession according to their divisions;
6139	199	8	In the mountains, and in the valleys, and in the plains, and in the springs, and in the wilderness, and in the south country; the Hittites, the Amorites, and the Canaanites, the Perizzites, the Hivites, and the Jebusites:
6140	199	9	The king of Jericho, one; the king of Ai, which is beside Beth-el, one;
6141	199	10	The king of Jerusalem, one; the king of Hebron, one;
6142	199	11	The king of Jarmuth, one; the king of Lachish, one;
6143	199	12	The king of Eglon, one; the king of Gezer, one;
6144	199	13	The king of Debir, one; the king of Geder, one;
6145	199	14	The king of Hormah, one; the king of Arad, one;
6146	199	15	The king of Libnah, one; the king of Adullam, one;
6147	199	16	The king of Makkedah, one; the king of Beth-el, one;
6148	199	17	The king of Tappuah, one; the king of Hepher, one;
6149	199	18	The king of Aphek, one; the king of Lasharon, one;
6150	199	19	The king of Madon, one; the king of Hazor, one;
6151	199	20	The king of Shimron-meron, one; the king of Achshaph, one;
6152	199	21	The king of Taanach, one; the king of Megiddo, one;
6153	199	22	The king of Kedesh, one; the king of Jokneam of Carmel, one;
6154	199	23	The king of Dor in the coast of Dor, one; the king of the nations of Gilgal, one;
6155	199	24	The king of Tirzah, one: all the kings thirty and one.
6156	200	1	NOW Joshua was old and stricken in years; and the LORD said unto him, Thou art old and stricken in years, and there remaineth yet very much land to be possessed.
6157	200	2	This is the land that yet remaineth: all the borders of the Philistines, and all Geshuri,
6158	200	3	From Sihor, which is before Egypt, even unto the borders of Ekron northward, which is counted to the Canaanite: five lords of the Philistines; the Gazathites, and the Ashdothites, the Eshkalonites, the Gittites, and the Ekronites; also the Avites:
6159	200	4	From the south, all the land of the Canaanites, and Mearah that is beside the Sidonians, unto Aphek, to the borders of the Amorites:
6160	200	5	And the land of the Giblites, and all Lebanon, toward the sunrising, from Baal-gad under mount Hermon unto the entering into Hamath.
6161	200	6	All the inhabitants of the hill country from Lebanon unto Misrephoth-maim, and all the Sidonians, them will I drive out from before the children of Israel: only divide thou it by lot unto the Israelites for an inheritance, as I have commanded thee.
6162	200	7	Now therefore divide this land for an inheritance unto the nine tribes, and the half tribe of Manasseh,
6163	200	8	With whom the Reubenites and the Gadites have received their inheritance, which Moses gave them, beyond Jordan eastward, even as Moses the servant of the LORD gave them;
6164	200	9	From Aroer, that is upon the bank of the river Arnon, and the city that is in the midst of the river, and all the plain of Medeba unto Dibon;
6165	200	10	And all the cities of Sihon king of the Amorites, which reigned in Heshbon, unto the border of the children of Ammon;
6166	200	11	And Gilead, and the border of the Geshurites and Maachathites, and all mount Hermon, and all Bashan unto Salcah;
6167	200	12	All the kingdom of Og in Bashan, which reigned in Ashtaroth and in Edrei, who remained of the remnant of the giants: for these did Moses smite, and cast them out.
6168	200	13	Nevertheless the children of Israel expelled not the Geshurites, nor the Maachathites: but the Geshurites and the Maachathites dwell among the Israelites until this day.
6169	200	14	Only unto the tribe of Levi he gave none inheritance; the sacrifices of the LORD God of Israel made by fire are their inheritance, as he said unto them.
6170	200	15	And Moses gave unto the tribe of the children of Reuben inheritance according to their families.
6171	200	16	And their coast was from Aroer, that is on the bank of the river Arnon, and the city that is in the midst of the river, and all the plain by Medeba;
6172	200	17	Heshbon, and all her cities that are in the plain; Dibon, and Bamoth-baal, and Beth-baal-meon,
6173	200	18	And Jahazah, and Kedemoth, and Mephaath,
6174	200	19	And Kirjathaim, and Sibmah, and Zareth-shahar in the mount of the valley,
6175	200	20	And Beth-peor, and Ashdoth-pisgah, and Beth-jeshimoth,
6176	200	21	And all the cities of the plain, and all the kingdom of Sihon king of the Amorites, which reigned in Heshbon, whom Moses smote with the princes of Midian, Evi, and Rekem, and Zur, and Hur, and Reba, which were dukes of Sihon, dwelling in the country.
6177	200	22	Balaam also the son of Beor, the soothsayer, did the children of Israel slay with the sword among them that were slain by them.
6178	200	23	And the border of the children of Reuben was Jordan, and the border thereof. This was the inheritance of the children of Reuben after their families, the cities and the villages thereof.
6179	200	24	And Moses gave inheritance unto the tribe of Gad, even unto the children of Gad according to their families.
6180	200	25	And their coast was Jazer, and all the cities of Gilead, and half the land of the children of Ammon, unto Aroer that is before Rabbah;
6181	200	26	And from Heshbon unto Ramath-mizpeh, and Betonim; and from Mahanaim unto the border of Debir;
6182	200	27	And in the valley, Beth-aram, and Beth-nimrah, and Succoth, and Zaphon, the rest of the kingdom of Sihon king of Heshbon, Jordan and his border, even unto the edge of the sea of Chinnereth on the other side Jordan eastward.
6183	200	28	This is the inheritance of the children of Gad after their families, the cities, and their villages.
6184	200	29	And Moses gave inheritance unto the half tribe of Manasseh: and this was the possession of the half tribe of the children of Manasseh by their families.
6185	200	30	And their coast was from Mahanaim, all Bashan, all the kingdom of Og king of Bashan, and all the towns of Jair, which are in Bashan, threescore cities:
6186	200	31	And half Gilead, and Ashtaroth, and Edrei, cities of the kingdom of Og in Bashan, were pertaining unto the children of Machir the son of Manasseh, even to the one half of the children of Machir by their families.
6187	200	32	These are the countries which Moses did distribute for inheritance in the plains of Moab, on the other side Jordan, by Jericho, eastward.
6188	200	33	But unto the tribe of Levi Moses gave not any inheritance: the LORD God of Israel was their inheritance, as he said unto them.
6189	201	1	AND these are the countries which the children of Israel inherited in the land of Canaan, which Eleazar the priest, and Joshua the son of Nun, and the heads of the fathers of the tribes of the children of Israel, distributed for inheritance to them.
6190	201	2	By lot was their inheritance, as the LORD commanded by the hand of Moses, for the nine tribes, and for the half tribe.
6191	201	3	For Moses had given the inheritance of two tribes and an half tribe on the other side Jordan: but unto the Levites he gave none inheritance among them.
6192	201	4	For the children of Joseph were two tribes, Manasseh and Ephraim: therefore they gave no part unto the Levites in the land, save cities to dwell in, with their suburbs for their cattle and for their substance.
6193	201	5	As the LORD commanded Moses, so the children of Israel did, and they divided the land.
6194	201	6	Then the children of Judah came unto Joshua in Gilgal: and Caleb the son of Jephunneh the Kenezite said unto him, Thou knowest the thing that the LORD said unto Moses the man of God concerning me and thee in Kadesh-barnea.
6195	201	7	Forty years old was I when Moses the servant of the LORD sent me from Kadesh-barnea to espy out the land; and I brought him word again as it was in mine heart.
6196	201	8	Nevertheless my brethren that went up with me made the heart of the people melt: but I wholly followed the LORD my God.
6197	201	9	And Moses sware on that day, saying, Surely the land whereon thy feet have trodden shall be thine inheritance, and thy children's for ever, because thou hast wholly followed the LORD my God.
6198	201	10	And now, behold, the LORD hath kept me alive, as he said, these forty and five years, even since the LORD spake this word unto Moses, while the children of Israel wandered in the wilderness: and now, lo, I am this day fourscore and five years old.
6199	201	11	As yet I am as strong this day as I was in the day that Moses sent me: as my strength was then, even so is my strength now, for war, both to go out, and to come in.
6200	201	12	Now therefore give me this mountain, whereof the LORD spake in that day; for thou heardest in that day how the Anakims were there, and that the cities were great and fenced: if so be the LORD will be with me, then I shall be able to drive them out, as the LORD said.
6201	201	13	And Joshua blessed him, and gave unto Caleb the son of Jephunneh Hebron for an inheritance.
6202	201	14	Hebron therefore became the inheritance of Caleb the son of Jephunneh the Kenezite unto this day, because that he wholly followed the LORD God of Israel.
6203	201	15	And the name of Hebron before was Kirjath-arba; which Arba was a great man among the Anakims. And the land had rest from war.
6204	202	1	THIS then was the lot of the tribe of the children of Judah by their families; even to the border of Edom the wilderness of Zin southward was the uttermost part of the south coast.
6205	202	2	And their south border was from the shore of the salt sea, from the bay that looketh southward:
6206	202	3	And it went out to the south side to Maaleh-acrabbim, and passed along to Zin, and ascended up on the south side unto Kadesh-barnea, and passed along to Hezron, and went up to Adar, and fetched a compass to Karkaa:
6207	202	4	From thence it passed toward Azmon, and went out unto the river of Egypt; and the goings out of that coast were at the sea: this shall be your south coast.
6208	202	5	And the east border was the salt sea, even unto the end of Jordan. And their border in the north quarter was from the bay of the sea at the uttermost part of Jordan:
6209	202	6	And the border went up to Beth-hogla, and passed along by the north of Beth-arabah; and the border went up to the stone of Bohan the son of Reuben:
6210	202	7	And the border went up toward Debir from the valley of Achor, and so northward, looking toward Gilgal, that is before the going up to Adummim, which is on the south side of the river: and the border passed toward the waters of En-shemesh, and the goings out thereof were at En-rogel:
6211	202	8	And the border went up by the valley of the son of Hinnom unto the south side of the Jebusite; the same is Jerusalem: and the border went up to the top of the mountain that lieth before the valley of Hinnom westward, which is at the end of the valley of the giants northward:
6212	202	9	And the border was drawn from the top of the hill unto the fountain of the water of Nephtoah, and went out to the cities of mount Ephron; and the border was drawn to Baalah, which is Kirjath-jearim:
6213	202	10	And the border compassed from Baalah westward unto mount Seir, and passed along unto the side of mount Jearim, which is Chesalon, on the north side, and went down to Beth-shemesh, and passed on to Timnah:
6214	202	11	And the border went out unto the side of Ekron northward: and the border was drawn to Shicron, and passed along to mount Baalah, and went out unto Jabneel; and the goings out of the border were at the sea.
6215	202	12	And the west border was to the great sea, and the coast thereof. This is the coast of the children of Judah round about according to their families.
6216	202	13	And unto Caleb the son of Jephunneh he gave a part among the children of Judah, according to the commandment of the LORD to Joshua, even the city of Arba the father of Anak, which city is Hebron.
6217	202	14	And Caleb drove thence the three sons of Anak, Sheshai, and Ahiman, and Talmai, the children of Anak.
6218	202	15	And he went up thence to the inhabitants of Debir: and the name of Debir before was Kirjath-sepher.
6219	202	16	And Caleb said, He that smiteth Kirjath-sepher, and taketh it, to him will I give Achsah my daughter to wife.
6220	202	17	And Othniel the son of Kenaz, the brother of Caleb, took it: and he gave him Achsah his daughter to wife.
6221	202	18	And it came to pass, as she came unto him, that she moved him to ask of her father a field: and she lighted off her ass; and Caleb said unto her, What wouldest thou?
6222	202	19	Who answered, Give me a blessing; for thou hast given me a south land; give me also springs of water. And he gave her the upper springs, and the nether springs.
6223	202	20	This is the inheritance of the tribe of the children of Judah according to their families.
6224	202	21	And the uttermost cities of the tribe of the children of Judah toward the coast of Edom southward were Kabzeel, and Eder, and Jagur,
6225	202	22	And Kinah, and Dimonah, and Adadah,
6226	202	23	And Kedesh, and Hazor, and Ithnan,
6227	202	24	Ziph, and Telem, and Bealoth,
6228	202	25	And Hazor, Hadattah, and Kerioth, and Hezron, which is Hazor,
6229	202	26	Amam, and Shema, and Moladah,
6230	202	27	And Hazar-gaddah, and Heshmon, and Beth-palet,
6231	202	28	And Hazar-shual, and Beer-sheba, and Bizjothjah,
6232	202	29	Baalah, and Iim, and Azem,
6233	202	30	And Eltolad, and Chesil, and Hormah,
6234	202	31	And Ziklag, and Madmannah, and Sansannah,
6235	202	32	And Lebaoth, and Shilhim, and Ain, and Rimmon: all the cities are twenty and nine, with their villages:
6236	202	33	And in the valley, Eshtaol, and Zoreah, and Ashnah,
6237	202	34	And Zanoah, and En-gannim, Tappuah, and Enam,
6238	202	35	Jarmuth, and Adullam, Socoh, and Azekah,
6239	202	36	And Sharaim, and Adithaim, and Gederah, and Gederothaim; fourteen cities with their villages:
6240	202	37	Zenan, and Hadashah, and Migdal-gad,
6241	202	38	And Dilean, and Mizpeh, and Joktheel,
6242	202	39	Lachish, and Bozkath, and Eglon,
6243	202	40	And Cabbon, and Lahmam, and Kithlish,
6244	202	41	And Gederoth, Beth-dagon, and Naamah, and Makkedah; sixteen cities with their villages:
6245	202	42	Libnah, and Ether, and Ashan,
6246	202	43	And Jiphtah, and Ashnah, and Nezib,
6247	202	44	And Keilah, and Achzib, and Mareshah; nine cities with their villages:
6248	202	45	Ekron, with her towns and her villages:
6249	202	46	From Ekron even unto the sea, all that lay near Ashdod, with their villages:
6250	202	47	Ashdod with her towns and her villages, Gaza with her towns and her villages, unto the river of Egypt, and the great sea, and the border thereof:
6251	202	48	And in the mountains, Shamir, and Jattir, and Socoh,
6252	202	49	And Dannah, and Kirjath-sannah, which is Debir,
6253	202	50	And Anab, and Eshtemoh, and Anim,
6254	202	51	And Goshen, and Holon, and Giloh; eleven cities with their villages:
6255	202	52	Arab, and Dumah, and Eshean,
6256	202	53	And Janum, and Beth-tappuah, and Aphekah,
6257	202	54	And Humtah, and Kirjath-arba, which is Hebron, and Zior; nine cities with their villages:
6258	202	55	Maon, Carmel, and Ziph, and Juttah,
6259	202	56	And Jezreel, and Jokdeam, and Zanoah,
6260	202	57	Cain, Gibeah, and Timnah; ten cities with their villages:
6261	202	58	Halhul, Beth-zur, and Gedor,
6262	202	59	And Maarath, and Beth-anoth, and Eltekon; six cities with their villages:
6263	202	60	Kirjath-baal, which is Kirjath-jearim, and Rabbah; two cities with their villages:
6264	202	61	In the wilderness, Beth-arabah, Middin, and Secacah,
6265	202	62	And Nibshan, and the city of Salt, and En-gedi; six cities with their villages.
6266	202	63	As for the Jebusites the inhabitants of Jerusalem, the children of Judah could not drive them out: but the Jebusites dwell with the children of Judah at Jerusalem unto this day.
6267	203	1	AND the lot of the children of Joseph fell from Jordan by Jericho, unto the water of Jericho on the east, to the wilderness that goeth up from Jericho throughout mount Beth-el,
6268	203	2	And goeth out from Beth-el to Luz, and passeth along unto the borders of Archi to Ataroth,
6269	203	3	And goeth down westward to the coast of Japhleti, unto the coast of Beth-horon the nether, and to Gezer: and the goings out thereof are at the sea.
6270	203	4	So the children of Joseph, Manasseh and Ephraim, took their inheritance.
6271	203	5	And the border of the children of Ephraim according to their families was thus: even the border of their inheritance on the east side was Ataroth-addar, unto Beth-horon the upper;
6272	203	6	And the border went out toward the sea to Michmethah on the north side; and the border went about eastward unto Taanath-shiloh, and passed by it on the east to Janohah;
6273	203	7	And it went down from Janohah to Ataroth, and to Naarath, and came to Jericho, and went out at Jordan.
6274	203	8	The border went out from Tappuah westward unto the river Kanah; and the goings out thereof were at the sea. This is the inheritance of the tribe of the children of Ephraim by their families.
6275	203	9	And the separate cities for the children of Ephraim were among the inheritance of the children of Manasseh, all the cities with their villages.
6276	203	10	And they drave not out the Canaanites that dwelt in Gezer: but the Canaanites dwell among the Ephraimites unto this day, and serve under tribute.
6277	204	1	THERE was also a lot for the tribe of Manasseh; for he was the firstborn of Joseph; to wit, for Machir the firstborn of Manasseh, the father of Gilead: because he was a man of war, therefore he had Gilead and Bashan.
6278	204	2	There was also a lot for the rest of the children of Manasseh by their families; for the children of Abiezer, and for the children of Helek, and for the children of Asriel, and for the children of Shechem, and for the children of Hepher, and for the children of Shemida: these were the male children of Manasseh the son of Joseph by their families.
6279	204	3	But Zelophehad, the son of Hepher, the son of Gilead, the son of Machir, the son of Manasseh, had no sons, but daughters: and these are the names of his daughters, Mahlah, and Noah, Hoglah, Milcah, and Tirzah.
6280	204	4	And they came near before Eleazar the priest, and before Joshua the son of Nun, and before the princes, saying, The LORD commanded Moses to give us an inheritance among our brethren. Therefore according to the commandment of the LORD he gave them an inheritance among the brethren of their father.
6281	204	5	And there fell ten portions to Manasseh, beside the land of Gilead and Bashan, which were on the other side Jordan;
6282	204	6	Because the daughters of Manasseh had an inheritance among his sons: and the rest of Manasseh's sons had the land of Gilead.
6283	204	7	And the coast of Manasseh was from Asher to Michmethah, that lieth before Shechem; and the border went along on the right hand unto the inhabitants of En-tappuah.
6284	204	8	Now Manasseh had the land of Tappuah: but Tappuah on the border of Manasseh belonged to the children of Ephraim;
6285	204	9	And the coast descended unto the river Kanah, southward of the river: these cities of Ephraim are among the cities of Manasseh: the coast of Manasseh also was on the north side of the river, and the outgoings of it were at the sea:
6286	204	10	Southward it was Ephraim's, and northward it was Manasseh's, and the sea is his border; and they met together in Asher on the north, and in Issachar on the east.
6287	204	11	And Manasseh had in Issachar and in Asher Beth-shean and her towns, and Ibleam and her towns, and the inhabitants of Dor and her towns, and the inhabitants of Endor and her towns, and the inhabitants of Taanach and her towns, and the inhabitants of Megiddo and her towns, even three countries.
6288	204	12	Yet the children of Manasseh could not drive out the inhabitants of those cities; but the Canaanites would dwell in that land.
6289	204	13	Yet it came to pass, when the children of Israel were waxen strong, that they put the Canaanites to tribute; but did not utterly drive them out.
6290	204	14	And the children of Joseph spake unto Joshua, saying, Why hast thou given me but one lot and one portion to inherit, seeing I am a great people, forasmuch as the LORD hath blessed me hitherto?
6291	204	15	And Joshua answered them, If thou be a great people, then get thee up to the wood country, and cut down for thyself there in the land of the Perizzites and of the giants, if mount Ephraim be too narrow for thee.
6292	204	16	And the children of Joseph said, The hill is not enough for us: and all the Canaanites that dwell in the land of the valley have chariots of iron, both they who are of Beth-shean and her towns, and they who are of the valley of Jezreel.
6293	204	17	And Joshua spake unto the house of Joseph, even to Ephraim and to Manasseh, saying, Thou art a great people, and hast great power: thou shalt not have one lot only:
6294	204	18	But the mountain shall be thine; for it is a wood, and thou shalt cut it down: and the outgoings of it shall be thine: for thou shalt drive out the Canaanites, though they have iron chariots, and though they be strong.
6295	205	1	AND the whole congregation of the children of Israel assembled together at Shiloh, and set up the tabernacle of the congregation there. And the land was subdued before them.
6296	205	2	And there remained among the children of Israel seven tribes, which had not yet received their inheritance.
6297	205	3	And Joshua said unto the children of Israel, How long are ye slack to go to possess the land, which the LORD God of your fathers hath given you?
6298	205	4	Give out from among you three men for each tribe: and I will send them, and they shall rise, and go through the land, and describe it according to the inheritance of them; and they shall come again to me.
6299	205	5	And they shall divide it into seven parts: Judah shall abide in their coast on the south, and the house of Joseph shall abide in their coasts on the north.
6300	205	6	Ye shall therefore describe the land into seven parts, and bring the description hither to me, that I may cast lots for you here before the LORD our God.
6301	205	7	But the Levites have no part among you; for the priesthood of the LORD is their inheritance: and Gad, and Reuben, and half the tribe of Manasseh, have received their inheritance beyond Jordan on the east, which Moses the servant of the LORD gave them.
6302	205	8	And the men arose, and went away: and Joshua charged them that went to describe the land, saying, Go and walk through the land, and describe it, and come again to me, that I may here cast lots for you before the LORD in Shiloh.
6303	205	9	And the men went and passed through the land, and described it by cities into seven parts in a book, and came again to Joshua to the host at Shiloh.
6304	205	10	And Joshua cast lots for them in Shiloh before the LORD: and there Joshua divided the land unto the children of Israel according to their divisions.
6305	205	11	And the lot of the tribe of the children of Benjamin came up according to their families: and the coast of their lot came forth between the children of Judah and the children of Joseph.
6306	205	12	And their border on the north side was from Jordan; and the border went up to the side of Jericho on the north side, and went up through the mountains westward; and the goings out thereof were at the wilderness of Beth-aven.
6307	205	13	And the border went over from thence toward Luz, to the side of Luz, which is Beth-el, southward; and the border descended to Ataroth-adar, near the hill that lieth on the south side of the nether Beth-horon.
6308	205	14	And the border was drawn thence, and compassed the corner of the sea southward, from the hill that lieth before Beth-horon southward; and the goings out thereof were at Kirjath-baal, which is Kirjath-jearim, a city of the children of Judah: this was the west quarter.
6309	205	15	And the south quarter was from the end of Kirjath-jearim, and the border went out on the west, and went out to the well of waters of Nephtoah:
6310	205	16	And the border came down to the end of the mountain that lieth before the valley of the son of Hinnom, and which is in the valley of the giants on the north, and descended to the valley of Hinnom, to the side of Jebusi on the south, and descended to En-rogel,
6311	205	17	And was drawn from the north, and went forth to En-shemesh, and went forth toward Geliloth, which is over against the going up of Adummim, and descended to the stone of Bohan the son of Reuben,
6312	205	18	And passed along toward the side over against Arabah northward, and went down unto Arabah:
6313	205	19	And the border passed along to the side of Beth-hoglah northward: and the outgoings of the border were at the north bay of the salt sea at the south end of Jordan: this was the south coast.
6314	205	20	And Jordan was the border of it on the east side. This was the inheritance of the children of Benjamin, by the coasts thereof round about, according to their families.
6315	205	21	Now the cities of the tribe of the children of Benjamin according to their families were Jericho, and Beth-hoglah, and the valley of Keziz,
6316	205	22	And Beth-arabah, and Zemaraim, and Beth-el,
6317	205	23	And Avim, and Parah, and Ophrah,
6318	205	24	And Chephar-haammonai, and Ophni, and Gaba; twelve cities with their villages:
6319	205	25	Gibeon, and Ramah, and Beeroth,
6320	205	26	And Mizpeh, and Chephirah, and Mozah,
6321	205	27	And Rekem, and Irpeel, and Taralah,
6322	205	28	And Zelah, Eleph, and Jebusi, which is Jerusalem, Gibeath, and Kirjath; fourteen cities with their villages. This is the inheritance of the children of Benjamin according to their families.
6323	206	1	AND the second lot came forth to Simeon, even for the tribe of the children of Simeon according to their families: and their inheritance was within the inheritance of the children of Judah.
6324	206	2	And they had in their inheritance Beer-sheba, or Sheba, and Moladah,
6325	206	3	And Hazar-shual, and Balah, and Azem,
6326	206	4	And Eltolad, and Bethul, and Hormah,
6327	206	5	And Ziklag, and Beth-marcaboth, and Hazar-susah,
6328	206	6	And Beth-lebaoth, and Sharuhen; thirteen cities and their villages:
6329	206	7	Ain, Remmon, and Ether, and Ashan; four cities and their villages:
6330	206	8	And all the villages that were round about these cities to Baalath-beer, Ramath of the south. This is the inheritance of the tribe of the children of Simeon according to their families.
6331	206	9	Out of the portion of the children of Judah was the inheritance of the children of Simeon: for the part of the children of Judah was too much for them: therefore the children of Simeon had their inheritance within the inheritance of them.
6332	206	10	And the third lot came up for the children of Zebulun according to their families: and the border of their inheritance was unto Sarid:
6333	206	11	And their border went up toward the sea, and Maralah, and reached to Dabbasheth, and reached to the river that is before Jokneam;
6334	206	12	And turned from Sarid eastward toward the sunrising unto the border of Chisloth-tabor, and then goeth out to Daberath, and goeth up to Japhia,
6335	206	13	And from thence passeth on along on the east to Gittah-hepher, to Ittah-kazin, and goeth out to Remmon-methoar to Neah;
6336	206	14	And the border compasseth it on the north side to Hannathon: and the outgoings thereof are in the valley of Jiphthah-el:
6337	206	15	And Kattath, and Nahallal, and Shimron, and Idalah, and Beth-lehem: twelve cities with their villages.
6338	206	16	This is the inheritance of the children of Zebulun according to their families, these cities with their villages.
6339	206	17	And the fourth lot came out to Issachar, for the children of Issachar according to their families.
6340	206	18	And their border was toward Jezreel, and Chesulloth, and Shunem,
6341	206	19	And Hapharaim, and Shion, and Anaharath,
6342	206	20	And Rabbith, and Kishion, and Abez,
6343	206	21	And Remeth, and En-gannim, and En-haddah, and Beth-pazzez;
6344	206	22	And the coast reached to Tabor, and Shahazimah, and Beth-shemesh; and the outgoings of their border were at Jordan: sixteen cities with their villages.
6345	206	23	This is the inheritance of the tribe of the children of Issachar according to their families, the cities and their villages.
6346	206	24	And the fifth lot came out for the tribe of the children of Asher according to their families.
6347	206	25	And their border was Helkath, and Hali, and Beten, and Achshaph,
6348	206	26	And Alammelech, and Amad, and Misheal; and reacheth to Carmel westward, and to Shihor-libnath;
6349	206	27	And turneth toward the sunrising to Beth-dagon, and reacheth to Zebulun, and to the valley of Jiphthah-el toward the north side of Beth-emek, and Neiel, and goeth out to Cabul on the left hand,
6350	206	28	And Hebron, and Rehob, and Hammon, and Kanah, even unto great Zidon;
6351	206	29	And then the coast turneth to Ramah, and to the strong city Tyre; and the coast turneth to Hosah; and the outgoings thereof are at the sea from the coast to Achzib:
6352	206	30	Ummah also, and Aphek, and Rehob: twenty and two cities with their villages.
6353	206	31	This is the inheritance of the tribe of the children of Asher according to their families, these cities with their villages.
6354	206	32	The sixth lot came out to the children of Naphtali, even for the children of Naphtali according to their families.
6355	206	33	And their coast was from Heleph, from Allon to Zaanannim, and Adami, Nekeb, and Jabneel, unto Lakum; and the outgoings thereof were at Jordan:
6356	206	34	And then the coast turneth westward to Aznoth-tabor, and goeth out from thence to Hukkok, and reacheth to Zebulun on the south side, and reacheth to Asher on the west side, and to Judah upon Jordan toward the sunrising.
6357	206	35	And the fenced cities are Ziddim, Zer, and Hammath, Rakkath, and Chinnereth,
6358	206	36	And Adamah, and Ramah, and Hazor,
6359	206	37	And Kedesh, and Edrei, and En-hazor,
6360	206	38	And Iron, and Migdal-el, Horem, and Beth-anath, and Beth-shemesh; nineteen cities with their villages.
6361	206	39	This is the inheritance of the tribe of the children of Naphtali according to their families, the cities and their villages.
6362	206	40	And the seventh lot came out for the tribe of the children of Dan according to their families.
6363	206	41	And the coast of their inheritance was Zorah, and Eshtaol, and Ir-shemesh,
6364	206	42	And Shaalabbin, and Ajalon, and Jethlah,
6365	206	43	And Elon, and Thimnathah, and Ekron,
6366	206	44	And Eltekeh, and Gibbethon, and Baalath,
6367	206	45	And Jehud, and Bene-berak, and Gath-rimmon,
6368	206	46	And Me-jarkon, and Rakkon, with the border before Japho.
6369	206	47	And the coast of the children of Dan went out too little for them: therefore the children of Dan went up to fight against Leshem, and took it, and smote it with the edge of the sword, and possessed it, and dwelt therein, and called Leshem, Dan, after the name of Dan their father.
6370	206	48	This is the inheritance of the tribe of the children of Dan according to their families, these cities with their villages.
6371	206	49	When they had made an end of dividing the land for inheritance by their coasts, the children of Israel gave an inheritance to Joshua the son of Nun among them:
6372	206	50	According to the word of the LORD they gave him the city which he asked, even Timnath-serah in mount Ephraim: and he built the city, and dwelt therein.
6373	206	51	These are the inheritances, which Eleazar the priest, and Joshua the son of Nun, and the heads of the fathers of the tribes of the children of Israel, divided for an inheritance by lot in Shiloh before the LORD, at the door of the tabernacle of the congregation. So they made an end of dividing the country.
6374	207	1	THE LORD also spake unto Joshua, saying,
6375	207	2	Speak to the children of Israel, saying, Appoint out for you cities of refuge, whereof I spake unto you by the hand of Moses:
6376	207	3	That the slayer that killeth any person unawares and unwittingly may flee thither: and they shall be your refuge from the avenger of blood.
6377	207	4	And when he that doth flee unto one of those cities shall stand at the entering of the gate of the city, and shall declare his cause in the ears of the elders of that city, they shall take him into the city unto them, and give him a place, that he may dwell among them.
6378	207	5	And if the avenger of blood pursue after him, then they shall not deliver the slayer up into his hand; because he smote his neighbour unwittingly, and hated him not beforetime.
6379	207	6	And he shall dwell in that city, until he stand before the congregation for judgment, and until the death of the high priest that shall be in those days: then shall the slayer return, and come unto his own city, and unto his own house, unto the city from whence he fled.
6380	207	7	And they appointed Kedesh in Galilee in mount Naphtali, and Shechem in mount Ephraim, and Kirjath-arba, which is Hebron, in the mountain of Judah.
6381	207	8	And on the other side Jordan by Jericho eastward, they assigned Bezer in the wilderness upon the plain out of the tribe of Reuben, and Ramoth in Gilead out of the tribe of Gad, and Golan in Bashan out of the tribe of Manasseh.
6382	207	9	These were the cities appointed for all the children of Israel, and for the stranger that sojourneth among them, that whosoever killeth any person at unawares might flee thither, and not die by the hand of the avenger of blood, until he stood before the congregation.
6383	208	1	THEN came near the heads of the fathers of the Levites unto Eleazar the priest, and unto Joshua the son of Nun, and unto the heads of the fathers of the tribes of the children of Israel;
6384	208	2	And they spake unto them at Shiloh in the land of Canaan, saying, The LORD commanded by the hand of Moses to give us cities to dwell in, with the suburbs thereof for our cattle.
6385	208	3	And the children of Israel gave unto the Levites out of their inheritance, at the commandment of the LORD, these cities and their suburbs.
6386	208	4	And the lot came out for the families of the Kohathites: and the children of Aaron the priest, which were of the Levites, had by lot out of the tribe of Judah, and out of the tribe of Simeon, and out of the tribe of Benjamin, thirteen cities.
6387	208	5	And the rest of the children of Kohath had by lot out of the families of the tribe of Ephraim, and out of the tribe of Dan, and out of the half tribe of Manasseh, ten cities.
6388	208	6	And the children of Gershon had by lot out of the families of the tribe of Issachar, and out of the tribe of Asher, and out of the tribe of Naphtali, and out of the half tribe of Manasseh in Bashan, thirteen cities.
6389	208	7	The children of Merari by their families had out of the tribe of Reuben, and out of the tribe of Gad, and out of the tribe of Zebulun, twelve cities.
6390	208	8	And the children of Israel gave by lot unto the Levites these cities with their suburbs, as the LORD commanded by the hand of Moses.
6391	208	9	And they gave out of the tribe of the children of Judah, and out of the tribe of the children of Simeon, these cities which are here mentioned by name,
6392	208	10	Which the children of Aaron, being of the families of the Kohathites, who were of the children of Levi, had: for theirs was the first lot.
6393	208	11	And they gave them the city of Arba the father of Anak, which city is Hebron, in the hill country of Judah, with the suburbs thereof round about it.
6394	208	12	But the fields of the city, and the villages thereof, gave they to Caleb the son of Jephunneh for his possession.
6395	208	13	Thus they gave to the children of Aaron the priest Hebron with her suburbs, to be a city of refuge for the slayer; and Libnah with her suburbs,
6396	208	14	And Jattir with her suburbs, and Eshtemoa with her suburbs,
6397	208	15	And Holon with her suburbs, and Debir with her suburbs,
6398	208	16	And Ain with her suburbs, and Juttah with her suburbs, and Beth-shemesh with her suburbs; nine cities out of those two tribes.
6399	208	17	And out of the tribe of Benjamin, Gibeon with her suburbs, Geba with her suburbs,
6400	208	18	Anathoth with her suburbs, and Almon with her suburbs; four cities.
6401	208	19	All the cities of the children of Aaron, the priests, were thirteen cities with their suburbs.
6402	208	20	And the families of the children of Kohath, the Levites which remained of the children of Kohath, even they had the cities of their lot out of the tribe of Ephraim.
6403	208	21	For they gave them Shechem with her suburbs in mount Ephraim, to be a city of refuge for the slayer; and Gezer with her suburbs,
6404	208	22	And Kibzaim with her suburbs, and Beth-horon with her suburbs; four cities.
6405	208	23	And out of the tribe of Dan, Eltekeh with her suburbs, Gibbethon with her suburbs,
6406	208	24	Aijalon with her suburbs, Gath-rimmon with her suburbs; four cities.
6407	208	25	And out of the half tribe of Manasseh, Tanach with her suburbs, and Gath-rimmon with her suburbs; two cities.
6408	208	26	All the cities were ten with their suburbs for the families of the children of Kohath that remained.
6409	208	27	And unto the children of Gershon, of the families of the Levites, out of the other half tribe of Manasseh they gave Golan in Bashan with her suburbs, to be a city of refuge for the slayer; and Beesh-terah with her suburbs; two cities.
6410	208	28	And out of the tribe of Issachar, Kishon with her suburbs, Dabareh with her suburbs,
6411	208	29	Jarmuth with her suburbs, En-gannim with her suburbs; four cities.
6412	208	30	And out of the tribe of Asher, Mishal with her suburbs, Abdon with her suburbs,
6413	208	31	Helkath with her suburbs, and Rehob with her suburbs; four cities.
6414	208	32	And out of the tribe of Naphtali, Kedesh in Galilee with her suburbs, to be a city of refuge for the slayer; and Hammoth-dor with her suburbs, and Kartan with her suburbs; three cities.
6415	208	33	All the cities of the Gershonites according to their families were thirteen cities with their suburbs.
6416	208	34	And unto the families of the children of Merari, the rest of the Levites, out of the tribe of Zebulun, Jokneam with her suburbs, and Kartah with her suburbs,
6417	208	35	Dimnah with her suburbs, Nahalal with her suburbs; four cities.
6418	208	36	And out of the tribe of Reuben, Bezer with her suburbs, and Jahazah with her suburbs,
6419	208	37	Kedemoth with her suburbs, and Mephaath with her suburbs; four cities.
6420	208	38	And out of the tribe of Gad, Ramoth in Gilead with her suburbs, to be a city of refuge for the slayer; and Mahanaim with her suburbs,
6421	208	39	Heshbon with her suburbs, Jazer with her suburbs; four cities in all.
6422	208	40	So all the cities for the children of Merari by their families, which were remaining of the families of the Levites, were by their lot twelve cities.
6423	208	41	All the cities of the Levites within the possession of the children of Israel were forty and eight cities with their suburbs.
6424	208	42	These cities were every one with their suburbs round about them: thus were all these cities.
6425	208	43	And the LORD gave unto Israel all the land which he sware to give unto their fathers; and they possessed it, and dwelt therein.
6426	208	44	And the LORD gave them rest round about, according to all that he sware unto their fathers: and there stood not a man of all their enemies before them; the LORD delivered all their enemies into their hand.
6427	208	45	There failed not ought of any good thing which the LORD had spoken unto the house of Israel; all came to pass.
6428	209	1	THEN Joshua called the Reubenites, and the Gadites, and the half tribe of Manasseh,
6429	209	2	And said unto them, Ye have kept all that Moses the servant of the LORD commanded you, and have obeyed my voice in all that I commanded you:
6430	209	3	Ye have not left your brethren these many days unto this day, but have kept the charge of the commandment of the LORD your God.
6431	209	4	And now the LORD your God hath given rest unto your brethren, as he promised them: therefore now return ye, and get you unto your tents, and unto the land of your possession, which Moses the servant of the LORD gave you on the other side Jordan.
6432	209	5	But take diligent heed to do the commandment and the law, which Moses the servant of the LORD charged you, to love the LORD your God, and to walk in all his ways, and to keep his commandments, and to cleave unto him, and to serve him with all your heart and with all your soul.
6433	209	6	So Joshua blessed them, and sent them away: and they went unto their tents.
6434	209	7	Now to the one half of the tribe of Manasseh Moses had given possession in Bashan: but unto the other half thereof gave Joshua among their brethren on this side Jordan westward. And when Joshua sent them away also unto their tents, then he blessed them,
6435	209	8	And he spake unto them, saying, Return with much riches unto your tents, and with very much cattle, with silver, and with gold, and with brass, and with iron, and with very much raiment: divide the spoil of your enemies with your brethren.
6436	209	9	And the children of Reuben and the children of Gad and the half tribe of Manasseh returned, and departed from the children of Israel out of Shiloh, which is in the land of Canaan, to go unto the country of Gilead, to the land of their possession, whereof they were possessed, according to the word of the LORD by the hand of Moses.
6437	209	10	And when they came unto the borders of Jordan, that are in the land of Canaan, the children of Reuben and the children of Gad and the half tribe of Manasseh built there an altar by Jordan, a great altar to see to.
6438	209	11	And the children of Israel heard say, Behold, the chidren of Reuben and the children of Gad and the half tribe of Manasseh have built an altar over against the land of Canaan, in the borders of Jordan, at the passage of the children of Israel.
6439	209	12	And when the children of Israel heard of it, the whole congregation of the children of Israel gathered themselves together at Shiloh, to go up to war against them.
6440	209	13	And the children of Israel sent unto the children of Reuben, and to the children of Gad, and to the half tribe of Manasseh, into the land of Gilead, Phinehas the son of Eleazar the priest,
6441	209	14	And with him ten princes, of each chief house a prince throughout all the tribes of Israel; and each one was an head of the house of their fathers among the thousands of Israel.
6442	209	15	And they came unto the children of Reuben, and to the children of Gad, and to the half tribe of Manasseh, unto the land of Gilead, and they spake with them, saying,
6443	209	16	Thus saith the whole congregation of the LORD, What trespass is this that ye have committed against the God of Israel, to turn away this day from following the LORD, in that ye have builded you an altar, that ye might rebel this day against the LORD?
6444	209	17	Is the iniquity of Peor too little for us, from which we are not cleansed until this day, although there was a plague in the congregation of the LORD,
6445	209	18	But that ye must turn away this day from following the LORD? and it will be, seeing ye rebel to day against the LORD, that to morrow he will be wroth with the whole congregation of Israel.
6446	209	19	Notwithstanding, if the land of your possession be unclean, then pass ye over unto the land of the possession of the LORD, wherein the LORD's tabernacle dwelleth, and take possession among us: but rebel not against the LORD, nor rebel against us, in building you an altar beside the altar of the LORD our God.
6447	209	20	Did not Achan the son of Zerah commit a trespass in the accursed thing, and wrath fell on all the congregation of Israel? and that man perished not alone in his iniquity.
6448	209	21	Then the children of Reuben and the children of Gad and the half tribe of Manasseh answered, and said unto the heads of the thousands of Israel,
6449	209	22	The LORD God of gods, the LORD God of gods, he knoweth, and Israel he shall know; if it be in rebellion, or if in transgression against the LORD, (save us not this day,)
6450	209	23	That we have built us an altar to turn from following the LORD, or if to offer thereon burnt offering or meat offering, or if to offer peace offerings thereon, let the LORD himself require it;
6451	209	24	And if we have not rather done it for fear of this thing, saying, In time to come your children might speak unto our children, saying, What have ye to do with the LORD God of Israel?
6452	209	25	For the LORD hath made Jordan a border between us and you, ye children of Reuben and children of Gad; ye have no part in the LORD: so shall your children make our children cease from fearing the LORD.
6453	209	26	Therefore we said, Let us now prepare to build us an altar, not for burnt offering, nor for sacrifice:
6454	209	27	But that it may be a witness between us, and you, and our generations after us, that we might do the service of the LORD before him with our burnt offerings, and with our sacrifices, and with our peace offerings; that your children may not say to our children in time to come, Ye have no part in the LORD.
6455	209	28	Therefore said we, that it shall be, when they should so say to us or to our generations in time to come, that we may say again, Behold the pattern of the altar of the LORD, which our fathers made, not for burnt offerings, nor for sacrifices; but it is a witness between us and you.
6456	209	29	God forbid that we should rebel against the LORD, and turn this day from following the LORD, to build an altar for burnt offerings, for meat offerings, or for sacrifices, beside the altar of the LORD our God that is before his tabernacle.
6457	209	30	And when Phinehas the priest, and the princes of the congregation and heads of the thousands of Israel which were with him, heard the words that the children of Reuben and the children of Gad and the children of Manasseh spake, it pleased them.
6458	209	31	And Phinehas the son of Eleazar the priest said unto the children of Reuben, and to the children of Gad, and to the children of Manasseh, This day we perceive that the LORD is among us, because ye have not committed this trespass against the LORD: now ye have delivered the children of Israel out of the hand of the LORD.
6459	209	32	And Phinehas the son of Eleazar the priest, and the princes, returned from the children of Reuben, and from the children of Gad, out of the land of Gilead, unto the land of Canaan, to the children of Israel, and brought them word again.
6460	209	33	And the thing pleased the children of Israel; and the children of Israel blessed God, and did not intend to go up against them in battle, to destroy the land wherein the children of Reuben and Gad dwelt.
6461	209	34	And the children of Reuben and the children of Gad called the altar Ed: for it shall be a witness between us that the LORD is God.
6462	210	1	AND it came to pass a long time after that the LORD had given rest unto Israel from all their enemies round about, that Joshua waxed old and stricken in age.
6463	210	2	And Joshua called for all Israel, and for their elders, and for their heads, and for their judges, and for their officers, and said unto them, I am old and stricken in age:
6464	210	3	And ye have seen all that the LORD your God hath done unto all these nations because of you; for the LORD your God is he that hath fought for you.
6465	210	4	Behold, I have divided unto you by lot these nations that remain, to be an inheritance for your tribes, from Jordan, with all the nations that I have cut off, even unto the great sea westward.
6466	210	5	And the LORD your God, he shall expel them from before you, and drive them from out of your sight; and ye shall possess their land, as the LORD your God hath promised unto you.
6467	210	6	Be ye therefore very courageous to keep and to do all that is written in the book of the law of Moses, that ye turn not aside therefrom to the right hand or to the left;
6468	210	7	That ye come not among these nations, these that remain among you; neither make mention of the name of their gods, nor cause to swear by them, neither serve them, nor bow yourselves unto them:
6469	210	8	But cleave unto the LORD your God, as ye have done unto this day.
6470	210	9	For the LORD hath driven out from before you great nations and strong: but as for you, no man hath been able to stand before you unto this day.
6471	210	10	One man of you shall chase a thousand: for the LORD your God, he it is that fighteth for you, as he hath promised you.
6472	210	11	Take good heed therefore unto yourselves, that ye love the LORD your God.
6473	210	12	Else if ye do in any wise go back, and cleave unto the remnant of these nations, even these that remain among you, and shall make marriages with them, and go in unto them, and they to you:
6474	210	13	Know for a certainty that the LORD your God will no more drive out any of these nations from before you; but they shall be snares and traps unto you, and scourges in your sides, and thorns in your eyes, until ye perish from off this good land which the LORD your God hath given you.
6475	210	14	And, behold, this day I am going the way of all the earth: and ye know in all your hearts and in all your souls, that not one thing hath failed of all the good things which the LORD your God spake concerning you; all are come to pass unto you, and not one thing hath failed thereof.
6476	210	15	Therefore it shall come to pass, that as all good things are come upon you, which the LORD your God promised you; so shall the LORD bring upon you all evil things, until he have destroyed you from off this good land which the LORD your God hath given you.
6477	210	16	When ye have transgressed the covenant of the LORD your God, which he commanded you, and have gone and served other gods, and bowed yourselves to them; then shall the anger of the LORD be kindled against you, and ye shall perish quickly from off the good land which he hath given unto you.
6478	211	1	AND Joshua gathered all the tribes of Israel to Shechem, and called for the elders of Israel, and for their heads, and for their judges, and for their officers; and they presented themselves before God.
6479	211	2	And Joshua said unto all the people, Thus saith the LORD God of Israel, Your fathers dwelt on the other side of the flood in old time, even Terah, the father of Abraham, and the father of Nachor: and they served other gods.
6480	211	3	And I took your father Abraham from the other side of the flood, and led him throughout all the land of Canaan, and multiplied his seed, and gave him Isaac.
6481	211	4	And I gave unto Isaac Jacob and Esau: and I gave unto Esau mount Seir, to possess it; but Jacob and his children went down into Egypt.
6482	211	5	I sent Moses also and Aaron, and I plagued Egypt, according to that which I did among them: and afterward I brought you out.
6483	211	6	And I brought your fathers out of Egypt: and ye came unto the sea; and the Egyptians pursued after your fathers with chariots and horsemen unto the Red sea.
6484	211	7	And when they cried unto the LORD, he put darkness between you and the Egyptians, and brought the sea upon them, and covered them; and your eyes have seen what I have done in Egypt: and ye dwelt in the wilderness a long season.
6485	211	8	And I brought you into the land of the Amorites, which dwelt on the other side Jordan; and they fought with you: and I gave them into your hand, that ye might possess their land; and I destroyed them from before you.
6486	211	9	Then Balak the son of Zippor, king of Moab, arose and warred against Israel, and sent and called Balaam the son of Beor to curse you:
6487	211	10	But I would not hearken unto Balaam; therefore he blessed you still: so I delivered you out of his hand.
6488	211	11	And ye went over Jordan, and came unto Jericho: and the men of Jericho fought against you, the Amorites, and the Perizzites, and the Canaanites, and the Hittites, and the Girgashites, the Hivites, and the Jebusites; and I delivered them into your hand.
6489	211	12	And I sent the hornet before you, which drave them out from before you, even the two kings of the Amorites; but not with thy sword, nor with thy bow.
6490	211	13	And I have given you a land for which ye did not labour, and cities which ye built not, and ye dwell in them; of the vineyards and oliveyards which ye planted not do ye eat.
6491	211	14	Now therefore fear the LORD, and serve him in sincerity and in truth: and put away the gods which your fathers served on the other side of the flood, and in Egypt; and serve ye the LORD.
6492	211	15	And if it seem evil unto you to serve the LORD, choose you this day whom ye will serve; whether the gods which your fathers served that were on the other side of the flood, or the gods of the Amorites, in whose land ye dwell: but as for me and my house, we will serve the LORD.
6493	211	16	And the people answered and said, God forbid that we should forsake the LORD, to serve other gods;
6494	211	17	For the LORD our God, he it is that brought us up and our fathers out of the land of Egypt, from the house of bondage, and which did those great signs in our sight, and preserved us in all the way wherein we went, and among all the people through whom we passed:
6495	211	18	And the LORD drave out from before us all the people, even the Amorites which dwelt in the land: therefore will we also serve the LORD; for he is our God.
6496	211	19	And Joshua said unto the people, Ye cannot serve the LORD: for he is an holy God; he is a jealous God; he will not forgive your transgressions nor your sins.
6497	211	20	If ye forsake the LORD, and serve strange gods, then he will turn and do you hurt, and consume you, after that he hath done you good.
6498	211	21	And the people said unto Joshua, Nay; but we will serve the LORD.
6499	211	22	And Joshua said unto the people, Ye are witnesses against yourselves that ye have chosen you the LORD, to serve him. And they said, We are witnesses.
6500	211	23	Now therefore put away, said he, the strange gods which are among you, and incline your heart unto the LORD God of Israel.
6501	211	24	And the people said unto Joshua, The LORD our God will we serve, and his voice will we obey.
6502	211	25	So Joshua made a covenant with the people that day, and set them a statute and an ordinance in Shechem.
6503	211	26	And Joshua wrote these words in the book of the law of God, and took a great stone, and set it up there under an oak, that was by the sanctuary of the LORD.
6504	211	27	And Joshua said unto all the people, Behold, this stone shall be a witness unto us; for it hath heard all the words of the LORD which he spake unto us: it shall be therefore a witness unto you, lest ye deny your God.
6505	211	28	So Joshua let the people depart, every man unto his inheritance.
6506	211	29	And it came to pass after these things, that Joshua the son of Nun, the servant of the LORD, died, being an hundred and ten years old.
6507	211	30	And they buried him in the border of his inheritance in Timnath-serah, which is in mount Ephraim, on the north side of the hill of Gaash.
6508	211	31	And Israel served the LORD all the days of Joshua, and all the days of the elders that overlived Joshua, and which had known all the works of the LORD, that he had done for Israel.
6509	211	32	And the bones of Joseph, which the children of Israel brought up out of Egypt, buried they in Shechem, in a parcel of ground which Jacob bought of the sons of Hamor the father of Shechem for an hundred pieces of silver: and it became the inheritance of the children of Joseph.
6510	211	33	And Eleazar the son of Aaron died; and they buried him in a hill that pertained to Phinehas his son, which was given him in mount Ephraim.
6511	212	1	NOW after the death of Joshua it came to pass, that the children of Israel asked the LORD, saying, Who shall go up for us against the Canaanites first, to fight against them?
6512	212	2	And the LORD said, Judah shall go up: behold, I have delivered the land into his hand.
6513	212	3	And Judah said unto Simeon his brother, Come up with me into my lot, that we may fight against the Canaanites; and I likewise will go with thee into thy lot. So Simeon went with him.
6514	212	4	And Judah went up; and the LORD delivered the Canaanites and the Perizzites into their hand: and they slew of them in Bezek ten thousand men.
6515	212	5	And they found Adoni-bezek in Bezek: and they fought against him, and they slew the Canaanites and the Perizzites.
6516	212	6	But Adoni-bezek fled; and they pursued after him, and caught him, and cut off his thumbs and his great toes.
6517	212	7	And Adoni-bezek said, Threescore and ten kings, having their thumbs and their great toes cut off, gathered their meat under my table: as I have done, so God hath requited me. And they brought him to Jerusalem, and there he died.
6518	212	8	Now the children of Judah had fought against Jerusalem, and had taken it, and smitten it with the edge of the sword, and set the city on fire.
6519	212	9	And afterward the children of Judah went down to fight against the Canaanites, that dwelt in the mountain, and in the south, and in the valley.
6520	212	10	And Judah went against the Canaanites that dwelt in Hebron: (now the name of Hebron before was Kirjath-arba:) and they slew Sheshai, and Ahiman, and Talmai.
6521	212	11	And from thence he went against the inhabitants of Debir: and the name of Debir before was Kirjath-sepher:
6522	212	12	And Caleb said, He that smiteth Kirjath-sepher, and taketh it, to him will I give Achsah my daughter to wife.
6523	212	13	And Othniel the son of Kenaz, Caleb's younger brother, took it: and he gave him Achsah his daughter to wife.
6524	212	14	And it came to pass, when she came to him, that she moved him to ask of her father a field: and she lighted from off her ass; and Caleb said unto her, What wilt thou?
6525	212	15	And she said unto him, Give me a blessing: for thou hast given me a south land; give me also springs of water. And Caleb gave her the upper springs and the nether springs.
6526	212	16	And the children of the Kenite, Moses' father in law, went up out of the city of palm trees with the children of Judah into the wilderness of Judah, which lieth in the south of Arad; and they went and dwelt among the people.
6527	212	17	And Judah went with Simeon his brother, and they slew the Canaanites that inhabited Zephath, and utterly destroyed it. And the name of the city was called Hormah.
6528	212	18	Also Judah took Gaza with the coast thereof, and Askelon with the coast thereof, and Ekron with the coast thereof.
6529	212	19	And the LORD was with Judah; and he drave out the inhabitants of the mountain; but could not drive out the inhabitants of the valley, because they had chariots of iron.
6530	212	20	And they gave Hebron unto Caleb, as Moses said: and he expelled thence the three sons of Anak.
6531	212	21	And the children of Benjamin did not drive out the Jebusites that inhabited Jerusalem; but the Jebusites dwell with the children of Benjamin in Jerusalem unto this day.
6532	212	22	And the house of Joseph, they also went up against Beth-el: and the LORD was with them.
6533	212	23	And the house of Joseph sent to descry Beth-el. (Now the name of the city before was Luz.)
6534	212	24	And the spies saw a man come forth out of the city, and they said unto him, Shew us, we pray thee, the entrance into the city, and we will shew thee mercy.
6535	212	25	And when he shewed them the entrance into the city, they smote the city with the edge of the sword; but they let go the man and all his family.
6536	212	26	And the man went into the land of the Hittites, and built a city, and called the name thereof Luz: which is the name thereof unto this day.
6537	212	27	Neither did Manasseh drive out the inhabitants of Beth-shean and her towns, nor Taanach and her towns, nor the inhabitants of Dor and her towns, nor the inhabitants of Ibleam and her towns, nor the inhabitants of Megiddo and her towns: but the Canaanites would dwell in that land.
6538	212	28	And it came to pass, when Israel was strong, that they put the Canaanites to tribute, and did not utterly drive them out.
6539	212	29	Neither did Ephraim drive out the Canaanites that dwelt in Gezer; but the Canaanites dwelt in Gezer among them.
6540	212	30	Neither did Zebulun drive out the inhabitants of Kitron, nor the inhabitants of Nahalol; but the Canaanites dwelt among them, and became tributaries.
6541	212	31	Neither did Asher drive out the inhabitants of Accho, nor the inhabitants of Zidon, nor of Ahlab, nor of Achzib, nor of Helbah, nor of Aphik, nor of Rehob:
6542	212	32	But the Asherites dwelt among the Canaanites, the inhabitants of the land: for they did not drive them out.
6543	212	33	Neither did Naphtali drive out the inhabitants of Beth-shemesh, nor the inhabitants of Beth-anath; but he dwelt among the Canaanites, the inhabitants of the land: nevertheless the inhabitants of Beth-shemesh and of Beth-anath became tributaries unto them.
6544	212	34	And the Amorites forced the children of Dan into the mountain: for they would not suffer them to come down to the valley:
6545	212	35	But the Amorites would dwell in mount Heres in Aijalon, and in Shaalbim: yet the hand of the house of Joseph prevailed, so that they became tributaries.
6546	212	36	And the coast of the Amorites was from the going up to Akrabbim, from the rock, and upward.
6547	213	1	AND an angel of the LORD came up from Gilgal to Bochim, and said, I made you to go up out of Egypt, and have brought you unto the land which I sware unto your fathers; and I said, I will never break my covenant with you.
6548	213	2	And ye shall make no league with the inhabitants of this land; ye shall throw down their altars: but ye have not obeyed my voice: why have ye done this?
6549	213	3	Wherefore I also said, I will not drive them out from before you; but they shall be as thorns in your sides, and their gods shall be a snare unto you.
6550	213	4	And it came to pass, when the angel of the LORD spake these words unto all the children of Israel, that the people lifted up their voice, and wept.
6551	213	5	And they called the name of that place Bochim: and they sacrificed there unto the LORD.
6552	213	6	And when Joshua had let the people go, the children of Israel went every man unto his inheritance to possess the land.
6553	213	7	And the people served the LORD all the days of Joshua, and all the days of the elders that outlived Joshua, who had seen all the great works of the LORD, that he did for Israel.
6554	213	8	And Joshua the son of Nun, the servant of the LORD, died, being an hundred and ten years old.
6555	213	9	And they buried him in the border of his inheritance in Timnath-heres, in the mount of Ephraim, on the north side of the hill Gaash.
6556	213	10	And also all that generation were gathered unto their fathers: and there arose another generation after them, which knew not the LORD, nor yet the works which he had done for Israel.
6557	213	11	And the children of Israel did evil in the sight of the LORD, and served Baalim:
6558	213	12	And they forsook the LORD God of their fathers, which brought them out of the land of Egypt, and followed other gods, of the gods of the people that were round about them, and bowed themselves unto them, and provoked the LORD to anger.
6559	213	13	And they forsook the LORD, and served Baal and Ashtaroth.
6560	213	14	And the anger of the LORD was hot against Israel, and he delivered them into the hands of spoilers that spoiled them, and he sold them into the hands of their enemies round about, so that they could not any longer stand before their enemies.
6561	213	15	Whithersoever they went out, the hand of the LORD was against them for evil, as the LORD had said, and as the LORD had sworn unto them: and they were greatly distressed.
6562	213	16	Nevertheless the LORD raised up judges, which delivered them out of the hand of those that spoiled them.
6563	213	17	And yet they would not hearken unto their judges, but they went a whoring after other gods, and bowed themselves unto them: they turned quickly out of the way which their fathers walked in, obeying the commandments of the LORD; but they did not so.
6564	213	18	And when the LORD raised them up judges, then the LORD was with the judge, and delivered them out of the hand of their enemies all the days of the judge: for it repented the LORD because of their groanings by reason of them that oppressed them and vexed them.
6565	213	19	And it came to pass, when the judge was dead, that they returned, and corrupted themselves more than their fathers, in following other gods to serve them, and to bow down unto them; they ceased not from their own doings, nor from their stubborn way.
6566	213	20	And the anger of the LORD was hot against Israel; and he said, Because that this people hath transgressed my covenant which I commanded their fathers, and have not hearkened unto my voice;
6567	213	21	I also will not henceforth drive out any from before them of the nations which Joshua left when he died:
6568	213	22	That through them I may prove Israel, whether they will keep the way of the LORD to walk therein, as their fathers did keep it, or not.
6569	213	23	Therefore the LORD left those nations, without driving them out hastily; neither delivered he them into the hand of Joshua.
6570	214	1	NOW these are the nations which the LORD left, to prove Israel by them, even as many of Israel as had not known all the wars of Canaan;
6571	214	2	Only that the generations of the children of Israel might know, to teach them war, at the least such as before knew nothing thereof;
6572	214	3	Namely, five lords of the Philistines, and all the Canaanites, and the Sidonians, and the Hivites that dwelt in mount Lebanon, from mount Baal-hermon unto the entering in of Hamath.
6573	214	4	And they were to prove Israel by them, to know whether they would hearken unto the commandments of the LORD, which he commanded their fathers by the hand of Moses.
6574	214	5	And the children of Israel dwelt among the Canaanites, Hittites, and Amorites, and Perizzites, and Hivites, and Jebusites:
6575	214	6	And they took their daughters to be their wives, and gave their daughters to their sons, and served their gods.
6576	214	7	And the children of Israel did evil in the sight of the LORD, and forgat the LORD their God, and served Baalim and the groves.
6577	214	8	Therefore the anger of the LORD was hot against Israel, and he sold them into the hand of Chushan-rishathaim king of Mesopotamia: and the children of Israel served Chushan-rishathaim eight years.
6578	214	9	And when the children of Israel cried unto the LORD, the LORD raised up a deliverer to the children of Israel, who delivered them, even Othniel the son of Kenaz, Caleb's younger brother.
6579	214	10	And the Spirit of the LORD came upon him, and he judged Israel, and went out to war: and the LORD delivered Chushan-rishathaim king of Mesopotamia into his hand; and his hand prevailed against Chushan-rishathaim.
6580	214	11	And the land had rest forty years. And Othniel the son of Kenaz died.
6581	214	12	And the children of Israel did evil again in the sight of the LORD: and the LORD strengthened Eglon the king of Moab against Israel, because they had done evil in the sight of the LORD.
6582	214	13	And he gathered unto him the children of Ammon and Amalek, and went and smote Israel, and possessed the city of palm trees.
6583	214	14	So the children of Israel served Eglon the king of Moab eighteen years.
6584	214	15	But when the children of Israel cried unto the LORD, the LORD raised them up a deliverer, Ehud the son of Gera, a Benjamite, a man lefthanded: and by him the children of Israel sent a present unto Eglon the king of Moab.
6585	214	16	But Ehud made him a dagger which had two edges, of a cubit length; and he did gird it under his raiment upon his right thigh.
6586	214	17	And he brought the present unto Eglon king of Moab: and Eglon was a very fat man.
6587	214	18	And when he had made an end to offer the present, he sent away the people that bare the present.
6588	214	19	But he himself turned again from the quarries that were by Gilgal, and said, I have a secret errand unto thee, O king: who said, Keep silence. And all that stood by him went out from him.
6589	214	20	And Ehud came unto him; and he was sitting in a summer parlour, which he had for himself alone. And Ehud said, I have a message from God unto thee. And he arose out of his seat.
6590	214	21	And Ehud put forth his left hand, and took the dagger from his right thigh, and thrust it into his belly:
6591	214	22	And the haft also went in after the blade; and the fat closed upon the blade, so that he could not draw the dagger out of his belly; and the dirt came out.
6592	214	23	Then Ehud went forth through the porch, and shut the doors of the parlour upon him, and locked them.
6593	214	24	When he was gone out, his servants came; and when they saw that, behold, the doors of the parlour were locked, they said, Surely he covereth his feet in his summer chamber.
6594	214	25	And they tarried till they were ashamed: and, behold, he opened not the doors of the parlour; therefore they took a key, and opened them: and, behold, their lord was fallen down dead on the earth.
6595	214	26	And Ehud escaped while they tarried, and passed beyond the quarries, and escaped unto Seirath.
6596	214	27	And it came to pass, when he was come, that he blew a trumpet in the mountain of Ephraim, and the children of Israel went down with him from the mount, and he before them.
6597	214	28	And he said unto them, Follow after me: for the LORD hath delivered your enemies the Moabites into your hand. And they went down after him, and took the fords of Jordan toward Moab, and suffered not a man to pass over.
6598	214	29	And they slew of Moab at that time about ten thousand men, all lusty, and all men of valour; and there escaped not a man.
6599	214	30	So Moab was subdued that day under the hand of Israel. And the land had rest fourscore years.
6600	214	31	And after him was Shamgar the son of Anath, which slew of the Philistines six hundred men with an ox goad: and he also delivered Israel.
6601	215	1	AND the children of Israel again did evil in the sight of the LORD, when Ehud was dead.
6602	215	2	And the LORD sold them into the hand of Jabin king of Canaan, that reigned in Hazor; the captain of whose host was Sisera, which dwelt in Harosheth of the Gentiles.
6603	215	3	And the children of Israel cried unto the LORD: for he had nine hundred chariots of iron; and twenty years he mightily oppressed the children of Israel.
6604	215	4	And Deborah, a prophetess, the wife of Lapidoth, she judged Israel at that time.
6605	215	5	And she dwelt under the palm tree of Deborah between Ramah and Beth-el in mount Ephraim: and the children of Israel came up to her for judgment.
6606	215	6	And she sent and called Barak the son of Abinoam out of Kedesh-naphtali, and said unto him, Hath not the LORD God of Israel commanded, saying, Go and draw toward mount Tabor, and take with thee ten thousand men of the children of Naphtali and of the children of Zebulun?
6607	215	7	And I will draw unto thee to the river Kishon Sisera, the captain of Jabin's army, with his chariots and his multitude; and I will deliver him into thine hand.
6608	215	8	And Barak said unto her, If thou wilt go with me, then I will go: but if thou wilt not go with me, then I will not go.
6609	215	9	And she said, I will surely go with thee: notwithstanding the journey that thou takest shall not be for thine honour; for the LORD shall sell Sisera into the hand of a woman. And Deborah arose, and went with Barak to Kedesh.
6610	215	10	And Barak called Zebulun and Naphtali to Kedesh; and he went up with ten thousand men at his feet: and Deborah went up with him.
6611	215	11	Now Heber the Kenite, which was of the children of Hobab the father in law of Moses, had severed himself from the Kenites, and pitched his tent unto the plain of Zaanaim, which is by Kedesh.
6612	215	12	And they shewed Sisera that Barak the son of Abinoam was gone up to mount Tabor.
6613	215	13	And Sisera gathered together all his chariots, even nine hundred chariots of iron, and all the people that were with him, from Harosheth of the Gentiles unto the river of Kishon.
6614	215	14	And Deborah said unto Barak, Up; for this is the day in which the LORD hath delivered Sisera into thine hand: is not the LORD gone out before thee? So Barak went down from mount Tabor, and ten thousand men after him.
6615	215	15	And the LORD discomfited Sisera, and all his chariots, and all his host, with the edge of the sword before Barak; so that Sisera lighted down off his chariot, and fled away on his feet.
6616	215	16	But Barak pursued after the chariots, and after the host, unto Harosheth of the Gentiles: and all the host of Sisera fell upon the edge of the sword; and there was not a man left.
6617	215	17	Howbeit Sisera fled away on his feet to the tent of Jael the wife of Heber the Kenite: for there was peace between Jabin the king of Hazor and the house of Heber the Kenite.
6618	215	18	And Jael went out to meet Sisera, and said unto him, Turn in, my lord, turn in to me; fear not. And when he had turned in unto her into the tent, she covered him with a mantle.
6619	215	19	And he said unto her, Give me, I pray thee, a little water to drink; for I am thirsty. And she opened a bottle of milk, and gave him drink, and covered him.
6620	215	20	Again he said unto her, Stand in the door of the tent, and it shall be, when any man doth come and inquire of thee, and say, Is there any man here? that thou shalt say, No.
6621	215	21	Then Jael Heber's wife took a nail of the tent, and took an hammer in her hand, and went softly unto him, and smote the nail into his temples, and fastened it into the ground: for he was fast asleep and weary. So he died.
6622	215	22	And, behold, as Barak pursued Sisera, Jael came out to meet him, and said unto him, Come, and I will shew thee the man whom thou seekest. And when he came into her tent, behold, Sisera lay dead, and the nail was in his temples.
6623	215	23	So God subdued on that day Jabin the king of Canaan before the children of Israel.
6624	215	24	And the hand of the children of Israel prospered, and prevailed against Jabin the king of Canaan, until they had destroyed Jabin king of Canaan.
6625	216	1	THEN sang Deborah and Barak the son of Abinoam on that day, saying,
6626	216	2	Praise ye the LORD for the avenging of Israel, when the people willingly offered themselves.
6627	216	3	Hear, O ye kings; give ear, O ye princes; I, even I, will sing unto the LORD; I will sing praise to the LORD God of Israel.
6628	216	4	LORD, when thou wentest out of Seir, when thou marchedst out of the field of Edom, the earth trembled, and the heavens dropped, the clouds also dropped water.
6629	216	5	The mountains melted from before the LORD, even that Sinai from before the LORD God of Israel.
6630	216	6	In the days of Shamgar the son of Anath, in the days of Jael, the highways were unoccupied, and the travellers walked through byways.
6631	216	7	The inhabitants of the villages ceased, they ceased in Israel, until that I Deborah arose, that I arose a mother in Israel.
6632	216	8	They chose new gods; then was war in the gates: was there a shield or spear seen among forty thousand in Israel?
6633	216	9	My heart is toward the governors of Israel, that offered themselves willingly among the people. Bless ye the LORD.
6634	216	10	Speak, ye that ride on white asses, ye that sit in judgment, and walk by the way.
6635	216	11	They that are delivered from the noise of archers in the places of drawing water, there shall they rehearse the righteous acts of the LORD, even the righteous acts toward the inhabitants of his villages in Israel: then shall the people of the LORD go down to the gates.
6636	216	12	Awake, awake, Deborah: awake, awake, utter a song: arise, Barak, and lead thy captivity captive, thou son of Abinoam.
6637	216	13	Then he made him that remaineth have dominion over the nobles among the people: the LORD made me have dominion over the mighty.
6638	216	14	Out of Ephraim was there a root of them against Amalek; after thee, Benjamin, among thy people; out of Machir came down governors, and out of Zebulun they that handle the pen of the writer.
6639	216	15	And the princes of Issachar were with Deborah; even Issachar, and also Barak: he was sent on foot into the valley. For the divisions of Reuben there were great thoughts of heart.
6640	216	16	Why abodest thou among the sheepfolds, to hear the bleatings of the flocks? For the divisions of Reuben there were great searchings of heart.
6641	216	17	Gilead abode beyond Jordan: and why did Dan remain in ships? Asher continued on the sea shore, and abode in his breaches.
6642	216	18	Zebulun and Naphtali were a people that jeoparded their lives unto the death in the high places of the field.
6643	216	19	The kings came and fought, then fought the kings of Canaan in Taanach by the waters of Megiddo; they took no gain of money.
6644	216	20	They fought from heaven; the stars in their courses fought against Sisera.
6645	216	21	The river of Kishon swept them away, that ancient river, the river Kishon. O my soul, thou hast trodden down strength.
6646	216	22	Then were the horsehoofs broken by the means of the pransings, the pransings of their mighty ones.
6647	216	23	Curse ye Meroz, said the angel of the LORD, curse ye bitterly the inhabitants thereof; because they came not to the help of the LORD, to the help of the LORD against the mighty.
6648	216	24	Blessed above women shall Jael the wife of Heber the Kenite be, blessed shall she be above women in the tent.
6649	216	25	He asked water, and she gave him milk; she brought forth butter in a lordly dish.
6650	216	26	She put her hand to the nail, and her right hand to the workmen's hammer; and with the hammer she smote Sisera, she smote off his head, when she had pierced and stricken through his temples.
6651	216	27	At her feet he bowed, he fell, he lay down: at her feet he bowed, he fell: where he bowed, there he fell down dead.
6652	216	28	The mother of Sisera looked out at a window, and cried through the lattice, Why is his chariot so long in coming? why tarry the wheels of his chariots?
6653	216	29	Her wise ladies answered her, yea, she returned answer to herself,
6654	216	30	Have they not sped? have they not divided the prey; to every man a damsel or two; to Sisera a prey of divers colours, a prey of divers colours of needlework, of divers colours of needlework on both sides, meet for the necks of them that take the spoil?
6655	216	31	So let all thine enemies perish, O LORD: but let them that love him be as the sun when he goeth forth in his might. And the land had rest forty years.
6656	217	1	AND the children of Israel did evil in the sight of the LORD: and the LORD delivered them into the hand of Midian seven years.
6657	217	2	And the hand of Midian prevailed against Israel: and because of the Midianites the children of Israel made them the dens which are in the mountains, and caves, and strong holds.
6658	217	3	And so it was, when Israel had sown, that the Midianites came up, and the Amalekites, and the children of the east, even they came up against them;
6659	217	4	And they encamped against them, and destroyed the increase of the earth, till thou come unto Gaza, and left no sustenance for Israel, neither sheep, nor ox, nor ass.
6660	217	5	For they came up with their cattle and their tents, and they came as grasshoppers for multitude; for both they and their camels were without number: and they entered into the land to destroy it.
6661	217	6	And Israel was greatly impoverished because of the Midianites; and the children of Israel cried unto the LORD.
6662	217	7	And it came to pass, when the children of Israel cried unto the LORD because of the Midianites,
6663	217	8	That the LORD sent a prophet unto the children of Israel, which said unto them, Thus saith the LORD God of Israel, I brought you up from Egypt, and brought you forth out of the house of bondage;
6664	217	9	And I delivered you out of the hand of the Egyptians, and out of the hand of all that oppressed you, and drave them out from before you, and gave you their land;
6665	217	10	And I said unto you, I am the LORD your God; fear not the gods of the Amorites, in whose land ye dwell: but ye have not obeyed my voice.
6666	217	11	And there came an angel of the LORD, and sat under an oak which was in Ophrah, that pertained unto Joash the Abi-ezrite: and his son Gideon threshed wheat by the winepress, to hide it from the Midianites.
6667	217	12	And the angel of the LORD appeared unto him, and said unto him, The LORD is with thee, thou mighty man of valour.
6668	217	13	And Gideon said unto him, Oh my Lord, if the LORD be with us, why then is all this befallen us? and where be all his miracles which our fathers told us of, saying, Did not the LORD bring us up from Egypt? but now the LORD hath forsaken us, and delivered us into the hands of the Midianites.
6669	217	14	And the LORD looked upon him, and said, Go in this thy might, and thou shalt save Israel from the hand of the Midianites: have not I sent thee?
6670	217	15	And he said unto him, Oh my Lord, wherewith shall I save Israel? behold, my family is poor in Manasseh, and I am the least in my father's house.
6671	217	16	And the LORD said unto him, Surely I will be with thee, and thou shalt smite the Midianites as one man.
6672	217	17	And he said unto him, If now I have found grace in thy sight, then shew me a sign that thou talkest with me.
6673	217	18	Depart not hence, I pray thee, until I come unto thee, and bring forth my present, and set it before thee. And he said, I will tarry until thou come again.
6674	217	19	And Gideon went in, and made ready a kid, and unleavened cakes of an ephah of flour: the flesh he put in a basket, and he put the broth in a pot, and brought it out unto him under the oak, and presented it.
6675	217	20	And the angel of God said unto him, Take the flesh and the unleavened cakes, and lay them upon this rock, and pour out the broth. And he did so.
6676	217	21	Then the angel of the LORD put forth the end of the staff that was in his hand, and touched the flesh and the unleavened cakes; and there rose up fire out of the rock, and consumed the flesh and the unleavened cakes. Then the angel of the LORD departed out of his sight.
6677	217	22	And when Gideon perceived that he was an angel of the LORD, Gideon said, Alas, O Lord GOD! for because I have seen an angel of the LORD face to face.
6678	217	23	And the LORD said unto him, Peace be unto thee; fear not: thou shalt not die.
6679	217	24	Then Gideon built an altar there unto the LORD, and called it Jehovah-shalom: unto this day it is yet in Ophrah of the Abi-ezrites.
6680	217	25	And it came to pass the same night, that the LORD said unto him, Take thy father's young bullock, even the second bullock of seven years old, and throw down the altar of Baal that thy father hath, and cut down the grove that is by it:
6681	217	26	And build an altar unto the LORD thy God upon the top of this rock, in the ordered place, and take the second bullock, and offer a burnt sacrifice with the wood of the grove which thou shalt cut down.
6682	217	27	Then Gideon took ten men of his servants, and did as the LORD had said unto him: and so it was, because he feared his father's household, and the men of the city, that he could not do it by day, that he did it by night.
6683	217	28	And when the men of the city arose early in the morning, behold, the altar of Baal was cast down, and the grove was cut down that was by it, and the second bullock was offered upon the altar that was built.
6684	217	29	And they said one to another, Who hath done this thing? And when they enquired and asked, they said, Gideon the son of Joash hath done this thing.
6685	217	30	Then the men of the city said unto Joash, Bring out thy son, that he may die: because he hath cast down the altar of Baal, and because he hath cut down the grove that was by it.
6686	217	31	And Joash said unto all that stood against him, Will ye plead for Baal? will ye save him? he that will plead for him, let him be put to death whilst it is yet morning: if he be a god, let him plead for himself, because one hath cast down his altar.
6687	217	32	Therefore on that day he called him Jerubbaal, saying, Let Baal plead against him, because he hath thrown down his altar.
6688	217	33	Then all the Midianites and the Amalekites and the children of the east were gathered together, and went over, and pitched in the valley of Jezreel.
6689	217	34	But the Spirit of the LORD came upon Gideon, and he blew a trumpet; and Abi-ezer was gathered after him.
6690	217	35	And he sent messengers throughout all Manasseh; who also was gathered after him: and he sent messengers unto Asher, and unto Zebulun, and unto Naphtali; and they came up to meet them.
6691	217	36	And Gideon said unto God, If thou wilt save Israel by mine hand, as thou hast said,
6692	217	37	Behold, I will put a fleece of wool in the floor; and if the dew be on the fleece only, and it be dry upon all the earth beside, then shall I know that thou wilt save Israel by mine hand, as thou hast said.
6693	217	38	And it was so: for he rose up early on the morrow, and thrust the fleece together, and wringed the dew out of the fleece, a bowl full of water.
6694	217	39	And Gideon said unto God, Let not thine anger be hot against me, and I will speak but this once: let me prove, I pray thee, but this once with the fleece; let it now be dry only upon the fleece, and upon all the ground let there be dew.
6695	217	40	And God did so that night: for it was dry upon the fleece only, and there was dew on all the ground.
6696	218	1	THEN Jerubbaal, who is Gideon, and all the people that were with him, rose up early, and pitched beside the well of Harod: so that the host of the Midianites were on the north side of them, by the hill of Moreh, in the valley.
6697	218	2	And the LORD said unto Gideon, The people that are with thee are too many for me to give the Midianites into their hands, lest Israel vaunt themselves against me, saying, Mine own hand hath saved me.
6698	218	3	Now therefore go to, proclaim in the ears of the people, saying, Whosoever is fearful and afraid, let him return and depart early from mount Gilead. And there returned of the people twenty and two thousand; and there remained ten thousand.
6699	218	4	And the LORD said unto Gideon, The people are yet too many; bring them down unto the water, and I will try them for thee there: and it shall be, that of whom I say unto thee, This shall go with thee, the same shall go with thee; and of whomsoever I say unto thee, This shall not go with thee, the same shall not go.
6700	218	5	So he brought down the people unto the water: and the LORD said unto Gideon, Every one that lappeth of the water with his tongue, as a dog lappeth, him shalt thou set by himself; likewise every one that boweth down upon his knees to drink.
6701	218	6	And the number of them that lapped, putting their hand to their mouth, were three hundred men: but all the rest of the people bowed down upon their knees to drink water.
6702	218	7	And the LORD said unto Gideon, By the three hundred men that lapped will I save you, and deliver the Midianites into thine hand: and let all the other people go every man unto his place.
6703	218	8	So the people took victuals in their hand, and their trumpets: and he sent all the rest of Israel every man unto his tent, and retained those three hundred men: and the host of Midian was beneath him in the valley.
6704	218	9	And it came to pass the same night, that the LORD said unto him, Arise, get thee down unto the host; for I have delivered it into thine hand.
6705	218	10	But if thou fear to go down, go thou with Phurah thy servant down to the host:
6706	218	11	And thou shalt hear what they say; and afterward shall thine hands be strengthened to go down unto the host. Then went he down with Phurah his servant unto the outside of the armed men that were in the host.
6707	218	12	And the Midianites and the Amalekites and all the children of the east lay along in the valley like grasshoppers for multitude; and their camels were without number, as the sand by the sea side for multitude.
6708	218	13	And when Gideon was come, behold, there was a man that told a dream unto his fellow, and said, Behold, I dreamed a dream, and, lo, a cake of barley bread tumbled into the host of Midian, and came unto a tent, and smote it that it fell, and overturned it, that the tent lay along.
6709	218	14	And his fellow answered and said, This is nothing else save the sword of Gideon the son of Joash, a man of Israel: for into his hand hath God delivered Midian, and all the host.
6710	218	15	And it was so, when Gideon heard the telling of the dream, and the interpretation thereof, that he worshipped, and returned into the host of Israel, and said, Arise; for the LORD hath delivered into your hand the host of Midian.
6711	218	16	And he divided the three hundred men into three companies, and he put a trumpet in every man's hand, with empty pitchers, and lamps within the pitchers.
6712	218	17	And he said unto them, Look on me, and do likewise: and, behold, when I come to the outside of the camp, it shall be that, as I do, so shall ye do.
6713	218	18	When I blow with a trumpet, I and all that are with me, then blow ye the trumpets also on every side of all the camp, and say, The sword of the LORD, and of Gideon.
6714	218	19	So Gideon, and the hundred men that were with him, came unto the outside of the camp in the beginning of the middle watch; and they had but newly set the watch: and they blew the trumpets, and brake the pitchers that were in their hands.
6715	218	20	And the three companies blew the trumpets, and brake the pitchers, and held the lamps in their left hands, and the trumpets in their right hands to blow withal: and they cried, The sword of the LORD, and of Gideon.
6716	218	21	And they stood every man in his place round about the camp: and all the host ran, and cried, and fled.
6717	218	22	And the three hundred blew the trumpets, and the LORD set every man's sword against his fellow, even throughout all the host: and the host fled to Beth-shittah in Zererath, and to the border of Abel-meholah, unto Tabbath.
6718	218	23	And the men of Israel gathered themselves together out of Naphtali, and out of Asher, and out of all Manasseh, and pursued after the Midianites.
6719	218	24	And Gideon sent messengers throughout all mount Ephraim, saying, Come down against the Midianites, and take before them the waters unto Beth-barah and Jordan. Then all the men of Ephraim gathered themselves together, and took the waters unto Beth-barah and Jordan.
6720	218	25	And they took two princes of the Midianites, Oreb and Zeeb; and they slew Oreb upon the rock Oreb, and Zeeb they slew at the winepress of Zeeb, and pursued Midian, and brought the heads of Oreb and Zeeb to Gideon on the other side Jordan.
6721	219	1	AND the men of Ephraim said unto him, Why hast thou served us thus, that thou calledst us not, when thou wentest to fight with the Midianites? And they did chide with him sharply.
6722	219	2	And he said unto them, What have I done now in comparison of you? Is not the gleaning of the grapes of Ephraim better than the vintage of Abi-ezer?
6723	219	3	God hath delivered into your hands the princes of Midian, Oreb and Zeeb: and what was I able to do in comparison of you? Then their anger was abated toward him, when he had said that.
6724	219	4	And Gideon came to Jordan, and passed over, he, and the three hundred men that were with him, faint, yet pursuing them.
6725	219	5	And he said unto the men of Succoth, Give, I pray you, loaves of bread unto the people that follow me; for they be faint, and I am pursuing after Zebah and Zalmunna, kings of Midian.
6726	219	6	And the princes of Succoth said, Are the hands of Zebah and Zalmunna now in thine hand, that we should give bread unto thine army?
6727	219	7	And Gideon said, Therefore when the LORD hath delivered Zebah and Zalmunna into mine hand, then I will tear your flesh with the thorns of the wilderness and with briers.
6728	219	8	And he went up thence to Penuel, and spake unto them likewise: and the men of Penuel answered him as the men of Succoth had answered him.
6729	219	9	And he spake also unto the men of Penuel, saying, When I come again in peace, I will break down this tower.
6730	219	10	Now Zebah and Zalmunna were in Karkor, and their hosts with them, about fifteen thousand men, all that were left of all the hosts of the children of the east: for there fell an hundred and twenty thousand men that drew sword.
6731	219	11	And Gideon went up by the way of them that dwelt in tents on the east of Nobah and Jogbehah, and smote the host: for the host was secure.
6732	219	12	And when Zebah and Zalmunna fled, he pursued after them, and took the two kings of Midian, Zebah and Zalmunna, and discomfited all the host.
6733	219	13	And Gideon the son of Joash returned from battle before the sun was up.
6734	219	14	And caught a young man of the men of Succoth, and enquired of him: and he described unto him the princes of Succoth, and the elders thereof, even threescore and seventeen men.
6735	219	15	And he came unto the men of Succoth, and said, Behold Zebah and Zalmunna, with whom ye did upbraid me, saying, Are the hands of Zebah and Zalmunna now in thine hand, that we should give bread unto thy men that are weary?
6736	219	16	And he took the elders of the city, and thorns of the wilderness and briers, and with them he taught the men of Succoth.
6737	219	17	And he beat down the tower of Penuel, and slew the men of the city.
6738	219	18	Then said he unto Zebah and Zalmunna, What manner of men were they whom ye slew at Tabor? And they answered, As thou art, so were they; each one resembled the children of a king.
6739	219	19	And he said, They were my brethren, even the sons of my mother: as the LORD liveth, if ye had saved them alive, I would not slay you.
6740	219	20	And he said unto Jether his firstborn, Up, and slay them. But the youth drew not his sword: for he feared, because he was yet a youth.
6741	219	21	Then Zebah and Zalmunna said, Rise thou, and fall upon us: for as the man is, so is his strength. And Gideon arose, and slew Zebah and Zalmunna, and took away the ornaments that were on their camels' necks.
6742	219	22	Then the men of Israel said unto Gideon, Rule thou over us, both thou, and thy son, and thy son's son also: for thou hast delivered us from the hand of Midian.
6743	219	23	And Gideon said unto them, I will not rule over you, neither shall my son rule over you: the LORD shall rule over you.
6744	219	24	And Gideon said unto them, I would desire a request of you, that ye would give me every man the earrings of his prey. (For they had golden earrings, because they were Ishmaelites.)
6745	219	25	And they answered, We will willingly give them. And they spread a garment, and did cast therein every man the earrings of his prey.
6746	219	26	And the weight of the golden earrings that he requested was a thousand and seven hundred shekels of gold; beside ornaments, and collars, and purple raiment that was on the kings of Midian, and beside the chains that were about their camels' necks.
6747	219	27	And Gideon made an ephod thereof, and put it in his city, even in Ophrah: and all Israel went thither a whoring after it: which thing became a snare unto Gideon, and to his house.
6748	219	28	Thus was Midian subdued before the children of Israel, so that they lifted up their heads no more. And the country was in quietness forty years in the days of Gideon.
6749	219	29	And Jerubbaal the son of Joash went and dwelt in his own house.
6750	219	30	And Gideon had threescore and ten sons of his body begotten: for he had many wives.
6751	219	31	And his concubine that was in Shechem, she also bare him a son, whose name he called Abimelech.
6752	219	32	And Gideon the son of Joash died in a good old age, and was buried in the sepulchre of Joash his father, in Ophrah of the Abi-ezrites.
6753	219	33	And it came to pass, as soon as Gideon was dead, that the children of Israel turned again, and went a whoring after Baalim, and made Baal-berith their god.
6754	219	34	And the children of Israel remembered not the LORD their God, who had delivered them out of the hands of all their enemies on every side:
6755	219	35	Neither shewed they kindness to the house of Jerubbaal, namely, Gideon, according to all the goodness which he had shewed unto Israel.
6756	220	1	AND Abimelech the son of Jerubbaal went to Shechem unto his mother's brethren, and communed with them, and with all the family of the house of his mother's father, saying,
6757	220	2	Speak, I pray you, in the ears of all the men of Shechem, Whether is better for you, either that all the sons of Jerubbaal, which are threescore and ten persons, reign over you, or that one reign over you? remember also that I am your bone and your flesh.
6758	220	3	And his mother's brethren spake of him in the ears of all the men of Shechem all these words: and their hearts inclined to follow Abimelech; for they said, He is our brother.
6759	220	4	And they gave him threescore and ten pieces of silver out of the house of Baal-berith, wherewith Abimelech hired vain and light persons, which followed him.
6760	220	5	And he went unto his father's house at Ophrah, and slew his brethren the sons of Jerubbaal, being threescore and ten persons, upon one stone: notwithstanding yet Jotham the youngest son of Jerubbaal was left; for he hid himself.
6761	220	6	And all the men of Shechem gathered together, and all the house of Millo, and went, and made Abimelech king, by the plain of the pillar that was in Shechem.
6762	220	7	And when they told it to Jotham, he went and stood in the top of mount Gerizim, and lifted up his voice, and cried, and said unto them, Hearken unto me, ye men of Shechem, that God may hearken unto you.
6763	220	8	The trees went forth on a time to anoint a king over them; and they said unto the olive tree, Reign thou over us.
6764	220	9	But the olive tree said unto them, Should I leave my fatness, wherewith by me they honour God and man, and go to be promoted over the trees?
6765	220	10	And the trees said to the fig tree, Come thou, and reign over us.
6766	220	11	But the fig tree said unto them, Should I forsake my sweetness, and my good fruit, and go to be promoted over the trees?
6767	220	12	Then said the trees unto the vine, Come thou, and reign over us.
6768	220	13	And the vine said unto them, Should I leave my wine, which cheereth God and man, and go to be promoted over the trees?
6769	220	14	Then said all the trees unto the bramble, Come thou, and reign over us.
6770	220	15	And the bramble said unto the trees, If in truth ye anoint me king over you, then come and put your trust in my shadow: and if not, let fire come out of the bramble, and devour the cedars of Lebanon.
6771	220	16	Now therefore, if ye have done truly and sincerely, in that ye have made Abimelech king, and if ye have dealt well with Jerubbaal and his house, and have done unto him according to the deserving of his hands;
6772	220	17	(For my father fought for you, and adventured his life far, and delivered you out of the hand of Midian:
6773	220	18	And ye are risen up against my father's house this day, and have slain his sons, threescore and ten persons, upon one stone, and have made Abimelech, the son of his maidservant, king over the men of Shechem, because he is your brother;)
6774	220	19	If ye then have dealt truly and sincerely with Jerubbaal and with his house this day, then rejoice ye in Abimelech, and let him also rejoice in you:
6775	220	20	But if not, let fire come out from Abimelech, and devour the men of Shechem, and the house of Millo; and let fire come out from the men of Shechem, and from the house of Millo, and devour Abimelech.
6776	220	21	And Jotham ran away, and fled, and went to Beer, and dwelt there, for fear of Abimelech his brother.
6777	220	22	When Abimelech had reigned three years over Israel,
6778	220	23	Then God sent an evil spirit between Abimelech and the men of Shechem; and the men of Shechem dealt treacherously with Abimelech:
6779	220	24	That the cruelty done to the threescore and ten sons of Jerubbaal might come, and their blood be laid upon Abimelech their brother, which slew them; and upon the men of Shechem, which aided him in the killing of his brethren.
6780	220	25	And the men of Shechem set liers in wait for him in the top of the mountains, and they robbed all that came along that way by them: and it was told Abimelech.
6781	220	26	And Gaal the son of Ebed came with his brethren, and went over to Shechem: and the men of Shechem put their confidence in him.
6782	220	27	And they went out into the fields, and gathered their vineyards, and trode the grapes, and made merry, and went into the house of their god, and did eat and drink, and cursed Abimelech.
6783	220	28	And Gaal the son of Ebed said, Who is Abimelech, and who is Shechem, that we should serve him? is not he the son of Jerubbaal? and Zebul his officer? serve the men of Hamor the father of Shechem: for why should we serve him?
6784	220	29	And would to God this people were under my hand! then would I remove Abimelech. And he said to Abimelech, Increase thine army, and come out.
6785	220	30	And when Zebul the ruler of the city heard the words of Gaal the son of Ebed, his anger was kindled.
6786	220	31	And he sent messengers unto Abimelech privily, saying, Behold, Gaal the son of Ebed and his brethren be come to Shechem; and, behold, they fortify the city against thee.
6787	220	32	Now therefore up by night, thou and the people that is with thee, and lie in wait in the field:
6788	220	33	And it shall be, that in the morning, as soon as the sun is up, thou shalt rise early, and set upon the city: and, behold, when he and the people that is with him come out against thee, then mayest thou do to them as thou shalt find occasion.
6789	220	34	And Abimelech rose up, and all the people that were with him, by night, and they laid wait against Shechem in four companies.
6790	220	35	And Gaal the son of Ebed went out, and stood in the entering of the gate of the city: and Abimelech rose up, and the people that were with him, from lying in wait.
6791	220	36	And when Gaal saw the people, he said to Zebul, Behold, there come people down from the top of the mountains. And Zebul said unto him, Thou seest the shadow of the mountains as if they were men.
6792	220	37	And Gaal spake again and said, See there come people down by the middle of the land, and another company come along by the plain of Meonenim.
6793	220	38	Then said Zebul unto him, Where is now thy mouth, wherewith thou saidst, Who is Abimelech, that we should serve him? is not this the people that thou hast despised? go out, I pray now, and fight with them.
6794	220	39	And Gaal went out before the men of Shechem, and fought with Abimelech.
6795	220	40	And Abimelech chased him, and he fled before him, and many were overthrown and wounded, even unto the entering of the gate.
6796	220	41	And Abimelech dwelt at Arumah: and Zebul thrust out Gaal and his brethren, that they should not dwell in Shechem.
6797	220	42	And it came to pass on the morrow, that the people went out into the field; and they told Abimelech.
6798	220	43	And he took the people, and divided them into three companies, and laid wait in the field, and looked, and, behold, the people were come forth out of the city; and he rose up against them, and smote them.
6799	220	44	And Abimelech, and the company that was with him, rushed forward, and stood in the entering of the gate of the city: and the two other companies ran upon all the people that were in the fields, and slew them.
6800	220	45	And Abimelech fought against the city all that day; and he took the city, and slew the people that was therein, and beat down the city, and sowed it with salt.
6801	220	46	And when all the men of the tower of Shechem heard that, they entered into an hold of the house of the god Berith.
6802	220	47	And it was told Abimelech, that all the men of the tower of Shechem were gathered together.
6803	220	48	And Abimelech gat him up to mount Zalmon, he and all the people that were with him; and Abimelech took an axe in his hand, and cut down a bough from the trees, and took it, and laid it on his shoulder, and said unto the people that were with him, What ye have seen me do, make haste, and do as I have done.
6804	220	49	And all the people likewise cut down every man his bough, and followed Abimelech, and put them to the hold, and set the hold on fire upon them; so that all the men of the tower of Shechem died also, about a thousand men and women.
6805	220	50	Then went Abimelech to Thebez, and encamped against Thebez, and took it.
6806	220	51	But there was a strong tower within the city, and thither fled all the men and women, and all they of the city, and shut it to them, and gat them up to the top of the tower.
6807	220	52	And Abimelech came unto the tower, and fought against it, and went hard unto the door of the tower to burn it with fire.
6808	220	53	And a certain woman cast a piece of a millstone upon Abimelech's head, and all to brake his skull.
6809	220	54	Then he called hastily unto the young man his armourbearer, and said unto him, Draw thy sword, and slay me, that men say not of me, A woman slew him. And his young man thrust him through, and he died.
6810	220	55	And when the men of Israel saw that Abimelech was dead, they departed every man unto his place.
6811	220	56	Thus God rendered the wickedness of Abimelech, which he did unto his father, in slaying his seventy brethren:
6812	220	57	And all the evil of the men of Shechem did God render upon their heads: and upon them came the curse of Jotham the son of Jerubbaal.
6813	221	1	AND after Abimelech there arose to defend Israel Tola the son of Puah, the son of Dodo, a man of Issachar; and he dwelt in Shamir in mount Ephraim.
6814	221	2	And he judged Israel twenty and three years, and died, and was buried in Shamir.
6815	221	3	And after him arose Jair, a Gileadite, and judged Israel twenty and two years.
6816	221	4	And he had thirty sons that rode on thirty ass colts, and they had thirty cities, which are called Havoth-jair unto this day, which are in the land of Gilead.
6817	221	5	And Jair died, and was buried in Camon.
6818	221	6	And the children of Israel did evil again in the sight of the LORD, and served Baalim, and Ashtaroth, and the gods of Syria, and the gods of Zidon, and the gods of Moab, and the gods of the children of Ammon, and the gods of the Philistines, and forsook the LORD, and served not him.
6819	221	7	And the anger of the LORD was hot against Israel, and he sold them into the hands of the Philistines, and into the hands of the children of Ammon.
6820	221	8	And that year they vexed and oppressed the children of Israel: eighteen years, all the children of Israel that were on the other side Jordan in the land of the Amorites, which is in Gilead.
6821	221	9	Moreover, the children of Ammon passed over Jordan to fight also against Judah, and against Benjamin, and against the house of Ephraim; so that Israel was sore distressed.
6822	221	10	And the children of Israel cried unto the LORD, saying, We have sinned against thee, both because we have forsaken our God, and also served Baalim.
6823	221	11	And the LORD said unto the children of Israel, Did not I deliver you from the Egyptians, and from the Amorites, from the children of Ammon, and from the Philistines?
6824	221	12	The Zidonians also, and the Amalekites, and the Maonites, did oppress you; and ye cried to me, and I delivered you out of their hand.
6825	221	13	Yet ye have forsaken me, and served other gods: wherefore I will deliver you no more.
6826	221	14	Go and cry unto the gods which ye have chosen; let them deliver you in the time of your tribulation.
6827	221	15	And the children of Israel said unto the LORD, We have sinned: do thou unto us whatsoever seemeth good unto thee; deliver us only, we pray thee, this day.
6828	221	16	And they put away the strange gods from among them, and served the LORD: and his soul was grieved for the misery of Israel.
6829	221	17	Then the children of Ammon were gathered together, and encamped in Gilead. And the children of Israel assembled themselves together, and encamped in Mizpeh.
6830	221	18	And the people and princes of Gilead said one to another, What man is he that will begin to fight against the children of Ammon? he shall be head over all the inhabitants of Gilead.
6831	222	1	NOW Jephthah the Gileadite was a mighty man of valour, and he was the son of an harlot: and Gilead begat Jephthah.
6832	222	2	And Gilead's wife bare him sons; and his wife's sons grew up, and they thrust out Jephthah, and said unto him, Thou shalt not inherit in our father's house; for thou art the son of a strange woman.
6833	222	3	Then Jephthah fled from his brethren, and dwelt in the land of Tob: and there were gathered vain men to Jephthah, and went out with him.
6834	222	4	And it came to pass in process of time, that the children of Ammon made war against Israel.
6835	222	5	And it was so, that when the children of Ammon made war against Israel, the elders of Gilead went to fetch Jephthah out of the land of Tob:
6836	222	6	And they said unto Jephthah, Come, and be our captain, that we may fight with the children of Ammon.
6837	222	7	And Jephthah said unto the elders of Gilead, Did not ye hate me, and expel me out of my father's house? and why are ye come unto me now when ye are in distress?
6838	222	8	And the elders of Gilead said unto Jephthah, Therefore we turn again to thee now, that thou mayest go with us, and fight against the children of Ammon, and be our head over all the inhabitants of Gilead.
6839	222	9	And Jephthah said unto the elders of Gilead, If ye bring me home again to fight against the children of Ammon, and the LORD deliver them before me, shall I be your head?
6840	222	10	And the elders of Gilead said unto Jephthah, The LORD be witness between us, if we do not so according to thy words.
6841	222	11	Then Jephthah went with the elders of Gilead, and the people made him head and captain over them: and Jephthah uttered all his words before the LORD in Mizpeh.
6842	222	12	And Jephthah sent messengers unto the king of the children of Ammon, saying, What hast thou to do with me, that thou art come against me to fight in my land?
6843	222	13	And the king of the children of Ammon answered unto the messengers of Jephthah, Because Israel took away my land, when they came up out of Egypt, from Arnon even unto Jabbok, and unto Jordan: now therefore restore those lands again peaceably.
6844	222	14	And Jephthah sent messengers again unto the king of the children of Ammon:
6845	222	15	And said unto him, Thus saith Jephthah, Israel took not away the land of Moab, nor the land of the children of Ammon:
6846	222	16	But when Israel came up from Egypt, and walked through the wilderness unto the Red sea, and came to Kadesh;
6847	222	17	Then Israel sent messengers unto the king of Edom, saying, Let me, I pray thee, pass through thy land: but the king of Edom would not hearken thereto. And in like manner they sent unto the king of Moab: but he would not consent: and Israel abode in Kadesh.
6848	222	18	Then they went along through the wilderness, and compassed the land of Edom, and the land of Moab, and came by the east side of the land of Moab, and pitched on the other side of Arnon, but came not within the border of Moab: for Arnon was the border of Moab.
6849	222	19	And Israel sent messengers unto Sihon king of the Amorites, the king of Heshbon; and Israel said unto him, Let us pass, we pray thee, through thy land into my place.
6850	222	20	But Sihon trusted not Israel to pass through his coast: but Sihon gathered all his people together, and pitched in Jahaz, and fought against Israel.
6851	222	21	And the LORD God of Israel delivered Sihon and all his people into the hand of Israel, and they smote them: so Israel possessed all the land of the Amorites, the inhabitants of that country.
6852	222	22	And they possessed all the coasts of the Amorites, from Arnon even unto Jabbok, and from the wilderness even unto Jordan.
6853	222	23	So now the LORD God of Israel hath dispossessed the Amorites from before his people Israel, and shouldest thou possess it?
6854	222	24	Wilt not thou possess that which Chemosh thy god giveth thee to possess? So whomsoever the LORD our God shall drive out from before us, them will we possess.
6855	222	25	And now art thou any thing better than Balak the son of Zippor, king of Moab? did he ever strive against Israel, or did he ever fight against them,
6856	222	26	While Israel dwelt in Heshbon and her towns, and in Aroer and her towns, and in all the cities that be along by the coasts of Arnon, three hundred years? why therefore did ye not recover them within that time?
6857	222	27	Wherefore I have not sinned against thee, but thou doest me wrong to war against me: the LORD the Judge be judge this day between the children of Israel and the children of Ammon.
6858	222	28	Howbeit the king of the children of Ammon hearkened not unto the words of Jephthah which he sent him.
6859	222	29	Then the Spirit of the LORD came upon Jephthah, and he passed over Gilead, and Manasseh, and passed over Mizpeh of Gilead, and from Mizpeh of Gilead he passed over unto the children of Ammon.
6860	222	30	And Jephthah vowed a vow unto the LORD, and said, If thou shalt without fail deliver the children of Ammon into mine hands,
6861	222	31	Then it shall be, that whatsoever cometh forth of the doors of my house to meet me, when I return in peace from the children of Ammon, shall surely be the LORD's, and I will offer it up for a burnt offering.
6862	222	32	So Jephthah passed over unto the children of Ammon to fight against them; and the LORD delivered them into his hands.
6863	222	33	And he smote them from Aroer, even till thou come to Minnith, even twenty cities, and unto the plain of the vineyards, with a very great slaughter. Thus the children of Ammon were subdued before the children of Israel.
6864	222	34	And Jephthah came to Mizpeh unto his house, and, behold, his daughter came out to meet him with timbrels and with dances: and she was his only child; beside her he had neither son nor daughter.
6865	222	35	And it came to pass, when he saw her, that he rent his clothes, and said, Alas, my daughter! thou hast brought me very low, and thou art one of them that trouble me: for I have opened my mouth unto the LORD, and I cannot go back.
6866	222	36	And she said unto him, My father, if thou hast opened thy mouth unto the LORD, do to me according to that which hath proceeded out of thy mouth; forasmuch as the LORD hath taken vengeance for thee of thine enemies, even of the children of Ammon.
6867	222	37	And she said unto her father, Let this thing be done for me: let me alone two months, that I may go up and down upon the mountains, and bewail my virginity, I and my fellows.
6868	222	38	And he said, Go. And he sent her away for two months: and she went with her companions, and bewailed her virginity upon the mountains.
6869	222	39	And it came to pass at the end of two months, that she returned unto her father, who did with her according to his vow which he had vowed: and she knew no man. And it was a custom in Israel,
6870	222	40	That the daughters of Israel went yearly to lament the daughter of Jephthah the Gileadite four days in a year.
6871	223	1	AND the men of Ephraim gathered themselves together, and went northward, and said unto Jephthah, Wherefore passedst thou over to fight against the children of Ammon, and didst not call us to go with thee? we will burn thine house upon thee with fire.
6872	223	2	And Jephthah said unto them, I and my people were at great strife with the children of Ammon; and when I called you, ye delivered me not out of their hands.
6873	223	3	And when I saw that ye delivered me not, I put my life in my hands, and passed over against the children of Ammon, and the LORD delivered them into my hand: wherefore then are ye come up unto me this day, to fight against me?
6874	223	4	Then Jephthah gathered together all the men of Gilead, and fought with Ephraim: and the men of Gilead smote Ephraim, because they said, Ye Gileadites are fugitives of Ephraim among the Ephraimites, and among the Manassites.
6875	223	5	And the Gileadites took the passages of Jordan before the Ephraimites: and it was so, that when those Ephraimites which were escaped said, Let me go over; that the men of Gilead said unto him, Art thou an Ephraimite? If he said, Nay;
6876	223	6	Then said they unto him, Say now Shibboleth: and he said Sibboleth: for he could not frame to pronounce it right. Then they took him, and slew him at the passages of Jordan: and there fell at that time of the Ephraimites forty and two thousand.
6877	223	7	And Jephthah judged Israel six years. Then died Jephthah the Gileadite, and was buried in one of the cities of Gilead.
6878	223	8	And after him Ibzan of Beth-lehem judged Israel.
6879	223	9	And he had thirty sons, and thirty daughters, whom he sent abroad, and took in thirty daughters from abroad for his sons. And he judged Israel seven years.
6880	223	10	Then died Ibzan, and was buried at Beth-lehem.
6881	223	11	And after him Elon, a Zebulonite, judged Israel; and he judged Israel ten years.
6882	223	12	And Elon the Zebulonite died, and was buried in Aijalon in the country of Zebulun.
6883	223	13	And after him Abdon the son of Hillel, a Pirathonite, judged Israel.
6884	223	14	And he had forty sons and thirty nephews, that rode on threescore and ten ass colts: and he judged Israel eight years.
6885	223	15	And Abdon the son of Hillel the Pirathonite died, and was buried in Pirathon in the land of Ephraim, in the mount of the Amalekites.
6886	224	1	AND the children of Israel did evil again in the sight of the LORD; and the LORD delivered them into the hand of the Philistines forty years.
6887	224	2	And there was a certain man of Zorah, of the family of the Danites, whose name was Manoah; and his wife was barren, and bare not.
6888	224	3	And the angel of the LORD appeared unto the woman, and said unto her, Behold now, thou art barren, and bearest not: but thou shalt conceive, and bear a son.
6889	224	4	Now therefore beware, I pray thee, and drink not wine nor strong drink, and eat not any unclean thing:
6890	224	5	For, lo, thou shalt conceive, and bear a son; and no razor shall come on his head: for the child shall be a Nazarite unto God from the womb: and he shall begin to deliver Israel out of the hand of the Philistines.
6891	224	6	Then the woman came and told her husband, saying, A man of God came unto me, and his countenance was like the countenance of an angel of God, very terrible: but I asked him not whence he was, neither told he me his name:
6892	224	7	But he said unto me, Behold, thou shalt conceive, and bear a son; and now drink no wine nor strong drink, neither eat any unclean thing: for the child shall be a Nazarite to God from the womb to the day of his death.
6893	224	8	Then Manoah intreated the LORD, and said, O my Lord, let the man of God which thou didst send come again unto us, and teach us what we shall do unto the child that shall be born.
6894	224	9	And God hearkened to the voice of Manoah; and the angel of God came again unto the woman as she sat in the field: but Manoah her husband was not with her.
6895	224	10	And the woman made haste, and ran, and shewed her husband, and said unto him, Behold, the man hath appeared unto me, that came unto me the other day.
6896	224	11	And Manoah arose, and went after his wife, and came to the man, and said unto him, Art thou the man that spakest unto the woman? And he said, I am.
6897	224	12	And Manoah said, Now let thy words come to pass. How shall we order the child, and how shall we do unto him?
6898	224	13	And the angel of the LORD said unto Manoah, Of all that I said unto the woman let her beware.
6899	224	14	She may not eat of any thing that cometh of the vine, neither let her drink wine or strong drink, nor eat any unclean thing: all that I commanded her let her observe.
6900	224	15	And Manoah said unto the angel of the LORD, I pray thee, let us detain thee, until we shall have made ready a kid for thee.
6901	224	16	And the angel of the LORD said unto Manoah, Though thou detain me, I will not eat of thy bread: and if thou wilt offer a burnt offering, thou must offer it unto the LORD. For Manoah knew not that he was an angel of the LORD.
6902	224	17	And Manoah said unto the angel of the LORD, What is thy name, that when thy sayings come to pass we may do thee honour?
6903	224	18	And the angel of the LORD said unto him, Why askest thou thus after my name, seeing it is secret?
6904	224	19	So Manoah took a kid with a meat offering, and offered it upon a rock unto the LORD: and the angel did wondrously; and Manoah and his wife looked on.
6905	224	20	For it came to pass, when the flame went up toward heaven from off the altar, that the angel of the LORD ascended in the flame of the altar. And Manoah and his wife looked on it, and fell on their faces to the ground.
6906	224	21	But the angel of the LORD did no more appear to Manoah and to his wife. Then Manoah knew that he was an angel of the LORD.
6907	224	22	And Manoah said unto his wife, We shall surely die, because we have seen God.
6908	224	23	But his wife said unto him, If the LORD were pleased to kill us, he would not have received a burnt offering and a meat offering at our hands, neither would he have shewed us all these things, nor would as at this time have told us such things as these.
6909	224	24	And the woman bare a son, and called his name Samson: and the child grew, and the LORD blessed him.
6910	224	25	And the Spirit of the LORD began to move him at times in the camp of Dan between Zorah and Eshtaol.
6911	225	1	AND Samson went down to Timnath, and saw a woman in Timnath of the daughters of the Philistines.
6912	225	2	And he came up, and told his father and his mother, and said, I have seen a woman in Timnath of the daughters of the Philistines: now therefore get her for me to wife.
6913	225	3	Then his father and his mother said unto him, Is there never a woman among the daughters of thy brethren, or among all my people, that thou goest to take a wife of the uncircumcised Philistines? And Samson said unto his father, Get her for me; for she pleaseth me well.
6914	225	4	But his father and his mother knew not that it was of the LORD, that he sought an occasion against the Philistines: for at that time the Philistines had dominion over Israel.
6915	225	5	Then went Samson down, and his father and his mother, to Timnath, and came to the vineyards of Timnath: and, behold, a young lion roared against him.
6916	225	6	And the Spirit of the LORD came mightily upon him, and he rent him as he would have rent a kid, and he had nothing in his hand: but he told not his father or his mother what he had done.
6917	225	7	And he went down, and talked with the woman; and she pleased Samson well.
6918	225	8	And after a time he returned to take her, and he turned aside to see the carcase of the lion: and, behold, there was a swarm of bees and honey in the carcase of the lion.
6919	225	9	And he took thereof in his hands, and went on eating, and came to his father and mother, and he gave them, and they did eat: but he told not them that he had taken the honey out of the carcase of the lion.
6920	225	10	So his father went down unto the woman: and Samson made there a feast; for so used the young men to do.
6921	225	11	And it came to pass, when they saw him, that they brought thirty companions to be with him.
6922	225	12	And Samson said unto them, I will now put forth a riddle unto you: if ye can certainly declare it me within the seven days of the feast, and find it out, then I will give you thirty sheets and thirty change of garments:
6923	225	13	But if ye cannot declare it me, then shall ye give me thirty sheets and thirty change of garments. And they said unto him, Put forth thy riddle, that we may hear it.
6924	225	14	And he said unto them, Out of the eater came forth meat, and out of the strong came forth sweetness. And they could not in three days expound the riddle.
6925	225	15	And it came to pass on the seventh day, that they said unto Samson's wife, Entice thy husband, that he may declare unto us the riddle, lest we burn thee and thy father's house with fire: have ye called us to take that we have? is it not so?
6926	225	16	And Samson's wife wept before him, and said, Thou dost but hate me, and lovest me not: thou hast put forth a riddle unto the children of my people, and hast not told it me. And he said unto her, Behold, I have not told it my father nor my mother, and shall I tell it thee?
6927	225	17	And she wept before him the seven days, while their feast lasted: and it came to pass on the seventh day, that he told her, because she lay sore upon him: and she told the riddle to the children of her people.
6928	225	18	And the men of the city said unto him on the seventh day before the sun went down, What is sweeter than honey? and what is stronger than a lion? And he said unto them, If ye had not plowed with my heifer, ye had not found out my riddle.
6929	225	19	And the Spirit of the LORD came upon him, and he went down to Ashkelon, and slew thirty men of them, and took their spoil, and gave change of garments unto them which expounded the riddle. And his anger was kindled, and he went up to his father's house.
6930	225	20	But Samson's wife was given to his companion, whom he had used as his friend.
6931	226	1	BUT it came to pass within a while after, in the time of wheat harvest, that Samson visited his wife with a kid; and he said, I will go in to my wife into the chamber. But her father would not suffer him to go in.
6932	226	2	And her father said, I verily thought that thou hadst utterly hated her; therefore I gave her to thy companion: is not her younger sister fairer than she? take her, I pray thee, instead of her.
6933	226	3	And Samson said concerning them, Now shall I be more blameless than the Philistines, though I do them a displeasure.
6934	226	4	And Samson went and caught three hundred foxes, and took firebrands, and turned tail to tail, and put a firebrand in the midst between two tails.
6935	226	5	And when he had set the brands on fire, he let them go into the standing corn of the Philistines, and burnt up both the shocks, and also the standing corn, with the vineyards and olives.
6936	226	6	Then the Philistines said, Who hath done this? And they answered, Samson, the son in law of the Timnite, because he had taken his wife, and given her to his companion. And the Philistines came up, and burnt her and her father with fire.
6937	226	7	And Samson said unto them, Though ye have done this, yet will I be avenged of you, and after that I will cease.
6938	226	8	And he smote them hip and thigh with a great slaughter: and he went down and dwelt in the top of the rock Etam.
6939	226	9	Then the Philistines went up, and pitched in Judah, and spread themselves in Lehi.
6940	226	10	And the men of Judah said, Why are ye come up against us? And they answered, To bind Samson are we come up, to do to him as he hath done to us.
6941	226	11	Then three thousand men of Judah went to the top of the rock Etam, and said to Samson, Knowest thou not that the Philistines are rulers over us? what is this that thou hast done unto us? And he said unto them, As they did unto me, so have I done unto them.
6942	226	12	And they said unto him, We are come down to bind thee, that we may deliver thee into the hand of the Philistines. And Samson said unto them, Swear unto me, that ye will not fall upon me yourselves.
6943	226	13	And they spake unto him, saying, No; but we will bind thee fast, and deliver thee into their hand: but surely we will not kill thee. And they bound him with two new cords, and brought him up from the rock.
6944	226	14	And when he came unto Lehi, the Philistines shouted against him: and the Spirit of the LORD came mightily upon him, and the cords that were upon his arms became as flax that was burnt with fire, and his bands loosed from off his hands.
6945	226	15	And he found a new jawbone of an ass, and put forth his hand, and took it, and slew a thousand men therewith.
6946	226	16	And Samson said, With the jawbone of an ass, heaps upon heaps, with the jaw of an ass have I slain a thousand men.
6947	226	17	And it came to pass, when he had made an end of speaking, that he cast away the jawbone out of his hand, and called that place Ramath-lehi.
6948	226	18	And he was sore athirst, and called on the LORD, and said, Thou hast given this great deliverance into the hand of thy servant: and now shall I die for thirst, and fall into the hand of the uncircumcised?
6949	226	19	But God clave an hollow place that was in the jaw, and there came water thereout; and when he had drunk, his spirit came again, and he revived: wherefore he called the name thereof En-hakkore, which is in Lehi unto this day.
6950	226	20	And he judged Israel in the days of the Philistines twenty years.
6951	227	1	THEN went Samson to Gaza, and saw there an harlot, and went in unto her.
6952	227	2	And it was told the Gazites, saying, Samson is come hither. And they compassed him in, and laid wait for him all night in the gate of the city, and were quiet all the night, saying, In the morning, when it is day, we shall kill him.
6953	227	3	And Samson lay till midnight, and arose at midnight, and took the doors of the gate of the city, and the two posts, and went away with them, bar and all, and put them upon his shoulders, and carried them up to the top of an hill that is before Hebron.
6954	227	4	And it came to pass afterward, that he loved a woman in the valley of Sorek, whose name was Delilah.
6955	227	5	And the lords of the Philistines came up unto her, and said unto her, Entice him, and see wherein his great strength lieth, and by what means we may prevail against him, that we may bind him to afflict him: and we will give thee every one of us eleven hundred pieces of silver.
6956	227	6	And Delilah said to Samson, Tell me, I pray thee, wherein thy great strength lieth, and wherewith thou mightest be bound to afflict thee.
6957	227	7	And Samson said unto her, If they bind me with seven green withs that were never dried, then shall I be weak, and be as another man.
6958	227	8	Then the lords of the Philistines brought up to her seven green withs which had not been dried, and she bound him with them.
6959	227	9	Now there were men lying in wait, abiding with her in the chamber. And she said unto him, The Philistines be upon thee, Samson. And he brake the withs, as a thread of tow is broken when it toucheth the fire. So his strength was not known.
6960	227	10	And Delilah said unto Samson, Behold, thou hast mocked me, and told me lies: now tell me, I pray thee, wherewith thou mightest be bound.
6961	227	11	And he said unto her, If they bind me fast with new ropes that never were occupied, then shall I be weak, and be as another man.
6962	227	12	Delilah therefore took new ropes, and bound him therewith, and said unto him, The Philistines be upon thee, Samson. And there were liers in wait abiding in the chamber. And he brake them from off his arms like a thread.
6963	227	13	And Delilah said unto Samson, Hitherto thou hast mocked me, and told me lies: tell me wherewith thou mightest be bound. And he said unto her, If thou weavest the seven locks of my head with the web.
6964	227	14	And she fastened it with the pin, and said unto him, The Philistines be upon thee, Samson. And he awaked out of his sleep, and went away with the pin of the beam, and with the web.
6965	227	15	And she said unto him, How canst thou say, I love thee, when thine heart is not with me? thou hast mocked me these three times, and hast not told me wherein thy great strength lieth.
6966	227	16	And it came to pass, when she pressed him daily with her words, and urged him, so that his soul was vexed unto death;
6967	227	17	That he told her all his heart, and said unto her, There hath not come a razor upon mine head; for I have been a Nazarite unto God from my mother's womb: if I be shaven, then my strength will go from me, and I shall become weak, and be like any other man.
6968	227	18	And when Delilah saw that he had told her all his heart, she sent and called for the lords of the Philistines, saying, Come up this once, for he hath shewed me all his heart. Then the lords of the Philistines came up unto her, and brought money in their hand.
6969	227	19	And she made him sleep upon her knees; and she called for a man, and she caused him to shave off the seven locks of his head; and she began to afflict him, and his strength went from him.
6970	227	20	And she said, The Philistines be upon thee, Samson. And he awoke out of his sleep, and said, I will go out as at other times before, and shake myself. And he wist not that the LORD was departed from him.
6971	227	21	But the Philistines took him, and put out his eyes, and brought him down to Gaza, and bound him with fetters of brass; and he did grind in the prison house.
6972	227	22	Howbeit the hair of his head began to grow again after he was shaven.
6973	227	23	Then the lords of the Philistines gathered them together for to offer a great sacrifice unto Dagon their god, and to rejoice: for they said, Our god hath delivered Samson our enemy into our hand.
6974	227	24	And when the people saw him, they praised their god: for they said, Our god hath delivered into our hands our enemy, and the destroyer of our country, which slew many of us.
6975	227	25	And it came to pass, when their hearts were merry, that they said, Call for Samson, that he may make us sport. And they called for Samson out of the prison house; and he made them sport: and they set him between the pillars.
6976	227	26	And Samson said unto the lad that held him by the hand, Suffer me that I may feel the pillars whereupon the house standeth, that I may lean upon them.
6977	227	27	Now the house was full of men and women; and all the lords of the Philistines were there; and there were upon the roof about three thousand men and women, that beheld while Samson made sport.
6978	227	28	And Samson called unto the LORD, and said, O Lord GOD, remember me, I pray thee, and strengthen me, I pray thee, only this once, O God, that I may be at once avenged of the Philistines for my two eyes.
6979	227	29	And Samson took hold of the two middle pillars upon which the house stood, and on which it was borne up, of the one with his right hand, and of the other with his left.
6980	227	30	And Samson said, Let me die with the Philistines. And he bowed himself with all his might; and the house fell upon the lords, and upon all the people that were therein. So the dead which he slew at his death were more than they which he slew in his life.
6981	227	31	Then his brethren and all the house of his father came down, and took him, and brought him up, and buried him between Zorah and Eshtaol in the buryingplace of Manoah his father. And he judged Israel twenty years.
6982	228	1	AND there was a man of mount Ephraim, whose name was Micah.
6983	228	2	And he said unto his mother, The eleven hundred shekels of silver that were taken from thee, about which thou cursedst, and spakest of also in mine ears, behold, the silver is with me; I took it. And his mother said, Blessed be thou of the LORD, my son.
6984	228	3	And when he had restored the eleven hundred shekels of silver to his mother, his mother said, I had wholly dedicated the silver unto the LORD from my hand for my son, to make a graven image and a molten image: now therefore I will restore it unto thee.
6985	228	4	Yet he restored the money unto his mother; and his mother took two hundred shekels of silver, and gave them to the founder, who made thereof a graven image and a molten image: and they were in the house of Micah.
6986	228	5	And the man Micah had an house of gods, and made an ephod, and teraphim, and consecrated one of his sons, who became his priest.
6987	228	6	In those days there was no king in Israel, but every man did that which was right in his own eyes.
6988	228	7	And there was a young man out of Beth-lehem-judah of the family of Judah, who was a Levite, and he sojourned there.
6989	228	8	And the man departed out of the city from Beth-lehem-judah to sojourn where he could find a place: and he came to mount Ephraim to the house of Micah, as he journeyed.
6990	228	9	And Micah said unto him, Whence comest thou? And he said unto him, I am a Levite of Beth-lehem-judah, and I go to sojourn where I may find a place.
6991	228	10	And Micah said unto him, Dwell with me, and be unto me a father and a priest, and I will give thee ten shekels of silver by the year, and a suit of apparel, and thy victuals. So the Levite went in.
6992	228	11	And the Levite was content to dwell with the man; and the young man was unto him as one of his sons.
6993	228	12	And Micah consecrated the Levite; and the young man became his priest, and was in the house of Micah.
6994	228	13	Then said Micah, Now know I that the LORD will do me good, seeing I have a Levite to my priest.
6995	229	1	IN those days there was no king in Israel: and in those days the tribe of the Danites sought them an inheritance to dwell in; for unto that day all their inheritance had not fallen unto them among the tribes of Israel.
6996	229	2	And the children of Dan sent of their family five men from their coasts, men of valour, from Zorah, and from Eshtaol, to spy out the land, and to search it; and they said unto them, Go, search the land: who when they came to mount Ephraim, to the house of Micah, they lodged there.
6997	229	3	When they were by the house of Micah, they knew the voice of the young man the Levite: and they turned in thither, and said unto him, Who brought thee hither? and what makest thou in this place? and what hast thou here?
6998	229	4	And he said unto them, Thus and thus dealeth Micah with me, and hath hired me, and I am his priest.
6999	229	5	And they said unto him, Ask counsel, we pray thee, of God, that we may know whether our way which we go shall be prosperous.
7000	229	6	And the priest said unto them, Go in peace: before the LORD is your way wherein ye go.
7001	229	7	Then the five men departed, and came to Laish, and saw the people that were therein, how they dwelt careless, after the manner of the Zidonians, quiet and secure; and there was no magistrate in the land, that might put them to shame in any thing; and they were far from the Zidonians, and had no business with any man.
7002	229	8	And they came unto their brethren to Zorah and Eshtaol: and their brethren said unto them, What say ye?
7003	229	9	And they said, Arise, that we may go up against them: for we have seen the land, and, behold, it is very good: and are ye still? be not slothful to go, and to enter to possess the land.
7004	229	10	When ye go, ye shall come unto a people secure, and to a large land: for God hath given it into your hands; a place where there is no want of any thing that is in the earth.
7005	229	11	And there went from thence of the family of the Danites, out of Zorah and out of Eshtaol, six hundred men appointed with weapons of war.
7006	229	12	And they went up, and pitched in Kirjath-jearim, in Judah: wherefore they called that place Mahaneh-dan unto this day: behold, it is behind Kirjath-jearim.
7007	229	13	And they passed thence unto mount Ephraim, and came unto the house of Micah.
7008	229	14	Then answered the five men that went to spy out the country of Laish, and said unto their brethren, Do ye know that there is in these houses an ephod, and teraphim, and a graven image, and a molten image? now therefore consider what ye have to do.
7009	229	15	And they turned thitherward, and came to the house of the young man the Levite, even unto the house of Micah, and saluted him.
7010	229	16	And the six hundred men appointed with their weapons of war, which were of the children of Dan, stood by the entering of the gate.
7011	229	17	And the five men that went to spy out the land went up, and came in thither, and took the graven image, and the ephod, and the teraphim, and the molten image: and the priest stood in the entering of the gate with the six hundred men that were appointed with weapons of war.
7012	229	18	And these went into Micah's house, and fetched the carved image, the ephod, and the teraphim, and the molten image. Then said the priest unto them, What do ye?
7013	229	19	And they said unto him, Hold thy peace, lay thine hand upon thy mouth, and go with us, and be to us a father and a priest: is it better for thee to be a priest unto the house of one man, or that thou be a priest unto a tribe and a family in Israel?
7014	229	20	And the priest's heart was glad, and he took the ephod, and the teraphim, and the graven image, and went in the midst of the people.
7015	229	21	So they turned and departed, and put the little ones and the cattle and the carriage before them.
7016	229	22	And when they were a good way from the house of Micah, the men that were in the houses near to Micah's house were gathered together, and overtook the children of Dan.
7017	229	23	And they cried unto the children of Dan. And they turned their faces, and said unto Micah, What aileth thee, that thou comest with such a company?
7018	229	24	And he said, Ye have taken away my gods which I made, and the priest, and ye are gone away: and what have I more? and what is this that ye say unto me, What aileth thee?
7019	229	25	And the children of Dan said unto him, Let not thy voice be heard among us, lest angry fellows run upon thee, and thou lose thy life, with the lives of thy household.
7020	229	26	And the children of Dan went their way: and when Micah saw that they were too strong for him, he turned and went back unto his house.
7021	229	27	And they took the things which Micah had made, and the priest which he had, and came unto Laish, unto a people that were at quiet and secure: and they smote them with the edge of the sword, and burnt the city with fire.
7022	229	28	And there was no deliverer, because it was far from Zidon, and they had no business with any man; and it was in the valley that lieth by Beth-rehob. And they built a city, and dwelt therein.
7023	229	29	And they called the name of the city Dan, after the name of Dan their father, who was born unto Israel: howbeit the name of the city was Laish at the first.
7024	229	30	And the children of Dan set up the graven image: and Jonathan, the son of Gershom, the son of Manasseh, he and his sons were priests to the tribe of Dan until the day of the captivity of the land.
7025	229	31	And they set them up Micah's graven image, which he made, all the time that the house of God was in Shiloh.
7026	230	1	AND it came to pass in those days, when there was no king in Israel, that there was a certain Levite sojourning on the side of mount Ephraim, who took to him a concubine out of Beth-lehem-judah.
7027	230	2	And his concubine played the whore against him, and went away from him unto her father's house to Beth-lehem-judah, and was there four whole months.
7028	230	3	And her husband arose, and went after her, to speak friendly unto her, and to bring her again, having his servant with him, and a couple of asses: and she brought him into her father's house: and when the father of the damsel saw him, he rejoiced to meet him.
7029	230	4	And his father in law, the damsel's father, retained him; and he abode with him three days: so they did eat and drink, and lodged there.
7030	230	5	And it came to pass on the fourth day, when they arose early in the morning, that he rose up to depart: and the damsel's father said unto his son in law, Comfort thine heart with a morsel of bread, and afterward go your way.
7031	230	6	And they sat down, and did eat and drink both of them together: for the damsel's father had said unto the man, Be content, I pray thee, and tarry all night, and let thine heart be merry.
7032	230	7	And when the man rose up to depart, his father in law urged him: therefore he lodged there again.
7033	230	8	And he arose early in the morning on the fifth day to depart: and the damsel's father said, Comfort thine heart, I pray thee. And they tarried until afternoon, and they did eat both of them.
7034	230	9	And when the man rose up to depart, he, and his concubine, and his servant, his father in law, the damsel's father, said unto him, Behold, now the day draweth toward evening, I pray you tarry all night: behold, the day groweth to an end, lodge here, that thine heart may be merry; and to morrow get you early on your way, that thou mayest go home.
7035	230	10	But the man would not tarry that night, but he rose up and departed, and came over against Jebus, which is Jerusalem; and there were with him two asses saddled, his concubine also was with him.
7036	230	11	And when they were by Jebus, the day was far spent; and the servant said unto his master, Come, I pray thee, and let us turn in into this city of the Jebusites, and lodge in it.
7037	230	12	And his master said unto him, We will not turn aside hither into the city of a stranger, that is not of the children of Israel; we will pass over to Gibeah.
7038	230	13	And he said unto his servant, Come, and let us draw near to one of these places to lodge all night, in Gibeah, or in Ramah.
7039	230	14	And they passed on and went their way; and the sun went down upon them when they were by Gibeah, which belongeth to Benjamin.
7040	230	15	And they turned aside thither, to go in and to lodge in Gibeah: and when he went in, he sat him down in a street of the city: for there was no man that took them into his house to lodging.
7041	230	16	And, behold, there came an old man from his work out of the field at even, which was also of mount Ephraim; and he sojourned in Gibeah: but the men of the place were Benjamites.
7042	230	17	And when he had lifted up his eyes, he saw a wayfaring man in the street of the city: and the old man said, Whither goest thou? and whence comest thou?
7043	230	18	And he said unto him, We are passing from Beth-lehem-judah toward the side of mount Ephraim; from thence am I: and I went to Beth-lehem-judah, but I am now going to the house of the LORD; and there is no man that receiveth me to house.
7044	230	19	Yet there is both straw and provender for our asses; and there is bread and wine also for me, and for thy handmaid, and for the young man which is with thy servants: there is no want of any thing.
7045	230	20	And the old man said, Peace be with thee; howsoever let all thy wants lie upon me; only lodge not in the street.
7046	230	21	So he brought him into his house, and gave provender unto the asses: and they washed their feet, and did eat and drink.
7047	230	22	Now as they were making their hearts merry, behold, the men of the city, certain sons of Belial, beset the house round about, and beat at the door, and spake to the master of the house, the old man, saying, Bring forth the man that came into thine house, that we may know him.
7048	230	23	And the man, the master of the house, went out unto them, and said unto them, Nay, my brethren, nay, I pray you, do not so wickedly; seeing that this man is come into mine house, do not this folly.
7049	230	24	Behold, here is my daughter a maiden, and his concubine; them I will bring out now, and humble ye them, and do with them what seemeth good unto you: but unto this man do not so vile a thing.
7050	230	25	But the men would not hearken to him: so the man took his concubine, and brought her forth unto them; and they knew her, and abused her all the night until the morning: and when the day began to spring, they let her go.
7051	230	26	Then came the woman in the dawning of the day, and fell down at the door of the man's house where her lord was, till it was light.
7052	230	27	And her lord rose up in the morning, and opened the doors of the house, and went out to go his way: and, behold, the woman his concubine was fallen down at the door of the house, and her hands were upon the threshold.
7053	230	28	And he said unto her, Up, and let us be going. But none answered. Then the man took her up upon an ass, and the man rose up, and gat him unto his place.
7054	230	29	And when he was come into his house, he took a knife, and laid hold on his concubine, and divided her, together with her bones, into twelve pieces, and sent her into all the coasts of Israel.
7055	230	30	And it was so, that all that saw it said, There was no such deed done nor seen from the day that the children of Israel came up out of the land of Egypt unto this day: consider of it, take advice, and speak your minds.
7056	231	1	THEN all the children of Israel went out, and the congregation was gathered together as one man, from Dan even to Beer-sheba, with the land of Gilead, unto the LORD in Mizpeh.
7057	231	2	And the chief of all the people, even of all the tribes of Israel, presented themselves in the assembly of the people of God, four hundred thousand footmen that drew sword.
7058	231	3	(Now the children of Benjamin heard that the children of Israel were gone up to Mizpeh.) Then said the children of Israel, Tell us, how was this wickedness?
7059	231	4	And the Levite, the husband of the woman that was slain, answered and said, I came into Gibeah that belongeth to Benjamin, I and my concubine, to lodge.
7060	231	5	And the men of Gibeah rose against me, and beset the house round about upon me by night, and thought to have slain me: and my concubine have they forced, that she is dead.
7061	231	6	And I took my concubine, and cut her in pieces, and sent her throughout all the country of the inheritance of Israel: for they have committed lewdness and folly in Israel.
7062	231	7	Behold, ye are all children of Israel; give here your advice and counsel.
7063	231	8	And all the people arose as one man, saying, We will not any of us go to his tent, neither will we any of us turn into his house.
7064	231	9	But now this shall be the thing which we will do to Gibeah; we will go up by lot against it;
7065	231	10	And we will take ten men of an hundred throughout all the tribes of Israel, and an hundred of a thousand, and a thousand out of ten thousand, to fetch victual for the people, that they may do, when they come to Gibeah of Benjamin, according to all the folly that they have wrought in Israel.
7066	231	11	So all the men of Israel were gathered against the city, knit together as one man.
7067	231	12	And the tribes of Israel sent men through all the tribe of Benjamin, saying, What wickedness is this that is done among you?
7068	231	13	Now therefore deliver us the men, the children of Belial, which are in Gibeah, that we may put them to death, and put away evil from Israel. But the children of Benjamin would not hearken to the voice of their brethren the children of Israel:
7069	231	14	But the children of Benjamin gathered themselves together out of the cities unto Gibeah, to go out to battle against the children of Israel.
7070	231	15	And the children of Benjamin were numbered at that time out of the cities twenty and six thousand men that drew sword, beside the inhabitants of Gibeah, which were numbered seven hundred chosen men.
7071	231	16	Among all this people there were seven hundred chosen men lefthanded; every one could sling stones at an hair breadth, and not miss.
7072	231	17	And the men of Israel, beside Benjamin, were numbered four hundred thousand men that drew sword: all these were men of war.
7073	231	18	And the children of Israel arose, and went up to the house of God, and asked counsel of God, and said, Which of us shall go up first to the battle against the children of Benjamin? And the LORD said, Judah shall go up first.
7074	231	19	And the children of Israel rose up in the morning, and encamped against Gibeah.
7075	231	20	And the men of Israel went out to battle against Benjamin; and the men of Israel put themselves in array to fight against them at Gibeah.
7076	231	21	And the children of Benjamin came forth out of Gibeah, and destroyed down to the ground of the Israelites that day twenty and two thousand men.
7077	231	22	And the people the men of Israel encouraged themselves, and set their battle again in array in the place where they put themselves in array the first day.
7078	231	23	(And the children of Israel went up and wept before the LORD until even, and asked counsel of the LORD, saying, Shall I go up again to battle against the children of Benjamin my brother? And the LORD said, Go up against him.)
7079	231	24	And the children of Israel came near against the children of Benjamin the second day.
7080	231	25	And Benjamin went forth against them out of Gibeah the second day, and destroyed down to the ground of the children of Israel again eighteen thousand men; all these drew the sword.
7081	231	26	Then all the children of Israel, and all the people, went up, and came unto the house of God, and wept, and sat there before the LORD, and fasted that day until even, and offered burnt offerings and peace offerings before the LORD.
7082	231	27	And the children of Israel inquired of the LORD, (for the ark of the covenant of God was there in those days,
7083	231	28	And Phinehas, the son of Eleazar, the son of Aaron, stood before it in those days,) saying, Shall I yet again go out to battle against the children of Benjamin my brother, or shall I cease? And the LORD said, Go up; for to morrow I will deliver them into thine hand.
7084	231	29	And Israel set liers in wait round about Gibeah.
7085	231	30	And the children of Israel went up against the children of Benjamin on the third day, and put themselves in array against Gibeah, as at other times.
7086	231	31	And the children of Benjamin went out against the people, and were drawn away from the city; and they began to smite of the people, and kill, as at other times, in the highways, of which one goeth up to the house of God, and the other to Gibeah in the field, about thirty men of Israel.
7087	231	32	And the children of Benjamin said, They are smitten down before us, as at the first. But the children of Israel said, Let us flee, and draw them from the city unto the highways.
7088	231	33	And all the men of Israel rose up out of their place, and put themselves in array at Baal-tamar: and the liers in wait of Israel came forth out of their places, even out of the meadows of Gibeah.
7089	231	34	And there came against Gibeah ten thousand chosen men out of all Israel, and the battle was sore: but they knew not that evil was near them.
7090	231	35	And the LORD smote Benjamin before Israel: and the children of Israel destroyed of the Benjamites that day twenty and five thousand and an hundred men: all these drew the sword.
7091	231	36	So the children of Benjamin saw that they were smitten: for the men of Israel gave place to the Benjamites, because they trusted unto the liers in wait which they had set beside Gibeah.
7092	231	37	And the liers in wait hasted, and rushed upon Gibeah; and the liers in wait drew themselves along, and smote all the city with the edge of the sword.
7093	231	38	Now there was an appointed sign between the men of Israel and the liers in wait, that they should make a great flame with smoke rise up out of the city.
7094	231	39	And when the men of Israel retired in the battle, Benjamin began to smite and kill of the men of Israel about thirty persons: for they said, Surely they are smitten down before us, as in the first battle.
7095	231	40	But when the flame began to arise up out of the city with a pillar of smoke, the Benjamites looked behind them, and, behold, the flame of the city ascended up to heaven.
7096	231	41	And when the men of Israel turned again, the men of Benjamin were amazed: for they saw that evil was come upon them.
7097	231	42	Therefore they turned their backs before the men of Israel unto the way of the wilderness; but the battle overtook them; and them which came out of the cities they destroyed in the midst of them.
7098	231	43	Thus they inclosed the Benjamites round about, and chased them, and trode them down with ease over against Gibeah toward the sunrising.
7099	231	44	And there fell of Benjamin eighteen thousand men; all these were men of valour.
7100	231	45	And they turned and fled toward the wilderness unto the rock of Rimmon: and they gleaned of them in the highways five thousand men; and pursued hard after them unto Gidom, and slew two thousand men of them.
7101	231	46	So that all which fell that day of Benjamin were twenty and five thousand men that drew the sword; all these were men of valour.
7102	231	47	But six hundred men turned and fled to the wilderness unto the rock Rimmon, and abode in the rock Rimmon four months.
7103	231	48	And the men of Israel turned again upon the children of Benjamin, and smote them with the edge of the sword, as well the men of every city, as the beast, and all that came to hand: also they set on fire all the cities that they came to.
7104	232	1	NOW the men of Israel had sworn in Mizpeh, saying, There shall not any of us give his daughter unto Benjamin to wife.
7105	232	2	And the people came to the house of God, and abode there till even before God, and lifted up their voices, and wept sore;
7106	232	3	And said, O LORD God of Israel, why is this come to pass in Israel, that there should be to day one tribe lacking in Israel?
7107	232	4	And it came to pass on the morrow, that the people rose early, and built there an altar, and offered burnt offerings and peace offerings.
7108	232	5	And the children of Israel said, Who is there among all the tribes of Israel that came not up with the congregation unto the LORD? For they had made a great oath concerning him that came not up to the LORD to Mizpeh, saying, He shall surely be put to death.
7109	232	6	And the children of Israel repented them for Benjamin their brother, and said, There is one tribe cut off from Israel this day.
7110	232	7	How shall we do for wives for them that remain, seeing we have sworn by the LORD that we will not give them of our daughters to wives?
7111	232	8	And they said, What one is there of the tribes of Israel that came not up to Mizpeh to the LORD? And, behold, there came none to the camp from Jabesh-gilead to the assembly.
7112	232	9	For the people were numbered, and, behold, there were none of the inhabitants of Jabesh-gilead there.
7113	232	10	And the congregation sent thither twelve thousand men of the valiantest, and commanded them, saying, Go and smite the inhabitants of Jabesh-gilead with the edge of the sword, with the women and the children.
7114	232	11	And this is the thing that ye shall do, Ye shall utterly destroy every male, and every woman that hath lain by man.
7115	232	12	And they found among the inhabitants of Jabesh-gilead four hundred young virgins, that had known no man by lying with any male: and they brought them unto the camp to Shiloh, which is in the land of Canaan.
7116	232	13	And the whole congregation sent some to speak to the children of Benjamin that were in the rock Rimmon, and to call peaceably unto them.
7117	232	14	And Benjamin came again at that time; and they gave them wives which they had saved alive of the women of Jabesh-gilead: and yet so they sufficed them not.
7118	232	15	And the people repented them for Benjamin, because that the LORD had made a breach in the tribes of Israel.
7119	232	16	Then the elders of the congregation said, How shall we do for wives for them that remain, seeing the women are destroyed out of Benjamin?
7120	232	17	And they said, There must be an inheritance for them that be escaped of Benjamin, that a tribe be not destroyed out of Israel.
7121	232	18	Howbeit we may not give them wives of our daughters: for the children of Israel have sworn, saying, Cursed be he that giveth a wife to Benjamin.
7122	232	19	Then they said, Behold, there is a feast of the LORD in Shiloh yearly in a place which is on the north side of Beth-el, on the east side of the highway that goeth up from Beth-el to Shechem, and on the south of Lebonah.
7123	232	20	Therefore they commanded the children of Benjamin, saying, Go and lie in wait in the vineyards;
7124	232	21	And see, and, behold, if the daughters of Shiloh come out to dance in dances, then come ye out of the vineyards, and catch you every man his wife of the daughters of Shiloh, and go to the land of Benjamin.
7125	232	22	And it shall be, when their fathers or their brethren come unto us to complain, that we will say unto them, Be favourable unto them for our sakes: because we reserved not to each man his wife in the war: for ye did not give unto them at this time, that ye should be guilty.
7126	232	23	And the children of Benjamin did so, and took them wives, according to their number, of them that danced, whom they caught: and they went and returned unto their inheritance, and repaired the cities, and dwelt in them.
7127	232	24	And the children of Israel departed thence at that time, every man to his tribe and to his family, and they went out from thence every man to his inheritance.
7128	232	25	In those days there was no king in Israel: every man did that which was right in his own eyes.
7129	233	1	NOW it came to pass in the days when the judges ruled, that there was a famine in the land. And a certain man of Beth-lehem-judah went to sojourn in the country of Moab, he, and his wife, and his two sons.
7130	233	2	And the name of the man was Elimelech, and the name of his wife Naomi, and the name of his two sons Mahlon and Chilion, Ephrathites of Beth-lehem-judah. And they came into the country of Moab, and continued there.
7131	233	3	And Elimelech Naomi's husband died; and she was left, and her two sons.
7132	233	4	And they took them wives of the women of Moab; the name of the one was Orpah, and the name of the other Ruth: and they dwelled there about ten years.
7133	233	5	And Mahlon and Chilion died also both of them; and the woman was left of her two sons and her husband.
7134	233	6	Then she arose with her daughters in law, that she might return from the country of Moab: for she had heard in the country of Moab how that the LORD had visited his people in giving them bread.
7135	233	7	Wherefore she went forth out of the place where she was, and her two daughters in law with her; and they went on the way to return unto the land of Judah.
7136	233	8	And Naomi said unto her two daughters in law, Go, return each to her mother's house: the LORD deal kindly with you, as ye have dealt with the dead, and with me.
7137	233	9	The LORD grant you that ye may find rest, each of you in the house of her husband. Then she kissed them; and they lifted up their voice, and wept.
7138	233	10	And they said unto her, Surely we will return with thee unto thy people.
7139	233	11	And Naomi said, Turn again, my daughters: why will ye go with me? are there yet any more sons in my womb, that they may be your husbands?
7140	233	12	Turn again, my daughters, go your way; for I am too old to have an husband. If I should say, I have hope, if I should have an husband also to night, and should also bear sons;
7141	233	13	Would ye tarry for them till they were grown? would ye stay for them from having husbands? nay, my daughters; for it grieveth me much for your sakes that the hand of the LORD is gone out against me.
7142	233	14	And they lifted up their voice, and wept again: and Orpah kissed her mother in law; but Ruth clave unto her.
7143	233	15	And she said, Behold, thy sister in law is gone back unto her people, and unto her gods: return thou after thy sister in law.
7144	233	16	And Ruth said, Intreat me not to leave thee, or to return from following after thee: for whither thou goest, I will go; and where thou lodgest, I will lodge: thy people shall be my people, and thy God my God:
7145	233	17	Where thou diest, will I die, and there will I be buried: the LORD do so to me, and more also, if ought but death part thee and me.
7146	233	18	When she saw that she was stedfastly minded to go with her, then she left speaking unto her.
7147	233	19	So they two went until they came to Beth-lehem. And it came to pass, when they were come to Beth-lehem, that all the city was moved about them, and they said, Is this Naomi?
7148	233	20	And she said unto them, Call me not Naomi, call me Mara: for the Almighty hath dealt very bitterly with me.
7149	233	21	I went out full, and the LORD hath brought me home again empty: why then call ye me Naomi, seeing the LORD hath testified against me, and the Almighty hath afflicted me?
7150	233	22	So Naomi returned, and Ruth the Moabitess, her daughter in law, with her, which returned out of the country of Moab: and they came to Beth-lehem in the beginning of barley harvest.
7151	234	1	AND Naomi had a kinsman of her husband's, a mighty man of wealth, of the family of Elimelech; and his name was Boaz.
7152	234	2	And Ruth the Moabitess said unto Naomi, Let me now go to the field, and glean ears of corn after him in whose sight I shall find grace. And she said unto her, Go, my daughter.
7153	234	3	And she went, and came, and gleaned in the field after the reapers: and her hap was to light on a part of the field belonging unto Boaz, who was of the kindred of Elimelech.
7154	234	4	And, behold, Boaz came from Beth-lehem, and said unto the reapers, The LORD be with you. And they answered him, The LORD bless thee.
7155	234	5	Then said Boaz unto his servant that was set over the reapers, Whose damsel is this?
7156	234	6	And the servant that was set over the reapers answered and said, It is the Moabitish damsel that came back with Naomi out of the country of Moab:
7157	234	7	And she said, I pray you, let me glean and gather after the reapers among the sheaves: so she came, and hath continued even from the morning until now, that she tarried a little in the house.
7158	234	8	Then said Boaz unto Ruth, Hearest thou not, my daughter? Go not to glean in another field, neither go from hence, but abide here fast by my maidens:
7159	234	9	Let thine eyes be on the field that they do reap, and go thou after them: have I not charged the young men that they shall not touch thee? and when thou art athirst, go unto the vessels, and drink of that which the young men have drawn.
7160	234	10	Then she fell on her face, and bowed herself to the ground, and said unto him, Why have I found grace in thine eyes, that thou shouldest take knowledge of me, seeing I am a stranger?
7161	234	11	And Boaz answered and said unto her, It hath fully been shewed me, all that thou hast done unto thy mother in law since the death of thine husband: and how thou hast left thy father and thy mother, and the land of thy nativity, and art come unto a people which thou knewest not heretofore.
7162	234	12	The LORD recompense thy work, and a full reward be given thee of the LORD God of Israel, under whose wings thou art come to trust.
7163	234	13	Then she said, Let me find favour in thy sight, my lord; for that thou hast comforted me, and for that thou hast spoken friendly unto thine handmaid, though I be not like unto one of thine handmaidens.
7164	234	14	And Boaz said unto her, At mealtime come thou hither, and eat of the bread, and dip thy morsel in the vinegar. And she sat beside the reapers: and he reached her parched corn, and she did eat, and was sufficed, and left.
7165	234	15	And when she was risen up to glean, Boaz commanded his young men, saying, Let her glean even among the sheaves, and reproach her not:
7166	234	16	And let fall also some of the handfuls of purpose for her, and leave them, that she may glean them, and rebuke her not.
7167	234	17	So she gleaned in the field until even, and beat out that she had gleaned: and it was about an ephah of barley.
7168	234	18	And she took it up, and went into the city: and her mother in law saw what she had gleaned: and she brought forth, and gave to her that she had reserved after she was sufficed.
7169	234	19	And her mother in law said unto her, Where hast thou gleaned to day? and where wroughtest thou? blessed be he that did take knowledge of thee. And she shewed her mother in law with whom she had wrought, and said, The man's name with whom I wrought to day is Boaz.
7170	234	20	And Naomi said unto her daughter in law, Blessed be he of the LORD, who hath not left off his kindness to the living and to the dead. And Naomi said unto her, The man is near of kin unto us, one of our next kinsmen.
7171	234	21	And Ruth the Moabitess said, He said unto me also, Thou shalt keep fast by my young men, until they have ended all my harvest.
7172	234	22	And Naomi said unto Ruth her daughter in law, It is good, my daughter, that thou go out with his maidens, that they meet thee not in any other field.
7173	234	23	So she kept fast by the maidens of Boaz to glean unto the end of barley harvest and of wheat harvest; and dwelt with her mother in law.
7174	235	1	THEN Naomi her mother in law said unto her, My daughter, shall I not seek rest for thee, that it may be well with thee?
7175	235	2	And now is not Boaz of our kindred, with whose maidens thou wast? Behold, he winnoweth barley to night in the threshingfloor.
7176	235	3	Wash thyself therefore, and anoint thee, and put thy raiment upon thee, and get thee down to the floor: but make not thyself known unto the man, until he shall have done eating and drinking.
7177	235	4	And it shall be, when he lieth down, that thou shalt mark the place where he shall lie, and thou shalt go in, and uncover his feet, and lay thee down; and he will tell thee what thou shalt do.
7178	235	5	And she said unto her, All that thou sayest unto me I will do.
7179	235	6	And she went down unto the floor, and did according to all that her mother in law bade her.
7180	235	7	And when Boaz had eaten and drunk, and his heart was merry, he went to lie down at the end of the heap of corn: and she came softly, and uncovered his feet, and laid her down.
7181	235	8	And it came to pass at midnight, that the man was afraid, and turned himself: and, behold, a woman lay at his feet.
7182	235	9	And he said, Who art thou? And she answered, I am Ruth thine handmaid: spread therefore thy skirt over thine handmaid; for thou art a near kinsman.
7183	235	10	And he said, Blessed be thou of the LORD, my daughter: for thou hast shewed more kindness in the latter end than at the beginning, inasmuch as thou followedst not young men, whether poor or rich.
7184	235	11	And now, my daughter, fear not; I will do to thee all that thou requirest: for all the city of my people doth know that thou art a virtuous woman.
7185	235	12	And now it is true that I am thy near kinsman: howbeit there is a kinsman nearer than I.
7186	235	13	Tarry this night, and it shall be in the morning, that if he will perform unto thee the part of a kinsman, well; let him do the kinsman's part: but if he will not do the part of a kinsman to thee, then will I do the part of a kinsman to thee, as the LORD liveth: lie down until the morning.
7187	235	14	And she lay at his feet until the morning: and she rose up before one could know another. And he said, Let it not be known that a woman came into the floor.
7188	235	15	Also he said, Bring the vail that thou hast upon thee, and hold it. And when she held it, he measured six measures of barley, and laid it on her: and she went into the city.
7189	235	16	And when she came to her mother in law, she said, Who art thou, my daughter? And she told her all that the man had done to her.
7190	235	17	And she said, These six measures of barley gave he me; for he said to me, Go not empty unto thy mother in law.
7191	235	18	Then said she, Sit still, my daughter, until thou know how the matter will fall: for the man will not be in rest, until he have finished the thing this day.
7192	236	1	THEN went Boaz up to the gate, and sat him down there: and, behold, the kinsman of whom Boaz spake came by; unto whom he said, Ho, such a one! turn aside, sit down here. And he turned aside, and sat down.
7193	236	2	And he took ten men of the elders of the city, and said, Sit ye down here. And they sat down.
7194	236	3	And he said unto the kinsman, Naomi, that is come again out of the country of Moab, selleth a parcel of land, which was our brother Elimelech's:
7195	236	4	And I thought to advertise thee, saying, Buy it before the inhabitants, and before the elders of my people. If thou wilt redeem it, redeem it: but if thou wilt not redeem it, then tell me, that I may know: for there is none to redeem it beside thee; and I am after thee. And he said, I will redeem it.
7196	236	5	Then said Boaz, What day thou buyest the field of the hand of Naomi, thou must buy it also of Ruth the Moabitess, the wife of the dead, to raise up the name of the dead upon his inheritance.
7197	236	6	And the kinsman said, I cannot redeem it for myself, lest I mar mine own inheritance: redeem thou my right to thyself; for I cannot redeem it.
7198	236	7	Now this was the manner in former time in Israel concerning redeeming and concerning changing, for to confirm all things; a man plucked off his shoe, and gave it to his neighbour: and this was a testimony in Israel.
7199	236	8	Therefore the kinsman said unto Boaz, Buy it for thee. So he drew off his shoe.
7200	236	9	And Boaz said unto the elders, and unto all the people, Ye are witnesses this day, that I have bought all that was Elimelech's, and all that was Chilion's and Mahlon's, of the hand of Naomi.
7201	236	10	Moreover Ruth the Moabitess, the wife of Mahlon, have I purchased to be my wife, to raise up the name of the dead upon his inheritance, that the name of the dead be not cut off from among his brethren, and from the gate of his place: ye are witnesses this day.
7202	236	11	And all the people that were in the gate, and the elders, said, We are witnesses. The LORD make the woman that is come into thine house like Rachel and like Leah, which two did build the house of Israel: and do thou worthily in Ephratah, and be famous in Beth-lehem:
7203	236	12	And let thy house be like the house of Pharez, whom Tamar bare unto Judah, of the seed which the LORD shall give thee of this young woman.
7204	236	13	So Boaz took Ruth, and she was his wife: and when he went in unto her, the LORD gave her conception, and she bare a son.
7205	236	14	And the women said unto Naomi, Blessed be the LORD, which hath not left thee this day without a kinsman, that his name may be famous in Israel.
7206	236	15	And he shall be unto thee a restorer of thy life, and a nourisher of thine old age: for thy daughter in law, which loveth thee, which is better to thee than seven sons, hath born him.
7207	236	16	And Naomi took the child, and laid it in her bosom, and became nurse unto it.
7208	236	17	And the women her neighbours gave it a name, saying, There is a son born to Naomi; and they called his name Obed: he is the father of Jesse, the father of David.
7209	236	18	Now these are the generations of Pharez: Pharez begat Hezron,
7210	236	19	And Hezron begat Ram, and Ram begat Amminadab,
7211	236	20	And Amminadab begat Nahshon, and Nahshon begat Salmon,
7212	236	21	And Salmon begat Boaz, and Boaz begat Obed,
7213	236	22	And Obed begat Jesse, and Jesse begat David.
7214	237	1	NOW there was a certain man of Ramathaim-zophim, of mount Ephraim, and his name was Elkanah, the son of Jeroham, the son of Elihu, the son of Tohu, the son of Zuph, an Ephrathite:
7215	237	2	And he had two wives; the name of the one was Hannah, and the name of the other Peninnah: and Peninnah had children, but Hannah had no children.
7216	237	3	And this man went up out of his city yearly to worship and to sacrifice unto the LORD of hosts in Shiloh. And the two sons of Eli, Hophni and Phinehas, the priests of the LORD, were there.
7217	237	4	And when the time was that Elkanah offered, he gave to Peninnah his wife, and to all her sons and her daughters, portions:
7218	237	5	But unto Hannah he gave a worthy portion; for he loved Hannah: but the LORD had shut up her womb.
7219	237	6	And her adversary also provoked her sore, for to make her fret, because the LORD had shut up her womb.
7220	237	7	And as he did so year by year, when she went up to the house of the LORD, so she provoked her; therefore she wept, and did not eat.
7221	237	8	Then said Elkanah her husband to her, Hannah, why weepest thou? and why eatest thou not? and why is thy heart grieved? am not I better to thee than ten sons?
7222	237	9	So Hannah rose up after they had eaten in Shiloh, and after they had drunk. Now Eli the priest sat upon a seat by a post of the temple of the LORD.
7223	237	10	And she was in bitterness of soul, and prayed unto the LORD, and wept sore.
7224	237	11	And she vowed a vow, and said, O LORD of hosts, if thou wilt indeed look on the affliction of thine handmaid, and remember me, and not forget thine handmaid, but wilt give unto thine handmaid a man child, then I will give him unto the LORD all the days of his life, and there shall no razor come upon his head.
7225	237	12	And it came to pass, as she continued praying before the LORD, that Eli marked her mouth.
7226	237	13	Now Hannah, she spake in her heart; only her lips moved, but her voice was not heard: therefore Eli thought she had been drunken.
7227	237	14	And Eli said unto her, How long wilt thou be drunken? put away thy wine from thee.
7228	237	15	And Hannah answered and said, No, my lord, I am a woman of a sorrowful spirit: I have drunk neither wine nor strong drink, but have poured out my soul before the LORD.
7229	237	16	Count not thine handmaid for a daughter of Belial: for out of the abundance of my complaint and grief have I spoken hitherto.
7230	237	17	Then Eli answered and said, Go in peace: and the God of Israel grant thee thy petition that thou hast asked of him.
7231	237	18	And she said, Let thine handmaid find grace in thy sight. So the woman went her way, and did eat, and her countenance was no more sad.
7232	237	19	And they rose up in the morning early, and worshipped before the LORD, and returned, and came to their house to Ramah: and Elkanah knew Hannah his wife; and the LORD remembered her.
7233	237	20	Wherefore it came to pass, when the time was come about after Hannah had conceived, that she bare a son, and called his name Samuel, saying, Because I have asked him of the LORD.
7234	237	21	And the man Elkanah, and all his house, went up to offer unto the LORD the yearly sacrifice, and his vow.
7235	237	22	But Hannah went not up; for she said unto her husband, I will not go up until the child be weaned, and then I will bring him, that he may appear before the LORD, and there abide for ever.
7236	237	23	And Elkanah her husband said unto her, Do what seemeth thee good; tarry until thou have weaned him; only the LORD establish his word. So the woman abode, and gave her son suck until she weaned him.
7237	237	24	And when she had weaned him, she took him up with her, with three bullocks, and one ephah of flour, and a bottle of wine, and brought him unto the house of the LORD in Shiloh: and the child was young.
7238	237	25	And they slew a bullock, and brought the child to Eli.
7239	237	26	And she said, O my lord, as thy soul liveth, my lord, I am the woman that stood by thee here, praying unto the LORD.
7240	237	27	For this child I prayed; and the LORD hath given me my petition which I asked of him:
7241	237	28	Therefore also I have lent him to the LORD; as long as he liveth he shall be lent to the LORD. And he worshipped the LORD there.
7242	238	1	AND Hannah prayed, and said, My heart rejoiceth in the LORD, mine horn is exalted in the LORD: my mouth is enlarged over mine enemies; because I rejoice in thy salvation.
7243	238	2	There is none holy as the LORD: for there is none beside thee: neither is there any rock like our God.
7244	238	3	Talk no more so exceeding proudly; let not arrogancy come out of your mouth: for the LORD is a God of knowledge, and by him actions are weighed.
7245	238	4	The bows of the mighty men are broken, and they that stumbled are girded with strength.
7246	238	5	They that were full have hired out themselves for bread; and they that were hungry ceased: so that the barren hath born seven; and she that hath many children is waxed feeble.
7247	238	6	The LORD killeth, and maketh alive: he bringeth down to the grave, and bringeth up.
7248	238	7	The LORD maketh poor, and maketh rich: he bringeth low, and lifteth up.
7249	238	8	He raiseth up the poor out of the dust, and lifteth up the beggar from the dunghill, to set them among princes, and to make them inherit the throne of glory: for the pillars of the earth are the LORD's, and he hath set the world upon them.
7250	238	9	He will keep the feet of his saints, and the wicked shall be silent in darkness; for by strength shall no man prevail.
7251	238	10	The adversaries of the LORD shall be broken to pieces; out of heaven shall he thunder upon them: the LORD shall judge the ends of the earth; and he shall give strength unto his king, and exalt the horn of his anointed.
7252	238	11	And Elkanah went to Ramah to his house. And the child did minister unto the LORD before Eli the priest.
7253	238	12	Now the sons of Eli were sons of Belial; they knew not the LORD.
7254	238	13	And the priests' custom with the people was, that, when any man offered sacrifice, the priest's servant came, while the flesh was in seething, with a fleshhook of three teeth in his hand;
7255	238	14	And he struck it into the pan, or kettle, or caldron, or pot; all that the fleshhook brought up the priest took for himself. So they did in Shiloh unto all the Israelites that came thither.
7256	238	15	Also before they burnt the fat, the priest's servant came, and said to the man that sacrificed, Give flesh to roast for the priest; for he will not have sodden flesh of thee, but raw.
7257	238	16	And if any man said unto him, Let them not fail to burn the fat presently, and then take as much as thy soul desireth; then he would answer him, Nay; but thou shalt give it me now: and if not, I will take it by force.
7258	238	17	Wherefore the sin of the young men was very great before the LORD: for men abhorred the offering of the LORD.
7259	238	18	But Samuel ministered before the LORD, being a child, girded with a linen ephod.
7260	238	19	Moreover his mother made him a little coat, and brought it to him from year to year, when she came up with her husband to offer the yearly sacrifice.
7261	238	20	And Eli blessed Elkanah and his wife, and said, The LORD give thee seed of this woman for the loan which is lent to the LORD. And they went unto their own home.
7262	238	21	And the LORD visited Hannah, so that she conceived, and bare three sons and two daughters. And the child Samuel grew before the LORD.
7263	238	22	Now Eli was very old, and heard all that his sons did unto all Israel; and how they lay with the women that assembled at the door of the tabernacle of the congregation.
7264	238	23	And he said unto them, Why do ye such things? for I hear of your evil dealings by all this people.
7265	238	24	Nay, my sons; for it is no good report that I hear: ye make the LORD's people to transgress.
7266	238	25	If one man sin against another, the judge shall judge him: but if a man sin against the LORD, who shall intreat for him? Notwithstanding they hearkened not unto the voice of their father, because the LORD would slay them.
7267	238	26	And the child Samuel grew on, and was in favour both with the LORD, and also with men.
7268	238	27	And there came a man of God unto Eli, and said unto him, Thus saith the LORD, Did I plainly appear unto the house of thy father, when they were in Egypt in Pharaoh's house?
7269	238	28	And did I choose him out of all the tribes of Israel to be my priest, to offer upon mine altar, to burn incense, to wear an ephod before me? and did I give unto the house of thy father all the offerings made by fire of the children of Israel?
7270	238	29	Wherefore kick ye at my sacrifice and at mine offering, which I have commanded in my habitation; and honourest thy sons above me, to make yourselves fat with the chiefest of all the offerings of Israel my people?
7271	238	30	Wherefore the LORD God of Israel saith, I said indeed that thy house, and the house of thy father, should walk before me for ever: but now the LORD saith, Be it far from me; for them that honour me I will honour, and they that despise me shall be lightly esteemed.
7272	238	31	Behold, the days come, that I will cut off thine arm, and the arm of thy father's house, that there shall not be an old man in thine house.
7273	238	32	And thou shalt see an enemy in my habitation, in all the wealth which God shall give Israel: and there shall not be an old man in thine house for ever.
7274	238	33	And the man of thine, whom I shall not cut off from mine altar, shall be to consume thine eyes, and to grieve thine heart: and all the increase of thine house shall die in the flower of their age.
7275	238	34	And this shall be a sign unto thee, that shall come upon thy two sons, on Hophni and Phinehas; in one day they shall die both of them.
7276	238	35	And I will raise me up a faithful priest, that shall do according to that which is in mine heart and in my mind: and I will build him a sure house; and he shall walk before mine anointed for ever.
7277	238	36	And it shall come to pass, that every one that is left in thine house shall come and crouch to him for a piece of silver and a morsel of bread, and shall say, Put me, I pray thee, into one of the priests' offices, that I may eat a piece of bread.
7278	239	1	AND the child Samuel ministered unto the LORD before Eli. And the word of the LORD was precious in those days; there was no open vision.
7279	239	2	And it came to pass at that time, when Eli was laid down in his place, and his eyes began to wax dim, that he could not see;
7280	239	3	And ere the lamp of God went out in the temple of the LORD, where the ark of God was, and Samuel was laid down to sleep;
7281	239	4	That the LORD called Samuel: and he answered, Here am I.
7282	239	5	And he ran unto Eli, and said, Here am I; for thou calledst me. And he said, I called not; lie down again. And he went and lay down.
7283	239	6	And the LORD called yet again, Samuel. And Samuel arose and went to Eli, and said, Here am I; for thou didst call me. And he answered, I called not, my son; lie down again.
7284	239	7	Now Samuel did not yet know the LORD, neither was the word of the LORD yet revealed unto him.
7285	239	8	And the LORD called Samuel again the third time. And he arose and went to Eli, and said, Here am I; for thou didst call me. And Eli perceived that the LORD had called the child.
7286	239	9	Therefore Eli said unto Samuel, Go, lie down: and it shall be, if he call thee, that thou shalt say, Speak, LORD; for thy servant heareth. So Samuel went and lay down in his place.
7287	239	10	And the LORD came, and stood, and called as at other times, Samuel, Samuel. Then Samuel answered, Speak; for thy servant heareth.
7288	239	11	And the LORD said to Samuel, Behold, I will do a thing in Israel, at which both the ears of every one that heareth it shall tingle.
7289	239	12	In that day I will perform against Eli all things which I have spoken concerning his house: when I begin, I will also make an end.
7290	239	13	For I have told him that I will judge his house for ever for the iniquity which he knoweth; because his sons made themselves vile, and he restrained them not.
7291	239	14	And therefore I have sworn unto the house of Eli, that the iniquity of Eli's house shall not be purged with sacrifice nor offering for ever.
7292	239	15	And Samuel lay until the morning, and opened the doors of the house of the LORD. And Samuel feared to shew Eli the vision.
7293	239	16	Then Eli called Samuel, and said, Samuel, my son. And he answered, Here am I.
7294	239	17	And he said, What is the thing that the LORD hath said unto thee? I pray thee hide it not from me: God do so to thee, and more also, if thou hide any thing from me of all the things that he said unto thee.
7295	239	18	And Samuel told him every whit, and hid nothing from him. And he said, It is the LORD: let him do what seemeth him good.
7296	239	19	And Samuel grew, and the LORD was with him, and did let none of his words fall to the ground.
7297	239	20	And all Israel from Dan even to Beer-sheba knew that Samuel was established to be a prophet of the LORD.
7298	239	21	And the LORD appeared again in Shiloh: for the LORD revealed himself to Samuel in Shiloh by the word of the LORD.
7299	240	1	AND the word of Samuel came to all Israel. Now Israel went out against the Philistines to battle, and pitched beside Eben-ezer: and the Philistines pitched in Aphek.
7300	240	2	And the Philistines put themselves in array against Israel: and when they joined battle, Israel was smitten before the Philistines: and they slew of the army in the field about four thousand men.
7301	240	3	And when the people were come into the camp, the elders of Israel said, Wherefore hath the LORD smitten us to day before the Philistines? Let us fetch the ark of the covenant of the LORD out of Shiloh unto us, that, when it cometh among us, it may save us out of the hand of our enemies.
7302	240	4	So the people sent to Shiloh, that they might bring from thence the ark of the covenant of the LORD of hosts, which dwelleth between the cherubims: and the two sons of Eli, Hophni and Phinehas, were there with the ark of the covenant of God.
7303	240	5	And when the ark of the covenant of the LORD came into the camp, all Israel shouted with a great shout, so that the earth rang again.
7304	240	6	And when the Philistines heard the noise of the shout, they said, What meaneth the noise of this great shout in the camp of the Hebrews? And they understood that the ark of the LORD was come into the camp.
7305	240	7	And the Philistines were afraid, for they said, God is come into the camp. And they said, Woe unto us! for there hath not been such a thing heretofore.
7306	240	8	Woe unto us! who shall deliver us out of the hand of these mighty Gods? these are the Gods that smote the Egyptians with all the plagues in the wilderness.
7307	240	9	Be strong, and quit yourselves like men, O ye Philistines, that ye be not servants unto the Hebrews, as they have been to you: quit yourselves like men, and fight.
7308	240	10	And the Philistines fought, and Israel was smitten, and they fled every man into his tent: and there was a very great slaughter; for there fell of Israel thirty thousand footmen.
7309	240	11	And the ark of God was taken; and the two sons of Eli, Hophni and Phinehas, were slain.
7310	240	12	And there ran a man of Benjamin out of the army, and came to Shiloh the same day with his clothes rent, and with earth upon his head.
7311	240	13	And when he came, lo, Eli sat upon a seat by the wayside watching: for his heart trembled for the ark of God. And when the man came into the city, and told it, all the city cried out.
7312	240	14	And when Eli heard the noise of the crying, he said, What meaneth the noise of this tumult? And the man came in hastily, and told Eli.
7313	240	15	Now Eli was ninety and eight years old; and his eyes were dim, that he could not see.
7314	240	16	And the man said unto Eli, I am he that came out of the army, and I fled to day out of the army. And he said, What is there done, my son?
7315	240	17	And the messenger answered and said, Israel is fled before the Philistines, and there hath been also a great slaughter among the people, and thy two sons also, Hophni and Phinehas, are dead, and the ark of God is taken.
7316	240	18	And it came to pass, when he made mention of the ark of God, that he fell from off the seat backward by the side of the gate, and his neck brake, and he died: for he was an old man, and heavy. And he had judged Israel forty years.
7317	240	19	And his daughter in law, Phinehas' wife, was with child, near to be delivered: and when she heard the tidings that the ark of God was taken, and that her father in law and her husband were dead, she bowed herself and travailed; for her pains came upon her.
7318	240	20	And about the time of her death the women that stood by her said unto her, Fear not; for thou hast born a son. But she answered not, neither did she regard it.
7319	240	21	And she named the child I-chabod, saying, The glory is departed from Israel: because the ark of God was taken, and because of her father in law and her husband.
7320	240	22	And she said, The glory is departed from Israel: for the ark of God is taken.
7321	241	1	AND the Philistines took the ark of God, and brought it from Eben-ezer unto Ashdod.
7322	241	2	When the Philistines took the ark of God, they brought it into the house of Dagon, and set it by Dagon.
7323	241	3	And when they of Ashdod arose early on the morrow, behold, Dagon was fallen upon his face to the earth before the ark of the LORD. And they took Dagon, and set him in his place again.
7324	241	4	And when they arose early on the morrow morning, behold, Dagon was fallen upon his face to the ground before the ark of the LORD; and the head of Dagon and both the palms of his hands were cut off upon the threshold; only the stump of Dagon was left to him.
7325	241	5	Therefore neither the priests of Dagon, nor any that come into Dagon's house, tread on the threshold of Dagon in Ashdod unto this day.
7326	241	6	But the hand of the LORD was heavy upon them of Ashdod, and he destroyed them, and smote them with emerods, even Ashdod and the coasts thereof.
7327	241	7	And when the men of Ashdod saw that it was so, they said, The ark of the God of Israel shall not abide with us: for his hand is sore upon us, and upon Dagon our god.
7328	241	8	They sent therefore and gathered all the lords of the Philistines unto them, and said, What shall we do with the ark of the God of Israel? And they answered, Let the ark of the God of Israel be carried about unto Gath. And they carried the ark of the God of Israel about thither.
7329	241	9	And it was so, that, after they had carried it about, the hand of the LORD was against the city with a very great destruction: and he smote the men of the city, both small and great, and they had emerods in their secret parts.
7330	241	10	Therefore they sent the ark of God to Ekron. And it came to pass, as the ark of God came to Ekron, that the Ekronites cried out, saying, They have brought about the ark of the God of Israel to us, to slay us and our people.
7331	241	11	So they sent and gathered together all the lords of the Philistines, and said, Send away the ark of the God of Israel, and let it go again to his own place, that it slay us not, and our people: for there was a deadly destruction throughout all the city; the hand of God was very heavy there.
7332	241	12	And the men that died not were smitten with the emerods: and the cry of the city went up to heaven.
7333	242	1	AND the ark of the LORD was in the country of the Philistines seven months.
7334	242	2	And the Philistines called for the priests and the diviners, saying, What shall we do to the ark of the LORD? tell us wherewith we shall send it to his place.
7335	242	3	And they said, If ye send away the ark of the God of Israel, send it not empty; but in any wise return him a trespass offering: then ye shall be healed, and it shall be known to you why his hand is not removed from you.
7336	242	4	Then said they, What shall be the trespass offering which we shall return to him? They answered, Five golden emerods, and five golden mice, according to the number of the lords of the Philistines: for one plague was on you all, and on your lords.
7337	242	5	Wherefore ye shall make images of your emerods, and images of your mice that mar the land; and ye shall give glory unto the God of Israel: peradventure he will lighten his hand from off you, and from off your gods, and from off your land.
7338	242	6	Wherefore then do ye harden your hearts, as the Egyptians and Pharaoh hardened their hearts? when he had wrought wonderfully among them, did they not let the people go, and they departed?
7339	242	7	Now therefore make a new cart, and take two milch kine, on which there hath come no yoke, and tie the kine to the cart, and bring their calves home from them:
7340	242	8	And take the ark of the LORD, and lay it upon the cart; and put the jewels of gold, which ye return him for a trespass offering, in a coffer by the side thereof; and send it away, that it may go.
7341	242	9	And see, if it goeth up by the way of his own coast to Beth-shemesh, then he hath done us this great evil: but if not, then we shall know that it is not his hand that smote us; it was a chance that happened to us.
7342	242	10	And the men did so; and took two milch kine, and tied them to the cart, and shut up their calves at home:
7343	242	11	And they laid the ark of the LORD upon the cart, and the coffer with the mice of gold and the images of their emerods.
7344	242	12	And the kine took the straight way to the way of Beth-shemesh, and went along the highway, lowing as they went, and turned not aside to the right hand or to the left; and the lords of the Philistines went after them unto the border of Beth-shemesh.
7345	242	13	And they of Beth-shemesh were reaping their wheat harvest in the valley: and they lifted up their eyes, and saw the ark, and rejoiced to see it.
7346	242	14	And the cart came into the field of Joshua, a Beth-shemite, and stood there, where there was a great stone: and they clave the wood of the cart, and offered the kine a burnt offering unto the LORD.
7347	242	15	And the Levites took down the ark of the LORD, and the coffer that was with it, wherein the jewels of gold were, and put them on the great stone: and the men of Beth-shemesh offered burnt offerings and sacrificed sacrifices the same day unto the LORD.
7348	242	16	And when the five lords of the Philistines had seen it, they returned to Ekron the same day.
7349	242	17	And these are the golden emerods which the Philistines returned for a trespass offering unto the LORD; for Ashdod one, for Gaza one, for Askelon one, for Gath one, for Ekron one;
7350	242	18	And the golden mice, according to the number of all the cities of the Philistines belonging to the five lords, both of fenced cities, and of country villages, even unto the great stone of Abel, whereon they set down the ark of the LORD: which stone remaineth unto this day in the field of Joshua, the Beth-shemite.
7351	242	19	And he smote the men of Beth-shemesh, because they had looked into the ark of the LORD, even he smote of the people fifty thousand and threescore and ten men: and the people lamented, because the LORD had smitten many of the people with a great slaughter.
7352	242	20	And the men of Beth-shemesh said, Who is able to stand before this holy LORD God? and to whom shall he go up from us?
7353	242	21	And they sent messengers to the inhabitants of Kirjath-jearim, saying, The Philistines have brought again the ark of the LORD; come ye down, and fetch it up to you.
7354	243	1	AND the men of Kirjath-jearim came, and fetched up the ark of the LORD, and brought it into the house of Abinadab in the hill, and sanctified Eleazar his son to keep the ark of the LORD.
7355	243	2	And it came to pass, while the ark abode in Kirjath-jearim, that the time was long; for it was twenty years: and all the house of Israel lamented after the LORD.
7356	243	3	And Samuel spake unto all the house of Israel, saying, If ye do return unto the LORD with all your hearts, then put away the strange gods and Ashtaroth from among you, and prepare your hearts unto the LORD, and serve him only: and he will deliver you out of the hand of the Philistines.
7357	243	4	Then the children of Israel did put away Baalim and Ashtaroth, and served the LORD only.
7358	243	5	And Samuel said, Gather all Israel to Mizpeh, and I will pray for you unto the LORD.
7359	243	6	And they gathered together to Mizpeh, and drew water, and poured it out before the LORD, and fasted on that day, and said there, We have sinned against the LORD. And Samuel judged the children of Israel in Mizpeh.
7360	243	7	And when the Philistines heard that the children of Israel were gathered together to Mizpeh, the lords of the Philistines went up against Israel. And when the children of Israel heard it, they were afraid of the Philistines.
7361	243	8	And the children of Israel said to Samuel, Cease not to cry unto the LORD our God for us, that he will save us out of the hand of the Philistines.
7362	243	9	And Samuel took a sucking lamb, and offered it for a burnt offering wholly unto the LORD: and Samuel cried unto the LORD for Israel; and the LORD heard him.
7363	243	10	And as Samuel was offering up the burnt offering, the Philistines drew near to battle against Israel: but the LORD thundered with a great thunder on that day upon the Philistines, and discomfited them; and they were smitten before Israel.
7364	243	11	And the men of Israel went out of Mizpeh, and pursued the Philistines, and smote them, until they came under Beth-car.
7365	243	12	Then Samuel took a stone, and set it between Mizpeh and Shen, and called the name of it Eben-ezer, saying, Hitherto hath the LORD helped us.
7366	243	13	So the Philistines were subdued, and they came no more into the coast of Israel: and the hand of the LORD was against the Philistines all the days of Samuel.
7367	243	14	And the cities which the Philistines had taken from Israel were restored to Israel, from Ekron even unto Gath; and the coasts thereof did Israel deliver out of the hands of the Philistines. And there was peace between Israel and the Amorites.
7368	243	15	And Samuel judged Israel all the days of his life.
7369	243	16	And he went from year to year in circuit to Beth-el, and Gilgal, and Mizpeh, and judged Israel in all those places.
7370	243	17	And his return was to Ramah; for there was his house; and there he judged Israel; and there he built an altar unto the LORD.
7371	244	1	AND it came to pass, when Samuel was old, that he made his sons judges over Israel.
7372	244	2	Now the name of his firstborn was Joel; and the name of his second, Abiah: they were judges in Beer-sheba.
7373	244	3	And his sons walked not in his ways, but turned aside after lucre, and took bribes, and perverted judgment.
7374	244	4	Then all the elders of Israel gathered themselves together, and came to Samuel unto Ramah,
7375	244	5	And said unto him, Behold, thou art old, and thy sons walk not in thy ways: now make us a king to judge us like all the nations.
7376	244	6	But the thing displeased Samuel, when they said, Give us a king to judge us. And Samuel prayed unto the LORD.
7377	244	7	And the LORD said unto Samuel, Hearken unto the voice of the people in all that they say unto thee: for they have not rejected thee, but they have rejected me, that I should not reign over them.
7378	244	8	According to all the works which they have done since the day that I brought them up out of Egypt even unto this day, wherewith they have forsaken me, and served other gods, so do they also unto thee.
7379	244	9	Now therefore hearken unto their voice: howbeit yet protest solemnly unto them, and shew them the manner of the king that shall reign over them.
7380	244	10	And Samuel told all the words of the LORD unto the people that asked of him a king.
7381	244	11	And he said, This will be the manner of the king that shall reign over you: He will take your sons, and appoint them for himself, for his chariots, and to be his horsemen; and some shall run before his chariots.
7382	244	12	And he will appoint him captains over thousands, and captains over fifties; and will set them to ear his ground, and to reap his harvest, and to make his instruments of war, and instruments of his chariots.
7383	244	13	And he will take your daughters to be confectionaries, and to be cooks, and to be bakers.
7384	244	14	And he will take your fields, and your vineyards, and your oliveyards, even the best of them, and give them to his servants.
7385	244	15	And he will take the tenth of your seed, and of your vineyards, and give to his officers, and to his servants.
7386	244	16	And he will take your menservants, and your maidservants, and your goodliest young men, and your asses, and put them to his work.
7387	244	17	He will take the tenth of your sheep: and ye shall be his servants.
7388	244	18	And ye shall cry out in that day because of your king which ye shall have chosen you; and the LORD will not hear you in that day.
7389	244	19	Nevertheless the people refused to obey the voice of Samuel; and they said, Nay; but we will have a king over us;
7390	244	20	That we also may be like all the nations; and that our king may judge us, and go out before us, and fight our battles.
7391	244	21	And Samuel heard all the words of the people, and he rehearsed them in the ears of the LORD.
7392	244	22	And the LORD said to Samuel, Hearken unto their voice, and make them a king. And Samuel said unto the men of Israel, Go ye every man unto his city.
7393	245	1	NOW there was a man of Benjamin, whose name was Kish, the son of Abiel, the son of Zeror, the son of Bechorath, the son of Aphiah, a Benjamite, a mighty man of power.
7394	245	2	And he had a son, whose name was Saul, a choice young man, and a goodly: and there was not among the children of Israel a goodlier person than he: from his shoulders and upward he was higher than any of the people.
7395	245	3	And the asses of Kish Saul's father were lost. And Kish said to Saul his son, Take now one of the servants with thee, and arise, go seek the asses.
7396	245	4	And he passed through mount Ephraim, and passed through the land of Shalisha, but they found them not: then they passed through the land of Shalim, and there they were not: and he passed through the land of the Benjamites, but they found them not.
7397	245	5	And when they were come to the land of Zuph, Saul said to his servant that was with him, Come, and let us return; lest my father leave caring for the asses, and take thought for us.
7398	245	6	And he said unto him, Behold now, there is in this city a man of God, and he is an honourable man; all that he saith cometh surely to pass: now let us go thither; peradventure he can shew us our way that we should go.
7399	245	7	Then said Saul to his servant, But, behold, if we go, what shall we bring the man? for the bread is spent in our vessels, and there is not a present to bring to the man of God: what have we?
7400	245	8	And the servant answered Saul again, and said, Behold, I have here at hand the fourth part of a shekel of silver: that will I give to the man of God, to tell us our way.
7401	245	9	(Beforetime in Israel, when a man went to enquire of God, thus he spake, Come, and let us go to the seer: for he that is now called a Prophet was beforetime called a Seer.)
7402	245	10	Then said Saul to his servant, Well said; come, let us go. So they went unto the city where the man of God was.
7403	245	11	And as they went up the hill to the city, they found young maidens going out to draw water, and said unto them, Is the seer here?
7404	245	12	And they answered them, and said, He is; behold, he is before you: make haste now, for he came to day to the city; for there is a sacrifice of the people to day in the high place:
7405	245	13	As soon as ye be come into the city, ye shall straightway find him, before he go up to the high place to eat: for the people will not eat until he come, because he doth bless the sacrifice; and afterwards they eat that be bidden. Now therefore get you up; for about this time ye shall find him.
7406	245	14	And they went up into the city: and when they were come into the city, behold, Samuel came out against them, for to go up to the high place.
7407	245	15	Now the LORD had told Samuel in his ear a day before Saul came, saying,
7408	245	16	To morrow about this time I will send thee a man out of the land of Benjamin, and thou shalt anoint him to be captain over my people Israel, that he may save my people out of the hand of the Philistines: for I have looked upon my people, because their cry is come unto me.
7409	245	17	And when Samuel saw Saul, the LORD said unto him, Behold the man whom I spake to thee of! this same shall reign over my people.
7410	245	18	Then Saul drew near to Samuel in the gate, and said, Tell me, I pray thee, where the seer's house is.
7411	245	19	And Samuel answered Saul, and said, I am the seer: go up before me unto the high place; for ye shall eat with me to day, and to morrow I will let thee go, and will tell thee all that is in thine heart.
7412	245	20	And as for thine asses that were lost three days ago, set not thy mind on them; for they are found. And on whom is all the desire of Israel? Is it not on thee, and on all thy father's house?
7413	245	21	And Saul answered and said, Am not I a Benjamite, of the smallest of the tribes of Israel? and my family the least of all the families of the tribe of Benjamin? wherefore then speakest thou so to me?
7414	245	22	And Samuel took Saul and his servant, and brought them into the parlour, and made them sit in the chiefest place among them that were bidden, which were about thirty persons.
7415	245	23	And Samuel said unto the cook, Bring the portion which I gave thee, of which I said unto thee, Set it by thee.
7416	245	24	And the cook took up the shoulder, and that which was upon it, and set it before Saul. And Samuel said, Behold that which is left! set it before thee, and eat: for unto this time hath it been kept for thee since I said, I have invited the people. So Saul did eat with Samuel that day.
7417	245	25	And when they were come down from the high place into the city, Samuel communed with Saul upon the top of the house.
7418	245	26	And they arose early: and it came to pass about the spring of the day, that Samuel called Saul to the top of the house, saying, Up, that I may send thee away. And Saul arose, and they went out both of them, he and Samuel, abroad.
7419	245	27	And as they were going down to the end of the city, Samuel said to Saul, Bid the servant pass on before us, (and he passed on,) but stand thou still a while, that I may shew thee the word of God.
7420	246	1	THEN Samuel took a vial of oil, and poured it upon his head, and kissed him, and said, Is it not because the LORD hath anointed thee to be captain over his inheritance?
7421	246	2	When thou art departed from me to day, then thou shalt find two men by Rachel's sepulchre in the border of Benjamin at Zelzah; and they will say unto thee, The asses which thou wentest to seek are found: and, lo, thy father hath left the care of the asses, and sorroweth for you, saying, What shall I do for my son?
7422	246	3	Then shalt thou go on forward from thence, and thou shalt come to the plain of Tabor, and there shall meet thee three men going up to God to Beth-el, one carrying three kids, and another carrying three loaves of bread, and another carrying a bottle of wine:
7423	246	4	And they will salute thee, and give thee two loaves of bread; which thou shalt receive of their hands.
7424	246	5	After that thou shalt come to the hill of God, where is the garrison of the Philistines: and it shall come to pass, when thou art come thither to the city, that thou shalt meet a company of prophets coming down from the high place with a psaltery, and a tabret, and a pipe, and a harp, before them; and they shall prophesy:
7425	246	6	And the Spirit of the LORD will come upon thee, and thou shalt prophesy with them, and shalt be turned into another man.
7426	246	7	And let it be, when these signs are come unto thee, that thou do as occasion serve thee; for God is with thee.
7427	246	8	And thou shalt go down before me to Gilgal; and, behold, I will come down unto thee, to offer burnt offerings, and to sacrifice sacrifices of peace offerings: seven days shalt thou tarry, till I come to thee, and shew thee what thou shalt do.
7428	246	9	And it was so, that when he had turned his back to go from Samuel, God gave him another heart: and all those signs came to pass that day.
7429	246	10	And when they came thither to the hill, behold, a company of prophets met him; and the Spirit of God came upon him, and he prophesied among them.
7430	246	11	And it came to pass, when all that knew him beforetime saw that, behold, he prophesied among the prophets, then the people said one to another, What is this that is come unto the son of Kish? Is Saul also among the prophets?
7431	246	12	And one of the same place answered and said, But who is their father? Therefore it became a proverb, Is Saul also among the prophets?
7432	246	13	And when he had made an end of prophesying, he came to the high place.
7433	246	14	And Saul's uncle said unto him and to his servant, Whither went ye? And he said, To seek the asses: and when we saw that they were no where, we came to Samuel.
7434	246	15	And Saul's uncle said, Tell me, I pray thee, what Samuel said unto you.
7435	246	16	And Saul said unto his uncle, He told us plainly that the asses were found. But of the matter of the kingdom, whereof Samuel spake, he told him not.
7436	246	17	And Samuel called the people together unto the LORD to Mizpeh;
7437	246	18	And said unto the children of Israel, Thus saith the LORD God of Israel, I brought up Israel out of Egypt, and delivered you out of the hand of the Egyptians, and out of the hand of all kingdoms, and of them that oppressed you:
7438	246	19	And ye have this day rejected your God, who himself saved you out of all your adversities and your tribulations; and ye have said unto him, Nay, but set a king over us. Now therefore present yourselves before the LORD by your tribes, and by your thousands.
7439	246	20	And when Samuel had caused all the tribes of Israel to come near, the tribe of Benjamin was taken.
7440	246	21	When he had caused the tribe of Benjamin to come near by their families, the family of Matri was taken, and Saul the son of Kish was taken: and when they sought him, he could not be found.
7441	246	22	Therefore they enquired of the LORD further, if the man should yet come thither. And the LORD answered, Behold, he hath hid himself among the stuff.
7442	246	23	And they ran and fetched him thence: and when he stood among the people, he was higher than any of the people from his shoulders and upward.
7443	246	24	And Samuel said to all the people, See ye him whom the LORD hath chosen, that there is none like him among all the people? And all the people shouted, and said, God save the king.
7444	246	25	Then Samuel told the people the manner of the kingdom, and wrote it in a book, and laid it up before the LORD. And Samuel sent all the people away, every man to his house.
7445	246	26	And Saul also went home to Gibeah; and there went with him a band of men, whose hearts God had touched.
7446	246	27	But the children of Belial said, How shall this man save us? And they despised him, and brought him no presents. But he held his peace.
7447	247	1	THEN Nahash the Ammonite came up, and encamped against Jabesh-gilead: and all the men of Jabesh said unto Nahash, Make a covenant with us, and we will serve thee.
7448	247	2	And Nahash the Ammonite answered them, On this condition will I make a covenant with you, that I may thrust out all your right eyes, and lay it for a reproach upon all Israel.
7449	247	3	And the elders of Jabesh said unto him, Give us seven days' respite, that we may send messengers unto all the coasts of Israel: and then, if there be no man to save us, we will come out to thee.
7450	247	4	Then came the messengers to Gibeah of Saul, and told the tidings in the ears of the people: and all the people lifted up their voices, and wept.
7451	247	5	And, behold, Saul came after the herd out of the field; and Saul said, What aileth the people that they weep? And they told him the tidings of the men of Jabesh.
7452	247	6	And the Spirit of God came upon Saul when he heard those tidings, and his anger was kindled greatly.
7453	247	7	And he took a yoke of oxen, and hewed them in pieces, and sent them throughout all the coasts of Israel by the hands of messengers, saying, Whosoever cometh not forth after Saul and after Samuel, so shall it be done unto his oxen. And the fear of the LORD fell on the people, and they came out with one consent.
7454	247	8	And when he numbered them in Bezek, the children of Israel were three hundred thousand, and the men of Judah thirty thousand.
7455	247	9	And they said unto the messengers that came, Thus shall ye say unto the men of Jabesh-gilead, To morrow, by that time the sun be hot, ye shall have help. And the messengers came and shewed it to the men of Jabesh; and they were glad.
7456	247	10	Therefore the men of Jabesh said, To morrow we will come out unto you, and ye shall do with us all that seemeth good unto you.
7457	247	11	And it was so on the morrow, that Saul put the people in three companies; and they came into the midst of the host in the morning watch, and slew the Ammonites until the heat of the day: and it came to pass, that they which remained were scattered, so that two of them were not left together.
7458	247	12	And the people said unto Samuel, Who is he that said, Shall Saul reign over us? bring the men, that we may put them to death.
7459	247	13	And Saul said, There shall not a man be put to death this day: for to day the LORD hath wrought salvation in Israel.
7460	247	14	Then said Samuel to the people, Come, and let us go to Gilgal, and renew the kingdom there.
7461	247	15	And all the people went to Gilgal; and there they made Saul king before the LORD in Gilgal; and there they sacrificed sacrifices of peace offerings before the LORD; and there Saul and all the men of Israel rejoiced greatly.
7462	248	1	AND Samuel said unto all Israel, Behold, I have hearkened unto your voice in all that ye said unto me, and have made a king over you.
7463	248	2	And now, behold, the king walketh before you: and I am old and gray-headed; and, behold, my sons are with you: and I have walked before you from my childhood unto this day.
7464	248	3	Behold, here I am: witness against me before the LORD, and before his anointed: whose ox have I taken? or whose ass have I taken? or whom have I defrauded? whom have I oppressed? or of whose hand have I received any bribe to blind mine eyes therewith? and I will restore it you.
7465	248	4	And they said, Thou hast not defrauded us, nor oppressed us, neither hast thou taken ought of any man's hand.
7466	248	5	And he said unto them, The LORD is witness against you, and his anointed is witness this day, that ye have not found ought in my hand. And they answered, He is witness.
7467	248	6	And Samuel said unto the people, It is the LORD that advanced Moses and Aaron, and that brought your fathers up out of the land of Egypt.
7468	248	7	Now therefore stand still, that I may reason with you before the LORD of all the righteous acts of the LORD, which he did to you and to your fathers.
7469	248	8	When Jacob was come into Egypt, and your fathers cried unto the LORD, then the LORD sent Moses and Aaron, which brought forth your fathers out of Egypt, and made them dwell in this place.
7470	248	9	And when they forgat the LORD their God, he sold them into the hand of Sisera, captain of the host of Hazor, and into the hand of the Philistines, and into the hand of the king of Moab, and they fought against them.
7471	248	10	And they cried unto the LORD, and said, We have sinned, because we have forsaken the LORD, and have served Baalim and Ashtaroth: but now deliver us out of the hand of our enemies, and we will serve thee.
7472	248	11	And the LORD sent Jerubbaal, and Bedan, and Jephthah, and Samuel, and delivered you out of the hand of your enemies on every side, and ye dwelled safe.
7473	248	12	And when ye saw that Nahash the king of the children of Ammon came against you, ye said unto me, Nay; but a king shall reign over us: when the LORD your God was your king.
7474	248	13	Now therefore behold the king whom ye have chosen, and whom ye have desired! and, behold, the LORD hath set a king over you.
7475	248	14	If ye will fear the LORD, and serve him, and obey his voice, and not rebel against the commandment of the LORD, then shall both ye and also the king that reigneth over you continue following the LORD your God:
7476	248	15	But if ye will not obey the voice of the LORD, but rebel against the commandment of the LORD, then shall the hand of the LORD be against you, as it was against your fathers.
7477	248	16	Now therefore stand and see this great thing, which the LORD will do before your eyes.
7478	248	17	Is it not wheat harvest to day? I will call unto the LORD, and he shall send thunder and rain; that ye may perceive and see that your wickedness is great, which ye have done in the sight of the LORD, in asking you a king.
7479	248	18	So Samuel called unto the LORD; and the LORD sent thunder and rain that day: and all the people greatly feared the LORD and Samuel.
7480	248	19	And all the people said unto Samuel, Pray for thy servants unto the LORD thy God, that we die not: for we have added unto all our sins this evil, to ask us a king.
7481	248	20	And Samuel said unto the people, Fear not: ye have done all this wickedness: yet turn not aside from following the LORD, but serve the LORD with all your heart;
7482	248	21	And turn ye not aside: for then should ye go after vain things, which cannot profit nor deliver; for they are vain.
7483	248	22	For the LORD will not forsake his people for his great name's sake: because it hath pleased the LORD to make you his people.
7484	248	23	Moreover as for me, God forbid that I should sin against the LORD in ceasing to pray for you: but I will teach you the good and the right way:
7485	248	24	Only fear the LORD, and serve him in truth with all your heart: for consider how great things he hath done for you.
7486	248	25	But if ye shall still do wickedly, ye shall be consumed, both ye and your king.
7487	249	1	SAUL reigned one year; and when he had reigned two years over Israel,
7488	249	2	Saul chose him three thousand men of Israel; whereof two thousand were with Saul in Michmash and in mount Beth-el, and a thousand were with Jonathan in Gibeah of Benjamin: and the rest of the people he sent every man to his tent.
7489	249	3	And Jonathan smote the garrison of the Philistines that was in Geba, and the Philistines heard of it. And Saul blew the trumpet throughout all the land, saying, Let the Hebrews hear.
7490	249	4	And all Israel heard say that Saul had smitten a garrison of the Philistines, and that Israel also was had in abomination with the Philistines. And the people were called together after Saul to Gilgal.
7491	249	5	And the Philistines gathered themselves together to fight with Israel, thirty thousand chariots, and six thousand horsemen, and people as the sand which is on the sea shore in multitude: and they came up, and pitched in Michmash, eastward from Beth-aven.
7492	249	6	When the men of Israel saw that they were in a strait, (for the people were distressed,) then the people did hide themselves in caves, and in thickets, and in rocks, and in high places, and in pits.
7493	249	7	And some of the Hebrews went over Jordan to the land of Gad and Gilead. As for Saul, he was yet in Gilgal, and all the people followed him trembling.
7494	249	8	And he tarried seven days, according to the set time that Samuel had appointed: but Samuel came not to Gilgal; and the people were scattered from him.
7495	249	9	And Saul said, Bring hither a burnt offering to me, and peace offerings. And he offered the burnt offering.
7496	249	10	And it came to pass, that as soon as he had made an end of offering the burnt offering, behold, Samuel came; and Saul went out to meet him, that he might salute him.
7497	249	11	And Samuel said, What hast thou done? And Saul said, Because I saw that the people were scattered from me, and that thou camest not within the days appointed, and that the Philistines gathered themselves together at Michmash;
7498	249	12	Therefore said I, The Philistines will come down now upon me to Gilgal, and I have not made supplication unto the LORD: I forced myself therefore, and offered a burnt offering.
7499	249	13	And Samuel said to Saul, Thou hast done foolishly: thou hast not kept the commandment of the LORD thy God, which he commanded thee: for now would the LORD have established thy kingdom upon Israel for ever.
7500	249	14	But now thy kingdom shall not continue: the LORD hath sought him a man after his own heart, and the LORD hath commanded him to be captain over his people, because thou hast not kept that which the LORD commanded thee.
7501	249	15	And Samuel arose, and gat him up from Gilgal unto Gibeah of Benjamin. And Saul numbered the people that were present with him, about six hundred men.
7502	249	16	And Saul, and Jonathan his son, and the people that were present with them, abode in Gibeah of Benjamin: but the Philistines encamped in Michmash.
7503	249	17	And the spoilers came out of the camp of the Philistines in three companies: one company turned unto the way that leadeth to Ophrah, unto the land of Shual:
7504	249	18	And another company turned the way to Beth-horon: and another company turned to the way of the border that looketh to the valley of Zeboim toward the wilderness.
7505	249	19	Now there was no smith found throughout all the land of Israel: for the Philistines said, Lest the Hebrews make them swords or spears:
7506	249	20	But all the Israelites went down to the Philistines, to sharpen every man his share, and his coulter, and his axe, and his mattock.
7507	249	21	Yet they had a file for the mattocks, and for the coulters, and for the forks, and for the axes, and to sharpen the goads.
7508	249	22	So it came to pass in the day of battle, that there was neither sword nor spear found in the hand of any of the people that were with Saul and Jonathan: but with Saul and with Jonathan his son was there found.
7509	249	23	And the garrison of the Philistines went out to the passage of Michmash.
7510	250	1	NOW it came to pass upon a day, that Jonathan the son of Saul said unto the young man that bare his armour, Come, and let us go over to the Philistines' garrison, that is on the other side. But he told not his father.
7511	250	2	And Saul tarried in the uttermost part of Gibeah under a pomegranate tree which is in Migron: and the people that were with him were about six hundred men;
7512	250	3	And Ahiah, the son of Ahitub, I-chabod's brother, the son of Phinehas, the son of Eli, the LORD'S priest in Shiloh, wearing an ephod. And the people knew not that Jonathan was gone.
7513	250	4	And between the passages, by which Jonathan sought to go over unto the Philistines' garrison, there was a sharp rock on the one side, and a sharp rock on the other side: and the name of the one was Bozez, and the name of the other Seneh.
7514	250	5	The forefront of the one was situate northward over against Michmash, and the other southward over against Gibeah.
7515	250	6	And Jonathan said to the young man that bare his armour, Come, and let us go over unto the garrison of these uncircumcised: it may be that the LORD will work for us: for there is no restraint to the LORD to save by many or by few.
7516	250	7	And his armourbearer said unto him, Do all that is in thine heart: turn thee; behold, I am with thee according to thy heart.
7517	250	8	Then said Jonathan, Behold, we will pass over unto these men, and we will discover ourselves unto them.
7518	250	9	If they say thus unto us, Tarry until we come to you; then we will stand still in our place, and will not go up unto them.
7519	250	10	But if they say thus, Come up unto us; then we will go up: for the LORD hath delivered them into our hand: and this shall be a sign unto us.
7520	250	11	And both of them discovered themselves unto the garrison of the Philistines: and the Philistines said, Behold, the Hebrews come forth out of the holes where they had hid themselves.
7521	250	12	And the men of the garrison answered Jonathan and his armourbearer, and said, Come up to us, and we will shew you a thing. And Jonathan said unto his armourbearer, Come up after me: for the LORD hath delivered them into the hand of Israel.
7522	250	13	And Jonathan climbed up upon his hands and upon his feet, and his armourbearer after him: and they fell before Jonathan; and his armourbearer slew after him.
7523	250	14	And that first slaughter, which Jonathan and his armourbearer made, was about twenty men, within as it were an half acre of land, which a yoke of oxen might plow.
7524	250	15	And there was trembling in the host, in the field, and among all the people: the garrison, and the spoilers, they also trembled, and the earth quaked: so it was a very great trembling.
7525	250	16	And the watchmen of Saul in Gibeah of Benjamin looked; and, behold, the multitude melted away, and they went on beating down one another.
7526	250	17	Then said Saul unto the people that were with him, Number now, and see who is gone from us. And when they had numbered, behold, Jonathan and his armourbearer were not there.
7527	250	18	And Saul said unto Ahiah, Bring hither the ark of God. For the ark of God was at that time with the children of Israel.
7528	250	19	And it came to pass, while Saul talked unto the priest, that the noise that was in the host of the Philistines went on and increased: and Saul said unto the priest, Withdraw thine hand.
7529	250	20	And Saul and all the people that were with him assembled themselves, and they came to the battle: and, behold, every man's sword was against his fellow, and there was a very great discomfiture.
7530	250	21	Moreover the Hebrews that were with the Philistines before that time, which went up with them into the camp from the country round about, even they also turned to be with the Israelites that were with Saul and Jonathan.
7531	250	22	Likewise all the men of Israel which had hid themselves in mount Ephraim, when they heard that the Philistines fled, even they also followed hard after them in the battle.
7532	250	23	So the LORD saved Israel that day: and the battle passed over unto Beth-aven.
7533	250	24	And the men of Israel were distressed that day: for Saul had adjured the people, saying, Cursed be the man that eateth any food until evening, that I may be avenged on mine enemies. So none of the people tasted any food.
7534	250	25	And all they of the land came to a wood; and there was honey upon the ground.
7535	250	26	And when the people were come into the wood, behold, the honey dropped; but no man put his hand to his mouth: for the people feared the oath.
7536	250	27	But Jonathan heard not when his father charged the people with the oath: wherefore he put forth the end of the rod that was in his hand, and dipped it in an honeycomb, and put his hand to his mouth; and his eyes were enlightened.
7537	250	28	Then answered one of the people, and said, Thy father straitly charged the people with an oath, saying, Cursed be the man that eateth any food this day. And the people were faint.
7538	250	29	Then said Jonathan, My father hath troubled the land: see, I pray you, how mine eyes have been enlightened, because I tasted a little of this honey.
7539	250	30	How much more, if haply the people had eaten freely to day of the spoil of their enemies which they found? for had there not been now a much greater slaughter among the Philistines?
7540	250	31	And they smote the Philistines that day from Michmash to Aijalon: and the people were very faint.
7541	250	32	And the people flew upon the spoil, and took sheep, and oxen, and calves, and slew them on the ground: and the people did eat them with the blood.
7542	250	33	Then they told Saul, saying, Behold, the people sin against the LORD, in that they eat with the blood. And he said, Ye have transgressed: roll a great stone unto me this day.
7543	250	34	And Saul said, Disperse yourselves among the people, and say unto them, Bring me hither every man his ox, and every man his sheep, and slay them here, and eat; and sin not against the LORD in eating with the blood. And all the people brought every man his ox with him that night, and slew them there.
7544	250	35	And Saul built an altar unto the LORD: the same was the first altar that he built unto the LORD.
7545	250	36	And Saul said, Let us go down after the Philistines by night, and spoil them until the morning light, and let us not leave a man of them. And they said, Do whatsoever seemeth good unto thee. Then said the priest, Let us draw near hither unto God.
7546	250	37	And Saul asked counsel of God, Shall I go down after the Philistines? wilt thou deliver them into the hand of Israel? But he answered him not that day.
7547	250	38	And Saul said, Draw ye near hither, all the chief of the people: and know and see wherein this sin hath been this day.
7548	250	39	For, as the LORD liveth, which saveth Israel, though it be in Jonathan my son, he shall surely die. But there was not a man among all the people that answered him.
7549	250	40	Then said he unto all Israel, Be ye on one side, and I and Jonathan my son will be on the other side. And the people said unto Saul, Do what seemeth good unto thee.
7550	250	41	Therefore Saul said unto the LORD God of Israel, Give a perfect lot. And Saul and Jonathan were taken: but the people escaped.
7551	250	42	And Saul said, Cast lots between me and Jonathan my son. And Jonathan was taken.
7552	250	43	Then Saul said to Jonathan, Tell me what thou hast done. And Jonathan told him, and said, I did but taste a little honey with the end of the rod that was in mine hand, and, lo, I must die.
7553	250	44	And Saul answered, God do so and more also: for thou shalt surely die, Jonathan.
7554	250	45	And the people said unto Saul, Shall Jonathan die, who hath wrought this great salvation in Israel? God forbid: as the LORD liveth, there shall not one hair of his head fall to the ground; for he hath wrought with God this day. So the people rescued Jonathan, that he died not.
7555	250	46	Then Saul went up from following the Philistines: and the Philistines went to their own place.
7556	250	47	So Saul took the kingdom over Israel, and fought against all his enemies on every side, against Moab, and against the children of Ammon, and against Edom, and against the kings of Zobah, and against the Philistines: and whithersoever he turned himself, he vexed them.
7557	250	48	And he gathered an host, and smote the Amalekites, and delivered Israel out of the hands of them that spoiled them.
7558	250	49	Now the sons of Saul were Jonathan, and Ishui, and Melchi-shua: and the names of his two daughters were these; the name of the firstborn Merab, and the name of the younger Michal:
7559	250	50	And the name of Saul's wife was Ahinoam, the daughter of Ahimaaz: and the name of the captain of his host was Abner, the son of Ner, Saul's uncle.
7560	250	51	And Kish was the father of Saul; and Ner the father of Abner was the son of Abiel.
7561	250	52	And there was sore war against the Philistines all the days of Saul: and when Saul saw any strong man, or any valiant man, he took him unto him.
7562	251	1	SAMUEL also said unto Saul, The LORD sent me to anoint thee to be king over his people, over Israel: now therefore hearken thou unto the voice of the words of the LORD.
7563	251	2	Thus saith the LORD of hosts, I remember that which Amalek did to Israel, how he laid wait for him in the way, when he came up from Egypt.
7564	251	3	Now go and smite Amalek, and utterly destroy all that they have, and spare them not; but slay both man and woman, infant and suckling, ox and sheep, camel and ass.
7565	251	4	And Saul gathered the people together, and numbered them in Telaim, two hundred thousand footmen, and ten thousand men of Judah.
7566	251	5	And Saul came to a city of Amalek, and laid wait in the valley.
7567	251	6	And Saul said unto the Kenites, Go, depart, get you down from among the Amalekites, lest I destroy you with them: for ye shewed kindness to all the children of Israel, when they came up out of Egypt. So the Kenites departed from among the Amalekites.
7568	251	7	And Saul smote the Amalekites from Havilah until thou comest to Shur, that is over against Egypt.
7569	251	8	And he took Agag the king of the Amalekites alive, and utterly destroyed all the people with the edge of the sword.
7570	251	9	But Saul and the people spared Agag, and the best of the sheep, and of the oxen, and of the fatlings, and the lambs, and all that was good, and would not utterly destroy them: but every thing that was vile and refuse, that they destroyed utterly.
7571	251	10	Then came the word of the LORD unto Samuel, saying,
7572	251	11	It repenteth me that I have set up Saul to be king: for he is turned back from following me, and hath not performed my commandments. And it grieved Samuel; and he cried unto the LORD all night.
7573	251	12	And when Samuel rose early to meet Saul in the morning, it was told Samuel, saying, Saul came to Carmel, and, behold, he set him up a place, and is gone about, and passed on, and gone down to Gilgal.
7574	251	13	And Samuel came to Saul: and Saul said unto him, Blessed be thou of the LORD: I have performed the commandment of the LORD.
7575	251	14	And Samuel said, What meaneth then this bleating of the sheep in mine ears, and the lowing of the oxen which I hear?
7576	251	15	And Saul said, They have brought them from the Amalekites: for the people spared the best of the sheep and of the oxen, to sacrifice unto the LORD thy God; and the rest we have utterly destroyed.
7577	251	16	Then Samuel said unto Saul, Stay, and I will tell thee what the LORD hath said to me this night. And he said unto him, Say on.
7578	251	17	And Samuel said, When thou wast little in thine own sight, wast thou not made the head of the tribes of Israel, and the LORD anointed thee king over Israel?
7579	251	18	And the LORD sent thee on a journey, and said, Go and utterly destroy the sinners the Amalekites, and fight against them until they be consumed.
7580	251	19	Wherefore then didst thou not obey the voice of the LORD, but didst fly upon the spoil, and didst evil in the sight of the LORD?
7581	251	20	And Saul said unto Samuel, Yea, I have obeyed the voice of the LORD, and have gone the way which the LORD sent me, and have brought Agag the king of Amalek, and have utterly destroyed the Amalekites.
7582	251	21	But the people took of the spoil, sheep and oxen, the chief of the things which should have been utterly destroyed, to sacrifice unto the LORD thy God in Gilgal.
7583	251	22	And Samuel said, Hath the LORD as great delight in burnt offerings and sacrifices, as in obeying the voice of the LORD? Behold, to obey is better than sacrifice, and to hearken than the fat of rams.
7584	251	23	For rebellion is as the sin of witchcraft, and stubbornness is as iniquity and idolatry. Because thou hast rejected the word of the LORD, he hath also rejected thee from being king.
7585	251	24	And Saul said unto Samuel, I have sinned: for I have transgressed the commandment of the LORD, and thy words: because I feared the people, and obeyed their voice.
7586	251	25	Now therefore, I pray thee, pardon my sin, and turn again with me, that I may worship the LORD.
7587	251	26	And Samuel said unto Saul, I will not return with thee: for thou hast rejected the word of the LORD, and the LORD hath rejected thee from being king over Israel.
7588	251	27	And as Samuel turned about to go away, he laid hold upon the skirt of his mantle, and it rent.
7589	251	28	And Samuel said unto him, The LORD hath rent the kingdom of Israel from thee this day, and hath given it to a neighbour of thine, that is better than thou.
7590	251	29	And also the Strength of Israel will not lie nor repent: for he is not a man, that he should repent.
7591	251	30	Then he said, I have sinned: yet honour me now, I pray thee, before the elders of my people, and before Israel, and turn again with me, that I may worship the LORD thy God.
7592	251	31	So Samuel turned again after Saul; and Saul worshipped the LORD.
7593	251	32	Then said Samuel, Bring ye hither to me Agag the king of the Amalekites. And Agag came unto him delicately. And Agag said, Surely the bitterness of death is past.
7594	251	33	And Samuel said, As thy sword hath made women childless, so shall thy mother be childless among women. And Samuel hewed Agag in pieces before the LORD in Gilgal.
7595	251	34	Then Samuel went to Ramah; and Saul went up to his house to Gibeah of Saul.
7596	251	35	And Samuel came no more to see Saul until the day of his death: nevertheless Samuel mourned for Saul: and the LORD repented that he had made Saul king over Israel.
7597	252	1	AND the LORD said unto Samuel, How long wilt thou mourn for Saul, seeing I have rejected him from reigning over Israel? fill thine horn with oil, and go, I will send thee to Jesse the Beth-lehemite: for I have provided me a king among his sons.
7598	252	2	And Samuel said, How can I go? if Saul hear it, he will kill me. And the LORD said, Take an heifer with thee, and say, I am come to sacrifice to the LORD.
7599	252	3	And call Jesse to the sacrifice, and I will shew thee what thou shalt do: and thou shalt anoint unto me him whom I name unto thee.
7600	252	4	And Samuel did that which the LORD spake, and came to Beth-lehem. And the elders of the town trembled at his coming, and said, Comest thou peaceably?
7601	252	5	And he said, Peaceably: I am come to sacrifice unto the LORD: sanctify yourselves, and come with me to the sacrifice. And he sanctified Jesse and his sons, and called them to the sacrifice.
7602	252	6	And it came to pass, when they were come, that he looked on Eliab, and said, Surely the LORD's anointed is before him.
7603	252	7	But the LORD said unto Samuel, Look not on his countenance, or on the height of his stature; because I have refused him: for the LORD seeth not as man seeth; for man looketh on the outward appearance, but the LORD looketh on the heart.
7604	252	8	Then Jesse called Abinadab, and made him pass before Samuel. And he said, Neither hath the LORD chosen this.
7605	252	9	Then Jesse made Shammah to pass by. And he said, Neither hath the LORD chosen this.
7606	252	10	Again, Jesse made seven of his sons to pass before Samuel. And Samuel said unto Jesse, The LORD hath not chosen these.
7607	252	11	And Samuel said unto Jesse, Are here all thy children? And he said, There remaineth yet the youngest, and, behold, he keepeth the sheep. And Samuel said unto Jesse, Send and fetch him: for we will not sit down till he come hither.
7608	252	12	And he sent, and brought him in. Now he was ruddy, and withal of a beautiful countenance, and goodly to look to. And the LORD said, Arise, anoint him: for this is he.
7609	252	13	Then Samuel took the horn of oil, and anointed him in the midst of his brethren: and the Spirit of the LORD came upon David from that day forward. So Samuel rose up, and went to Ramah.
7610	252	14	But the Spirit of the LORD departed from Saul, and an evil spirit from the LORD troubled him.
7611	252	15	And Saul's servants said unto him, Behold now, an evil spirit from God troubleth thee.
7612	252	16	Let our lord now command thy servants, which are before thee, to seek out a man, who is a cunning player on an harp: and it shall come to pass, when the evil spirit from God is upon thee, that he shall play with his hand, and thou shalt be well.
7613	252	17	And Saul said unto his servants, Provide me now a man that can play well, and bring him to me.
7614	252	18	Then answered one of the servants, and said, Behold, I have seen a son of Jesse the Beth-lehemite, that is cunning in playing, and a mighty valiant man, and a man of war, and prudent in matters, and a comely person, and the LORD is with him.
7615	252	19	Wherefore Saul sent messengers unto Jesse, and said, Send me David thy son, which is with the sheep.
7616	252	20	And Jesse took an ass laden with bread, and a bottle of wine, and a kid, and sent them by David his son unto Saul.
7617	252	21	And David came to Saul, and stood before him: and he loved him greatly; and he became his armourbearer.
7618	252	22	And Saul sent to Jesse, saying, Let David, I pray thee, stand before me; for he hath found favour in my sight.
7619	252	23	And it came to pass, when the evil spirit from God was upon Saul, that David took an harp, and played with his hand: so Saul was refreshed, and was well, and the evil spirit departed from him.
7620	253	1	NOW the Philistines gathered together their armies to battle, and were gathered together at Shochoh, which belongeth to Judah, and pitched between Shochoh and Azekah, in Ephes-dammim.
7621	253	2	And Saul and the men of Israel were gathered together, and pitched by the valley of Elah, and set the battle in array against the Philistines.
7622	253	3	And the Philistines stood on a mountain on the one side, and Israel stood on a mountain on the other side: and there was a valley between them.
7623	253	4	And there went out a champion out of the camp of the Philistines, named Goliath, of Gath, whose height was six cubits and a span.
7624	253	5	And he had an helmet of brass upon his head, and he was armed with a coat of mail; and the weight of the coat was five thousand shekels of brass.
7625	253	6	And he had greaves of brass upon his legs, and a target of brass between his shoulders.
7626	253	7	And the staff of his spear was like a weaver's beam; and his spear's head weighed six hundred shekels of iron: and one bearing a shield went before him.
7627	253	8	And he stood and cried unto the armies of Israel, and said unto them, Why are ye come out to set your battle in array? am not I a Philistine, and ye servants to Saul? choose you a man for you, and let him come down to me.
7628	253	9	If he be able to fight with me, and to kill me, then will we be your servants: but if I prevail against him, and kill him, then shall ye be our servants, and serve us.
7629	253	10	And the Philistine said, I defy the armies of Israel this day; give me a man, that we may fight together.
7630	253	11	When Saul and all Israel heard those words of the Philistine, they were dismayed, and greatly afraid.
7631	253	12	Now David was the son of that Ephrathite of Beth-lehem-judah, whose name was Jesse; and he had eight sons: and the man went among men for an old man in the days of Saul.
7632	253	13	And the three eldest sons of Jesse went and followed Saul to the battle: and the names of his three sons that went to the battle were Eliab the firstborn, and next unto him Abinadab, and the third Shammah.
7633	253	14	And David was the youngest: and the three eldest followed Saul.
7634	253	15	But David went and returned from Saul to feed his father's sheep at Beth-lehem.
7635	253	16	And the Philistine drew near morning and evening, and presented himself forty days.
7636	253	17	And Jesse said unto David his son, Take now for thy brethren an ephah of this parched corn, and these ten loaves, and run to the camp to thy brethren;
7637	253	18	And carry these ten cheeses unto the captain of their thousand, and look how thy brethren fare, and take their pledge.
7638	253	19	Now Saul, and they, and all the men of Israel, were in the valley of Elah, fighting with the Philistines.
7639	253	20	And David rose up early in the morning, and left the sheep with a keeper, and took, and went, as Jesse had commanded him; and he came to the trench, as the host was going forth to the fight, and shouted for the battle.
7640	253	21	For Israel and the Philistines had put the battle in array, army against army.
7641	253	22	And David left his carriage in the hand of the keeper of the carriage, and ran into the army, and came and saluted his brethren.
7642	253	23	And as he talked with them, behold, there came up the champion, the Philistine of Gath, Goliath by name, out of the armies of the Philistines, and spake according to the same words: and David heard them.
7643	253	24	And all the men of Israel, when they saw the man, fled from him, and were sore afraid.
7644	253	25	And the men of Israel said, Have ye seen this man that is come up? surely to defy Israel is he come up: and it shall be, that the man who killeth him, the king will enrich him with great riches, and will give him his daughter, and make his father's house free in Israel.
7645	253	26	And David spake to the men that stood by him, saying, What shall be done to the man that killeth this Philistine, and taketh away the reproach from Israel? for who is this uncircumcised Philistine, that he should defy the armies of the living God?
7646	253	27	And the people answered him after this manner, saying, So shall it be done to the man that killeth him.
7647	253	28	And Eliab his eldest brother heard when he spake unto the men; and Eliab's anger was kindled against David, and he said, Why camest thou down hither? and with whom hast thou left those few sheep in the wilderness? I know thy pride, and the naughtiness of thine heart; for thou art come down that thou mightest see the battle.
7648	253	29	And David said, What have I now done? Is there not a cause?
7649	253	30	And he turned from him toward another, and spake after the same manner: and the people answered him again after the former manner.
7650	253	31	And when the words were heard which David spake, they rehearsed them before Saul: and he sent for him.
7651	253	32	And David said to Saul, Let no man's heart fail because of him; thy servant will go and fight with this Philistine.
7652	253	33	And Saul said to David, Thou art not able to go against this Philistine to fight with him: for thou art but a youth, and he a man of war from his youth.
7653	253	34	And David said unto Saul, Thy servant kept his father's sheep, and there came a lion, and a bear, and took a lamb out of the flock:
7654	253	35	And I went out after him, and smote him, and delivered it out of his mouth: and when he arose against me, I caught him by his beard, and smote him, and slew him.
7655	253	36	Thy servant slew both the lion and the bear: and this uncircumcised Philistine shall be as one of them, seeing he hath defied the armies of the living God.
7656	253	37	David said moreover, The LORD that delivered me out of the paw of the lion, and out of the paw of the bear, he will deliver me out of the hand of this Philistine. And Saul said unto David, Go, and the LORD be with thee.
7657	253	38	And Saul armed David with his armour, and he put an helmet of brass upon his head; also he armed him with a coat of mail.
7658	253	39	And David girded his sword upon his armour, and he assayed to go; for he had not proved it. And David said unto Saul, I cannot go with these; for I have not proved them. And David put them off him.
7659	253	40	And he took his staff in his hand, and chose him five smooth stones out of the brook, and put them in a shepherd's bag which he had, even in a scrip; and his sling was in his hand: and he drew near to the Philistine.
7660	253	41	And the Philistine came on and drew near unto David; and the man that bare the shield went before him.
7661	253	42	And when the Philistine looked about, and saw David, he disdained him: for he was but a youth, and ruddy, and of a fair countenance.
7662	253	43	And the Philistine said unto David, Am I a dog, that thou comest to me with staves? And the Philistine cursed David by his gods.
7663	253	44	And the Philistine said to David, Come to me, and I will give thy flesh unto the fowls of the air, and to the beasts of the field.
7664	253	45	Then said David to the Philistine, Thou comest to me with a sword, and with a spear, and with a shield: but I come to thee in the name of the LORD of hosts, the God of the armies of Israel, whom thou hast defied.
7665	253	46	This day will the LORD deliver thee into mine hand; and I will smite thee, and take thine head from thee; and I will give the carcases of the host of the Philistines this day unto the fowls of the air, and to the wild beasts of the earth; that all the earth may know that there is a God in Israel.
7666	253	47	And all this assembly shall know that the LORD saveth not with sword and spear: for the battle is the LORD's, and he will give you into our hands.
7667	253	48	And it came to pass, when the Philistine arose, and came and drew nigh to meet David, that David hasted, and ran toward the army to meet the Philistine.
7668	253	49	And David put his hand in his bag, and took thence a stone, and slang it, and smote the Philistine in his forehead, that the stone sunk into his forehead; and he fell upon his face to the earth.
7669	253	50	So David prevailed over the Philistine with a sling and with a stone, and smote the Philistine, and slew him; but there was no sword in the hand of David.
7670	253	51	Therefore David ran, and stood upon the Philistine, and took his sword, and drew it out of the sheath thereof, and slew him, and cut off his head therewith. And when the Philistines saw their champion was dead, they fled.
7671	253	52	And the men of Israel and of Judah arose, and shouted, and pursued the Philistines, until thou come to the valley, and to the gates of Ekron. And the wounded of the Philistines fell down by the way to Shaaraim, even unto Gath, and unto Ekron.
7672	253	53	And the children of Israel returned from chasing after the Philistines, and they spoiled their tents.
7673	253	54	And David took the head of the Philistine, and brought it to Jerusalem; but he put his armour in his tent.
7674	253	55	And when Saul saw David go forth against the Philistine, he said unto Abner, the captain of the host, Abner, whose son is this youth? And Abner said, As thy soul liveth, O king, I cannot tell.
7675	253	56	And the king said, Enquire thou whose son the stripling is.
7676	253	57	And as David returned from the slaughter of the Philistine, Abner took him, and brought him before Saul with the head of the Philistine in his hand.
7677	253	58	And Saul said to him, Whose son art thou, thou young man? And David answered, I am the son of thy servant Jesse the Beth-lehemite.
7678	254	1	AND it came to pass, when he had made an end of speaking unto Saul, that the soul of Jonathan was knit with the soul of David, and Jonathan loved him as his own soul.
7679	254	2	And Saul took him that day, and would let him go no more home to his father's house.
7680	254	3	Then Jonathan and David made a covenant, because he loved him as his own soul.
7681	254	4	And Jonathan stripped himself of the robe that was upon him, and gave it to David, and his garments, even to his sword, and to his bow, and to his girdle.
7682	254	5	And David went out whithersoever Saul sent him, and behaved himself wisely: and Saul set him over the men of war, and he was accepted in the sight of all the people, and also in the sight of Saul's servants.
7683	254	6	And it came to pass as they came, when David was returned from the slaughter of the Philistine, that the women came out of all cities of Israel, singing and dancing, to meet king Saul, with tabrets, with joy, and with instruments of musick.
7684	254	7	And the women answered one another as they played, and said, Saul hath slain his thousands, and David his ten thousands.
7685	254	8	And Saul was very wroth, and the saying displeased him; and he said, They have ascribed unto David ten thousands, and to me they have ascribed but thousands: and what can he have more but the kingdom?
7686	254	9	And Saul eyed David from that day and forward.
7687	254	10	And it came to pass on the morrow, that the evil spirit from God came upon Saul, and he prophesied in the midst of the house: and David played with his hand, as at other times: and there was a javelin in Saul's hand.
7688	254	11	And Saul cast the javelin; for he said, I will smite David even to the wall with it. And David avoided out of his presence twice.
7689	254	12	And Saul was afraid of David, because the LORD was with him, and was departed from Saul.
7690	254	13	Therefore Saul removed him from him, and made him his captain over a thousand; and he went out and came in before the people.
7691	254	14	And David behaved himself wisely in all his ways; and the LORD was with him.
7692	254	15	Wherefore when Saul saw that he behaved himself very wisely, he was afraid of him.
7693	254	16	But all Israel and Judah loved David, because he went out and came in before them.
7694	254	17	And Saul said to David, Behold my elder daughter Merab, her will I give thee to wife: only be thou valiant for me, and fight the LORD's battles. For Saul said, Let not mine hand be upon him, but let the hand of the Philistines be upon him.
7695	254	18	And David said unto Saul, Who am I? and what is my life, or my father's family in Israel, that I should be son in law to the king?
7696	254	19	But it came to pass at the time when Merab Saul's daughter should have been given to David, that she was given unto Adriel the Meholathite to wife.
7697	254	20	And Michal Saul's daughter loved David: and they told Saul, and the thing pleased him.
7698	254	21	And Saul said, I will give him her, that she may be a snare to him, and that the hand of the Philistines may be against him. Wherefore Saul said to David, Thou shalt this day be my son in law in the one of the twain.
7699	254	22	And Saul commanded his servants, saying, Commune with David secretly, and say, Behold, the king hath delight in thee, and all his servants love thee: now therefore be the king's son in law.
7700	254	23	And Saul's servants spake those words in the ears of David. And David said, Seemeth it to you a light thing to be a king's son in law, seeing that I am a poor man, and lightly esteemed?
7701	254	24	And the servants of Saul told him, saying, On this manner spake David.
7702	254	25	And Saul said, Thus shall ye say to David, The king desireth not any dowry, but an hundred foreskins of the Philistines, to be avenged of the king's enemies. But Saul thought to make David fall by the hand of the Philistines.
7703	254	26	And when his servants told David these words, it pleased David well to be the king's son in law: and the days were not expired.
7704	254	27	Wherefore David arose and went, he and his men, and slew of the Philistines two hundred men; and David brought their foreskins, and they gave them in full tale to the king, that he might be the king's son in law. And Saul gave him Michal his daughter to wife.
7705	254	28	And Saul saw and knew that the LORD was with David, and that Michal Saul's daughter loved him.
7706	254	29	And Saul was yet the more afraid of David; and Saul became David's enemy continually.
7707	254	30	Then the princes of the Philistines went forth: and it came to pass, after they went forth, that David behaved himself more wisely than all the servants of Saul; so that his name was much set by.
7708	255	1	AND Saul spake to Jonathan his son, and to all his servants, that they should kill David.
7709	255	2	But Jonathan Saul's son delighted much in David: and Jonathan told David, saying, Saul my father seeketh to kill thee: now therefore, I pray thee, take heed to thyself until the morning, and abide in a secret place, and hide thyself:
7710	255	3	And I will go out and stand beside my father in the field where thou art, and I will commune with my father of thee; and what I see, that I will tell thee.
7711	255	4	And Jonathan spake good of David unto Saul his father, and said unto him, Let not the king sin against his servant, against David; because he hath not sinned against thee, and because his works have been to thee-ward very good:
7712	255	5	For he did put his life in his hand, and slew the Philistine, and the LORD wrought a great salvation for all Israel: thou sawest it, and didst rejoice: wherefore then wilt thou sin against innocent blood, to slay David without a cause?
7713	255	6	And Saul hearkened unto the voice of Jonathan: and Saul sware, As the LORD liveth, he shall not be slain.
7714	255	7	And Jonathan called David, and Jonathan shewed him all those things. And Jonathan brought David to Saul, and he was in his presence, as in times past.
7715	255	8	And there was war again: and David went out, and fought with the Philistines, and slew them with a great slaughter; and they fled from him.
7716	255	9	And the evil spirit from the LORD was upon Saul, as he sat in his house with his javelin in his hand: and David played with his hand.
7717	255	10	And Saul sought to smite David even to the wall with the javelin; but he slipped away out of Saul's presence, and he smote the javelin into the wall: and David fled, and escaped that night.
7718	255	11	Saul also sent messengers unto David's house, to watch him, and to slay him in the morning: and Michal David's wife told him, saying, If thou save not thy life to night, to morrow thou shalt be slain.
7719	255	12	So Michal let David down through a window: and he went, and fled, and escaped.
7720	255	13	And Michal took an image, and laid it in the bed, and put a pillow of goats' hair for his bolster, and covered it with a cloth.
7721	255	14	And when Saul sent messengers to take David, she said, He is sick.
7722	255	15	And Saul sent the messengers again to see David, saying, Bring him up to me in the bed, that I may slay him.
7723	255	16	And when the messengers were come in, behold, there was an image in the bed, with a pillow of goats' hair for his bolster.
7724	255	17	And Saul said unto Michal, Why hast thou deceived me so, and sent away mine enemy, that he is escaped? And Michal answered Saul, He said unto me, Let me go; why should I kill thee?
7725	255	18	So David fled, and escaped, and came to Samuel to Ramah, and told him all that Saul had done to him. And he and Samuel went and dwelt in Naioth.
7726	255	19	And it was told Saul, saying, Behold, David is at Naioth in Ramah.
7727	255	20	And Saul sent messengers to take David: and when they saw the company of the prophets prophesying, and Samuel standing as appointed over them, the Spirit of God was upon the messengers of Saul, and they also prophesied.
7728	255	21	And when it was told Saul, he sent other messengers, and they prophesied likewise. And Saul sent messengers again the third time, and they prophesied also.
7729	255	22	Then went he also to Ramah, and came to a great well that is in Sechu: and he asked and said, Where are Samuel and David? And one said, Behold, they be at Naioth in Ramah.
7730	255	23	And he went thither to Naioth in Ramah: and the Spirit of God was upon him also, and he went on, and prophesied, until he came to Naioth in Ramah.
7731	255	24	And he stripped off his clothes also, and prophesied before Samuel in like manner, and lay down naked all that day and all that night. Wherefore they say, Is Saul also among the prophets?
7732	256	1	AND David fled from Naioth in Ramah, and came and said before Jonathan, What have I done? what is mine iniquity? and what is my sin before thy father, that he seeketh my life?
7733	256	2	And he said unto him, God forbid; thou shalt not die: behold, my father will do nothing either great or small, but that he will shew it me: and why should my father hide this thing from me? it is not so.
7734	256	3	And David sware moreover, and said, Thy father certainly knoweth that I have found grace in thine eyes; and he saith, Let not Jonathan know this, lest he be grieved: but truly as the LORD liveth, and as thy soul liveth, there is but a step between me and death.
7735	256	4	Then said Jonathan unto David, Whatsoever thy soul desireth, I will even do it for thee.
7736	256	5	And David said unto Jonathan, Behold, to morrow is the new moon, and I should not fail to sit with the king at meat: but let me go, that I may hide myself in the field unto the third day at even.
7737	256	6	If thy father at all miss me, then say, David earnestly asked leave of me that he might run to Beth-lehem his city: for there is a yearly sacrifice there for all the family.
7738	256	7	If he say thus, It is well; thy servant shall have peace: but if he be very wroth, then be sure that evil is determined by him.
7739	256	8	Therefore thou shalt deal kindly with thy servant; for thou hast brought thy servant into a covenant of the LORD with thee: notwithstanding, if there be in me iniquity, slay me thyself; for why shouldest thou bring me to thy father?
7740	256	9	And Jonathan said, Far be it from thee: for if I knew certainly that evil were determined by my father to come upon thee, then would not I tell it thee?
7741	256	10	Then said David to Jonathan, Who shall tell me? or what if thy father answer thee roughly?
7742	256	11	And Jonathan said unto David, Come, and let us go out into the field. And they went out both of them into the field.
7743	256	12	And Jonathan said unto David, O LORD God of Israel, when I have sounded my father about to morrow any time, or the third day, and, behold, if there be good toward David, and I then send not unto thee, and shew it thee;
7744	256	13	The LORD do so and much more to Jonathan: but if it please my father to do thee evil, then I will shew it thee, and send thee away, that thou mayest go in peace: and the LORD be with thee, as he hath been with my father.
7745	256	14	And thou shalt not only while yet I live shew me the kindness of the LORD, that I die not:
7746	256	15	But also thou shalt not cut off thy kindness from my house for ever: no, not when the LORD hath cut off the enemies of David every one from the face of the earth.
7747	256	16	So Jonathan made a covenant with the house of David, saying, Let the LORD even require it at the hand of David's enemies.
7748	256	17	And Jonathan caused David to swear again, because he loved him: for he loved him as he loved his own soul.
7749	256	18	Then Jonathan said to David, To morrow is the new moon: and thou shalt be missed, because thy seat will be empty.
7750	256	19	And when thou hast stayed three days, then thou shalt go down quickly, and come to the place where thou didst hide thyself when the business was in hand, and shalt remain by the stone Ezel.
7751	256	20	And I will shoot three arrows on the side thereof, as though I shot at a mark.
7752	256	21	And, behold, I will send a lad, saying, Go, find out the arrows. If I expressly say unto the lad, Behold, the arrows are on this side of thee, take them; then come thou: for there is peace to thee, and no hurt; as the LORD liveth.
7753	256	22	But if I say thus unto the young man, Behold, the arrows are beyond thee; go thy way: for the LORD hath sent thee away.
7754	256	23	And as touching the matter which thou and I have spoken of, behold, the LORD be between thee and me for ever.
7755	256	24	So David hid himself in the field: and when the new moon was come, the king sat him down to eat meat.
7756	256	25	And the king sat upon his seat, as at other times, even upon a seat by the wall: and Jonathan arose, and Abner sat by Saul's side, and David's place was empty.
7757	256	26	Nevertheless Saul spake not any thing that day: for he thought, Something hath befallen him, he is not clean; surely he is not clean.
7758	256	27	And it came to pass on the morrow, which was the second day of the month, that David's place was empty: and Saul said unto Jonathan his son, Wherefore cometh not the son of Jesse to meat, neither yesterday, nor to day?
7759	256	28	And Jonathan answered Saul, David earnestly asked leave of me to go to Beth-lehem:
7760	256	29	And he said, Let me go, I pray thee; for our family hath a sacrifice in the city; and my brother, he hath commanded me to be there: and now, if I have found favour in thine eyes, let me get away, I pray thee, and see my brethren. Therefore he cometh not unto the king's table.
7761	256	30	Then Saul's anger was kindled against Jonathan, and he said unto him, Thou son of the perverse rebellious woman, do not I know that thou hast chosen the son of Jesse to thine own confusion, and unto the confusion of thy mother's nakedness?
7762	256	31	For as long as the son of Jesse liveth upon the ground, thou shalt not be established, nor thy kingdom. Wherefore now send and fetch him unto me, for he shall surely die.
7763	256	32	And Jonathan answered Saul his father, and said unto him, Wherefore shall he be slain? what hath he done?
7764	256	33	And Saul cast a javelin at him to smite him: whereby Jonathan knew that it was determined of his father to slay David.
7765	256	34	So Jonathan arose from the table in fierce anger, and did eat no meat the second day of the month: for he was grieved for David, because his father had done him shame.
7766	256	35	And it came to pass in the morning, that Jonathan went out into the field at the time appointed with David, and a little lad with him.
7767	256	36	And he said unto his lad, Run, find out now the arrows which I shoot. And as the lad ran, he shot an arrow beyond him.
7768	256	37	And when the lad was come to the place of the arrow which Jonathan had shot, Jonathan cried after the lad, and said, Is not the arrow beyond thee?
7769	256	38	And Jonathan cried after the lad, Make speed, haste, stay not. And Jonathan's lad gathered up the arrows, and came to his master.
7770	256	39	But the lad knew not any thing: only Jonathan and David knew the matter.
7771	256	40	And Jonathan gave his artillery unto his lad, and said unto him, Go, carry them to the city.
7772	256	41	And as soon as the lad was gone, David arose out of a place toward the south, and fell on his face to the ground, and bowed himself three times: and they kissed one another, and wept one with another, until David exceeded.
7773	256	42	And Jonathan said to David, Go in peace, forasmuch as we have sworn both of us in the name of the LORD, saying, The LORD be between me and thee, and between my seed and thy seed for ever. And he arose and departed: and Jonathan went into the city.
7774	257	1	THEN came David to Nob to Ahimelech the priest: and Ahimelech was afraid at the meeting of David, and said unto him, Why art thou alone, and no man with thee?
7775	257	2	And David said unto Ahimelech the priest, The king hath commanded me a business, and hath said unto me, Let no man know any thing of the business whereabout I send thee, and what I have commanded thee: and I have appointed my servants to such and such a place.
7776	257	3	Now therefore what is under thine hand? give me five loaves of bread in mine hand, or what there is present.
7777	257	4	And the priest answered David, and said, There is no common bread under mine hand, but there is hallowed bread; if the young men have kept themselves at least from women.
7778	257	5	And David answered the priest, and said unto him, Of a truth women have been kept from us about these three days, since I came out, and the vessels of the young men are holy, and the bread is in a manner common, yea, though it were sanctified this day in the vessel.
7779	257	6	So the priest gave him hallowed bread: for there was no bread there but the shewbread, that was taken from before the LORD, to put hot bread in the day when it was taken away.
7780	257	7	Now a certain man of the servants of Saul was there that day, detained before the LORD; and his name was Doeg, an Edomite, the chiefest of the herdmen that belonged to Saul.
7781	257	8	And David said unto Ahimelech, And is there not here under thine hand spear or sword? for I have neither brought my sword nor my weapons with me, because the king's business required haste.
7782	257	9	And the priest said, The sword of Goliath the Philistine, whom thou slewest in the valley of Elah, behold, it is here wrapped in a cloth behind the ephod: if thou wilt take that, take it: for there is no other save that here. And David said, There is none like that; give it me.
7783	257	10	And David arose, and fled that day for fear of Saul, and went to Achish the king of Gath.
7784	257	11	And the servants of Achish said unto him, Is not this David the king of the land? did they not sing one to another of him in dances, saying, Saul hath slain his thousands, and David his ten thousands?
7785	257	12	And David laid up these words in his heart, and was sore afraid of Achish the king of Gath.
7786	257	13	And he changed his behaviour before them, and feigned himself mad in their hands, and scrabbled on the doors of the gate, and let his spittle fall down upon his beard.
7787	257	14	Then said Achish unto his servants, Lo, ye see the man is mad: wherefore then have ye brought him to me?
7788	257	15	Have I need of mad men, that ye have brought this fellow to play the mad man in my presence? shall this fellow come into my house?
7789	258	1	DAVID therefore departed thence, and escaped to the cave Adullam: and when his brethren and all his father's house heard it, they went down thither to him.
7790	258	2	And every one that was in distress, and every one that was in debt, and every one that was discontented, gathered themselves unto him; and he became a captain over them: and there were with him about four hundred men.
7791	258	3	And David went thence to Mizpeh of Moab: and he said unto the king of Moab, Let my father and my mother, I pray thee, come forth, and be with you, till I know what God will do for me.
7792	258	4	And he brought them before the king of Moab: and they dwelt with him all the while that David was in the hold.
7793	258	5	And the prophet Gad said unto David, Abide not in the hold; depart, and get thee into the land of Judah. Then David departed, and came into the forest of Hareth.
7794	258	6	When Saul heard that David was discovered, and the men that were with him, (now Saul abode in Gibeah under a tree in Ramah, having his spear in his hand, and all his servants were standing about him;)
7795	258	7	Then Saul said unto his servants that stood about him, Hear now, ye Benjamites; will the son of Jesse give every one of you fields and vineyards, and make you all captains of thousands, and captains of hundreds;
7796	258	8	That all of you have conspired against me, and there is none that sheweth me that my son hath made a league with the son of Jesse, and there is none of you that is sorry for me, or sheweth unto me that my son hath stirred up my servant against me, to lie in wait, as at this day?
7797	258	9	Then answered Doeg the Edomite, which was set over the servants of Saul, and said, I saw the son of Jesse coming to Nob, to Ahimelech the son of Ahitub.
7798	258	10	And he enquired of the LORD for him, and gave him victuals, and gave him the sword of Goliath the Philistine.
7799	258	11	Then the king sent to call Ahimelech the priest, the son of Ahitub, and all his father's house, the priests that were in Nob: and they came all of them to the king.
7800	258	12	And Saul said, Hear now, thou son of Ahitub. And he answered, Here I am, my lord.
7801	258	13	And Saul said unto him, Why have ye conspired against me, thou and the son of Jesse, in that thou hast given him bread, and a sword, and hast enquired of God for him, that he should rise against me, to lie in wait, as at this day?
7802	258	14	Then Ahimelech answered the king, and said, And who is so faithful among all thy servants as David, which is the king's son in law, and goeth at thy bidding, and is honourable in thine house?
7803	258	15	Did I then begin to enquire of God for him? be it far from me: let not the king impute any thing unto his servant, nor to all the house of my father: for thy servant knew nothing of all this, less or more.
7804	258	16	And the king said, Thou shalt surely die, Ahimelech, thou, and all thy father's house.
7805	258	17	And the king said unto the footmen that stood about him, Turn, and slay the priests of the LORD; because their hand also is with David, and because they knew when he fled, and did not shew it to me. But the servants of the king would not put forth their hand to fall upon the priests of the LORD.
7806	258	18	And the king said to Doeg, Turn thou, and fall upon the priests. And Doeg the Edomite turned, and he fell upon the priests, and slew on that day fourscore and five persons that did wear a linen ephod.
7807	258	19	And Nob, the city of the priests, smote he with the edge of the sword, both men and women, children and sucklings, and oxen, and asses, and sheep, with the edge of the sword.
7808	258	20	And one of the sons of Ahimelech the son of Ahitub, named Abiathar, escaped, and fled after David.
7809	258	21	And Abiathar shewed David that Saul had slain the LORD's priests.
7810	258	22	And David said unto Abiathar, I knew it that day, when Doeg the Edomite was there, that he would surely tell Saul: I have occasioned the death of all the persons of thy father's house.
7811	258	23	Abide thou with me, fear not: for he that seeketh my life seeketh thy life: but with me thou shalt be in safeguard.
7812	259	1	THEN they told David, saying, Behold, the Philistines fight against Keilah, and they rob the threshingfloors.
7813	259	2	Therefore David enquired of the LORD, saying, Shall I go and smite these Philistines? And the LORD said unto David, Go, and smite the Philistines, and save Keilah.
7814	259	3	And David's men said unto him, Behold, we be afraid here in Judah: how much more then if we come to Keilah against the armies of the Philistines?
7815	259	4	Then David enquired of the LORD yet again. And the LORD answered him and said, Arise, go down to Keilah; for I will deliver the Philistines into thine hand.
7816	259	5	So David and his men went to Keilah, and fought with the Philistines, and brought away their cattle, and smote them with a great slaughter. So David saved the inhabitants of Keilah.
7817	259	6	And it came to pass, when Abiathar the son of Ahimelech fled to David to Keilah, that he came down with an ephod in his hand.
7818	259	7	And it was told Saul that David was come to Keilah. And Saul said, God hath delivered him into mine hand; for he is shut in, by entering into a town that hath gates and bars.
7819	259	8	And Saul called all the people together to war, to go down to Keilah, to besiege David and his men.
7820	259	9	And David knew that Saul secretly practised mischief against him; and he said to Abiathar the priest, Bring hither the ephod.
7821	259	10	Then said David, O LORD God of Israel, thy servant hath certainly heard that Saul seeketh to come to Keilah, to destroy the city for my sake.
7822	259	11	Will the men of Keilah deliver me up into his hand? will Saul come down, as thy servant hath heard? O LORD God of Israel, I beseech thee, tell thy servant. And the LORD said, He will come down.
7823	259	12	Then said David, Will the men of Keilah deliver me and my men into the hand of Saul? And the LORD said, They will deliver thee up.
7824	259	13	Then David and his men, which were about six hundred, arose and departed out of Keilah, and went whithersoever they could go. And it was told Saul that David was escaped from Keilah; and he forbare to go forth.
7825	259	14	And David abode in the wilderness in strong holds, and remained in a mountain in the wilderness of Ziph. And Saul sought him every day, but God delivered him not into his hand.
7826	259	15	And David saw that Saul was come out to seek his life: and David was in the wilderness of Ziph in a wood.
7827	259	16	And Jonathan Saul's son arose, and went to David into the wood, and strengthened his hand in God.
7828	259	17	And he said unto him, Fear not: for the hand of Saul my father shall not find thee; and thou shalt be king over Israel, and I shall be next unto thee; and that also Saul my father knoweth.
7829	259	18	And they two made a covenant before the LORD: and David abode in the wood, and Jonathan went to his house.
7830	259	19	Then came up the Ziphites to Saul to Gibeah, saying, Doth not David hide himself with us in strong holds in the wood, in the hill of Hachilah, which is on the south of Jeshimon?
7831	259	20	Now therefore, O king, come down according to all the desire of thy soul to come down; and our part shall be to deliver him into the king's hand.
7832	259	21	And Saul said, Blessed be ye of the LORD; for ye have compassion on me.
7833	259	22	Go, I pray you, prepare yet, and know and see his place where his haunt is, and who hath seen him there: for it is told me that he dealeth very subtilly.
7834	259	23	See therefore, and take knowledge of all the lurking places where he hideth himself, and come ye again to me with the certainty, and I will go with you: and it shall come to pass, if he be in the land, that I will search him out throughout all the thousands of Judah.
7835	259	24	And they arose, and went to Ziph before Saul: but David and his men were in the wilderness of Maon, in the plain on the south of Jeshimon.
7836	259	25	Saul also and his men went to seek him. And they told David: wherefore he came down into a rock, and abode in the wilderness of Maon. And when Saul heard that, he pursued after David in the wilderness of Maon.
7837	259	26	And Saul went on this side of the mountain, and David and his men on that side of the mountain: and David made haste to get away for fear of Saul; for Saul and his men compassed David and his men round about to take them.
7838	259	27	But there came a messenger unto Saul, saying, Haste thee, and come; for the Philistines have invaded the land.
7839	259	28	Wherefore Saul returned from pursuing after David, and went against the Philistines: therefore they called that place Sela-hammahlekoth.
7840	259	29	And David went up from thence, and dwelt in strong holds at En-gedi.
7841	260	1	AND it came to pass, when Saul was returned from following the Philistines, that it was told him, saying, Behold, David is in the wilderness of En-gedi.
7842	260	2	Then Saul took three thousand chosen men out of all Israel, and went to seek David and his men upon the rocks of the wild goats.
7843	260	3	And he came to the sheepcotes by the way, where was a cave; and Saul went in to cover his feet: and David and his men remained in the sides of the cave.
7844	260	4	And the men of David said unto him, Behold the day of which the LORD said unto thee, Behold, I will deliver thine enemy into thine hand, that thou mayest do to him as it shall seem good unto thee. Then David arose, and cut off the skirt of Saul's robe privily.
7845	260	5	And it came to pass afterward, that David's heart smote him, because he had cut off Saul's skirt.
7846	260	6	And he said unto his men, The LORD forbid that I should do this thing unto my master, the LORD's anointed, to stretch forth mine hand against him, seeing he is the anointed of the LORD.
7847	260	7	So David stayed his servants with these words, and suffered them not to rise against Saul. But Saul rose up out of the cave, and went on his way.
7848	260	8	David also arose afterward, and went out of the cave, and cried after Saul, saying, My lord the king. And when Saul looked behind him, David stooped with his face to the earth, and bowed himself.
7849	260	9	And David said to Saul, Wherefore hearest thou men's words, saying, Behold, David seeketh thy hurt?
7850	260	10	Behold, this day thine eyes have seen how that the LORD had delivered thee to day into mine hand in the cave: and some bade me kill thee: but mine eye spared thee; and I said, I will not put forth mine hand against my lord; for he is the LORD's anointed.
7851	260	11	Moreover, my father, see, yea, see the skirt of thy robe in my hand: for in that I cut off the skirt of thy robe, and killed thee not, know thou and see that there is neither evil nor transgression in mine hand, and I have not sinned against thee; yet thou huntest my soul to take it.
7852	260	12	The LORD judge between me and thee, and the LORD avenge me of thee: but mine hand shall not be upon thee.
7853	260	13	As saith the proverb of the ancients, Wickedness proceedeth from the wicked: but mine hand shall not be upon thee.
7854	260	14	After whom is the king of Israel come out? after whom dost thou pursue? after a dead dog, after a flea.
7855	260	15	The LORD therefore be judge, and judge between me and thee, and see, and plead my cause, and deliver me out of thine hand.
7856	260	16	And it came to pass, when David had made an end of speaking these words unto Saul, that Saul said, Is this thy voice, my son David? And Saul lifted up his voice, and wept.
7857	260	17	And he said to David, Thou art more righteous than I: for thou hast rewarded me good, whereas I have rewarded thee evil.
7858	260	18	And thou hast shewed this day how that thou hast dealt well with me: forasmuch as when the LORD had delivered me into thine hand, thou killedst me not.
7859	260	19	For if a man find his enemy, will he let him go well away? wherefore the LORD reward thee good for that thou hast done unto me this day.
7860	260	20	And now, behold, I know well that thou shalt surely be king, and that the kingdom of Israel shall be established in thine hand.
7861	260	21	Swear now therefore unto me by the LORD, that thou wilt not cut off my seed after me, and that thou wilt not destroy my name out of my father's house.
7862	260	22	And David sware unto Saul. And Saul went home; but David and his men gat them up unto the hold.
7863	261	1	AND Samuel died; and all the Israelites were gathered together, and lamented him, and buried him in his house at Ramah. And David arose, and went down to the wilderness of Paran.
7864	261	2	And there was a man in Maon, whose possessions were in Carmel; and the man was very great, and he had three thousand sheep, and a thousand goats: and he was shearing his sheep in Carmel.
7865	261	3	Now the name of the man was Nabal; and the name of his wife Abigail: and she was a woman of good understanding, and of a beautiful countenance: but the man was churlish and evil in his doings; and he was of the house of Caleb.
7866	261	4	And David heard in the wilderness that Nabal did shear his sheep.
7867	261	5	And David sent out ten young men, and David said unto the young men, Get you up to Carmel, and go to Nabal, and greet him in my name:
7868	261	6	And thus shall ye say to him that liveth in prosperity, Peace be both to thee, and peace be to thine house, and peace be unto all that thou hast.
7869	261	7	And now I have heard that thou hast shearers: now thy shepherds which were with us, we hurt them not, neither was there ought missing unto them, all the while they were in Carmel.
7870	261	8	Ask thy young men, and they will shew thee. Wherefore let the young men find favour in thine eyes: for we come in a good day: give, I pray thee, whatsoever cometh to thine hand unto thy servants, and to thy son David.
7871	261	9	And when David's young men came, they spake to Nabal according to all those words in the name of David, and ceased.
7872	261	10	And Nabal answered David's servants, and said, Who is David? and who is the son of Jesse? there be many servants now a days that break away every man from his master.
7873	261	11	Shall I then take my bread, and my water, and my flesh that I have killed for my shearers, and give it unto men, whom I know not whence they be?
7874	261	12	So David's young men turned their way, and went again, and came and told him all those sayings.
7875	261	13	And David said unto his men, Gird ye on every man his sword. And they girded on every man his sword; and David also girded on his sword: and there went up after David about four hundred men; and two hundred abode by the stuff.
7876	261	14	But one of the young men told Abigail, Nabal's wife, saying, Behold, David sent messengers out of the wilderness to salute our master; and he railed on them.
7877	261	15	But the men were very good unto us, and we were not hurt, neither missed we any thing, as long as we were conversant with them, when we were in the fields:
7878	261	16	They were a wall unto us both by night and day, all the while we were with them keeping the sheep.
7879	261	17	Now therefore know and consider what thou wilt do; for evil is determined against our master, and against all his household: for he is such a son of Belial, that a man cannot speak to him.
7880	261	18	Then Abigail made haste, and took two hundred loaves, and two bottles of wine, and five sheep ready dressed, and five measures of parched corn, and an hundred clusters of raisins, and two hundred cakes of figs, and laid them on asses.
7881	261	19	And she said unto her servants, Go on before me; behold, I come after you. But she told not her husband Nabal.
7882	261	20	And it was so, as she rode on the ass, that she came down by the covert of the hill, and, behold, David and his men came down against her; and she met them.
7883	261	21	Now David had said, Surely in vain have I kept all that this fellow hath in the wilderness, so that nothing was missed of all that pertained unto him: and he hath requited me evil for good.
7884	261	22	So and more also do God unto the enemies of David, if I leave of all that pertain to him by the morning light any that pisseth against the wall.
7885	261	23	And when Abigail saw David, she hasted, and lighted off the ass, and fell before David on her face, and bowed herself to the ground,
7886	261	24	And fell at his feet, and said, Upon me, my lord, upon me let this iniquity be: and let thine handmaid, I pray thee, speak in thine audience, and hear the words of thine handmaid.
7887	261	25	Let not my lord, I pray thee, regard this man of Belial, even Nabal: for as his name is, so is he; Nabal is his name, and folly is with him: but I thine handmaid saw not the young men of my lord, whom thou didst send.
7888	261	26	Now therefore, my lord, as the LORD liveth, and as thy soul liveth, seeing the LORD hath withholden thee from coming to shed blood, and from avenging thyself with thine own hand, now let thine enemies, and they that seek evil to my lord, be as Nabal.
7889	261	27	And now this blessing which thine handmaid hath brought unto my lord, let it even be given unto the young men that follow my lord.
7890	261	28	I pray thee, forgive the trespass of thine handmaid: for the LORD will certainly make my lord a sure house; because my lord fighteth the battles of the LORD, and evil hath not been found in thee all thy days.
7891	261	29	Yet a man is risen to pursue thee, and to seek thy soul: but the soul of my lord shall be bound in the bundle of life with the LORD thy God; and the souls of thine enemies, them shall he sling out, as out of the middle of a sling.
7892	261	30	And it shall come to pass, when the LORD shall have done to my lord according to all the good that he hath spoken concerning thee, and shall have appointed thee ruler over Israel;
7893	261	31	That this shall be no grief unto thee, nor offence of heart unto my lord, either that thou hast shed blood causeless, or that my lord hath avenged himself: but when the LORD shall have dealt well with my lord, then remember thine handmaid.
7894	261	32	And David said to Abigail, Blessed be the LORD God of Israel, which sent thee this day to meet me:
7895	261	33	And blessed be thy advice, and blessed be thou, which hast kept me this day from coming to shed blood, and from avenging myself with mine own hand.
7896	261	34	For in very deed, as the LORD God of Israel liveth, which hath kept me back from hurting thee, except thou hadst hasted and come to meet me, surely there had not been left unto Nabal by the morning light any that pisseth against the wall.
7897	261	35	So David received of her hand that which she had brought him, and said unto her, Go up in peace to thine house; see, I have hearkened to thy voice, and have accepted thy person.
7898	261	36	And Abigail came to Nabal; and, behold, he held a feast in his house, like the feast of a king; and Nabal's heart was merry within him, for he was very drunken: wherefore she told him nothing, less or more, until the morning light.
7899	261	37	But it came to pass in the morning, when the wine was gone out of Nabal, and his wife had told him these things, that his heart died within him, and he became as a stone.
7900	261	38	And it came to pass about ten days after, that the LORD smote Nabal, that he died.
7901	261	39	And when David heard that Nabal was dead, he said, Blessed be the LORD, that hath pleaded the cause of my reproach from the hand of Nabal, and hath kept his servant from evil: for the LORD hath returned the wickedness of Nabal upon his own head. And David sent and communed with Abigail, to take her to him to wife.
7902	261	40	And when the servants of David were come to Abigail to Carmel, they spake unto her, saying, David sent us unto thee, to take thee to him to wife.
7903	261	41	And she arose, and bowed herself on her face to the earth, and said, Behold, let thine handmaid be a servant to wash the feet of the servants of my lord.
7904	261	42	And Abigail hasted, and arose, and rode upon an ass, with five damsels of hers that went after her; and she went after the messengers of David, and became his wife.
7905	261	43	David also took Ahinoam of Jezreel; and they were also both of them his wives.
7906	261	44	But Saul had given Michal his daughter, David's wife, to Phalti the son of Laish, which was of Gallim.
7907	262	1	AND the Ziphites came unto Saul to Gibeah, saying, Doth not David hide himself in the hill of Hachilah, which is before Jeshimon?
7908	262	2	Then Saul arose, and went down to the wilderness of Ziph, having three thousand chosen men of Israel with him, to seek David in the wilderness of Ziph.
7909	262	3	And Saul pitched in the hill of Hachilah, which is before Jeshimon, by the way. But David abode in the wilderness, and he saw that Saul came after him into the wilderness.
7910	262	4	David therefore sent out spies, and understood that Saul was come in very deed.
7911	262	5	And David arose, and came to the place where Saul had pitched: and David beheld the place where Saul lay, and Abner the son of Ner, the captain of his host: and Saul lay in the trench, and the people pitched round about him.
7912	262	6	Then answered David and said to Ahimelech the Hittite, and to Abishai the son of Zeruiah, brother to Joab, saying, Who will go down with me to Saul to the camp? And Abishai said, I will go down with thee.
7913	262	7	So David and Abishai came to the people by night: and, behold, Saul lay sleeping within the trench, and his spear stuck in the ground at his bolster: but Abner and the people lay round about him.
7914	262	8	Then said Abishai to David, God hath delivered thine enemy into thine hand this day: now therefore let me smite him, I pray thee, with the spear even to the earth at once, and I will not smite him the second time.
7915	262	9	And David said to Abishai, Destroy him not: for who can stretch forth his hand against the LORD's anointed, and be guiltless?
7916	262	10	David said furthermore, As the LORD liveth, the LORD shall smite him; or his day shall come to die; or he shall descend into battle, and perish.
7917	262	11	The LORD forbid that I should stretch forth mine hand against the LORD's anointed: but, I pray thee, take thou now the spear that is at his bolster, and the cruse of water, and let us go.
7918	262	12	So David took the spear and the cruse of water from Saul's bolster; and they gat them away, and no man saw it, nor knew it, neither awaked: for they were all asleep; because a deep sleep from the LORD was fallen upon them.
7919	262	13	Then David went over to the other side, and stood on the top of an hill afar off; a great space being between them:
7920	262	14	And David cried to the people, and to Abner the son of Ner, saying, Answerest thou not, Abner? Then Abner answered and said, Who art thou that criest to the king?
7921	262	15	And David said to Abner, Art not thou a valiant man? and who is like to thee in Israel? wherefore then hast thou not kept thy lord the king? for there came one of the people in to destroy the king thy lord.
7922	262	16	This thing is not good that thou hast done. As the LORD liveth, ye are worthy to die, because ye have not kept your master, the LORD's anointed. And now see where the king's spear is, and the cruse of water that was at his bolster.
7923	262	17	And Saul knew David's voice, and said, Is this thy voice, my son David? And David said, It is my voice, my lord, O king.
7924	262	18	And he said, Wherefore doth my lord thus pursue after his servant? for what have I done? or what evil is in mine hand?
7925	262	19	Now therefore, I pray thee, let my lord the king hear the words of his servant. If the LORD have stirred thee up against me, let him accept an offering: but if they be the children of men, cursed be they before the LORD; for they have driven me out this day from abiding in the inheritance of the LORD, saying, Go, serve other gods.
7926	262	20	Now therefore, let not my blood fall to the earth before the face of the LORD: for the king of Israel is come out to seek a flea, as when one doth hunt a partridge in the mountains.
7927	262	21	Then said Saul, I have sinned: return, my son David: for I will no more do thee harm, because my soul was precious in thine eyes this day: behold, I have played the fool, and have erred exceedingly.
7928	262	22	And David answered and said, Behold the king's spear! and let one of the young men come over and fetch it.
7929	262	23	The LORD render to every man his righteousness and his faithfulness: for the LORD delivered thee into my hand to day, but I would not stretch forth mine hand against the LORD's anointed.
7930	262	24	And, behold, as thy life was much set by this day in mine eyes, so let my life be much set by in the eyes of the LORD, and let him deliver me out of all tribulation.
7931	262	25	Then Saul said to David, Blessed be thou, my son David: thou shalt both do great things, and also shalt still prevail. So David went on his way, and Saul returned to his place.
7932	263	1	AND David said in his heart, I shall now perish one day by the hand of Saul: there is nothing better for me than that I should speedily escape into the land of the Philistines; and Saul shall despair of me, to seek me any more in any coast of Israel: so shall I escape out of his hand.
7933	263	2	And David arose, and he passed over with the six hundred men that were with him unto Achish, the son of Maoch, king of Gath.
7934	263	3	And David dwelt with Achish at Gath, he and his men, every man with his household, even David with his two wives, Ahinoam the Jezreelitess, and Abigail the Carmelitess, Nabal's wife.
7935	263	4	And it was told Saul that David was fled to Gath: and he sought no more again for him.
7936	263	5	And David said unto Achish, If I have now found grace in thine eyes, let them give me a place in some town in the country, that I may dwell there: for why should thy servant dwell in the royal city with thee?
7937	263	6	Then Achish gave him Ziklag that day: wherefore Ziklag pertaineth unto the kings of Judah unto this day.
7938	263	7	And the time that David dwelt in the country of the Philistines was a full year and four months.
7939	263	8	And David and his men went up, and invaded the Geshurites, and the Gezrites, and the Amalekites: for those nations were of old the inhabitants of the land, as thou goest to Shur, even unto the land of Egypt.
7940	263	9	And David smote the land, and left neither man nor woman alive, and took away the sheep, and the oxen, and the asses, and the camels, and the apparel, and returned, and came to Achish.
7941	263	10	And Achish said, Whither have ye made a road to day? And David said, Against the south of Judah, and against the south of the Jerahmeelites, and against the south of the Kenites.
7942	263	11	And David saved neither man nor woman alive, to bring tidings to Gath, saying, Lest they should tell on us, saying, So did David, and so will be his manner all the while he dwelleth in the country of the Philistines.
7943	263	12	And Achish believed David, saying, He hath made his people Israel utterly to abhor him; therefore he shall be my servant for ever.
7944	264	1	AND it came to pass in those days, that the Philistines gathered their armies together for warfare, to fight with Israel. And Achish said unto David, Know thou assuredly, that thou shalt go out with me to battle, thou and thy men.
7945	264	2	And David said to Achish, Surely thou shalt know what thy servant can do. And Achish said to David, Therefore will I make thee keeper of mine head for ever.
7946	264	3	Now Samuel was dead, and all Israel had lamented him, and buried him in Ramah, even in his own city. And Saul had put away those that had familiar spirits, and the wizards, out of the land.
7947	264	4	And the Philistines gathered themselves together, and came and pitched in Shunem: and Saul gathered all Israel together, and they pitched in Gilboa.
7948	264	5	And when Saul saw the host of the Philistines, he was afraid, and his heart greatly trembled.
7949	264	6	And when Saul enquired of the LORD, the LORD answered him not, neither by dreams nor by Urim, nor by prophets.
7950	264	7	Then said Saul unto his servants, Seek me a woman that hath a familiar spirit, that I may go to her, and enquire of her. And his servants said to him, Behold, there is a woman that hath a familiar spirit at En-dor.
7951	264	8	And Saul disguised himself, and put on other raiment, and he went, and two men with him, and they came to the woman by night: and he said, I pray thee, divine unto me by the familiar spirit, and bring me him up, whom I shall name unto thee.
7952	264	9	And the woman said unto him, Behold, thou knowest what Saul hath done, how he hath cut off those that have familiar spirits, and the wizards, out of the land: wherefore then layest thou a snare for my life, to cause me to die?
7953	264	10	And Saul sware to her by the LORD, saying, As the LORD liveth, there shall no punishment happen to thee for this thing.
7954	264	11	Then said the woman, Whom shall I bring up unto thee? And he said, Bring me up Samuel.
7955	264	12	And when the woman saw Samuel, she cried with a loud voice: and the woman spake to Saul, saying, Why hast thou deceived me? for thou art Saul.
7956	264	13	And the king said unto her, Be not afraid: for what sawest thou? And the woman said unto Saul, I saw gods ascending out of the earth.
7957	264	14	And he said unto her, What form is he of? And she said, An old man cometh up; and he is covered with a mantle. And Saul perceived that it was Samuel, and he stooped with his face to the ground, and bowed himself.
7958	264	15	And Samuel said to Saul, Why hast thou disquieted me, to bring me up? And Saul answered, I am sore distressed; for the Philistines make war against me, and God is departed from me, and answereth me no more, neither by prophets, nor by dreams: therefore I have called thee, that thou mayest make known unto me what I shall do.
7959	264	16	Then said Samuel, Wherefore then dost thou ask of me, seeing the LORD is departed from thee, and is become thine enemy?
7960	264	17	And the LORD hath done to him, as he spake by me: for the LORD hath rent the kingdom out of thine hand, and given it to thy neighbour, even to David:
7961	264	18	Because thou obeyedst not the voice of the LORD, nor executedst his fierce wrath upon Amalek, therefore hath the LORD done this thing unto thee this day.
7962	264	19	Moreover the LORD will also deliver Israel with thee into the hand of the Philistines: and to morrow shalt thou and thy sons be with me: the LORD also shall deliver the host of Israel into the hand of the Philistines.
7963	264	20	Then Saul fell straightway all along on the earth, and was sore afraid, because of the words of Samuel: and there was no strength in him; for he had eaten no bread all the day, nor all the night.
7964	264	21	And the woman came unto Saul, and saw that he was sore troubled, and said unto him, Behold, thine handmaid hath obeyed thy voice, and I have put my life in my hand, and have hearkened unto thy words which thou spakest unto me.
7965	264	22	Now therefore, I pray thee, hearken thou also unto the voice of thine handmaid, and let me set a morsel of bread before thee; and eat, that thou mayest have strength, when thou goest on thy way.
7966	264	23	But he refused, and said, I will not eat. But his servants, together with the woman, compelled him; and he hearkened unto their voice. So he arose from the earth, and sat upon the bed.
7967	264	24	And the woman had a fat calf in the house; and she hasted, and killed it, and took flour, and kneaded it, and did bake unleavened bread thereof:
7968	264	25	And she brought it before Saul, and before his servants; and they did eat. Then they rose up, and went away that night.
7969	265	1	NOW the Philistines gathered together all their armies to Aphek: and the Israelites pitched by a fountain which is in Jezreel.
7970	265	2	And the lords of the Philistines passed on by hundreds, and by thousands: but David and his men passed on in the rereward with Achish.
7971	265	3	Then said the princes of the Philistines, What do these Hebrews here? And Achish said unto the princes of the Philistines, Is not this David, the servant of Saul the king of Israel, which hath been with me these days, or these years, and I have found no fault in him since he fell unto me unto this day?
7972	265	4	And the princes of the Philistines were wroth with him; and the princes of the Philistines said unto him, Make this fellow return, that he may go again to his place which thou hast appointed him, and let him not go down with us to battle, lest in the battle he be an adversary to us: for wherewith should he reconcile himself unto his master? should it not be with the heads of these men?
7973	265	5	Is not this David, of whom they sang one to another in dances, saying, Saul slew his thousands, and David his ten thousands?
7974	265	6	Then Achish called David, and said unto him, Surely, as the LORD liveth, thou hast been upright, and thy going out and thy coming in with me in the host is good in my sight: for I have not found evil in thee since the day of thy coming unto me unto this day: nevertheless the lords favour thee not.
7975	265	7	Wherefore now return, and go in peace, that thou displease not the lords of the Philistines.
7976	265	8	And David said unto Achish, But what have I done? and what hast thou found in thy servant so long as I have been with thee unto this day, that I may not go fight against the enemies of my lord the king?
7977	265	9	And Achish answered and said to David, I know that thou art good in my sight, as an angel of God: notwithstanding the princes of the Philistines have said, He shall not go up with us to the battle.
7978	265	10	Wherefore now rise up early in the morning with thy master's servants that are come with thee: and as soon as ye be up early in the morning, and have light, depart.
7979	265	11	So David and his men rose up early to depart in the morning, to return into the land of the Philistines. And the Philistines went up to Jezreel.
7980	266	1	AND it came to pass, when David and his men were come to Ziklag on the third day, that the Amalekites had invaded the south, and Ziklag, and smitten Ziklag, and burned it with fire;
7981	266	2	And had taken the women captives, that were therein: they slew not any, either great or small, but carried them away, and went on their way.
7982	266	3	So David and his men came to the city, and, behold, it was burned with fire; and their wives, and their sons, and their daughters, were taken captives.
7983	266	4	Then David and the people that were with him lifted up their voice and wept, until they had no more power to weep.
7984	266	5	And David's two wives were taken captives, Ahinoam the Jezreelitess, and Abigail the wife of Nabal the Carmelite.
7985	266	6	And David was greatly distressed; for the people spake of stoning him, because the soul of all the people was grieved, every man for his sons and for his daughters: but David encouraged himself in the LORD his God.
7986	266	7	And David said to Abiathar the priest, Ahimelech's son, I pray thee, bring me hither the ephod. And Abiathar brought thither the ephod to David.
7987	266	8	And David inquired at the LORD, saying, Shall I pursue after this troop? shall I overtake them? And he answered him, Pursue: for thou shalt surely overtake them, and without fail recover all.
7988	266	9	So David went, he and the six hundred men that were with him, and came to the brook Besor, where those that were left behind stayed.
7989	266	10	But David pursued, he and four hundred men: for two hundred abode behind, which were so faint that they could not go over the brook Besor.
7990	266	11	And they found an Egyptian in the field, and brought him to David, and gave him bread, and he did eat; and they made him drink water;
7991	266	12	And they gave him a piece of a cake of figs, and two clusters of raisins: and when he had eaten, his spirit came again to him: for he had eaten no bread, nor drunk any water, three days and three nights.
7992	266	13	And David said unto him, To whom belongest thou? and whence art thou? And he said, I am a young man of Egypt, servant to an Amalekite; and my master left me, because three days agone I fell sick.
7993	266	14	We made an invasion upon the south of the Cherethites, and upon the coast which belongeth to Judah, and upon the south of Caleb; and we burned Ziklag with fire.
7994	266	15	And David said to him, Canst thou bring me down to this company? And he said, Swear unto me by God, that thou wilt neither kill me, nor deliver me into the hands of my master, and I will bring thee down to this company.
7995	266	16	And when he had brought him down, behold, they were spread abroad upon all the earth, eating and drinking, and dancing, because of all the great spoil that they had taken out of the land of the Philistines, and out of the land of Judah.
7996	266	17	And David smote them from the twilight even unto the evening of the next day: and there escaped not a man of them, save four hundred young men, which rode upon camels, and fled.
7997	266	18	And David recovered all that the Amalekites had carried away: and David rescued his two wives.
7998	266	19	And there was nothing lacking to them, neither small nor great, neither sons nor daughters, neither spoil, nor any thing that they had taken to them: David recovered all.
7999	266	20	And David took all the flocks and the herds, which they drave before those other cattle, and said, This is David's spoil.
8000	266	21	And David came to the two hundred men, which were so faint that they could not follow David, whom they had made also to abide at the brook Besor: and they went forth to meet David, and to meet the people that were with him: and when David came near to the people, he saluted them.
8001	266	22	Then answered all the wicked men and men of Belial, of those that went with David, and said, Because they went not with us, we will not give them ought of the spoil that we have recovered, save to every man his wife and his children, that they may lead them away, and depart.
8002	266	23	Then said David, Ye shall not do so, my brethren, with that which the LORD hath given us, who hath preserved us, and delivered the company that came against us into our hand.
8003	266	24	For who will hearken unto you in this matter? but as his part is that goeth down to the battle, so shall his part be that tarrieth by the stuff: they shall part alike.
8004	266	25	And it was so from that day forward, that he made it a statute and an ordinance for Israel unto this day.
8005	266	26	And when David came to Ziklag, he sent of the spoil unto the elders of Judah, even to his friends, saying, Behold a present for you of the spoil of the enemies of the LORD;
8006	266	27	To them which were in Beth-el, and to them which were in south Ramoth, and to them which were in Jattir,
8007	266	28	And to them which were in Aroer, and to them which were in Siphmoth, and to them which were in Eshtemoa,
8008	266	29	And to them which were in Rachal, and to them which were in the cities of the Jerahmeelites, and to them which were in the cities of the Kenites,
8009	266	30	And to them which were in Hormah, and to them which were in Chor-ashan, and to them which were in Athach,
8010	266	31	And to them which were in Hebron, and to all the places where David himself and his men were wont to haunt.
8011	267	1	NOW the Philistines fought against Israel: and the men of Israel fled from before the Philistines, and fell down slain in mount Gilboa.
8012	267	2	And the Philistines followed hard upon Saul and upon his sons; and the Philistines slew Jonathan, and Abinadab, and Malchi-shua, Saul's sons.
8013	267	3	And the battle went sore against Saul, and the archers hit him; and he was sore wounded of the archers.
8014	267	4	Then said Saul unto his armourbearer, Draw thy sword, and thrust me through therewith; lest these uncircumcised come and thrust me through, and abuse me. But his armourbearer would not; for he was sore afraid. Therefore Saul took a sword, and fell upon it.
8015	267	5	And when his armourbearer saw that Saul was dead, he fell likewise upon his sword, and died with him.
8016	267	6	So Saul died, and his three sons, and his armourbearer, and all his men, that same day together.
8017	267	7	And when the men of Israel that were on the other side of the valley, and they that were on the other side Jordan, saw that the men of Israel fled, and that Saul and his sons were dead, they forsook the cities, and fled; and the Philistines came and dwelt in them.
8018	267	8	And it came to pass on the morrow, when the Philistines came to strip the slain, that they found Saul and his three sons fallen in mount Gilboa.
8019	267	9	And they cut off his head, and stripped off his armour, and sent into the land of the Philistines round about, to publish it in the house of their idols, and among the people.
8020	267	10	And they put his armour in the house of Ashtaroth: and they fastened his body to the wall of Beth-shan.
8021	267	11	And when the inhabitants of Jabesh-gilead heard of that which the Philistines had done to Saul;
8022	267	12	All the valiant men arose, and went all night, and took the body of Saul and the bodies of his sons from the wall of Beth-shan, and came to Jabesh, and burnt them there.
8023	267	13	And they took their bones, and buried them under a tree at Jabesh, and fasted seven days.
8024	268	1	NOW it came to pass after the death of Saul, when David was returned from the slaughter of the Amalekites, and David had abode two days in Ziklag;
8025	268	2	It came even to pass on the third day, that, behold, a man came out of the camp from Saul with his clothes rent, and earth upon his head: and so it was, when he came to David, that he fell to the earth, and did obeisance.
8026	268	3	And David said unto him, From whence comest thou? And he said unto him, Out of the camp of Israel am I escaped.
8027	268	4	And David said unto him, How went the matter? I pray thee, tell me. And he answered, That the people are fled from the battle, and many of the people also are fallen and dead; and Saul and Jonathan his son are dead also.
8028	268	5	And David said unto the young man that told him, How knowest thou that Saul and Jonathan his son be dead?
8029	268	6	And the young man that told him said, As I happened by chance upon mount Gilboa, behold, Saul leaned upon his spear; and, lo, the chariots and horsemen followed hard after him.
8030	268	7	And when he looked behind him, he saw me, and called unto me. And I answered, Here am I.
8031	268	8	And he said unto me, Who art thou? And I answered him, I am an Amalekite.
8032	268	9	And he said unto me again, Stand, I pray thee, upon me, and slay me: for anguish is come upon me, because my life is yet whole in me.
8033	268	10	So I stood upon him, and slew him, because I was sure that he could not live after that he was fallen: and I took the crown that was upon his head, and the bracelet that was on his arm, and have brought them hither unto my lord.
8034	268	11	Then David took hold on his clothes, and rent them; and likewise all the men that were with him:
8035	268	12	And they mourned, and wept, and fasted until even, for Saul, and for Jonathan his son, and for the people of the LORD, and for the house of Israel; because they were fallen by the sword.
8036	268	13	And David said unto the young man that told him, Whence art thou? And he answered, I am the son of a stranger, an Amalekite.
8037	268	14	And David said unto him, How wast thou not afraid to stretch forth thine hand to destroy the LORD's anointed?
8038	268	15	And David called one of the young men, and said, Go near, and fall upon him. And he smote him that he died.
8039	268	16	And David said unto him, Thy blood be upon thy head; for thy mouth hath testified against thee, saying, I have slain the LORD's anointed.
8040	268	17	And David lamented with this lamentation over Saul and over Jonathan his son:
8041	268	18	(Also he bade them teach the children of Judah the use of the bow: behold, it is written in the book of Jasher.)
8042	268	19	The beauty of Israel is slain upon thy high places: how are the mighty fallen!
8043	268	20	Tell it not in Gath, publish it not in the streets of Askelon; lest the daughters of the Philistines rejoice, lest the daughters of the uncircumcised triumph.
8044	268	21	Ye mountains of Gilboa, let there be no dew, neither let there be rain, upon you, nor fields of offerings: for there the shield of the mighty is vilely cast away, the shield of Saul, as though he had not been anointed with oil.
8045	268	22	From the blood of the slain, from the fat of the mighty, the bow of Jonathan turned not back, and the sword of Saul returned not empty.
8046	268	23	Saul and Jonathan were lovely and pleasant in their lives, and in their death they were not divided: they were swifter than eagles, they were stronger than lions.
8047	268	24	Ye daughters of Israel, weep over Saul, who clothed you in scarlet, with other delights, who put on ornaments of gold upon your apparel.
8048	268	25	How are the mighty fallen in the midst of the battle! O Jonathan, thou wast slain in thine high places.
8049	268	26	I am distressed for thee, my brother Jonathan: very pleasant hast thou been unto me: thy love to me was wonderful, passing the love of women.
8050	268	27	How are the mighty fallen, and the weapons of war perished!
8051	269	1	AND it came to pass after this, that David enquired of the LORD, saying, Shall I go up into any of the cities of Judah? And the LORD said unto him, Go up. And David said, Whither shall I go up? And he said, Unto Hebron.
8052	269	2	So David went up thither, and his two wives also, Ahinoam the Jezreelitess, and Abigail Nabal's wife the Carmelite.
8053	269	3	And his men that were with him did David bring up, every man with his household: and they dwelt in the cities of Hebron.
8054	269	4	And the men of Judah came, and there they anointed David king over the house of Judah. And they told David, saying, That the men of Jabesh-gilead were they that buried Saul.
8055	269	5	And David sent messengers unto the men of Jabesh-gilead, and said unto them, Blessed be ye of the LORD, that ye have shewed this kindness unto your lord, even unto Saul, and have buried him.
8056	269	6	And now the LORD shew kindness and truth unto you: and I also will requite you this kindness, because ye have done this thing.
8057	269	7	Therefore now let your hands be strengthened, and be ye valiant: for your master Saul is dead, and also the house of Judah have anointed me king over them.
8058	269	8	But Abner the son of Ner, captain of Saul's host, took Ish-bosheth the son of Saul, and brought him over to Mahanaim;
8059	269	9	And made him king over Gilead, and over the Ashurites, and over Jezreel, and over Ephraim, and over Benjamin, and over all Israel.
8060	269	10	Ish-bosheth Saul's son was forty years old when he began to reign over Israel, and reigned two years. But the house of Judah followed David.
8061	269	11	And the time that David was king in Hebron over the house of Judah was seven years and six months.
8062	269	12	And Abner the son of Ner, and the servants of Ish-bosheth the son of Saul, went out from Mahanaim to Gibeon.
8063	269	13	And Joab the son of Zeruiah, and the servants of David, went out, and met together by the pool of Gibeon: and they sat down, the one on the one side of the pool, and the other on the other side of the pool.
8064	269	14	And Abner said to Joab, Let the young men now arise, and play before us. And Joab said, Let them arise.
8065	269	15	Then there arose and went over by number twelve of Benjamin, which pertained to Ish-bosheth the son of Saul, and twelve of the servants of David.
8066	269	16	And they caught every one his fellow by the head, and thrust his sword in his fellow's side; so they fell down together: wherefore that place was called Helkath-hazzurim, which is in Gibeon.
8067	269	17	And there was a very sore battle that day; and Abner was beaten, and the men of Israel, before the servants of David.
8068	269	18	And there were three sons of Zeruiah there, Joab, and Abishai, and Asahel: and Asahel was as light of foot as a wild roe.
8069	269	19	And Asahel pursued after Abner; and in going he turned not to the right hand nor to the left from following Abner.
8070	269	20	Then Abner looked behind him, and said, Art thou Asahel? And he answered, I am.
8071	269	21	And Abner said to him, Turn thee aside to thy right hand or to thy left, and lay thee hold on one of the young men, and take thee his armour. But Asahel would not turn aside from following of him.
8072	269	22	And Abner said again to Asahel, Turn thee aside from following me: wherefore should I smite thee to the ground? how then should I hold up my face to Joab thy brother?
8073	269	23	Howbeit he refused to turn aside: wherefore Abner with the hinder end of the spear smote him under the fifth rib, that the spear came out behind him; and he fell down there, and died in the same place: and it came to pass, that as many as came to the place where Asahel fell down and died stood still.
8074	269	24	Joab also and Abishai pursued after Abner: and the sun went down when they were come to the hill of Ammah, that lieth before Giah by the way of the wilderness of Gibeon.
8075	269	25	And the children of Benjamin gathered themselves together after Abner, and became one troop, and stood on the top of an hill.
8076	269	26	Then Abner called to Joab, and said, Shall the sword devour for ever? knowest thou not that it will be bitterness in the latter end? how long shall it be then, ere thou bid the people return from following their brethren?
8077	269	27	And Joab said, As God liveth, unless thou hadst spoken, surely then in the morning the people had gone up every one from following his brother.
8078	269	28	So Joab blew a trumpet, and all the people stood still, and pursued after Israel no more, neither fought they any more.
8079	269	29	And Abner and his men walked all that night through the plain, and passed over Jordan, and went through all Bithron, and they came to Mahanaim.
8080	269	30	And Joab returned from following Abner: and when he had gathered all the people together, there lacked of David's servants nineteen men and Asahel.
8081	269	31	But the servants of David had smitten of Benjamin, and of Abner's men, so that three hundred and threescore men died.
8082	269	32	And they took up Asahel, and buried him in the sepulchre of his father, which was in Beth-lehem. And Joab and his men went all night, and they came to Hebron at break of day.
8083	270	1	NOW there was long war between the house of Saul and the house of David: but David waxed stronger and stronger, and the house of Saul waxed weaker and weaker.
8084	270	2	And unto David were sons born in Hebron: and his firstborn was Amnon, of Ahinoam the Jezreelitess;
8085	270	3	And his second, Chileab, of Abigail the wife of Nabal the Carmelite; and the third, Absalom the son of Maacah the daughter of Talmai king of Geshur;
8086	270	4	And the fourth, Adonijah the son of Haggith; and the fifth, Shephatiah the son of Abital;
8087	270	5	And the sixth, Ithream, by Eglah David's wife. These were born to David in Hebron.
8088	270	6	And it came to pass, while there was war between the house of Saul and the house of David, that Abner made himself strong for the house of Saul.
8089	270	7	And Saul had a concubine, whose name was Rizpah, the daughter of Aiah: and Ish-bosheth said to Abner, Wherefore hast thou gone in unto my father's concubine?
8090	270	8	Then was Abner very wroth for the words of Ish-bosheth, and said, Am I a dog's head, which against Judah do shew kindness this day unto the house of Saul thy father, to his brethren, and to his friends, and have not delivered thee into the hand of David, that thou chargest me to day with a fault concerning this woman?
8091	270	9	So do God to Abner, and more also, except, as the LORD hath sworn to David, even so I do to him;
8092	270	10	To translate the kingdom from the house of Saul, and to set up the throne of David over Israel and over Judah, from Dan even to Beer-sheba.
8093	270	11	And he could not answer Abner a word again, because he feared him.
8094	270	12	And Abner sent messengers to David on his behalf, saying, Whose is the land? saying also, Make thy league with me, and, behold, my hand shall be with thee, to bring about all Israel unto thee.
8095	270	13	And he said, Well; I will make a league with thee: but one thing I require of thee, that is, Thou shalt not see my face, except thou first bring Michal Saul's daughter, when thou comest to see my face.
8096	270	14	And David sent messengers to Ish-bosheth Saul's son, saying, Deliver me my wife Michal, which I espoused to me for an hundred foreskins of the Philistines.
8097	270	15	And Ish-bosheth sent, and took her from her husband, even from Phaltiel the son of Laish.
8098	270	16	And her husband went with her along weeping behind her to Bahurim. Then said Abner unto him, Go, return. And he returned.
8099	270	17	And Abner had communication with the elders of Israel, saying, Ye sought for David in times past to be king over you:
8100	270	18	Now then do it: for the LORD hath spoken of David, saying, By the hand of my servant David I will save my people Israel out of the hand of the Philistines, and out of the hand of all their enemies.
8101	270	19	And Abner also spake in the ears of Benjamin: and Abner went also to speak in the ears of David in Hebron all that seemed good to Israel, and that seemed good to the whole house of Benjamin.
8102	270	20	So Abner came to David to Hebron, and twenty men with him. And David made Abner and the men that were with him a feast.
8103	270	21	And Abner said unto David, I will arise and go, and will gather all Israel unto my lord the king, that they may make a league with thee, and that thou mayest reign over all that thine heart desireth. And David sent Abner away; and he went in peace.
8104	270	22	And, behold, the servants of David and Joab came from pursuing a troop, and brought in a great spoil with them: but Abner was not with David in Hebron; for he had sent him away, and he was gone in peace.
8105	270	23	When Joab and all the host that was with him were come, they told Joab, saying, Abner the son of Ner came to the king, and he hath sent him away, and he is gone in peace.
8106	270	24	Then Joab came to the king, and said, What hast thou done? behold, Abner came unto thee; why is it that thou hast sent him away, and he is quite gone?
8107	270	25	Thou knowest Abner the son of Ner, that he came to deceive thee, and to know thy going out and thy coming in, and to know all that thou doest.
8108	270	26	And when Joab was come out from David, he sent messengers after Abner, which brought him again from the well of Sirah: but David knew it not.
8109	270	27	And when Abner was returned to Hebron, Joab took him aside in the gate to speak with him quietly, and smote him there under the fifth rib, that he died, for the blood of Asahel his brother.
8110	270	28	And afterward when David heard it, he said, I and my kingdom are guiltless before the LORD for ever from the blood of Abner the son of Ner:
8111	270	29	Let it rest on the head of Joab, and on all his father's house; and let there not fail from the house of Joab one that hath an issue, or that is a leper, or that leaneth on a staff, or that falleth on the sword, or that lacketh bread.
8112	270	30	So Joab and Abishai his brother slew Abner, because he had slain their brother Asahel at Gibeon in the battle.
8113	270	31	And David said to Joab, and to all the people that were with him, Rend your clothes, and gird you with sackcloth, and mourn before Abner. And king David himself followed the bier.
8114	270	32	And they buried Abner in Hebron: and the king lifted up his voice, and wept at the grave of Abner; and all the people wept.
8115	270	33	And the king lamented over Abner, and said, Died Abner as a fool dieth?
8116	270	34	Thy hands were not bound, nor thy feet put into fetters: as a man falleth before wicked men, so fellest thou. And all the people wept again over him.
8117	270	35	And when all the people came to cause David to eat meat while it was yet day, David sware, saying, So do God to me, and more also, if I taste bread, or ought else, till the sun be down.
8118	270	36	And all the people took notice of it, and it pleased them: as whatsoever the king did pleased all the people.
8119	270	37	For all the people and all Israel understood that day that it was not of the king to slay Abner the son of Ner.
8120	270	38	And the king said unto his servants, Know ye not that there is a prince and a great man fallen this day in Israel?
8121	270	39	And I am this day weak, though anointed king; and these men the sons of Zeruiah be too hard for me: the LORD shall reward the doer of evil according to his wickedness.
8122	271	1	AND when Saul's son heard that Abner was dead in Hebron, his hands were feeble, and all the Israelites were troubled.
8123	271	2	And Saul's son had two men that were captains of bands: the name of the one was Baanah, and the name of the other Rechab, the sons of Rimmon a Beerothite, of the children of Benjamin: (for Beeroth also was reckoned to Benjamin:
8124	271	3	And the Beerothites fled to Gittaim, and were sojourners there until this day.)
8125	271	4	And Jonathan, Saul's son, had a son that was lame of his feet. He was five years old when the tidings came of Saul and Jonathan out of Jezreel, and his nurse took him up, and fled: and it came to pass, as she made haste to flee, that he fell, and became lame. And his name was Mephibosheth.
8126	271	5	And the sons of Rimmon the Beerothite, Rechab and Baanah, went, and came about the heat of the day to the house of Ish-bosheth, who lay on a bed at noon,
8127	271	6	And they came thither into the midst of the house, as though they would have fetched wheat; and they smote him under the fifth rib: and Rechab and Baanah his brother escaped.
8128	271	7	For when they came into the house, he lay on his bed in his bedchamber, and they smote him, and slew him, and beheaded him, and took his head, and gat them away through the plain all night.
8129	271	8	And they brought the head of Ish-bosheth unto David to Hebron, and said to the king, Behold the head of Ish-bosheth the son of Saul thine enemy, which sought thy life; and the LORD hath avenged my lord the king this day of Saul, and of his seed.
8130	271	9	And David answered Rechab and Baanah his brother, the sons of Rimmon the Beerothite, and said unto them, As the LORD liveth, who hath redeemed my soul out of all adversity,
8131	271	10	When one told me, saying, Behold, Saul is dead, thinking to have brought good tidings, I took hold of him, and slew him in Ziklag, who thought that I would have given him a reward for his tidings:
8132	271	11	How much more, when wicked men have slain a righteous person in his own house upon his bed? shall I not therefore now require his blood of your hand, and take you away from the earth?
8133	271	12	And David commanded his young men, and they slew them, and cut off their hands and their feet, and hanged them up over the pool in Hebron. But they took the head of Ish-bosheth, and buried it in the sepulchre of Abner in Hebron.
8134	272	1	THEN came all the tribes of Israel to David unto Hebron, and spake, saying, Behold, we are thy bone and thy flesh.
8135	272	2	Also in time past, when Saul was king over us, thou wast he that leddest out and broughtest in Israel: and the LORD said to thee, Thou shalt feed my people Israel, and thou shalt be a captain over Israel.
8136	272	3	So all the elders of Israel came to the king to Hebron; and king David made a league with them in Hebron before the LORD: and they anointed David king over Israel.
8137	272	4	David was thirty years old when he began to reign, and he reigned forty years.
8138	272	5	In Hebron he reigned over Judah seven years and six months: and in Jerusalem he reigned thirty and three years over all Israel and Judah.
8139	272	6	And the king and his men went to Jerusalem unto the Jebusites, the inhabitants of the land: which spake unto David, saying, Except thou take away the blind and the lame, thou shalt not come in hither: thinking, David cannot come in hither.
8140	272	7	Nevertheless David took the strong hold of Zion: the same is the city of David.
8141	272	8	And David said on that day, Whosoever getteth up to the gutter, and smiteth the Jebusites, and the lame and the blind, that are hated of David's soul, he shall be chief and captain. Wherefore they said, The blind and the lame shall not come into the house.
8142	272	9	So David dwelt in the fort, and called it the city of David. And David built round about from Millo and inward.
8143	272	10	And David went on, and grew great, and the LORD God of hosts was with him.
8144	272	11	And Hiram king of Tyre sent messengers to David, and cedar trees, and carpenters, and masons: and they built David an house.
8145	272	12	And David perceived that the LORD had established him king over Israel, and that he had exalted his kingdom for his people Israel's sake.
8146	272	13	And David took him more concubines and wives out of Jerusalem, after he was come from Hebron: and there were yet sons and daughters born to David.
8147	272	14	And these be the names of those that were born unto him in Jerusalem; Shammua, and Shobab, and Nathan, and Solomon,
8148	272	15	Ibhar also, and Elishua, and Nepheg, and Japhia,
8149	272	16	And Elishama, and Eliada, and Eliphalet.
8150	272	17	But when the Philistines heard that they had anointed David king over Israel, all the Philistines came up to seek David; and David heard of it, and went down to the hold.
8151	272	18	The Philistines also came and spread themselves in the valley of Rephaim.
8152	272	19	And David enquired of the LORD, saying, Shall I go up to the Philistines? wilt thou deliver them into mine hand? And the LORD said unto David, Go up: for I will doubtless deliver the Philistines into thine hand.
8153	272	20	And David came to Baal-perazim, and David smote them there, and said, The LORD hath broken forth upon mine enemies before me, as the breach of waters. Therefore he called the name of that place Baal-perazim.
8154	272	21	And there they left their images, and David and his men burned them.
8155	272	22	And the Philistines came up yet again, and spread themselves in the valley of Rephaim.
8156	272	23	And when David enquired of the LORD, he said, Thou shalt not go up; but fetch a compass behind them, and come upon them over against the mulberry trees.
8157	272	24	And let it be, when thou hearest the sound of a going in the tops of the mulberry trees, that then thou shalt bestir thyself: for then shall the LORD go out before thee, to smite the host of the Philistines.
8158	272	25	And David did so, as the LORD had commanded him; and smote the Philistines from Geba until thou come to Gazer.
8159	273	1	AGAIN, David gathered together all the chosen men of Israel, thirty thousand.
8160	273	2	And David arose, and went with all the people that were with him from Baale of Judah, to bring up from thence the ark of God, whose name is called by the name of the LORD of hosts that dwelleth between the cherubims.
8161	273	3	And they set the ark of God upon a new cart, and brought it out of the house of Abinadab that was in Gibeah: and Uzzah and Ahio, the sons of Abinadab, drave the new cart.
8162	273	4	And they brought it out of the house of Abinadab which was at Gibeah, accompanying the ark of God: and Ahio went before the ark.
8163	273	5	And David and all the house of Israel played before the LORD on all manner of instruments made of fir wood, even on harps, and on psalteries, and on timbrels, and on cornets, and on cymbals.
8164	273	6	And when they came to Nachon's threshingfloor, Uzzah put forth his hand to the ark of God, and took hold of it; for the oxen shook it.
8165	273	7	And the anger of the LORD was kindled against Uzzah; and God smote him there for his error; and there he died by the ark of God.
8166	273	8	And David was displeased, because the LORD had made a breach upon Uzzah: and he called the name of the place Perez-uzzah to this day.
8167	273	9	And David was afraid of the LORD that day, and said, How shall the ark of the LORD come to me?
8168	273	10	So David would not remove the ark of the LORD unto him into the city of David: but David carried it aside into the house of Obed-edom the Gittite.
8169	273	11	And the ark of the LORD continued in the house of Obed-edom the Gittite three months: and the LORD blessed Obed-edom, and all his household.
8170	273	12	And it was told king David, saying, The LORD hath blessed the house of Obed-edom, and all that pertaineth unto him, because of the ark of God. So David went and brought up the ark of God from the house of Obed-edom into the city of David with gladness.
8171	273	13	And it was so, that when they that bare the ark of the LORD had gone six paces, he sacrificed oxen and fatlings.
8172	273	14	And David danced before the LORD with all his might; and David was girded with a linen ephod.
8173	273	15	So David and all the house of Israel brought up the ark of the LORD with shouting, and with the sound of the trumpet.
8174	273	16	And as the ark of the LORD came into the city of David, Michal Saul's daughter looked through a window, and saw king David leaping and dancing before the LORD; and she despised him in her heart.
8175	273	17	And they brought in the ark of the LORD, and set it in his place, in the midst of the tabernacle that David had pitched for it: and David offered burnt offerings and peace offerings before the LORD.
8176	273	18	And as soon as David had made an end of offering burnt offerings and peace offerings, he blessed the people in the name of the LORD of hosts.
8177	273	19	And he dealt among all the people, even among the whole multitude of Israel, as well to the women as men, to every one a cake of bread, and a good piece of flesh, and a flagon of wine. So all the people departed every one to his house.
8178	273	20	Then David returned to bless his household. And Michal the daughter of Saul came out to meet David, and said, How glorious was the king of Israel to day, who uncovered himself to day in the eyes of the handmaids of his servants, as one of the vain fellows shamelessly uncovereth himself!
8179	273	21	And David said unto Michal, It was before the LORD, which chose me before thy father, and before all his house, to appoint me ruler over the people of the LORD, over Israel: therefore will I play before the LORD.
8180	273	22	And I will yet be more vile than thus, and will be base in mine own sight: and of the maidservants which thou hast spoken of, of them shall I be had in honour.
8181	273	23	Therefore Michal the daughter of Saul had no child unto the day of her death.
8182	274	1	AND it came to pass, when the king sat in his house, and the LORD had given him rest round about from all his enemies;
8183	274	2	That the king said unto Nathan the prophet, See now, I dwell in an house of cedar, but the ark of God dwelleth within curtains.
8184	274	3	And Nathan said to the king, Go, do all that is in thine heart; for the LORD is with thee.
8185	274	4	And it came to pass that night, that the word of the LORD came unto Nathan, saying,
8186	274	5	Go and tell my servant David, Thus saith the LORD, Shalt thou build me an house for me to dwell in?
8187	274	6	Whereas I have not dwelt in any house since the time that I brought up the children of Israel out of Egypt, even to this day, but have walked in a tent and in a tabernacle.
8188	274	7	In all the places wherein I have walked with all the children of Israel spake I a word with any of the tribes of Israel, whom I commanded to feed my people Israel, saying, Why build ye not me an house of cedar?
8189	274	8	Now therefore so shalt thou say unto my servant David, Thus saith the LORD of hosts, I took thee from the sheepcote, from following the sheep, to be ruler over my people, over Israel:
8190	274	9	And I was with thee whithersoever thou wentest, and have cut off all thine enemies out of thy sight, and have made thee a great name, like unto the name of the great men that are in the earth.
8191	274	10	Moreover I will appoint a place for my people Israel, and will plant them, that they may dwell in a place of their own, and move no more; neither shall the children of wickedness afflict them any more, as beforetime,
8192	274	11	And as since the time that I commanded judges to be over my people Israel, and have caused thee to rest from all thine enemies. Also the LORD telleth thee that he will make thee an house.
8193	274	12	And when thy days be fulfilled, and thou shalt sleep with thy fathers, I will set up thy seed after thee, which shall proceed out of thy bowels, and I will establish his kingdom.
8194	274	13	He shall build an house for my name, and I will stablish the throne of his kingdom for ever.
8195	274	14	I will be his father, and he shall be my son. If he commit iniquity, I will chasten him with the rod of men, and with the stripes of the children of men:
8196	274	15	But my mercy shall not depart away from him, as I took it from Saul, whom I put away before thee.
8197	274	16	And thine house and thy kingdom shall be established for ever before thee: thy throne shall be established for ever.
8198	274	17	According to all these words, and according to all this vision, so did Nathan speak unto David.
8199	274	18	Then went king David in, and sat before the LORD, and he said, Who am I, O Lord GOD? and what is my house, that thou hast brought me hitherto?
8200	274	19	And this was yet a small thing in thy sight, O Lord GOD; but thou hast spoken also of thy servant's house for a great while to come. And is this the manner of man, O Lord GOD?
8201	274	20	And what can David say more unto thee? for thou, Lord GOD, knowest thy servant.
8202	274	21	For thy word's sake, and according to thine own heart, hast thou done all these great things, to make thy servant know them.
8203	274	22	Wherefore thou art great, O LORD God: for there is none like thee, neither is there any God beside thee, according to all that we have heard with our ears.
8204	274	23	And what one nation in the earth is like thy people, even like Israel, whom God went to redeem for a people to himself, and to make him a name, and to do for you great things and terrible, for thy land, before thy people, which thou redeemedst to thee from Egypt, from the nations and their gods?
8205	274	24	For thou hast confirmed to thyself thy people Israel to be a people unto thee for ever: and thou, LORD, art become their God.
8206	274	25	And now, O LORD God, the word that thou hast spoken concerning thy servant, and concerning his house, establish it for ever, and do as thou hast said.
8207	274	26	And let thy name be magnified for ever, saying, The LORD of hosts is the God over Israel: and let the house of thy servant David be established before thee.
8208	274	27	For thou, O LORD of hosts, God of Israel, hast revealed to thy servant, saying, I will build thee an house: therefore hath thy servant found in his heart to pray this prayer unto thee.
8209	274	28	And now, O Lord GOD, thou art that God, and thy words be true, and thou hast promised this goodness unto thy servant:
8210	274	29	Therefore now let it please thee to bless the house of thy servant, that it may continue for ever before thee: for thou, O Lord GOD, hast spoken it: and with thy blessing let the house of thy servant be blessed for ever.
8211	275	1	AND after this it came to pass, that David smote the Philistines, and subdued them: and David took Metheg-ammah out of the hand of the Philistines.
8212	275	2	And he smote Moab, and measured them with a line, casting them down to the ground; even with two lines measured he to put to death, and with one full line to keep alive. And so the Moabites became David's servants, and brought gifts.
8213	275	3	David smote also Hadadezer, the son of Rehob, king of Zobah, as he went to recover his border at the river Euphrates.
8214	275	4	And David took from him a thousand chariots, and seven hundred horsemen, and twenty thousand footmen: and David houghed all the chariot horses, but reserved of them for an hundred chariots.
8215	275	5	And when the Syrians of Damascus came to succour Hadadezer king of Zobah, David slew of the Syrians two and twenty thousand men.
8216	275	6	Then David put garrisons in Syria of Damascus: and the Syrians became servants to David, and brought gifts. And the LORD preserved David whithersoever he went.
8217	275	7	And David took the shields of gold that were on the servants of Hadadezer, and brought them to Jerusalem.
8218	275	8	And from Betah, and from Berothai, cities of Hadadezer, king David took exceeding much brass.
8219	275	9	When Toi king of Hamath heard that David had smitten all the host of Hadadezer,
8220	275	10	Then Toi sent Joram his son unto king David, to salute him, and to bless him, because he had fought against Hadadezer, and smitten him: for Hadadezer had wars with Toi. And Joram brought with him vessels of silver, and vessels of gold, and vessels of brass:
8221	275	11	Which also king David did dedicate unto the LORD, with the silver and gold that he had dedicated of all nations which he subdued;
8222	275	12	Of Syria, and of Moab, and of the children of Ammon, and of the Philistines, and of Amalek, and of the spoil of Hadadezer, son of Rehob, king of Zobah.
8223	275	13	And David gat him a name when he returned from smiting of the Syrians in the valley of salt, being eighteen thousand men.
8224	275	14	And he put garrisons in Edom; throughout all Edom put he garrisons, and all they of Edom became David's servants. And the LORD preserved David whithersoever he went.
8225	275	15	And David reigned over all Israel; and David executed judgment and justice unto all his people.
8226	275	16	And Joab the son of Zeruiah was over the host; and Jehoshaphat the son of Ahilud was recorder;
8227	275	17	And Zadok the son of Ahitub, and Ahimelech the son of Abiathar, were the priests; and Seraiah was the scribe;
8228	275	18	And Benaiah the son of Jehoiada was over both the Cherethites and the Pelethites; and David's sons were chief rulers.
8229	276	1	AND David said, Is there yet any that is left of the house of Saul, that I may shew him kindness for Jonathan's sake?
8230	276	2	And there was of the house of Saul a servant whose name was Ziba. And when they had called him unto David, the king said unto him, Art thou Ziba? And he said, Thy servant is he.
8231	276	3	And the king said, Is there not yet any of the house of Saul, that I may shew the kindness of God unto him? And Ziba said unto the king, Jonathan hath yet a son, which is lame on his feet.
8232	276	4	And the king said unto him, Where is he? And Ziba said unto the king, Behold, he is in the house of Machir, the son of Ammiel, in Lo-debar.
8233	276	5	Then king David sent, and fetched him out of the house of Machir, the son of Ammiel, from Lo-debar.
8234	276	6	Now when Mephibosheth, the son of Jonathan, the son of Saul, was come unto David, he fell on his face, and did reverence. And David said, Mephibosheth. And he answered, Behold thy servant!
8235	276	7	And David said unto him, Fear not: for I will surely shew thee kindness for Jonathan thy father's sake, and will restore thee all the land of Saul thy father; and thou shalt eat bread at my table continually.
8236	276	8	And he bowed himself, and said, What is thy servant, that thou shouldest look upon such a dead dog as I am?
8237	276	9	Then the king called to Ziba, Saul's servant, and said unto him, I have given unto thy master's son all that pertained to Saul and to all his house.
8238	276	10	Thou therefore, and thy sons, and thy servants, shall till the land for him, and thou shalt bring in the fruits, that thy master's son may have food to eat: but Mephibosheth thy master's son shall eat bread alway at my table. Now Ziba had fifteen sons and twenty servants.
8239	276	11	Then said Ziba unto the king, According to all that my lord the king hath commanded his servant, so shall thy servant do. As for Mephibosheth, said the king, he shall eat at my table, as one of the king's sons.
8240	276	12	And Mephibosheth had a young son, whose name was Micha. And all that dwelt in the house of Ziba were servants unto Mephibosheth.
8241	276	13	So Mephibosheth dwelt in Jerusalem: for he did eat continually at the king's table; and was lame on both his feet.
8242	277	1	AND it came to pass after this, that the king of the children of Ammon died, and Hanun his son reigned in his stead.
8243	277	2	Then said David, I will shew kindness unto Hanun the son of Nahash, as his father shewed kindness unto me. And David sent to comfort him by the hand of his servants for his father. And David's servants came into the land of the children of Ammon.
8244	277	3	And the princes of the children of Ammon said unto Hanun their lord, Thinkest thou that David doth honour thy father, that he hath sent comforters unto thee? hath not David rather sent his servants unto thee, to search the city, and to spy it out, and to overthrow it?
8245	277	4	Wherefore Hanun took David's servants, and shaved off the one half of their beards, and cut off their garments in the middle, even to their buttocks, and sent them away.
8246	277	5	When they told it unto David, he sent to meet them, because the men were greatly ashamed: and the king said, Tarry at Jericho until your beards be grown, and then return.
8247	277	6	And when the children of Ammon saw that they stank before David, the children of Ammon sent and hired the Syrians of Beth-rehob, and the Syrians of Zoba, twenty thousand footmen, and of king Maacah a thousand men, and of Ish-tob twelve thousand men.
8248	277	7	And when David heard of it, he sent Joab, and all the host of the mighty men.
8249	277	8	And the children of Ammon came out, and put the battle in array at the entering in of the gate: and the Syrians of Zoba, and of Rehob, and Ish-tob, and Maacah, were by themselves in the field.
8250	277	9	When Joab saw that the front of the battle was against him before and behind, he chose of all the choice men of Israel, and put them in array against the Syrians:
8251	277	10	And the rest of the people he delivered into the hand of Abishai his brother, that he might put them in array against the children of Ammon.
8252	277	11	And he said, If the Syrians be too strong for me, then thou shalt help me: but if the children of Ammon be too strong for thee, then I will come and help thee.
8253	277	12	Be of good courage, and let us play the men for our people, and for the cities of our God: and the LORD do that which seemeth him good.
8254	277	13	And Joab drew nigh, and the people that were with him, unto the battle against the Syrians: and they fled before him.
8255	277	14	And when the children of Ammon saw that the Syrians were fled, then fled they also before Abishai, and entered into the city. So Joab returned from the children of Ammon, and came to Jerusalem.
8256	277	15	And when the Syrians saw that they were smitten before Israel, they gathered themselves together.
8257	277	16	And Hadarezer sent, and brought out the Syrians that were beyond the river: and they came to Helam; and Shobach the captain of the host of Hadarezer went before them.
8258	277	17	And when it was told David, he gathered all Israel together, and passed over Jordan, and came to Helam. And the Syrians set themselves in array against David, and fought with him.
8259	277	18	And the Syrians fled before Israel; and David slew the men of seven hundred chariots of the Syrians, and forty thousand horsemen, and smote Shobach the captain of their host, who died there.
8260	277	19	And when all the kings that were servants to Hadarezer saw that they were smitten before Israel, they made peace with Israel, and served them. So the Syrians feared to help the children of Ammon any more.
8261	278	1	AND it came to pass, after the year was expired, at the time when kings go forth to battle, that David sent Joab, and his servants with him, and all Israel; and they destroyed the children of Ammon, and besieged Rabbah. But David tarried still at Jerusalem.
8262	278	2	And it came to pass in an eveningtide, that David arose from off his bed, and walked upon the roof of the king's house: and from the roof he saw a woman washing herself; and the woman was very beautiful to look upon.
8263	278	3	And David sent and enquired after the woman. And one said, Is not this Bath-sheba, the daughter of Eliam, the wife of Uriah the Hittite?
8264	278	4	And David sent messengers, and took her; and she came in unto him, and he lay with her; for she was purified from her uncleanness: and she returned unto her house.
8265	278	5	And the woman conceived, and sent and told David, and said, I am with child.
8266	278	6	And David sent to Joab, saying, Send me Uriah the Hittite. And Joab sent Uriah to David.
8267	278	7	And when Uriah was come unto him, David demanded of him how Joab did, and how the people did, and how the war prospered.
8268	278	8	And David said to Uriah, Go down to thy house, and wash thy feet. And Uriah departed out of the king's house, and there followed him a mess of meat from the king.
8269	278	9	But Uriah slept at the door of the king's house with all the servants of his lord, and went not down to his house.
8270	278	10	And when they had told David, saying, Uriah went not down unto his house, David said unto Uriah, Camest thou not from thy journey? why then didst thou not go down unto thine house?
8271	278	11	And Uriah said unto David, The ark, and Israel, and Judah, abide in tents; and my lord Joab, and the servants of my lord, are encamped in the open fields; shall I then go into mine house, to eat and to drink, and to lie with my wife? as thou livest, and as thy soul liveth, I will not do this thing.
8272	278	12	And David said to Uriah, Tarry here to day also, and to morrow I will let thee depart. So Uriah abode in Jerusalem that day, and the morrow.
8273	278	13	And when David had called him, he did eat and drink before him; and he made him drunk: and at even he went out to lie on his bed with the servants of his lord, but went not down to his house.
8274	278	14	And it came to pass in the morning, that David wrote a letter to Joab, and sent it by the hand of Uriah.
8275	278	15	And he wrote in the letter, saying, Set ye Uriah in the forefront of the hottest battle, and retire ye from him, that he may be smitten, and die.
8276	278	16	And it came to pass, when Joab observed the city, that he assigned Uriah unto a place where he knew that valiant men were.
8277	278	17	And the men of the city went out, and fought with Joab: and there fell some of the people of the servants of David; and Uriah the Hittite died also.
8278	278	18	Then Joab sent and told David all the things concerning the war;
8279	278	19	And charged the messenger, saying, When thou hast made an end of telling the matters of the war unto the king,
8280	278	20	And if so be that the king's wrath arise, and he say unto thee, Wherefore approached ye so nigh unto the city when ye did fight? knew ye not that they would shoot from the wall?
8281	278	21	Who smote Abimelech the son of Jerubbesheth? did not a woman cast a piece of a millstone upon him from the wall, that he died in Thebez? why went ye nigh the wall? then say thou, Thy servant Uriah the Hittite is dead also.
8282	278	22	So the messenger went, and came and shewed David all that Joab had sent him for.
8283	278	23	And the messenger said unto David, Surely the men prevailed against us, and came out unto us into the field, and we were upon them even unto the entering of the gate.
8284	278	24	And the shooters shot from off the wall upon thy servants; and some of the king's servants be dead, and thy servant Uriah the Hittite is dead also.
8285	278	25	Then David said unto the messenger, Thus shalt thou say unto Joab, Let not this thing displease thee, for the sword devoureth one as well as another: make thy battle more strong against the city, and overthrow it: and encourage thou him.
8286	278	26	And when the wife of Uriah heard that Uriah her husband was dead, she mourned for her husband.
8287	278	27	And when the mourning was past, David sent and fetched her to his house, and she became his wife, and bare him a son. But the thing that David had done displeased the LORD.
8288	279	1	AND the LORD sent Nathan unto David. And he came unto him, and said unto him, There were two men in one city; the one rich, and the other poor.
8289	279	2	The rich man had exceeding many flocks and herds:
8290	279	3	But the poor man had nothing, save one little ewe lamb, which he had bought and nourished up: and it grew up together with him, and with his children; it did eat of his own meat, and drank of his own cup, and lay in his bosom, and was unto him as a daughter.
8291	279	4	And there came a traveller unto the rich man, and he spared to take of his own flock and of his own herd, to dress for the wayfaring man that was come unto him; but took the poor man's lamb, and dressed it for the man that was come to him.
8292	279	5	And David's anger was greatly kindled against the man; and he said to Nathan, As the LORD liveth, the man that hath done this thing shall surely die:
8293	279	6	And he shall restore the lamb fourfold, because he did this thing, and because he had no pity.
8294	279	7	And Nathan said to David, Thou art the man. Thus saith the LORD God of Israel, I anointed thee king over Israel, and I delivered thee out of the hand of Saul;
8295	279	8	And I gave thee thy master's house, and thy master's wives into thy bosom, and gave thee the house of Israel and of Judah; and if that had been too little, I would moreover have given unto thee such and such things.
8296	279	9	Wherefore hast thou despised the commandment of the LORD, to do evil in his sight? thou hast killed Uriah the Hittite with the sword, and hast taken his wife to be thy wife, and hast slain him with the sword of the children of Ammon.
8297	279	10	Now therefore the sword shall never depart from thine house; because thou hast despised me, and hast taken the wife of Uriah the Hittite to be thy wife.
8298	279	11	Thus saith the LORD, Behold, I will raise up evil against thee out of thine own house, and I will take thy wives before thine eyes, and give them unto thy neighbour, and he shall lie with thy wives in the sight of this sun.
8299	279	12	For thou didst it secretly: but I will do this thing before all Israel, and before the sun.
8300	279	13	And David said unto Nathan, I have sinned against the LORD. And Nathan said unto David, The LORD also hath put away thy sin; thou shalt not die.
8301	279	14	Howbeit, because by this deed thou hast given great occasion to the enemies of the LORD to blaspheme, the child also that is born unto thee shall surely die.
8302	279	15	And Nathan departed unto his house. And the LORD struck the child that Uriah's wife bare unto David, and it was very sick.
8303	279	16	David therefore besought God for the child; and David fasted, and went in, and lay all night upon the earth.
8304	279	17	And the elders of his house arose, and went to him, to raise him up from the earth: but he would not, neither did he eat bread with them.
8305	279	18	And it came to pass on the seventh day, that the child died. And the servants of David feared to tell him that the child was dead: for they said, Behold, while the child was yet alive, we spake unto him, and he would not hearken unto our voice: how will he then vex himself, if we tell him that the child is dead?
8306	279	19	But when David saw that his servants whispered, David perceived that the child was dead: therefore David said unto his servants, Is the child dead? And they said, He is dead.
8307	279	20	Then David arose from the earth, and washed, and anointed himself, and changed his apparel, and came into the house of the LORD, and worshipped: then he came to his own house; and when he required, they set bread before him, and he did eat.
8308	279	21	Then said his servants unto him, What thing is this that thou hast done? thou didst fast and weep for the child, while it was alive; but when the child was dead, thou didst rise and eat bread.
8309	279	22	And he said, While the child was yet alive, I fasted and wept: for I said, Who can tell whether GOD will be gracious to me, that the child may live?
8310	279	23	But now he is dead, wherefore should I fast? can I bring him back again? I shall go to him, but he shall not return to me.
8311	279	24	And David comforted Bath-sheba his wife, and went in unto her, and lay with her: and she bare a son, and he called his name Solomon: and the LORD loved him.
8312	279	25	And he sent by the hand of Nathan the prophet; and he called his name Jedidiah, because of the LORD.
8313	279	26	And Joab fought against Rabbah of the children of Ammon, and took the royal city.
8314	279	27	And Joab sent messengers to David, and said, I have fought against Rabbah, and have taken the city of waters.
8315	279	28	Now therefore gather the rest of the people together, and encamp against the city, and take it: lest I take the city, and it be called after my name.
8316	279	29	And David gathered all the people together, and went to Rabbah, and fought against it, and took it.
8317	279	30	And he took their king's crown from off his head, the weight whereof was a talent of gold with the precious stones: and it was set on David's head. And he brought forth the spoil of the city in great abundance.
8318	279	31	And he brought forth the people that were therein, and put them under saws, and under harrows of iron, and under axes of iron, and made them pass through the brickkiln: and thus did he unto all the cities of the children of Ammon. So David and all the people returned unto Jerusalem.
8319	280	1	AND it came to pass after this, that Absalom the son of David had a fair sister, whose name was Tamar; and Amnon the son of David loved her.
8320	280	2	And Amnon was so vexed, that he fell sick for his sister Tamar; for she was a virgin; and Amnon thought it hard for him to do any thing to her.
8321	280	3	But Amnon had a friend, whose name was Jonadab, the son of Shimeah David's brother: and Jonadab was a very subtil man.
8322	280	4	And he said unto him, Why art thou, being the king's son, lean from day to day? wilt thou not tell me? And Amnon said unto him, I love Tamar, my brother Absalom's sister.
8323	280	5	And Jonadab said unto him, Lay thee down on thy bed, and make thyself sick: and when thy father cometh to see thee, say unto him, I pray thee, let my sister Tamar come, and give me meat, and dress the meat in my sight, that I may see it, and eat it at her hand.
8324	280	6	So Amnon lay down, and made himself sick: and when the king was come to see him, Amnon said unto the king, I pray thee, let Tamar my sister come, and make me a couple of cakes in my sight, that I may eat at her hand.
8325	280	7	Then David sent home to Tamar, saying, Go now to thy brother Amnon's house, and dress him meat.
8326	280	8	So Tamar went to her brother Amnon's house; and he was laid down. And she took flour, and kneaded it, and made cakes in his sight, and did bake the cakes.
8327	280	9	And she took a pan, and poured them out before him; but he refused to eat. And Amnon said, Have out all men from me. And they went out every man from him.
8328	280	10	And Amnon said unto Tamar, Bring the meat into the chamber, that I may eat of thine hand. And Tamar took the cakes which she had made, and brought them into the chamber to Amnon her brother.
8329	280	11	And when she had brought them unto him to eat, he took hold of her, and said unto her, Come lie with me, my sister.
8330	280	12	And she answered him, Nay, my brother, do not force me; for no such thing ought to be done in Israel: do not thou this folly.
8331	280	13	And I, whither shall I cause my shame to go? and as for thee, thou shalt be as one of the fools in Israel. Now therefore, I pray thee, speak unto the king; for he will not withhold me from thee.
8332	280	14	Howbeit he would not hearken unto her voice: but, being stronger than she, forced her, and lay with her.
8333	280	15	Then Amnon hated her exceedingly; so that the hatred wherewith he hated her was greater than the love wherewith he had loved her. And Amnon said unto her, Arise, be gone.
8334	280	16	And she said unto him, There is no cause: this evil in sending me away is greater than the other that thou didst unto me. But he would not hearken unto her.
8335	280	17	Then he called his servant that ministered unto him, and said, Put now this woman out from me, and bolt the door after her.
8336	280	18	And she had a garment of divers colours upon her: for with such robes were the king's daughters that were virgins apparelled. Then his servant brought her out, and bolted the door after her.
8337	280	19	And Tamar put ashes on her head, and rent her garment of divers colours that was on her, and laid her hand on her head, and went on crying.
8338	280	20	And Absalom her brother said unto her, Hath Amnon thy brother been with thee? but hold now thy peace, my sister: he is thy brother; regard not this thing. So Tamar remained desolate in her brother Absalom's house.
8339	280	21	But when king David heard of all these things, he was very wroth.
8340	280	22	And Absalom spake unto his brother Amnon neither good nor bad: for Absalom hated Amnon, because he had forced his sister Tamar.
8341	280	23	And it came to pass after two full years, that Absalom had sheepshearers in Baal-hazor, which is beside Ephraim: and Absalom invited all the king's sons.
8342	280	24	And Absalom came to the king, and said, Behold now, thy servant hath sheepshearers; let the king, I beseech thee, and his servants go with thy servant.
8343	280	25	And the king said to Absalom, Nay, my son, let us not all now go, lest we be chargeable unto thee. And he pressed him: howbeit he would not go, but blessed him.
8344	280	26	Then said Absalom, If not, I pray thee, let my brother Amnon go with us. And the king said unto him, Why should he go with thee?
8345	280	27	But Absalom pressed him, that he let Amnon and all the king's sons go with him.
8346	280	28	Now Absalom had commanded his servants, saying, Mark ye now when Amnon's heart is merry with wine, and when I say unto you, Smite Amnon; then kill him, fear not: have not I commanded you? be courageous, and be valiant.
8347	280	29	And the servants of Absalom did unto Amnon as Absalom had commanded. Then all the king's sons arose, and every man gat him up upon his mule, and fled.
8348	280	30	And it came to pass, while they were in the way, that tidings came to David, saying, Absalom hath slain all the king's sons, and there is not one of them left.
8349	280	31	Then the king arose, and tare his garments, and lay on the earth; and all his servants stood by with their clothes rent.
8350	280	32	And Jonadab, the son of Shimeah David's brother, answered and said, Let not my lord suppose that they have slain all the young men the king's sons; for Amnon only is dead: for by the appointment of Absalom this hath been determined from the day that he forced his sister Tamar.
8351	280	33	Now therefore let not my lord the king take the thing to his heart, to think that all the king's sons are dead: for Amnon only is dead.
8352	280	34	But Absalom fled. And the young man that kept the watch lifted up his eyes, and looked, and, behold, there came much people by the way of the hill side behind him.
8353	280	35	And Jonadab said unto the king, Behold, the king's sons come: as thy servant said, so it is.
8354	280	36	And it came to pass, as soon as he had made an end of speaking, that, behold, the king's sons came, and lifted up their voice and wept: and the king also and all his servants wept very sore.
8355	280	37	But Absalom fled, and went to Talmai, the son of Ammihud, king of Geshur. And David mourned for his son every day.
8356	280	38	So Absalom fled, and went to Geshur, and was there three years.
8357	280	39	And the soul of king David longed to go forth unto Absalom: for he was comforted concerning Amnon, seeing he was dead.
8358	281	1	NOW Joab the son of Zeruiah perceived that the king's heart was toward Absalom.
8359	281	2	And Joab sent to Tekoah, and fetched thence a wise woman, and said unto her, I pray thee, feign thyself to be a mourner, and put on now mourning apparel, and anoint not thyself with oil, but be as a woman that had a long time mourned for the dead:
8360	281	3	And come to the king, and speak on this manner unto him. So Joab put the words in her mouth.
8361	281	4	And when the woman of Tekoah spake to the king, she fell on her face to the ground, and did obeisance, and said, Help, O king.
8362	281	5	And the king said unto her, What aileth thee? And she answered, I am indeed a widow woman, and mine husband is dead.
8363	281	6	And thy handmaid had two sons, and they two strove together in the field, and there was none to part them, but the one smote the other, and slew him.
8364	281	7	And, behold, the whole family is risen against thine handmaid, and they said, Deliver him that smote his brother, that we may kill him, for the life of his brother whom he slew; and we will destroy the heir also: and so they shall quench my coal which is left, and shall not leave to my husband neither name nor remainder upon the earth.
8365	281	8	And the king said unto the woman, Go to thine house, and I will give charge concerning thee.
8366	281	9	And the woman of Tekoah said unto the king, My lord, O king, the iniquity be on me, and on my father's house: and the king and his throne be guiltless.
8367	281	10	And the king said, Whosoever saith ought unto thee, bring him to me, and he shall not touch thee any more.
8368	281	11	Then said she, I pray thee, let the king remember the LORD thy God, that thou wouldest not suffer the revengers of blood to destroy any more, lest they destroy my son. And he said, As the LORD liveth, there shall not one hair of thy son fall to the earth.
8369	281	12	Then the woman said, Let thine handmaid, I pray thee, speak one word unto my lord the king. And he said, Say on.
8370	281	13	And the woman said, Wherefore then hast thou thought such a thing against the people of God? for the king doth speak this thing as one which is faulty, in that the king doth not fetch home again his banished.
8371	281	14	For we must needs die, and are as water spilt on the ground, which cannot be gathered up again; neither doth God respect any person: yet doth he devise means, that his banished be not expelled from him.
8372	281	15	Now therefore that I am come to speak of this thing unto my lord the king, it is because the people have made me afraid: and thy handmaid said, I will now speak unto the king; it may be that the king will perform the request of his handmaid.
8373	281	16	For the king will hear, to deliver his handmaid out of the hand of the man that would destroy me and my son together out of the inheritance of God.
8374	281	17	Then thine handmaid said, The word of my lord the king shall now be comfortable: for as an angel of God, so is my lord the king to discern good and bad: therefore the LORD thy God will be with thee.
8375	281	18	Then the king answered and said unto the woman, Hide not from me, I pray thee, the thing that I shall ask thee. And the woman said, Let my lord the king now speak.
8376	281	19	And the king said, Is not the hand of Joab with thee in all this? And the woman answered and said, As thy soul liveth, my lord the king, none can turn to the right hand or to the left from ought that my lord the king hath spoken: for thy servant Joab, he bade me, and he put all these words in the mouth of thine handmaid:
8377	281	20	To fetch about this form of speech hath thy servant Joab done this thing: and my lord is wise, according to the wisdom of an angel of God, to know all things that are in the earth.
8378	281	21	And the king said unto Joab, Behold now, I have done this thing: go therefore, bring the young man Absalom again.
8379	281	22	And Joab fell to the ground on his face, and bowed himself, and thanked the king: and Joab said, To day thy servant knoweth that I have found grace in thy sight, my lord, O king, in that the king hath fulfilled the request of his servant.
8380	281	23	So Joab arose and went to Geshur, and brought Absalom to Jerusalem.
8381	281	24	And the king said, Let him turn to his own house, and let him not see my face. So Absalom returned to his own house, and saw not the king's face.
8382	281	25	But in all Israel there was none to be so much praised as Absalom for his beauty: from the sole of his foot even to the crown of his head there was no blemish in him.
8383	281	26	And when he polled his head, (for it was at every year's end that he polled it: because the hair was heavy on him, therefore he polled it:) he weighed the hair of his head at two hundred shekels after the king's weight.
8384	281	27	And unto Absalom there were born three sons, and one daughter, whose name was Tamar: she was a woman of a fair countenance.
8385	281	28	So Absalom dwelt two full years in Jerusalem, and saw not the king's face.
8386	281	29	Therefore Absalom sent for Joab, to have sent him to the king; but he would not come to him: and when he sent again the second time, he would not come.
8387	281	30	Therefore he said unto his servants, See, Joab's field is near mine, and he hath barley there; go and set it on fire. And Absalom's servants set the field on fire.
8388	281	31	Then Joab arose, and came to Absalom unto his house, and said unto him, Wherefore have thy servants set my field on fire?
8389	281	32	And Absalom answered Joab, Behold, I sent unto thee, saying, Come hither, that I may send thee to the king, to say, Wherefore am I come from Geshur? it had been good for me to have been there still: now therefore let me see the king's face; and if there be any iniquity in me, let him kill me.
8390	281	33	So Joab came to the king, and told him: and when he had called for Absalom, he came to the king, and bowed himself on his face to the ground before the king: and the king kissed Absalom.
8391	282	1	AND it came to pass after this, that Absalom prepared him chariots and horses, and fifty men to run before him.
8392	282	2	And Absalom rose up early, and stood beside the way of the gate: and it was so, that when any man that had a controversy came to the king for judgment, then Absalom called unto him, and said, Of what city art thou? And he said, Thy servant is of one of the tribes of Israel.
8393	282	3	And Absalom said unto him, See, thy matters are good and right; but there is no man deputed of the king to hear thee.
8394	282	4	Absalom said moreover, Oh that I were made judge in the land, that every man which hath any suit or cause might come unto me, and I would do him justice!
8395	282	5	And it was so, that when any man came nigh to him to do him obeisance, he put forth his hand, and took him, and kissed him.
8396	282	6	And on this manner did Absalom to all Israel that came to the king for judgment: so Absalom stole the hearts of the men of Israel.
8397	282	7	And it came to pass after forty years, that Absalom said unto the king, I pray thee, let me go and pay my vow, which I have vowed unto the LORD, in Hebron.
8398	282	8	For thy servant vowed a vow while I abode at Geshur in Syria, saying, If the LORD shall bring me again indeed to Jerusalem, then I will serve the LORD.
8399	282	9	And the king said unto him, Go in peace. So he arose, and went to Hebron.
8400	282	10	But Absalom sent spies throughout all the tribes of Israel, saying, As soon as ye hear the sound of the trumpet, then ye shall say, Absalom reigneth in Hebron.
8401	282	11	And with Absalom went two hundred men out of Jerusalem, that were called; and they went in their simplicity, and they knew not any thing.
8402	282	12	And Absalom sent for Ahithophel the Gilonite, David's counsellor, from his city, even from Giloh, while he offered sacrifices. And the conspiracy was strong; for the people increased continually with Absalom.
8403	282	13	And there came a messenger to David, saying, The hearts of the men of Israel are after Absalom.
8404	282	14	And David said unto all his servants that were with him at Jerusalem, Arise, and let us flee; for we shall not else escape from Absalom: make speed to depart, lest he overtake us suddenly, and bring evil upon us, and smite the city with the edge of the sword.
8405	282	15	And the king's servants said unto the king, Behold, thy servants are ready to do whatsoever my lord the king shall appoint.
8406	282	16	And the king went forth, and all his household after him. And the king left ten women, which were concubines, to keep the house.
8407	282	17	And the king went forth, and all the people after him, and tarried in a place that was far off.
8408	282	18	And all his servants passed on beside him; and all the Cherethites, and all the Pelethites, and all the Gittites, six hundred men which came after him from Gath, passed on before the king.
8409	282	19	Then said the king to Ittai the Gittite, Wherefore goest thou also with us? return to thy place, and abide with the king: for thou art a stranger, and also an exile.
8410	282	20	Whereas thou camest but yesterday, should I this day make thee go up and down with us? seeing I go whither I may, return thou, and take back thy brethren: mercy and truth be with thee.
8411	282	21	And Ittai answered the king, and said, As the LORD liveth, and as my lord the king liveth, surely in what place my lord the king shall be, whether in death or life, even there also will thy servant be.
8412	282	22	And David said to Ittai, Go and pass over. And Ittai the Gittite passed over, and all his men, and all the little ones that were with him.
8413	282	23	And all the country wept with a loud voice, and all the people passed over: the king also himself passed over the brook Kidron, and all the people passed over, toward the way of the wilderness.
8414	282	24	And lo Zadok also, and all the Levites were with him, bearing the ark of the covenant of God: and they set down the ark of God; and Abiathar went up, until all the people had done passing out of the city.
8415	282	25	And the king said unto Zadok, Carry back the ark of God into the city: if I shall find favour in the eyes of the LORD, he will bring me again, and shew me both it, and his habitation:
8416	282	26	But if he thus say, I have no delight in thee; behold, here am I, let him do to me as seemeth good unto him.
8417	282	27	The king said also unto Zadok the priest, Art not thou a seer? return into the city in peace, and your two sons with you, Ahimaaz thy son, and Jonathan the son of Abiathar.
8418	282	28	See, I will tarry in the plain of the wilderness, until there come word from you to certify me.
8419	282	29	Zadok therefore and Abiathar carried the ark of God again to Jerusalem: and they tarried there.
8420	282	30	And David went up by the ascent of mount Olivet, and wept as he went up, and had his head covered, and he went barefoot: and all the people that was with him covered every man his head, and they went up, weeping as they went up.
8421	282	31	And one told David, saying, Ahithophel is among the conspirators with Absalom. And David said, O LORD, I pray thee, turn the counsel of Ahithophel into foolishness.
8422	282	32	And it came to pass, that when David was come to the top of the mount, where he worshipped God, behold, Hushai the Archite came to meet him with his coat rent, and earth upon his head:
8423	282	33	Unto whom David said, If thou passest on with me, then thou shalt be a burden unto me:
8424	282	34	But if thou return to the city, and say unto Absalom, I will be thy servant, O king; as I have been thy father's servant hitherto, so will I now also be thy servant: then mayest thou for me defeat the counsel of Ahithophel.
8425	282	35	And hast thou not there with thee Zadok and Abiathar the priests? therefore it shall be, that what thing soever thou shalt hear out of the king's house, thou shalt tell it to Zadok and Abiathar the priests.
8426	282	36	Behold, they have there with them their two sons, Ahimaaz Zadok's son, and Jonathan Abiathar's son; and by them ye shall send unto me every thing that ye can hear.
8427	282	37	So Hushai David's friend came into the city, and Absalom came into Jerusalem.
8428	283	1	AND when David was a little past the top of the hill, behold, Ziba the servant of Mephibosheth met him, with a couple of asses saddled, and upon them two hundred loaves of bread, and an hundred bunches of raisins, and an hundred of summer fruits, and a bottle of wine.
8429	283	2	And the king said unto Ziba, What meanest thou by these? And Ziba said, The asses be for the king's household to ride on; and the bread and summer fruit for the young men to eat; and the wine, that such as be faint in the wilderness may drink.
8430	283	3	And the king said, And where is thy master's son? And Ziba said unto the king, Behold, he abideth at Jerusalem: for he said, To day shall the house of Israel restore me the kingdom of my father.
8431	283	4	Then said the king to Ziba, Behold, thine are all that pertained unto Mephibosheth. And Ziba said, I humbly beseech thee that I may find grace in thy sight, my lord, O king.
8432	283	5	And when king David came to Bahurim, behold, thence came out a man of the family of the house of Saul, whose name was Shimei, the son of Gera: he came forth, and cursed still as he came.
8433	283	6	And he cast stones at David, and at all the servants of king David: and all the people and all the mighty men were on his right hand and on his left.
8434	283	7	And thus said Shimei when he cursed, Come out, come out, thou bloody man, and thou man of Belial:
8435	283	8	The LORD hath returned upon thee all the blood of the house of Saul, in whose stead thou hast reigned; and the LORD hath delivered the kingdom into the hand of Absalom thy son: and, behold, thou art taken in thy mischief, because thou art a bloody man.
8436	283	9	Then said Abishai the son of Zeruiah unto the king, Why should this dead dog curse my lord the king? let me go over, I pray thee, and take off his head.
8437	283	10	And the king said, What have I to do with you, ye sons of Zeruiah? so let him curse, because the LORD hath said unto him, Curse David. Who shall then say, Wherefore hast thou done so?
8438	283	11	And David said to Abishai, and to all his servants, Behold, my son, which came forth of my bowels, seeketh my life: how much more now may this Benjamite do it? let him alone, and let him curse; for the LORD hath bidden him.
8439	283	12	It may be that the LORD will look on mine affliction, and that the LORD will requite me good for his cursing this day.
8440	283	13	And as David and his men went by the way, Shimei went along on the hill's side over against him, and cursed as he went, and threw stones at him, and cast dust.
8441	283	14	And the king, and all the people that were with him, came weary, and refreshed themselves there.
8442	283	15	And Absalom, and all the people the men of Israel, came to Jerusalem, and Ahithophel with him.
8443	283	16	And it came to pass, when Hushai the Archite, David's friend, was come unto Absalom, that Hushai said unto Absalom, God save the king, God save the king.
8444	283	17	And Absalom said to Hushai, Is this thy kindness to thy friend? why wentest thou not with thy friend?
8445	283	18	And Hushai said unto Absalom, Nay; but whom the LORD, and this people, and all the men of Israel, choose, his will I be, and with him will I abide.
8446	283	19	And again, whom should I serve? should I not serve in the presence of his son? as I have served in thy father's presence, so will I be in thy presence.
8447	283	20	Then said Absalom to Ahithophel, Give counsel among you what we shall do.
8448	283	21	And Ahithophel said unto Absalom, Go in unto thy father's concubines, which he hath left to keep the house; and all Israel shall hear that thou art abhorred of thy father: then shall the hands of all that are with thee be strong.
8449	283	22	So they spread Absalom a tent upon the top of the house; and Absalom went in unto his father's concubines in the sight of all Israel.
8450	283	23	And the counsel of Ahithophel, which he counselled in those days, was as if a man had enquired at the oracle of God: so was all the counsel of Ahithophel both with David and with Absalom.
8451	284	1	MOREOVER Ahithophel said unto Absalom, Let me now choose out twelve thousand men, and I will arise and pursue after David this night:
8452	284	2	And I will come upon him while he is weary and weak handed, and will make him afraid: and all the people that are with him shall flee; and I will smite the king only:
8453	284	3	And I will bring back all the people unto thee: the man whom thou seekest is as if all returned: so all the people shall be in peace.
8454	284	4	And the saying pleased Absalom well, and all the elders of Israel.
8455	284	5	Then said Absalom, Call now Hushai the Archite also, and let us hear likewise what he saith.
8456	284	6	And when Hushai was come to Absalom, Absalom spake unto him, saying, Ahithophel hath spoken after this manner: shall we do after his saying? if not; speak thou.
8457	284	7	And Hushai said unto Absalom, The counsel that Ahithophel hath given is not good at this time.
8458	284	8	For, said Hushai, thou knowest thy father and his men, that they be mighty men, and they be chafed in their minds, as a bear robbed of her whelps in the field: and thy father is a man of war, and will not lodge with the people.
8459	284	9	Behold, he is hid now in some pit, or in some other place: and it will come to pass, when some of them be overthrown at the first, that whosoever heareth it will say, There is a slaughter among the people that follow Absalom.
8460	284	10	And he also that is valiant, whose heart is as the heart of a lion, shall utterly melt: for all Israel knoweth that thy father is a mighty man, and they which be with him are valiant men.
8461	284	11	Therefore I counsel that all Israel be generally gathered unto thee, from Dan even to Beer-sheba, as the sand that is by the sea for multitude; and that thou go to battle in thine own person.
8462	284	12	So shall we come upon him in some place where he shall be found, and we will light upon him as the dew falleth on the ground: and of him and of all the men that are with him there shall not be left so much as one.
8463	284	13	Moreover, if he be gotten into a city, then shall all Israel bring ropes to that city, and we will draw it into the river, until there be not one small stone found there.
8464	284	14	And Absalom and all the men of Israel said, The counsel of Hushai the Archite is better than the counsel of Ahithophel. For the LORD had appointed to defeat the good counsel of Ahithophel, to the intent that the LORD might bring evil upon Absalom.
8465	284	15	Then said Hushai unto Zadok and to Abiathar the priests, Thus and thus did Ahithophel counsel Absalom and the elders of Israel; and thus and thus have I counselled.
8466	284	16	Now therefore send quickly, and tell David, saying, Lodge not this night in the plains of the wilderness, but speedily pass over; lest the king be swallowed up, and all the people that are with him.
8467	284	17	Now Jonathan and Ahimaaz stayed by En-rogel; for they might not be seen to come into the city: and a wench went and told them; and they went and told king David.
8468	284	18	Nevertheless a lad saw them, and told Absalom: but they went both of them away quickly, and came to a man's house in Bahurim, which had a well in his court; whither they went down.
8469	284	19	And the woman took and spread a covering over the well's mouth, and spread ground corn thereon; and the thing was not known.
8470	284	20	And when Absalom's servants came to the woman to the house, they said, Where is Ahimaaz and Jonathan? And the woman said unto them, They be gone over the brook of water. And when they had sought and could not find them, they returned to Jerusalem.
8471	284	21	And it came to pass, after they were departed, that they came up out of the well, and went and told king David, and said unto David, Arise, and pass quickly over the water: for thus hath Ahithophel counselled against you.
8472	284	22	Then David arose, and all the people that were with him, and they passed over Jordan: by the morning light there lacked not one of them that was not gone over Jordan.
8473	284	23	And when Ahithophel saw that his counsel was not followed, he saddled his ass, and arose, and gat him home to his house, to his city, and put his household in order, and hanged himself, and died, and was buried in the sepulchre of his father.
8474	284	24	Then David came to Mahanaim. And Absalom passed over Jordan, he and all the men of Israel with him.
8475	284	25	And Absalom made Amasa captain of the host instead of Joab: which Amasa was a man's son, whose name was Ithra an Israelite, that went in to Abigail the daughter of Nahash, sister to Zeruiah Joab's mother.
8476	284	26	So Israel and Absalom pitched in the land of Gilead.
8477	284	27	And it came to pass, when David was come to Mahanaim, that Shobi the son of Nahash of Rabbah of the children of Ammon, and Machir the son of Ammiel of Lo-debar, and Barzillai the Gileadite of Rogelim,
8478	284	28	Brought beds, and basons, and earthen vessels, and wheat, and barley, and flour, and parched corn, and beans, and lentiles, and parched pulse,
8479	284	29	And honey, and butter, and sheep, and cheese of kine, for David, and for the people that were with him, to eat: for they said, The people is hungry, and weary, and thirsty, in the wilderness.
8480	285	1	AND David numbered the people that were with him, and set captains of thousands and captains of hundreds over them.
8481	285	2	And David sent forth a third part of the people under the hand of Joab, and a third part under the hand of Abishai the son of Zeruiah, Joab's brother, and a third part under the hand of Ittai the Gittite. And the king said unto the people, I will surely go forth with you myself also.
8482	285	3	But the people answered, Thou shalt not go forth: for if we flee away, they will not care for us; neither if half of us die, will they care for us: but now thou art worth ten thousand of us: therefore now it is better that thou succour us out of the city.
8483	285	4	And the king said unto them, What seemeth you best I will do. And the king stood by the gate side, and all the people came out by hundreds and by thousands.
8484	285	5	And the king commanded Joab and Abishai and Ittai, saying, Deal gently for my sake with the young man, even with Absalom. And all the people heard when the king gave all the captains charge concerning Absalom.
8485	285	6	So the people went out into the field against Israel: and the battle was in the wood of Ephraim;
8486	285	7	Where the people of Israel were slain before the servants of David, and there was there a great slaughter that day of twenty thousand men.
8487	285	8	For the battle was there scattered over the face of all the country: and the wood devoured more people that day than the sword devoured.
8488	285	9	And Absalom met the servants of David. And Absalom rode upon a mule, and the mule went under the thick boughs of a great oak, and his head caught hold of the oak, and he was taken up between the heaven and the earth; and the mule that was under him went away.
8489	285	10	And a certain man saw it, and told Joab, and said, Behold, I saw Absalom hanged in an oak.
8490	285	11	And Joab said unto the man that told him, And, behold, thou sawest him, and why didst thou not smite him there to the ground? and I would have given thee ten shekels of silver, and a girdle.
8491	285	12	And the man said unto Joab, Though I should receive a thousand shekels of silver in mine hand, yet would I not put forth mine hand against the king's son: for in our hearing the king charged thee and Abishai and Ittai, saying, Beware that none touch the young man Absalom.
8492	285	13	Otherwise I should have wrought falsehood against mine own life: for there is no matter hid from the king, and thou thyself wouldest have set thyself against me.
8493	285	14	Then said Joab, I may not tarry thus with thee. And he took three darts in his hand, and thrust them through the heart of Absalom, while he was yet alive in the midst of the oak.
8494	285	15	And ten young men that bare Joab's armour compassed about and smote Absalom, and slew him.
8495	285	16	And Joab blew the trumpet, and the people returned from pursuing after Israel: for Joab held back the people.
8496	285	17	And they took Absalom, and cast him into a great pit in the wood, and laid a very great heap of stones upon him: and all Israel fled every one to his tent.
8497	285	18	Now Absalom in his lifetime had taken and reared up for himself a pillar, which is in the king's dale: for he said, I have no son to keep my name in remembrance: and he called the pillar after his own name: and it is called unto this day, Absalom's place.
8498	285	19	Then said Ahimaaz the son of Zadok, Let me now run, and bear the king tidings, how that the LORD hath avenged him of his enemies.
8499	285	20	And Joab said unto him, Thou shalt not bear tidings this day, but thou shalt bear tidings another day: but this day thou shalt bear no tidings, because the king's son is dead.
8500	285	21	Then said Joab to Cushi, Go tell the king what thou hast seen. And Cushi bowed himself unto Joab, and ran.
8501	285	22	Then said Ahimaaz the son of Zadok yet again to Joab, But howsoever, let me, I pray thee, also run after Cushi. And Joab said, Wherefore wilt thou run, my son, seeing that thou hast no tidings ready?
8502	285	23	But howsoever, said he, let me run. And he said unto him, Run. Then Ahimaaz ran by the way of the plain, and overran Cushi.
8503	285	24	And David sat between the two gates: and the watchman went up to the roof over the gate unto the wall, and lifted up his eyes, and looked, and behold a man running alone.
8504	285	25	And the watchman cried, and told the king. And the king said, If he be alone, there is tidings in his mouth. And he came apace, and drew near.
8505	285	26	And the watchman saw another man running: and the watchman called unto the porter, and said, Behold another man running alone. And the king said, He also bringeth tidings.
8506	285	27	And the watchman said, Me thinketh the running of the foremost is like the running of Ahimaaz the son of Zadok. And the king said, He is a good man, and cometh with good tidings.
8507	285	28	And Ahimaaz called, and said unto the king, All is well. And he fell down to the earth upon his face before the king, and said, Blessed be the LORD thy God, which hath delivered up the men that lifted up their hand against my lord the king.
8508	285	29	And the king said, Is the young man Absalom safe? And Ahimaaz answered, When Joab sent the king's servant, and me thy servant, I saw a great tumult, but I knew not what it was.
8509	285	30	And the king said unto him, Turn aside, and stand here. And he turned aside, and stood still.
8510	285	31	And, behold, Cushi came; and Cushi said, Tidings, my lord the king: for the LORD hath avenged thee this day of all them that rose up against thee.
8511	285	32	And the king said unto Cushi, Is the young man Absalom safe? And Cushi answered, The enemies of my lord the king, and all that rise against thee to do thee hurt, be as that young man is.
8512	285	33	And the king was much moved, and went up to the chamber over the gate, and wept: and as he went, thus he said, O my son Absalom, my son, my son Absalom! would God I had died for thee, O Absalom, my son, my son!
8513	286	1	AND it was told Joab, Behold, the king weepeth and mourneth for Absalom.
8514	286	2	And the victory that day was turned into mourning unto all the people: for the people heard say that day how the king was grieved for his son.
8515	286	3	And the people gat them by stealth that day into the city, as people being ashamed steal away when they flee in battle.
8516	286	4	But the king covered his face, and the king cried with a loud voice, O my son Absalom, O Absalom, my son, my son!
8517	286	5	And Joab came into the house to the king, and said, Thou hast shamed this day the faces of all thy servants, which this day have saved thy life, and the lives of thy sons and of thy daughters, and the lives of thy wives, and the lives of thy concubines;
8518	286	6	In that thou lovest thine enemies, and hatest thy friends. For thou hast declared this day, that thou regardest neither princes nor servants: for this day I perceive, that if Absalom had lived, and all we had died this day, then it had pleased thee well.
8519	286	7	Now therefore arise, go forth, and speak comfortably unto thy servants: for I swear by the LORD, if thou go not forth, there will not tarry one with thee this night: and that will be worse unto thee than all the evil that befell thee from thy youth until now.
8520	286	8	Then the king arose, and sat in the gate. And they told unto all the people, saying, Behold, the king doth sit in the gate. And all the people came before the king: for Israel had fled every man to his tent.
8521	286	9	And all the people were at strife throughout all the tribes of Israel, saying, The king saved us out of the hand of our enemies, and he delivered us out of the hand of the Philistines; and now he is fled out of the land for Absalom.
8522	286	10	And Absalom, whom we anointed over us, is dead in battle. Now therefore why speak ye not a word of bringing the king back?
8523	286	11	And king David sent to Zadok and to Abiathar the priests, saying, Speak unto the elders of Judah, saying, Why are ye the last to bring the king back to his house? seeing the speech of all Israel is come to the king, even to his house.
8524	286	12	Ye are my brethren, ye are my bones and my flesh: wherefore then are ye the last to bring back the king?
8525	286	13	And say ye to Amasa, Art thou not of my bone, and of my flesh? God do so to me, and more also, if thou be not captain of the host before me continually in the room of Joab.
8526	286	14	And he bowed the heart of all the men of Judah, even as the heart of one man; so that they sent this word unto the king, Return thou, and all thy servants.
8527	286	15	So the king returned, and came to Jordan. And Judah came to Gilgal, to go to meet the king, to conduct the king over Jordan.
8528	286	16	And Shimei the son of Gera, a Benjamite, which was of Bahurim, hasted and came down with the men of Judah to meet king David.
8529	286	17	And there were a thousand men of Benjamin with him, and Ziba the servant of the house of Saul, and his fifteen sons and his twenty servants with him; and they went over Jordan before the king.
8530	286	18	And there went over a ferry boat to carry over the king's household, and to do what he thought good. And Shimei the son of Gera fell down before the king, as he was come over Jordan;
8531	286	19	And said unto the king, Let not my lord impute iniquity unto me, neither do thou remember that which thy servant did perversely the day that my lord the king went out of Jerusalem, that the king should take it to his heart.
8532	286	20	For thy servant doth know that I have sinned: therefore, behold, I am come the first this day of all the house of Joseph to go down to meet my lord the king.
8533	286	21	But Abishai the son of Zeruiah answered and said, Shall not Shimei be put to death for this, because he cursed the LORD's anointed?
8534	286	22	And David said, What have I to do with you, ye sons of Zeruiah, that ye should this day be adversaries unto me? shall there any man be put to death this day in Israel? for do not I know that I am this day king over Israel?
8535	286	23	Therefore the king said unto Shimei, Thou shalt not die. And the king sware unto him.
8536	286	24	And Mephibosheth the son of Saul came down to meet the king, and had neither dressed his feet, nor trimmed his beard, nor washed his clothes, from the day the king departed until the day he came again in peace.
8537	286	25	And it came to pass, when he was come to Jerusalem to meet the king, that the king said unto him, Wherefore wentest not thou with me, Mephibosheth?
8538	286	26	And he answered, My lord, O king, my servant deceived me: for thy servant said, I will saddle me an ass, that I may ride thereon, and go to the king; because thy servant is lame.
8539	286	27	And he hath slandered thy servant unto my lord the king; but my lord the king is as an angel of God: do therefore what is good in thine eyes.
8540	286	28	For all of my father's house were but dead men before my lord the king: yet didst thou set thy servant among them that did eat at thine own table. What right therefore have I yet to cry any more unto the king?
8541	286	29	And the king said unto him, Why speakest thou any more of thy matters? I have said, Thou and Ziba divide the land.
8542	286	30	And Mephibosheth said unto the king, Yea, let him take all, forasmuch as my lord the king is come again in peace unto his own house.
8543	286	31	And Barzillai the Gileadite came down from Rogelim, and went over Jordan with the king, to conduct him over Jordan.
8544	286	32	Now Barzillai was a very aged man, even fourscore years old: and he had provided the king of sustenance while he lay at Mahanaim; for he was a very great man.
8545	286	33	And the king said unto Barzillai, Come thou over with me, and I will feed thee with me in Jerusalem.
8546	286	34	And Barzillai said unto the king, How long have I to live, that I should go up with the king unto Jerusalem?
8547	286	35	I am this day fourscore years old: and can I discern between good and evil? can thy servant taste what I eat or what I drink? can I hear any more the voice of singing men and singing women? wherefore then should thy servant be yet a burden unto my lord the king?
8548	286	36	Thy servant will go a little way over Jordan with the king: and why should the king recompense it me with such a reward?
8549	286	37	Let thy servant, I pray thee, turn back again, that I may die in mine own city, and be buried by the grave of my father and of my mother. But behold thy servant Chimham; let him go over with my lord the king; and do to him what shall seem good unto thee.
8550	286	38	And the king answered, Chimham shall go over with me, and I will do to him that which shall seem good unto thee: and whatsoever thou shalt require of me, that will I do for thee.
8551	286	39	And all the people went over Jordan. And when the king was come over, the king kissed Barzillai, and blessed him; and he returned unto his own place.
8552	286	40	Then the king went on to Gilgal, and Chimham went on with him: and all the people of Judah conducted the king, and also half the people of Israel.
8553	286	41	And, behold, all the men of Israel came to the king, and said unto the king, Why have our brethren the men of Judah stolen thee away, and have brought the king, and his household, and all David's men with him, over Jordan?
8554	286	42	And all the men of Judah answered the men of Israel, Because the king is near of kin to us: wherefore then be ye angry for this matter? have we eaten at all of the king's cost? or hath he given us any gift?
8555	286	43	And the men of Israel answered the men of Judah, and said, We have ten parts in the king, and we have also more right in David than ye: why then did ye despise us, that our advice should not be first had in bringing back our king? And the words of the men of Judah were fiercer than the words of the men of Israel.
8556	287	1	AND there happened to be there a man of Belial, whose name was Sheba, the son of Bichri, a Benjamite: and he blew a trumpet, and said, We have no part in David, neither have we inheritance in the son of Jesse: every man to his tents, O Israel.
8557	287	2	So every man of Israel went up from after David, and followed Sheba the son of Bichri: but the men of Judah clave unto their king, from Jordan even to Jerusalem.
8558	287	3	And David came to his house at Jerusalem; and the king took the ten women his concubines, whom he had left to keep the house, and put them in ward, and fed them, but went not in unto them. So they were shut up unto the day of their death, living in widowhood.
8559	287	4	Then said the king to Amasa, Assemble me the men of Judah within three days, and be thou here present.
8560	287	5	So Amasa went to assemble the men of Judah: but he tarried longer than the set time which he had appointed him.
8561	287	6	And David said to Abishai, Now shall Sheba the son of Bichri do us more harm than did Absalom: take thou thy lord's servants, and pursue after him, lest he get him fenced cities, and escape us.
8562	287	7	And there went out after him Joab's men, and the Cherethites, and the Pelethites, and all the mighty men: and they went out of Jerusalem, to pursue after Sheba the son of Bichri.
8563	287	8	When they were at the great stone which is in Gibeon, Amasa went before them. And Joab's garment that he had put on was girded unto him, and upon it a girdle with a sword fastened upon his loins in the sheath thereof; and as he went forth it fell out.
8564	287	9	And Joab said to Amasa, Art thou in health, my brother? And Joab took Amasa by the beard with the right hand to kiss him.
8565	287	10	But Amasa took no heed to the sword that was in Joab's hand: so he smote him therewith in the fifth rib, and shed out his bowels to the ground, and struck him not again; and he died. So Joab and Abishai his brother pursued after Sheba the son of Bichri.
8566	287	11	And one of Joab's men stood by him, and said, He that favoureth Joab, and he that is for David, let him go after Joab.
8567	287	12	And Amasa wallowed in blood in the midst of the highway. And when the man saw that all the people stood still, he removed Amasa out of the highway into the field, and cast a cloth upon him, when he saw that every one that came by him stood still.
8568	287	13	When he was removed out of the highway, all the people went on after Joab, to pursue after Sheba the son of Bichri.
8569	287	14	And he went through all the tribes of Israel unto Abel, and to Beth-maachah, and all the Berites: and they were gathered together, and went also after him.
8570	287	15	And they came and besieged him in Abel of Beth-maachah, and they cast up a bank against the city, and it stood in the trench: and all the people that were with Joab battered the wall, to throw it down.
8571	287	16	Then cried a wise woman out of the city, Hear, hear; say, I pray you, unto Joab, Come near hither, that I may speak with thee.
8572	287	17	And when he was come near unto her, the woman said, Art thou Joab? And he answered, I am he. Then she said unto him, Hear the words of thine handmaid. And he answered, I do hear.
8573	287	18	Then she spake, saying, They were wont to speak in old time, saying, They shall surely ask counsel at Abel: and so they ended the matter.
8574	287	19	I am one of them that are peaceable and faithful in Israel: thou seekest to destroy a city and a mother in Israel: why wilt thou swallow up the inheritance of the LORD?
8575	287	20	And Joab answered and said, Far be it, far be it from me, that I should swallow up or destroy.
8576	287	21	The matter is not so: but a man of mount Ephraim, Sheba the son of Bichri by name, hath lifted up his hand against the king, even against David: deliver him only, and I will depart from the city. And the woman said unto Joab, Behold, his head shall be thrown to thee over the wall.
8577	287	22	Then the woman went unto all the people in her wisdom. And they cut off the head of Sheba the son of Bichri, and cast it out to Joab. And he blew a trumpet, and they retired from the city, every man to his tent. And Joab returned to Jerusalem unto the king.
8578	287	23	Now Joab was over all the host of Israel: and Benaiah the son of Jehoiada was over the Cherethites and over the Pelethites:
8579	287	24	And Adoram was over the tribute: and Jehoshaphat the son of Ahilud was recorder:
8580	287	25	And Sheva was scribe: and Zadok and Abiathar were the priests:
8581	287	26	And Ira also the Jairite was a chief ruler about David.
8582	288	1	THEN there was a famine in the days of David three years, year after year; and David enquired of the LORD. And the LORD answered, It is for Saul, and for his bloody house, because he slew the Gibeonites.
8583	288	2	And the king called the Gibeonites, and said unto them; (now the Gibeonites were not of the children of Israel, but of the remnant of the Amorites; and the children of Israel had sworn unto them: and Saul sought to slay them in his zeal to the children of Israel and Judah.)
8584	288	3	Wherefore David said unto the Gibeonites, What shall I do for you? and wherewith shall I make the atonement, that ye may bless the inheritance of the LORD?
8585	288	4	And the Gibeonites said unto him, We will have no silver nor gold of Saul, nor of his house; neither for us shalt thou kill any man in Israel. And he said, What ye shall say, that will I do for you.
8586	288	5	And they answered the king, The man that consumed us, and that devised against us that we should be destroyed from remaining in any of the coasts of Israel,
8587	288	6	Let seven men of his sons be delivered unto us, and we will hang them up unto the LORD in Gibeah of Saul, whom the LORD did choose. And the king said, I will give them.
8588	288	7	But the king spared Mephibosheth, the son of Jonathan the son of Saul, because of the LORD's oath that was between them, between David and Jonathan the son of Saul.
8589	288	8	But the king took the two sons of Rizpah the daughter of Aiah, whom she bare unto Saul, Armoni and Mephibosheth; and the five sons of Michal the daughter of Saul, whom she brought up for Adriel the son of Barzillai the Meholathite:
8590	288	9	And he delivered them into the hands of the Gibeonites, and they hanged them in the hill before the LORD: and they fell all seven together, and were put to death in the days of harvest, in the first days, in the beginning of barley harvest.
8591	288	10	And Rizpah the daughter of Aiah took sackcloth, and spread it for her upon the rock, from the beginning of harvest until water dropped upon them out of heaven, and suffered neither the birds of the air to rest on them by day, nor the beasts of the field by night.
8592	288	11	And it was told David what Rizpah the daughter of Aiah, the concubine of Saul, had done.
8593	288	12	And David went and took the bones of Saul and the bones of Jonathan his son from the men of Jabesh-gilead, which had stolen them from the street of Beth-shan, where the Philistines had hanged them, when the Philistines had slain Saul in Gilboa:
8594	288	13	And he brought up from thence the bones of Saul and the bones of Jonathan his son; and they gathered the bones of them that were hanged.
8595	288	14	And the bones of Saul and Jonathan his son buried they in the country of Benjamin in Zelah, in the sepulchre of Kish his father: and they performed all that the king commanded. And after that God was intreated for the land.
8596	288	15	Moreover the Philistines had yet war again with Israel; and David went down, and his servants with him, and fought against the Philistines: and David waxed faint.
8597	288	16	And Ishbi-benob, which was of the sons of the giant, the weight of whose spear weighed three hundred shekels of brass in weight, he being girded with a new sword, thought to have slain David.
8598	288	17	But Abishai the son of Zeruiah succoured him, and smote the Philistine, and killed him. Then the men of David sware unto him, saying, Thou shalt go no more out with us to battle, that thou quench not the light of Israel.
8599	288	18	And it came to pass after this, that there was again a battle with the Philistines at Gob: then Sibbechai the Hushathite slew Saph, which was of the sons of the giant.
8600	288	19	And there was again a battle in Gob with the Philistines, where Elhanan the son of Jaare-oregim, a Beth-lehemite, slew the brother of Goliath the Gittite, the staff of whose spear was like a weaver's beam.
8601	288	20	And there was yet a battle in Gath, where was a man of great stature, that had on every hand six fingers, and on every foot six toes, four and twenty in number; and he also was born to the giant.
8602	288	21	And when he defied Israel, Jonathan the son of Shimea the brother of David slew him.
8603	288	22	These four were born to the giant in Gath, and fell by the hand of David, and by the hand of his servants.
8604	289	1	AND David spake unto the LORD the words of this song in the day that the LORD had delivered him out of the hand of all his enemies, and out of the hand of Saul:
8605	289	2	And he said, The LORD is my rock, and my fortress, and my deliverer;
8606	289	3	The God of my rock; in him will I trust: he is my shield, and the horn of my salvation, my high tower, and my refuge, my saviour; thou savest me from violence.
8607	289	4	I will call on the LORD, who is worthy to be praised: so shall I be saved from mine enemies.
8608	289	5	When the waves of death compassed me, the floods of ungodly men made me afraid;
8609	289	6	The sorrows of hell compassed me about; the snares of death prevented me;
8610	289	7	In my distress I called upon the LORD, and cried to my God: and he did hear my voice out of his temple, and my cry did enter into his ears.
8611	289	8	Then the earth shook and trembled; the foundations of heaven moved and shook, because he was wroth.
8612	289	9	There went up a smoke out of his nostrils, and fire out of his mouth devoured: coals were kindled by it.
8613	289	10	He bowed the heavens also, and came down; and darkness was under his feet.
8614	289	11	And he rode upon a cherub, and did fly: and he was seen upon the wings of the wind.
8615	289	12	And he made darkness pavilions round about him, dark waters, and thick clouds of the skies.
8616	289	13	Through the brightness before him were coals of fire kindled.
8617	289	14	The LORD thundered from heaven, and the most High uttered his voice.
8618	289	15	And he sent out arrows, and scattered them; lightning, and discomfited them.
8619	289	16	And the channels of the sea appeared, the foundations of the world were discovered, at the rebuking of the LORD, at the blast of the breath of his nostrils.
8620	289	17	He sent from above, he took me; he drew me out of many waters;
8621	289	18	He delivered me from my strong enemy, and from them that hated me: for they were too strong for me.
8622	289	19	They prevented me in the day of my calamity: but the LORD was my stay.
8623	289	20	He brought me forth also into a large place: he delivered me, because he delighted in me.
8624	289	21	The LORD rewarded me according to my righteousness: according to the cleanness of my hands hath he recompensed me.
8625	289	22	For I have kept the ways of the LORD, and have not wickedly departed from my God.
8626	289	23	For all his judgments were before me: and as for his statutes, I did not depart from them.
8627	289	24	I was also upright before him, and have kept myself from mine iniquity.
8628	289	25	Therefore the LORD hath recompensed me according to my righteousness; according to my cleanness in his eye sight.
8629	289	26	With the merciful thou wilt shew thyself merciful, and with the upright man thou wilt shew thyself upright.
8630	289	27	With the pure thou wilt shew thyself pure; and with the froward thou wilt shew thyself unsavoury.
8631	289	28	And the afflicted people thou wilt save: but thine eyes are upon the haughty, that thou mayest bring them down.
8632	289	29	For thou art my lamp, O LORD: and the LORD will lighten my darkness.
8633	289	30	For by thee I have run through a troop: by my God have I leaped over a wall.
8634	289	31	As for God, his way is perfect; the word of the LORD is tried: he is a buckler to all them that trust in him.
8635	289	32	For who is God, save the LORD? and who is a rock, save our God?
8636	289	33	God is my strength and power: and he maketh my way perfect.
8637	289	34	He maketh my feet like hinds' feet: and setteth me upon my high places.
8638	289	35	He teacheth my hands to war; so that a bow of steel is broken by mine arms.
8639	289	36	Thou hast also given me the shield of thy salvation: and thy gentleness hath made me great.
8640	289	37	Thou hast enlarged my steps under me; so that my feet did not slip.
8641	289	38	I have pursued mine enemies, and destroyed them; and turned not again until I had consumed them.
8642	289	39	And I have consumed them, and wounded them, that they could not arise: yea, they are fallen under my feet.
8643	289	40	For thou hast girded me with strength to battle: them that rose up against me hast thou subdued under me.
8644	289	41	Thou hast also given me the necks of mine enemies, that I might destroy them that hate me.
8645	289	42	They looked, but there was none to save; even unto the LORD, but he answered them not.
8646	289	43	Then did I beat them as small as the dust of the earth, I did stamp them as the mire of the street, and did spread them abroad.
8647	289	44	Thou also hast delivered me from the strivings of my people, thou hast kept me to be head of the heathen: a people which I knew not shall serve me.
8648	289	45	Strangers shall submit themselves unto me: as soon as they hear, they shall be obedient unto me.
8649	289	46	Strangers shall fade away, and they shall be afraid out of their close places.
8650	289	47	The LORD liveth; and blessed be my rock; and exalted be the God of the rock of my salvation.
8651	289	48	It is God that avengeth me, and that bringeth down the people under me,
8652	289	49	And that bringeth me forth from mine enemies: thou also hast lifted me up on high above them that rose up against me: thou hast delivered me from the violent man.
8653	289	50	Therefore I will give thanks unto thee, O LORD, among the heathen, and I will sing praises unto thy name.
8654	289	51	He is the tower of salvation for his king: and sheweth mercy to his anointed, unto David, and to his seed for evermore.
8655	290	1	NOW these be the last words of David. David the son of Jesse said, and the man who was raised up on high, the anointed of the God of Jacob, and the sweet psalmist of Israel, said,
8656	290	2	The Spirit of the LORD spake by me, and his word was in my tongue.
8657	290	3	The God of Israel said, the Rock of Israel spake to me, He that ruleth over men must be just, ruling in the fear of God.
8658	290	4	And he shall be as the light of the morning, when the sun riseth, even a morning without clouds; as the tender grass springing out of the earth by clear shining after rain.
8659	290	5	Although my house be not so with God; yet he hath made with me an everlasting covenant, ordered in all things, and sure: for this is all my salvation, and all my desire, although he make it not to grow.
8660	290	6	But the sons of Belial shall be all of them as thorns thrust away, because they cannot be taken with hands:
8661	290	7	But the man that shall touch them must be fenced with iron and the staff of a spear; and they shall be utterly burned with fire in the same place.
8662	290	8	These be the names of the mighty men whom David had: The Tachmonite that sat in the seat, chief among the captains; the same was Adino the Eznite: he lift up his spear against eight hundred, whom he slew at one time.
8663	290	9	And after him was Eleazar the son of Dodo the Ahohite, one of the three mighty men with David, when they defied the Philistines that were there gathered together to battle, and the men of Israel were gone away:
8664	290	10	He arose, and smote the Philistines until his hand was weary, and his hand clave unto the sword: and the LORD wrought a great victory that day; and the people returned after him only to spoil.
8665	290	11	And after him was Shammah the son of Agee the Hararite. And the Philistines were gathered together into a troop, where was a piece of ground full of lentiles: and the people fled from the Philistines.
8666	290	12	But he stood in the midst of the ground, and defended it, and slew the Philistines: and the LORD wrought a great victory.
8667	290	13	And three of the thirty chief went down, and came to David in the harvest time unto the cave of Adullam: and the troop of the Philistines pitched in the valley of Rephaim.
8668	290	14	And David was then in an hold, and the garrison of the Philistines was then in Beth-lehem.
8669	290	15	And David longed, and said, Oh that one would give me drink of the water of the well of Beth-lehem, which is by the gate!
8670	290	16	And the three mighty men brake through the host of the Philistines, and drew water out of the well of Beth-lehem, that was by the gate, and took it, and brought it to David: nevertheless he would not drink thereof, but poured it out unto the LORD.
8671	290	17	And he said, Be it far from me, O LORD, that I should do this: is not this the blood of the men that went in jeopardy of their lives? therefore he would not drink it. These things did these three mighty men.
8672	290	18	And Abishai, the brother of Joab, the son of Zeruiah, was chief among three. And he lifted up his spear against three hundred, and slew them, and had the name among three.
8673	290	19	Was he not most honourable of three? therefore he was their captain: howbeit he attained not unto the first three.
8674	290	20	And Benaiah the son of Jehoiada, the son of a valiant man, of Kabzeel, who had done many acts, he slew two lionlike men of Moab: he went down also and slew a lion in the midst of a pit in time of snow:
8675	290	21	And he slew an Egyptian, a goodly man: and the Egyptian had a spear in his hand; but he went down to him with a staff, and plucked the spear out of the Egyptian's hand, and slew him with his own spear.
8676	290	22	These things did Benaiah the son of Jehoiada, and had the name among three mighty men.
8677	290	23	He was more honourable than the thirty, but he attained not to the first three. And David set him over his guard.
8678	290	24	Asahel the brother of Joab was one of the thirty; Elhanan the son of Dodo of Beth-lehem,
8679	290	25	Shammah the Harodite, Elika the Harodite,
8680	290	26	Helez the Paltite, Ira the son of Ikkesh the Tekoite,
8681	290	27	Abiezer the Anethothite, Mebunnai the Hushathite,
8682	290	28	Zalmon the Ahohite, Maharai the Netophathite,
8683	290	29	Heleb the son of Baanah, a Netophathite, Ittai the son of Ribai out of Gibeah of the children of Benjamin,
8684	290	30	Benaiah the Pirathonite, Hiddai of the brooks of Gaash,
8685	290	31	Abi-albon the Arbathite, Azmaveth the Barhumite,
8686	290	32	Eliahba the Shaalbonite, of the sons of Jashen, Jonathan,
8687	290	33	Shammah the Hararite, Ahiam the son of Sharar the Hararite,
8688	290	34	Eliphelet the son of Ahasbai, the son of the Maachathite, Eliam the son of Ahithophel the Gilonite,
8689	290	35	Hezrai the Carmelite, Paarai the Arbite,
8690	290	36	Igal the son of Nathan of Zobah, Bani the Gadite,
8691	290	37	Zelek the Ammonite, Naharai the Beerothite, armourbearer to Joab the son of Zeruiah,
8692	290	38	Ira an Ithrite, Gareb an Ithrite,
8693	290	39	Uriah the Hittite: thirty and seven in all.
8694	291	1	AND again the anger of the LORD was kindled against Israel, and he moved David against them to say, Go, number Israel and Judah.
8695	291	2	For the king said to Joab the captain of the host, which was with him, Go now through all the tribes of Israel, from Dan even to Beer-sheba, and number ye the people, that I may know the number of the people.
8696	291	3	And Joab said unto the king, Now the LORD thy God add unto the people, how many soever they be, an hundredfold, and that the eyes of my lord the king may see it: but why doth my lord the king delight in this thing?
8697	291	4	Notwithstanding the king's word prevailed against Joab, and against the captains of the host. And Joab and the captains of the host went out from the presence of the king, to number the people of Israel.
8698	291	5	And they passed over Jordan, and pitched in Aroer, on the right side of the city that lieth in the midst of the river of Gad, and toward Jazer:
8699	291	6	Then they came to Gilead, and to the land of Tahtim-hodshi; and they came to Dan-jaan, and about to Zidon,
8700	291	7	And came to the strong hold of Tyre, and to all the cities of the Hibites, and of the Canaanites: and they went out to the south of Judah, even to Beer-sheba.
8701	291	8	So when they had gone through all the land, they came to Jerusalem at the end of nine months and twenty days.
8702	291	9	And Joab gave up the sum of the number of the people unto the king: and there were in Israel eight hundred thousand valiant men that drew the sword; and the men of Judah were five hundred thousand men.
8703	291	10	And David's heart smote him after that he had numbered the people. And David said unto the LORD, I have sinned greatly in that I have done: and now, I beseech thee, O LORD, take away the iniquity of thy servant; for I have done very foolishly.
8704	291	11	For when David was up in the morning, the word of the LORD came unto the prophet Gad, David's seer, saying,
8705	291	12	Go and say unto David, Thus saith the LORD, I offer thee three things; choose thee one of them, that I may do it unto thee.
8706	291	13	So Gad came to David, and told him, and said unto him, Shall seven years of famine come unto thee in thy land? or wilt thou flee three months before thine enemies, while they pursue thee? or that there be three days' pestilence in thy land? now advise, and see what answer I shall return to him that sent me.
8707	291	14	And David said unto Gad, I am in a great strait: let us fall now into the hand of the LORD; for his mercies are great: and let me not fall into the hand of man.
8708	291	15	So the LORD sent a pestilence upon Israel from the morning even to the time appointed: and there died of the people from Dan even to Beer-sheba seventy thousand men.
8709	291	16	And when the angel stretched out his hand upon Jerusalem to destroy it, the LORD repented him of the evil, and said to the angel that destroyed the people, It is enough: stay now thine hand. And the angel of the LORD was by the threshingplace of Araunah the Jebusite.
8710	291	17	And David spake unto the LORD when he saw the angel that smote the people, and said, Lo, I have sinned, and I have done wickedly: but these sheep, what have they done? let thine hand, I pray thee, be against me, and against my father's house.
8711	291	18	And Gad came that day to David, and said unto him, Go up, rear an altar unto the LORD in the threshingfloor of Araunah the Jebusite.
8712	291	19	And David, according to the saying of Gad, went up as the LORD commanded.
8713	291	20	And Araunah looked, and saw the king and his servants coming on toward him: and Araunah went out, and bowed himself before the king on his face upon the ground.
8714	291	21	And Araunah said, Wherefore is my lord the king come to his servant? And David said, To buy the threshingfloor of thee, to build an altar unto the LORD, that the plague may be stayed from the people.
8715	291	22	And Araunah said unto David, Let my lord the king take and offer up what seemeth good unto him: behold, here be oxen for burnt sacrifice, and threshing instruments and other instruments of the oxen for wood.
8716	291	23	All these things did Araunah, as a king, give unto the king. And Araunah said unto the king, The LORD thy God accept thee.
8717	291	24	And the king said unto Araunah, Nay; but I will surely buy it of thee at a price: neither will I offer burnt offerings unto the LORD my God of that which doth cost me nothing. So David bought the threshingfloor and the oxen for fifty shekels of silver.
8718	291	25	And David built there an altar unto the LORD, and offered burnt offerings and peace offerings. So the LORD was intreated for the land, and the plague was stayed from Israel.
8719	292	1	NOW king David was old and stricken in years; and they covered him with clothes, but he gat no heat.
8720	292	2	Wherefore his servants said unto him, Let there be sought for my lord the king a young virgin: and let her stand before the king, and let her cherish him, and let her lie in thy bosom, that my lord the king may get heat.
8721	292	3	So they sought for a fair damsel throughout all the coasts of Israel, and found Abishag a Shunammite, and brought her to the king.
8722	292	4	And the damsel was very fair, and cherished the king, and ministered to him: but the king knew her not.
8723	292	5	Then Adonijah the son of Haggith exalted himself, saying, I will be king: and he prepared him chariots and horsemen, and fifty men to run before him.
8724	292	6	And his father had not displeased him at any time in saying, Why hast thou done so? and he also was a very goodly man; and his mother bare him after Absalom.
8725	292	7	And he conferred with Joab the son of Zeruiah, and with Abiathar the priest: and they following Adonijah helped him.
8726	292	8	But Zadok the priest, and Benaiah the son of Jehoiada, and Nathan the prophet, and Shimei, and Rei, and the mighty men which belonged to David, were not with Adonijah.
8727	292	9	And Adonijah slew sheep and oxen and fat cattle by the stone of Zoheleth, which is by En-rogel, and called all his brethren the king's sons, and all the men of Judah the king's servants:
8728	292	10	But Nathan the prophet, and Benaiah, and the mighty men, and Solomon his brother, he called not.
8729	292	11	Wherefore Nathan spake unto Bath-sheba the mother of Solomon, saying, Hast thou not heard that Adonijah the son of Haggith doth reign, and David our lord knoweth it not?
8730	292	12	Now therefore come, let me, I pray thee, give thee counsel, that thou mayest save thine own life, and the life of thy son Solomon.
8731	292	13	Go and get thee in unto king David, and say unto him, Didst not thou, my lord, O king, swear unto thine handmaid, saying, Assuredly Solomon thy son shall reign after me, and he shall sit upon my throne? why then doth Adonijah reign?
8732	292	14	Behold, while thou yet talkest there with the king, I also will come in after thee, and confirm thy words.
8733	292	15	And Bath-sheba went in unto the king into the chamber: and the king was very old; and Abishag the Shunammite ministered unto the king.
8734	292	16	And Bath-sheba bowed, and did obeisance unto the king. And the king said, What wouldest thou?
8735	292	17	And she said unto him, My lord, thou swarest by the LORD thy God unto thine handmaid, saying, Assuredly Solomon thy son shall reign after me, and he shall sit upon my throne.
8736	292	18	And now, behold, Adonijah reigneth; and now, my lord the king, thou knowest it not:
8737	292	19	And he hath slain oxen and fat cattle and sheep in abundance, and hath called all the sons of the king, and Abiathar the priest, and Joab the captain of the host: but Solomon thy servant hath he not called.
8738	292	20	And thou, my lord, O king, the eyes of all Israel are upon thee, that thou shouldest tell them who shall sit on the throne of my lord the king after him.
8739	292	21	Otherwise it shall come to pass, when my lord the king shall sleep with his fathers, that I and my son Solomon shall be counted offenders.
8740	292	22	And, lo, while she yet talked with the king, Nathan the prophet also came in.
8741	292	23	And they told the king, saying, Behold Nathan the prophet. And when he was come in before the king, he bowed himself before the king with his face to the ground.
8742	292	24	And Nathan said, My lord, O king, hast thou said, Adonijah shall reign after me, and he shall sit upon my throne?
8743	292	25	For he is gone down this day, and hath slain oxen and fat cattle and sheep in abundance, and hath called all the king's sons, and the captains of the host, and Abiathar the priest; and, behold, they eat and drink before him, and say, God save king Adonijah.
8744	292	26	But me, even me thy servant, and Zadok the priest, and Benaiah the son of Jehoiada, and thy servant Solomon, hath he not called.
8745	292	27	Is this thing done by my lord the king, and thou hast not shewed it unto thy servant, who should sit on the throne of my lord the king after him?
8746	292	28	Then king David answered and said, Call me Bath-sheba. And she came into the king's presence, and stood before the king.
8747	292	29	And the king sware, and said, As the LORD liveth, that hath redeemed my soul out of all distress,
8748	292	30	Even as I sware unto thee by the LORD God of Israel, saying, Assuredly Solomon thy son shall reign after me, and he shall sit upon my throne in my stead; even so will I certainly do this day.
8749	292	31	Then Bath-sheba bowed with her face to the earth, and did reverence to the king, and said, Let my lord king David live for ever.
8750	292	32	And king David said, Call me Zadok the priest, and Nathan the prophet, and Benaiah the son of Jehoiada. And they came before the king.
8751	292	33	The king also said unto them, Take with you the servants of your lord, and cause Solomon my son to ride upon mine own mule, and bring him down to Gihon:
8752	292	34	And let Zadok the priest and Nathan the prophet anoint him there king over Israel: and blow ye with the trumpet, and say, God save king Solomon.
8753	292	35	Then ye shall come up after him, that he may come and sit upon my throne; for he shall be king in my stead: and I have appointed him to be ruler over Israel and over Judah.
8754	292	36	And Benaiah the son of Jehoiada answered the king, and said, Amen: the LORD God of my lord the king say so too.
8755	292	37	As the LORD hath been with my lord the king, even so be he with Solomon, and make his throne greater than the throne of my lord king David.
8756	292	38	So Zadok the priest, and Nathan the prophet, and Benaiah the son of Jehoiada, and the Cherethites, and the Pelethites, went down, and caused Solomon to ride upon king David's mule, and brought him to Gihon.
8757	292	39	And Zadok the priest took an horn of oil out of the tabernacle, and anointed Solomon. And they blew the trumpet; and all the people said, God save king Solomon.
8758	292	40	And all the people came up after him, and the people piped with pipes, and rejoiced with great joy, so that the earth rent with the sound of them.
8759	292	41	And Adonijah and all the guests that were with him heard it as they had made an end of eating. And when Joab heard the sound of the trumpet, he said, Wherefore is this noise of the city being in an uproar?
8760	292	42	And while he yet spake, behold, Jonathan the son of Abiathar the priest came: and Adonijah said unto him, Come in; for thou art a valiant man, and bringest good tidings.
8761	292	43	And Jonathan answered and said to Adonijah, Verily our lord king David hath made Solomon king.
8762	292	44	And the king hath sent with him Zadok the priest, and Nathan the prophet, and Benaiah the son of Jehoiada, and the Cherethites, and the Pelethites, and they have caused him to ride upon the king's mule:
8763	292	45	And Zadok the priest and Nathan the prophet have anointed him king in Gihon: and they are come up from thence rejoicing, so that the city rang again. This is the noise that ye have heard.
8764	292	46	And also Solomon sitteth on the throne of the kingdom.
8765	292	47	And moreover the king's servants came to bless our lord king David, saying, God make the name of Solomon better than thy name, and make his throne greater than thy throne. And the king bowed himself upon the bed.
8766	292	48	And also thus said the king, Blessed be the LORD God of Israel, which hath given one to sit on my throne this day, mine eyes even seeing it.
8767	292	49	And all the guests that were with Adonijah were afraid, and rose up, and went every man his way.
8768	292	50	And Adonijah feared because of Solomon, and arose, and went, and caught hold on the horns of the altar.
8769	292	51	And it was told Solomon, saying, Behold, Adonijah feareth king Solomon: for, lo, he hath caught hold on the horns of the altar, saying, Let king Solomon swear unto me to day that he will not slay his servant with the sword.
8770	292	52	And Solomon said, If he will shew himself a worthy man, there shall not an hair of him fall to the earth: but if wickedness shall be found in him, he shall die.
8771	292	53	So king Solomon sent, and they brought him down from the altar. And he came and bowed himself to king Solomon: and Solomon said unto him, Go to thine house.
8772	293	1	NOW the days of David drew nigh that he should die; and he charged Solomon his son, saying,
8773	293	2	I go the way of all the earth: be thou strong therefore, and shew thyself a man;
8774	293	3	And keep the charge of the LORD thy God, to walk in his ways, to keep his statutes, and his commandments, and his judgments, and his testimonies, as it is written in the law of Moses, that thou mayest prosper in all that thou doest, and whithersoever thou turnest thyself:
8775	293	4	That the LORD may continue his word which he spake concerning me, saying, If thy children take heed to their way, to walk before me in truth with all their heart and with all their soul, there shall not fail thee (said he) a man on the throne of Israel.
8776	293	5	Moreover thou knowest also what Joab the son of Zeruiah did to me, and what he did to the two captains of the hosts of Israel, unto Abner the son of Ner, and unto Amasa the son of Jether, whom he slew, and shed the blood of war in peace, and put the blood of war upon his girdle that was about his loins, and in his shoes that were on his feet.
8777	293	6	Do therefore according to thy wisdom, and let not his hoar head go down to the grave in peace.
8778	293	7	But shew kindness unto the sons of Barzillai the Gileadite, and let them be of those that eat at thy table: for so they came to me when I fled because of Absalom thy brother.
8779	293	8	And, behold, thou hast with thee Shimei the son of Gera, a Benjamite of Bahurim, which cursed me with a grievous curse in the day when I went to Mahanaim: but he came down to meet me at Jordan, and I sware to him by the LORD, saying, I will not put thee to death with the sword.
8780	293	9	Now therefore hold him not guiltless: for thou art a wise man, and knowest what thou oughtest to do unto him; but his hoar head bring thou down to the grave with blood.
8781	293	10	So David slept with his fathers, and was buried in the city of David.
8782	293	11	And the days that David reigned over Israel were forty years: seven years reigned he in Hebron, and thirty and three years reigned he in Jerusalem.
8783	293	12	Then sat Solomon upon the throne of David his father; and his kingdom was established greatly.
8784	293	13	And Adonijah the son of Haggith came to Bath-sheba the mother of Solomon. And she said, Comest thou peaceably? And he said, Peaceably.
8785	293	14	He said moreover, I have somewhat to say unto thee. And she said, Say on.
8786	293	15	And he said, Thou knowest that the kingdom was mine, and that all Israel set their faces on me, that I should reign: howbeit the kingdom is turned about, and is become my brother's: for it was his from the LORD.
8787	293	16	And now I ask one petition of thee, deny me not. And she said unto him, Say on.
8788	293	17	And he said, Speak, I pray thee, unto Solomon the king, (for he will not say thee nay,) that he give me Abishag the Shunammite to wife.
8789	293	18	And Bath-sheba said, Well; I will speak for thee unto the king.
8790	293	19	Bath-sheba therefore went unto king Solomon, to speak unto him for Adonijah. And the king rose up to meet her, and bowed himself unto her, and sat down on his throne, and caused a seat to be set for the king's mother; and she sat on his right hand.
8791	293	20	Then she said, I desire one small petition of thee; I pray thee, say me not nay. And the king said unto her, Ask on, my mother: for I will not say thee nay.
8792	293	21	And she said, Let Abishag the Shunammite be given to Adonijah thy brother to wife.
8793	293	22	And king Solomon answered and said unto his mother, And why dost thou ask Abishag the Shunammite for Adonijah? ask for him the kingdom also; for he is mine elder brother; even for him, and for Abiathar the priest, and for Joab the son of Zeruiah.
8794	293	23	Then king Solomon sware by the LORD, saying, God do so to me, and more also, if Adonijah have not spoken this word against his own life.
8795	293	24	Now therefore, as the LORD liveth, which hath established me, and set me on the throne of David my father, and who hath made me an house, as he promised, Adonijah shall be put to death this day.
8796	293	25	And king Solomon sent by the hand of Benaiah the son of Jehoiada; and he fell upon him that he died.
8797	293	26	And unto Abiathar the priest said the king, Get thee to Anathoth, unto thine own fields; for thou art worthy of death: but I will not at this time put thee to death, because thou barest the ark of the Lord GOD before David my father, and because thou hast been afflicted in all wherein my father was afflicted.
8798	293	27	So Solomon thrust out Abiathar from being priest unto the LORD; that he might fulfil the word of the LORD, which he spake concerning the house of Eli in Shiloh.
8799	293	28	Then tidings came to Joab: for Joab had turned after Adonijah, though he turned not after Absalom. And Joab fled unto the tabernacle of the LORD, and caught hold on the horns of the altar.
8800	293	29	And it was told king Solomon that Joab was fled unto the tabernacle of the LORD; and, behold, he is by the altar. Then Solomon sent Benaiah the son of Jehoiada, saying, Go, fall upon him.
8801	293	30	And Benaiah came to the tabernacle of the LORD, and said unto him, Thus saith the king, Come forth. And he said, Nay; but I will die here. And Benaiah brought the king word again, saying, Thus said Joab, and thus he answered me.
8802	293	31	And the king said unto him, Do as he hath said, and fall upon him, and bury him; that thou mayest take away the innocent blood, which Joab shed, from me, and from the house of my father.
8803	293	32	And the LORD shall return his blood upon his own head, who fell upon two men more righteous and better than he, and slew them with the sword, my father David not knowing thereof, to wit, Abner the son of Ner, captain of the host of Israel, and Amasa the son of Jether, captain of the host of Judah.
8804	293	33	Their blood shall therefore return upon the head of Joab, and upon the head of his seed for ever: but upon David, and upon his seed, and upon his house, and upon his throne, shall there be peace for ever from the LORD.
8805	293	34	So Benaiah the son of Jehoiada went up, and fell upon him, and slew him: and he was buried in his own house in the wilderness.
8806	293	35	And the king put Benaiah the son of Jehoiada in his room over the host: and Zadok the priest did the king put in the room of Abiathar.
8807	293	36	And the king sent and called for Shimei, and said unto him, Build thee an house in Jerusalem, and dwell there, and go not forth thence any whither.
8808	293	37	For it shall be, that on the day thou goest out, and passest over the brook Kidron, thou shalt know for certain that thou shalt surely die: thy blood shall be upon thine own head.
8809	293	38	And Shimei said unto the king, The saying is good: as my lord the king hath said, so will thy servant do. And Shimei dwelt in Jerusalem many days.
8810	293	39	And it came to pass at the end of three years, that two of the servants of Shimei ran away unto Achish son of Maachah king of Gath. And they told Shimei, saying, Behold, thy servants be in Gath.
8811	293	40	And Shimei arose, and saddled his ass, and went to Gath to Achish to seek his servants: and Shimei went, and brought his servants from Gath.
8812	293	41	And it was told Solomon that Shimei had gone from Jerusalem to Gath, and was come again.
8813	293	42	And the king sent and called for Shimei, and said unto him, Did I not make thee to swear by the LORD, and protested unto thee, saying, Know for a certain, on the day thou goest out, and walkest abroad any wither, that thou shalt surely die? and thou saidst unto me, The word that I have heard is good.
8814	293	43	Why then hast thou not kept the oath of the LORD, and the commandment that I have charged thee with?
8815	293	44	The king said moreover to Shimei, Thou knowest all the wickedness which thine heart is privy to, that thou didst to David my father: therefore the LORD shall return thy wickedness upon thine own head;
8816	293	45	And king Solomon shall be blessed, and the throne of David shall be established before the LORD for ever.
8817	293	46	So the king commanded Benaiah the son of Jehoiada; which went out, and fell upon him, that he died. And the kingdom was established in the hand of Solomon.
8818	294	1	AND Solomon made affinity with Pharaoh king of Egypt, and took Pharaoh's daughter, and brought her into the city of David, until he had made an end of building his own house, and the house of the LORD, and the wall of Jerusalem round about.
8819	294	2	Only the people sacrificed in high places, because there was no house built unto the name of the LORD, until those days.
8820	294	3	And Solomon loved the LORD, walking in the statutes of David his father: only he sacrificed and burnt incense in high places.
8821	294	4	And the king went to Gibeon to sacrifice there; for that was the great high place: a thousand burnt offerings did Solomon offer upon that altar.
8822	294	5	In Gibeon the LORD appeared to Solomon in a dream by night: and God said, Ask what I shall give thee.
8823	294	6	And Solomon said, Thou hast shewed unto thy servant David my father great mercy, according as he walked before thee in truth, and in righteousness, and in uprightness of heart with thee; and thou hast kept for him this great kindness, that thou hast given him a son to sit on his throne, as it is this day.
8824	294	7	And now, O LORD my God, thou hast made thy servant king instead of David my father: and I am but a little child: I know not how to go out or come in.
8825	294	8	And thy servant is in the midst of thy people which thou hast chosen, a great people, that cannot be numbered nor counted for multitude.
8826	294	9	Give therefore thy servant an understanding heart to judge thy people, that I may discern between good and bad: for who is able to judge this thy so great a people?
8827	294	10	And the speech pleased the Lord, that Solomon had asked this thing.
8828	294	11	And God said unto him, Because thou hast asked this thing, and hast not asked for thyself long life; neither hast asked riches for thyself, nor hast asked the life of thine enemies; but hast asked for thyself understanding to discern judgment;
8829	294	12	Behold, I have done according to thy words: lo, I have given thee a wise and an understanding heart; so that there was none like thee before thee, neither after thee shall any arise like unto thee.
8830	294	13	And I have also given thee that which thou hast not asked, both riches, and honour: so that there shall not be any among the kings like unto thee all thy days.
8831	294	14	And if thou wilt walk in my ways, to keep my statutes and my commandments, as thy father David did walk, then I will lengthen thy days.
8832	294	15	And Solomon awoke; and, behold, it was a dream. And he came to Jerusalem, and stood before the ark of the covenant of the LORD, and offered up burnt offerings, and offered peace offerings, and made a feast to all his servants.
8833	294	16	Then came there two women, that were harlots, unto the king, and stood before him.
8834	294	17	And the one woman said, O my lord, I and this woman dwell in one house; and I was delivered of a child with her in the house.
8835	294	18	And it came to pass the third day after that I was delivered, that this woman was delivered also: and we were together; there was no stranger with us in the house, save we two in the house.
8836	294	19	And this woman's child died in the night; because she overlaid it.
8837	294	20	And she arose at midnight, and took my son from beside me, while thine handmaid slept, and laid it in her bosom, and laid her dead child in my bosom.
8838	294	21	And when I rose in the morning to give my child suck, behold, it was dead: but when I had considered it in the morning, behold, it was not my son, which I did bear.
8839	294	22	And the other woman said, Nay; but the living is my son, and the dead is thy son. And this said, No; but the dead is thy son, and the living is my son. Thus they spake before the king.
8840	294	23	Then said the king, The one saith, This is my son that liveth, and thy son is the dead: and the other saith, Nay; but thy son is the dead, and my son is the living.
8841	294	24	And the king said, Bring me a sword. And they brought a sword before the king.
8842	294	25	And the king said, Divide the living child in two, and give half to the one, and half to the other.
8843	294	26	Then spake the woman whose the living child was unto the king, for her bowels yearned upon her son, and she said, O my lord, give her the living child, and in no wise slay it. But the other said, Let it be neither mine nor thine, but divide it.
8844	294	27	Then the king answered and said, Give her the living child, and in no wise slay it: she is the mother thereof.
8845	294	28	And all Israel heard of the judgment which the king had judged; and they feared the king: for they saw that the wisdom of God was in him, to do judgment.
8846	295	1	SO king Solomon was king over all Israel.
8847	295	2	And these were the princes which he had; Azariah the son of Zadok the priest,
8848	295	3	Elihoreph and Ahiah, the sons of Shisha, scribes; Jehoshaphat the son of Ahilud, the recorder.
8849	295	4	And Benaiah the son of Jehoiada was over the host: and Zadok and Abiathar were the priests:
8850	295	5	And Azariah the son of Nathan was over the officers: and Zabud the son of Nathan was principal officer, and the king's friend:
8851	295	6	And Ahishar was over the household: and Adoniram the son of Abda was over the tribute.
8852	295	7	And Solomon had twelve officers over all Israel, which provided victuals for the king and his household: each man his month in a year made provision.
8853	295	8	And these are their names: The son of Hur, in mount Ephraim:
8854	295	9	The son of Dekar, in Makaz, and in Shaalbim, and Beth-shemesh, and Elon-beth-hanan:
8855	295	10	The son of Hesed, in Aruboth; to him pertained Sochoh, and all the land of Hepher:
8856	295	11	The son of Abinadab, in all the region of Dor; which had Taphath the daughter of Solomon to wife:
8857	295	12	Baana the son of Ahilud; to him pertained Taanach and Megiddo, and all Beth-shean, which is by Zartanah beneath Jezreel, from Beth-shean to Abel-meholah, even unto the place that is beyond Jokneam:
8858	295	13	The son of Geber, in Ramoth-gilead; to him pertained the towns of Jair the son of Manasseh, which are in Gilead; to him also pertained the region of Argob, which is in Bashan, threescore great cities with walls and brasen bars:
8859	295	14	Ahinadab the son of Iddo had Mahanaim:
8860	295	15	Ahimaaz was in Naphtali; he also took Basmath the daughter of Solomon to wife:
8861	295	16	Baanah the son of Hushai was in Asher and in Aloth:
8862	295	17	Jehoshaphat the son of Paruah, in Issachar:
8863	295	18	Shimei the son of Elah, in Benjamin:
8864	295	19	Geber the son of Uri was in the country of Gilead, in the country of Sihon king of the Amorites, and of Og king of Bashan; and he was the only officer which was in the land.
8865	295	20	Judah and Israel were many, as the sand which is by the sea in multitude, eating and drinking, and making merry.
8866	295	21	And Solomon reigned over all kingdoms from the river unto the land of the Philistines, and unto the border of Egypt: they brought presents, and served Solomon all the days of his life.
8867	295	22	And Solomon's provision for one day was thirty measures of fine flour, and threescore measures of meal,
8868	295	23	Ten fat oxen, and twenty oxen out of the pastures, and an hundred sheep, beside harts, and roebucks, and fallowdeer, and fatted fowl.
8869	295	24	For he had dominion over all the region on this side the river, from Tiphsah even to Azzah, over all the kings on this side the river: and he had peace on all sides round about him.
8870	295	25	And Judah and Israel dwelt safely, every man under his vine and under his fig tree, from Dan even to Beer-sheba, all the days of Solomon.
8871	295	26	And Solomon had forty thousand stalls of horses for his chariots, and twelve thousand horsemen.
8872	295	27	And those officers provided victual for king Solomon, and for all that came unto king Solomon's table, every man in his month: they lacked nothing.
8873	295	28	Barley also and straw for the horses and dromedaries brought they unto the place where the officers were, every man according to his charge.
8874	295	29	And God gave Solomon wisdom and understanding exceeding much, and largeness of heart, even as the sand that is on the sea shore.
8875	295	30	And Solomon's wisdom excelled the wisdom of all the children of the east country, and all the wisdom of Egypt.
8876	295	31	For he was wiser than all men; than Ethan the Ezrahite, and Heman, and Chalcol, and Darda, the sons of Mahol: and his fame was in all nations round about.
8877	295	32	And he spake three thousand proverbs: and his songs were a thousand and five.
8878	295	33	And he spake of trees, from the cedar tree that is in Lebanon even unto the hyssop that springeth out of the wall: he spake also of beasts, and of fowl, and of creeping things, and of fishes.
8879	295	34	And there came of all people to hear the wisdom of Solomon, from all kings of the earth, which had heard of his wisdom.
8880	296	1	AND Hiram king of Tyre sent his servants unto Solomon; for he had heard that they had anointed him king in the room of his father: for Hiram was ever a lover of David.
8881	296	2	And Solomon sent to Hiram, saying,
8882	296	3	Thou knowest how that David my father could not build an house unto the name of the LORD his God for the wars which were about him on every side, until the LORD put them under the soles of his feet.
8883	296	4	But now the LORD my God hath given me rest on every side, so that there is neither adversary nor evil occurrent.
8884	296	5	And, behold, I purpose to build an house unto the name of the LORD my God, as the LORD spake unto David my father, saying, Thy son, whom I will set upon thy throne in thy room, he shall build an house unto my name.
8885	296	6	Now therefore command thou that they hew me cedar trees out of Lebanon; and my servants shall be with thy servants: and unto thee will I give hire for thy servants according to all that thou shalt appoint: for thou knowest that there is not among us any that can skill to hew timber like unto the Sidonians.
8886	296	7	And it came to pass, when Hiram heard the words of Solomon, that he rejoiced greatly, and said, Blessed be the LORD this day, which hath given unto David a wise son over this great people.
8887	296	8	And Hiram sent to Solomon, saying, I have considered the things which thou sentest to me for: and I will do all thy desire concerning timber of cedar, and concerning timber of fir.
8888	296	9	My servants shall bring them down from Lebanon unto the sea: and I will convey them by sea in floats unto the place that thou shalt appoint me, and will cause them to be discharged there, and thou shalt receive them: and thou shalt accomplish my desire, in giving food for my household.
8889	296	10	So Hiram gave Solomon cedar trees and fir trees according to all his desire.
8890	296	11	And Solomon gave Hiram twenty thousand measures of wheat for food to his household, and twenty measures of pure oil: thus gave Solomon to Hiram year by year.
8891	296	12	And the LORD gave Solomon wisdom, as he promised him: and there was peace between Hiram and Solomon; and they two made a league together.
8892	296	13	And king Solomon raised a levy out of all Israel; and the levy was thirty thousand men.
8893	296	14	And he sent them to Lebanon, ten thousand a month by courses: a month they were in Lebanon, and two months at home: and Adoniram was over the levy.
8894	296	15	And Solomon had threescore and ten thousand that bare burdens, and fourscore thousand hewers in the mountains;
8895	296	16	Beside the chief of Solomon's officers which were over the work, three thousand and three hundred, which ruled over the people that wrought in the work.
8896	296	17	And the king commanded, and they brought great stones, costly stones, and hewed stones, to lay the foundation of the house.
8897	296	18	And Solomon's builders and Hiram's builders did hew them, and the stonesquarers: so they prepared timber and stones to build the house.
8898	297	1	AND it came to pass in the four hundred and eightieth year after the children of Israel were come out of the land of Egypt, in the fourth year of Solomon's reign over Israel, in the month Zif, which is the second month, that he began to build the house of the LORD.
8899	297	2	And the house which king Solomon built for the LORD, the length thereof was threescore cubits, and the breadth thereof twenty cubits, and the height thereof thirty cubits.
8900	297	3	And the porch before the temple of the house, twenty cubits was the length thereof, according to the breadth of the house; and ten cubits was the breadth thereof before the house.
8901	297	4	And for the house he made windows of narrow lights.
8902	297	5	And against the wall of the house he built chambers round about, against the walls of the house round about, both of the temple and of the oracle: and he made chambers round about:
8903	297	6	The nethermost chamber was five cubits broad, and the middle was six cubits broad, and the third was seven cubits broad: for without in the wall of the house he made narrowed rests round about, that the beams should not be fastened in the walls of the house.
8904	297	7	And the house, when it was in building, was built of stone made ready before it was brought thither: so that there was neither hammer nor axe nor any tool of iron heard in the house, while it was in building.
8905	297	8	The door for the middle chamber was in the right side of the house: and they went up with winding stairs into the middle chamber, and out of the middle into the third.
8906	297	9	So he built the house, and finished it; and covered the house with beams and boards of cedar.
8907	297	10	And then he built chambers against all the house, five cubits high: and they rested on the house with timber of cedar.
8908	297	11	And the word of the LORD came to Solomon, saying,
8909	297	12	Concerning this house which thou art in building, if thou wilt walk in my statutes, and execute my judgments, and keep all my commandments to walk in them; then will I perform my word with thee, which I spake unto David thy father:
8910	297	13	And I will dwell among the children of Israel, and will not forsake my people Israel.
8911	297	14	So Solomon built the house, and finished it.
8912	297	15	And he built the walls of the house within with boards of cedar, both the floor of the house, and the walls of the cieling: and he covered them on the inside with wood, and covered the floor of the house with planks of fir.
8913	297	16	And he built twenty cubits on the sides of the house, both the floor and the walls with boards of cedar: he even built them for it within, even for the oracle, even for the most holy place.
8914	297	17	And the house, that is, the temple before it, was forty cubits long.
8915	297	18	And the cedar of the house within was carved with knops and open flowers: all was cedar; there was no stone seen.
8916	297	19	And the oracle he prepared in the house within, to set there the ark of the covenant of the LORD.
8917	297	20	And the oracle in the forepart was twenty cubits in length, and twenty cubits in breadth, and twenty cubits in the height thereof: and he overlaid it with pure gold; and so covered the altar which was of cedar.
8918	297	21	So Solomon overlaid the house within with pure gold: and he made a partition by the chains of gold before the oracle; and he overlaid it with gold.
8919	297	22	And the whole house he overlaid with gold, until he had finished all the house: also the whole altar that was by the oracle he overlaid with gold.
8920	297	23	And within the oracle he made two cherubims of olive tree, each ten cubits high.
8921	297	24	And five cubits was the one wing of the cherub, and five cubits the other wing of the cherub: from the uttermost part of the one wing unto the uttermost part of the other were ten cubits.
8922	297	25	And the other cherub was ten cubits: both the cherubims were of one measure and one size.
8923	297	26	The height of the one cherub was ten cubits, and so was it of the other cherub.
8924	297	27	And he set the cherubims within the inner house: and they stretched forth the wings of the cherubims, so that the wing of the one touched the one wall, and the wing of the other cherub touched the other wall; and their wings touched one another in the midst of the house.
8925	297	28	And he overlaid the cherubims with gold.
8926	297	29	And he carved all the walls of the house round about with carved figures of cherubims and palm trees and open flowers, within and without.
8927	297	30	And the floor of the house he overlaid with gold, within and without.
8928	297	31	And for the entering of the oracle he made doors of olive tree: the lintel and side posts were a fifth part of the wall.
8929	297	32	The two doors also were of olive tree; and he carved upon them carvings of cherubims and palm trees and open flowers, and overlaid them with gold, and spread gold upon the cherubims, and upon the palm trees.
8930	297	33	So also made he for the door of the temple posts of olive tree, a fourth part of the wall.
8931	297	34	And the two doors were of fir tree: the two leaves of the one door were folding, and the two leaves of the other door were folding.
8932	297	35	And he carved thereon cherubims and palm trees and open flowers: and covered them with gold fitted upon the carved work.
8933	297	36	And he built the inner court with three rows of hewed stone, and a row of cedar beams.
8934	297	37	In the fourth year was the foundation of the house of the LORD laid, in the month Zif:
8935	297	38	And in the eleventh year, in the month Bul, which is the eighth month, was the house finished throughout all the parts thereof, and according to all the fashion of it. So was he seven years in building it.
8936	298	1	BUT Solomon was building his own house thirteen years, and he finished all his house.
8937	298	2	He built also the house of the forest of Lebanon; the length thereof was an hundred cubits, and the breadth thereof fifty cubits, and the height thereof thirty cubits, upon four rows of cedar pillars, with cedar beams upon the pillars.
8938	298	3	And it was covered with cedar above upon the beams, that lay on forty five pillars, fifteen in a row.
8939	298	4	And there were windows in three rows, and light was against light in three ranks.
8940	298	5	And all the doors and posts were square, with the windows: and light was against light in three ranks.
8941	298	6	And he made a porch of pillars; the length thereof was fifty cubits, and the breadth thereof thirty cubits: and the porch was before them: and the other pillars and the thick beam were before them.
8942	298	7	Then he made a porch for the throne where he might judge, even the porch of judgment: and it was covered with cedar from one side of the floor to the other.
8943	298	8	And his house where he dwelt had another court within the porch, which was of the like work. Solomon made also an house for Pharaoh's daughter, whom he had taken to wife, like unto this porch.
8944	298	9	All these were of costly stones, according to the measures of hewed stones, sawed with saws, within and without, even from the foundation unto the coping, and so on the outside toward the great court.
8945	298	10	And the foundation was of costly stones, even great stones, stones of ten cubits, and stones of eight cubits.
8946	298	11	And above were costly stones, after the measures of hewed stones, and cedars.
8947	298	12	And the great court round about was with three rows of hewed stones, and a row of cedar beams, both for the inner court of the house of the LORD, and for the porch of the house.
8948	298	13	And king Solomon sent and fetched Hiram out of Tyre.
8949	298	14	He was a widow's son of the tribe of Naphtali, and his father was a man of Tyre, a worker in brass: and he was filled with wisdom, and understanding, and cunning to work all works in brass. And he came to king Solomon, and wrought all his work.
8950	298	15	For he cast two pillars of brass, of eighteen cubits high apiece: and a line of twelve cubits did compass either of them about.
8951	298	16	And he made two chapiters of molten brass, to set upon the tops of the pillars: the height of the one chapiter was five cubits, and the height of the other chapiter was five cubits:
8952	298	17	And nets of checker work, and wreaths of chain work, for the chapiters which were upon the top of the pillars; seven for the one chapiter, and seven for the other chapiter.
8953	298	18	And he made the pillars, and two rows round about upon the one network, to cover the chapiters that were upon the top, with pomegranates: and so did he for the other chapiter.
8954	298	19	And the chapiters that were upon the top of the pillars were of lily work in the porch, four cubits.
8955	298	20	And the chapiters upon the two pillars had pomegranates also above, over against the belly which was by the network: and the pomegranates were two hundred in rows round about upon the other chapiter.
8956	298	21	And he set up the pillars in the porch of the temple: and he set up the right pillar, and called the name thereof Jachin: and he set up the left pillar, and called the name thereof Boaz.
8957	298	22	And upon the top of the pillars was lily work: so was the work of the pillars finished.
8958	298	23	And he made a molten sea, ten cubits from the one brim to the other: it was round all about, and his height was five cubits: and a line of thirty cubits did compass it round about.
8959	298	24	And under the brim of it round about there were knops compassing it, ten in a cubit, compassing the sea round about: the knops were cast in two rows, when it was cast.
8960	298	25	It stood upon twelve oxen, three looking toward the north, and three looking toward the west, and three looking toward the south, and three looking toward the east: and the sea was set above upon them, and all their hinder parts were inward.
8961	298	26	And it was an hand breadth thick, and the brim thereof was wrought like the brim of a cup, with flowers of lilies: it contained two thousand baths.
8962	298	27	And he made ten bases of brass; four cubits was the length of one base, and four cubits the breadth thereof, and three cubits the height of it.
8963	298	28	And the work of the bases was on this manner: they had borders, and the borders were between the ledges:
8964	298	29	And on the borders that were between the ledges were lions, oxen, and cherubims: and upon the ledges there was a base above: and beneath the lions and oxen were certain additions made of thin work.
8965	298	30	And every base had four brasen wheels, and plates of brass: and the four corners thereof had undersetters: under the laver were undersetters molten, at the side of every addition.
8966	298	31	And the mouth of it within the chapiter and above was a cubit: but the mouth thereof was round after the work of the base, a cubit and an half: and also upon the mouth of it were gravings with their borders, foursquare, not round.
8967	298	32	And under the borders were four wheels; and the axletrees of the wheels were joined to the base: and the height of a wheel was a cubit and half a cubit.
8968	298	33	And the work of the wheels was like the work of a chariot wheel: their axletrees, and their naves, and their felloes, and their spokes, were all molten.
8969	298	34	And there were four undersetters to the four corners of one base: and the undersetters were of the very base itself.
8970	298	35	And in the top of the base was there a round compass of half a cubit high: and on the top of the base the ledges thereof and the borders thereof were of the same.
8971	298	36	For on the plates of the ledges thereof, and on the borders thereof, he graved cherubims, lions, and palm trees, according to the proportion of every one, and additions round about.
8972	298	37	After this manner he made the ten bases: all of them had one casting, one measure, and one size.
8973	298	38	Then made he ten lavers of brass: one laver contained forty baths: and every laver was four cubits: and upon every one of the ten bases one laver.
8974	298	39	And he put five bases on the right side of the house, and five on the left side of the house: and he set the sea on the right side of the house eastward over against the south.
8975	298	40	And Hiram made the lavers, and the shovels, and the basons. So Hiram made an end of doing all the work that he made king Solomon for the house of the LORD:
8976	298	41	The two pillars, and the two bowls of the chapiters that were on the top of the two pillars; and the two networks, to cover the two bowls of the chapiters which were upon the top of the pillars;
8977	298	42	And four hundred pomegranates for the two networks, even two rows of pomegranates for one network, to cover the two bowls of the chapiters that were upon the pillars;
8978	298	43	And the ten bases, and ten lavers on the bases;
8979	298	44	And one sea, and twelve oxen under the sea;
8980	298	45	And the pots, and the shovels, and the basons: and all these vessels, which Hiram made to king Solomon for the house of the LORD, were of bright brass.
8981	298	46	In the plain of Jordan did the king cast them, in the clay ground between Succoth and Zarthan.
8982	298	47	And Solomon left all the vessels unweighed, because they were exceeding many: neither was the weight of the brass found out.
8983	298	48	And Solomon made all the vessels that pertained unto the house of the LORD: the altar of gold, and the table of gold, whereupon the shewbread was,
8984	298	49	And the candlesticks of pure gold, five on the right side, and five on the left, before the oracle, with the flowers, and the lamps, and the tongs of gold,
8985	298	50	And the bowls, and the snuffers, and the basons, and the spoons, and the censers of pure gold; and the hinges of gold, both for the doors of the inner house, the most holy place, and for the doors of the house, to wit, of the temple.
8986	298	51	So was ended all the work that king Solomon made for the house of the LORD. And Solomon brought in the things which David his father had dedicated; even the silver, and the gold, and the vessels, did he put among the treasures of the house of the LORD.
8987	299	1	THEN Solomon assembled the elders of Israel, and all the heads of the tribes, the chief of the fathers of the children of Israel, unto king Solomon in Jerusalem, that they might bring up the ark of the covenant of the LORD out of the city of David, which is Zion.
8988	299	2	And all the men of Israel assembled themselves unto king Solomon at the feast in the month Ethanim, which is the seventh month.
8989	299	3	And all the elders of Israel came, and the priests took up the ark.
8990	299	4	And they brought up the ark of the LORD, and the tabernacle of the congregation, and all the holy vessels that were in the tabernacle, even those did the priests and the Levites bring up.
8991	299	5	And king Solomon, and all the congregation of Israel, that were assembled unto him, were with him before the ark, sacrificing sheep and oxen, that could not be told nor numbered for multitude.
8992	299	6	And the priests brought in the ark of the covenant of the LORD unto his place, into the oracle of the house, to the most holy place, even under the wings of the cherubims.
8993	299	7	For the cherubims spread forth their two wings over the place of the ark, and the cherubims covered the ark and the staves thereof above.
8994	299	8	And they drew out the staves, that the ends of the staves were seen out in the holy place before the oracle, and they were not seen without: and there they are unto this day.
8995	299	9	There was nothing in the ark save the two tables of stone, which Moses put there at Horeb, when the LORD made a covenant with the children of Israel, when they came out of the land of Egypt.
8996	299	10	And it came to pass, when the priests were come out of the holy place, that the cloud filled the house of the LORD,
8997	299	11	So that the priests could not stand to minister because of the cloud: for the glory of the LORD had filled the house of the LORD.
8998	299	12	Then spake Solomon, The LORD said that he would dwell in the thick darkness.
8999	299	13	I have surely built thee an house to dwell in, a settled place for thee to abide in for ever.
9000	299	14	And the king turned his face about, and blessed all the congregation of Israel: (and all the congregation of Israel stood;)
9001	299	15	And he said, Blessed be the LORD God of Israel, which spake with his mouth unto David my father, and hath with his hand fulfilled it, saying,
9002	299	16	Since the day that I brought forth my people Israel out of Egypt, I chose no city out of all the tribes of Israel to build an house, that my name might be therein; but I chose David to be over my people Israel.
9003	299	17	And it was in the heart of David my father to build an house for the name of the LORD God of Israel.
9004	299	18	And the LORD said unto David my father, Whereas it was in thine heart to build an house unto my name, thou didst well that it was in thine heart.
9005	299	19	Nevertheless thou shalt not build the house; but thy son that shall come forth out of thy loins, he shall build the house unto my name.
9006	299	20	And the LORD hath performed his word that he spake, and I am risen up in the room of David my father, and sit on the throne of Israel, as the LORD promised, and have built an house for the name of the LORD God of Israel.
9007	299	21	And I have set there a place for the ark, wherein is the covenant of the LORD, which he made with our fathers, when he brought them out of the land of Egypt.
9008	299	22	And Solomon stood before the altar of the LORD in the presence of all the congregation of Israel, and spread forth his hands toward heaven:
9009	299	23	And he said, LORD God of Israel, there is no God like thee, in heaven above, or on earth beneath, who keepest covenant and mercy with thy servants that walk before thee with all their heart:
9010	299	24	Who hast kept with thy servant David my father that thou promisedst him: thou spakest also with thy mouth, and hast fulfilled it with thine hand, as it is this day.
9011	299	25	Therefore now, LORD God of Israel, keep with thy servant David my father that thou promisedst him, saying, There shall not fail thee a man in my sight to sit on the throne of Israel; so that thy children take heed to their way, that they walk before me as thou hast walked before me.
9012	299	26	And now, O God of Israel, let thy word, I pray thee, be verified, which thou spakest unto thy servant David my father.
9013	299	27	But will God indeed dwell on the earth? behold, the heaven and heaven of heavens cannot contain thee; how much less this house that I have builded?
9014	299	28	Yet have thou respect unto the prayer of thy servant, and to his supplication, O LORD my God, to hearken unto the cry and to the prayer, which thy servant prayeth before thee to day:
9015	299	29	That thine eyes may be open toward this house night and day, even toward the place of which thou hast said, My name shall be there: that thou mayest hearken unto the prayer which thy servant shall make toward this place.
9016	299	30	And hearken thou to the supplication of thy servant, and of thy people Israel, when they shall pray toward this place: and hear thou in heaven thy dwelling place: and when thou hearest, forgive.
9017	299	31	If any man trespass against his neighbour, and an oath be laid upon him to cause him to swear, and the oath come before thine altar in this house:
9018	299	32	Then hear thou in heaven, and do, and judge thy servants, condemning the wicked, to bring his way upon his head; and justifying the righteous, to give him according to his righteousness.
9019	299	33	When thy people Israel be smitten down before the enemy, because they have sinned against thee, and shall turn again to thee, and confess thy name, and pray, and make supplication unto thee in this house:
9020	299	34	Then hear thou in heaven, and forgive the sin of thy people Israel, and bring them again unto the land which thou gavest unto their fathers.
9021	299	35	When heaven is shut up, and there is no rain, because they have sinned against thee; if they pray toward this place, and confess thy name, and turn from their sin, when thou afflictest them:
9022	299	36	Then hear thou in heaven, and forgive the sin of thy servants, and of thy people Israel, that thou teach them the good way wherein they should walk, and give rain upon thy land, which thou hast given to thy people for an inheritance.
9023	299	37	If there be in the land famine, if there be pestilence, blasting, mildew, locust, or if there be caterpiller; if their enemy besiege them in the land of their cities; whatsoever plague, whatsoever sickness there be;
9024	299	38	What prayer and supplication soever be made by any man, or by all thy people Israel, which shall know every man the plague of his own heart, and spread forth his hands toward this house:
9025	299	39	Then hear thou in heaven thy dwelling place, and forgive, and do, and give to every man according to his ways, whose heart thou knowest; (for thou, even thou only, knowest the hearts of all the children of men;)
9026	299	40	That they may fear thee all the days that they live in the land which thou gavest unto our fathers.
9027	299	41	Moreover concerning a stranger, that is not of thy people Israel, but cometh out of a far country for thy name's sake;
9028	299	42	(For they shall hear of thy great name, and of thy strong hand, and of thy stretched out arm;) when he shall come and pray toward this house;
9029	299	43	Hear thou in heaven thy dwelling place, and do according to all that the stranger calleth to thee for: that all people of the earth may know thy name, to fear thee, as do thy people Israel; and that they may know that this house, which I have builded, is called by thy name.
9030	299	44	If thy people go out to battle against their enemy, whithersoever thou shalt send them, and shall pray unto the LORD toward the city which thou hast chosen, and toward the house that I have built for thy name:
9031	299	45	Then hear thou in heaven their prayer and their supplication, and maintain their cause.
9032	299	46	If they sin against thee, (for there is no man that sinneth not,) and thou be angry with them, and deliver them to the enemy, so that they carry them away captives unto the land of the enemy, far or near;
9033	299	47	Yet if they shall bethink themselves in the land whither they were carried captives, and repent, and make supplication unto thee in the land of them that carried them captives, saying, We have sinned, and have done perversely, we have committed wickedness;
9034	299	48	And so return unto thee with all their heart, and with all their soul, in the land of their enemies, which led them away captive, and pray unto thee toward their land, which thou gavest unto their fathers, the city which thou hast chosen, and the house which I have built for thy name:
9035	299	49	Then hear thou their prayer and their supplication in heaven thy dwelling place, and maintain their cause,
9036	299	50	And forgive thy people that have sinned against thee, and all their transgressions wherein they have transgressed against thee, and give them compassion before them who carried them captive, that they may have compassion on them:
9037	299	51	For they be thy people, and thine inheritance, which thou broughtest forth out of Egypt, from the midst of the furnace of iron:
9038	299	52	That thine eyes may be open unto the supplication of thy servant, and unto the supplication of thy people Israel, to hearken unto them in all that they call for unto thee.
9039	299	53	For thou didst separate them from among all the people of the earth, to be thine inheritance, as thou spakest by the hand of Moses thy servant, when thou broughtest our fathers out of Egypt, O Lord GOD.
9040	299	54	And it was so, that when Solomon had made an end of praying all this prayer and supplication unto the LORD, he arose from before the altar of the LORD, from kneeling on his knees with his hands spread up to heaven.
9041	299	55	And he stood, and blessed all the congregation of Israel with a loud voice, saying,
9042	299	56	Blessed be the LORD, that hath given rest unto his people Israel, according to all that he promised: there hath not failed one word of all his good promise, which he promised by the hand of Moses his servant.
9043	299	57	The LORD our God be with us, as he was with our fathers: let him not leave us, nor forsake us:
9044	299	58	That he may incline our hearts unto him, to walk in all his ways, and to keep his commandments, and his statutes, and his judgments, which he commanded our fathers.
9045	299	59	And let these my words, wherewith I have made supplication before the LORD, be nigh unto the LORD our God day and night, that he maintain the cause of his servant, and the cause of his people Israel at all times, as the matter shall require:
9046	299	60	That all the people of the earth may know that the LORD is God, and that there is none else.
9047	299	61	Let your heart therefore be perfect with the LORD our God, to walk in his statutes, and to keep his commandments, as at this day.
9048	299	62	And the king, and all Israel with him, offered sacrifice before the LORD.
9049	299	63	And Solomon offered a sacrifice of peace offerings, which he offered unto the LORD, two and twenty thousand oxen, and an hundred and twenty thousand sheep. So the king and all the children of Israel dedicated the house of the LORD.
9050	299	64	The same day did the king hallow the middle of the court that was before the house of the LORD: for there he offered burnt offerings, and meat offerings, and the fat of the peace offerings: because the brasen altar that was before the LORD was too little to receive the burnt offerings, and meat offerings, and the fat of the peace offerings.
9051	299	65	And at that time Solomon held a feast, and all Israel with him, a great congregation, from the entering in of Hamath unto the river of Egypt, before the LORD our God, seven days and seven days, even fourteen days.
9052	299	66	On the eighth day he sent the people away: and they blessed the king, and went unto their tents joyful and glad of heart for all the goodness that the LORD had done for David his servant, and for Israel his people.
9053	300	1	AND it came to pass, when Solomon had finished the building of the house of the LORD, and the king's house, and all Solomon's desire which he was pleased to do,
9054	300	2	That the LORD appeared to Solomon the second time, as he had appeared unto him at Gibeon.
9055	300	3	And the LORD said unto him, I have heard thy prayer and thy supplication, that thou hast made before me: I have hallowed this house, which thou hast built, to put my name there for ever; and mine eyes and mine heart shall be there perpetually.
9056	300	4	And if thou wilt walk before me, as David thy father walked, in integrity of heart, and in uprightness, to do according to all that I have commanded thee, and wilt keep my statutes and my judgments:
9057	300	5	Then I will establish the throne of thy kingdom upon Israel for ever, as I promised to David thy father, saying, There shall not fail thee a man upon the throne of Israel.
9058	300	6	But if ye shall at all turn from following me, ye or your children, and will not keep my commandments and my statutes which I have set before you, but go and serve other gods, and worship them:
9059	300	7	Then will I cut off Israel out of the land which I have given them; and this house, which I have hallowed for my name, will I cast out of my sight; and Israel shall be a proverb and a byword among all people:
9060	300	8	And at this house, which is high, every one that passeth by it shall be astonished, and shall hiss; and they shall say, Why hath the LORD done thus unto this land, and to this house?
9061	300	9	And they shall answer, Because they forsook the LORD their God, who brought forth their fathers out of the land of Egypt, and have taken hold upon other gods, and have worshipped them, and served them: therefore hath the LORD brought upon them all this evil.
9062	300	10	And it came to pass at the end of twenty years, when Solomon had built the two houses, the house of the LORD, and the king's house,
9063	300	11	(Now Hiram the king of Tyre had furnished Solomon with cedar trees and fir trees, and with gold, according to all his desire,) that then king Solomon gave Hiram twenty cities in the land of Galilee.
9064	300	12	And Hiram came out from Tyre to see the cities which Solomon had given him; and they pleased him not.
9065	300	13	And he said, What cities are these which thou hast given me, my brother? And he called them the land of Cabul unto this day.
9066	300	14	And Hiram sent to the king sixscore talents of gold.
9067	300	15	And this is the reason of the levy which king Solomon raised; for to build the house of the LORD, and his own house, and Millo, and the wall of Jerusalem, and Hazor, and Megiddo, and Gezer.
9068	300	16	For Pharaoh king of Egypt had gone up, and taken Gezer, and burnt it with fire, and slain the Canaanites that dwelt in the city, and given it for a present unto his daughter, Solomon's wife.
9069	300	17	And Solomon built Gezer, and Beth-horon the nether,
9070	300	18	And Baalath, and Tadmor in the wilderness, in the land,
9071	300	19	And all the cities of store that Solomon had, and cities for his chariots, and cities for his horsemen, and that which Solomon desired to build in Jerusalem, and in Lebanon, and in all the land of his dominion.
9072	300	20	And all the people that were left of the Amorites, Hittites, Perizzites, Hivites, and Jebusites, which were not of the children of Israel,
9073	300	21	Their children that were left after them in the land, whom the children of Israel also were not able utterly to destroy, upon those did Solomon levy a tribute of bondservice unto this day.
9074	300	22	But of the children of Israel did Solomon make no bondmen: but they were men of war, and his servants, and his princes, and his captains, and rulers of his chariots, and his horsemen.
9075	300	23	These were the chief of the officers that were over Solomon's work, five hundred and fifty, which bare rule over the people that wrought in the work.
9076	300	24	But Pharaoh's daughter came up out of the city of David unto her house which Solomon had built for her: then did he build Millo.
9077	300	25	And three times in a year did Solomon offer burnt offerings and peace offerings upon the altar which he built unto the LORD, and he burnt incense upon the altar that was before the LORD. So he finished the house.
9078	300	26	And king Solomon made a navy of ships in Ezion-geber, which is beside Eloth, on the shore of the Red sea, in the land of Edom.
9079	300	27	And Hiram sent in the navy his servants, shipmen that had knowledge of the sea, with the servants of Solomon.
9080	300	28	And they came to Ophir, and fetched from thence gold, four hundred and twenty talents, and brought it to king Solomon.
9081	301	1	AND when the queen of Sheba heard of the fame of Solomon concerning the name of the LORD, she came to prove him with hard questions.
9082	301	2	And she came to Jerusalem with a very great train, with camels that bare spices, and very much gold, and precious stones: and when she was come to Solomon, she communed with him of all that was in her heart.
9083	301	3	And Solomon told her all her questions: there was not any thing hid from the king, which he told her not.
9084	301	4	And when the queen of Sheba had seen all Solomon's wisdom, and the house that he had built,
9085	301	5	And the meat of his table, and the sitting of his servants, and the attendance of his ministers, and their apparel, and his cupbearers, and his ascent by which he went up unto the house of the LORD; there was no more spirit in her.
9086	301	6	And she said to the king, It was a true report that I heard in mine own land of thy acts and of thy wisdom.
9087	301	7	Howbeit I believed not the words, until I came, and mine eyes had seen it: and, behold, the half was not told me: thy wisdom and prosperity exceedeth the fame which I heard.
9088	301	8	Happy are thy men, happy are these thy servants, which stand continually before thee, and that hear thy wisdom.
9089	301	9	Blessed be the LORD thy God, which delighted in thee, to set thee on the throne of Israel: because the LORD loved Israel for ever, therefore made he thee king, to do judgment and justice.
9090	301	10	And she gave the king an hundred and twenty talents of gold, and of spices very great store, and precious stones: there came no more such abundance of spices as these which the queen of Sheba gave to king Solomon.
9091	301	11	And the navy also of Hiram, that brought gold from Ophir, brought in from Ophir great plenty of almug trees, and precious stones.
9092	301	12	And the king made of the almug trees pillars for the house of the LORD, and for the king's house, harps also and psalteries for singers: there came no such almug trees, nor were seen unto this day.
9093	301	13	And king Solomon gave unto the queen of Sheba all her desire, whatsoever she asked, beside that which Solomon gave her of his royal bounty. So she turned and went to her own country, she and her servants.
9094	301	14	Now the weight of gold that came to Solomon in one year was six hundred threescore and six talents of gold,
9095	301	15	Beside that he had of the merchantmen, and of the traffick of the spice merchants, and of all the kings of Arabia, and of the governors of the country.
9096	301	16	And king Solomon made two hundred targets of beaten gold: six hundred shekels of gold went to one target.
9097	301	17	And he made three hundred shields of beaten gold; three pound of gold went to one shield: and the king put them in the house of the forest of Lebanon.
9098	301	18	Moreover the king made a great throne of ivory, and overlaid it with the best gold.
9099	301	19	The throne had six steps, and the top of the throne was round behind: and there were stays on either side on the place of the seat, and two lions stood beside the stays.
9100	301	20	And twelve lions stood there on the one side and on the other upon the six steps: there was not the like made in any kingdom.
9101	301	21	And all king Solomon's drinking vessels were of gold, and all the vessels of the house of the forest of Lebanon were of pure gold; none were of silver: it was nothing accounted of in the days of Solomon.
9102	301	22	For the king had at sea a navy of Tharshish with the navy of Hiram: once in three years came the navy of Tharshish, bringing gold, and silver, ivory, and apes, and peacocks.
9103	301	23	So king Solomon exceeded all the kings of the earth for riches and for wisdom.
9104	301	24	And all the earth sought to Solomon, to hear his wisdom, which God had put in his heart.
9105	301	25	And they brought every man his present, vessels of silver, and vessels of gold, and garments, and armour, and spices, horses, and mules, a rate year by year.
9106	301	26	And Solomon gathered together chariots and horsemen: and he had a thousand and four hundred chariots, and twelve thousand horsemen, whom he bestowed in the cities for chariots, and with the king at Jerusalem.
9107	301	27	And the king made silver to be in Jerusalem as stones, and cedars made he to be as the sycomore trees that are in the vale, for abundance.
9108	301	28	And Solomon had horses brought out of Egypt, and linen yarn: the king's merchants received the linen yarn at a price.
9109	301	29	And a chariot came up and went out of Egypt for six hundred shekels of silver, and an horse for an hundred and fifty: and so for all the kings of the Hittites, and for the kings of Syria, did they bring them out by their means.
9110	302	1	BUT king Solomon loved many strange women, together with the daughter of Pharaoh, women of the Moabites, Ammonites, Edomites, Zidonians, and Hittites;
9111	302	2	Of the nations concerning which the LORD said unto the children of Israel, Ye shall not go in to them, neither shall they come in unto you: for surely they will turn away your heart after their gods: Solomon clave unto these in love.
9112	302	3	And he had seven hundred wives, princesses, and three hundred concubines: and his wives turned away his heart.
9113	302	4	For it came to pass, when Solomon was old, that his wives turned away his heart after other gods: and his heart was not perfect with the LORD his God, as was the heart of David his father.
9114	302	5	For Solomon went after Ashtoreth the goddess of the Zidonians, and after Milcom the abomination of the Ammonites.
9115	302	6	And Solomon did evil in the sight of the LORD, and went not fully after the LORD, as did David his father.
9116	302	7	Then did Solomon build an high place for Chemosh, the abomination of Moab, in the hill that is before Jerusalem, and for Molech, the abomination of the children of Ammon.
9117	302	8	And likewise did he for all his strange wives, which burnt incense and sacrificed unto their gods.
9118	302	9	And the LORD was angry with Solomon, because his heart was turned from the LORD God of Israel, which had appeared unto him twice,
9119	302	10	And had commanded him concerning this thing, that he should not go after other gods: but he kept not that which the LORD commanded.
9120	302	11	Wherefore the LORD said unto Solomon, Forasmuch as this is done of thee, and thou hast not kept my covenant and my statutes, which I have commanded thee, I will surely rend the kingdom from thee, and will give it to thy servant.
9121	302	12	Notwithstanding in thy days I will not do it for David thy father's sake: but I will rend it out of the hand of thy son.
9122	302	13	Howbeit I will not rend away all the kingdom; but will give one tribe to thy son for David my servant's sake, and for Jerusalem's sake which I have chosen.
9123	302	14	And the LORD stirred up an adversary unto Solomon, Hadad the Edomite: he was of the king's seed in Edom.
9124	302	15	For it came to pass, when David was in Edom, and Joab the captain of the host was gone up to bury the slain, after he had smitten every male in Edom;
9125	302	16	(For six months did Joab remain there with all Israel, until he had cut off every male in Edom:)
9126	302	17	That Hadad fled, he and certain Edomites of his father's servants with him, to go into Egypt; Hadad being yet a little child.
9127	302	18	And they arose out of Midian, and came to Paran: and they took men with them out of Paran, and they came to Egypt, unto Pharaoh king of Egypt; which gave him an house, and appointed him victuals, and gave him land.
9128	302	19	And Hadad found great favour in the sight of Pharaoh, so that he gave him to wife the sister of his own wife, the sister of Tahpenes the queen.
9129	302	20	And the sister of Tahpenes bare him Genubath his son, whom Tahpenes weaned in Pharaoh's house: and Genubath was in Pharaoh's household among the sons of Pharaoh.
9130	302	21	And when Hadad heard in Egypt that David slept with his fathers, and that Joab the captain of the host was dead, Hadad said to Pharaoh, Let me depart, that I may go to mine own country.
9131	302	22	Then Pharaoh said unto him, But what hast thou lacked with me, that, behold, thou seekest to go to thine own country? And he answered, Nothing: howbeit let me go in any wise.
9132	302	23	And God stirred him up another adversary, Rezon the son of Eliadah, which fled from his lord Hadadezer king of Zobah:
9133	302	24	And he gathered men unto him, and became captain over a band, when David slew them of Zobah: and they went to Damascus, and dwelt therein, and reigned in Damascus.
9134	302	25	And he was an adversary to Israel all the days of Solomon, beside the mischief that Hadad did: and he abhorred Israel, and reigned over Syria.
9135	302	26	And Jeroboam the son of Nebat, an Ephrathite of Zereda, Solomon's servant, whose mother's name was Zeruah, a widow woman, even he lifted up his hand against the king.
9136	302	27	And this was the cause that he lifted up his hand against the king: Solomon built Millo, and repaired the breaches of the city of David his father.
9137	302	28	And the man Jeroboam was a mighty man of valour: and Solomon seeing the young man that he was industrious, he made him ruler over all the charge of the house of Joseph.
9138	302	29	And it came to pass at that time when Jeroboam went out of Jerusalem, that the prophet Ahijah the Shilonite found him in the way; and he had clad himself with a new garment; and they two were alone in the field:
9139	302	30	And Ahijah caught the new garment that was on him, and rent it in twelve pieces:
9140	302	31	And he said to Jeroboam, Take thee ten pieces: for thus saith the LORD, the God of Israel, Behold, I will rend the kingdom out of the hand of Solomon, and will give ten tribes to thee:
9141	302	32	(But he shall have one tribe for my servant David's sake, and for Jerusalem's sake, the city which I have chosen out of all the tribes of Israel:)
9142	302	33	Because that they have forsaken me, and have worshipped Ashtoreth the goddess of the Zidonians, Chemosh the god of the Moabites, and Milcom the god of the children of Ammon, and have not walked in my ways, to do that which is right in mine eyes, and to keep my statutes and my judgments, as did David his father.
9143	302	34	Howbeit I will not take the whole kingdom out of his hand: but I will make him prince all the days of his life for David my servant's sake, whom I chose, because he kept my commandments and my statutes:
9144	302	35	But I will take the kingdom out of his son's hand, and will give it unto thee, even ten tribes.
9145	302	36	And unto his son will I give one tribe, that David my servant may have a light alway before me in Jerusalem, the city which I have chosen me to put my name there.
9146	302	37	And I will take thee, and thou shalt reign according to all that thy soul desireth, and shalt be king over Israel.
9147	302	38	And it shall be, if thou wilt hearken unto all that I command thee, and wilt walk in my ways, and do that is right in my sight, to keep my statutes and my commandments, as David my servant did; that I will be with thee, and build thee a sure house, as I built for David, and will give Israel unto thee.
9148	302	39	And I will for this afflict the seed of David, but not for ever.
9149	302	40	Solomon sought therefore to kill Jeroboam. And Jeroboam arose, and fled into Egypt, unto Shishak king of Egypt, and was in Egypt until the death of Solomon.
9150	302	41	And the rest of the acts of Solomon, and all that he did, and his wisdom, are they not written in the book of the acts of Solomon?
9151	302	42	And the time that Solomon reigned in Jerusalem over all Israel was forty years.
9152	302	43	And Solomon slept with his fathers, and was buried in the city of David his father: and Rehoboam his son reigned in his stead.
9153	303	1	AND Rehoboam went to Shechem: for all Israel were come to Shechem to make him king.
9154	303	2	And it came to pass, when Jeroboam the son of Nebat, who was yet in Egypt, heard of it, (for he was fled from the presence of king Solomon, and Jeroboam dwelt in Egypt;)
9155	303	3	That they sent and called him. And Jeroboam and all the congregation of Israel came, and spake unto Rehoboam, saying,
9156	303	4	Thy father made our yoke grievous: now therefore make thou the grievous service of thy father, and his heavy yoke which he put upon us, lighter, and we will serve thee.
9157	303	5	And he said unto them, Depart yet for three days, then come again to me. And the people departed.
9158	303	6	And king Rehoboam consulted with the old men, that stood before Solomon his father while he yet lived, and said, How do ye advise that I may answer this people?
9159	303	7	And they spake unto him, saying, If thou wilt be a servant unto this people this day, and wilt serve them, and answer them, and speak good words to them, then they will be thy servants for ever.
9160	303	8	But he forsook the counsel of the old men, which they had given him, and consulted with the young men that were grown up with him, and which stood before him:
9161	303	9	And he said unto them, What counsel give ye that we may answer this people, who have spoken to me, saying, Make the yoke which thy father did put upon us lighter?
9162	303	10	And the young men that were grown up with him spake unto him, saying, Thus shalt thou speak unto this people that spake unto thee, saying, Thy father made our yoke heavy, but make thou it lighter unto us; thus shalt thou say unto them, My little finger shall be thicker than my father's loins.
9163	303	11	And now whereas my father did lade you with a heavy yoke, I will add to your yoke: my father hath chastised you with whips, but I will chastise you with scorpions.
9164	303	12	So Jeroboam and all the people came to Rehoboam the third day, as the king had appointed, saying, Come to me again the third day.
9165	303	13	And the king answered the people roughly, and forsook the old men's counsel that they gave him;
9166	303	14	And spake to them after the counsel of the young men, saying, My father made your yoke heavy, and I will add to your yoke: my father also chastised you with whips, but I will chastise you with scorpions.
9167	303	15	Wherefore the king hearkened not unto the people; for the cause was from the LORD, that he might perform his saying, which the LORD spake by Ahijah the Shilonite unto Jeroboam the son of Nebat.
9168	303	16	So when all Israel saw that the king hearkened not unto them, the people answered the king, saying, What portion have we in David? neither have we inheritance in the son of Jesse: to your tents, O Israel: now see to thine own house, David. So Israel departed unto their tents.
9169	303	17	But as for the children of Israel which dwelt in the cities of Judah, Rehoboam reigned over them.
9170	303	18	Then king Rehoboam sent Adoram, who was over the tribute; and all Israel stoned him with stones, that he died. Therefore king Rehoboam made speed to get him up to his chariot, to flee to Jerusalem.
9171	303	19	So Israel rebelled against the house of David unto this day.
9172	303	20	And it came to pass, when all Israel heard that Jeroboam was come again, that they sent and called him unto the congregation, and made him king over all Israel: there was none that followed the house of David, but the tribe of Judah only.
9173	303	21	And when Rehoboam was come to Jerusalem, he assembled all the house of Judah, with the tribe of Benjamin, an hundred and fourscore thousand chosen men, which were warriors, to fight against the house of Israel, to bring the kingdom again to Rehoboam the son of Solomon.
9174	303	22	But the word of God came unto Shemaiah the man of God, saying,
9175	303	23	Speak unto Rehoboam, the son of Solomon, king of Judah, and unto all the house of Judah and Benjamin, and to the remnant of the people, saying,
9176	303	24	Thus saith the LORD, Ye shall not go up, nor fight against your brethren the children of Israel: return every man to his house; for this thing is from me. They hearkened therefore to the word of the LORD, and returned to depart, according to the word of the LORD.
9177	303	25	Then Jeroboam built Shechem in mount Ephraim, and dwelt therein; and went out from thence, and built Penuel.
9178	303	26	And Jeroboam said in his heart, Now shall the kingdom return to the house of David:
9179	303	27	If this people go up to do sacrifice in the house of the LORD at Jerusalem, then shall the heart of this people turn again unto their lord, even unto Rehoboam king of Judah, and they shall kill me, and go again to Rehoboam king of Judah.
9180	303	28	Whereupon the king took counsel, and made two calves of gold, and said unto them, It is too much for you to go up to Jerusalem: behold thy gods, O Israel, which brought thee up out of the land of Egypt.
9181	303	29	And he set the one in Beth-el, and the other put he in Dan.
9182	303	30	And this thing became a sin: for the people went to worship before the one, even unto Dan.
9183	303	31	And he made an house of high places, and made priests of the lowest of the people, which were not of the sons of Levi.
9184	303	32	And Jeroboam ordained a feast in the eighth month, on the fifteenth day of the month, like unto the feast that is in Judah, and he offered upon the altar. So did he in Beth-el, sacrificing unto the calves that he had made: and he placed in Beth-el the priests of the high places which he had made.
9185	303	33	So he offered upon the altar which he had made in Beth-el the fifteenth day of the eighth month, even in the month which he had devised of his own heart; and ordained a feast unto the children of Israel: and he offered upon the altar, and burnt incense.
9186	304	1	AND, behold, there came a man of God out of Judah by the word of the LORD unto Beth-el: and Jeroboam stood by the altar to burn incense.
9187	304	2	And he cried against the altar in the word of the LORD, and said, O altar, altar, thus saith the LORD; Behold, a child shall be born unto the house of David, Josiah by name; and upon thee shall he offer the priests of the high places that burn incense upon thee, and men's bones shall be burnt upon thee.
9188	304	3	And he gave a sign the same day, saying, This is the sign which the LORD hath spoken; Behold, the altar shall be rent, and the ashes that are upon it shall be poured out.
9189	304	4	And it came to pass, when king Jeroboam heard the saying of the man of God, which had cried against the altar in Beth-el, that he put forth his hand from the altar, saying, Lay hold on him. And his hand, which he put forth against him, dried up, so that he could not pull it in again to him.
9190	304	5	The altar also was rent, and the ashes poured out from the altar, according to the sign which the man of God had given by the word of the LORD.
9191	304	6	And the king answered and said unto the man of God, Intreat now the face of the LORD thy God, and pray for me, that my hand may be restored me again. And the man of God besought the LORD, and the king's hand was restored him again, and became as it was before.
9192	304	7	And the king said unto the man of God, Come home with me, and refresh thyself, and I will give thee a reward.
9193	304	8	And the man of God said unto the king, If thou wilt give me half thine house, I will not go in with thee, neither will I eat bread nor drink water in this place:
9194	304	9	For so was it charged me by the word of the LORD, saying, Eat no bread, nor drink water, nor turn again by the same way that thou camest.
9195	304	10	So he went another way, and returned not by the way that he came to Beth-el.
9196	304	11	Now there dwelt an old prophet in Beth-el; and his sons came and told him all the works that the man of God had done that day in Beth-el: the words which he had spoken unto the king, them they told also to their father.
9197	304	12	And their father said unto them, What way went he? For his sons had seen what way the man of God went, which came from Judah.
9198	304	13	And he said unto his sons, Saddle me the ass. So they saddled him the ass: and he rode thereon,
9199	304	14	And went after the man of God, and found him sitting under an oak: and he said unto him, Art thou the man of God that camest from Judah? And he said, I am.
9200	304	15	Then he said unto him, Come home with me, and eat bread.
9201	304	16	And he said, I may not return with thee, nor go in with thee: neither will I eat bread nor drink water with thee in this place:
9202	304	17	For it was said to me by the word of the LORD, Thou shalt eat no bread nor drink water there, nor turn again to go by the way that thou camest.
9203	304	18	He said unto him, I am a prophet also as thou art; and an angel spake unto me by the word of the LORD, saying, Bring him back with thee into thine house, that he may eat bread and drink water. But he lied unto him.
9204	304	19	So he went back with him, and did eat bread in his house, and drank water.
9205	304	20	And it came to pass, as they sat at the table, that the word of the LORD came unto the prophet that brought him back:
9206	304	21	And he cried unto the man of God that came from Judah, saying, Thus saith the LORD, Forasmuch as thou hast disobeyed the mouth of the LORD, and hast not kept the commandment which the LORD thy God commanded thee,
9207	304	22	But camest back, and hast eaten bread and drunk water in the place, of the which the LORD did say to thee, Eat no bread, and drink no water; thy carcase shall not come unto the sepulchre of thy fathers.
9208	304	23	And it came to pass, after he had eaten bread, and after he had drunk, that he saddled for him the ass, to wit, for the prophet whom he had brought back.
9209	304	24	And when he was gone, a lion met him by the way, and slew him: and his carcase was cast in the way, and the ass stood by it, the lion also stood by the carcase.
9210	304	25	And, behold, men passed by, and saw the carcase cast in the way, and the lion standing by the carcase: and they came and told it in the city where the old prophet dwelt.
9211	304	26	And when the prophet that brought him back from the way heard thereof, he said, It is the man of God, who was disobedient unto the word of the LORD: therefore the LORD hath delivered him unto the lion, which hath torn him, and slain him, according to the word of the LORD, which he spake unto him.
9212	304	27	And he spake to his sons, saying, Saddle me the ass. And they saddled him.
9213	304	28	And he went and found his carcase cast in the way, and the ass and the lion standing by the carcase: the lion had not eaten the carcase, nor torn the ass.
9214	304	29	And the prophet took up the carcase of the man of God, and laid it upon the ass, and brought it back: and the old prophet came to the city, to mourn and to bury him.
9215	304	30	And he laid his carcase in his own grave; and they mourned over him, saying, Alas, my brother!
9216	304	31	And it came to pass, after he had buried him, that he spake to his sons, saying, When I am dead, then bury me in the sepulchre wherein the man of God is buried; lay my bones beside his bones:
9217	304	32	For the saying which he cried by the word of the LORD against the altar in Beth-el, and against all the houses of the high places which are in the cities of Samaria, shall surely come to pass.
9218	304	33	After this thing Jeroboam returned not from his evil way, but made again of the lowest of the people priests of the high places: whosoever would, he consecrated him, and he became one of the priests of the high places.
9219	304	34	And this thing became sin unto the house of Jeroboam, even to cut it off, and to destroy it from off the face of the earth.
9220	305	1	AT that time Abijah the son of Jeroboam fell sick.
9221	305	2	And Jeroboam said to his wife, Arise, I pray thee, and disguise thyself, that thou be not known to be the wife of Jeroboam; and get thee to Shiloh: behold, there is Ahijah the prophet, which told me that I should be king over this people.
9222	305	3	And take with thee ten loaves, and cracknels, and a cruse of honey, and go to him: he shall tell thee what shall become of the child.
9223	305	4	And Jeroboam's wife did so, and arose, and went to Shiloh, and came to the house of Ahijah. But Ahijah could not see; for his eyes were set by reason of his age.
9224	305	5	And the LORD said unto Ahijah, Behold, the wife of Jeroboam cometh to ask a thing of thee for her son; for he is sick: thus and thus shalt thou say unto her: for it shall be, when she cometh in, that she shall feign herself to be another woman.
9225	305	6	And it was so, when Ahijah heard the sound of her feet, as she came in at the door, that he said, Come in, thou wife of Jeroboam; why feignest thou thyself to be another? for I am sent to thee with heavy tidings.
9226	305	7	Go, tell Jeroboam, Thus saith the LORD God of Israel, Forasmuch as I exalted thee from among the people, and made thee prince over my people Israel,
9227	305	8	And rent the kingdom away from the house of David, and gave it thee: and yet thou hast not been as my servant David, who kept my commandments, and who followed me with all his heart, to do that only which was right in mine eyes;
9228	305	9	But hast done evil above all that were before thee: for thou hast gone and made thee other gods, and molten images, to provoke me to anger, and hast cast me behind thy back:
9229	305	10	Therefore, behold, I will bring evil upon the house of Jeroboam, and will cut off from Jeroboam him that pisseth against the wall, and him that is shut up and left in Israel, and will take away the remnant of the house of Jeroboam, as a man taketh away dung, till it be all gone.
9230	305	11	Him that dieth of Jeroboam in the city shall the dogs eat; and him that dieth in the field shall the fowls of the air eat: for the LORD hath spoken it.
9231	305	12	Arise thou therefore, get thee to thine own house: and when thy feet enter into the city, the child shall die.
9232	305	13	And all Israel shall mourn for him, and bury him: for he only of Jeroboam shall come to the grave, because in him there is found some good thing toward the LORD God of Israel in the house of Jeroboam.
9233	305	14	Moreover the LORD shall raise him up a king over Israel, who shall cut off the house of Jeroboam that day: but what? even now.
9234	305	15	For the LORD shall smite Israel, as a reed is shaken in the water, and he shall root up Israel out of this good land, which he gave to their fathers, and shall scatter them beyond the river, because they have made their groves, provoking the LORD to anger.
9235	305	16	And he shall give Israel up because of the sins of Jeroboam, who did sin, and who made Israel to sin.
9236	305	17	And Jeroboam's wife arose, and departed, and came to Tirzah: and when she came to the threshold of the door, the child died;
9237	305	18	And they buried him; and all Israel mourned for him, according to the word of the LORD, which he spake by the hand of his servant Ahijah the prophet.
9238	305	19	And the rest of the acts of Jeroboam, how he warred, and how he reigned, behold, they are written in the book of the chronicles of the kings of Israel.
9239	305	20	And the days which Jeroboam reigned were two and twenty years: and he slept with his fathers, and Nadab his son reigned in his stead.
9240	305	21	And Rehoboam the son of Solomon reigned in Judah. Rehoboam was forty and one years old when he began to reign, and he reigned seventeen years in Jerusalem, the city which the LORD did choose out of all the tribes of Israel, to put his name there. And his mother's name was Naamah an Ammonitess.
9241	305	22	And Judah did evil in the sight of the LORD, and they provoked him to jealousy with their sins which they had committed, above all that their fathers had done.
9242	305	23	For they also built them high places, and images, and groves, on every high hill, and under every green tree.
9243	305	24	And there were also sodomites in the land: and they did according to all the abominations of the nations which the LORD cast out before the children of Israel.
9244	305	25	And it came to pass in the fifth year of king Rehoboam, that Shishak king of Egypt came up against Jerusalem:
9245	305	26	And he took away the treasures of the house of the LORD, and the treasures of the king's house; he even took away all: and he took away all the shields of gold which Solomon had made.
9246	305	27	And king Rehoboam made in their stead brasen shields, and committed them unto the hands of the chief of the guard, which kept the door of the king's house.
9247	305	28	And it was so, when the king went into the house of the LORD, that the guard bare them, and brought them back into the guard chamber.
9248	305	29	Now the rest of the acts of Rehoboam, and all that he did, are they not written in the book of the chronicles of the kings of Judah?
9249	305	30	And there was war between Rehoboam and Jeroboam all their days.
9250	305	31	And Rehoboam slept with his fathers, and was buried with his fathers in the city of David. And his mother's name was Naamah an Ammonitess. And Abijam his son reigned in his stead.
9251	306	1	NOW in the eighteenth year of king Jeroboam the son of Nebat reigned Abijam over Judah.
9252	306	2	Three years reigned he in Jerusalem. And his mother's name was Maachah, the daughter of Abishalom.
9253	306	3	And he walked in all the sins of his father, which he had done before him: and his heart was not perfect with the LORD his God, as the heart of David his father.
9254	306	4	Nevertheless for David's sake did the LORD his God give him a lamp in Jerusalem, to set up his son after him, and to establish Jerusalem:
9255	306	5	Because David did that which was right in the eyes of the LORD, and turned not aside from any thing that he commanded him all the days of his life, save only in the matter of Uriah the Hittite.
9256	306	6	And there was war between Rehoboam and Jeroboam all the days of his life.
9257	306	7	Now the rest of the acts of Abijam, and all that he did, are they not written in the book of the chronicles of the kings of Judah? And there was war between Abijam and Jeroboam.
9258	306	8	And Abijam slept with his fathers; and they buried him in the city of David: and Asa his son reigned in his stead.
9259	306	9	And in the twentieth year of Jeroboam king of Israel reigned Asa over Judah.
9260	306	10	And forty and one years reigned he in Jerusalem. And his mother's name was Maachah, the daughter of Abishalom.
9261	306	11	And Asa did that which was right in the eyes of the LORD, as did David his father.
9262	306	12	And he took away the sodomites out of the land, and removed all the idols that his fathers had made.
9263	306	13	And also Maachah his mother, even her he removed from being queen, because she had made an idol in a grove; and Asa destroyed her idol, and burnt it by the brook Kidron.
9264	306	14	But the high places were not removed: nevertheless Asa's heart was perfect with the LORD all his days.
9265	306	15	And he brought in the things which his father had dedicated, and the things which himself had dedicated, into the house of the LORD, silver, and gold, and vessels.
9266	306	16	And there was war between Asa and Baasha king of Israel all their days.
9267	306	17	And Baasha king of Israel went up against Judah, and built Ramah, that he might not suffer any to go out or come in to Asa king of Judah.
9268	306	18	Then Asa took all the silver and the gold that were left in the treasures of the house of the LORD, and the treasures of the king's house, and delivered them into the hand of his servants: and king Asa sent them to Ben-hadad, the son of Tabrimon, the son of Hezion, king of Syria, that dwelt at Damascus, saying,
9269	306	19	There is a league between me and thee, and between my father and thy father: behold, I have sent unto thee a present of silver and gold; come and break thy league with Baasha king of Israel, that he may depart from me.
9270	306	20	So Ben-hadad hearkened unto king Asa, and sent the captains of the hosts which he had against the cities of Israel, and smote Ijon, and Dan, and Abel-beth-maachah, and all Cinneroth, with all the land of Naphtali.
9271	306	21	And it came to pass, when Baasha heard thereof, that he left off building of Ramah, and dwelt in Tirzah.
9272	306	22	Then king Asa made a proclamation throughout all Judah; none was exempted: and they took away the stones of Ramah, and the timber thereof, wherewith Baasha had builded; and king Asa built with them Geba of Benjamin, and Mizpah.
9273	306	23	The rest of all the acts of Asa, and all his might, and all that he did, and the cities which he built, are they not written in the book of the chronicles of the kings of Judah? Nevertheless in the time of his old age he was diseased in his feet.
9274	306	24	And Asa slept with his fathers, and was buried with his fathers in the city of David his father: and Jehoshaphat his son reigned in his stead.
9275	306	25	And Nadab the son of Jeroboam began to reign over Israel in the second year of Asa king of Judah, and reigned over Israel two years.
9276	306	26	And he did evil in the sight of the LORD, and walked in the way of his father, and in his sin wherewith he made Israel to sin.
9277	306	27	And Baasha the son of Ahijah, of the house of Issachar, conspired against him; and Baasha smote him at Gibbethon, which belonged to the Philistines; for Nadab and all Israel laid siege to Gibbethon.
9278	306	28	Even in the third year of Asa king of Judah did Baasha slay him, and reigned in his stead.
9279	306	29	And it came to pass, when he reigned, that he smote all the house of Jeroboam; he left not to Jeroboam any that breathed, until he had destroyed him, according unto the saying of the LORD, which he spake by his servant Ahijah the Shilonite:
9280	306	30	Because of the sins of Jeroboam which he sinned, and which he made Israel sin, by his provocation wherewith he provoked the LORD God of Israel to anger.
9281	306	31	Now the rest of the acts of Nadab, and all that he did, are they not written in the book of the chronicles of the kings of Israel?
9282	306	32	And there was war between Asa and Baasha king of Israel all their days.
9283	306	33	In the third year of Asa king of Judah began Baasha the son of Ahijah to reign over all Israel in Tirzah, twenty and four years.
9284	306	34	And he did evil in the sight of the LORD, and walked in the way of Jeroboam, and in his sin wherewith he made Israel to sin.
9285	307	1	THEN the word of the LORD came to Jehu the son of Hanani against Baasha, saying,
9286	307	2	Forasmuch as I exalted thee out of the dust, and made thee prince over my people Israel; and thou hast walked in the way of Jeroboam, and hast made my people Israel to sin, to provoke me to anger with their sins;
9287	307	3	Behold, I will take away the posterity of Baasha, and the posterity of his house; and will make thy house like the house of Jeroboam the son of Nebat.
9288	307	4	Him that dieth of Baasha in the city shall the dogs eat; and him that dieth of his in the fields shall the fowls of the air eat.
9289	307	5	Now the rest of the acts of Baasha, and what he did, and his might, are they not written in the book of the chronicles of the kings of Israel?
9290	307	6	So Baasha slept with his fathers, and was buried in Tirzah: and Elah his son reigned in his stead.
9291	307	7	And also by the hand of the prophet Jehu the son of Hanani came the word of the LORD against Baasha, and against his house, even for all the evil that he did in the sight of the LORD, in provoking him to anger with the work of his hands, in being like the house of Jeroboam; and because he killed him.
9292	307	8	In the twenty and sixth year of Asa king of Judah began Elah the son of Baasha to reign over Israel in Tirzah, two years.
9293	307	9	And his servant Zimri, captain of half his chariots, conspired against him, as he was in Tirzah, drinking himself drunk in the house of Arza steward of his house in Tirzah.
9294	307	10	And Zimri went in and smote him, and killed him, in the twenty and seventh year of Asa king of Judah, and reigned in his stead.
9295	307	11	And it came to pass, when he began to reign, as soon as he sat on his throne, that he slew all the house of Baasha: he left him not one that pisseth against a wall, neither of his kinsfolks, nor of his friends.
9296	307	12	Thus did Zimri destroy all the house of Baasha, according to the word of the LORD, which he spake against Baasha by Jehu the prophet,
9297	307	13	For all the sins of Baasha, and the sins of Elah his son, by which they sinned, and by which they made Israel to sin, in provoking the LORD God of Israel to anger with their vanities.
9298	307	14	Now the rest of the acts of Elah, and all that he did, are they not written in the book of the chronicles of the kings of Israel?
9299	307	15	In the twenty and seventh year of Asa king of Judah did Zimri reign seven days in Tirzah. And the people were encamped against Gibbethon, which belonged to the Philistines.
9300	307	16	And the people that were encamped heard say, Zimri hath conspired, and hath also slain the king: wherefore all Israel made Omri, the captain of the host, king over Israel that day in the camp.
9301	307	17	And Omri went up from Gibbethon, and all Israel with him, and they besieged Tirzah.
9302	307	18	And it came to pass, when Zimri saw that the city was taken, that he went into the palace of the king's house, and burnt the king's house over him with fire, and died,
9303	307	19	For his sins which he sinned in doing evil in the sight of the LORD, in walking in the way of Jeroboam, and in his sin which he did, to make Israel to sin.
9304	307	20	Now the rest of the acts of Zimri, and his treason that he wrought, are they not written in the book of the chronicles of the kings of Israel?
9305	307	21	Then were the people of Israel divided into two parts: half of the people followed Tibni the son of Ginath, to make him king; and half followed Omri.
9306	307	22	But the people that followed Omri prevailed against the people that followed Tibni the son of Ginath: so Tibni died, and Omri reigned.
9307	307	23	In the thirty and first year of Asa king of Judah began Omri to reign over Israel, twelve years: six years reigned he in Tirzah.
9308	307	24	And he bought the hill Samaria of Shemer for two talents of silver, and built on the hill, and called the name of the city which he built, after the name of Shemer, owner of the hill, Samaria.
9309	307	25	But Omri wrought evil in the eyes of the LORD, and did worse than all that were before him.
9310	307	26	For he walked in all the way of Jeroboam the son of Nebat, and in his sin wherewith he made Israel to sin, to provoke the LORD God of Israel to anger with their vanities.
9311	307	27	Now the rest of the acts of Omri which he did, and his might that he shewed, are they not written in the book of the chronicles of the kings of Israel?
9312	307	28	So Omri slept with his fathers, and was buried in Samaria: and Ahab his son reigned in his stead.
9313	307	29	And in the thirty and eighth year of Asa king of Judah began Ahab the son of Omri to reign over Israel: and Ahab the son of Omri reigned over Israel in Samaria twenty and two years.
9314	307	30	And Ahab the son of Omri did evil in the sight of the LORD above all that were before him.
9315	307	31	And it came to pass, as if it had been a light thing for him to walk in the sins of Jeroboam the son of Nebat, that he took to wife Jezebel the daughter of Ethbaal king of the Zidonians, and went and served Baal, and worshipped him.
9316	307	32	And he reared up an altar for Baal in the house of Baal, which he had built in Samaria.
9317	307	33	And Ahab made a grove; and Ahab did more to provoke the LORD God of Israel to anger than all the kings of Israel that were before him.
9318	307	34	In his days did Hiel the Beth-elite build Jericho: he laid the foundation thereof in Abiram his firstborn, and set up the gates thereof in his youngest son Segub, according to the word of the LORD, which he spake by Joshua the son of Nun.
9319	308	1	AND Elijah the Tishbite, who was of the inhabitants of Gilead, said unto Ahab, As the LORD God of Israel liveth, before whom I stand, there shall not be dew nor rain these years, but according to my word.
9320	308	2	And the word of the LORD came unto him, saying,
9321	308	3	Get thee hence, and turn thee eastward, and hide thyself by the brook Cherith, that is before Jordan.
9322	308	4	And it shall be, that thou shalt drink of the brook; and I have commanded the ravens to feed thee there.
9323	308	5	So he went and did according unto the word of the LORD: for he went and dwelt by the brook Cherith, that is before Jordan.
9324	308	6	And the ravens brought him bread and flesh in the morning, and bread and flesh in the evening; and he drank of the brook.
9325	308	7	And it came to pass after a while, that the brook dried up, because there had been no rain in the land.
9326	308	8	And the word of the LORD came unto him, saying,
9327	308	9	Arise, get thee to Zarephath, which belongeth to Zidon, and dwell there: behold, I have commanded a widow woman there to sustain thee.
9328	308	10	So he arose and went to Zarephath. And when he came to the gate of the city, behold, the widow woman was there gathering of sticks: and he called to her, and said, Fetch me, I pray thee, a little water in a vessel, that I may drink.
9329	308	11	And as she was going to fetch it, he called to her, and said, Bring me, I pray thee, a morsel of bread in thine hand.
9330	308	12	And she said, As the LORD thy God liveth, I have not a cake, but an handful of meal in a barrel, and a little oil in a cruse: and, behold, I am gathering two sticks, that I may go in and dress it for me and my son, that we may eat it, and die.
9331	308	13	And Elijah said unto her, Fear not; go and do as thou hast said: but make me thereof a little cake first, and bring it unto me, and after make for thee and for thy son.
9332	308	14	For thus saith the LORD God of Israel, The barrel of meal shall not waste, neither shall the cruse of oil fail, until the day that the LORD sendeth rain upon the earth.
9333	308	15	And she went and did according to the saying of Elijah: and she, and he, and her house, did eat many days.
9334	308	16	And the barrel of meal wasted not, neither did the cruse of oil fail, according to the word of the LORD, which he spake by Elijah.
9335	308	17	And it came to pass after these things, that the son of the woman, the mistress of the house, fell sick; and his sickness was so sore, that there was no breath left in him.
9336	308	18	And she said unto Elijah, What have I to do with thee, O thou man of God? art thou come unto me to call my sin to remembrance, and to slay my son?
9337	308	19	And he said unto her, Give me thy son. And he took him out of her bosom, and carried him up into a loft, where he abode, and laid him upon his own bed.
9338	308	20	And he cried unto the LORD, and said, O LORD my God, hast thou also brought evil upon the widow with whom I sojourn, by slaying her son?
9339	308	21	And he stretched himself upon the child three times, and cried unto the LORD, and said, O LORD my God, I pray thee, let this child's soul come into him again.
9340	308	22	And the LORD heard the voice of Elijah; and the soul of the child came into him again, and he revived.
9341	308	23	And Elijah took the child, and brought him down out of the chamber into the house, and delivered him unto his mother: and Elijah said, See, thy son liveth.
9342	308	24	And the woman said to Elijah, Now by this I know that thou art a man of God, and that the word of the LORD in thy mouth is truth.
9343	309	1	AND it came to pass after many days, that the word of the LORD came to Elijah in the third year, saying, Go, shew thyself unto Ahab; and I will send rain upon the earth.
9344	309	2	And Elijah went to shew himself unto Ahab. And there was a sore famine in Samaria.
9345	309	3	And Ahab called Obadiah, which was the governor of his house. (Now Obadiah feared the LORD greatly:
9346	309	4	For it was so, when Jezebel cut off the prophets of the LORD, that Obadiah took an hundred prophets, and hid them by fifty in a cave, and fed them with bread and water.)
9347	309	5	And Ahab said unto Obadiah, Go into the land, unto all fountains of water, and unto all brooks: peradventure we may find grass to save the horses and mules alive, that we lose not all the beasts.
9348	309	6	So they divided the land between them to pass throughout it: Ahab went one way by himself, and Obadiah went another way by himself.
9349	309	7	And as Obadiah was in the way, behold, Elijah met him: and he knew him, and fell on his face, and said, Art thou that my lord Elijah?
9350	309	8	And he answered him, I am: go, tell thy lord, Behold, Elijah is here.
9351	309	9	And he said, What have I sinned, that thou wouldest deliver thy servant into the hand of Ahab, to slay me?
9352	309	10	As the LORD thy God liveth, there is no nation or kingdom, whither my lord hath not sent to seek thee: and when they said, He is not there; he took an oath of the kingdom and nation, that they found thee not.
9353	309	11	And now thou sayest, Go, tell thy lord, Behold, Elijah is here.
9354	309	12	And it shall come to pass, as soon as I am gone from thee, that the Spirit of the LORD shall carry thee whither I know not; and so when I come and tell Ahab, and he cannot find thee, he shall slay me: but I thy servant fear the LORD from my youth.
9355	309	13	Was it not told my lord what I did when Jezebel slew the prophets of the LORD, how I hid an hundred men of the LORD's prophets by fifty in a cave, and fed them with bread and water?
9356	309	14	And now thou sayest, Go, tell thy lord, Behold, Elijah is here: and he shall slay me.
9357	309	15	And Elijah said, As the LORD of hosts liveth, before whom I stand, I will surely shew myself unto him to day.
9358	309	16	So Obadiah went to meet Ahab, and told him: and Ahab went to meet Elijah.
9359	309	17	And it came to pass, when Ahab saw Elijah, that Ahab said unto him, Art thou he that troubleth Israel?
9360	309	18	And he answered, I have not troubled Israel; but thou, and thy father's house, in that ye have forsaken the commandments of the LORD, and thou hast followed Baalim.
9361	309	19	Now therefore send, and gather to me all Israel unto mount Carmel, and the prophets of Baal four hundred and fifty, and the prophets of the groves four hundred, which eat at Jezebel's table.
9362	309	20	So Ahab sent unto all the children of Israel, and gathered the prophets together unto mount Carmel.
9363	309	21	And Elijah came unto all the people, and said, How long halt ye between two opinions? if the LORD be God, follow him: but if Baal, then follow him. And the people answered him not a word.
9364	309	22	Then said Elijah unto the people, I, even I only, remain a prophet of the LORD; but Baal's prophets are four hundred and fifty men.
9365	309	23	Let them therefore give us two bullocks; and let them choose one bullock for themselves, and cut it in pieces, and lay it on wood, and put no fire under: and I will dress the other bullock, and lay it on wood, and put no fire under:
9366	309	24	And call ye on the name of your gods, and I will call on the name of the LORD: and the God that answereth by fire, let him be God. And all the people answered and said, It is well spoken.
9367	309	25	And Elijah said unto the prophets of Baal, Choose you one bullock for yourselves, and dress it first; for ye are many; and call on the name of your gods, but put no fire under.
9368	309	26	And they took the bullock which was given them, and they dressed it, and called on the name of Baal from morning even until noon, saying, O Baal, hear us. But there was no voice, nor any that answered. And they leaped upon the altar which was made.
9369	309	27	And it came to pass at noon, that Elijah mocked them, and said, Cry aloud: for he is a god; either he is talking, or he is pursuing, or he is in a journey, or peradventure he sleepeth, and must be awaked.
9370	309	28	And they cried aloud, and cut themselves after their manner with knives and lancets, till the blood gushed out upon them.
9371	309	29	And it came to pass, when midday was past, and they prophesied until the time of the offering of the evening sacrifice, that there was neither voice, nor any to answer, nor any that regarded.
9372	309	30	And Elijah said unto all the people, Come near unto me. And all the people came near unto him. And he repaired the altar of the LORD that was broken down.
9373	309	31	And Elijah took twelve stones, according to the number of the tribes of the sons of Jacob, unto whom the word of the LORD came, saying, Israel shall be thy name:
9374	309	32	And with the stones he built an altar in the name of the LORD: and he made a trench about the altar, as great as would contain two measures of seed.
9375	309	33	And he put the wood in order, and cut the bullock in pieces, and laid him on the wood, and said, Fill four barrels with water, and pour it on the burnt sacrifice, and on the wood.
9376	309	34	And he said, Do it the second time. And they did it the second time. And he said, Do it the third time. And they did it the third time.
9377	309	35	And the water ran round about the altar; and he filled the trench also with water.
9378	309	36	And it came to pass at the time of the offering of the evening sacrifice, that Elijah the prophet came near, and said, LORD God of Abraham, Isaac, and of Israel, let it be known this day that thou art God in Israel, and that I am thy servant, and that I have done all these things at thy word.
9379	309	37	Hear me, O LORD, hear me, that this people may know that thou art the LORD God, and that thou hast turned their heart back again.
9380	309	38	Then the fire of the LORD fell, and consumed the burnt sacrifice, and the wood, and the stones, and the dust, and licked up the water that was in the trench.
9381	309	39	And when all the people saw it, they fell on their faces: and they said, The LORD, he is the God; the LORD, he is the God.
9382	309	40	And Elijah said unto them, Take the prophets of Baal; let not one of them escape. And they took them: and Elijah brought them down to the brook Kishon, and slew them there.
9383	309	41	And Elijah said unto Ahab, Get thee up, eat and drink; for there is a sound of abundance of rain.
9384	309	42	So Ahab went up to eat and to drink. And Elijah went up to the top of Carmel; and he cast himself down upon the earth, and put his face between his knees,
9385	309	43	And said to his servant, Go up now, look toward the sea. And he went up, and looked, and said, There is nothing. And he said, Go again seven times.
9386	309	44	And it came to pass at the seventh time, that he said, Behold, there ariseth a little cloud out of the sea, like a man's hand. And he said, Go up, say unto Ahab, Prepare thy chariot, and get thee down, that the rain stop thee not.
9387	309	45	And it came to pass in the mean while, that the heaven was black with clouds and wind, and there was a great rain. And Ahab rode, and went to Jezreel.
9388	309	46	And the hand of the LORD was on Elijah; and he girded up his loins, and ran before Ahab to the entrance of Jezreel.
9389	310	1	AND Ahab told Jezebel all that Elijah had done, and withal how he had slain all the prophets with the sword.
9390	310	2	Then Jezebel sent a messenger unto Elijah, saying, So let the gods do to me, and more also, if I make not thy life as the life of one of them by to morrow about this time.
9391	310	3	And when he saw that, he arose, and went for his life, and came to Beer-sheba, which belongeth to Judah, and left his servant there.
9392	310	4	But he himself went a day's journey into the wilderness, and came and sat down under a juniper tree: and he requested for himself that he might die; and said, It is enough; now, O LORD, take away my life; for I am not better than my fathers.
9393	310	5	And as he lay and slept under a juniper tree, behold, then an angel touched him, and said unto him, Arise and eat.
9394	310	6	And he looked, and, behold, there was a cake baken on the coals, and a cruse of water at his head. And he did eat and drink, and laid him down again.
9395	310	7	And the angel of the LORD came again the second time, and touched him, and said, Arise and eat; because the journey is too great for thee.
9396	310	8	And he arose, and did eat and drink, and went in the strength of that meat forty days and forty nights unto Horeb the mount of God.
9397	310	9	And he came thither unto a cave, and lodged there; and, behold, the word of the LORD came to him, and he said unto him, What doest thou here, Elijah?
9398	310	10	And he said, I have been very jealous for the LORD God of hosts: for the children of Israel have forsaken thy covenant, thrown down thine altars, and slain thy prophets with the sword; and I, even I only, am left; and they seek my life, to take it away.
9399	310	11	And he said, Go forth, and stand upon the mount before the LORD. And, behold, the LORD passed by, and a great and strong wind rent the mountains, and brake in pieces the rocks before the LORD; but the LORD was not in the wind: and after the wind an earthquake; but the LORD was not in the earthquake:
9400	310	12	And after the earthquake a fire; but the LORD was not in the fire: and after the fire a still small voice.
9401	310	13	And it was so, when Elijah heard it, that he wrapped his face in his mantle, and went out, and stood in the entering in of the cave. And, behold, there came a voice unto him, and said, What doest thou here, Elijah?
9402	310	14	And he said, I have been very jealous for the LORD God of hosts: because the children of Israel have forsaken thy covenant, thrown down thine altars, and slain thy prophets with the sword; and I, even I only, am left; and they seek my life, to take it away.
9403	310	15	And the LORD said unto him, Go, return on thy way to the wilderness of Damascus: and when thou comest, anoint Hazael to be king over Syria:
9404	310	16	And Jehu the son of Nimshi shalt thou anoint to be king over Israel: and Elisha the son of Shaphat of Abel-meholah shalt thou anoint to be prophet in thy room.
9405	310	17	And it shall come to pass, that him that escapeth the sword of Hazael shall Jehu slay: and him that escapeth from the sword of Jehu shall Elisha slay.
9406	310	18	Yet I have left me seven thousand in Israel, all the knees which have not bowed unto Baal, and every mouth which hath not kissed him.
9407	310	19	So he departed thence, and found Elisha the son of Shaphat, who was plowing with twelve yoke of oxen before him, and he with the twelfth: and Elijah passed by him, and cast his mantle upon him.
9408	310	20	And he left the oxen, and ran after Elijah, and said, Let me, I pray thee, kiss my father and my mother, and then I will follow thee. And he said unto him, Go back again: for what have I done to thee?
9409	310	21	And he returned back from him, and took a yoke of oxen, and slew them, and boiled their flesh with the instruments of the oxen, and gave unto the people, and they did eat. Then he arose, and went after Elijah, and ministered unto him.
9410	311	1	AND Ben-hadad the king of Syria gathered all his host together: and there were thirty and two kings with him, and horses, and chariots: and he went up and besieged Samaria, and warred against it.
9411	311	2	And he sent messengers to Ahab king of Israel into the city, and said unto him, Thus saith Ben-hadad,
9412	311	3	Thy silver and thy gold is mine; thy wives also and thy children, even the goodliest, are mine.
9413	311	4	And the king of Israel answered and said, My lord, O king, according to thy saying, I am thine, and all that I have.
9414	311	5	And the messengers came again, and said, Thus speaketh Ben-hadad, saying, Although I have sent unto thee, saying, Thou shalt deliver me thy silver, and thy gold, and thy wives, and thy children;
9415	311	6	Yet I will send my servants unto thee to morrow about this time, and they shall search thine house, and the houses of thy servants; and it shall be, that whatsoever is pleasant in thine eyes, they shall put it in their hand, and take it away.
9416	311	7	Then the king of Israel called all the elders of the land, and said, Mark, I pray you, and see how this man seeketh mischief: for he sent unto me for my wives, and for my children, and for my silver, and for my gold; and I denied him not.
9417	311	8	And all the elders and all the people said unto him, Hearken not unto him, nor consent.
9418	311	9	Wherefore he said unto the messengers of Ben-hadad, Tell my lord the king, All that thou didst send for to thy servant at the first I will do: but this thing I may not do. And the messengers departed, and brought him word again.
9419	311	10	And Ben-hadad sent unto him, and said, The gods do so unto me, and more also, if the dust of Samaria shall suffice for handfuls for all the people that follow me.
9420	311	11	And the king of Israel answered and said, Tell him, Let not him that girdeth on his harness boast himself as he that putteth it off.
9421	311	12	And it came to pass, when Ben-hadad heard this message, as he was drinking, he and the kings in the pavilions, that he said unto his servants, Set yourselves in array. And they set themselves in array against the city.
9422	311	13	And, behold, there came a prophet unto Ahab king of Israel, saying, Thus saith the LORD, Hast thou seen all this great multitude? behold, I will deliver it into thine hand this day; and thou shalt know that I am the LORD.
9423	311	14	And Ahab said, By whom? And he said, Thus saith the LORD, Even by the young men of the princes of the provinces. Then he said, Who shall order the battle? And he answered, Thou.
9424	311	15	Then he numbered the young men of the princes of the provinces, and they were two hundred and thirty two: and after them he numbered all the people, even all the children of Israel, being seven thousand.
9425	311	16	And they went out at noon. But Ben-hadad was drinking himself drunk in the pavilions, he and the kings, the thirty and two kings that helped him.
9426	311	17	And the young men of the princes of the provinces went out first; and Ben-hadad sent out, and they told him, saying, There are men come out of Samaria.
9427	311	18	And he said, Whether they be come out for peace, take them alive; or whether they be come out for war, take them alive.
9428	311	19	So these young men of the princes of the provinces came out of the city, and the army which followed them.
9429	311	20	And they slew every one his man: and the Syrians fled; and Israel pursued them: and Ben-hadad the king of Syria escaped on an horse with the horsemen.
9430	311	21	And the king of Israel went out, and smote the horses and chariots, and slew the Syrians with a great slaughter.
9431	311	22	And the prophet came to the king of Israel, and said unto him, Go, strengthen thy self, and mark, and see what thou doest: for at the return of the year the king of Syria will come up against thee.
9432	311	23	And the servants of the king of Syria said unto him, Their gods are gods of the hills; therefore they were stronger than we; but let us fight against them in the plain, and surely we shall be stronger than they.
9433	311	24	And do this thing, Take the kings away, every man out of his place, and put captains in their rooms:
9434	311	25	And number thee an army, like the army that thou hast lost, horse for horse, and chariot for chariot: and we will fight against them in the plain, and surely we shall be stronger than they. And he hearkened unto their voice, and did so.
9435	311	26	And it came to pass at the return of the year, that Ben-hadad numbered the Syrians, and went up to Aphek, to fight against Israel.
9436	311	27	And the children of Israel were numbered, and were all present, and went against them: and the children of Israel pitched before them like two little flocks of kids; but the Syrians filled the country.
9437	311	28	And there came a man of God, and spake unto the king of Israel, and said, Thus saith the LORD, Because the Syrians have said, The LORD is God of the hills, but he is not God of the valleys, therefore will I deliver all this great multitude into thine hand, and ye shall know that I am the LORD.
9438	311	29	And they pitched one over against the other seven days. And so it was, that in the seventh day the battle was joined: and the children of Israel slew of the Syrians an hundred thousand footmen in one day.
9439	311	30	But the rest fled to Aphek, into the city; and there a wall fell upon twenty and seven thousand of the men that were left. And Ben-hadad fled, and came into the city, into an inner chamber.
9440	311	31	And his servants said unto him, Behold now, we have heard that the kings of the house of Israel are merciful kings: let us, I pray thee, put sackcloth on our loins, and ropes upon our heads, and go out to the king of Israel: peradventure he will save thy life.
9441	311	32	So they girded sackcloth on their loins, and put ropes on their heads, and came to the king of Israel, and said, Thy servant Ben-hadad saith, I pray thee, let me live. And he said, Is he yet alive? he is my brother.
9442	311	33	Now the men did diligently observe whether any thing would come from him, and did hastily catch it: and they said, Thy brother Ben-hadad. Then he said, Go ye, bring him. Then Ben-hadad came forth to him; and he caused him to come up into the chariot.
9443	311	34	And Ben-hadad said unto him, The cities, which my father took from thy father, I will restore; and thou shalt make streets for thee in Damascus, as my father made in Samaria. Then said Ahab, I will send thee away with this covenant. So he made a covenant with him, and sent him away.
9444	311	35	And a certain man of the sons of the prophets said unto his neighbour in the word of the LORD, Smite me, I pray thee. And the man refused to smite him.
9445	311	36	Then said he unto him, Because thou hast not obeyed the voice of the LORD, behold, as soon as thou art departed from me, a lion shall slay thee. And as soon as he was departed from him, a lion found him, and slew him.
9446	311	37	Then he found another man, and said, Smite me, I pray thee. And the man smote him, so that in smiting he wounded him.
9447	311	38	So the prophet departed, and waited for the king by the way, and disguised himself with ashes upon his face.
9448	311	39	And as the king passed by, he cried unto the king: and he said, Thy servant went out into the midst of the battle; and, behold, a man turned aside, and brought a man unto me, and said, Keep this man: if by any means he be missing, then shall thy life be for his life, or else thou shalt pay a talent of silver.
9449	311	40	And as thy servant was busy here and there, he was gone. And the king of Israel said unto him, So shall thy judgment be; thyself hast decided it.
9450	311	41	And he hasted, and took the ashes away from his face; and the king of Israel discerned him that he was of the prophets.
9451	311	42	And he said unto him, Thus saith the LORD, Because thou hast let go out of thy hand a man whom I appointed to utter destruction, therefore thy life shall go for his life, and thy people for his people.
9452	311	43	And the king of Israel went to his house heavy and displeased, and came to Samaria.
9453	312	1	AND it came to pass after these things, that Naboth the Jezreelite had a vineyard, which was in Jezreel, hard by the palace of Ahab king of Samaria.
9454	312	2	And Ahab spake unto Naboth, saying, Give me thy vineyard, that I may have it for a garden of herbs, because it is near unto my house: and I will give thee for it a better vineyard than it; or, if it seem good to thee, I will give thee the worth of it in money.
9455	312	3	And Naboth said to Ahab, The LORD forbid it me, that I should give the inheritance of my fathers unto thee.
9456	312	4	And Ahab came into his house heavy and displeased because of the word which Naboth the Jezreelite had spoken to him: for he had said, I will not give thee the inheritance of my fathers. And he laid him down upon his bed, and turned away his face, and would eat no bread.
9457	312	5	But Jezebel his wife came to him, and said unto him, Why is thy spirit so sad, that thou eatest no bread?
9458	312	6	And he said unto her, Because I spake unto Naboth the Jezreelite, and said unto him, Give me thy vineyard for money; or else, if it please thee, I will give thee another vineyard for it: and he answered, I will not give thee my vineyard.
9459	312	7	And Jezebel his wife said unto him, Dost thou now govern the kingdom of Israel? arise, and eat bread, and let thine heart be merry: I will give thee the vineyard of Naboth the Jezreelite.
9460	312	8	So she wrote letters in Ahab's name, and sealed them with his seal, and sent the letters unto the elders and to the nobles that were in his city, dwelling with Naboth.
9461	312	9	And she wrote in the letters, saying, Proclaim a fast, and set Naboth on high among the people:
9462	312	10	And set two men, sons of Belial, before him, to bear witness against him, saying, Thou didst blaspheme God and the king. And then carry him out, and stone him, that he may die.
9463	312	11	And the men of his city, even the elders and the nobles who were the inhabitants in his city, did as Jezebel had sent unto them, and as it was written in the letters which she had sent unto them.
9464	312	12	They proclaimed a fast, and set Naboth on high among the people.
9465	312	13	And there came in two men, children of Belial, and sat before him: and the men of Belial witnessed against him, even against Naboth, in the presence of the people, saying, Naboth did blaspheme God and the king. Then they carried him forth out of the city, and stoned him with stones, that he died.
9466	312	14	Then they sent to Jezebel, saying, Naboth is stoned, and is dead.
9467	312	15	And it came to pass, when Jezebel heard that Naboth was stoned, and was dead, that Jezebel said to Ahab, Arise, take possession of the vineyard of Naboth the Jezreelite, which he refused to give thee for money: for Naboth is not alive, but dead.
9468	312	16	And it came to pass, when Ahab heard that Naboth was dead, that Ahab rose up to go down to the vineyard of Naboth the Jezreelite, to take possession of it.
9469	312	17	And the word of the LORD came to Elijah the Tishbite, saying,
9470	312	18	Arise, go down to meet Ahab king of Israel, which is in Samaria: behold, he is in the vineyard of Naboth, whither he is gone down to possess it.
9471	312	19	And thou shalt speak unto him, saying, Thus saith the LORD, Hast thou killed, and also taken possession? And thou shalt speak unto him, saying, Thus saith the LORD, In the place where dogs licked the blood of Naboth shall dogs lick thy blood, even thine.
9472	312	20	And Ahab said to Elijah, Hast thou found me, O mine enemy? And he answered, I have found thee: because thou hast sold thyself to work evil in the sight of the LORD.
9473	312	21	Behold, I will bring evil upon thee, and will take away thy posterity, and will cut off from Ahab him that pisseth against the wall, and him that is shut up and left in Israel,
9474	312	22	And will make thine house like the house of Jeroboam the son of Nebat, and like the house of Baasha the son of Ahijah, for the provocation wherewith thou hast provoked me to anger, and made Israel to sin.
9475	312	23	And of Jezebel also spake the LORD, saying, The dogs shall eat Jezebel by the wall of Jezreel.
9476	312	24	Him that dieth of Ahab in the city the dogs shall eat; and him that dieth in the field shall the fowls of the air eat.
9477	312	25	But there was none like unto Ahab, which did sell himself to work wickedness in the sight of the LORD, whom Jezebel his wife stirred up.
9478	312	26	And he did very abominably in following idols, according to all things as did the Amorites, whom the LORD cast out before the children of Israel.
9479	312	27	And it came to pass, when Ahab heard those words, that he rent his clothes, and put sackcloth upon his flesh, and fasted, and lay in sackcloth, and went softly.
9480	312	28	And the word of the LORD came to Elijah the Tishbite, saying,
9481	312	29	Seest thou how Ahab humbleth himself before me? because he humbleth himself before me, I will not bring the evil in his days: but in his son's days will I bring the evil upon his house.
9482	313	1	AND they continued three years without war between Syria and Israel.
9483	313	2	And it came to pass in the third year, that Jehoshaphat the king of Judah came down to the king of Israel.
9484	313	3	And the king of Israel said unto his servants, Know ye that Ramoth in Gilead is ours, and we be still, and take it not out of the hand of the king of Syria?
9485	313	4	And he said unto Jehoshaphat, Wilt thou go with me to battle to Ramoth-gilead? And Jehoshaphat said to the king of Israel, I am as thou art, my people as thy people, my horses as thy horses.
9486	313	5	And Jehoshaphat said unto the king of Israel, Enquire, I pray thee, at the word of the LORD to day.
9487	313	6	Then the king of Israel gathered the prophets together, about four hundred men, and said unto them, Shall I go against Ramoth-gilead to battle, or shall I forbear? And they said, Go up; for the Lord shall deliver it into the hand of the king.
9488	313	7	And Jehoshaphat said, Is there not here a prophet of the LORD besides, that we might enquire of him?
9489	313	8	And the king of Israel said unto Jehoshaphat, There is yet one man, Micaiah the son of Imlah, by whom we may enquire of the LORD: but I hate him; for he doth not prophesy good concerning me, but evil. And Jehoshaphat said, Let not the king say so.
9490	313	9	Then the king of Israel called an officer, and said, Hasten hither Micaiah the son of Imlah.
9491	313	10	And the king of Israel and Jehoshaphat the king of Judah sat each on his throne, having put on their robes, in a void place in the entrance of the gate of Samaria; and all the prophets prophesied before them.
9492	313	11	And Zedekiah the son of Chenaanah made him horns of iron: and he said, Thus saith the LORD, With these shalt thou push the Syrians, until thou have consumed them.
9493	313	12	And all the prophets prophesied so, saying, Go up to Ramoth-gilead, and prosper: for the LORD shall deliver it into the king's hand.
9494	313	13	And the messenger that was gone to call Micaiah spake unto him, saying, Behold now, the words of the prophets declare good unto the king with one mouth: let thy word, I pray thee, be like the word of one of them, and speak that which is good.
9495	313	14	And Micaiah said, As the LORD liveth, what the LORD saith unto me, that will I speak.
9496	313	15	So he came to the king. And the king said unto him, Micaiah, shall we go against Ramoth-gilead to battle, or shall we forbear? And he answered him, Go, and prosper: for the LORD shall deliver it into the hand of the king.
9497	313	16	And the king said unto him, How many times shall I adjure thee that thou tell me nothing but that which is true in the name of the LORD?
9498	313	17	And he said, I saw all Israel scattered upon the hills, as sheep that have not a shepherd: and the LORD said, These have no master: let them return every man to his house in peace.
9499	313	18	And the king of Israel said unto Jehoshaphat, Did I not tell thee that he would prophesy no good concerning me, but evil?
9500	313	19	And he said, Hear thou therefore the word of the LORD: I saw the LORD sitting on his throne, and all the host of heaven standing by him on his right hand and on his left.
9501	313	20	And the LORD said, Who shall persuade Ahab, that he may go up and fall at Ramoth-gilead? And one said on this manner, and another said on that manner.
9502	313	21	And there came forth a spirit, and stood before the LORD, and said, I will persuade him.
9503	313	22	And the LORD said unto him, Wherewith? And he said, I will go forth, and I will be a lying spirit in the mouth of all his prophets. And he said, Thou shalt persuade him, and prevail also: go forth, and do so.
9504	313	23	Now therefore, behold, the LORD hath put a lying spirit in the mouth of all these thy prophets, and the LORD hath spoken evil concerning thee.
9505	313	24	But Zedekiah the son of Chenaanah went near, and smote Micaiah on the cheek, and said, Which way went the Spirit of the LORD from me to speak unto thee?
9506	313	25	And Micaiah said, Behold, thou shalt see in that day, when thou shalt go into an inner chamber to hide thyself.
9507	313	26	And the king of Israel said, Take Micaiah, and carry him back unto Amon the governor of the city, and to Joash the king's son;
9508	313	27	And say, Thus saith the king, Put this fellow in the prison, and feed him with bread of affliction and with water of affliction, until I come in peace.
9509	313	28	And Micaiah said, If thou return at all in peace, the LORD hath not spoken by me. And he said, Hearken, O people, every one of you.
9510	313	29	So the king of Israel and Jehoshaphat the king of Judah went up to Ramoth-gilead.
9511	313	30	And the king of Israel said unto Jehoshaphat, I will disguise myself, and enter into the battle; but put thou on thy robes. And the king of Israel disguised himself, and went into the battle.
9512	313	31	But the king of Syria commanded his thirty and two captains that had rule over his chariots, saying, Fight neither with small nor great, save only with the king of Israel.
9513	313	32	And it came to pass, when the captains of the chariots saw Jehoshaphat, that they said, Surely it is the king of Israel. And they turned aside to fight against him: and Jehoshaphat cried out.
9514	313	33	And it came to pass, when the captains of the chariots perceived that it was not the king of Israel, that they turned back from pursuing him.
9515	313	34	And a certain man drew a bow at a venture, and smote the king of Israel between the joints of the harness: wherefore he said unto the driver of his chariot, Turn thine hand, and carry me out of the host; for I am wounded.
9516	313	35	And the battle increased that day: and the king was stayed up in his chariot against the Syrians, and died at even: and the blood ran out of the wound into the midst of the chariot.
9517	313	36	And there went a proclamation throughout the host about the going down of the sun, saying, Every man to his city, and every man to his own country.
9518	313	37	So the king died, and was brought to Samaria; and they buried the king in Samaria.
9519	313	38	And one washed the chariot in the pool of Samaria; and the dogs licked up his blood; and they washed his armour; according unto the word of the LORD which he spake.
9520	313	39	Now the rest of the acts of Ahab, and all that he did, and the ivory house which he made, and all the cities that he built, are they not written in the book of the chronicles of the kings of Israel?
9521	313	40	So Ahab slept with his fathers; and Ahaziah his son reigned in his stead.
9522	313	41	And Jehoshaphat the son of Asa began to reign over Judah in the fourth year of Ahab king of Israel.
9523	313	42	Jehoshaphat was thirty and five years old when he began to reign; and he reigned twenty and five years in Jerusalem. And his mother's name was Azubah the daughter of Shilhi.
9524	313	43	And he walked in all the ways of Asa his father; he turned not aside from it, doing that which was right in the eyes of the LORD: nevertheless the high places were not taken away; for the people offered and burnt incense yet in the high places.
9525	313	44	And Jehoshaphat made peace with the king of Israel.
9526	313	45	Now the rest of the acts of Jehoshaphat, and his might that he shewed, and how he warred, are they not written in the book of the chronicles of the kings of Judah?
9527	313	46	And the remnant of the sodomites, which remained in the days of his father Asa, he took out of the land.
9528	313	47	There was then no king in Edom: a deputy was king.
9529	313	48	Jehoshaphat made ships of Tharshish to go to Ophir for gold: but they went not; for the ships were broken at Ezion-geber.
9530	313	49	Then said Ahaziah the son of Ahab unto Jehoshaphat, Let my servants go with thy servants in the ships. But Jehoshaphat would not.
9531	313	50	And Jehoshaphat slept with his fathers, and was buried with his fathers in the city of David his father: and Jehoram his son reigned in his stead.
9532	313	51	Ahaziah the son of Ahab began to reign over Israel in Samaria the seventeenth year of Jehoshaphat king of Judah, and reigned two years over Israel.
9533	313	52	And he did evil in the sight of the LORD, and walked in the way of his father, and in the way of his mother, and in the way of Jeroboam the son of Nebat, who made Israel to sin:
9534	313	53	For he served Baal, and worshipped him, and provoked to anger the LORD God of Israel, according to all that his father had done.
9535	314	1	THEN Moab rebelled against Israel after the death of Ahab.
9536	314	2	And Ahaziah fell down through a lattice in his upper chamber that was in Samaria, and was sick: and he sent messengers, and said unto them, Go, enquire of Baal-zebub the god of Ekron whether I shall recover of this disease.
9537	314	3	But the angel of the LORD said to Elijah the Tishbite, Arise, go up to meet the messengers of the king of Samaria, and say unto them, Is it not because there is not a God in Israel, that ye go to enquire of Baal-zebub the god of Ekron?
9538	314	4	Now therefore thus saith the LORD, Thou shalt not come down from that bed on which thou art gone up, but shalt surely die. And Elijah departed.
9539	314	5	And when the messengers turned back unto him, he said unto them, Why are ye now turned back?
9540	314	6	And they said unto him, There came a man up to meet us, and said unto us, Go, turn again unto the king that sent you, and say unto him, Thus saith the LORD, Is it not because there is not a God in Israel, that thou sendest to enquire of Baal-zebub the god of Ekron? therefore thou shalt not come down from that bed on which thou art gone up, but shalt surely die.
9541	314	7	And he said unto them, What manner of man was he which came up to meet you, and told you these words?
9542	314	8	And they answered him, He was an hairy man, and girt with a girdle of leather about his loins. And he said, It is Elijah the Tishbite.
9543	314	9	Then the king sent unto him a captain of fifty with his fifty. And he went up to him: and, behold, he sat on the top of an hill. And he spake unto him, Thou man of God, the king hath said, Come down.
9544	314	10	And Elijah answered and said to the captain of fifty, If I be a man of God, then let fire come down from heaven, and consume thee and thy fifty. And there came down fire from heaven, and consumed him and his fifty.
9545	314	11	Again also he sent unto him another captain of fifty with his fifty. And he answered and said unto him, O man of God, thus hath the king said, Come down quickly.
9546	314	12	And Elijah answered and said unto them, If I be a man of God, let fire come down from heaven, and consume thee and thy fifty. And the fire of God came down from heaven, and consumed him and his fifty.
9547	314	13	And he sent again a captain of the third fifty with his fifty. And the third captain of fifty went up, and came and fell on his knees before Elijah, and besought him, and said unto him, O man of God, I pray thee, let my life, and the life of these fifty thy servants, be precious in thy sight.
9548	314	14	Behold, there came fire down from heaven, and burnt up the two captains of the former fifties with their fifties: therefore let my life now be precious in thy sight.
9549	314	15	And the angel of the LORD said unto Elijah, Go down with him: be not afraid of him. And he arose, and went down with him unto the king.
9550	314	16	And he said unto him, Thus saith the LORD, Forasmuch as thou hast sent messengers to enquire of Baal-zebub the god of Ekron, is it not because there is no God in Israel to enquire of his word? therefore thou shalt not come down off that bed on which thou art gone up, but shalt surely die.
9551	314	17	So he died according to the word of the LORD which Elijah had spoken. And Jehoram reigned in his stead in the second year of Jehoram the son of Jehoshaphat king of Judah; because he had no son.
9552	314	18	Now the rest of the acts of Ahaziah which he did, are they not written in the book of the chronicles of the kings of Israel?
9553	315	1	AND it came to pass, when the LORD would take up Elijah into heaven by a whirlwind, that Elijah went with Elisha from Gilgal.
9554	315	2	And Elijah said unto Elisha, Tarry here, I pray thee; for the LORD hath sent me to Beth-el. And Elisha said unto him, As the LORD liveth, and as thy soul liveth, I will not leave thee. So they went down to Beth-el.
9555	315	3	And the sons of the prophets that were at Beth-el came forth to Elisha, and said unto him, Knowest thou that the LORD will take away thy master from thy head to day? And he said, Yea, I know it; hold ye your peace.
9556	315	4	And Elijah said unto him, Elisha, tarry here, I pray thee; for the LORD hath sent me to Jericho. And he said, As the LORD liveth, and as thy soul liveth, I will not leave thee. So they came to Jericho.
9557	315	5	And the sons of the prophets that were at Jericho came to Elisha, and said unto him, Knowest thou that the LORD will take away thy master from thy head to day? And he answered, Yea, I know it; hold ye your peace.
9558	315	6	And Elijah said unto him, Tarry, I pray thee, here; for the LORD hath sent me to Jordan. And he said, As the LORD liveth, and as thy soul liveth, I will not leave thee. And they two went on.
9559	315	7	And fifty men of the sons of the prophets went, and stood to view afar off: and they two stood by Jordan.
9560	315	8	And Elijah took his mantle, and wrapped it together, and smote the waters, and they were divided hither and thither, so that they two went over on dry ground.
9561	315	9	And it came to pass, when they were gone over, that Elijah said unto Elisha, Ask what I shall do for thee, before I be taken away from thee. And Elisha said, I pray thee, let a double portion of thy spirit be upon me.
9562	315	10	And he said, Thou hast asked a hard thing: nevertheless, if thou see me when I am taken from thee, it shall be so unto thee; but if not, it shall not be so.
9563	315	11	And it came to pass, as they still went on, and talked, that, behold, there appeared a chariot of fire, and horses of fire, and parted them both asunder; and Elijah went up by a whirlwind into heaven.
9564	315	12	And Elisha saw it, and he cried, My father, my father, the chariot of Israel, and the horsemen thereof. And he saw him no more: and he took hold of his own clothes, and rent them in two pieces.
9565	315	13	He took up also the mantle of Elijah that fell from him, and went back, and stood by the bank of Jordan;
9566	315	14	And he took the mantle of Elijah that fell from him, and smote the waters, and said, Where is the LORD God of Elijah? and when he also had smitten the waters, they parted hither and thither: and Elisha went over.
9567	315	15	And when the sons of the prophets which were to view at Jericho saw him, they said, The spirit of Elijah doth rest on Elisha. And they came to meet him, and bowed themselves to the ground before him.
9568	315	16	And they said unto him, Behold now, there be with thy servants fifty strong men; let them go, we pray thee, and seek thy master: lest peradventure the Spirit of the LORD hath taken him up, and cast him upon some mountain, or into some valley. And he said, Ye shall not send.
9569	315	17	And when they urged him till he was ashamed, he said, Send. They sent therefore fifty men; and they sought three days, but found him not.
9570	315	18	And when they came again to him, (for he tarried at Jericho,) he said unto them, Did I not say unto you, Go not?
9571	315	19	And the men of the city said unto Elisha, Behold, I pray thee, the situation of this city is pleasant, as my lord seeth: but the water is naught, and the ground barren.
9572	315	20	And he said, Bring me a new cruse, and put salt therein. And they brought it to him.
9573	315	21	And he went forth unto the spring of the waters, and cast the salt in there, and said, Thus saith the LORD, I have healed these waters; there shall not be from thence any more death or barren land.
9574	315	22	So the waters were healed unto this day, according to the saying of Elisha which he spake.
9575	315	23	And he went up from thence unto Beth-el: and as he was going up by the way, there came forth little children out of the city, and mocked him, and said unto him, Go up, thou bald head; go up, thou bald head.
9576	315	24	And he turned back, and looked on them, and cursed them in the name of the LORD. And there came forth two she bears out of the wood, and tare forty and two children of them.
9577	315	25	And he went from thence to mount Carmel, and from thence he returned to Samaria.
9578	316	1	NOW Jehoram the son of Ahab began to reign over Israel in Samaria the eighteenth year of Jehoshaphat king of Judah, and reigned twelve years.
9579	316	2	And he wrought evil in the sight of the LORD; but not like his father, and like his mother: for he put away the image of Baal that his father had made.
9580	316	3	Nevertheless he cleaved unto the sins of Jeroboam the son of Nebat, which made Israel to sin; he departed not therefrom.
9581	316	4	And Mesha king of Moab was a sheepmaster, and rendered unto the king of Israel an hundred thousand lambs, and an hundred thousand rams, with the wool.
9582	316	5	But it came to pass, when Ahab was dead, that the king of Moab rebelled against the king of Israel.
9583	316	6	And king Jehoram went out of Samaria the same time, and numbered all Israel.
9584	316	7	And he went and sent to Jehoshaphat the king of Judah, saying, The king of Moab hath rebelled against me: wilt thou go with me against Moab to battle? And he said, I will go up: I am as thou art, my people as thy people, and my horses as thy horses.
9585	316	8	And he said, Which way shall we go up? And he answered, The way through the wilderness of Edom.
9586	316	9	So the king of Israel went, and the king of Judah, and the king of Edom: and they fetched a compass of seven days' journey: and there was no water for the host, and for the cattle that followed them.
9587	316	10	And the king of Israel said, Alas! that the LORD hath called these three kings together, to deliver them into the hand of Moab!
9588	316	11	But Jehoshaphat said, Is there not here a prophet of the LORD, that we may enquire of the LORD by him? And one of the king of Israel's servants answered and said, Here is Elisha the son of Shaphat, which poured water on the hands of Elijah.
9589	316	12	And Jehoshaphat said, The word of the LORD is with him. So the king of Israel and Jehoshaphat and the king of Edom went down to him.
9590	316	13	And Elisha said unto the king of Israel, What have I to do with thee? get thee to the prophets of thy father, and to the prophets of thy mother. And the king of Israel said unto him, Nay: for the LORD hath called these three kings together, to deliver them into the hand of Moab.
9591	316	14	And Elisha said, As the LORD of hosts liveth, before whom I stand, surely, were it not that I regard the presence of Jehoshaphat the king of Judah, I would not look toward thee, nor see thee.
9592	316	15	But now bring me a minstrel. And it came to pass, when the minstrel played, that the hand of the LORD came upon him.
9593	316	16	And he said, Thus saith the LORD, Make this valley full of ditches.
9594	316	17	For thus saith the LORD, Ye shall not see wind, neither shall ye see rain; yet that valley shall be filled with water, that ye may drink, both ye, and your cattle, and your beasts.
9595	316	18	And this is but a light thing in the sight of the LORD: he will deliver the Moabites also into your hand.
9596	316	19	And ye shall smite every fenced city, and every choice city, and shall fell every good tree, and stop all wells of water, and mar every good piece of land with stones.
9597	316	20	And it came to pass in the morning, when the meat offering was offered, that, behold, there came water by the way of Edom, and the country was filled with water.
9598	316	21	And when all the Moabites heard that the kings were come up to fight against them, they gathered all that were able to put on armour, and upward, and stood in the border.
9599	316	22	And they rose up early in the morning, and the sun shone upon the water, and the Moabites saw the water on the other side as red as blood:
9600	316	23	And they said, This is blood: the kings are surely slain, and they have smitten one another: now therefore, Moab, to the spoil.
9601	316	24	And when they came to the camp of Israel, the Israelites rose up and smote the Moabites, so that they fled before them: but they went forward smiting the Moabites, even in their country.
9602	316	25	And they beat down the cities, and on every good piece of land cast every man his stone, and filled it; and they stopped all the wells of water, and felled all the good trees: only in Kir-haraseth left they the stones thereof; howbeit the slingers went about it, and smote it.
9603	316	26	And when the king of Moab saw that the battle was too sore for him, he took with him seven hundred men that drew swords, to break through even unto the king of Edom: but they could not.
9604	316	27	Then he took his eldest son that should have reigned in his stead, and offered him for a burnt offering upon the wall. And there was great indignation against Israel: and they departed from him, and returned to their own land.
9605	317	1	NOW there cried a certain woman of the wives of the sons of the prophets unto Elisha, saying, Thy servant my husband is dead; and thou knowest that thy servant did fear the LORD: and the creditor is come to take unto him my two sons to be bondmen.
9606	317	2	And Elisha said unto her, What shall I do for thee? tell me, what hast thou in the house? And she said, Thine handmaid hath not any thing in the house, save a pot of oil.
9607	317	3	Then he said, Go, borrow thee vessels abroad of all thy neighbours, even empty vessels; borrow not a few.
9608	317	4	And when thou art come in, thou shalt shut the door upon thee and upon thy sons, and shalt pour out into all those vessels, and thou shalt set aside that which is full.
9609	317	5	So she went from him, and shut the door upon her and upon her sons, who brought the vessels to her; and she poured out.
9610	317	6	And it came to pass, when the vessels were full, that she said unto her son, Bring me yet a vessel. And he said unto her, There is not a vessel more. And the oil stayed.
9611	317	7	Then she came and told the man of God. And he said, Go, sell the oil, and pay thy debt, and live thou and thy children of the rest.
9612	317	8	And it fell on a day, that Elisha passed to Shunem, where was a great woman; and she constrained him to eat bread. And so it was, that as oft as he passed by, he turned in thither to eat bread.
9613	317	9	And she said unto her husband, Behold now, I perceive that this is an holy man of God, which passeth by us continually.
9614	317	10	Let us make a little chamber, I pray thee, on the wall; and let us set for him there a bed, and a table, and a stool, and a candlestick: and it shall be, when he cometh to us, that he shall turn in thither.
9615	317	11	And it fell on a day, that he came thither, and he turned into the chamber, and lay there.
9616	317	12	And he said to Gehazi his servant, Call this Shunammite. And when he had called her, she stood before him.
9617	317	13	And he said unto him, Say now unto her, Behold, thou hast been careful for us with all this care; what is to be done for thee? wouldest thou be spoken for to the king, or to the captain of the host? And she answered, I dwell among mine own people.
9618	317	14	And he said, What then is to be done for her? And Gehazi answered, Verily she hath no child, and her husband is old.
9619	317	15	And he said, Call her. And when he had called her, she stood in the door.
9620	317	16	And he said, About this season, according to the time of life, thou shalt embrace a son. And she said, Nay, my lord, thou man of God, do not lie unto thine handmaid.
9621	317	17	And the woman conceived, and bare a son at that season that Elisha had said unto her, according to the time of life.
9622	317	18	And when the child was grown, it fell on a day, that he went out to his father to the reapers.
9623	317	19	And he said unto his father, My head, my head. And he said to a lad, Carry him to his mother.
9624	317	20	And when he had taken him, and brought him to his mother, he sat on her knees till noon, and then died.
9625	317	21	And she went up, and laid him on the bed of the man of God, and shut the door upon him, and went out.
9626	317	22	And she called unto her husband, and said, Send me, I pray thee, one of the young men, and one of the asses, that I may run to the man of God, and come again.
9627	317	23	And he said, Wherefore wilt thou go to him to day? it is neither new moon, nor sabbath. And she said, It shall be well.
9628	317	24	Then she saddled an ass, and said to her servant, Drive, and go forward; slack not thy riding for me, except I bid thee.
9629	317	25	So she went and came unto the man of God to mount Carmel. And it came to pass, when the man of God saw her afar off, that he said to Gehazi his servant, Behold, yonder is that Shunammite:
9630	317	26	Run now, I pray thee, to meet her, and say unto her, Is it well with thee? is it well with thy husband? is it well with the child? And she answered, It is well.
9631	317	27	And when she came to the man of God to the hill, she caught him by the feet: but Gehazi came near to thrust her away. And the man of God said, Let her alone; for her soul is vexed within her: and the LORD hath hid it from me, and hath not told me.
9632	317	28	Then she said, Did I desire a son of my lord? did I not say, Do not deceive me?
9633	317	29	Then he said to Gehazi, Gird up thy loins, and take my staff in thine hand, and go thy way: if thou meet any man, salute him not; and if any salute thee, answer him not again: and lay my staff upon the face of the child.
9634	317	30	And the mother of the child said, As the LORD liveth, and as thy soul liveth, I will not leave thee. And he arose, and followed her.
9635	317	31	And Gehazi passed on before them, and laid the staff upon the face of the child; but there was neither voice, nor hearing. Wherefore he went again to meet him, and told him, saying, The child is not awaked.
9636	317	32	And when Elisha was come into the house, behold, the child was dead, and laid upon his bed.
9637	317	33	He went in therefore, and shut the door upon them twain, and prayed unto the LORD.
9638	317	34	And he went up, and lay upon the child, and put his mouth upon his mouth, and his eyes upon his eyes, and his hands upon his hands: and he stretched himself upon the child; and the flesh of the child waxed warm.
9639	317	35	Then he returned, and walked in the house to and fro; and went up, and stretched himself upon him: and the child sneezed seven times, and the child opened his eyes.
9640	317	36	And he called Gehazi, and said, Call this Shunammite. So he called her. And when she was come in unto him, he said, Take up thy son.
9641	317	37	Then she went in, and fell at his feet, and bowed herself to the ground, and took up her son, and went out.
9642	317	38	And Elisha came again to Gilgal: and there was a dearth in the land; and the sons of the prophets were sitting before him: and he said unto his servant, Set on the great pot, and seethe pottage for the sons of the prophets.
9643	317	39	And one went out into the field to gather herbs, and found a wild vine, and gathered thereof wild gourds his lap full, and came and shred them into the pot of pottage: for they knew them not.
9644	317	40	So they poured out for the men to eat. And it came to pass, as they were eating of the pottage, that they cried out, and said, O thou man of God, there is death in the pot. And they could not eat thereof.
9645	317	41	But he said, Then bring meal. And he cast it into the pot; and he said, Pour out for the people, that they may eat. And there was no harm in the pot.
9646	317	42	And there came a man from Baal-shalisha, and brought the man of God bread of the firstfruits, twenty loaves of barley, and full ears of corn in the husk thereof. And he said, Give unto the people, that they may eat.
9647	317	43	And his servitor said, What, should I set this before an hundred men? He said again, Give the people, that they may eat: for thus saith the LORD, They shall eat, and shall leave thereof.
9648	317	44	So he set it before them, and they did eat, and left thereof, according to the word of the LORD.
9649	318	1	NOW Naaman, captain of the host of the king of Syria, was a great man with his master, and honourable, because by him the LORD had given deliverance unto Syria: he was also a mighty man in valour, but he was a leper.
9650	318	2	And the Syrians had gone out by companies, and had brought away captive out of the land of Israel a little maid; and she waited on Naaman's wife.
9651	318	3	And she said unto her mistress, Would God my lord were with the prophet that is in Samaria! for he would recover him of his leprosy.
9652	318	4	And one went in, and told his lord, saying, Thus and thus said the maid that is of the land of Israel.
9653	318	5	And the king of Syria said, Go to, go, and I will send a letter unto the king of Israel. And he departed, and took with him ten talents of silver, and six thousand pieces of gold, and ten changes of raiment.
9654	318	6	And he brought the letter to the king of Israel, saying, Now when this letter is come unto thee, behold, I have therewith sent Naaman my servant to thee, that thou mayest recover him of his leprosy.
9655	318	7	And it came to pass, when the king of Israel had read the letter, that he rent his clothes, and said, Am I God, to kill and to make alive, that this man doth send unto me to recover a man of his leprosy? wherefore consider, I pray you, and see how he seeketh a quarrel against me.
9656	318	8	And it was so, when Elisha the man of God had heard that the king of Israel had rent his clothes, that he sent to the king, saying, Wherefore hast thou rent thy clothes? let him come now to me, and he shall know that there is a prophet in Israel.
9657	318	9	So Naaman came with his horses and with his chariot, and stood at the door of the house of Elisha.
9658	318	10	And Elisha sent a messenger unto him, saying, Go and wash in Jordan seven times, and thy flesh shall come again to thee, and thou shalt be clean.
9659	318	11	But Naaman was wroth, and went away, and said, Behold, I thought, He will surely come out to me, and stand, and call on the name of the LORD his God, and strike his hand over the place, and recover the leper.
9660	318	12	Are not Abana and Pharpar, rivers of Damascus, better than all the waters of Israel? may I not wash in them, and be clean? So he turned and went away in a rage.
9661	318	13	And his servants came near, and spake unto him, and said, My father, if the prophet had bid thee do some great thing, wouldest thou not have done it? how much rather then, when he saith to thee, Wash, and be clean?
9662	318	14	Then went he down, and dipped himself seven times in Jordan, according to the saying of the man of God: and his flesh came again like unto the flesh of a little child, and he was clean.
9663	318	15	And he returned to the man of God, he and all his company, and came, and stood before him: and he said, Behold, now I know that there is no God in all earth, but in Israel: now therefore, I pray thee, take a blessing of thy servant.
9664	318	16	But he said, As the LORD liveth, before whom I stand, I will receive none. And he urged him to take it; but he refused.
9665	318	17	And Naaman said, Shall there not then, I pray thee, be given to thy servant two mules' burden of earth? for thy servant will henceforth offer neither burnt offering nor sacrifice unto other gods, but unto the LORD.
9666	318	18	In this thing the LORD pardon thy servant, that when my master goeth into the house of Rimmon to worship there, and he leaneth on my hand, and I bow myself in the house of Rimmon: when I bow down myself in the house of Rimmon, the LORD pardon thy servant in this thing.
9667	318	19	And he said unto him, Go in peace. So he departed from him a little way.
9668	318	20	But Gehazi, the servant of Elisha the man of God, said, Behold, my master hath spared Naaman this Syrian, in not receiving at his hands that which he brought: but, as the LORD liveth, I will run after him, and take somewhat of him.
9669	318	21	So Gehazi followed after Naaman. And when Naaman saw him running after him, he lighted down from the chariot to meet him, and said, Is all well?
9670	318	22	And he said, All is well. My master hath sent me, saying, Behold, even now there be come to me from mount Ephraim two young men of the sons of the prophets: give them, I pray thee, a talent of silver, and two changes of garments.
9671	318	23	And Naaman said, Be content, take two talents. And he urged him, and bound two talents of silver in two bags, with two changes of garments, and laid them upon two of his servants; and they bare them before him.
9672	318	24	And when he came to the tower, he took them from their hand, and bestowed them in the house: and he let the men go, and they departed.
9673	318	25	But he went in, and stood before his master. And Elisha said unto him, Whence comest thou, Gehazi? And he said, Thy servant went no whither.
9674	318	26	And he said unto him, Went not mine heart with thee, when the man turned again from his chariot to meet thee? Is it a time to receive money, and to receive garments, and oliveyards, and vineyards, and sheep, and oxen, and menservants, and maidservants?
9675	318	27	The leprosy therefore of Naaman shall cleave unto thee, and unto thy seed for ever. And he went out from his presence a leper as white as snow.
9676	319	1	AND the sons of the prophets said unto Elisha, Behold now, the place where we dwell with thee is too strait for us.
9677	319	2	Let us go, we pray thee, unto Jordan, and take thence every man a beam, and let us make us a place there, where we may dwell. And he answered, Go ye.
9678	319	3	And one said, Be content, I pray thee, and go with thy servants. And he answered, I will go.
9679	319	4	So he went with them. And when they came to Jordan, they cut down wood.
9680	319	5	But as one was felling a beam, the axe head fell into the water: and he cried, and said, Alas, master! for it was borrowed.
9681	319	6	And the man of God said, Where fell it? And he shewed him the place. And he cut down a stick, and cast it in thither; and the iron did swim.
9682	319	7	Therefore said he, Take it up to thee. And he put out his hand, and took it.
9683	319	8	Then the king of Syria warred against Israel, and took counsel with his servants, saying, In such and such a place shall be my camp.
9684	319	9	And the man of God sent unto the king of Israel, saying, Beware that thou pass not such a place; for thither the Syrians are come down.
9685	319	10	And the king of Israel sent to the place which the man of God told him and warned him of, and saved himself there, not once nor twice.
9686	319	11	Therefore the heart of the king of Syria was sore troubled for this thing; and he called his servants, and said unto them, Will ye not shew me which of us is for the king of Israel?
9687	319	12	And one of his servants said, None, my lord, O king: but Elisha, the prophet that is in Israel, telleth the king of Israel the words that thou speakest in thy bedchamber.
9688	319	13	And he said, Go and spy where he is, that I may send and fetch him. And it was told him, saying, Behold, he is in Dothan.
9689	319	14	Therefore sent he thither horses, and chariots, and a great host: and they came by night, and compassed the city about.
9690	319	15	And when the servant of the man of God was risen early, and gone forth, behold, an host compassed the city both with horses and chariots. And his servant said unto him, Alas, my master! how shall we do?
9691	319	16	And he answered, Fear not: for they that be with us are more than they that be with them.
9692	319	17	And Elisha prayed, and said, LORD, I pray thee, open his eyes, that he may see. And the LORD opened the eyes of the young man; and he saw: and, behold, the mountain was full of horses and chariots of fire round about Elisha.
9693	319	18	And when they came down to him, Elisha prayed unto the LORD, and said, Smite this people, I pray thee, with blindness. And he smote them with blindness according to the word of Elisha.
9694	319	19	And Elisha said unto them, This is not the way, neither is this the city: follow me, and I will bring you to the man whom ye seek. But he led them to Samaria.
9695	319	20	And it came to pass, when they were come into Samaria, that Elisha said, LORD, open the eyes of these men, that they may see. And the LORD opened their eyes, and they saw; and, behold, they were in the midst of Samaria.
9696	319	21	And the king of Israel said unto Elisha, when he saw them, My father, shall I smite them? shall I smite them?
9697	319	22	And he answered, Thou shalt not smite them: wouldest thou smite those whom thou hast taken captive with thy sword and with thy bow? set bread and water before them, that they may eat and drink, and go to their master.
9698	319	23	And he prepared great provision for them: and when they had eaten and drunk, he sent them away, and they went to their master. So the bands of Syria came no more into the land of Israel.
9699	319	24	And it came to pass after this, that Ben-hadad king of Syria gathered all his host, and went up, and besieged Samaria.
9700	319	25	And there was a great famine in Samaria: and, behold, they besieged it, until an ass's head was sold for fourscore pieces of silver, and the fourth part of a cab of dove's dung for five pieces of silver.
9701	319	26	And as the king of Israel was passing by upon the wall, there cried a woman unto him, saying, Help, my lord, O king.
9702	319	27	And he said, If the LORD do not help thee, whence shall I help thee? out of the barnfloor, or out of the winepress?
9703	319	28	And the king said unto her, What aileth thee? And she answered, This woman said unto me, Give thy son, that we may eat him to day, and we will eat my son to morrow.
9704	319	29	So we boiled my son, and did eat him: and I said unto her on the next day, Give thy son, that we may eat him: and she hath hid her son.
9705	319	30	And it came to pass, when the king heard the words of the woman, that he rent his clothes; and he passed by upon the wall, and the people looked, and, behold, he had sackcloth within upon his flesh.
9706	319	31	Then he said, God do so and more also to me, if the head of Elisha the son of Shaphat shall stand on him this day.
9707	319	32	But Elisha sat in his house, and the elders sat with him; and the king sent a man from before him: but ere the messenger came to him, he said to the elders, See ye how this son of a murderer hath sent to take away mine head? look, when the messenger cometh, shut the door, and hold him fast at the door: is not the sound of his master's feet behind him?
9708	319	33	And while he yet talked with them, behold, the messenger came down unto him: and he said, Behold, this evil is of the LORD; what should I wait for the LORD any longer?
9709	320	1	THEN Elisha said, Hear ye the word of the LORD; Thus saith the LORD, To morrow about this time shall a measure of fine flour be sold for a shekel, and two measures of barley for a shekel, in the gate of Samaria.
9710	320	2	Then a lord on whose hand the king leaned answered the man of God, and said, Behold, if the LORD would make windows in heaven, might this thing be? And he said, Behold, thou shalt see it with thine eyes, but shalt not eat thereof.
9711	320	3	And there were four leprous men at the entering in of the gate: and they said one to another, Why sit we here until we die?
9712	320	4	If we say, We will enter into the city, then the famine is in the city, and we shall die there: and if we sit still here, we die also. Now therefore come, and let us fall unto the host of the Syrians: if they save us alive, we shall live; and if they kill us, we shall but die.
9713	320	5	And they rose up in the twilight, to go unto the camp of the Syrians: and when they were come to the uttermost part of the camp of Syria, behold, there was no man there.
9714	320	6	For the Lord had made the host of the Syrians to hear a noise of chariots, and a noise of horses, even the noise of a great host: and they said one to another, Lo, the king of Israel hath hired against us the kings of the Hittites, and the kings of the Egyptians, to come upon us.
9715	320	7	Wherefore they arose and fled in the twilight, and left their tents, and their horses, and their asses, even the camp as it was, and fled for their life.
9716	320	8	And when these lepers came to the uttermost part of the camp, they went into one tent, and did eat and drink, and carried thence silver, and gold, and raiment, and went and hid it; and came again, and entered into another tent, and carried thence also, and went and hid it.
9717	320	9	Then they said one to another, We do not well: this day is a day of good tidings, and we hold our peace: if we tarry till the morning light, some mischief will come upon us: now therefore come, that we may go and tell the king's household.
9718	320	10	So they came and called unto the porter of the city: and they told them, saying, We came to the camp of the Syrians, and, behold, there was no man there, neither voice of man, but horses tied, and asses tied, and the tents as they were.
9719	320	11	And he called the porters; and they told it to the king's house within.
9720	320	12	And the king arose in the night, and said unto his servants, I will now shew you what the Syrians have done to us. They know that we be hungry; therefore are they gone out of the camp to hide themselves in the field, saying, When they come out of the city, we shall catch them alive, and get into the city.
9721	320	13	And one of his servants answered and said, Let some take, I pray thee, five of the horses that remain, which are left in the city, (behold, they are as all the multitude of Israel that are left in it: behold, I say, they are even as all the multitude of the Israelites that are consumed:) and let us send and see.
9722	320	14	They took therefore two chariot horses; and the king sent after the host of the Syrians, saying, Go and see.
9723	320	15	And they went after them unto Jordan: and, lo, all the way was full of garments and vessels, which the Syrians had cast away in their haste. And the messengers returned, and told the king.
9724	320	16	And the people went out, and spoiled the tents of the Syrians. So a measure of fine flour was sold for a shekel, and two measures of barley for a shekel, according to the word of the LORD.
9725	320	17	And the king appointed the lord on whose hand he leaned to have the charge of the gate: and the people trode upon him in the gate, and he died, as the man of God had said, who spake when the king came down to him.
9726	320	18	And it came to pass as the man of God had spoken to the king, saying, Two measures of barley for a shekel, and a measure of fine flour for a shekel, shall be to morrow about this time in the gate of Samaria:
9727	320	19	And that lord answered the man of God, and said, Now, behold, if the LORD should make windows in heaven, might such a thing be? And he said, Behold, thou shalt see it with thine eyes, but shalt not eat thereof.
9728	320	20	And so it fell out unto him: for the people trode upon him in the gate, and he died.
9729	321	1	THEN spake Elisha unto the woman, whose son he had restored to life, saying, Arise, and go thou and thine household, and sojourn wheresoever thou canst sojourn: for the LORD hath called for a famine; and it shall also come upon the land seven years.
9730	321	2	And the woman arose, and did after the saying of the man of God: and she went with her household, and sojourned in the land of the Philistines seven years.
9731	321	3	And it came to pass at the seven years' end, that the woman returned out of the land of the Philistines: and she went forth to cry unto the king for her house and for her land.
9732	321	4	And the king talked with Gehazi the servant of the man of God, saying, Tell me, I pray thee, all the great things that Elisha hath done.
9733	321	5	And it came to pass, as he was telling the king how he had restored a dead body to life, that, behold, the woman, whose son he had restored to life, cried to the king for her house and for her land. And Gehazi said, My lord, O king, this is the woman, and this is her son, whom Elisha restored to life.
9734	321	6	And when the king asked the woman, she told him. So the king appointed unto her a certain officer, saying, Restore all that was hers, and all the fruits of the field since the day that she left the land, even until now.
9735	321	7	And Elisha came to Damascus; and Ben-hadad the king of Syria was sick; and it was told him, saying, The man of God is come hither.
9736	321	8	And the king said unto Hazael, Take a present in thine hand, and go, meet the man of God, and enquire of the LORD by him, saying, Shall I recover of this disease?
9737	321	9	So Hazael went to meet him, and took a present with him, even of every good thing of Damascus, forty camels' burden, and came and stood before him, and said, Thy son Ben-hadad king of Syria hath sent me to thee, saying, Shall I recover of this disease?
9738	321	10	And Elisha said unto him, Go, say unto him, Thou mayest certainly recover: howbeit the LORD hath shewed me that he shall surely die.
9739	321	11	And he settled his countenance stedfastly, until he was ashamed: and the man of God wept.
9740	321	12	And Hazael said, Why weepeth my lord? And he answered, Because I know the evil that thou wilt do unto the children of Israel: their strong holds wilt thou set on fire, and their young men wilt thou slay with the sword, and wilt dash their children, and rip up their women with child.
9741	321	13	And Hazael said, But what, is thy servant a dog, that he should do this great thing? And Elisha answered, The LORD hath shewed me that thou shalt be king over Syria.
9742	321	14	So he departed from Elisha, and came to his master; who said to him, What said Elisha to thee? And he answered, He told me that thou shouldest surely recover.
9743	321	15	And it came to pass on the morrow, that he took a thick cloth, and dipped it in water, and spread it on his face, so that he died: and Hazael reigned in his stead.
9744	321	16	And in the fifth year of Joram the son of Ahab king of Israel, Jehoshaphat being then king of Judah, Jehoram the son of Jehoshaphat king of Judah began to reign.
9745	321	17	Thirty and two years old was he when he began to reign; and he reigned eight years in Jerusalem.
9746	321	18	And he walked in the way of the kings of Israel, as did the house of Ahab: for the daughter of Ahab was his wife: and he did evil in the sight of the LORD.
9747	321	19	Yet the LORD would not destroy Judah for David his servant's sake, as he promised him to give him alway a light, and to his children.
9748	321	20	In his days Edom revolted from under the hand of Judah, and made a king over themselves.
9749	321	21	So Joram went over to Zair, and all the chariots with him: and he rose by night, and smote the Edomites which compassed him about, and the captains of the chariots: and the people fled into their tents.
9750	321	22	Yet Edom revolted from under the hand of Judah unto this day. Then Libnah revolted at the same time.
9751	321	23	And the rest of the acts of Joram, and all that he did, are they not written in the book of the chronicles of the kings of Judah?
9752	321	24	And Joram slept with his fathers, and was buried with his fathers in the city of David: and Ahaziah his son reigned in his stead.
9753	321	25	In the twelfth year of Joram the son of Ahab king of Israel did Ahaziah the son of Jehoram king of Judah begin to reign.
9754	321	26	Two and twenty years old was Ahaziah when he began to reign; and he reigned one year in Jerusalem. And his mother's name was Athaliah, the daughter of Omri king of Israel.
9755	321	27	And he walked in the way of the house of Ahab, and did evil in the sight of the LORD, as did the house of Ahab: for he was the son in law of the house of Ahab.
9756	321	28	And he went with Joram the son of Ahab to the war against Hazael king of Syria in Ramoth-gilead; and the Syrians wounded Joram.
9757	321	29	And king Joram went back to be healed in Jezreel of the wounds which the Syrians had given him at Ramah, when he fought against Hazael king of Syria. And Ahaziah the son of Jehoram king of Judah went down to see Joram the son of Ahab in Jezreel, because he was sick.
9758	322	1	AND Elisha the prophet called one of the children of the prophets, and said unto him, Gird up thy loins, and take this box of oil in thine hand, and go to Ramoth-gilead:
9759	322	2	And when thou comest thither, look out there Jehu the son of Jehoshaphat the son of Nimshi, and go in, and make him arise up from among his brethren, and carry him to an inner chamber;
9760	322	3	Then take the box of oil, and pour it on his head, and say, Thus saith the LORD, I have anointed thee king over Israel. Then open the door, and flee, and tarry not.
9761	322	4	So the young man, even the young man the prophet, went to Ramoth-gilead.
9762	322	5	And when he came, behold, the captains of the host were sitting; and he said, I have an errand to thee, O captain. And Jehu said, Unto which of all us? And he said, To thee, O captain.
9763	322	6	And he arose, and went into the house; and he poured the oil on his head, and said unto him, Thus saith the LORD God of Israel, I have anointed thee king over the people of the LORD, even over Israel.
9764	322	7	And thou shalt smite the house of Ahab thy master, that I may avenge the blood of my servants the prophets, and the blood of all the servants of the LORD, at the hand of Jezebel.
9765	322	8	For the whole house of Ahab shall perish: and I will cut off from Ahab him that pisseth against the wall, and him that is shut up and left in Israel:
9766	322	9	And I will make the house of Ahab like the house of Jeroboam the son of Nebat, and like the house of Baasha the son of Ahijah:
9767	322	10	And the dogs shall eat Jezebel in the portion of Jezreel, and there shall be none to bury her. And he opened the door, and fled.
9768	322	11	Then Jehu came forth to the servants of his lord: and one said unto him, Is all well? wherefore came this mad fellow to thee? And he said unto them, Ye know the man, and his communication.
9769	322	12	And they said, It is false; tell us now. And he said, Thus and thus spake he to me, saying, Thus saith the LORD, I have anointed thee king over Israel.
9770	322	13	Then they hasted, and took every man his garment, and put it under him on the top of the stairs, and blew with trumpets, saying, Jehu is king.
9771	322	14	So Jehu the son of Jehoshaphat the son of Nimshi conspired against Joram. (Now Joram had kept Ramoth-gilead, he and all Israel, because of Hazael king of Syria.
9772	322	15	But king Joram was returned to be healed in Jezreel of the wounds which the Syrians had given him, when he fought with Hazael king of Syria.) And Jehu said, If it be your minds, then let none go forth nor escape out of the city to go to tell it in Jezreel.
9773	322	16	So Jehu rode in a chariot, and went to Jezreel; for Joram lay there. And Ahaziah king of Judah was come down to see Joram.
9774	322	17	And there stood a watchman on the tower in Jezreel, and he spied the company of Jehu as he came, and said, I see a company. And Joram said, Take an horseman, and send to meet them, and let him say, Is it peace?
9775	322	18	So there went one on horseback to meet him, and said, Thus saith the king, Is it peace? And Jehu said, What hast thou to do with peace? turn thee behind me. And the watchman told, saying, The messenger came to them, but he cometh not again.
9776	322	19	Then he sent out a second on horseback, which came to them, and said, Thus saith the king, Is it peace? And Jehu answered, What hast thou to do with peace? turn thee behind me.
9777	322	20	And the watchman told, saying, He came even unto them, and cometh not again: and the driving is like the driving of Jehu the son of Nimshi; for he driveth furiously.
9778	322	21	And Joram said, Make ready. And his chariot was made ready. And Joram king of Israel and Ahaziah king of Judah went out, each in his chariot, and they went out against Jehu, and met him in the portion of Naboth the Jezreelite.
9779	322	22	And it came to pass, when Joram saw Jehu, that he said, Is it peace, Jehu? And he answered, What peace, so long as the whoredoms of thy mother Jezebel and her witchcrafts are so many?
9780	322	23	And Joram turned his hands, and fled, and said to Ahaziah, There is treachery, O Ahaziah.
9781	322	24	And Jehu drew a bow with his full strength, and smote Jehoram between his arms, and the arrow went out at his heart, and he sunk down in his chariot.
9782	322	25	Then said Jehu to Bidkar his captain, Take up, and cast him in the portion of the field of Naboth the Jezreelite: for remember how that, when I and thou rode together after Ahab his father, the LORD laid this burden upon him;
9783	322	26	Surely I have seen yesterday the blood of Naboth, and the blood of his sons, saith the LORD; and I will requite thee in this plat, saith the LORD. Now therefore take and cast him into the plat of ground, according to the word of the LORD.
9784	322	27	But when Ahaziah the king of Judah saw this, he fled by the way of the garden house. And Jehu followed after him, and said, Smite him also in the chariot. And they did so at the going up to Gur, which is by Ibleam. And he fled to Megiddo, and died there.
9785	322	28	And his servants carried him in a chariot to Jerusalem, and buried him in his sepulchre with his fathers in the city of David.
9786	322	29	And in the eleventh year of Joram the son of Ahab began Ahaziah to reign over Judah.
9787	322	30	And when Jehu was come to Jezreel, Jezebel heard of it; and she painted her face, and tired her head, and looked out at a window.
9788	322	31	And as Jehu entered in at the gate, she said, Had Zimri peace, who slew his master?
9789	322	32	And he lifted up his face to the window, and said, Who is on my side? who? And there looked out to him two or three eunuchs.
9790	322	33	And he said, Throw her down. So they threw her down: and some of her blood was sprinkled on the wall, and on the horses: and he trode her under foot.
9791	322	34	And when he was come in, he did eat and drink, and said, Go, see now this cursed woman, and bury her: for she is a king's daughter.
9792	322	35	And they went to bury her: but they found no more of her than the skull, and the feet, and the palms of her hands.
9793	322	36	Wherefore they came again, and told him. And he said, This is the word of the LORD, which he spake by his servant Elijah the Tishbite, saying, In the portion of Jezreel shall dogs eat the flesh of Jezebel:
9794	322	37	And the carcase of Jezebel shall be as dung upon the face of the field in the portion of Jezreel; so that they shall not say, This is Jezebel.
9795	323	1	AND Ahab had seventy sons in Samaria. And Jehu wrote letters, and sent to Samaria, unto the rulers of Jezreel, to the elders, and to them that brought up Ahab's children, saying,
9796	323	2	Now as soon as this letter cometh to you, seeing your master's sons are with you, and there are with you chariots and horses, a fenced city also, and armour;
9797	323	3	Look even out the best and meetest of your master's sons, and set him on his father's throne, and fight for your master's house.
9798	323	4	But they were exceedingly afraid, and said, Behold, two kings stood not before him: how then shall we stand?
9799	323	5	And he that was over the house, and he that was over the city, the elders also, and the bringers up of the children, sent to Jehu, saying, We are thy servants, and will do all that thou shalt bid us; we will not make any king: do thou that which is good in thine eyes.
9800	323	6	Then he wrote a letter the second time to them, saying, If ye be mine, and if ye will hearken unto my voice, take ye the heads of the men your master's sons, and come to me to Jezreel by to morrow this time. Now the king's sons, being seventy persons, were with the great men of the city, which brought them up.
9801	323	7	And it came to pass, when the letter came to them, that they took the king's sons, and slew seventy persons, and put their heads in baskets, and sent him them to Jezreel.
9802	323	8	And there came a messenger, and told him, saying, They have brought the heads of the king's sons. And he said, Lay ye them in two heaps at the entering in of the gate until the morning.
9803	323	9	And it came to pass in the morning, that he went out, and stood, and said to all the people, Ye be righteous: behold, I conspired against my master, and slew him: but who slew all these?
9804	323	10	Know now that there shall fall unto the earth nothing of the word of the LORD, which the LORD spake concerning the house of Ahab: for the LORD hath done that which he spake by his servant Elijah.
9805	323	11	So Jehu slew all that remained of the house of Ahab in Jezreel, and all his great men, and his kinsfolks, and his priests, until he left him none remaining.
9806	323	12	And he arose and departed, and came to Samaria. And as he was at the shearing house in the way,
9807	323	13	Jehu met with the brethren of Ahaziah king of Judah, and said, Who are ye? And they answered, We are the brethren of Ahaziah; and we go down to salute the children of the king and the children of the queen.
9808	323	14	And he said, Take them alive. And they took them alive, and slew them at the pit of the shearing house, even two and forty men; neither left he any of them.
9809	323	15	And when he was departed thence, he lighted on Jehonadab the son of Rechab coming to meet him: and he saluted him, and said to him, Is thine heart right, as my heart is with thy heart? And Jehonadab answered, It is. If it be, give me thine hand. And he gave him his hand; and he took him up to him into the chariot.
9810	323	16	And he said, Come with me, and see my zeal for the LORD. So they made him ride in his chariot.
9811	323	17	And when he came to Samaria, he slew all that remained unto Ahab in Samaria, till he had destroyed him, according to the saying of the LORD, which he spake to Elijah.
9812	323	18	And Jehu gathered all the people together, and said unto them, Ahab served Baal a little; but Jehu shall serve him much.
9813	323	19	Now therefore call unto me all the prophets of Baal, all his servants, and all his priests; let none be wanting: for I have a great sacrifice to do to Baal; whosoever shall be wanting, he shall not live. But Jehu did it in subtilty, to the intent that he might destroy the worshippers of Baal.
9814	323	20	And Jehu said, Proclaim a solemn assembly for Baal. And they proclaimed it.
9815	323	21	And Jehu sent through all Israel: and all the worshippers of Baal came, so that there was not a man left that came not. And they came into the house of Baal; and the house of Baal was full from one end to another.
9816	323	22	And he said unto him that was over the vestry, Bring forth vestments for all the worshippers of Baal. And he brought them forth vestments.
9817	323	23	And Jehu went, and Jehonadab the son of Rechab, into the house of Baal, and said unto the worshippers of Baal, Search, and look that there be here with you none of the servants of the LORD, but the worshippers of Baal only.
9818	323	24	And when they went in to offer sacrifices and burnt offerings, Jehu appointed fourscore men without, and said, If any of the men whom I have brought into your hands escape, he that letteth him go, his life shall be for the life of him.
9819	323	25	And it came to pass, as soon as he had made an end of offering the burnt offering, that Jehu said to the guard and to the captains, Go in, and slay them; let none come forth. And they smote them with the edge of the sword; and the guard and the captains cast them out, and went to the city of the house of Baal.
9820	323	26	And they brought forth the images out of the house of Baal, and burned them.
9821	323	27	And they brake down the image of Baal, and brake down the house of Baal, and made it a draught house unto this day.
9822	323	28	Thus Jehu destroyed Baal out of Israel.
9823	323	29	Howbeit from the sins of Jeroboam the son of Nebat, who made Israel to sin, Jehu departed not from after them, to wit, the golden calves that were in Beth-el, and that were in Dan.
9824	323	30	And the LORD said unto Jehu, Because thou hast done well in executing that which is right in mine eyes, and hast done unto the house of Ahab according to all that was in mine heart, thy children of the fourth generation shall sit on the throne of Israel.
9825	323	31	But Jehu took no heed to walk in the law of the LORD God of Israel with all his heart: for he departed not from the sins of Jeroboam, which made Israel to sin.
9826	323	32	In those days the LORD began to cut Israel short: and Hazael smote them in all the coasts of Israel;
9827	323	33	From Jordan eastward, all the land of Gilead, the Gadites, and the Reubenites, and the Manassites, from Aroer, which is by the river Arnon, even Gilead and Bashan.
9828	323	34	Now the rest of the acts of Jehu, and all that he did, and all his might, are they not written in the book of the chronicles of the kings of Israel?
9829	323	35	And Jehu slept with his fathers: and they buried him in Samaria. And Jehoahaz his son reigned in his stead.
9830	323	36	And the time that Jehu reigned over Israel in Samaria was twenty and eight years.
9831	324	1	AND when Athaliah the mother of Ahaziah saw that her son was dead, she arose and destroyed all the seed royal.
9832	324	2	But Jehosheba, the daughter of king Joram, sister of Ahaziah, took Joash the son of Ahaziah and stole him from among the king's sons which were slain; and they hid him, even him and his nurse, in the bedchamber from Athaliah, so that he was not slain.
9833	324	3	And he was with her hid in the house of the LORD six years. And Athaliah did reign over the land.
9834	324	4	And the seventh year Jehoiada sent and fetched the rulers over hundreds, with the captains and the guard, and brought them to him into the house of the LORD, and made a covenant with them, and took an oath of them in the house of the LORD, and shewed them the king's son.
9835	324	5	And he commanded them, saying, This is the thing that ye shall do; A third part of you that enter in on the sabbath shall even be keepers of the watch of the king's house;
9836	324	6	And a third part shall be at the gate of Sur; and a third part at the gate behind the guard: so shall ye keep the watch of the house, that it be not broken down.
9837	324	7	And two parts of all you that go forth on the sabbath, even they shall keep the watch of the house of the LORD about the king.
9838	324	8	And ye shall compass the king round about, every man with his weapons in his hand: and he that cometh within the ranges, let him be slain: and be ye with the king as he goeth out and as he cometh in.
9839	324	9	And the captains over the hundreds did according to all things that Jehoiada the priest commanded: and they took every man his men that were to come in on the sabbath, with them that should go out on the sabbath, and came to Jehoiada the priest.
9840	324	10	And to the captains over hundreds did the priest give king David's spears and shields, that were in the temple of the LORD.
9841	324	11	And the guard stood, every man with his weapons in his hand, round about the king, from the right corner of the temple to the left corner of the temple, along by the altar and the temple.
9842	324	12	And he brought forth the king's son, and put the crown upon him, and gave him the testimony; and they made him king, and anointed him; and they clapped their hands, and said, God save the king.
9843	324	13	And when Athaliah heard the noise of the guard and of the people, she came to the people into the temple of the LORD.
9844	324	14	And when she looked, behold, the king stood by a pillar, as the manner was, and the princes and the trumpeters by the king, and all the people of the land rejoiced, and blew with trumpets: and Athaliah rent her clothes, and cried, Treason, Treason.
9845	324	15	But Jehoiada the priest commanded the captains of the hundreds, the officers of the host, and said unto them, Have her forth without the ranges: and him that followeth her kill with the sword. For the priest had said, Let her not be slain in the house of the LORD.
9846	324	16	And they laid hands on her; and she went by the way by the which the horses came into the king's house: and there was she slain.
9847	324	17	And Jehoiada made a covenant between the LORD and the king and the people, that they should be the LORD's people; between the king also and the people.
9848	324	18	And all the people of the land went into the house of Baal, and brake it down; his altars and his images brake they in pieces thoroughly, and slew Mattan the priest of Baal before the altars. And the priest appointed officers over the house of the LORD.
9849	324	19	And he took the rulers over hundreds, and the captains, and the guard, and all the people of the land; and they brought down the king from the house of the LORD, and came by the way of the gate of the guard to the king's house. And he sat on the throne of the kings.
9850	324	20	And all the people of the land rejoiced, and the city was in quiet: and they slew Athaliah with the sword beside the king's house.
9851	324	21	Seven years old was Jehoash when he began to reign.
9852	325	1	IN the seventh year of Jehu Jehoash began to reign; and forty years reigned he in Jerusalem. And his mother's name was Zibiah of Beer-sheba.
9853	325	2	And Jehoash did that which was right in the sight of the LORD all his days wherein Jehoiada the priest instructed him.
9854	325	3	But the high places were not taken away: the people still sacrificed and burnt incense in the high places.
9855	325	4	And Jehoash said to the priests, All the money of the dedicated things that is brought into the house of the LORD, even the money of every one that passeth the account, the money that every man is set at, and all the money that cometh into any man's heart to bring into the house of the LORD,
9856	325	5	Let the priests take it to them, every man of his acquaintance: and let them repair the breaches of the house, wheresoever any breach shall be found.
9857	325	6	But it was so, that in the three and twentieth year of king Jehoash the priests had not repaired the breaches of the house.
9858	325	7	Then king Jehoash called for Jehoiada the priest, and the other priests, and said unto them, Why repair ye not the breaches of the house? now therefore receive no more money of your acquaintance, but deliver it for the breaches of the house.
9859	325	8	And the priests consented to receive no more money of the people, neither to repair the breaches of the house.
9860	325	9	But Jehoiada the priest took a chest, and bored a hole in the lid of it, and set it beside the altar, on the right side as one cometh into the house of the LORD: and the priests that kept the door put therein all the money that was brought into the house of the LORD.
9861	325	10	And it was so, when they saw that there was much money in the chest, that the king's scribe and the high priest came up, and they put up in bags, and told the money that was found in the house of the LORD.
9862	325	11	And they gave the money, being told, into the hands of them that did the work, that had the oversight of the house of the LORD: and they laid it out to the carpenters and builders, that wrought upon the house of the LORD,
9863	325	12	And to masons, and hewers of stone, and to buy timber and hewed stone to repair the breaches of the house of the LORD, and for all that was laid out for the house to repair it.
9864	325	13	Howbeit there were not made for the house of the LORD bowls of silver, snuffers, basons, trumpets, any vessels of gold, or vessels of silver, of the money that was brought into the house of the LORD:
9865	325	14	But they gave that to the workmen, and repaired therewith the house of the LORD.
9866	325	15	Moreover they reckoned not with the men, into whose hand they delivered the money to be bestowed on workmen: for they dealt faithfully.
9867	325	16	The trespass money and sin money was not brought into the house of the LORD: it was the priests'.
9868	325	17	Then Hazael king of Syria went up, and fought against Gath, and took it: and Hazael set his face to go up to Jerusalem.
9869	325	18	And Jehoash king of Judah took all the hallowed things that Jehoshaphat, and Jehoram, and Ahaziah, his fathers, kings of Judah, had dedicated, and his own hallowed things, and all the gold that was found in the treasures of the house of the LORD, and in the king's house, and sent it to Hazael king of Syria: and he went away from Jerusalem.
9870	325	19	And the rest of the acts of Joash, and all that he did, are they not written in the book of the chronicles of the kings of Judah?
9871	325	20	And his servants arose, and made a conspiracy, and slew Joash in the house of Millo, which goeth down to Silla.
9872	325	21	For Jozachar the son of Shimeath, and Jehozabad the son of Shomer, his servants, smote him, and he died; and they buried him with his fathers in the city of David: and Amaziah his son reigned in his stead.
9873	326	1	IN the three and twentieth year of Joash the son of Ahaziah king of Judah Jehoahaz the son of Jehu began to reign over Israel in Samaria, and reigned seventeen years.
9874	326	2	And he did that which was evil in the sight of the LORD, and followed the sins of Jeroboam the son of Nebat, which made Israel to sin; he departed not therefrom.
9875	326	3	And the anger of the LORD was kindled against Israel, and he delivered them into the hand of Hazael king of Syria, and into the hand of Ben-hadad the son of Hazael, all their days.
9876	326	4	And Jehoahaz besought the LORD, and the LORD hearkened unto him: for he saw the oppression of Israel, because the king of Syria oppressed them.
9877	326	5	(And the LORD gave Israel a saviour, so that they went out from under the hand of the Syrians: and the children of Israel dwelt in their tents, as beforetime.
9878	326	6	Nevertheless they departed not from the sins of the house of Jeroboam, who made Israel sin, but walked therein: and there remained the grove also in Samaria.)
9879	326	7	Neither did he leave of the people to Jehoahaz but fifty horsemen, and ten chariots, and ten thousand footmen; for the king of Syria had destroyed them, and had made them like the dust by threshing.
9880	326	8	Now the rest of the acts of Jehoahaz, and all that he did, and his might, are they not written in the book of the chronicles of the kings of Israel?
9881	326	9	And Jehoahaz slept with his fathers; and they buried him in Samaria: and Joash his son reigned in his stead.
9882	326	10	In the thirty and seventh year of Joash king of Judah began Jehoash the son of Jehoahaz to reign over Israel in Samaria, and reigned sixteen years.
9883	326	11	And he did that which was evil in the sight of the LORD; he departed not from all the sins of Jeroboam the son of Nebat, who made Israel sin: but he walked therein.
9884	326	12	And the rest of the acts of Joash, and all that he did, and his might wherewith he fought against Amaziah king of Judah, are they not written in the book of the chronicles of the kings of Israel?
9885	326	13	And Joash slept with his fathers; and Jeroboam sat upon his throne: and Joash was buried in Samaria with the kings of Israel.
9886	326	14	Now Elisha was fallen sick of his sickness whereof he died. And Joash the king of Israel came down unto him, and wept over his face, and said, O my father, my father, the chariot of Israel, and the horsemen thereof.
9887	326	15	And Elisha said unto him, Take bow and arrows. And he took unto him bow and arrows.
9888	326	16	And he said to the king of Israel, Put thine hand upon the bow. And he put his hand upon it: and Elisha put his hands upon the king's hands.
9889	326	17	And he said, Open the window eastward. And he opened it. Then Elisha said, Shoot. And he shot. And he said, The arrow of the LORD's deliverance, and the arrow of deliverance from Syria: for thou shalt smite the Syrians in Aphek, till thou have consumed them.
9890	326	18	And he said, Take the arrows. And he took them. And he said unto the king of Israel, Smite upon the ground. And he smote thrice, and stayed.
9891	326	19	And the man of God was wroth with him, and said, Thou shouldest have smitten five or six times; then hadst thou smitten Syria till thou hadst consumed it: whereas now thou shalt smite Syria but thrice.
9892	326	20	And Elisha died, and they buried him. And the bands of the Moabites invaded the land at the coming in of the year.
9893	326	21	And it came to pass, as they were burying a man, that, behold, they spied a band of men; and they cast the man into the sepulchre of Elisha: and when the man was let down, and touched the bones of Elisha, he revived, and stood up on his feet.
9894	326	22	But Hazael king of Syria oppressed Israel all the days of Jehoahaz.
9895	326	23	And the LORD was gracious unto them, and had compassion on them, and had respect unto them, because of his covenant with Abraham, Isaac, and Jacob, and would not destroy them, neither cast he them from his presence as yet.
9896	326	24	So Hazael king of Syria died; and Ben-hadad his son reigned in his stead.
9897	326	25	And Jehoash the son of Jehoahaz took again out of the hand of Ben-hadad the son of Hazael the cities, which he had taken out of the hand of Jehoahaz his father by war. Three times did Joash beat him, and recovered the cities of Israel.
9898	327	1	IN the second year of Joash son of Jehoahaz king of Israel reigned Amaziah the son of Joash king of Judah.
9899	327	2	He was twenty and five years old when he began to reign, and reigned twenty and nine years in Jerusalem. And his mother's name was Jehoaddan of Jerusalem.
9900	327	3	And he did that which was right in the sight of the LORD, yet not like David his father: he did according to all things as Joash his father did.
9901	327	4	Howbeit the high places were not taken away: as yet the people did sacrifice and burnt incense on the high places.
9902	327	5	And it came to pass, as soon as the kingdom was confirmed in his hand, that he slew his servants which had slain the king his father.
9903	327	6	But the children of the murderers he slew not: according unto that which is written in the book of the law of Moses, wherein the LORD commanded, saying, The fathers shall not be put to death for the children, nor the children be put to death for the fathers; but every man shall be put to death for his own sin.
9904	327	7	He slew of Edom in the valley of salt ten thousand, and took Selah by war, and called the name of it Joktheel unto this day.
9905	327	8	Then Amaziah sent messengers to Jehoash, the son of Jehoahaz son of Jehu, king of Israel, saying, Come, let us look one another in the face.
9906	327	9	And Jehoash the king of Israel sent to Amaziah king of Judah, saying, The thistle that was in Lebanon sent to the cedar that was in Lebanon, saying, Give thy daughter to my son to wife: and there passed by a wild beast that was in Lebanon, and trode down the thistle.
9907	327	10	Thou hast indeed smitten Edom, and thine heart hath lifted thee up: glory of this, and tarry at home: for why shouldest thou meddle to thy hurt, that thou shouldest fall, even thou, and Judah with thee?
9908	327	11	But Amaziah would not hear. Therefore Jehoash king of Israel went up; and he and Amaziah king of Judah looked one another in the face at Beth-shemesh, which belongeth to Judah.
9909	327	12	And Judah was put to the worse before Israel; and they fled every man to their tents.
9910	327	13	And Jehoash king of Israel took Amaziah king of Judah, the son of Jehoash the son of Ahaziah, at Beth-shemesh, and came to Jerusalem, and brake down the wall of Jerusalem from the gate of Ephraim unto the corner gate, four hundred cubits.
9911	327	14	And he took all the gold and silver, and all the vessels that were found in the house of the LORD, and in the treasures of the king's house, and hostages, and returned to Samaria.
9912	327	15	Now the rest of the acts of Jehoash which he did, and his might, and how he fought with Amaziah king of Judah, are they not written in the book of the chronicles of the kings of Israel?
9913	327	16	And Jehoash slept with his fathers, and was buried in Samaria with the kings of Israel; and Jeroboam his son reigned in his stead.
9914	327	17	And Amaziah the son of Joash king of Judah lived after the death of Jehoash son of Jehoahaz king of Israel fifteen years.
9915	327	18	And the rest of the acts of Amaziah, are they not written in the book of the chronicles of the kings of Judah?
9916	327	19	Now they made a conspiracy against him in Jerusalem: and he fled to Lachish; but they sent after him to Lachish, and slew him there.
9917	327	20	And they brought him on horses: and he was buried at Jerusalem with his fathers in the city of David.
9918	327	21	And all the people of Judah took Azariah, which was sixteen years old, and made him king instead of his father Amaziah.
9919	327	22	He built Elath, and restored it to Judah, after that the king slept with his fathers.
9920	327	23	In the fifteenth year of Amaziah the son of Joash king of Judah Jeroboam the son of Joash king of Israel began to reign in Samaria, and reigned forty and one years.
9921	327	24	And he did that which was evil in the sight of the LORD: he departed not from all the sins of Jeroboam the son of Nebat, who made Israel to sin.
9922	327	25	He restored the coast of Israel from the entering of Hamath unto the sea of the plain, according to the word of the LORD God of Israel, which he spake by the hand of his servant Jonah, the son of Amittai, the prophet, which was of Gath-hepher.
9923	327	26	For the LORD saw the affliction of Israel, that it was very bitter: for there was not any shut up, nor any left, nor any helper for Israel.
9924	327	27	And the LORD said not that he would blot out the name of Israel from under heaven: but he saved them by the hand of Jeroboam the son of Joash.
9925	327	28	Now the rest of the acts of Jeroboam, and all that he did, and his might, how he warred, and how he recovered Damascus, and Hamath, which belonged to Judah, for Israel, are they not written in the book of the chronicles of the kings of Israel?
9926	327	29	And Jeroboam slept with his fathers, even with the kings of Israel; and Zachariah his son reigned in his stead.
9927	328	1	IN the twenty and seventh year of Jeroboam king of Israel began Azariah son of Amaziah king of Judah to reign.
9928	328	2	Sixteen years old was he when he began to reign, and he reigned two and fifty years in Jerusalem. And his mother's name was Jecholiah of Jerusalem.
9929	328	3	And he did that which was right in the sight of the LORD, according to all that his father Amaziah had done;
9930	328	4	Save that the high places were not removed: the people sacrificed and burnt incense still on the high places.
9931	328	5	And the LORD smote the king, so that he was a leper unto the day of his death, and dwelt in a several house. And Jotham the king's son was over the house, judging the people of the land.
9932	328	6	And the rest of the acts of Azariah, and all that he did, are they not written in the book of the chronicles of the kings of Judah?
9933	328	7	So Azariah slept with his fathers; and they buried him with his fathers in the city of David: and Jotham his son reigned in his stead.
9934	328	8	In the thirty and eighth year of Azariah king of Judah did Zachariah the son of Jeroboam reign over Israel in Samaria six months.
9935	328	9	And he did that which was evil in the sight of the LORD, as his fathers had done: he departed not from the sins of Jeroboam the son of Nebat, who made Israel to sin.
9936	328	10	And Shallum the son of Jabesh conspired against him, and smote him before the people, and slew him, and reigned in his stead.
9937	328	11	And the rest of the acts of Zachariah, behold, they are written in the book of the chronicles of the kings of Israel.
9938	328	12	This was the word of the LORD which he spake unto Jehu, saying, Thy sons shall sit on the throne of Israel unto the fourth generation. And so it came to pass.
9939	328	13	Shallum the son of Jabesh began to reign in the nine and thirtieth year of Uzziah king of Judah; and he reigned a full month in Samaria.
9940	328	14	For Menahem the son of Gadi went up from Tirzah, and came to Samaria, and smote Shallum the son of Jabesh in Samaria, and slew him, and reigned in his stead.
9941	328	15	And the rest of the acts of Shallum, and his conspiracy which he made, behold, they are written in the book of the chronicles of the kings of Israel.
9942	328	16	Then Menahem smote Tiphsah, and all that were therein, and the coasts thereof from Tirzah: because they opened not to him, therefore he smote it; and all the women therein that were with child he ripped up.
9943	328	17	In the nine and thirtieth year of Azariah king of Judah began Menahem the son of Gadi to reign over Israel, and reigned ten years in Samaria.
9944	328	18	And he did that which was evil in the sight of the LORD: he departed not all his days from the sins of Jeroboam the son of Nebat, who made Israel to sin.
9945	328	19	And Pul the king of Assyria came against the land: and Menahem gave Pul a thousand talents of silver, that his hand might be with him to confirm the kingdom in his hand.
9946	328	20	And Menahem exacted the money of Israel, even of all the mighty men of wealth, of each man fifty shekels of silver, to give to the king of Assyria. So the king of Assyria turned back, and stayed not there in the land.
9947	328	21	And the rest of the acts of Menahem, and all that he did, are they not written in the book of the chronicles of the kings of Israel?
9948	328	22	And Menahem slept with his fathers; and Pekahiah his son reigned in his stead.
9949	328	23	In the fiftieth year of Azariah king of Judah Pekahiah the son of Menahem began to reign over Israel in Samaria, and reigned two years.
9950	328	24	And he did that which was evil in the sight of the LORD: he departed not from the sins of Jeroboam the son of Nebat, who made Israel to sin.
9951	328	25	But Pekah the son of Remaliah, a captain of his, conspired against him, and smote him in Samaria, in the palace of the king's house, with Argob and Arieh, and with him fifty men of the Gileadites: and he killed him, and reigned in his room.
9952	328	26	And the rest of the acts of Pekahiah, and all that he did, behold, they are written in the book of the chronicles of the kings of Israel.
9953	328	27	In the two and fiftieth year of Azariah king of Judah Pekah the son of Remaliah began to reign over Israel in Samaria, and reigned twenty years.
9954	328	28	And he did that which was evil in the sight of the LORD: he departed not from the sins of Jeroboam the son of Nebat, who made Israel to sin.
9955	328	29	In the days of Pekah king of Israel came Tiglath-pileser king of Assyria, and took Ijon, and Abel-beth-maachah, and Janoah, and Kedesh, and Hazor, and Gilead, and Galilee, all the land of Naphtali, and carried them captive to Assyria.
9956	328	30	And Hoshea the son of Elah made a conspiracy against Pekah the son of Remaliah, and smote him, and slew him, and reigned in his stead, in the twentieth year of Jotham the son of Uzziah.
9957	328	31	And the rest of the acts of Pekah, and all that he did, behold, they are written in the book of the chronicles of the kings of Israel.
9958	328	32	In the second year of Pekah the son of Remaliah king of Israel began Jotham the son of Uzziah king of Judah to reign.
9959	328	33	Five and twenty years old was he when he began to reign, and he reigned sixteen years in Jerusalem. And his mother's name was Jerusha, the daughter of Zadok.
9960	328	34	And he did that which was right in the sight of the LORD: he did according to all that his father Uzziah had done.
9961	328	35	Howbeit the high places were not removed: the people sacrificed and burned incense still in the high places. He built the higher gate of the house of the LORD.
9962	328	36	Now the rest of the acts of Jotham, and all that he did, are they not written in the book of the chronicles of the kings of Judah?
9963	328	37	In those days the LORD began to send against Judah Rezin the king of Syria, and Pekah the son of Remaliah.
9964	328	38	And Jotham slept with his fathers, and was buried with his fathers in the city of David his father: and Ahaz his son reigned in his stead.
9965	329	1	IN the seventeenth year of Pekah the son of Remaliah Ahaz the son of Jotham king of Judah began to reign.
9966	329	2	Twenty years old was Ahaz when he began to reign, and reigned sixteen years in Jerusalem, and did not that which was right in the sight of the LORD his God, like David his father.
9967	329	3	But he walked in the way of the kings of Israel, yea, and made his son to pass through the fire, according to the abominations of the heathen, whom the LORD cast out from before the children of Israel.
9968	329	4	And he sacrificed and burnt incense in the high places, and on the hills, and under every green tree.
9969	329	5	Then Rezin king of Syria and Pekah son of Remaliah king of Israel came up to Jerusalem to war: and they besieged Ahaz, but could not overcome him.
9970	329	6	At that time Rezin king of Syria recovered Elath to Syria, and drave the Jews from Elath: and the Syrians came to Elath, and dwelt there unto this day.
9971	329	7	So Ahaz sent messengers to Tiglath-pileser king of Assyria, saying, I am thy servant and thy son: come up, and save me out of the hand of the king of Syria, and out of the hand of the king of Israel, which rise up against me.
9972	329	8	And Ahaz took the silver and gold that was found in the house of the LORD, and in the treasures of the king's house, and sent it for a present to the king of Assyria.
9973	329	9	And the king of Assyria hearkened unto him: for the king of Assyria went up against Damascus, and took it, and carried the people of it captive to Kir, and slew Rezin.
9974	329	10	And king Ahaz went to Damascus to meet Tiglath-pileser king of Assyria, and saw an altar that was at Damascus: and king Ahaz sent to Urijah the priest the fashion of the altar, and the pattern of it, according to all the workmanship thereof.
9975	329	11	And Urijah the priest built an altar according to all that king Ahaz had sent from Damascus: so Urijah the priest made it against king Ahaz came from Damascus.
9976	329	12	And when the king was come from Damascus, the king saw the altar: and the king approached to the altar, and offered thereon.
9977	329	13	And he burnt his burnt offering and his meat offering, and poured his drink offering, and sprinkled the blood of his peace offerings, upon the altar.
9978	329	14	And he brought also the brasen altar, which was before the LORD, from the forefront of the house, from between the altar and the house of the LORD, and put it on the north side of the altar.
9979	329	15	And king Ahaz commanded Urijah the priest, saying, Upon the great altar burn the morning burnt offering, and the evening meat offering, and the king's burnt sacrifice, and his meat offering, with the burnt offering of all the people of the land, and their meat offering, and their drink offerings; and sprinkle upon it all the blood of the burnt offering, and all the blood of the sacrifice: and the brasen altar shall be for me to enquire by.
9980	329	16	Thus did Urijah the priest, according to all that king Ahaz commanded.
9981	329	17	And king Ahaz cut off the borders of the bases, and removed the laver from off them; and took down the sea from off the brasen oxen that were under it, and put it upon a pavement of stones.
9982	329	18	And the covert for the sabbath that they had built in the house, and the king's entry without, turned he from the house of the LORD for the king of Assyria.
9983	329	19	Now the rest of the acts of Ahaz which he did, are they not written in the book of the chronicles of the kings of Judah?
9984	329	20	And Ahaz slept with his fathers, and was buried with his fathers in the city of David: and Hezekiah his son reigned in his stead.
9985	330	1	IN the twelfth year of Ahaz king of Judah began Hoshea the son of Elah to reign in Samaria over Israel nine years.
9986	330	2	And he did that which was evil in the sight of the LORD, but not as the kings of Israel that were before him.
9987	330	3	Against him came up Shalmaneser king of Assyria; and Hoshea became his servant, and gave him presents.
9988	330	4	And the king of Assyria found conspiracy in Hoshea: for he had sent messengers to So king of Egypt, and brought no present to the king of Assyria, as he had done year by year: therefore the king of Assyria shut him up, and bound him in prison.
9989	330	5	Then the king of Assyria came up throughout all the land, and went up to Samaria, and besieged it three years.
9990	330	6	In the ninth year of Hoshea the king of Assyria took Samaria, and carried Israel away into Assyria, and placed them in Halah and in Habor by the river of Gozan, and in the cities of the Medes.
9991	330	7	For so it was, that the children of Israel had sinned against the LORD their God, which had brought them up out of the land of Egypt, from under the hand of Pharaoh king of Egypt, and had feared other gods,
9992	330	8	And walked in the statutes of the heathen, whom the LORD cast out from before the children of Israel, and of the kings of Israel, which they had made.
9993	330	9	And the children of Israel did secretly those things that were not right against the LORD their God, and they built them high places in all their cities, from the tower of the watchmen to the fenced city.
9994	330	10	And they set them up images and groves in every high hill, and under every green tree:
9995	330	11	And there they burnt incense in all the high places, as did the heathen whom the LORD carried away before them; and wrought wicked things to provoke the LORD to anger:
9996	330	12	For they served idols, whereof the LORD had said unto them, Ye shall not do this thing.
9997	330	13	Yet the LORD testified against Israel, and against Judah, by all the prophets, and by all the seers, saying, Turn ye from your evil ways, and keep my commandments and my statutes, according to all the law which I commanded your fathers, and which I sent to you by my servants the prophets.
9998	330	14	Notwithstanding they would not hear, but hardened their necks, like to the neck of their fathers, that did not believe in the LORD their God.
9999	330	15	And they rejected his statutes, and his covenant that he made with their fathers, and his testimonies which he testified against them; and they followed vanity, and became vain, and went after the heathen that were round about them, concerning whom the LORD had charged them, that they should not do like them.
10000	330	16	And they left all the commandments of the LORD their God, and made them molten images, even two calves, and made a grove, and worshipped all the host of heaven, and served Baal.
10001	330	17	And they caused their sons and their daughters to pass through the fire, and used divination and enchantments, and sold themselves to do evil in the sight of the LORD, to provoke him to anger.
10002	330	18	Therefore the LORD was very angry with Israel, and removed them out of his sight: there was none left but the tribe of Judah only.
10003	330	19	Also Judah kept not the commandments of the LORD their God, but walked in the statutes of Israel which they made.
10004	330	20	And the LORD rejected all the seed of Israel, and afflicted them, and delivered them into the hand of spoilers, until he had cast them out of his sight.
10005	330	21	For he rent Israel from the house of David; and they made Jeroboam the son of Nebat king: and Jeroboam drave Israel from following the LORD, and made them sin a great sin.
10006	330	22	For the children of Israel walked in all the sins of Jeroboam which he did; they departed not from them;
10007	330	23	Until the LORD removed Israel out of his sight, as he had said by all his servants the prophets. So was Israel carried away out of their own land to Assyria unto this day.
10008	330	24	And the king of Assyria brought men from Babylon, and from Cuthah, and from Ava, and from Hamath, and from Sepharvaim, and placed them in the cities of Samaria instead of the children of Israel: and they possessed Samaria, and dwelt in the cities thereof.
10009	330	25	And so it was at the beginning of their dwelling there, that they feared not the LORD: therefore the LORD sent lions among them, which slew some of them.
10010	330	26	Wherefore they spake to the king of Assyria, saying, The nations which thou hast removed, and placed in the cities of Samaria, know not the manner of the God of the land: therefore he hath sent lions among them, and, behold, they slay them, because they know not the manner of the God of the land.
10011	330	27	Then the king of Assyria commanded, saying, Carry thither one of the priests whom ye brought from thence; and let them go and dwell there, and let him teach them the manner of the God of the land.
10012	330	28	Then one of the priests whom they had carried away from Samaria came and dwelt in Beth-el, and taught them how they should fear the LORD.
10013	330	29	Howbeit every nation made gods of their own, and put them in the houses of the high places which the Samaritans had made, every nation in their cities wherein they dwelt.
10014	330	30	And the men of Babylon made Succoth-benoth, and the men of Cuth made Nergal, and the men of Hamath made Ashima,
10015	330	31	And the Avites made Nibhaz and Tartak, and the Sepharvites burnt their children in fire to Adrammelech and Anammelech, the gods of Sepharvaim.
10016	330	32	So they feared the LORD, and made unto themselves of the lowest of them priests of the high places, which sacrificed for them in the houses of the high places.
10017	330	33	They feared the LORD, and served their own gods, after the manner of the nations whom they carried away from thence.
10018	330	34	Unto this day they do after the former manners: they fear not the LORD, neither do they after their statutes, or after their ordinances, or after the law and commandment which the LORD commanded the children of Jacob, whom he named Israel;
10019	330	35	With whom the LORD had made a covenant, and charged them, saying, Ye shall not fear other gods, nor bow yourselves to them, nor serve them, nor sacrifice to them:
10020	330	36	But the LORD, who brought you up out of the land of Egypt with great power and a stretched out arm, him shall ye fear, and him shall ye worship, and to him shall ye do sacrifice.
10021	330	37	And the statutes, and the ordinances, and the law, and the commandment, which he wrote for you, ye shall observe to do for evermore; and ye shall not fear other gods.
10022	330	38	And the covenant that I have made with you ye shall not forget; neither shall ye fear other gods.
10023	330	39	But the LORD your God ye shall fear; and he shall deliver you out of the hand of all your enemies.
10024	330	40	Howbeit they did not hearken, but they did after their former manner.
10025	330	41	So these nations feared the LORD, and served their graven images, both their children, and their children's children: as did their fathers, so do they unto this day.
10026	331	1	NOW it came to pass in the third year of Hoshea son of Elah king of Israel, that Hezekiah the son of Ahaz king of Judah began to reign.
10027	331	2	Twenty and five years old was he when he began to reign; and he reigned twenty and nine years in Jerusalem. His mother's name also was Abi, the daughter of Zachariah.
10028	331	3	And he did that which was right in the sight of the LORD, according to all that David his father did.
10029	331	4	He removed the high places, and brake the images, and cut down the groves, and brake in pieces the brasen serpent that Moses had made: for unto those days the children of Israel did burn incense to it: and he called it Nehushtan.
10030	331	5	He trusted in the LORD God of Israel; so that after him was none like him among all the kings of Judah, nor any that were before him.
10031	331	6	For he clave to the LORD, and departed not from following him, but kept his commandments, which the LORD commanded Moses.
10032	331	7	And the LORD was with him; and he prospered whithersoever he went forth: and he rebelled against the king of Assyria, and served him not.
10033	331	8	He smote the Philistines, even unto Gaza, and the borders thereof, from the tower of the watchmen to the fenced city.
10034	331	9	And it came to pass in the fourth year of king Hezekiah, which was the seventh year of Hoshea son of Elah king of Israel, that Shalmaneser king of Assyria came up against Samaria, and besieged it.
10035	331	10	And at the end of three years they took it: even in the sixth year of Hezekiah, that is the ninth year of Hoshea king of Israel, Samaria was taken.
10036	331	11	And the king of Assyria did carry away Israel unto Assyria, and put them in Halah and in Habor by the river of Gozan, and in the cities of the Medes:
10037	331	12	Because they obeyed not the voice of the LORD their God, but transgressed his covenant, and all that Moses the servant of the LORD commanded, and would not hear them, nor do them.
10038	331	13	Now in the fourteenth year of king Hezekiah did Sennacherib king of Assyria come up against all the fenced cities of Judah, and took them.
10039	331	14	And Hezekiah king of Judah sent to the king of Assyria to Lachish, saying, I have offended; return from me: that which thou puttest on me will I bear. And the king of Assyria appointed unto Hezekiah king of Judah three hundred talents of silver and thirty talents of gold.
10040	331	15	And Hezekiah gave him all the silver that was found in the house of the LORD, and in the treasures of the king's house.
10041	331	16	At that time did Hezekiah cut off the gold from the doors of the temple of the LORD, and from the pillars which Hezekiah king of Judah had overlaid, and gave it to the king of Assyria.
10042	331	17	And the king of Assyria sent Tartan and Rabsaris and Rab-shakeh from Lachish to king Hezekiah with a great host against Jerusalem. And they went up and came to Jerusalem. And when they were come up, they came and stood by the conduit of the upper pool, which is in the highway of the fuller's field.
10043	331	18	And when they had called to the king, there came out to them Eliakim the son of Hilkiah, which was over the household, and Shebna the scribe, and Joah the son of Asaph the recorder.
10044	331	19	And Rab-shakeh said unto them, Speak ye now to Hezekiah, Thus saith the great king, the king of Assyria, What confidence is this wherein thou trustest?
10045	331	20	Thou sayest, (but they are but vain words,) I have counsel and strength for the war. Now on whom dost thou trust, that thou rebellest against me?
10046	331	21	Now, behold, thou trustest upon the staff of this bruised reed, even upon Egypt, on which if a man lean, it will go into his hand, and pierce it: so is Pharaoh king of Egypt unto all that trust on him.
10047	331	22	But if ye say unto me, We trust in the LORD our God: is not that he, whose high places and whose altars Hezekiah hath taken away, and hath said to Judah and Jerusalem, Ye shall worship before this altar in Jerusalem?
10048	331	23	Now therefore, I pray thee, give pledges to my lord the king of Assyria, and I will deliver thee two thousand horses, if thou be able on thy part to set riders upon them.
10049	331	24	How then wilt thou turn away the face of one captain of the least of my master's servants, and put thy trust on Egypt for chariots and for horsemen?
10050	331	25	Am I now come up without the LORD against this place to destroy it? The LORD said to me, Go up against this land, and destroy it.
10051	331	26	Then said Eliakim the son of Hilkiah, and Shebna, and Joah, unto Rab-shakeh, Speak, I pray thee, to thy servants in the Syrian language; for we understand it: and talk not with us in the Jews' language in the ears of the people that are on the wall.
10052	331	27	But Rab-shakeh said unto them, Hath my master sent me to thy master, and to thee, to speak these words? hath he not sent me to the men which sit on the wall, that they may eat their own dung, and drink their own piss with you?
10053	331	28	Then Rab-shakeh stood and cried with a loud voice in the Jews' language, and spake, saying, Hear the word of the great king, the king of Assyria:
10054	331	29	Thus saith the king, Let not Hezekiah deceive you: for he shall not be able to deliver you out of his hand:
10055	331	30	Neither let Hezekiah make you trust in the LORD, saying, The LORD will surely deliver us, and this city shall not be delivered into the hand of the king of Assyria.
10056	331	31	Hearken not to Hezekiah: for thus saith the king of Assyria, Make an agreement with me by a present, and come out to me, and then eat ye every man of his own vine, and every one of his fig tree, and drink ye every one the waters of his cistern:
10057	331	32	Until I come and take you away to a land like your own land, a land of corn and wine, a land of bread and vineyards, a land of oil olive and of honey, that ye may live, and not die: and hearken not unto Hezekiah, when he persuadeth you, saying, The LORD will deliver us.
10058	331	33	Hath any of the gods of the nations delivered at all his land out of the hand of the king of Assyria?
10059	331	34	Where are the gods of Hamath, and of Arpad? where are the gods of Sepharvaim, Hena, and Ivah? have they delivered Samaria out of mine hand?
10060	331	35	Who are they among all the gods of the countries, that have delivered their country out of mine hand, that the LORD should deliver Jerusalem out of mine hand?
10061	331	36	But the people held their peace, and answered him not a word: for the king's commandment was, saying, Answer him not.
10062	331	37	Then came Eliakim the son of Hilkiah, which was over the household, and Shebna the scribe, and Joah the son of Asaph the recorder, to Hezekiah with their clothes rent, and told him the words of Rab-shakeh.
10063	332	1	AND it came to pass, when king Hezekiah heard it, that he rent his clothes, and covered himself with sackcloth, and went into the house of the LORD.
10064	332	2	And he sent Eliakim, which was over the household, and Shebna the scribe, and the elders of the priests, covered with sackcloth, to Isaiah the prophet the son of Amoz.
10065	332	3	And they said unto him, Thus saith Hezekiah, This day is a day of trouble, and of rebuke, and blasphemy: for the children are come to the birth, and there is not strength to bring forth.
10066	332	4	It may be the LORD thy God will hear all the words of Rab-shakeh, whom the king of Assyria his master hath sent to reproach the living God; and will reprove the words which the LORD thy God hath heard: wherefore lift up thy prayer for the remnant that are left.
10067	332	5	So the servants of king Hezekiah came to Isaiah.
10068	332	6	And Isaiah said unto them, Thus shall ye say to your master, Thus saith the LORD, Be not afraid of the words which thou hast heard, with which the servants of the king of Assyria have blasphemed me.
10069	332	7	Behold, I will send a blast upon him, and he shall hear a rumour, and shall return to his own land; and I will cause him to fall by the sword in his own land.
10070	332	8	So Rab-shakeh returned, and found the king of Assyria warring against Libnah: for he had heard that he was departed from Lachish.
10071	332	9	And when he heard say of Tirhakah king of Ethiopia, Behold, he is come out to fight against thee: he sent messengers again unto Hezekiah, saying,
10072	332	10	Thus shall ye speak to Hezekiah king of Judah, saying, Let not thy God in whom thou trustest deceive thee, saying, Jerusalem shall not be delivered into the hand of the king of Assyria.
10073	332	11	Behold, thou hast heard what the kings of Assyria have done to all lands, by destroying them utterly: and shalt thou be delivered?
10074	332	12	Have the gods of the nations delivered them which my fathers have destroyed; as Gozan, and Haran, and Rezeph, and the children of Eden which were in Thelasar?
10075	332	13	Where is the king of Hamath, and the king of Arpad, and the king of the city of Sepharvaim, of Hena, and Ivah?
10076	332	14	And Hezekiah received the letter of the hand of the messengers, and read it: and Hezekiah went up into the house of the LORD, and spread it before the LORD.
10077	332	15	And Hezekiah prayed before the LORD, and said, O LORD God of Israel, which dwellest between the cherubims, thou art the God, even thou alone, of all the kingdoms of the earth: thou hast made heaven and earth.
10078	332	16	LORD, bow down thine ear, and hear: open, LORD, thine eyes, and see: and hear the words of Sennacherib, which hath sent him to reproach the living God.
10079	332	17	Of a truth, LORD, the kings of Assyria have destroyed the nations and their lands,
10080	332	18	And have cast their gods into the fire: for they were no gods, but the work of men's hands, wood and stone: therefore they have destroyed them.
10081	332	19	Now therefore, O LORD our God, I beseech thee, save thou us out of his hand, that all the kingdoms of the earth may know that thou art the LORD God, even thou only.
10082	332	20	Then Isaiah the son of Amoz sent to Hezekiah, saying, Thus saith the LORD God of Israel, That which thou hast prayed to me against Sennacherib king of Assyria I have heard.
10083	332	21	This is the word that the LORD hath spoken concerning him; The virgin the daughter of Zion hath despised thee, and laughed thee to scorn; the daughter of Jerusalem hath shaken her head at thee.
10084	332	22	Whom hast thou reproached and blasphemed? and against whom hast thou exalted thy voice, and lifted up thine eyes on high? even against the Holy One of Israel.
10085	332	23	By thy messengers thou hast reproached the Lord, and hast said, With the multitude of my chariots I am come up to the height of the mountains, to the sides of Lebanon, and will cut down the tall cedar trees thereof, and the choice fir trees thereof: and I will enter into the lodgings of his borders, and into the forest of his Carmel.
10086	332	24	I have digged and drunk strange waters, and with the sole of my feet have I dried up all the rivers of besieged places.
10087	332	25	Hast thou not heard long ago how I have done it, and of ancient times that I have formed it? now have I brought it to pass, that thou shouldest be to lay waste fenced cities into ruinous heaps.
10088	332	26	Therefore their inhabitants were of small power, they were dismayed and confounded; they were as the grass of the field, and as the green herb, as the grass on the housetops, and as corn blasted before it be grown up.
10089	332	27	But I know thy abode, and thy going out, and thy coming in, and thy rage against me.
10090	332	28	Because thy rage against me and thy tumult is come up into mine ears, therefore I will put my hook in thy nose, and my bridle in thy lips, and I will turn thee back by the way by which thou camest.
10091	332	29	And this shall be a sign unto thee, Ye shall eat this year such things as grow of themselves, and in the second year that which springeth of the same; and in the third year sow ye, and reap, and plant vineyards, and eat the fruits thereof.
10092	332	30	And the remnant that is escaped of the house of Judah shall yet again take root downward, and bear fruit upward.
10093	332	31	For out of Jerusalem shall go forth a remnant, and they that escape out of mount Zion: the zeal of the LORD of hosts shall do this.
10094	332	32	Therefore thus saith the LORD concerning the king of Assyria, He shall not come into this city, nor shoot an arrow there, nor come before it with shield, nor cast a bank against it.
10095	332	33	By the way that he came, by the same shall he return, and shall not come into this city, saith the LORD.
10096	332	34	For I will defend this city, to save it, for mine own sake, and for my servant David's sake.
10097	332	35	And it came to pass that night, that the angel of the LORD went out, and smote in the camp of the Assyrians an hundred fourscore and five thousand: and when they arose early in the morning, behold, they were all dead corpses.
10098	332	36	So Sennacherib king of Assyria departed, and went and returned, and dwelt at Nineveh.
10099	332	37	And it came to pass, as he was worshipping in the house of Nisroch his god, that Adrammelech and Sharezer his sons smote him with the sword: and they escaped into the land of Armenia. And Esarhaddon his son reigned in his stead.
10100	333	1	IN those days was Hezekiah sick unto death. And the prophet Isaiah the son of Amoz came to him, and said unto him, Thus saith the LORD, Set thine house in order; for thou shalt die, and not live.
10101	333	2	Then he turned his face to the wall, and prayed unto the LORD, saying,
10102	333	3	I beseech thee, O LORD, remember now how I have walked before thee in truth and with a perfect heart, and have done that which is good in thy sight. And Hezekiah wept sore.
10103	333	4	And it came to pass, afore Isaiah was gone out into the middle court, that the word of the LORD came to him, saying,
10104	333	5	Turn again, and tell Hezekiah the captain of my people, Thus saith the LORD, the God of David thy father, I have heard thy prayer, I have seen thy tears: behold, I will heal thee: on the third day thou shalt go up unto the house of the LORD.
10105	333	6	And I will add unto thy days fifteen years; and I will deliver thee and this city out of the hand of the king of Assyria; and I will defend this city for mine own sake, and for my servant David's sake.
10106	333	7	And Isaiah said, Take a lump of figs. And they took and laid it on the boil, and he recovered.
10107	333	8	And Hezekiah said unto Isaiah, What shall be the sign that the LORD will heal me, and that I shall go up into the house of the LORD the third day?
10108	333	9	And Isaiah said, This sign shalt thou have of the LORD, that the LORD will do the thing that he hath spoken: shall the shadow go forward ten degrees, or go back ten degrees?
10109	333	10	And Hezekiah answered, It is a light thing for the shadow to go down ten degrees: nay, but let the shadow return backward ten degrees.
10110	333	11	And Isaiah the prophet cried unto the LORD: and he brought the shadow ten degrees backward, by which it had gone down in the dial of Ahaz.
10111	333	12	At that time Berodach-baladan, the son of Baladan, king of Babylon, sent letters and a present unto Hezekiah: for he had heard that Hezekiah had been sick.
10112	333	13	And Hezekiah hearkened unto them, and shewed them all the house of his precious things, the silver, and the gold, and the spices, and the precious ointment, and all the house of his armour, and all that was found in his treasures: there was nothing in his house, nor in all his dominion, that Hezekiah shewed them not.
10113	333	14	Then came Isaiah the prophet unto king Hezekiah, and said unto him, What said these men? and from whence came they unto thee? And Hezekiah said, They are come from a far country, even from Babylon.
10114	333	15	And he said, What have they seen in thine house? And Hezekiah answered, All the things that are in mine house have they seen: there is nothing among my treasures that I have not shewed them.
10115	333	16	And Isaiah said unto Hezekiah, Hear the word of the LORD.
10116	333	17	Behold, the days come, that all that is in thine house, and that which thy fathers have laid up in store unto this day, shall be carried into Babylon: nothing shall be left, saith the LORD.
10117	333	18	And of thy sons that shall issue from thee, which thou shalt beget, shall they take away; and they shall be eunuchs in the palace of the king of Babylon.
10118	333	19	Then said Hezekiah unto Isaiah, Good is the word of the LORD which thou hast spoken. And he said, Is it not good, if peace and truth be in my days?
10119	333	20	And the rest of the acts of Hezekiah, and all his might, and how he made a pool, and a conduit, and brought water into the city, are they not written in the book of the chronicles of the kings of Judah?
10120	333	21	And Hezekiah slept with his fathers: and Manasseh his son reigned in his stead.
10121	334	1	MANASSEH was twelve years old when he began to reign, and reigned fifty and five years in Jerusalem. And his mother's name was Hephzi-bah.
10122	334	2	And he did that which was evil in the sight of the LORD, after the abominations of the heathen, whom the LORD cast out before the children of Israel.
10123	334	3	For he built up again the high places which Hezekiah his father had destroyed; and he reared up altars for Baal, and made a grove, as did Ahab king of Israel; and worshipped all the host of heaven, and served them.
10124	334	4	And he built altars in the house of the LORD, of which the LORD said, In Jerusalem will I put my name.
10125	334	5	And he built altars for all the host of heaven in the two courts of the house of the LORD.
10126	334	6	And he made his son pass through the fire, and observed times, and used enchantments, and dealt with familiar spirits and wizards: he wrought much wickedness in the sight of the LORD, to provoke him to anger.
10127	334	7	And he set a graven image of the grove that he had made in the house, of which the LORD said to David, and to Solomon his son, In this house, and in Jerusalem, which I have chosen out of all tribes of Israel, will I put my name for ever:
10128	334	8	Neither will I make the feet of Israel move any more out of the land which I gave their fathers; only if they will observe to do according to all that I have commanded them, and according to all the law that my servant Moses commanded them.
10129	334	9	But they hearkened not: and Manasseh seduced them to do more evil than did the nations whom the LORD destroyed before the children of Israel.
10130	334	10	And the LORD spake by his servants the prophets, saying,
10131	334	11	Because Manasseh king of Judah hath done these abominations, and hath done wickedly above all that the Amorites did, which were before him, and hath made Judah also to sin with his idols:
10132	334	12	Therefore thus saith the LORD God of Israel, Behold, I am bringing such evil upon Jerusalem and Judah, that whosoever heareth of it, both his ears shall tingle.
10133	334	13	And I will stretch over Jerusalem the line of Samaria, and the plummet of the house of Ahab: and I will wipe Jerusalem as a man wipeth a dish, wiping it, and turning it upside down.
10134	334	14	And I will forsake the remnant of mine inheritance, and deliver them into the hand of their enemies; and they shall become a prey and a spoil to all their enemies;
10135	334	15	Because they have done that which was evil in my sight, and have provoked me to anger, since the day their fathers came forth out of Egypt, even unto this day.
10136	334	16	Moreover Manasseh shed innocent blood very much, till he had filled Jerusalem from one end to another; beside his sin wherewith he made Judah to sin, in doing that which was evil in the sight of the LORD.
10137	334	17	Now the rest of the acts of Manasseh, and all that he did, and his sin that he sinned, are they not written in the book of the chronicles of the kings of Judah?
10138	334	18	And Manasseh slept with his fathers, and was buried in the garden of his own house, in the garden of Uzza: and Amon his son reigned in his stead.
10139	334	19	Amon was twenty and two years old when he began to reign, and he reigned two years in Jerusalem. And his mother's name was Meshullemeth, the daughter of Haruz of Jotbah.
10140	334	20	And he did that which was evil in the sight of the LORD, as his father Manasseh did.
10141	334	21	And he walked in all the way that his father walked in, and served the idols that his father served, and worshipped them:
10142	334	22	And he forsook the LORD God of his fathers, and walked not in the way of the LORD.
10143	334	23	And the servants of Amon conspired against him, and slew the king in his own house.
10144	334	24	And the people of the land slew all them that had conspired against king Amon; and the people of the land made Josiah his son king in his stead.
10145	334	25	Now the rest of the acts of Amon which he did, are they not written in the book of the chronicles of the kings of Judah?
10146	334	26	And he was buried in his sepulchre in the garden of Uzza: and Josiah his son reigned in his stead.
10147	335	1	JOSIAH was eight years old when he began to reign, and he reigned thirty and one years in Jerusalem. And his mother's name was Jedidah, the daughter of Adaiah of Boscath.
10148	335	2	And he did that which was right in the sight of the LORD, and walked in all the way of David his father, and turned not aside to the right hand or to the left.
10149	335	3	And it came to pass in the eighteenth year of king Josiah, that the king sent Shaphan the son of Azaliah, the son of Meshullam, the scribe, to the house of the LORD, saying,
10150	335	4	Go up to Hilkiah the high priest, that he may sum the silver which is brought into the house of the LORD, which the keepers of the door have gathered of the people:
10151	335	5	And let them deliver it into the hand of the doers of the work, that have the oversight of the house of the LORD: and let them give it to the doers of the work which is in the house of the LORD, to repair the breaches of the house,
10152	335	6	Unto carpenters, and builders, and masons, and to buy timber and hewn stone to repair the house.
10153	335	7	Howbeit there was no reckoning made with them of the money that was delivered into their hand, because they dealt faithfully.
10154	335	8	And Hilkiah the high priest said unto Shaphan the scribe, I have found the book of the law in the house of the LORD. And Hilkiah gave the book to Shaphan, and he read it.
10155	335	9	And Shaphan the scribe came to the king, and brought the king word again, and said, Thy servants have gathered the money that was found in the house, and have delivered it into the hand of them that do the work, that have the oversight of the house of the LORD.
10156	335	10	And Shaphan the scribe shewed the king, saying, Hilkiah the priest hath delivered me a book. And Shaphan read it before the king.
10157	335	11	And it came to pass, when the king had heard the words of the book of the law, that he rent his clothes.
10158	335	12	And the king commanded Hilkiah the priest, and Ahikam the son of Shaphan, and Achbor the son of Michaiah, and Shaphan the scribe, and Asahiah a servant of the king's, saying,
10159	335	13	Go ye, enquire of the LORD for me, and for the people, and for all Judah, concerning the words of this book that is found: for great is the wrath of the LORD that is kindled against us, because our fathers have not hearkened unto the words of this book, to do according unto all that which is written concerning us.
10160	335	14	So Hilkiah the priest, and Ahikam, and Achbor, and Shaphan, and Asahiah, went unto Huldah the prophetess, the wife of Shallum the son of Tikvah, the son of Harhas, keeper of the wardrobe; (now she dwelt in Jerusalem in the college;) and they communed with her.
10161	335	15	And she said unto them, Thus saith the LORD God of Israel, Tell the man that sent you to me,
10162	335	16	Thus saith the LORD, Behold, I will bring evil upon this place, and upon the inhabitants thereof, even all the words of the book which the king of Judah hath read:
10163	335	17	Because they have forsaken me, and have burned incense unto other gods, that they might provoke me to anger with all the works of their hands; therefore my wrath shall be kindled against this place, and shall not be quenched.
10164	335	18	But to the king of Judah which sent you to enquire of the LORD, thus shall ye say to him, Thus saith the LORD God of Israel, As touching the words which thou hast heard;
10165	335	19	Because thine heart was tender, and thou hast humbled thyself before the LORD, when thou heardest what I spake against this place, and against the inhabitants thereof, that they should become a desolation and a curse, and hast rent thy clothes, and wept before me; I also have heard thee, saith the LORD.
10166	335	20	Behold therefore, I will gather thee unto thy fathers, and thou shalt be gathered into thy grave in peace; and thine eyes shall not see all the evil which I will bring upon this place. And they brought the king word again.
10167	336	1	AND the king sent, and they gathered unto him all the elders of Judah and of Jerusalem.
10168	336	2	And the king went up into the house of the LORD, and all the men of Judah and all the inhabitants of Jerusalem with him, and the priests, and the prophets, and all the people, both small and great: and he read in their ears all the words of the book of the covenant which was found in the house of the LORD.
10169	336	3	And the king stood by a pillar, and made a covenant before the LORD, to walk after the LORD, and to keep his commandments and his testimonies and his statutes with all their heart and all their soul, to perform the words of this covenant that were written in this book. And all the people stood to the covenant.
10170	336	4	And the king commanded Hilkiah the high priest, and the priests of the second order, and the keepers of the door, to bring forth out of the temple of the LORD all the vessels that were made for Baal, and for the grove, and for all the host of heaven: and he burned them without Jerusalem in the fields of Kidron, and carried the ashes of them unto Beth-el.
10171	336	5	And he put down the idolatrous priests, whom the kings of Judah had ordained to burn incense in the high places in the cities of Judah, and in the places round about Jerusalem; them also that burned incense unto Baal, to the sun, and to the moon, and to the planets, and to all the host of heaven.
10172	336	6	And he brought out the grove from the house of the LORD, without Jerusalem, unto the brook Kidron, and burned it at the brook Kidron, and stamped it small to powder, and cast the powder thereof upon the graves of the children of the people.
10173	336	7	And he brake down the houses of the sodomites, that were by the house of the LORD, where the women wove hangings for the grove.
10174	336	8	And he brought all the priests out of the cities of Judah, and defiled the high places where the priests had burned incense, from Geba to Beer-sheba, and brake down the high places of the gates that were in the entering in of the gate of Joshua the governor of the city, which were on a man's left hand at the gate of the city.
10175	336	9	Nevertheless the priests of the high places came not up to the altar of the LORD in Jerusalem, but they did eat of the unleavened bread among their brethren.
10176	336	10	And he defiled Topheth, which is in the valley of the children of Hinnom, that no man might make his son or his daughter to pass through the fire to Molech.
10177	336	11	And he took away the horses that the kings of Judah had given to the sun, at the entering in of the house of the LORD, by the chamber of Nathan-melech the chamberlain, which was in the suburbs, and burned the chariots of the sun with fire.
10178	336	12	And the altars that were on the top of the upper chamber of Ahaz, which the kings of Judah had made, and the altars which Manasseh had made in the two courts of the house of the LORD, did the king beat down, and brake them down from thence, and cast the dust of them into the brook Kidron.
10179	336	13	And the high places that were before Jerusalem, which were on the right hand of the mount of corruption, which Solomon the king of Israel had builded for Ashtoreth the abomination of the Zidonians, and for Chemosh the abomination of the Moabites, and for Milcom the abomination of the children of Ammon, did the king defile.
10180	336	14	And he brake in pieces the images, and cut down the groves, and filled their places with the bones of men.
10181	336	15	Moreover the altar that was at Beth-el, and the high place which Jeroboam the son of Nebat, who made Israel to sin, had made, both that altar and the high place he brake down, and burned the high place, and stamped it small to powder, and burned the grove.
10182	336	16	And as Josiah turned himself, he spied the sepulchres that were there in the mount, and sent, and took the bones out of the sepulchres, and burned them upon the altar, and polluted it, according to the word of the LORD which the man of God proclaimed, who proclaimed these words.
10183	336	17	Then he said, What title is that that I see? And the men of the city told him, It is the sepulchre of the man of God, which came from Judah, and proclaimed these things that thou hast done against the altar of Beth-el.
10184	336	18	And he said, Let him alone; let no man move his bones. So they let his bones alone, with the bones of the prophet that came out of Samaria.
10185	336	19	And all the houses also of the high places that were in the cities of Samaria, which the kings of Israel had made to provoke the LORD to anger, Josiah took away, and did to them according to all the acts that he had done in Beth-el.
10186	336	20	And he slew all the priests of the high places that were there upon the altars, and burned men's bones upon them, and returned to Jerusalem.
10187	336	21	And the king commanded all the people, saying, Keep the passover unto the LORD your God, as it is written in the book of this covenant.
10188	336	22	Surely there was not holden such a passover from the days of the judges that judged Israel, nor in all the days of the kings of Israel, nor of the kings of Judah;
10189	336	23	But in the eighteenth year of king Josiah, wherein this passover was holden to the LORD in Jerusalem.
10190	336	24	Moreover the workers with familiar spirits, and the wizards, and the images, and the idols, and all the abominations that were spied in the land of Judah and in Jerusalem, did Josiah put away, that he might perform the words of the law which were written in the book that Hilkiah the priest found in the house of the LORD.
10191	336	25	And like unto him was there no king before him, that turned to the LORD with all his heart, and with all his soul, and with all his might, according to all the law of Moses; neither after him arose there any like him.
10192	336	26	Notwithstanding the LORD turned not from the fierceness of his great wrath, wherewith his anger was kindled against Judah, because of all the provocations that Manasseh had provoked him withal.
10193	336	27	And the LORD said, I will remove Judah also out of my sight, as I have removed Israel, and will cast off this city Jerusalem which I have chosen, and the house of which I said, My name shall be there.
10194	336	28	Now the rest of the acts of Josiah, and all that he did, are they not written in the book of the chronicles of the kings of Judah?
10195	336	29	In his days Pharaoh-nechoh king of Egypt went up against the king of Assyria to the river Euphrates: and king Josiah went against him; and he slew him at Megiddo, when he had seen him.
10196	336	30	And his servants carried him in a chariot dead from Megiddo, and brought him to Jerusalem, and buried him in his own sepulchre. And the people of the land took Jehoahaz the son of Josiah, and anointed him, and made him king in his father's stead.
10197	336	31	Jehoahaz was twenty and three years old when he began to reign; and he reigned three months in Jerusalem. And his mother's name was Hamutal, the daughter of Jeremiah of Libnah.
10198	336	32	And he did that which was evil in the sight of the LORD, according to all that his fathers had done.
10199	336	33	And Pharaoh-nechoh put him in bands at Riblah in the land of Hamath, that he might not reign in Jerusalem; and put the land to a tribute of an hundred talents of silver, and a talent of gold.
10200	336	34	And Pharaoh-nechoh made Eliakim the son of Josiah king in the room of Josiah his father, and turned his name to Jehoiakim, and took Jehoahaz away: and he came to Egypt, and died there.
10201	336	35	And Jehoiakim gave the silver and the gold to Pharaoh; but he taxed the land to give the money according to the commandment of Pharaoh: he exacted the silver and the gold of the people of the land, of every one according to his taxation, to give it unto Pharaoh-nechoh.
10202	336	36	Jehoiakim was twenty and five years old when he began to reign; and he reigned eleven years in Jerusalem. And his mother's name was Zebudah, the daughter of Pedaiah of Rumah.
10203	336	37	And he did that which was evil in the sight of the LORD, according to all that his fathers had done.
10204	337	1	IN his days Nebuchadnezzar king of Babylon came up, and Jehoiakim became his servant three years: then he turned and rebelled against him.
10205	337	2	And the LORD sent against him bands of the Chaldees, and bands of the Syrians, and bands of the Moabites, and bands of the children of Ammon, and sent them against Judah to destroy it, according to the word of the LORD, which he spake by his servants the prophets.
10206	337	3	Surely at the commandment of the LORD came this upon Judah, to remove them out of his sight, for the sins of Manasseh, according to all that he did;
10207	337	4	And also for the innocent blood that he shed: for he filled Jerusalem with innocent blood; which the LORD would not pardon.
10208	337	5	Now the rest of the acts of Jehoiakim, and all that he did, are they not written in the book of the chronicles of the kings of Judah?
10209	337	6	So Jehoiakim slept with his fathers: and Jehoiachin his son reigned in his stead.
10210	337	7	And the king of Egypt came not again any more out of his land: for the king of Babylon had taken from the river of Egypt unto the river Euphrates all that pertained to the king of Egypt.
10211	337	8	Jehoiachin was eighteen years old when he began to reign, and he reigned in Jerusalem three months. And his mother's name was Nehushta, the daughter of Elnathan of Jerusalem.
10212	337	9	And he did that which was evil in the sight of the LORD, according to all that his father had done.
10213	337	10	At that time the servants of Nebuchadnezzar king of Babylon came up against Jerusalem, and the city was besieged.
10214	337	11	And Nebuchadnezzar king of Babylon came against the city, and his servants did besiege it.
10215	337	12	And Jehoiachin the king of Judah went out to the king of Babylon, he, and his mother, and his servants, and his princes, and his officers: and the king of Babylon took him in the eighth year of his reign.
10216	337	13	And he carried out thence all the treasures of the house of the LORD, and the treasures of the king's house, and cut in pieces all the vessels of gold which Solomon king of Israel had made in the temple of the LORD, as the LORD had said.
10217	337	14	And he carried away all Jerusalem, and all the princes, and all the mighty men of valour, even ten thousand captives, and all the craftsmen and smiths: none remained, save the poorest sort of the people of the land.
10218	337	15	And he carried away Jehoiachin to Babylon, and the king's mother, and the king's wives, and his officers, and the mighty of the land, those carried he into captivity from Jerusalem to Babylon.
10219	337	16	And all the men of might, even seven thousand, and craftsmen and smiths a thousand, all that were strong and apt for war, even them the king of Babylon brought captive to Babylon.
10220	337	17	And the king of Babylon made Mattaniah his father's brother king in his stead, and changed his name to Zedekiah.
10221	337	18	Zedekiah was twenty and one years old when he began to reign, and he reigned eleven years in Jerusalem. And his mother's name was Hamutal, the daughter of Jeremiah of Libnah.
10222	337	19	And he did that which was evil in the sight of the LORD, according to all that Jehoiakim had done.
10223	337	20	For through the anger of the LORD it came to pass in Jerusalem and Judah, until he had cast them out from his presence, that Zedekiah rebelled against the king of Babylon.
10224	338	1	AND it came to pass in the ninth year of his reign, in the tenth month, in the tenth day of the month, that Nebuchadnezzar king of Babylon came, he, and all his host, against Jerusalem, and pitched against it; and they built forts against it round about.
10225	338	2	And the city was besieged unto the eleventh year of king Zedekiah.
10226	338	3	And on the ninth day of the fourth month the famine prevailed in the city, and there was no bread for the people of the land.
10227	338	4	And the city was broken up, and all the men of war fled by night by the way of the gate between two walls, which is by the king's garden: (now the Chaldees were against the city round about:) and the king went the way toward the plain.
10228	338	5	And the army of the Chaldees pursued after the king, and overtook him in the plains of Jericho: and all his army were scattered from him.
10229	338	6	So they took the king, and brought him up to the king of Babylon to Riblah; and they gave judgment upon him.
10230	338	7	And they slew the sons of Zedekiah before his eyes, and put out the eyes of Zedekiah, and bound him with fetters of brass, and carried him to Babylon.
10231	338	8	And in the fifth month, on the seventh day of the month, which is the nineteenth year of king Nebuchadnezzar king of Babylon, came Nebuzar-adan, captain of the guard, a servant of the king of Babylon, unto Jerusalem:
10232	338	9	And he burnt the house of the LORD, and the king's house, and all the houses of Jerusalem, and every great man's house burnt he with fire.
10233	338	10	And all the army of the Chaldees, that were with the captain of the guard, brake down the walls of Jerusalem round about.
10234	338	11	Now the rest of the people that were left in the city, and the fugitives that fell away to the king of Babylon, with the remnant of the multitude, did Nebuzar-adan the captain of the guard carry away.
10235	338	12	But the captain of the guard left of the poor of the land to be vinedressers and husbandmen.
10236	338	13	And the pillars of brass that were in the house of the LORD, and the bases, and the brasen sea that was in the house of the LORD, did the Chaldees break in pieces, and carried the brass of them to Babylon.
10237	338	14	And the pots, and the shovels, and the snuffers, and the spoons, and all the vessels of brass wherewith they ministered, took they away.
10238	338	15	And the firepans, and the bowls, and such things as were of gold, in gold, and of silver, in silver, the captain of the guard took away.
10239	338	16	The two pillars, one sea, and the bases which Solomon had made for the house of the LORD; the brass of all these vessels was without weight.
10240	338	17	The height of the one pillar was eighteen cubits, and the chapiter upon it was brass: and the height of the chapiter three cubits; and the wreathen work, and pomegranates upon the chapiter round about, all of brass: and like unto these had the second pillar with wreathen work.
10241	338	18	And the captain of the guard took Seraiah the chief priest, and Zephaniah the second priest, and the three keepers of the door:
10242	338	19	And out of the city he took an officer that was set over the men of war, and five men of them that were in the king's presence, which were found in the city, and the principal scribe of the host, which mustered the people of the land, and threescore men of the people of the land that were found in the city:
10243	338	20	And Nebuzar-adan captain of the guard took these, and brought them to the king of Babylon to Riblah:
10244	338	21	And the king of Babylon smote them, and slew them at Riblah in the land of Hamath. So Judah was carried away out of their land.
10245	338	22	And as for the people that remained in the land of Judah, whom Nebuchadnezzar king of Babylon had left, even over them he made Gedaliah the son of Ahikam, the son of Shaphan, ruler.
10246	338	23	And when all the captains of the armies, they and their men, heard that the king of Babylon had made Gedaliah governor, there came to Gedaliah to Mizpah, even Ishmael the son of Nethaniah, and Johanan the son of Careah, and Seraiah the son of Tanhumeth the Netophathite, and Jaazaniah the son of a Maachathite, they and their men.
10247	338	24	And Gedaliah sware to them, and to their men, and said unto them, Fear not to be the servants of the Chaldees: dwell in the land, and serve the king of Babylon; and it shall be well with you.
10248	338	25	But it came to pass in the seventh month, that Ishmael the son of Nethaniah, the son of Elishama, of the seed royal, came, and ten men with him, and smote Gedaliah, that he died, and the Jews and the Chaldees that were with him at Mizpah.
10249	338	26	And all the people, both small and great, and the captains of the armies, arose, and came to Egypt: for they were afraid of the Chaldees.
10250	338	27	And it came to pass in the seven and thirtieth year of the captivity of Jehoiachin king of Judah, in the twelfth month, on the seven and twentieth day of the month, that Evil-merodach king of Babylon in the year that he began to reign did lift up the head of Jehoiachin king of Judah out of prison;
10251	338	28	And he spake kindly to him, and set his throne above the throne of the kings that were with him in Babylon;
10252	338	29	And changed his prison garments: and he did eat bread continually before him all the days of his life.
10253	338	30	And his allowance was a continual allowance given him of the king, a daily rate for every day, all the days of his life.
10254	339	1	ADAM, Sheth, Enosh,
10255	339	2	Kenan, Mahalaleel, Jered,
10256	339	3	Henoch, Methuselah, Lamech,
10257	339	4	Noah, Shem, Ham, and Japheth.
10258	339	5	The sons of Japheth; Gomer, and Magog, and Madai, and Javan, and Tubal, and Meshech, and Tiras.
10259	339	6	And the sons of Gomer; Ashchenaz, and Riphath, and Togarmah.
10260	339	7	And the sons of Javan; Elishah, and Tarshish, Kittim, and Dodanim.
10261	339	8	The sons of Ham; Cush, and Mizraim, Put, and Canaan.
10262	339	9	And the sons of Cush; Seba, and Havilah, and Sabta, and Raamah, and Sabtecha. And the sons of Raamah; Sheba, and Dedan.
10263	339	10	And Cush begat Nimrod: he began to be mighty upon the earth.
10264	339	11	And Mizraim begat Ludim, and Anamim, and Lehabim, and Naphtuhim,
10265	339	12	And Pathrusim, and Casluhim, (of whom came the Philistines,) and Caphthorim.
10266	339	13	And Canaan begat Zidon his firstborn, and Heth,
10267	339	14	The Jebusite also, and the Amorite, and the Girgashite,
10268	339	15	And the Hivite, and the Arkite, and the Sinite,
10269	339	16	And the Arvadite, and the Zemarite, and the Hamathite.
10270	339	17	The sons of Shem; Elam, and Asshur, and Arphaxad, and Lud, and Aram, and Uz, and Hul, and Gether, and Meshech.
10271	339	18	And Arphaxad begat Shelah, and Shelah begat Eber.
10272	339	19	And unto Eber were born two sons: the name of the one was Peleg; because in his days the earth was divided: and his brother's name was Joktan.
10273	339	20	And Joktan begat Almodad, and Sheleph, and Hazarmaveth, and Jerah,
10274	339	21	Hadoram also, and Uzal, and Diklah,
10275	339	22	And Ebal, and Abimael, and Sheba,
10276	339	23	And Ophir, and Havilah, and Jobab. All these were the sons of Joktan.
10277	339	24	Shem, Arphaxad, Shelah,
10278	339	25	Eber, Peleg, Reu,
10279	339	26	Serug, Nahor, Terah,
10280	339	27	Abram; the same is Abraham.
10281	339	28	The sons of Abraham; Isaac, and Ishmael.
10282	339	29	These are their generations: The firstborn of Ishmael, Nebaioth; then Kedar, and Adbeel, and Mibsam,
10283	339	30	Mishma and Dumah, Massa, Hadad, and Tema,
10284	339	31	Jetur, Naphish, and Kedemah. These are the sons of Ishmael.
10285	339	32	Now the sons of Keturah, Abraham's concubine: she bare Zimran, and Jokshan, and Medan, and Midian, and Ishbak, and Shuah. And the sons of Jokshan; Sheba, and Dedan.
10286	339	33	And the sons of Midian; Ephah, and Epher, and Henoch, and Abida, and Eldaah. All these are the sons of Keturah.
10287	339	34	And Abraham begat Isaac. The sons of Isaac; Esau and Israel.
10288	339	35	The sons of Esau; Eliphaz, Reuel, and Jeush, and Jaalam, and Korah.
10289	339	36	The sons of Eliphaz; Teman, and Omar, Zephi, and Gatam, Kenaz, and Timna, and Amalek.
10290	339	37	The sons of Reuel; Nahath, Zerah, Shammah, and Mizzah.
10291	339	38	And the sons of Seir; Lotan, and Shobal, and Zibeon, and Anah, and Dishon, and Ezer, and Dishan.
10292	339	39	And the sons of Lotan; Hori, and Homam: and Timna was Lotan's sister.
10293	339	40	The sons of Shobal; Alian, and Manahath, and Ebal, Shephi, and Onam. And the sons of Zibeon; Aiah, and Anah.
10294	339	41	The sons of Anah; Dishon. And the sons of Dishon; Amram, and Eshban, and Ithran, and Cheran.
10295	339	42	The sons of Ezer; Bilhan, and Zavan, and Jakan. The sons of Dishan; Uz, and Aran.
10296	339	43	Now these are the kings that reigned in the land of Edom before any king reigned over the children of Israel; Bela the son of Beor: and the name of his city was Dinhabah.
10297	339	44	And when Bela was dead, Jobab the son of Zerah of Bozrah reigned in his stead.
10298	339	45	And when Jobab was dead, Husham of the land of the Temanites reigned in his stead.
10299	339	46	And when Husham was dead, Hadad the son of Bedad, which smote Midian in the field of Moab, reigned in his stead: and the name of his city was Avith.
10300	339	47	And when Hadad was dead, Samlah of Masrekah reigned in his stead.
10301	339	48	And when Samlah was dead, Shaul of Rehoboth by the river reigned in his stead.
10302	339	49	And when Shaul was dead, Baal-hanan the son of Achbor reigned in his stead.
10303	339	50	And when Baal-hanan was dead, Hadad reigned in his stead: and the name of his city was Pai; and his wife's name was Mehetabel, the daughter of Matred, the daughter of Mezahab.
10304	339	51	Hadad died also. And the dukes of Edom were; duke Timnah, duke Aliah, duke Jetheth,
10305	339	52	Duke Aholibamah, duke Elah, duke Pinon,
10306	339	53	Duke Kenaz, duke Teman, duke Mibzar,
10307	339	54	Duke Magdiel, duke Iram. These are the dukes of Edom.
10308	340	1	THESE are the sons of Israel; Reuben, Simeon, Levi, and Judah, Issachar, and Zebulun,
10309	340	2	Dan, Joseph, and Benjamin, Naphtali, Gad, and Asher.
10310	340	3	The sons of Judah; Er, and Onan, and Shelah: which three were born unto him of the daughter of Shua the Canaanitess. And Er, the firstborn of Judah, was evil in the sight of the LORD; and he slew him.
10311	340	4	And Tamar his daughter in law bare him Pharez and Zerah. All the sons of Judah were five.
10312	340	5	The sons of Pharez; Hezron, and Hamul.
10313	340	6	And the sons of Zerah; Zimri, and Ethan, and Heman, and Calcol, and Dara: five of them in all.
10314	340	7	And the sons of Carmi; Achar, the troubler of Israel, who transgressed in the thing accursed.
10315	340	8	And the sons of Ethan; Azariah.
10316	340	9	The sons also of Hezron, that were born unto him; Jerahmeel, and Ram, and Chelubai.
10317	340	10	And Ram begat Amminadab; and Amminadab begat Nahshon, prince of the children of Judah;
10318	340	11	And Nahshon begat Salma, and Salma begat Boaz,
10319	340	12	And Boaz begat Obed, and Obed begat Jesse,
10320	340	13	And Jesse begat his firstborn Eliab, and Abinadab the second, and Shimma the third,
10321	340	14	Nethaneel the fourth, Raddai the fifth,
10322	340	15	Ozem the sixth, David the seventh:
10323	340	16	Whose sisters were Zeruiah, and Abigail. And the sons of Zeruiah; Abishai, and Joab, and Asahel, three.
10324	340	17	And Abigail bare Amasa: and the father of Amasa was Jether the Ishmeelite.
10325	340	18	And Caleb the son of Hezron begat children of Azubah his wife, and of Jerioth: her sons are these; Jesher, and Shobab, and Ardon.
10326	340	19	And when Azubah was dead, Caleb took unto him Ephrath, which bare him Hur.
10327	340	20	And Hur begat Uri, and Uri begat Bezaleel.
10328	340	21	And afterward Hezron went in to the daughter of Machir the father of Gilead, whom he married when he was threescore years old; and she bare him Segub.
10329	340	22	And Segub begat Jair, who had three and twenty cities in the land of Gilead.
10330	340	23	And he took Geshur, and Aram, with the towns of Jair, from them, with Kenath, and the towns thereof, even threescore cities. All these belonged to the sons of Machir the father of Gilead.
10331	340	24	And after that Hezron was dead in Caleb-ephratah, then Abiah Hezron's wife bare him Ashur the father of Tekoa.
10332	340	25	And the sons of Jerahmeel the firstborn of Hezron were, Ram the firstborn, and Bunah, and Oren, and Ozem, and Ahijah.
10333	340	26	Jerahmeel had also another wife, whose name was Atarah; she was the mother of Onam.
10334	340	27	And the sons of Ram the firstborn of Jerahmeel were, Maaz, and Jamin, and Eker.
10335	340	28	And the sons of Onam were, Shammai, and Jada. And the sons of Shammai; Nadab, and Abishur.
10336	340	29	And the name of the wife of Abishur was Abihail, and she bare him Ahban, and Molid.
10337	340	30	And the sons of Nadab; Seled, and Appaim: but Seled died without children.
10338	340	31	And the sons of Appaim; Ishi. And the sons of Ishi; Sheshan. And the children of Sheshan; Ahlai.
10339	340	32	And the sons of Jada the brother of Shammai; Jether, and Jonathan: and Jether died without children.
10340	340	33	And the sons of Jonathan; Peleth, and Zaza. These were the sons of Jerahmeel.
10341	340	34	Now Sheshan had no sons, but daughters. And Sheshan had a servant, an Egyptian, whose name was Jarha.
10342	340	35	And Sheshan gave his daughter to Jarha his servant to wife; and she bare him Attai.
10343	340	36	And Attai begat Nathan, and Nathan begat Zabad,
10344	340	37	And Zabad begat Ephlal, and Ephlal begat Obed,
10345	340	38	And Obed begat Jehu, and Jehu begat Azariah,
10346	340	39	And Azariah begat Helez, and Helez begat Eleasah,
10347	340	40	And Eleasah begat Sisamai, and Sisamai begat Shallum,
10348	340	41	And Shallum begat Jekamiah, and Jekamiah begat Elishama.
10349	340	42	Now the sons of Caleb the brother of Jerahmeel were, Mesha his firstborn, which was the father of Ziph; and the sons of Mareshah the father of Hebron.
10350	340	43	And the sons of Hebron; Korah, and Tappuah, and Rekem, and Shema.
10351	340	44	And Shema begat Raham, the father of Jorkoam: and Rekem begat Shammai.
10352	340	45	And the son of Shammai was Maon: and Maon was the father of Beth-zur.
10353	340	46	And Ephah, Caleb's concubine, bare Haran, and Moza, and Gazez: and Haran begat Gazez.
10354	340	47	And the sons of Jahdai; Regem, and Jotham, and Geshan, and Pelet, and Ephah, and Shaaph.
10355	340	48	Maachah, Caleb's concubine, bare Sheber, and Tirhanah.
10356	340	49	She bare also Shaaph the father of Madmannah, Sheva the father of Machbenah, and the father of Gibea: and the daughter of Caleb was Achsah.
10357	340	50	These were the sons of Caleb the son of Hur, the firstborn of Ephratah; Shobal the father of Kirjath-jearim,
10358	340	51	Salma the father of Beth-lehem, Hareph the father of Beth-gader.
10359	340	52	And Shobal the father of Kirjath-jearim had sons; Haroeh, and half of the Manahethites.
10360	340	53	And the families of Kirjath-jearim; the Ithrites, and the Puhites, and the Shumathites, and the Mishraites; of them came the Zareathites, and the Eshtaulites.
10361	340	54	The sons of Salma; Beth-lehem, and the Netophathites, Ataroth, the house of Joab, and half of the Manahethites, the Zorites.
10362	340	55	And the families of the scribes which dwelt at Jabez; the Tirathites, the Shimeathites, and Suchathites. These are the Kenites that came of Hemath, the father of the house of Rechab.
10363	341	1	NOW these were the sons of David, which were born unto him in Hebron; the firstborn Amnon, of Ahinoam the Jezreelitess; the second Daniel, of Abigail the Carmelitess:
10364	341	2	The third, Absalom the son of Maachah the daughter of Talmai king of Geshur: the fourth, Adonijah the son of Haggith:
10365	341	3	The fifth, Shephatiah of Abital: the sixth, Ithream by Eglah his wife.
10366	341	4	These six were born unto him in Hebron; and there he reigned seven years and six months: and in Jerusalem he reigned thirty and three years.
10367	341	5	And these were born unto him in Jerusalem; Shimea, and Shobab, and Nathan, and Solomon, four, of Bath-shua the daughter of Ammiel:
10368	341	6	Ibhar also, and Elishama, and Eliphelet,
10369	341	7	And Nogah, and Nepheg, and Japhia,
10370	341	8	And Elishama, and Eliada, and Eliphelet, nine.
10371	341	9	These were all the sons of David, beside the sons of the concubines, and Tamar their sister.
10372	341	10	And Solomon's son was Rehoboam, Abia his son, Asa his son, Jehoshaphat his son,
10373	341	11	Joram his son, Ahaziah his son, Joash his son,
10374	341	12	Amaziah his son, Azariah his son, Jotham his son,
10375	341	13	Ahaz his son, Hezekiah his son, Manasseh his son,
10376	341	14	Amon his son, Josiah his son.
10377	341	15	And the sons of Josiah were, the firstborn Johanan, the second Jehoiakim, the third Zedekiah, the fourth Shallum.
10378	341	16	And the sons of Jehoiakim: Jeconiah his son, Zedekiah his son.
10379	341	17	And the sons of Jeconiah; Assir, Salathiel his son,
10380	341	18	Malchiram also, and Pedaiah, and Shenazar, Jecamiah, Hoshama, and Nedabiah.
10381	341	19	And the sons of Pedaiah were, Zerubbabel, and Shimei: and the sons of Zerubbabel; Meshullam, and Hananiah, and Shelomith their sister:
10382	341	20	And Hashubah, and Ohel, and Berechiah, and Hasadiah, Jushab-hesed, five.
10383	341	21	And the sons of Hananiah; Pelatiah, and Jesaiah: the sons of Rephaiah, the sons of Arnan, the sons of Obadiah, the sons of Shechaniah.
10384	341	22	And the sons of Shechaniah; Shemaiah; and the sons of Shemaiah; Hattush, and Igeal, and Bariah, and Neariah, and Shaphat, six.
10385	341	23	And the sons of Neariah; Elioenai, and Hezekiah, and Azrikam, three.
10386	341	24	And the sons of Elioenai were, Hodaiah, and Eliashib, and Pelaiah, and Akkub, and Johanan, and Dalaiah, and Anani, seven.
10387	342	1	THE sons of Judah; Pharez, Hezron, and Carmi, and Hur, and Shobal.
10388	342	2	And Reaiah the son of Shobal begat Jahath; and Jahath begat Ahumai, and Lahad. These are the families of the Zorathites.
10389	342	3	And these were of the father of Etam; Jezreel, and Ishma, and Idbash: and the name of their sister was Hazelelponi:
10390	342	4	And Penuel the father of Gedor and Ezer the father of Hushah. These are the sons of Hur, the firstborn of Ephratah, the father of Beth-lehem.
10391	342	5	And Ashur the father of Tekoa had two wives, Helah and Naarah.
10392	342	6	And Naarah bare him Ahuzam, and Hepher, and Temeni, and Haahashtari. These were the sons of Naarah.
10393	342	7	And the sons of Helah were, Zereth, and Jezoar, and Ethnan.
10394	342	8	And Coz begat Anub, and Zobebah, and the families of Aharhel the son of Harum.
10395	342	9	And Jabez was more honourable than his brethren: and his mother called his name Jabez, saying, Because I bare him with sorrow.
10396	342	10	And Jabez called on the God of Israel, saying, Oh that thou wouldest bless me indeed, and enlarge my coast, and that thine hand might be with me, and that thou wouldest keep me from evil, that it may not grieve me! And God granted him that which he requested.
10397	342	11	And Chelub the brother of Shuah begat Mehir, which was the father of Eshton.
10398	342	12	And Eshton begat Beth-rapha, and Paseah, and Tehinnah the father of Irnahash. These are the men of Rechah.
10399	342	13	And the sons of Kenaz; Othniel, and Seraiah: and the sons of Othniel; Hathath.
10400	342	14	And Meonothai begat Ophrah: and Seraiah begat Joab, the father of the valley of Charashim; for they were craftsmen.
10401	342	15	And the sons of Caleb the son of Jephunneh; Iru, Elah, and Naam: and the sons of Elah, even Kenaz.
10402	342	16	And the sons of Jehaleleel; Ziph, and Ziphah, Tiria, and Asareel.
10403	342	17	And the sons of Ezra were, Jether, and Mered, and Epher, and Jalon: and she bare Miriam, and Shammai, and Ishbah the father of Eshtemoa.
10404	342	18	And his wife Jehudijah bare Jered the father of Gedor, and Heber the father of Socho, and Jekuthiel the father of Zanoah. And these are the sons of Bithiah the daughter of Pharaoh, which Mered took.
10405	342	19	And the sons of his wife Hodiah the sister of Naham, the father of Keilah the Garmite, and Eshtemoa the Maachathite.
10406	342	20	And the sons of Shimon were, Amnon, and Rinnah, Ben-hanan, and Tilon. And the sons of Ishi were, Zoheth, and Ben-zoheth.
10407	342	21	The sons of Shelah the son of Judah were, Er the father of Lecah, and Laadah the father of Mareshah, and the families of the house of them that wrought fine linen, of the house of Ashbea,
10408	342	22	And Jokim, and the men of Chozeba, and Joash, and Saraph, who had the dominion in Moab, and Jashubi-lehem. And these are ancient things.
10409	342	23	These were the potters, and those that dwelt among plants and hedges: there they dwelt with the king for his work.
10410	342	24	The sons of Simeon were, Nemuel, and Jamin, Jarib, Zerah, and Shaul:
10411	342	25	Shallum his son, Mibsam his son, Mishma his son.
10412	342	26	And the sons of Mishma; Hamuel his son, Zacchur his son, Shimei his son.
10413	342	27	And Shimei had sixteen sons and six daughters; but his brethren had not many children, neither did all their family multiply, like to the children of Judah.
10414	342	28	And they dwelt at Beer-sheba, and Moladah, and Hazar-shual,
10415	342	29	And at Bilhah, and at Ezem, and at Tolad,
10416	342	30	And at Bethuel, and at Hormah, and at Ziklag,
10417	342	31	And at Beth-marcaboth, and Hazar-susim, and at Beth-birei, and at Shaaraim. These were their cities unto the reign of David.
10418	342	32	And their villages were, Etam, and Ain, Rimmon, and Tochen, and Ashan, five cities:
10419	342	33	And all their villages that were round about the same cities, unto Baal. These were their habitations, and their genealogy.
10420	342	34	And Meshobab, and Jamlech, and Joshah the son of Amaziah,
10421	342	35	And Joel, and Jehu the son of Josibiah, the son of Seraiah, the son of Asiel,
10422	342	36	And Elioenai, and Jaakobah, and Jeshohaiah, and Asaiah, and Adiel, and Jesimiel, and Benaiah,
10423	342	37	And Ziza the son of Shiphi, the son of Allon, the son of Jedaiah, the son of Shimri, the son of Shemaiah;
10424	342	38	These mentioned by their names were princes in their families: and the house of their fathers increased greatly.
10425	342	39	And they went to the entrance of Gedor, even unto the east side of the valley, to seek pasture for their flocks.
10426	342	40	And they found fat pasture and good, and the land was wide, and quiet, and peaceable; for they of Ham had dwelt there of old.
10427	342	41	And these written by name came in the days of Hezekiah king of Judah, and smote their tents, and the habitations that were found there, and destroyed them utterly unto this day, and dwelt in their rooms: because there was pasture there for their flocks.
10428	342	42	And some of them, even of the sons of Simeon, five hundred men, went to mount Seir, having for their captains Pelatiah, and Neariah, and Rephaiah, and Uzziel, the sons of Ishi.
10429	342	43	And they smote the rest of the Amalekites that were escaped, and dwelt there unto this day.
10430	343	1	NOW the sons of Reuben the firstborn of Israel, (for he was the firstborn; but, forasmuch as he defiled his father's bed, his birthright was given unto the sons of Joseph the son of Israel: and the genealogy is not to be reckoned after the birthright.
10431	343	2	For Judah prevailed above his brethren, and of him came the chief ruler; but the birthright was Joseph's:)
10432	343	3	The sons, I say, of Reuben the firstborn of Israel were, Hanoch, and Pallu, Hezron, and Carmi.
10433	343	4	The sons of Joel; Shemaiah his son, Gog his son, Shimei his son,
10434	343	5	Micah his son, Reaia his son, Baal his son,
10435	343	6	Beerah his son, whom Tilgath-pilneser king of Assyria carried away captive: he was prince of the Reubenites.
10436	343	7	And his brethren by their families, when the genealogy of their generations was reckoned, were the chief, Jeiel, and Zechariah,
10437	343	8	And Bela the son of Azaz, the son of Shema, the son of Joel, who dwelt in Aroer, even unto Nebo and Baal-meon:
10438	343	9	And eastward he inhabited unto the entering in of the wilderness from the river Euphrates: because their cattle were multiplied in the land of Gilead.
10439	343	10	And in the days of Saul they made war with the Hagarites, who fell by their hand: and they dwelt in their tents throughout all the east land of Gilead.
10440	343	11	And the children of Gad dwelt over against them, in the land of Bashan unto Salchah:
10441	343	12	Joel the chief, and Shapham the next, and Jaanai, and Shaphat in Bashan.
10442	343	13	And their brethren of the house of their fathers were, Michael, and Meshullam, and Sheba, and Jorai, and Jachan, and Zia, and Heber, seven.
10443	343	14	These are the children of Abihail the son of Huri, the son of Jaroah, the son of Gilead, the son of Michael, the son of Jeshishai, the son of Jahdo, the son of Buz;
10444	343	15	Ahi the son of Abdiel, the son of Guni, chief of the house of their fathers.
10445	343	16	And they dwelt in Gilead in Bashan, and in her towns, and in all the suburbs of Sharon, upon their borders.
10446	343	17	All these were reckoned by genealogies in the days of Jotham king of Judah, and in the days of Jeroboam king of Israel.
10447	343	18	The sons of Reuben, and the Gadites, and half the tribe of Manasseh, of valiant men, men able to bear buckler and sword, and to shoot with bow, and skilful in war, were four and forty thousand seven hundred and threescore, that went out to the war.
10448	343	19	And they made war with the Hagarites, with Jetur, and Nephish, and Nodab.
10449	343	20	And they were helped against them, and the Hagarites were delivered into their hand, and all that were with them: for they cried to God in the battle, and he was intreated of them; because they put their trust in him.
10450	343	21	And they took away their cattle; of their camels fifty thousand, and of sheep two hundred and fifty thousand, and of asses two thousand, and of men an hundred thousand.
10451	343	22	For there fell down many slain, because the war was of God. And they dwelt in their steads until the captivity.
10452	343	23	And the children of the half tribe of Manasseh dwelt in the land: they increased from Bashan unto Baal-hermon and Senir, and unto mount Hermon.
10453	343	24	And these were the heads of the house of their fathers, even Epher, and Ishi, and Eliel, and Azriel, and Jeremiah, and Hodaviah, and Jahdiel, mighty men of valour, famous men, and heads of the house of their fathers.
10454	343	25	And they transgressed against the God of their fathers, and went a whoring after the gods of the people of the land, whom God destroyed before them.
10455	343	26	And the God of Israel stirred up the spirit of Pul king of Assyria, and the spirit of Tilgath-pilneser king of Assyria, and he carried them away, even the Reubenites, and the Gadites, and the half tribe of Manasseh, and brought them unto Halah, and Habor, and Hara, and to the river Gozan, unto this day.
10456	344	1	THE sons of Levi; Gershon, Kohath, and Merari.
10457	344	2	And the sons of Kohath; Amram, Izhar, and Hebron, and Uzziel.
10458	344	3	And the children of Amram; Aaron, and Moses, and Miriam. The sons also of Aaron; Nadab, and Abihu, Eleazar, and Ithamar.
10459	344	4	Eleazar begat Phinehas, Phinehas begat Abishua,
10460	344	5	And Abishua begat Bukki, and Bukki begat Uzzi,
10461	344	6	And Uzzi begat Zerahiah, and Zerahiah begat Meraioth,
10462	344	7	Meraioth begat Amariah, and Amariah begat Ahitub,
10463	344	8	And Ahitub begat Zadok, and Zadok begat Ahimaaz,
10464	344	9	And Ahimaaz begat Azariah, and Azariah begat Johanan,
10465	344	10	And Johanan begat Azariah, (he it is that executed the priest's office in the temple that Solomon built in Jerusalem:)
10466	344	11	And Azariah begat Amariah, and Amariah begat Ahitub,
10467	344	12	And Ahitub begat Zadok, and Zadok begat Shallum,
10468	344	13	And Shallum begat Hilkiah, and Hilkiah begat Azariah,
10469	344	14	And Azariah begat Seraiah, and Seraiah begat Jehozadak,
10470	344	15	And Jehozadak went into captivity, when the LORD carried away Judah and Jerusalem by the hand of Nebuchadnezzar.
10471	344	16	The sons of Levi; Gershom, Kohath, and Merari.
10472	344	17	And these be the names of the sons of Gershom; Libni, and Shimei.
10473	344	18	And the sons of Kohath were, Amram, and Izhar, and Hebron, and Uzziel.
10474	344	19	The sons of Merari; Mahli, and Mushi. And these are the families of the Levites according to their fathers.
10475	344	20	Of Gershom; Libni his son, Jahath his son, Zimmah his son,
10476	344	21	Joah his son, Iddo his son, Zerah his son, Jeaterai his son.
10477	344	22	The sons of Kohath; Amminadab his son, Korah his son, Assir his son,
10478	344	23	Elkanah his son, and Ebiasaph his son, and Assir his son,
10479	344	24	Tahath his son, Uriel his son, Uzziah his son, and Shaul his son.
10480	344	25	And the sons of Elkanah; Amasai, and Ahimoth.
10481	344	26	As for Elkanah: the sons of Elkanah; Zophai his son, and Nahath his son,
10482	344	27	Eliab his son, Jeroham his son, Elkanah his son.
10483	344	28	And the sons of Samuel; the firstborn Vashni, and Abiah.
10484	344	29	The sons of Merari; Mahli, Libni his son, Shimei his son, Uzza his son,
10485	344	30	Shimea his son, Haggiah his son, Asaiah his son.
10486	344	31	And these are they whom David set over the service of song in the house of the LORD, after that the ark had rest.
10487	344	32	And they ministered before the dwelling place of the tabernacle of the congregation with singing, until Solomon had built the house of the LORD in Jerusalem: and then they waited on their office according to their order.
10488	344	33	And these are they that waited with their children. Of the sons of the Kohathites: Heman a singer, the son of Joel, the son of Shemuel,
10489	344	34	The son of Elkanah, the son of Jeroham, the son of Eliel, the son of Toah,
10490	344	35	The son of Zuph, the son of Elkanah, the son of Mahath, the son of Amasai,
10491	344	36	The son of Elkanah, the son of Joel, the son of Azariah, the son of Zephaniah,
10492	344	37	The son of Tahath, the son of Assir, the son of Ebiasaph, the son of Korah,
10493	344	38	The son of Izhar, the son of Kohath, the son of Levi, the son of Israel.
10494	344	39	And his brother Asaph, who stood on his right hand, even Asaph the son of Berachiah, the son of Shimea,
10495	344	40	The son of Michael, the son of Baaseiah, the son of Malchiah,
10496	344	41	The son of Ethni, the son of Zerah, the son of Adaiah,
10497	344	42	The son of Ethan, the son of Zimmah, the son of Shimei,
10498	344	43	The son of Jahath, the son of Gershom, the son of Levi.
10499	344	44	And their brethren the sons of Merari stood on the left hand: Ethan the son of Kishi, the son of Abdi, the son of Malluch,
10500	344	45	The son of Hashabiah, the son of Amaziah, the son of Hilkiah,
10501	344	46	The son of Amzi, the son of Bani, the son of Shamer,
10502	344	47	The son of Mahli, the son of Mushi, the son of Merari, the son of Levi.
10503	344	48	Their brethren also the Levites were appointed unto all manner of service of the tabernacle of the house of God.
10504	344	49	But Aaron and his sons offered upon the altar of the burnt offering, and on the altar of incense, and were appointed for all the work of the place most holy, and to make an atonement for Israel, according to all that Moses the servant of God had commanded.
10505	344	50	And these are the sons of Aaron; Eleazar his son, Phinehas his son, Abishua his son,
10506	344	51	Bukki his son, Uzzi his son, Zerahiah his son,
10507	344	52	Meraioth his son, Amariah his son, Ahitub his son,
10508	344	53	Zadok his son, Ahimaaz his son.
10509	344	54	Now these are their dwelling places throughout their castles in their coasts, of the sons of Aaron, of the families of the Kohathites: for theirs was the lot.
10510	344	55	And they gave them Hebron in the land of Judah, and the suburbs thereof round about it.
10511	344	56	But the fields of the city, and the villages thereof, they gave to Caleb the son of Jephunneh.
10512	344	57	And to the sons of Aaron they gave the cities of Judah, namely, Hebron, the city of refuge, and Libnah with her suburbs, and Jattir, and Eshtemoa, with their suburbs,
10513	344	58	And Hilen with her suburbs, Debir with her suburbs,
10514	344	59	And Ashan with her suburbs, and Beth-shemesh with her suburbs:
10515	344	60	And out of the tribe of Benjamin; Geba with her suburbs, and Alemeth with her suburbs, and Anathoth with her suburbs. All their cities throughout their families were thirteen cities.
10516	344	61	And unto the sons of Kohath, which were left of the family of that tribe, were cities given out of the half tribe, namely, out of the half tribe of Manasseh, by lot, ten cities.
10517	344	62	And to the sons of Gershom throughout their families out of the tribe of Issachar, and out of the tribe of Asher, and out of the tribe of Naphtali, and out of the tribe of Manasseh in Bashan, thirteen cities.
10518	344	63	Unto the sons of Merari were given by lot, throughout their families, out of the tribe of Reuben, and out of the tribe of Gad, and out of the tribe of Zebulun, twelve cities.
10519	344	64	And the children of Israel gave to the Levites these cities with their suburbs.
10520	344	65	And they gave by lot out of the tribe of the children of Judah, and out of the tribe of the children of Simeon, and out of the tribe of the children of Benjamin, these cities, which are called by their names.
10521	344	66	And the residue of the families of the sons of Kohath had cities of their coasts out of the tribe of Ephraim.
10522	344	67	And they gave unto them, of the cities of refuge, Shechem in mount Ephraim with her suburbs; they gave also Gezer with her suburbs,
10523	344	68	And Jokmeam with her suburbs, and Beth-horon with her suburbs,
10524	344	69	And Aijalon with her suburbs, and Gath-rimmon with her suburbs:
10525	344	70	And out of the half tribe of Manasseh; Aner with her suburbs, and Bileam with her suburbs, for the family of the remnant of the sons of Kohath.
10526	344	71	Unto the sons of Gershom were given out of the family of the half tribe of Manasseh, Golan in Bashan with her suburbs, and Ashtaroth with her suburbs:
10527	344	72	And out of the tribe of Issachar; Kedesh with her suburbs, Daberath with her suburbs,
10528	344	73	And Ramoth with her suburbs, and Anem with her suburbs:
10529	344	74	And out of the tribe of Asher; Mashal with her suburbs, and Abdon with her suburbs,
10530	344	75	And Hukok with her suburbs, and Rehob with her suburbs:
10531	344	76	And out of the tribe of Naphtali; Kedesh in Galilee with her suburbs, and Hammon with her suburbs, and Kirjathaim with her suburbs.
10532	344	77	Unto the rest of the children of Merari were given out of the tribe of Zebulun, Rimmon with her suburbs, Tabor with her suburbs:
10533	344	78	And on the other side Jordan by Jericho, on the east side of Jordan, were given them out of the tribe of Reuben, Bezer in the wilderness with her suburbs, and Jahzah with her suburbs,
10534	344	79	Kedemoth also with her suburbs, and Mephaath with her suburbs:
10535	344	80	And out of the tribe of Gad; Ramoth in Gilead with her suburbs, and Mahanaim with her suburbs,
10536	344	81	And Heshbon with her suburbs, and Jazer with her suburbs.
10537	345	1	NOW the sons of Issachar were, Tola, and Puah, Jashub, and Shimron, four.
10538	345	2	And the sons of Tola; Uzzi, and Rephaiah, and Jeriel, and Jahmai, and Jibsam, and Shemuel, heads of their father's house, to wit, of Tola: they were valiant men of might in their generations; whose number was in the days of David two and twenty thousand and six hundred.
10539	345	3	And the sons of Uzzi; Izrahiah: and the sons of Izrahiah; Michael, and Obadiah, and Joel, Ishiah, five: all of them chief men.
10540	345	4	And with them, by their generations, after the house of their fathers, were bands of soldiers for war, six and thirty thousand men: for they had many wives and sons.
10541	345	5	And their brethren among all the families of Issachar were valiant men of might, reckoned in all by their genealogies fourscore and seven thousand.
10542	345	6	The sons of Benjamin; Bela, and Becher, and Jediael, three.
10543	345	7	And the sons of Bela; Ezbon, and Uzzi, and Uzziel, and Jerimoth, and Iri, five; heads of the house of their fathers, mighty men of valour; and were reckoned by their genealogies twenty and two thousand and thirty and four.
10544	345	8	And the sons of Becher; Zemira, and Joash, and Eliezer, and Elioenai, and Omri, and Jerimoth, and Abiah, and Anathoth, and Alameth. All these are the sons of Becher.
10545	345	9	And the number of them, after their genealogy by their generations, heads of the house of their fathers, mighty men of valour, was twenty thousand and two hundred.
10546	345	10	The sons also of Jediael; Bilhan: and the sons of Bilhan; Jeush, and Benjamin, and Ehud, and Chenaanah, and Zethan, and Tharshish, and Ahishahar.
10547	345	11	All these the sons of Jediael, by the heads of their fathers, mighty men of valour, were seventeen thousand and two hundred soldiers, fit to go out for war and battle.
10548	345	12	Shuppim also, and Huppim, the children of Ir, and Hushim, the sons of Aher.
10549	345	13	The sons of Naphtali; Jahziel, and Guni, and Jezer, and Shallum, the sons of Bilhah.
10550	345	14	The sons of Manasseh; Ashriel, whom she bare: (but his concubine the Aramitess bare Machir the father of Gilead:
10551	345	15	And Machir took to wife the sister of Huppim and Shuppim, whose sister's name was Maachah;) and the name of the second was Zelophehad: and Zelophehad had daughters.
10552	345	16	And Maachah the wife of Machir bare a son, and she called his name Peresh; and the name of his brother was Sheresh; and his sons were Ulam and Rakem.
10553	345	17	And the sons of Ulam; Bedan. These were the sons of Gilead, the son of Machir, the son of Manasseh.
10554	345	18	And his sister Hammoleketh bare Ishod, and Abiezer, and Mahalah.
10555	345	19	And the sons of Shemida were, Ahian, and Shechem, and Likhi, and Aniam.
10556	345	20	And the sons of Ephraim; Shuthelah, and Bered his son, and Tahath his son, and Eladah his son, and Tahath his son,
10557	345	21	And Zabad his son, and Shuthelah his son, and Ezer, and Elead, whom the men of Gath that were born in that land slew, because they came down to take away their cattle.
10558	345	22	And Ephraim their father mourned many days, and his brethren came to comfort him.
10559	345	23	And when he went in to his wife, she conceived, and bare a son, and he called his name Beriah, because it went evil with his house.
10560	345	24	(And his daughter was Sherah, who built Beth-horon the nether, and the upper, and Uzzen-sherah.)
10561	345	25	And Rephah was his son, also Resheph, and Telah his son, and Tahan his son,
10562	345	26	Laadan his son, Ammihud his son, Elishama his son,
10563	345	27	Non his son, Jehoshua his son.
10564	345	28	And their possessions and habitations were, Beth-el and the towns thereof, and eastward Naaran, and westward Gezer, with the towns thereof; Shechem also and the towns thereof, unto Gaza and the towns thereof:
10565	345	29	And by the borders of the children of Manasseh, Beth-shean and her towns, Taanach and her towns, Megiddo and her towns, Dor and her towns. In these dwelt the children of Joseph the son of Israel.
10566	345	30	The sons of Asher; Imnah, and Isuah, and Ishuai, and Beriah, and Serah their sister.
10567	345	31	And the sons of Beriah; Heber, and Malchiel, who is the father of Birzavith.
10568	345	32	And Heber begat Japhlet, and Shomer, and Hotham, and Shua their sister.
10569	345	33	And the sons of Japhlet; Pasach, and Bimhal, and Ashvath. These are the children of Japhlet.
10570	345	34	And the sons of Shamer; Ahi, and Rohgah, Jehubbah, and Aram.
10571	345	35	And the sons of his brother Helem; Zophah, and Imna, and Shelesh, and Amal.
10572	345	36	The sons of Zophah; Suah, and Harnepher, and Shual, and Beri, and Imrah,
10573	345	37	Bezer, and Hod, and Shamma and Shilshah, and Ithran, and Beera.
10574	345	38	And the sons of Jether; Jephunneh, and Pispah, and Ara.
10575	345	39	And the sons of Ulla; Arah, and Haniel, and Rezia.
10576	345	40	All these were the children of Asher, heads of their father's house, choice and mighty men of valour, chief of the princes. And the number throughout the genealogy of them that were apt to the war and to battle was twenty and six thousand men.
10577	346	1	NOW Benjamin begat Bela his firstborn, Ashbel the second, and Aharah the third,
10578	346	2	Nohah the fourth, and Rapha the fifth.
10579	346	3	And the sons of Bela were, Addar, and Gera, and Abihud,
10580	346	4	And Abishua, and Naaman, and Ahoah,
10581	346	5	And Gera, and Shephuphan, and Huram.
10582	346	6	And these are the sons of Ehud: these are the heads of the fathers of the inhabitants of Geba, and they removed them to Manahath:
10583	346	7	And Naaman, and Ahiah, and Gera, he removed them, and begat Uzza, and Ahihud.
10584	346	8	And Shaharaim begat children in the country of Moab, after he had sent them away; Hushim and Baara were his wives.
10585	346	9	And he begat of Hodesh his wife, Jobab, and Zibia, and Mesha, and Malcham,
10586	346	10	And Jeuz, and Shachia, and Mirma. These were his sons, heads of the fathers.
10587	346	11	And of Hushim he begat Abitub, and Elpaal.
10588	346	12	The sons of Elpaal; Eber, and Misham, and Shamed, who built Ono, and Lod, with the towns thereof:
10589	346	13	Beriah also, and Shema, who were heads of the fathers of the inhabitants of Aijalon, who drove away the inhabitants of Gath:
10590	346	14	And Ahio, Shashak, and Jeremoth,
10591	346	15	And Zebadiah, and Arad, and Ader,
10592	346	16	And Michael, and Ispah, and Joha, the sons of Beriah;
10593	346	17	And Zebadiah, and Meshullam, and Hezeki, and Heber,
10594	346	18	Ishmerai also, and Jezliah, and Jobab, the sons of Elpaal;
10595	346	19	And Jakim, and Zichri, and Zabdi,
10596	346	20	And Elienai, and Zilthai, and Eliel,
10597	346	21	And Adaiah, and Beraiah, and Shimrath, the sons of Shimhi;
10598	346	22	And Ishpan, and Heber, and Eliel,
10599	346	23	And Abdon, and Zichri, and Hanan,
10600	346	24	And Hananiah, and Elam, and Antothijah,
10601	346	25	And Iphedeiah, and Penuel, the sons of Shashak;
10602	346	26	And Shamsherai, and Shehariah, and Athaliah,
10603	346	27	And Jaresiah, and Eliah, and Zichri, the sons of Jeroham.
10604	346	28	These were heads of the fathers, by their generations, chief men. These dwelt in Jerusalem.
10605	346	29	And at Gibeon dwelt the father of Gibeon; whose wife's name was Maachah:
10606	346	30	And his firstborn son Abdon, and Zur, and Kish, and Baal, and Nadab,
10607	346	31	And Gedor, and Ahio, and Zacher.
10608	346	32	And Mikloth begat Shimeah. And these also dwelt with their brethren in Jerusalem, over against them.
10609	346	33	And Ner begat Kish, and Kish begat Saul, and Saul begat Jonathan, and Malchi-shua, and Abinadab, and Esh-baal.
10610	346	34	And the son of Jonathan was Merib-baal; and Merib-baal begat Micah.
10611	346	35	And the sons of Micah were, Pithon, and Melech, and Tarea, and Ahaz.
10612	346	36	And Ahaz begat Jehoadah; and Jehoadah begat Alemeth, and Azmaveth, and Zimri; and Zimri begat Moza,
10613	346	37	And Moza begat Binea: Rapha was his son, Eleasah his son, Azel his son:
10614	346	38	And Azel had six sons, whose names are these, Azrikam, Bocheru, and Ishmael, and Sheariah, and Obadiah, and Hanan. All these were the sons of Azel.
10615	346	39	And the sons of Eshek his brother were, Ulam his firstborn, Jehush the second, and Eliphelet the third.
10616	346	40	And the sons of Ulam were mighty men of valour, archers, and had many sons, and sons' sons, an hundred and fifty. All these are of the sons of Benjamin.
10617	347	1	SO all Israel were reckoned by genealogies; and, behold, they were written in the book of the kings of Israel and Judah, who were carried away to Babylon for their transgression.
10618	347	2	Now the first inhabitants that dwelt in their possessions in their cities were, the Israelites, the priests, Levites, and the Nethinims.
10619	347	3	And in Jerusalem dwelt of the children of Judah, and of the children of Benjamin, and of the children of Ephraim, and Manasseh;
10620	347	4	Uthai the son of Ammihud, the son of Omri, the son of Imri, the son of Bani, of the children of Pharez the son of Judah.
10621	347	5	And of the Shilonites; Asaiah the firstborn, and his sons.
10622	347	6	And of the sons of Zerah; Jeuel, and their brethren, six hundred and ninety.
10623	347	7	And of the sons of Benjamin; Sallu the son of Meshullam, the son of Hodaviah, the son of Hasenuah,
10624	347	8	And Ibneiah the son of Jeroham, and Elah the son of Uzzi, the son of Michri, and Meshullam the son of Shephathiah, the son of Reuel, the son of Ibnijah;
10625	347	9	And their brethren, according to their generations, nine hundred and fifty and six. All these men were chief of the fathers in the house of their fathers.
10626	347	10	And of the priests; Jedaiah, and Jehoiarib, and Jachin,
10627	347	11	And Azariah the son of Hilkiah, the son of Meshullam, the son of Zadok, the son of Meraioth, the son of Ahitub, the ruler of the house of God;
10628	347	12	And Adaiah the son of Jeroham, the son of Pashur, the son of Malchijah, and Maasiai the son of Adiel, the son of Jahzerah, the son of Meshullam, the son of Meshillemith, the son of Immer;
10629	347	13	And their brethren, heads of the house of their fathers, a thousand and seven hundred and threescore; very able men for the work of the service of the house of God.
10630	347	14	And of the Levites; Shemaiah the son of Hasshub, the son of Azrikam, the son of Hashabiah, of the sons of Merari;
10631	347	15	And Bakbakkar, Heresh, and Galal, and Mattaniah the son of Micah, the son of Zichri, the son of Asaph;
10632	347	16	And Obadiah the son of Shemaiah, the son of Galal, the son of Jeduthun, and Berechiah the son of Asa, the son of Elkanah, that dwelt in the villages of the Netophathites.
10633	347	17	And the porters were, Shallum, and Akkub, and Talmon, and Ahiman, and their brethren: Shallum was the chief;
10634	347	18	Who hitherto waited in the king's gate eastward: they were porters in the companies of the children of Levi.
10635	347	19	And Shallum the son of Kore, the son of Ebiasaph, the son of Korah, and his brethren, of the house of his father, the Korahites, were over the work of the service, keepers of the gates of the tabernacle: and their fathers, being over the host of the LORD, were keepers of the entry.
10636	347	20	And Phinehas the son of Eleazar was the ruler over them in time past, and the LORD was with him.
10637	347	21	And Zechariah the son of Meshelemiah was porter of the door of the tabernacle of the congregation.
10638	347	22	All these which were chosen to be porters in the gates were two hundred and twelve. These were reckoned by their genealogy in their villages, whom David and Samuel the seer did ordain in their set office.
10639	347	23	So they and their children had the oversight of the gates of the house of the LORD, namely, the house of the tabernacle, by wards.
10640	347	24	In four quarters were the porters, toward the east, west, north, and south.
10641	347	25	And their brethren, which were in their villages, were to come after seven days from time to time with them.
10642	347	26	For these Levites, the four chief porters, were in their set office, and were over the chambers and treasuries of the house of God.
10643	347	27	And they lodged round about the house of God, because the charge was upon them, and the opening thereof every morning pertained to them.
10644	347	28	And certain of them had the charge of the ministering vessels, that they should bring them in and out by tale.
10645	347	29	Some of them also were appointed to oversee the vessels, and all the instruments of the sanctuary, and the fine flour, and the wine, and the oil, and the frankincense, and the spices.
10646	347	30	And some of the sons of the priests made the ointment of the spices.
10647	347	31	And Mattithiah, one of the Levites, who was the firstborn of Shallum the Korahite, had the set office over the things that were made in the pans.
10648	347	32	And other of their brethren, of the sons of the Kohathites, were over the shewbread, to prepare it every sabbath.
10649	347	33	And these are the singers, chief of the fathers of the Levites, who remaining in the chambers were free: for they were employed in that work day and night.
10650	347	34	These chief fathers of the Levites were chief throughout their generations; these dwelt at Jerusalem.
10651	347	35	And in Gibeon dwelt the father of Gibeon, Jehiel, whose wife's name was Maachah:
10652	347	36	And his firstborn son Abdon, then Zur, and Kish, and Baal, and Ner, and Nadab,
10653	347	37	And Gedor, and Ahio, and Zechariah, and Mikloth.
10654	347	38	And Mikloth begat Shimeam. And they also dwelt with their brethren at Jerusalem, over against their brethren.
10655	347	39	And Ner begat Kish; and Kish begat Saul; and Saul begat Jonathan, and Malchi-shua, and Abinadab, and Esh-baal.
10656	347	40	And the son of Jonathan was Merib-baal: and Merib-baal begat Micah.
10657	347	41	And the sons of Micah were, Pithon, and Melech, and Tahrea, and Ahaz.
10658	347	42	And Ahaz begat Jarah; and Jarah begat Alemeth, and Azmaveth, and Zimri; and Zimri begat Moza;
10659	347	43	And Moza begat Binea; and Rephaiah his son, Eleasah his son, Azel his son.
10660	347	44	And Azel had six sons, whose names are these, Azrikam, Bocheru, and Ishmael, and Sheariah, and Obadiah, and Hanan: these were the sons of Azel.
10661	348	1	NOW the Philistines fought against Israel; and the men of Israel fled from before the Philistines, and fell down slain in mount Gilboa.
10662	348	2	And the Philistines followed hard after Saul, and after his sons; and the Philistines slew Jonathan, and Abinadab, and Malchi-shua, the sons of Saul.
10663	348	3	And the battle went sore against Saul, and the archers hit him, and he was wounded of the archers.
10664	348	4	Then said Saul to his armour-bearer, Draw thy sword, and thrust me through therewith; lest these uncircumcised come and abuse me. But his armourbearer would not; for he was sore afraid. So Saul took a sword, and fell upon it.
10665	348	5	And when his armourbearer saw that Saul was dead, he fell likewise on the sword, and died.
10666	348	6	So Saul died, and his three sons, and all his house died together.
10667	348	7	And when all the men of Israel that were in the valley saw that they fled, and that Saul and his sons were dead, then they forsook their cities, and fled: and the Philistines came and dwelt in them.
10668	348	8	And it came to pass on the morrow, when the Philistines came to strip the slain, that they found Saul and his sons fallen in mount Gilboa.
10669	348	9	And when they had stripped him, they took his head, and his armour, and sent into the land of the Philistines round about, to carry tidings unto their idols, and to the people.
10670	348	10	And they put his armour in the house of their gods, and fastened his head in the temple of Dagon.
10671	348	11	And when all Jabesh-gilead heard all that the Philistines had done to Saul,
10672	348	12	They arose, all the valiant men, and took away the body of Saul, and the bodies of his sons, and brought them to Jabesh, and buried their bones under the oak in Jabesh, and fasted seven days.
10673	348	13	So Saul died for his transgression which he committed against the LORD, even against the word of the LORD, which he kept not, and also for asking counsel of one that had a familiar spirit, to enquire of it;
10674	348	14	And enquired not of the LORD: therefore he slew him, and turned the kingdom unto David the son of Jesse.
10675	349	1	THEN all Israel gathered themselves to David unto Hebron, saying, Behold, we are thy bone and thy flesh.
10676	349	2	And moreover in time past, even when Saul was king, thou wast he that leddest out and broughtest in Israel: and the LORD thy God said unto thee, Thou shalt feed my people Israel, and thou shalt be ruler over my people Israel.
10677	349	3	Therefore came all the elders of Israel to the king to Hebron; and David made a covenant with them in Hebron before the LORD; and they anointed David king over Israel, according to the word of the LORD by Samuel.
10678	349	4	And David and all Israel went to Jerusalem, which is Jebus; where the Jebusites were, the inhabitants of the land.
10679	349	5	And the inhabitants of Jebus said to David, Thou shalt not come hither. Nevertheless David took the castle of Zion, which is the city of David.
10680	349	6	And David said, Whosoever smiteth the Jebusites first shall be chief and captain. So Joab the son of Zeruiah went first up, and was chief.
10681	349	7	And David dwelt in the castle; therefore they called it the city of David.
10682	349	8	And he built the city round about, even from Millo round about: and Joab repaired the rest of the city.
10683	349	9	So David waxed greater and greater: for the LORD of hosts was with him.
10684	349	10	These also are the chief of the mighty men whom David had, who strengthened themselves with him in his kingdom, and with all Israel, to make him king, according to the word of the LORD concerning Israel.
10685	349	11	And this is the number of the mighty men whom David had; Jashobeam, and Hachmonite, the chief of the captains: he lifted up his spear against three hundred slain by him at one time.
10686	349	12	And after him was Eleazar the son of Dodo, the Ahohite, who was one of the three mighties.
10687	349	13	He was with David at Pas-dammim, and there the Philistines were gathered together to battle, where was a parcel of ground full of barley; and the people fled from before the Philistines.
10688	349	14	And they set themselves in the midst of that parcel, and delivered it, and slew the Philistines; and the LORD saved them by a great deliverance.
10689	349	15	Now three of the thirty captains went down to the rock to David, into the cave of Adullam; and the host of the Philistines encamped in the valley of Rephaim.
10690	349	16	And David was then in the hold, and the Philistines' garrison was then at Beth-lehem.
10691	349	17	And David longed, and said, Oh that one would give me drink of the water of the well of Beth-lehem, that is at the gate!
10692	349	18	And the three brake through the host of the Philistines, and drew water out of the well of Beth-lehem, that was by the gate, and took it, and brought it to David: but David would not drink of it, but poured it out to the LORD,
10693	349	19	And said, My God forbid it me, that I should do this thing: shall I drink the blood of these men that have put their lives in jeopardy? for with the jeopardy of their lives they brought it. Therefore he would not drink it. These things did these three mightiest.
10694	349	20	And Abishai the brother of Joab, he was chief of the three: for lifting up his spear against three hundred, he slew them, and had a name among the three.
10695	349	21	Of the three, he was more honourable than the two; for he was their captain: howbeit he attained not to the first three.
10696	349	22	Benaiah the son of Jehoiada, the son of a valiant man of Kabzeel, who had done many acts; he slew two lionlike men of Moab: also he went down and slew a lion in a pit in a snowy day.
10697	349	23	And he slew an Egyptian, a man of great stature, five cubits high; and in the Egyptian's hand was a spear like a weaver's beam; and he went down to him with a staff, and plucked the spear out of the Egyptian's hand, and slew him with his own spear.
10698	349	24	These things did Benaiah the son of Jehoiada, and had the name among the three mighties.
10699	349	25	Behold, he was honourable among the thirty, but attained not to the first three: and David set him over his guard.
10700	349	26	Also the valiant men of the armies were, Asahel the brother of Joab, Elhanan the son of Dodo of Beth-lehem,
10701	349	27	Shammoth the Harorite, Helez the Pelonite,
10702	349	28	Ira the son of Ikkesh the Tekoite, Abi-ezer the Antothite,
10703	349	29	Sibbecai the Hushathite, Ilai the Ahohite,
10704	349	30	Maharai the Netophathite, Heled the son of Baanah the Netophathite,
10705	349	31	Ithai the son of Ribai of Gibeah, that pertained to the children of Benjamin, Benaiah the Pirathonite,
10706	349	32	Hurai of the brooks of Gaash, Abiel the Arbathite.
10707	349	33	Azmaveth the Baharumite, Eliahba the Shaalbonite,
10708	349	34	The sons of Hashem the Gizonite, Jonathan the son of Shage the Hararite,
10709	349	35	Ahiam the son of Sacar the Hararite, Eliphal the son of Ur,
10710	349	36	Hepher the Mecherathite, Ahijah the Pelonite,
10711	349	37	Hezro the Carmelite, Naarai the son of Ezbai,
10712	349	38	Joel the brother of Nathan, Mibhar the son of Haggeri,
10713	349	39	Zelek the Ammonite, Naharai the Berothite, the armourbearer of Joab the son of Zeruiah,
10714	349	40	Ira the Ithrite, Gareb the Ithrite,
10715	349	41	Uriah the Hittite, Zabad the son of Ahlai,
10716	349	42	Adina the son of Shiza the Reubenite, a captain of the Reubenites, and thirty with him,
10717	349	43	Hanan the son of Maachah, and Joshaphat the Mithnite,
10718	349	44	Uzzia the Ashterathite, Shama and Jehiel the sons of Hothan the Aroerite,
10719	349	45	Jediael the son of Shimri, and Joha his brother, the Tizite,
10720	349	46	Eliel the Mahavite, and Jeribai, and Joshaviah, the sons of Elnaam, and Ithmah the Moabite,
10721	349	47	Eliel, and Obed, and Jasiel the Mesobaite.
10722	350	1	NOW these are they that came to David to Ziklag, while he yet kept himself close because of Saul the son of Kish: and they were among the mighty men, helpers of the war.
10723	350	2	They were armed with bows, and could use both the right hand and the left in hurling stones and shooting arrows out of a bow, even of Saul's brethren of Benjamin.
10724	350	3	The chief was Ahiezer, then Joash, the sons of Shemaah the Gibeathite; and Jeziel, and Pelet, the sons of Azmaveth; and Berachah, and Jehu the Antothite,
10725	350	4	And Ismaiah the Gibeonite, a mighty man among the thirty, and over the thirty; and Jeremiah, and Jahaziel, and Johanan, and Josabad the Gederathite,
10726	350	5	Eluzai, and Jerimoth, and Bealiah, and Shemariah, and Shephatiah the Haruphite,
10727	350	6	Elkanah, and Jesiah, and Azareel, and Joezer, and Jashobeam, the Korhites,
10728	350	7	And Joelah, and Zebadiah, the sons of Jeroham of Gedor.
10729	350	8	And of the Gadites there separated themselves unto David into the hold to the wilderness men of might, and men of war fit for the battle, that could handle shield and buckler, whose faces were like the faces of lions, and were as swift as the roes upon the mountains;
10730	350	9	Ezer the first, Obadiah the second, Eliab the third,
10731	350	10	Mishmannah the fourth, Jeremiah the fifth,
10732	350	11	Attai the sixth, Eliel the seventh,
10733	350	12	Johanan the eighth, Elzabad the ninth,
10734	350	13	Jeremiah the tenth, Machbanai the eleventh.
10735	350	14	These were of the sons of Gad, captains of the host: one of the least was over an hundred, and the greatest over a thousand.
10736	350	15	These are they that went over Jordan in the first month, when it had overflown all his banks; and they put to flight all them of the valleys, both toward the east, and toward the west.
10737	350	16	And there came of the children of Benjamin and Judah to the hold unto David.
10738	350	17	And David went out to meet them, and answered and said unto them, If ye be come peaceably unto me to help me, mine heart shall be knit unto you: but if ye be come to betray me to mine enemies, seeing there is no wrong in mine hands, the God of our fathers look thereon, and rebuke it.
10739	350	18	Then the spirit came upon Amasai, who was chief of the captains, and he said, Thine are we, David, and on thy side, thou son of Jesse: peace, peace, be unto thee, and peace be to thine helpers; for thy God helpeth thee. Then David received them, and made them captains of the band.
10740	350	19	And there fell some of Manasseh to David, when he came with the Philistines against Saul to battle: but they helped them not: for the lords of the Philistines upon advisement sent him away, saying, He will fall to his master Saul to the jeopardy of our heads.
10741	350	20	As he went to Ziklag, there fell to him of Manasseh, Adnah, and Jozabad, and Jediael, and Michael, and Jozabad, and Elihu, and Zilthai, captains of the thousands that were of Manasseh.
10742	350	21	And they helped David against the band of the rovers: for they were all mighty men of valour, and were captains in the host.
10743	350	22	For at that time day by day there came to David to help him, until it was a great host, like the host of God.
10744	350	23	And these are the numbers of the bands that were ready armed to the war, and came to David to Hebron, to turn the kingdom of Saul to him, according to the word of the LORD.
10745	350	24	The children of Judah that bare shield and spear were six thousand and eight hundred, ready armed to the war.
10746	350	25	Of the children of Simeon, mighty men of valour for the war, seven thousand and one hundred.
10747	350	26	Of the children of Levi four thousand and six hundred.
10748	350	27	And Jehoiada was the leader of the Aaronites, and with him were three thousand and seven hundred;
10749	350	28	And Zadok, a young man mighty of valour, and of his father's house twenty and two captains.
10750	350	29	And of the children of Benjamin, the kindred of Saul, three thousand: for hitherto the greatest part of them had kept the ward of the house of Saul.
10751	350	30	And of the children of Ephraim twenty thousand and eight hundred, mighty men of valour, famous throughout the house of their fathers.
10752	350	31	And of the half tribe of Manasseh eighteen thousand, which were expressed by name, to come and make David king.
10753	350	32	And of the children of Issachar, which were men that had understanding of the times, to know what Israel ought to do; the heads of them were two hundred; and all their brethren were at their commandment.
10754	350	33	Of Zebulun, such as went forth to battle, expert in war, with all instruments of war, fifty thousand, which could keep rank: they were not of double heart.
10755	350	34	And of Naphtali a thousand captains, and with them with shield and spear thirty and seven thousand.
10756	350	35	And of the Danites expert in war twenty and eight thousand and six hundred.
10757	350	36	And of Asher, such as went forth to battle, expert in war, forty thousand.
10758	350	37	And on the other side of Jordan, of the Reubenites, and the Gadites, and of the half tribe of Manasseh, with all manner of instruments of war for the battle, an hundred and twenty thousand.
10759	350	38	All these men of war, that could keep rank, came with a perfect heart to Hebron, to make David king over all Israel: and all the rest also of Israel were of one heart to make David king.
10760	350	39	And there they were with David three days, eating and drinking: for their brethren had prepared for them.
10761	350	40	Moreover they that were nigh them, even unto Issachar and Zebulun and Naphtali, brought bread on asses, and on camels, and on mules, and on oxen, and meat, meal, cakes of figs, and bunches of raisins, and wine, and oil, and oxen, and sheep abundantly: for there was joy in Israel.
10762	351	1	AND David consulted with the captains of thousands and hundreds, and with every leader.
10763	351	2	And David said unto all the congregation of Israel, If it seem good unto you, and that it be of the LORD our God, let us send abroad unto our brethren every where, that are left in all the land of Israel, and with them also to the priests and Levites which are in their cities and suburbs, that they may gather themselves unto us:
10764	351	3	And let us bring again the ark of our God to us: for we enquired not at it in the days of Saul.
10765	351	4	And all the congregation said that they would do so: for the thing was right in the eyes of all the people.
10766	351	5	So David gathered all Israel together, from Shihor of Egypt even unto the entering of Hemath, to bring the ark of God from Kirjath-jearim.
10767	351	6	And David went up, and all Israel, to Baalah, that is, to Kirjath-jearim, which belonged to Judah, to bring up thence the ark of God the LORD, that dwelleth between the cherubims, whose name is called on it.
10768	351	7	And they carried the ark of God in a new cart out of the house of Abinadab: and Uzza and Ahio drave the cart.
10769	351	8	And David and all Israel played before God with all their might, and with singing, and with harps, and with psalteries, and with timbrels, and with cymbals, and with trumpets.
10770	351	9	And when they came unto the threshingfloor of Chidon, Uzza put forth his hand to hold the ark; for the oxen stumbled.
10771	351	10	And the anger of the LORD was kindled against Uzza, and he smote him, because he put his hand to the ark: and there he died before God.
10772	351	11	And David was displeased, because the LORD had made a breach upon Uzza: wherefore that place is called Perez-uzza to this day.
10773	351	12	And David was afraid of God that day, saying, How shall I bring the ark of God home to me?
10774	351	13	So David brought not the ark home to himself to the city of David, but carried it aside into the house of Obed-edom the Gittite.
10775	351	14	And the ark of God remained with the family of Obed-edom in his house three months. And the LORD blessed the house of Obed-edom, and all that he had.
10776	352	1	NOW Hiram king of Tyre sent messengers to David, and timber of cedars, with masons and carpenters, to build him an house.
10777	352	2	And David perceived that the LORD had confirmed him king over Israel, for his kingdom was lifted up on high, because of his people Israel.
10778	352	3	And David took more wives at Jerusalem: and David begat more sons and daughters.
10779	352	4	Now these are the names of his children which he had in Jerusalem; Shammua, and Shobab, Nathan, and Solomon,
10780	352	5	And Ibhar, and Elishua, and Elpalet,
10781	352	6	And Nogah, and Nepheg, and Japhia,
10782	352	7	And Elishama, and Beeliada, and Eliphalet.
10783	352	8	And when the Philistines heard that David was anointed king over all Israel, all the Philistines went up to seek David. And David heard of it, and went out against them.
10784	352	9	And the Philistines came and spread themselves in the valley of Rephaim.
10785	352	10	And David enquired of God, saying, Shall I go up against the Philistines? and wilt thou deliver them into mine hand? And the LORD said unto him, Go up; for I will deliver them into thine hand.
10786	352	11	So they came up to Baal-perazim; and David smote them there. Then David said, God hath broken in upon mine enemies by mine hand like the breaking forth of waters: therefore they called the name of that place Baal-perazim.
10787	352	12	And when they had left their gods there, David gave a commandment, and they were burned with fire.
10788	352	13	And the Philistines yet again spread themselves abroad in the valley.
10789	352	14	Therefore David enquired again of God; and God said unto him, Go not up after them; turn away from them, and come upon them over against the mulberry trees.
10790	352	15	And it shall be, when thou shalt hear a sound of going in the tops of the mulberry trees, that then thou shalt go out to battle: for God is gone forth before thee to smite the host of the Philistines.
10791	352	16	David therefore did as God commanded him: and they smote the host of the Philistines from Gibeon even to Gazer.
10792	352	17	And the fame of David went out into all lands; and the LORD brought the fear of him upon all nations.
10793	353	1	AND David made him houses in the city of David, and prepared a place for the ark of God, and pitched for it a tent.
10794	353	2	Then David said, None ought to carry the ark of God but the Levites: for them hath the LORD chosen to carry the ark of God, and to minister unto him for ever.
10795	353	3	And David gathered all Israel together to Jerusalem, to bring up the ark of the LORD unto his place, which he had prepared for it.
10796	353	4	And David assembled the children of Aaron, and the Levites:
10797	353	5	Of the sons of Kohath; Uriel the chief, and his brethren an hundred and twenty:
10798	353	6	Of the sons of Merari; Asaiah the chief, and his brethren two hundred and twenty:
10799	353	7	Of the sons of Gershom; Joel the chief, and his brethren an hundred and thirty:
10800	353	8	Of the sons of Elizaphan; Shemaiah the chief, and his brethren two hundred:
10801	353	9	Of the sons of Hebron; Eliel the chief, and his brethren fourscore:
10802	353	10	Of the sons of Uzziel; Amminadab the chief, and his brethren an hundred and twelve.
10803	353	11	And David called for Zadok and Abiathar the priests, and for the Levites, for Uriel, Asaiah, and Joel, Shemaiah, and Eliel, and Amminadab,
10804	353	12	And said unto them, Ye are the chief of the fathers of the Levites: sanctify yourselves, both ye and your brethren, that ye may bring up the ark of the LORD God of Israel unto the place that I have prepared for it.
10805	353	13	For because ye did it not at the first, the LORD our God made a breach upon us, for that we sought him not after the due order.
10806	353	14	So the priests and the Levites sanctified themselves to bring up the ark of the LORD God of Israel.
10807	353	15	And the children of the Levites bare the ark of God upon their shoulders with the staves thereon, as Moses commanded according to the word of the LORD.
10808	353	16	And David spake to the chief of the Levites to appoint their brethren to be the singers with instruments of musick, psalteries and harps and cymbals, sounding, by lifting up the voice with joy.
10809	353	17	So the Levites appointed Heman the son of Joel; and of his brethren, Asaph the son of Berechiah; and of the sons of Merari their brethren, Ethan the son of Kushaiah;
10810	353	18	And with them their brethren of the second degree, Zechariah, Ben, and Jaaziel, and Shemiramoth, and Jehiel, and Unni, Eliab, and Benaiah, and Maaseiah, and Mattithiah, and Elipheleh, and Mikneiah, and Obed-edom, and Jeiel, the porters.
10811	353	19	So the singers, Heman, Asaph, and Ethan, were appointed to sound with cymbals of brass;
10812	353	20	And Zechariah, and Aziel, and Shemiramoth, and Jehiel, and Unni, and Eliab, and Maaseiah, and Benaiah, with psalteries on Alamoth;
10813	353	21	And Mattithiah, and Elipheleh, and Mikneiah, and Obed-edom, and Jeiel, and Azaziah, with harps on the Sheminith to excel.
10814	353	22	And Chenaniah, chief of the Levites, was for song: he instructed about the song, because he was skilful.
10815	353	23	And Berechiah and Elkanah were doorkeepers for the ark.
10816	353	24	And Shebaniah, and Jehoshaphat, and Nethaneel, and Amasai, and Zechariah, and Benaiah, and Eliezer, the priests, did blow with the trumpets before the ark of God: and Obed-edom and Jehiah were doorkeepers for the ark.
10817	353	25	So David, and the elders of Israel, and the captains over thousands, went to bring up the ark of the covenant of the LORD out of the house of Obed-edom with joy.
10818	353	26	And it came to pass, when God helped the Levites that bare the ark of the covenant of the LORD, that they offered seven bullocks and seven rams.
10819	353	27	And David was clothed with a robe of fine linen, and all the Levites that bare the ark, and the singers, and Chenaniah the master of the song with the singers: David also had upon him an ephod of linen.
10820	353	28	Thus all Israel brought up the ark of the covenant of the LORD with shouting, and with sound of the cornet, and with trumpets, and with cymbals, making a noise with psalteries and harps.
10821	353	29	And it came to pass, as the ark of the covenant of the LORD came to the city of David, that Michal the daughter of Saul looking out at a window saw king David dancing and playing: and she despised him in her heart.
10822	354	1	SO they brought the ark of God, and set it in the midst of the tent that David had pitched for it: and they offered burnt sacrifices and peace offerings before God.
10823	354	2	And when David had made an end of offering the burnt offerings and the peace offerings, he blessed the people in the name of the LORD.
10824	354	3	And he dealt to every one of Israel, both man and woman, to every one a loaf of bread, and a good piece of flesh, and a flagon of wine.
10825	354	4	And he appointed certain of the Levites to minister before the ark of the LORD, and to record, and to thank and praise the LORD God of Israel:
10826	354	5	Asaph the chief, and next to him Zechariah, Jeiel, and Shemiramoth, and Jehiel, and Mattithiah, and Eliab, and Benaiah, and Obed-edom: and Jeiel with psalteries and with harps; but Asaph made a sound with cymbals;
10827	354	6	Benaiah also and Jahaziel the priests with trumpets continually before the ark of the covenant of God.
10828	354	7	Then on that day David delivered first this psalm to thank the LORD into the hand of Asaph and his brethren.
10829	354	8	Give thanks unto the LORD, call upon his name, make known his deeds among the people.
10830	354	9	Sing unto him, sing psalms unto him, talk ye of all his wondrous works.
10831	354	10	Glory ye in his holy name: let the heart of them rejoice that seek the LORD.
10832	354	11	Seek the LORD and his strength, seek his face continually.
10833	354	12	Remember his marvellous works that he hath done, his wonders, and the judgments of his mouth;
10834	354	13	O ye seed of Israel his servant, ye children of Jacob, his chosen ones.
10835	354	14	He is the LORD our God; his judgments are in all the earth.
10836	354	15	Be ye mindful always of his covenant; the word which he commanded to a thousand generations;
10837	354	16	Even of the covenant which he made with Abraham, and of his oath unto Isaac;
10838	354	17	And hath confirmed the same to Jacob for a law, and to Israel for an everlasting covenant,
10839	354	18	Saying, Unto thee will I give the land of Canaan, the lot of your inheritance;
10840	354	19	When ye were but few, even a few, and strangers in it.
10841	354	20	And when they went from nation to nation, and from one kingdom to another people;
10842	354	21	He suffered no man to do them wrong: yea, he reproved kings for their sakes,
10843	354	22	Saying, Touch not mine anointed, and do my prophets no harm.
10844	354	23	Sing unto the LORD, all the earth; shew forth from day to day his salvation.
10845	354	24	Declare his glory among the heathen; his marvellous works among all nations.
10846	354	25	For great is the LORD, and greatly to be praised: he also is to be feared above all gods.
10847	354	26	For all the gods of the people are idols: but the LORD made the heavens.
10848	354	27	Glory and honour are in his presence; strength and gladness are in his place.
10849	354	28	Give unto the LORD, ye kindreds of the people, give unto the LORD glory and strength.
10850	354	29	Give unto the LORD the glory due unto his name: bring an offering, and come before him: worship the LORD in the beauty of holiness.
10851	354	30	Fear before him, all the earth: the world also shall be stable, that it be not moved.
10852	354	31	Let the heavens be glad, and let the earth rejoice: and let men say among the nations, The LORD reigneth.
10853	354	32	Let the sea roar, and the fulness thereof: let the fields rejoice, and all that is therein.
10854	354	33	Then shall the trees of the wood sing out at the presence of the LORD, because he cometh to judge the earth.
10855	354	34	O give thanks unto the LORD; for he is good; for his mercy endureth for ever.
10856	354	35	And say ye, Save us, O God of our salvation, and gather us together, and deliver us from the heathen, that we may give thanks to thy holy name, and glory in thy praise.
10857	354	36	Blessed be the LORD God of Israel for ever and ever. And all the people said, Amen, and praised the LORD.
10858	354	37	So he left there before the ark of the covenant of the LORD Asaph and his brethren, to minister before the ark continually, as every day's work required:
10859	354	38	And Obed-edom with their brethren, threescore and eight; Obed-edom also the son of Jeduthun and Hosah to be porters:
10860	354	39	And Zadok the priest, and his brethren the priests, before the tabernacle of the LORD in the high place that was at Gibeon,
10861	354	40	To offer burnt offerings unto the LORD upon the altar of the burnt offering continually morning and evening, and to do according to all that is written in the law of the LORD, which he commanded Israel;
10862	354	41	And with them Heman and Jeduthun, and the rest that were chosen, who were expressed by name, to give thanks to the LORD, because his mercy endureth for ever;
10863	354	42	And with them Heman and Jeduthun, with trumpets and cymbals for those that should make a sound, and with musical instruments of God. And the sons of Jeduthun were porters.
10864	354	43	And all the people departed every man to his house: and David returned to bless his house.
10865	355	1	NOW it came to pass, as David sat in his house, that David said to Nathan the prophet, Lo, I dwell in an house of cedars, but the ark of the covenant of the LORD remaineth under curtains.
10866	355	2	Then Nathan said unto David, Do all that is in thine heart; for God is with thee.
10867	355	3	And it came to pass the same night, that the word of God came to Nathan, saying,
10868	355	4	Go and tell David my servant, Thus saith the LORD, Thou shalt not build me an house to dwell in:
10869	355	5	For I have not dwelt in an house since the day that I brought up Israel unto this day; but have gone from tent to tent, and from one tabernacle to another.
10870	355	6	Wheresoever I have walked with all Israel, spake I a word to any of the judges of Israel, whom I commanded to feed my people, saying, Why have ye not built me an house of cedars?
10871	355	7	Now therefore thus shalt thou say unto my servant David, Thus saith the LORD of hosts, I took thee from the sheepcote, even from following the sheep, that thou shouldest be ruler over my people Israel:
10872	355	8	And I have been with thee whithersoever thou hast walked, and have cut off all thine enemies from before thee, and have made thee a name like the name of the great men that are in the earth.
10873	355	9	Also I will ordain a place for my people Israel, and will plant them, and they shall dwell in their place, and shall be moved no more; neither shall the children of wickedness waste them any more, as at the beginning,
10874	355	10	And since the time that I commanded judges to be over my people Israel. Moreover I will subdue all thine enemies. Furthermore I tell thee that the LORD will build thee an house.
10875	355	11	And it shall come to pass, when thy days be expired that thou must go to be with thy fathers, that I will raise up thy seed after thee, which shall be of thy sons; and I will establish his kingdom.
10876	355	12	He shall build me an house, and I will stablish his throne for ever.
10877	355	13	I will be his father, and he shall be my son: and I will not take my mercy away from him, as I took it from him that was before thee:
10878	355	14	But I will settle him in mine house and in my kingdom for ever: and his throne shall be established for evermore.
10879	355	15	According to all these words, and according to all this vision, so did Nathan speak unto David.
10880	355	16	And David the king came and sat before the LORD, and said, Who am I, O LORD God, and what is mine house, that thou hast brought me hitherto?
10881	355	17	And yet this was a small thing in thine eyes, O God; for thou hast also spoken of thy servant's house for a great while to come, and hast regarded me according to the estate of a man of high degree, O LORD God.
10882	355	18	What can David speak more to thee for the honour of thy servant? for thou knowest thy servant.
10883	355	19	O LORD, for thy servant's sake, and according to thine own heart, hast thou done all this greatness, in making known all these great things.
10884	355	20	O LORD, there is none like thee, neither is there any God beside thee, according to all that we have heard with our ears.
10885	355	21	And what one nation in the earth is like thy people Israel, whom God went to redeem to be his own people, to make thee a name of greatness and terribleness, by driving out nations from before thy people, whom thou hast redeemed out of Egypt?
10886	355	22	For thy people Israel didst thou make thine own people for ever; and thou, LORD, becamest their God.
10887	355	23	Therefore now, LORD, let the thing that thou hast spoken concerning thy servant and concerning his house be established for ever, and do as thou hast said.
10888	355	24	Let it even be established, that thy name may be magnified for ever, saying, The LORD of hosts is the God of Israel, even a God to Israel: and let the house of David thy servant be established before thee.
10889	355	25	For thou, O my God, hast told thy servant that thou wilt build him an house: therefore thy servant hath found in his heart to pray before thee.
10890	355	26	And now, LORD, thou art God, and hast promised this goodness unto thy servant:
10891	355	27	Now therefore let it please thee to bless the house of thy servant, that it may be before thee for ever: for thou blessest, O LORD, and it shall be blessed for ever.
10892	356	1	NOW after this it came to pass, that David smote the Philistines, and subdued them, and took Gath and her towns out of the hand of the Philistines.
10893	356	2	And he smote Moab; and the Moabites became David's servants, and brought gifts.
10894	356	3	And David smote Hadarezer king of Zobah unto Hamath, as he went to stablish his dominion by the river Euphrates.
10895	356	4	And David took from him a thousand chariots, and seven thousand horsemen, and twenty thousand footmen: David also houghed all the chariot horses, but reserved of them an hundred chariots.
10896	356	5	And when the Syrians of Damascus came to help Hadarezer king of Zobah, David slew of the Syrians two and twenty thousand men.
10897	356	6	Then David put garrisons in Syria-damascus; and the Syrians became David's servants, and brought gifts. Thus the LORD preserved David whithersoever he went.
10898	356	7	And David took the shields of gold that were on the servants of Hadarezer, and brought them to Jerusalem.
10899	356	8	Likewise from Tibhath, and from Chun, cities of Hadarezer, brought David very much brass, wherewith Solomon made the brasen sea, and the pillars, and the vessels of brass.
10900	356	9	Now when Tou king of Hamath heard how David had smitten all the host of Hadarezer king of Zobah;
10901	356	10	He sent Hadoram his son to king David, to enquire of his welfare, and to congratulate him, because he had fought against Hadarezer, and smitten him; (for Hadarezer had war with Tou;) and with him all manner of vessels of gold and silver and brass.
10902	356	11	Them also king David dedicated unto the LORD, with the silver and the gold that he brought from all these nations; from Edom, and from Moab, and from the children of Ammon, and from the Philistines, and from Amalek.
10903	356	12	Moreover Abishai the son of Zeruiah slew of the Edomites in the valley of salt eighteen thousand.
10904	356	13	And he put garrisons in Edom; and all the Edomites became David's servants. Thus the LORD preserved David whithersoever he went.
10905	356	14	So David reigned over all Israel, and executed judgment and justice among all his people.
10906	356	15	And Joab the son of Zeruiah was over the host; and Jehoshaphat the son of Ahilud, recorder.
10907	356	16	And Zadok the son of Ahitub, and Abimelech the son of Abiathar, were the priests; and Shavsha was scribe;
10908	356	17	And Benaiah the son of Jehoiada was over the Cherethites and the Pelethites; and the sons of David were chief about the king.
10909	357	1	NOW it came to pass after this, that Nahash the king of the children of Ammon died, and his son reigned in his stead.
10910	357	2	And David said, I will shew kindness unto Hanun the son of Nahash, because his father shewed kindness to me. And David sent messengers to comfort him concerning his father. So the servants of David came into the land of the children of Ammon to Hanun, to comfort him.
10911	357	3	But the princes of the children of Ammon said to Hanun, Thinkest thou that David doth honour thy father, that he hath sent comforters unto thee? are not his servants come unto thee for to search, and to overthrow, and to spy out the land?
10912	357	4	Wherefore Hanun took David's servants, and shaved them, and cut off their garments in the midst hard by their buttocks, and sent them away.
10913	357	5	Then there went certain, and told David how the men were served. And he sent to meet them: for the men were greatly ashamed. And the king said, Tarry at Jericho until your beards be grown, and then return.
10914	357	6	And when the children of Ammon saw that they had made themselves odious to David, Hanun and the children of Ammon sent a thousand talents of silver to hire them chariots and horsemen out of Mesopotamia, and out of Syria-maachah, and out of Zobah.
10915	357	7	So they hired thirty and two thousand chariots, and the king of Maachah and his people; who came and pitched before Medeba. And the children of Ammon gathered themselves together from their cities, and came to battle.
10916	357	8	And when David heard of it, he sent Joab, and all the host of the mighty men.
10917	357	9	And the children of Ammon came out, and put the battle in array before the gate of the city: and the kings that were come were by themselves in the field.
10918	357	10	Now when Joab saw that the battle was set against him before and behind, he chose out of all the choice of Israel, and put them in array against the Syrians.
10919	357	11	And the rest of the people he delivered unto the hand of Abishai his brother, and they set themselves in array against the children of Ammon.
10920	357	12	And he said, If the Syrians be too strong for me, then thou shalt help me: but if the children of Ammon be too strong for thee, then I will help thee.
10921	357	13	Be of good courage, and let us behave ourselves valiantly for our people, and for the cities of our God: and let the LORD do that which is good in his sight.
10922	357	14	So Joab and the people that were with him drew nigh before the Syrians unto the battle; and they fled before him.
10923	357	15	And when the children of Ammon saw that the Syrians were fled, they likewise fled before Abishai his brother, and entered into the city. Then Joab came to Jerusalem.
10924	357	16	And when the Syrians saw that they were put to the worse before Israel, they sent messengers, and drew forth the Syrians that were beyond the river: and Shophach the captain of the host of Hadarezer went before them.
10925	357	17	And it was told David; and he gathered all Israel, and passed over Jordan, and came upon them, and set the battle in array against them. So when David had put the battle in array against the Syrians, they fought with him.
10926	357	18	But the Syrians fled before Israel; and David slew of the Syrians seven thousand men which fought in chariots, and forty thousand footmen, and killed Shophach the captain of the host.
10927	357	19	And when the servants of Hadarezer saw that they were put to the worse before Israel, they made peace with David, and became his servants: neither would the Syrians help the children of Ammon any more.
10928	358	1	AND it came to pass, that after the year was expired, at the time that kings go out to battle, Joab led forth the power of the army, and wasted the country of the children of Ammon, and came and besieged Rabbah. But David tarried at Jerusalem. And Joab smote Rabbah, and destroyed it.
10929	358	2	And David took the crown of their king from off his head, and found it to weigh a talent of gold, and there were precious stones in it; and it was set upon David's head: and he brought also exceeding much spoil out of the city.
10930	358	3	And he brought out the people that were in it, and cut them with saws, and with harrows of iron, and with axes. Even so dealt David with all the cities of the children of Ammon. And David and all the people returned to Jerusalem.
10931	358	4	And it came to pass after this, that there arose war at Gezer with the Philistines; at which time Sibbechai the Hushathite slew Sippai, that was of the children of the giant: and they were subdued.
10932	358	5	And there was war again with the Philistines; and Elhanan the son of Jair slew Lahmi the brother of Goliath the Gittite, whose spear staff was like a weaver's beam.
10933	358	6	And yet again there was war at Gath, where was a man of great stature, whose fingers and toes were four and twenty, six on each hand, and six on each foot: and he also was the son of the giant.
10934	358	7	But when he defied Israel, Jonathan the son of Shimea David's brother slew him.
10935	358	8	These were born unto the giant in Gath; and they fell by the hand of David, and by the hand of his servants.
10936	359	1	AND Satan stood up against Israel, and provoked David to number Israel.
10937	359	2	And David said to Joab and to the rulers of the people, Go, number Israel from Beer-sheba even to Dan; and bring the number of them to me, that I may know it.
10938	359	3	And Joab answered, The LORD make his people an hundred times so many more as they be: but, my lord the king, are they not all my lord's servants? why then doth my lord require this thing? why will he be a cause of trespass to Israel?
10939	359	4	Nevertheless the king's word prevailed against Joab. Wherefore Joab departed, and went throughout all Israel, and came to Jerusalem.
10940	359	5	And Joab gave the sum of the number of the people unto David. And all they of Israel were a thousand thousand and an hundred thousand men that drew sword: and Judah was four hundred threescore and ten thousand men that drew sword.
10941	359	6	But Levi and Benjamin counted he not among them: for the king's word was abominable to Joab.
10942	359	7	And God was displeased with this thing; therefore he smote Israel.
10943	359	8	And David said unto God, I have sinned greatly, because I have done this thing: but now, I beseech thee, do away the iniquity of thy servant; for I have done very foolishly.
10944	359	9	And the LORD spake unto Gad, David's seer, saying,
10945	359	10	Go and tell David, saying, Thus saith the LORD, I offer thee three things: choose thee one of them, that I may do it unto thee.
10946	359	11	So Gad came to David, and said unto him, Thus saith the LORD, Choose thee
10947	359	12	Either three years' famine; or three months to be destroyed before thy foes, while that the sword of thine enemies overtaketh thee; or else three days the sword of the LORD, even the pestilence, in the land, and the angel of the LORD destroying throughout all the coasts of Israel. Now therefore advise thyself what word I shall bring again to him that sent me.
10948	359	13	And David said unto Gad, I am in a great strait: let me fall now into the hand of the LORD; for very great are his mercies: but let me not fall into the hand of man.
10949	359	14	So the LORD sent pestilence upon Israel: and there fell of Israel seventy thousand men.
10950	359	15	And God sent an angel unto Jerusalem to destroy it: and as he was destroying, the LORD beheld, and he repented him of the evil, and said to the angel that destroyed, It is enough, stay now thine hand. And the angel of the LORD stood by the threshingfloor of Ornan the Jebusite.
10951	359	16	And David lifted up his eyes, and saw the angel of the LORD stand between the earth and the heaven, having a drawn sword in his hand stretched out over Jerusalem. Then David and the elders of Israel, who were clothed in sackcloth, fell upon their faces.
10952	359	17	And David said unto God, Is it not I that commanded the people to be numbered? even I it is that have sinned and done evil indeed; but as for these sheep, what have they done? let thine hand, I pray thee, O LORD my God, be on me, and on my father's house; but not on thy people, that they should be plagued.
10953	359	18	Then the angel of the LORD commanded Gad to say to David, that David should go up, and set up an altar unto the LORD in the threshingfloor of Ornan the Jebusite.
10954	359	19	And David went up at the saying of Gad, which he spake in the name of the LORD.
10955	359	20	And Ornan turned back, and saw the angel; and his four sons with him hid themselves. Now Ornan was threshing wheat.
10956	359	21	And as David came to Ornan, Ornan looked and saw David, and went out of the threshingfloor, and bowed himself to David with his face to the ground.
10957	359	22	Then David said to Ornan, Grant me the place of this threshingfloor, that I may build an altar therein unto the LORD: thou shalt grant it me for the full price: that the plague may be stayed from the people.
10958	359	23	And Ornan said unto David, Take it to thee, and let my lord the king do that which is good in his eyes: lo, I give thee the oxen also for burnt offerings, and the threshing instruments for wood, and the wheat for the meat offering; I give it all.
10959	359	24	And king David said to Ornan, Nay; but I will verily buy it for the full price: for I will not take that which is thine for the LORD, nor offer burnt offerings without cost.
10960	359	25	So David gave to Ornan for the place six hundred shekels of gold by weight.
10961	359	26	And David built there an altar unto the LORD, and offered burnt offerings and peace offerings, and called upon the LORD; and he answered him from heaven by fire upon the altar of burnt offering.
10962	359	27	And the LORD commanded the angel; and he put up his sword again into the sheath thereof.
10963	359	28	At that time when David saw that the LORD had answered him in the threshingfloor of Ornan the Jebusite, then he sacrificed there.
10964	359	29	For the tabernacle of the LORD, which Moses made in the wilderness, and the altar of the burnt offering, were at that season in the high place at Gibeon.
10965	359	30	But David could not go before it to enquire of God: for he was afraid because of the sword of the angel of the LORD.
10966	360	1	THEN David said, This is the house of the LORD God, and this is the altar of the burnt offering for Israel.
10967	360	2	And David commanded to gather together the strangers that were in the land of Israel; and he set masons to hew wrought stones to build the house of God.
10968	360	3	And David prepared iron in abundance for the nails for the doors of the gates, and for the joinings; and brass in abundance without weight;
10969	360	4	Also cedar trees in abundance: for the Zidonians and they of Tyre brought much cedar wood to David.
10970	360	5	And David said, Solomon my son is young and tender, and the house that is to be builded for the LORD must be exceeding magnifical, of fame and of glory throughout all countries: I will therefore now make preparation for it. So David prepared abundantly before his death.
10971	360	6	Then he called for Solomon his son, and charged him to build an house for the LORD God of Israel.
10972	360	7	And David said to Solomon, My son, as for me, it was in my mind to build an house unto the name of the LORD my God:
10973	360	8	But the word of the LORD came to me, saying, Thou hast shed blood abundantly, and hast made great wars: thou shalt not build an house unto my name, because thou hast shed much blood upon the earth in my sight.
10974	360	9	Behold, a son shall be born to thee, who shall be a man of rest; and I will give him rest from all his enemies round about: for his name shall be Solomon, and I will give peace and quietness unto Israel in his days.
10975	360	10	He shall build an house for my name; and he shall be my son, and I will be his father; and I will establish the throne of his kingdom over Israel for ever.
10976	360	11	Now, my son, the LORD be with thee; and prosper thou, and build the house of the LORD thy God, as he hath said of thee.
10977	360	12	Only the LORD give thee wisdom and understanding, and give thee charge concerning Israel, that thou mayest keep the law of the LORD thy God.
10978	360	13	Then shalt thou prosper, if thou takest heed to fulfil the statutes and judgments which the LORD charged Moses with concerning Israel: be strong, and of good courage; dread not, nor be dismayed.
10979	360	14	Now, behold, in my trouble I have prepared for the house of the LORD an hundred thousand talents of gold, and a thousand thousand talents of silver; and of brass and iron without weight; for it is in abundance: timber also and stone have I prepared; and thou mayest add thereto.
10980	360	15	Moreover there are workmen with thee in abundance, hewers and workers of stone and timber, and all manner of cunning men for every manner of work.
10981	360	16	Of the gold, the silver, and the brass, and the iron, there is no number. Arise therefore, and be doing, and the LORD be with thee.
10982	360	17	David also commanded all the princes of Israel to help Solomon his son, saying,
10983	360	18	Is not the LORD your God with you? and hath he not given you rest on every side? for he hath given the inhabitants of the land into mine hand; and the land is subdued before the LORD, and before his people.
10984	360	19	Now set your heart and your soul to seek the LORD your God; arise therefore, and build ye the sanctuary of the LORD God, to bring the ark of the covenant of the LORD, and the holy vessels of God, into the house that is to be built to the name of the LORD.
10985	361	1	SO when David was old and full of days, he made Solomon his son king over Israel.
10986	361	2	And he gathered together all the princes of Israel, with the priests and the Levites.
10987	361	3	Now the Levites were numbered from the age of thirty years and upward: and their number by their polls, man by man, was thirty and eight thousand.
10988	361	4	Of which, twenty and four thousand were to set forward the work of the house of the LORD; and six thousand were officers and judges:
10989	361	5	Moreover four thousand were porters; and four thousand praised the LORD with the instruments which I made, said David, to praise therewith.
10990	361	6	And David divided them into courses among the sons of Levi, namely, Gershon, Kohath, and Merari.
10991	361	7	Of the Gershonites were, Laadan, and Shimei.
10992	361	8	The sons of Laadan; the chief was Jehiel, and Zetham, and Joel, three.
10993	361	9	The sons of Shimei; Shelomith, and Haziel, and Haran, three. These were the chief of the fathers of Laadan.
10994	361	10	And the sons of Shimei were, Jahath, Zina, and Jeush, and Beriah. These four were the sons of Shimei.
10995	361	11	And Jahath was the chief, and Zizah the second: but Jeush and Beriah had not many sons; therefore they were in one reckoning, according to their father's house.
10996	361	12	The sons of Kohath; Amram, Ishar, Hebron, and Uzziel, four.
10997	361	13	The sons of Amram; Aaron and Moses: and Aaron was separated, that he should sanctify the most holy things, he and his sons for ever, to burn incense before the LORD, to minister unto him, and to bless in his name for ever.
10998	361	14	Now concerning Moses the man of God, his sons were named of the tribe of Levi.
10999	361	15	The sons of Moses were, Gershom, and Eliezer.
11000	361	16	Of the sons of Gershom, Shebuel was the chief.
11001	361	17	And the sons of Eliezer were, Rehabiah the chief. And Eliezer had none other sons; but the sons of Rehabiah were very many.
11002	361	18	Of the sons of Izhar; Shelomith the chief.
11003	361	19	Of the sons of Hebron; Jeriah the first, Amariah the second, Jahaziel the third, and Jekameam the fourth.
11004	361	20	Of the sons of Uzziel; Michah the first, and Jesiah the second.
11005	361	21	The sons of Merari; Mahli, and Mushi. The sons of Mahli; Eleazar, and Kish.
11006	361	22	And Eleazar died, and had no sons, but daughters: and their brethren the sons of Kish took them.
11007	361	23	The sons of Mushi; Mahli, and Eder, and Jeremoth, three.
11008	361	24	These were the sons of Levi after the house of their fathers; even the chief of the fathers, as they were counted by number of names by their polls, that did the work for the service of the house of the LORD, from the age of twenty years and upward.
11009	361	25	For David said, The LORD God of Israel hath given rest unto his people, that they may dwell in Jerusalem for ever:
11010	361	26	And also unto the Levites; they shall no more carry the tabernacle, nor any vessels of it for the service thereof.
11011	361	27	For by the last words of David the Levites were numbered from twenty years old and above:
11012	361	28	Because their office was to wait on the sons of Aaron for the service of the house of the LORD, in the courts, and in the chambers, and in the purifying of all holy things, and the work of the service of the house of God;
11013	361	29	Both for the shewbread, and for the fine flour for meat offering, and for the unleavened cakes, and for that which is baked in the pan, and for that which is fried, and for all manner of measure and size;
11014	361	30	And to stand every morning to thank and praise the LORD, and likewise at even;
11015	361	31	And to offer all burnt sacrifices unto the LORD in the sabbaths, in the new moons, and on the set feasts, by number, according to the order commanded unto them, continually before the LORD:
11016	361	32	And that they should keep the charge of the tabernacle of the congregation, and the charge of the holy place, and the charge of the sons of Aaron their brethren, in the service of the house of the LORD.
11017	362	1	NOW these are the divisions of the sons of Aaron. The sons of Aaron; Nadab, and Abihu, Eleazar, and Ithamar.
11018	362	2	But Nadab and Abihu died before their father, and had no children: therefore Eleazar and Ithamar executed the priest's office.
11019	362	3	And David distributed them, both Zadok of the sons of Eleazar, and Ahimelech of the sons of Ithamar, according to their offices in their service.
11020	362	4	And there were more chief men found of the sons of Eleazar than of the sons of Ithamar; and thus were they divided. Among the sons of Eleazar there were sixteen chief men of the house of their fathers, and eight among the sons of Ithamar according to the house of their fathers.
11021	362	5	Thus were they divided by lot, one sort with another; for the governors of the sanctuary, and governors of the house of God, were of the sons of Eleazar, and of the sons of Ithamar.
11022	362	6	And Shemaiah the son of Nethaneel the scribe, one of the Levites, wrote them before the king, and the princes, and Zadok the priest, and Ahimelech the son of Abiathar, and before the chief of the fathers of the priests and Levites: one principal household being taken for Eleazar, and one taken for Ithamar.
11023	362	7	Now the first lot came forth to Jehoiarib, the second to Jedaiah,
11024	362	8	The third to Harim, the fourth to Seorim,
11025	362	9	The fifth to Malchijah, the sixth to Mijamin,
11026	362	10	The seventh to Hakkoz, the eighth to Abijah,
11027	362	11	The ninth to Jeshua, the tenth to Shecaniah,
11028	362	12	The eleventh to Eliashib, the twelfth to Jakim,
11029	362	13	The thirteenth to Huppah, the fourteenth to Jeshebeab,
11030	362	14	The fifteenth to Bilgah, the sixteenth to Immer,
11031	362	15	The seventeenth to Hezir, the eighteenth to Aphses,
11032	362	16	The nineteenth to Pethahiah, the twentieth to Jehezekel,
11033	362	17	The one and twentieth to Jachin, the two and twentieth to Gamul,
11034	362	18	The three and twentieth to Delaiah, the four and twentieth to Maaziah.
11035	362	19	These were the orderings of them in their service to come into the house of the LORD, according to their manner, under Aaron their father, as the LORD God of Israel had commanded him.
11036	362	20	And the rest of the sons of Levi were these: Of the sons of Amram; Shubael: of the sons of Shubael; Jehdeiah.
11037	362	21	Concerning Rehabiah: of the sons of Rehabiah, the first was Isshiah.
11038	362	22	Of the Izharites; Shelomoth: of the sons of Shelomoth; Jahath.
11039	362	23	And the sons of Hebron; Jeriah the first, Amariah the second, Jahaziel the third, Jekameam the fourth.
11040	362	24	Of the sons of Uzziel; Michah: of the sons of Michah; Shamir.
11041	362	25	The brother of Michah was Isshiah: of the sons of Isshiah; Zechariah.
11042	362	26	The sons of Merari were Mahli and Mushi: the sons of Jaaziah; Beno.
11043	362	27	The sons of Merari by Jaaziah; Beno, and Shoham, and Zaccur, and Ibri.
11044	362	28	Of Mahli came Eleazar, who had no sons.
11045	362	29	Concerning Kish: the son of Kish was Jerahmeel.
11046	362	30	The sons also of Mushi; Mahli, and Eder, and Jerimoth. These were the sons of the Levites after the house of their fathers.
11047	362	31	These likewise cast lots over against their brethren the sons of Aaron in the presence of David the king, and Zadok, and Ahimelech, and the chief of the fathers of the priests and Levites, even the principal fathers over against their younger brethren.
11048	363	1	MOREOVER David and the captains of the host separated to the service of the sons of Asaph, and of Heman, and of Jeduthun, who should prophesy with harps, with psalteries, and with cymbals: and the number of the workmen according to their service was:
11049	363	2	Of the sons of Asaph; Zaccur, and Joseph, and Nethaniah, and Asarelah, the sons of Asaph under the hands of Asaph, which prophesied according to the order of the king.
11050	363	3	Of Jeduthun: the sons of Jeduthun; Gedaliah, and Zeri, and Jeshaiah, Hashabiah, and Mattithiah, six, under the hands of their father Jeduthun, who prophesied with a harp, to give thanks and to praise the LORD.
11051	363	4	Of Heman: the sons of Heman; Bukkiah, Mattaniah, Uzziel, Shebuel, and Jerimoth, Hananiah, Hanani, Eliathah, Giddalti, and Romamti-ezer, Joshbekashah, Mallothi, Hothir, and Mahazioth:
11052	363	5	All these were the sons of Heman the king's seer in the words of God, to lift up the horn. And God gave to Heman fourteen sons and three daughters.
11053	363	6	All these were under the hands of their father for song in the house of the LORD, with cymbals, psalteries, and harps, for the service of the house of God, according to the king's order to Asaph, Jeduthun, and Heman.
11054	363	7	So the number of them, with their brethren that were instructed in the songs of the LORD, even all that were cunning, was two hundred fourscore and eight.
11055	363	8	And they cast lots, ward against ward, as well the small as the great, the teacher as the scholar.
11056	363	9	Now the first lot came forth for Asaph to Joseph: the second to Gedaliah, who with his brethren and sons were twelve:
11057	363	10	The third to Zaccur, he, his sons, and his brethren, were twelve:
11058	363	11	The fourth to Izri, he, his sons, and his brethren, were twelve:
11059	363	12	The fifth to Nethaniah, he, his sons, and his brethren, were twelve:
11060	363	13	The sixth to Bukkiah, he, his sons, and his brethren, were twelve:
11061	363	14	The seventh to Jesharelah, he, his sons, and his brethren, were twelve:
11062	363	15	The eighth to Jeshaiah, he, his sons, and his brethren, were twelve:
11063	363	16	The ninth to Mattaniah, he, his sons, and his brethren, were twelve:
11064	363	17	The tenth to Shimei, he, his sons, and his brethren, were twelve:
11065	363	18	The eleventh to Azareel, he, his sons, and his brethren, were twelve:
11066	363	19	The twelfth to Hashabiah, he, his sons, and his brethren, were twelve:
11067	363	20	The thirteenth to Shubael, he, his sons, and his brethren, were twelve:
11068	363	21	The fourteenth to Mattithiah, he, his sons, and his brethren, were twelve:
11069	363	22	The fifteenth to Jeremoth, he, his sons, and his brethren, were twelve:
11070	363	23	The sixteenth to Hananiah, he, his sons, and his brethren, were twelve:
11071	363	24	The seventeenth to Joshbekashah, he, his sons, and his brethren, were twelve:
11072	363	25	The eighteenth to Hanani, he, his sons, and his brethren, were twelve:
11073	363	26	The nineteenth to Mallothi, he, his sons, and his brethren, were twelve:
11074	363	27	The twentieth to Eliathah, he, his sons, and his brethren, were twelve:
11075	363	28	The one and twentieth to Hothir, he, his sons, and his brethren, were twelve:
11076	363	29	The two and twentieth to Giddalti, he, his sons, and his brethren, were twelve:
11077	363	30	The three and twentieth to Mahazioth, he, his sons, and his brethren, were twelve:
11078	363	31	The four and twentieth to Romamti-ezer, he, his sons, and his brethren, were twelve.
11079	364	1	CONCERNING the divisions of the porters: Of the Korhites was Meshelemiah the son of Kore, of the sons of Asaph.
11080	364	2	And the sons of Meshelemiah were, Zechariah the firstborn, Jediael the second, Zebadiah the third, Jathniel the fourth,
11081	364	3	Elam the fifth, Jehohanan the sixth, Elioenai the seventh.
11082	364	4	Moreover the sons of Obed-edom were, Shemaiah the firstborn, Jehozabad the second, Joah the third, and Sacar the fourth, and Nethaneel the fifth,
11083	364	5	Ammiel the sixth, Issachar the seventh, Peulthai the eighth: for God blessed him.
11084	364	6	Also unto Shemaiah his son were sons born, that ruled throughout the house of their father: for they were mighty men of valour.
11085	364	7	The sons of Shemaiah; Othni, and Rephael, and Obed, Elzabad, whose brethren were strong men, Elihu, and Semachiah.
11086	364	8	All these of the sons of Obed-edom: they and their sons and their brethren, able men for strength for the service, were threescore and two of Obed-edom.
11087	364	9	And Meshelemiah had sons and brethren, strong men, eighteen.
11088	364	10	Also Hosah, of the children of Merari, had sons; Simri the chief, (for though he was not the firstborn, yet his father made him the chief;)
11089	364	11	Hilkiah the second, Tebaliah the third, Zechariah the fourth: all the sons and brethren of Hosah were thirteen.
11090	364	12	Among these were the divisions of the porters, even among the chief men, having wards one against another, to minister in the house of the LORD.
11091	364	13	And they cast lots, as well the small as the great, according to the house of their fathers, for every gate.
11092	364	14	And the lot eastward fell to Shelemiah. Then for Zechariah his son, a wise counsellor, they cast lots; and his lot came out northward.
11093	364	15	To Obed-edom southward; and to his sons the house of Asuppim.
11094	364	16	To Shuppim and Hosah the lot came forth westward, with the gate Shallecheth, by the causeway of the going up, ward against ward.
11095	364	17	Eastward were six Levites, northward four a day, southward four a day, and toward Asuppim two and two.
11096	364	18	At Parbar westward, four at the causeway, and two at Parbar.
11097	364	19	These are the divisions of the porters among the sons of Kore, and among the sons of Merari.
11098	364	20	And of the Levites, Ahijah was over the treasures of the house of God, and over the treasures of the dedicated things.
11099	364	21	As concerning the sons of Laadan; the sons of the Gershonite Laadan, chief fathers, even of Laadan the Gershonite, were Jehieli.
11100	364	22	The sons of Jehieli; Zetham, and Joel his brother, which were over the treasures of the house of the LORD.
11101	364	23	Of the Amramites, and the Izharites, the Hebronites, and the Uzzielites:
11102	364	24	And Shebuel the son of Gershom, the son of Moses, was ruler of the treasures.
11103	364	25	And his brethren by Eliezer; Rehabiah his son, and Jeshaiah his son, and Joram his son, and Zichri his son, and Shelomith his son.
11104	364	26	Which Shelomith and his brethren were over all the treasures of the dedicated things, which David the king, and the chief fathers, the captains over thousands and hundreds, and the captains of the host, had dedicated.
11105	364	27	Out of the spoils won in battles did they dedicate to maintain the house of the LORD.
11106	364	28	And all that Samuel the seer, and Saul the son of Kish, and Abner the son of Ner, and Joab the son of Zeruiah, had dedicated; and whosoever had dedicated any thing, it was under the hand of Shelomith, and of his brethren.
11107	364	29	Of the Izharites, Chenaniah and his sons were for the outward business over Israel, for officers and judges.
11108	364	30	And of the Hebronites, Hashabiah and his brethren, men of valour, a thousand and seven hundred, were officers among them of Israel on this side Jordan westward in all the business of the LORD, and in the service of the king.
11109	364	31	Among the Hebronites was Jerijah the chief, even among the Hebronites, according to the generations of his fathers. In the fortieth year of the reign of David they were sought for, and there were found among them mighty men of valour at Jazer of Gilead.
11110	364	32	And his brethren, men of valour, were two thousand and seven hundred chief fathers, whom king David made rulers over the Reubenites, the Gadites, and the half tribe of Manasseh, for every matter pertaining to God, and affairs of the king.
11111	365	1	NOW the children of Israel after their number, to wit, the chief fathers and captains of thousands and hundreds, and their officers that served the king in any matter of the courses, which came in and went out month by month throughout all the months of the year, of every course were twenty and four thousand.
11112	365	2	Over the first course for the first month was Jashobeam the son of Zabdiel: and in his course were twenty and four thousand.
11113	365	3	Of the children of Perez was the chief of all the captains of the host for the first month.
11114	365	4	And over the course of the second month was Dodai an Ahohite, and of his course was Mikloth also the ruler: in his course likewise were twenty and four thousand.
11115	365	5	The third captain of the host for the third month was Benaiah the son of Jehoiada, a chief priest: and in his course were twenty and four thousand.
11116	365	6	This is that Benaiah, who was mighty among the thirty, and above the thirty: and in his course was Ammizabad his son.
11117	365	7	The fourth captain for the fourth month was Asahel the brother of Joab, and Zebadiah his son after him: and in his course were twenty and four thousand.
11118	365	8	The fifth captain for the fifth month was Shamhuth the Izrahite: and in his course were twenty and four thousand.
11119	365	9	The sixth captain for the sixth month was Ira the son of Ikkesh the Tekoite: and in his course were twenty and four thousand.
11120	365	10	The seventh captain for the seventh month was Helez the Pelonite, of the children of Ephraim: and in his course were twenty and four thousand.
11121	365	11	The eighth captain for the eighth month was Sibbecai the Hushathite, of the Zarhites: and in his course were twenty and four thousand.
11122	365	12	The ninth captain for the ninth month was Abiezer the Anetothite, of the Benjamites: and in his course were twenty and four thousand.
11123	365	13	The tenth captain for the tenth month was Maharai the Netophathite, of the Zarhites: and in his course were twenty and four thousand.
11124	365	14	The eleventh captain for the eleventh month was Benaiah the Pirathonite, of the children of Ephraim: and in his course were twenty and four thousand.
11125	365	15	The twelfth captain for the twelfth month was Heldai the Netophathite, of Othniel: and in his course were twenty and four thousand.
11126	365	16	Furthermore over the tribes of Israel: the ruler of the Reubenites was Eliezer the son of Zichri: of the Simeonites, Shephatiah the son of Maachah:
11127	365	17	Of the Levites, Hashabiah the son of Kemuel: of the Aaronites, Zadok:
11128	365	18	Of Judah, Elihu, one of the brethren of David: of Issachar, Omri the son of Michael:
11129	365	19	Of Zebulun, Ishmaiah the son of Obadiah: of Naphtali, Jerimoth the son of Azriel:
11130	365	20	Of the children of Ephraim, Hoshea the son of Azaziah: of the half tribe of Manasseh, Joel the son of Pedaiah:
11131	365	21	Of the half tribe of Manasseh in Gilead, Iddo the son of Zechariah: of Benjamin, Jaasiel the son of Abner:
11132	365	22	Of Dan, Azareel the son of Jeroham. These were the princes of the tribes of Israel.
11133	365	23	But David took not the number of them from twenty years old and under: because the LORD had said he would increase Israel like to the stars of the heavens.
11134	365	24	Joab the son of Zeruiah began to number, but he finished not, because there fell wrath for it against Israel; neither was the number put in the account of the chronicles of king David.
11135	365	25	And over the king's treasures was Azmaveth the son of Adiel: and over the storehouses in the fields, in the cities, and in the villages, and in the castles, was Jehonathan the son of Uzziah:
11136	365	26	And over them that did the work of the field for tillage of the ground was Ezri the son of Chelub:
11137	365	27	And over the vineyards was Shimei the Ramathite: over the increase of the vineyards for the wine cellars was Zabdi the Shiphmite:
11138	365	28	And over the olive trees and the sycomore trees that were in the low plains was Baal-hanan the Gederite: and over the cellars of oil was Joash:
11139	365	29	And over the herds that fed in Sharon was Shitrai the Sharonite: and over the herds that were in the valleys was Shaphat the son of Adlai:
11140	365	30	Over the camels also was Obil the Ishmaelite: and over the asses was Jehdeiah the Meronothite:
11141	365	31	And over the flocks was Jaziz the Hagerite. All these were the rulers of the substance which was king David's.
11142	365	32	Also Jonathan David's uncle was a counsellor, a wise man, and a scribe: and Jehiel the son of Hachmoni was with the king's sons:
11143	365	33	And Ahithophel was the king's counsellor: and Hushai the Archite was the king's companion:
11144	365	34	And after Ahithophel was Jehoiada the son of Benaiah, and Abiathar: and the general of the king's army was Joab.
11145	366	1	AND David assembled all the princes of Israel, the princes of the tribes, and the captains of the companies that ministered to the king by course, and the captains over the thousands, and captains over the hundreds, and the stewards over all the substance and possession of the king, and of his sons, with the officers, and with the mighty men, and with all the valiant men, unto Jerusalem.
11146	366	2	Then David the king stood up upon his feet, and said, Hear me, my brethren, and my people: As for me, I had in mine heart to build an house of rest for the ark of the covenant of the LORD, and for the footstool of our God, and had made ready for the building:
11147	366	3	But God said unto me, Thou shalt not build an house for my name, because thou hast been a man of war, and hast shed blood.
11148	366	4	Howbeit the LORD God of Israel chose me before all the house of my father to be king over Israel for ever: for he hath chosen Judah to be the ruler; and of the house of Judah, the house of my father; and among the sons of my father he liked me to make me king over all Israel:
11149	366	5	And of all my sons, (for the LORD hath given me many sons,) he hath chosen Solomon my son to sit upon the throne of the kingdom of the LORD over Israel.
11150	366	6	And he said unto me, Solomon thy son, he shall build my house and my courts: for I have chosen him to be my son, and I will be his father.
11151	366	7	Moreover I will establish his kingdom for ever, if he be constant to do my commandments and my judgments, as at this day.
11152	366	8	Now therefore in the sight of all Israel the congregation of the LORD, and in the audience of our God, keep and seek for all the commandments of the LORD your God: that ye may possess this good land, and leave it for an inheritance for your children after you for ever.
11153	366	9	And thou, Solomon my son, know thou the God of thy father, and serve him with a perfect heart and with a willing mind: for the LORD searcheth all hearts, and understandeth all the imaginations of the thoughts: if thou seek him, he will be found of thee; but if thou forsake him, he will cast thee off for ever.
11154	366	10	Take heed now; for the LORD hath chosen thee to build an house for the sanctuary: be strong, and do it.
11155	366	11	Then David gave to Solomon his son the pattern of the porch, and of the houses thereof, and of the treasuries thereof, and of the upper chambers thereof, and of the inner parlours thereof, and of the place of the mercy seat,
11156	366	12	And the pattern of all that he had by the spirit, of the courts of the house of the LORD, and of all the chambers round about, of the treasuries of the house of God, and of the treasuries of the dedicated things:
11157	366	13	Also for the courses of the priests and the Levites, and for all the work of the service of the house of the LORD, and for all the vessels of service in the house of the LORD.
11158	366	14	He gave of gold by weight for things of gold, for all instruments of all manner of service; silver also for all instruments of silver by weight, for all instruments of every kind of service:
11159	366	15	Even the weight for the candlesticks of gold, and for their lamps of gold, by weight for every candlestick, and for the lamps thereof: and for the candlesticks of silver by weight, both for the candlestick, and also for the lamps thereof, according to the use of every candlestick.
11160	366	16	And by weight he gave gold for the tables of shewbread, for every table; and likewise silver for the tables of silver:
11161	366	17	Also pure gold for the fleshhooks, and the bowls, and the cups: and for the golden basons he gave gold by weight for every bason; and likewise silver by weight for every bason of silver:
11162	366	18	And for the altar of incense refined gold by weight; and gold for the pattern of the chariot of the cherubims, that spread out their wings, and covered the ark of the covenant of the LORD.
11163	366	19	All this, said David, the LORD made me understand in writing by his hand upon me, even all the works of this pattern.
11164	366	20	And David said to Solomon his son, Be strong and of good courage, and do it: fear not, nor be dismayed: for the LORD God, even my God, will be with thee; he will not fail thee, nor forsake thee, until thou hast finished all the work for the service of the house of the LORD.
11165	366	21	And, behold, the courses of the priests and the Levites, even they shall be with thee for all the service of the house of God: and there shall be with thee for all manner of workmanship every willing skilful man, for any manner of service: also the princes and all the people will be wholly at thy commandment.
11166	367	1	FURTHERMORE David the king said unto all the congregation, Solomon my son, whom alone God hath chosen, is yet young and tender, and the work is great: for the palace is not for man, but for the LORD God.
11167	367	2	Now I have prepared with all my might for the house of my God the gold for things to be made of gold, and the silver for things of silver, and the brass for things of brass, the iron for things of iron, and wood for things of wood; onyx stones, and stones to be set, glistering stones, and of divers colours, and all manner of precious stones, and marble stones in abundance.
11168	367	3	Moreover, because I have set my affection to the house of my God, I have of mine own proper good, of gold and silver, which I have given to the house of my God, over and above all that I have prepared for the holy house,
11169	367	4	Even three thousand talents of gold, of the gold of Ophir, and seven thousand talents of refined silver, to overlay the walls of the houses withal:
11170	367	5	The gold for things of gold, and the silver for things of silver, and for all manner of work to be made by the hands of artificers. And who then is willing to consecrate his service this day unto the LORD?
11171	367	6	Then the chief of the fathers and princes of the tribes of Israel, and the captains of thousands and of hundreds, with the rulers of the king's work, offered willingly,
11172	367	7	And gave for the service of the house of God of gold five thousand talents and ten thousand drams, and of silver ten thousand talents, and of brass eighteen thousand talents, and one hundred thousand talents of iron.
11173	367	8	And they with whom precious stones were found gave them to the treasure of the house of the LORD, by the hand of Jehiel the Gershonite.
11174	367	9	Then the people rejoiced, for that they offered willingly, because with perfect heart they offered willingly to the LORD: and David the king also rejoiced with great joy.
11175	367	10	Wherefore David blessed the LORD before all the congregation: and David said, Blessed be thou, LORD God of Israel our father, for ever and ever.
11176	367	11	Thine, O LORD, is the greatness, and the power, and the glory, and the victory, and the majesty: for all that is in the heaven and in the earth is thine; thine is the kingdom, O LORD, and thou art exalted as head above all.
11177	367	12	Both riches and honour come of thee, and thou reignest over all; and in thine hand is power and might; and in thine hand it is to make great, and to give strength unto all.
11178	367	13	Now therefore, our God, we thank thee, and praise thy glorious name.
11179	367	14	But who am I, and what is my people, that we should be able to offer so willingly after this sort? for all things come of thee, and of thine own have we given thee.
11180	367	15	For we are strangers before thee, and sojourners, as were all our fathers: our days on the earth are as a shadow, and there is none abiding.
11181	367	16	O LORD our God, all this store that we have prepared to build thee an house for thine holy name cometh of thine hand, and is all thine own.
11182	367	17	I know also, my God, that thou triest the heart, and hast pleasure in uprightness. As for me, in the uprightness of mine heart I have willingly offered all these things: and now have I seen with joy thy people, which are present here, to offer willingly unto thee.
11183	367	18	O LORD God of Abraham, Isaac, and of Israel, our fathers, keep this for ever in the imagination of the thoughts of the heart of thy people, and prepare their heart unto thee:
11184	367	19	And give unto Solomon my son a perfect heart, to keep thy commandments, thy testimonies, and thy statutes, and to do all these things, and to build the palace, for the which I have made provision.
11185	367	20	And David said to all the congregation, Now bless the LORD your God. And all the congregation blessed the LORD God of their fathers, and bowed down their heads, and worshipped the LORD, and the king.
11186	367	21	And they sacrificed sacrifices unto the LORD, and offered burnt offerings unto the LORD, on the morrow after that day, even a thousand bullocks, a thousand rams, and a thousand lambs, with their drink offerings, and sacrifices in abundance for all Israel:
11187	367	22	And did eat and drink before the LORD on that day with great gladness. And they made Solomon the son of David king the second time, and anointed him unto the LORD to be the chief governor, and Zadok to be priest.
11188	367	23	Then Solomon sat on the throne of the LORD as king instead of David his father, and prospered; and all Israel obeyed him.
11189	367	24	And all the princes, and the mighty men, and all the sons likewise of king David, submitted themselves unto Solomon the king.
11190	367	25	And the LORD magnified Solomon exceedingly in the sight of all Israel, and bestowed upon him such royal majesty as had not been on any king before him in Israel.
11191	367	26	Thus David the son of Jesse reigned over all Israel.
11192	367	27	And the time that he reigned over Israel was forty years; seven years reigned he in Hebron, and thirty and three years reigned he in Jerusalem.
11193	367	28	And he died in a good old age, full of days, riches, and honour: and Solomon his son reigned in his stead.
11194	367	29	Now the acts of David the king, first and last, behold, they are written in the book of Samuel the seer, and in the book of Nathan the prophet, and in the book of Gad the seer,
11195	367	30	With all his reign and his might, and the times that went over him, and over Israel, and over all the kingdoms of the countries.
11196	368	1	AND Solomon the son of David was strengthened in his kingdom, and the LORD his God was with him, and magnified him exceedingly.
11197	368	2	Then Solomon spake unto all Israel, to the captains of thousands and of hundreds, and to the judges, and to every governor in all Israel, the chief of the fathers.
11198	368	3	So Solomon, and all the congregation with him, went to the high place that was at Gibeon; for there was the tabernacle of the congregation of God, which Moses the servant of the LORD had made in the wilderness.
11199	368	4	But the ark of God had David brought up from Kirjath-jearim to the place which David had prepared for it: for he had pitched a tent for it at Jerusalem.
11200	368	5	Moreover the brasen altar, that Bezaleel the son of Uri, the son of Hur, had made, he put before the tabernacle of the LORD: and Solomon and the congregation sought unto it.
11201	368	6	And Solomon went up thither to the brasen altar before the LORD, which was at the tabernacle of the congregation, and offered a thousand burnt offerings upon it.
11202	368	7	In that night did God appear unto Solomon, and said unto him, Ask what I shall give thee.
11203	368	8	And Solomon said unto God, Thou hast shewed great mercy unto David my father, and hast made me to reign in his stead.
11204	368	9	Now, O LORD God, let thy promise unto David my father be established: for thou hast made me king over a people like the dust of the earth in multitude.
11205	368	10	Give me now wisdom and knowledge, that I may go out and come in before this people: for who can judge this thy people, that is so great?
11206	368	11	And God said to Solomon, Because this was in thine heart, and thou hast not asked riches, wealth, or honour, nor the life of thine enemies, neither yet hast asked long life; but hast asked wisdom and knowledge for thyself, that thou mayest judge my people, over whom I have made thee king:
11207	368	12	Wisdom and knowledge is granted unto thee; and I will give thee riches, and wealth, and honour, such as none of the kings have had that have been before thee, neither shall there any after thee have the like.
11208	368	13	Then Solomon came from his journey to the high place that was at Gibeon to Jerusalem, from before the tabernacle of the congregation, and reigned over Israel.
11209	368	14	And Solomon gathered chariots and horsemen: and he had a thousand and four hundred chariots, and twelve thousand horsemen, which he placed in the chariot cities, and with the king at Jerusalem.
11210	368	15	And the king made silver and gold at Jerusalem as plenteous as stones, and cedar trees made he as the sycomore trees that are in the vale for abundance.
11211	368	16	And Solomon had horses brought out of Egypt, and linen yarn: the king's merchants received the linen yarn at a price.
11212	368	17	And they fetched up, and brought forth out of Egypt a chariot for six hundred shekels of silver, and an horse for an hundred and fifty: and so brought they out horses for all the kings of the Hittites, and for the kings of Syria, by their means.
11213	369	1	AND Solomon determined to build an house for the name of the LORD, and an house for his kingdom.
11214	369	2	And Solomon told out threescore and ten thousand men to bear burdens, and fourscore thousand to hew in the mountain, and three thousand and six hundred to oversee them.
11215	369	3	And Solomon sent to Huram the king of Tyre, saying, As thou didst deal with David my father, and didst send him cedars to build him an house to dwell therein, even so deal with me.
11216	369	4	Behold, I build an house to the name of the LORD my God, to dedicate it to him, and to burn before him sweet incense, and for the continual shewbread, and for the burnt offerings morning and evening, on the sabbaths, and on the new moons, and on the solemn feasts of the LORD our God. This is an ordinance for ever to Israel.
11217	369	5	And the house which I build is great: for great is our God above all gods.
11218	369	6	But who is able to build him an house, seeing the heaven and heaven of heavens cannot contain him? who am I then, that I should build him an house, save only to burn sacrifice before him?
11219	369	7	Send me now therefore a man cunning to work in gold, and in silver, and in brass, and in iron, and in purple, and crimson, and blue, and that can skill to grave with the cunning men that are with me in Judah and in Jerusalem, whom David my father did provide.
11220	369	8	Send me also cedar trees, fir trees, and algum trees, out of Lebanon: for I know that thy servants can skill to cut timber in Lebanon; and, behold, my servants shall be with thy servants,
11221	369	9	Even to prepare me timber in abundance: for the house which I am about to build shall be wonderful great.
11222	369	10	And, behold, I will give to thy servants, the hewers that cut timber, twenty thousand measures of beaten wheat, and twenty thousand measures of barley, and twenty thousand baths of wine, and twenty thousand baths of oil.
11223	369	11	Then Huram the king of Tyre answered in writing, which he sent to Solomon, Because the LORD hath loved his people, he hath made thee king over them.
11224	369	12	Huram said moreover, Blessed be the LORD God of Israel, that made heaven and earth, who hath given to David the king a wise son, endued with prudence and understanding, that might build an house for the LORD, and an house for his kingdom.
11225	369	13	And now I have sent a cunning man, endued with understanding, of Huram my father's,
11226	369	14	The son of a woman of the daughters of Dan, and his father was a man of Tyre, skilful to work in gold, and in silver, in brass, in iron, in stone, and in timber, in purple, in blue, and in fine linen, and in crimson; also to grave any manner of graving, and to find out every device which shall be put to him, with thy cunning men, and with the cunning men of my lord David thy father.
11227	369	15	Now therefore the wheat, and the barley, the oil, and the wine, which my lord hath spoken of, let him send unto his servants:
11228	369	16	And we will cut wood out of Lebanon, as much as thou shalt need: and we will bring it to thee in floats by sea to Joppa; and thou shall carry it up to Jerusalem.
11229	369	17	And Solomon numbered all the strangers that were in the land of Israel, after the numbering wherewith David his father had numbered them; and they were found an hundred and fifty thousand and three thousand and six hundred.
11230	369	18	And he set threescore and ten thousand of them to be bearers of burdens, and fourscore thousand to be hewers in the mountain, and three thousand and six hundred overseers to set the people a work.
11231	370	1	THEN Solomon began to build the house of the LORD at Jerusalem in mount Moriah, where the LORD appeared unto David his father, in the place that David had prepared in the threshingfloor of Ornan the Jebusite.
11232	370	2	And he began to build in the second day of the second month, in the fourth year of his reign.
11233	370	3	Now these are the things wherein Solomon was instructed for the building of the house of God. The length by cubits after the first measure was threescore cubits, and the breadth twenty cubits.
11234	370	4	And the porch that was in the front of the house, the length of it was according to the breadth of the house, twenty cubits, and the height was an hundred and twenty: and he overlaid it within with pure gold.
11235	370	5	And the greater house he cieled with fir tree, which he overlaid with fine gold, and set thereon palm trees and chains.
11236	370	6	And he garnished the house with precious stones for beauty: and the gold was gold of Parvaim.
11237	370	7	He overlaid also the house, the beams, the posts, and the walls thereof, and the doors thereof, with gold; and graved cherubims on the walls.
11238	370	8	And he made the most holy house, the length whereof was according to the breadth of the house, twenty cubits, and the breadth thereof twenty cubits: and he overlaid it with fine gold, amounting to six hundred talents.
11239	370	9	And the weight of the nails was fifty shekels of gold. And he overlaid the upper chambers with gold.
11240	370	10	And in the most holy house he made two cherubims of image work, and overlaid them with gold.
11241	370	11	And the wings of the cherubims were twenty cubits long: one wing of the one cherub was five cubits, reaching to the wall of the house: and the other wing was likewise five cubits, reaching to the wing of the other cherub.
11242	370	12	And one wing of the other cherub was five cubits, reaching to the wall of the house: and the other wing was five cubits also, joining to the wing of the other cherub.
11243	370	13	The wings of these cherubims spread themselves forth twenty cubits: and they stood on their feet, and their faces were inward.
11244	370	14	And he made the vail of blue, and purple, and crimson, and fine linen, and wrought cherubims thereon.
11245	370	15	Also he made before the house two pillars of thirty and five cubits high, and the chapiter that was on the top of each of them was five cubits.
11246	370	16	And he made chains, as in the oracle, and put them on the heads of the pillars; and made an hundred pomegranates, and put them on the chains.
11247	370	17	And he reared up the pillars before the temple, one on the right hand, and the other on the left; and called the name of that on the right hand Jachin, and the name of that on the left Boaz.
11248	371	1	MOREOVER he made an altar of brass, twenty cubits the length thereof, and twenty cubits the breadth thereof, and ten cubits the height thereof.
11249	371	2	Also he made a molten sea of ten cubits from brim to brim, round in compass, and five cubits the height thereof; and a line of thirty cubits did compass it round about.
11250	371	3	And under it was the similitude of oxen, which did compass it round about: ten in a cubit, compassing the sea round about. Two rows of oxen were cast, when it was cast.
11251	371	4	It stood upon twelve oxen, three looking toward the north, and three looking toward the west, and three looking toward the south, and three looking toward the east: and the sea was set above upon them, and all their hinder parts were inward.
11252	371	5	And the thickness of it was an handbreadth, and the brim of it like the work of the brim of a cup, with flowers of lilies; and it received and held three thousand baths.
11253	371	6	He made also ten lavers, and put five on the right hand, and five on the left, to wash in them: such things as they offered for the burnt offering they washed in them; but the sea was for the priests to wash in.
11254	371	7	And he made ten candlesticks of gold according to their form, and set them in the temple, five on the right hand, and five on the left.
11255	371	8	He made also ten tables, and placed them in the temple, five on the right side, and five on the left. And he made an hundred basons of gold.
11256	371	9	Furthermore he made the court of the priests, and the great court, and doors for the court, and overlaid the doors of them with brass.
11257	371	10	And he set the sea on the right side of the east end, over against the south.
11258	371	11	And Huram made the pots, and the shovels, and the basons. And Huram finished the work that he was to make for king Solomon for the house of God;
11259	371	12	To wit, the two pillars, and the pommels, and the chapiters which were on the top of the two pillars, and the two wreaths to cover the two pommels of the chapiters which were on the top of the pillars;
11260	371	13	And four hundred pomegranates on the two wreaths; two rows of pomegranates on each wreath, to cover the two pommels of the chapiters which were upon the pillars.
11261	371	14	He made also bases, and lavers made he upon the bases;
11262	371	15	One sea, and twelve oxen under it.
11263	371	16	The pots also, and the shovels, and the fleshhooks, and all their instruments, did Huram his father make to king Solomon for the house of the LORD of bright brass.
11264	371	17	In the plain of Jordan did the king cast them, in the clay ground between Succoth and Zeredathah.
11265	371	18	Thus Solomon made all these vessels in great abundance: for the weight of the brass could not be found out.
11266	371	19	And Solomon made all the vessels that were for the house of God, the golden altar also, and the tables whereon the shewbread was set;
11267	371	20	Moreover the candlesticks with their lamps, that they should burn after the manner before the oracle, of pure gold;
11268	371	21	And the flowers, and the lamps, and the tongs, made he of gold, and that perfect gold;
11269	371	22	And the snuffers, and the basons, and the spoons, and the censers, of pure gold: and the entry of the house, the inner doors thereof for the most holy place, and the doors of the house of the temple, were of gold.
11270	372	1	THUS all the work that Solomon made for the house of the LORD was finished: and Solomon brought in all the things that David his father had dedicated; and the silver, and the gold, and all the instruments, put he among the treasures of the house of God.
11271	372	2	Then Solomon assembled the elders of Israel, and all the heads of the tribes, the chief of the fathers of the children of Israel, unto Jerusalem, to bring up the ark of the covenant of the LORD out of the city of David, which is Zion.
11272	372	3	Wherefore all the men of Israel assembled themselves unto the king in the feast which was in the seventh month.
11273	372	4	And all the elders of Israel came; and the Levites took up the ark.
11274	372	5	And they brought up the ark, and the tabernacle of the congregation, and all the holy vessels that were in the tabernacle, these did the priests and the Levites bring up.
11275	372	6	Also king Solomon, and all the congregation of Israel that were assembled unto him before the ark, sacrificed sheep and oxen, which could not be told nor numbered for multitude.
11276	372	7	And the priests brought in the ark of the covenant of the LORD unto his place, to the oracle of the house, into the most holy place, even under the wings of the cherubims:
11277	372	8	For the cherubims spread forth their wings over the place of the ark, and the cherubims covered the ark and the staves thereof above.
11278	372	9	And they drew out the staves of the ark, that the ends of the staves were seen from the ark before the oracle; but they were not seen without. And there it is unto this day.
11279	372	10	There was nothing in the ark save the two tables which Moses put therein at Horeb, when the LORD made a covenant with the children of Israel, when they came out of Egypt.
11280	372	11	And it came to pass, when the priests were come out of the holy place: (for all the priests that were present were sanctified, and did not then wait by course:
11281	372	12	Also the Levites which were the singers, all of them of Asaph, of Heman, of Jeduthun, with their sons and their brethren, being arrayed in white linen, having cymbals and psalteries and harps, stood at the east end of the altar, and with them an hundred and twenty priests sounding with trumpets:)
11282	372	13	It came even to pass, as the trumpeters and singers were as one, to make one sound to be heard in praising and thanking the LORD; and when they lifted up their voice with the trumpets and cymbals and instruments of musick, and praised the LORD, saying, For he is good; for his mercy endureth for ever: that then the house was filled with a cloud, even the house of the LORD;
11283	372	14	So that the priests could not stand to minister by reason of the cloud: for the glory of the LORD had filled the house of God.
11284	373	1	THEN said Solomon, The LORD hath said that he would dwell in the thick darkness.
11285	373	2	But I have built an house of habitation for thee, and a place for thy dwelling for ever.
11286	373	3	And the king turned his face, and blessed the whole congregation of Israel: and all the congregation of Israel stood.
11287	373	4	And he said, Blessed be the LORD God of Israel, who hath with his hands fulfilled that which he spake with his mouth to my father David, saying,
11288	373	5	Since the day that I brought forth my people out of the land of Egypt I chose no city among all the tribes of Israel to build an house in, that my name might be there; neither chose I any man to be a ruler over my people Israel:
11289	373	6	But I have chosen Jerusalem, that my name might be there; and have chosen David to be over my people Israel.
11290	373	7	Now it was in the heart of David my father to build an house for the name of the LORD God of Israel.
11291	373	8	But the LORD said to David my father, Forasmuch as it was in thine heart to build an house for my name, thou didst well in that it was in thine heart:
11292	373	9	Notwithstanding thou shalt not build the house; but thy son which shall come forth out of thy loins, he shall build the house for my name.
11293	373	10	The LORD therefore hath performed his word that he hath spoken: for I am risen up in the room of David my father, and am set on the throne of Israel, as the LORD promised, and have built the house for the name of the LORD God of Israel.
11294	373	11	And in it have I put the ark, wherein is the covenant of the LORD, that he made with the children of Israel.
11295	373	12	And he stood before the altar of the LORD in the presence of all the congregation of Israel, and spread forth his hands:
11296	373	13	For Solomon had made a brasen scaffold, of five cubits long, and five cubits broad, and three cubits high, and had set it in the midst of the court: and upon it he stood, and kneeled down upon his knees before all the congregation of Israel, and spread forth his hands toward heaven,
11297	373	14	And said, O LORD God of Israel, there is no God like thee in the heaven, nor in the earth; which keepest covenant, and shewest mercy unto thy servants, that walk before thee with all their hearts:
11298	373	15	Thou which hast kept with thy servant David my father that which thou hast promised him; and spakest with thy mouth, and hast fulfilled it with thine hand, as it is this day.
11299	373	16	Now therefore, O LORD God of Israel, keep with thy servant David my father that which thou hast promised him, saying, There shall not fail thee a man in my sight to sit upon the throne of Israel; yet so that thy children take heed to their way to walk in my law, as thou hast walked before me.
11300	373	17	Now then, O LORD God of Israel, let thy word be verified, which thou hast spoken unto thy servant David.
11301	373	18	But will God in very deed dwell with men on the earth? behold, heaven and the heaven of heavens cannot contain thee; how much less this house which I have built!
11302	373	19	Have respect therefore to the prayer of thy servant, and to his supplication, O LORD my God, to hearken unto the cry and the prayer which thy servant prayeth before thee:
11303	373	20	That thine eyes may be open upon this house day and night, upon the place whereof thou hast said that thou wouldest put thy name there; to hearken unto the prayer which thy servant prayeth toward this place.
11304	373	21	Hearken therefore unto the supplications of thy servant, and of thy people Israel, which they shall make toward this place: hear thou from thy dwelling place, even from heaven; and when thou hearest, forgive.
11305	373	22	If a man sin against his neighbour, and an oath be laid upon him to make him swear, and the oath come before thine altar in this house;
11306	373	23	Then hear thou from heaven, and do, and judge thy servants, by requiting the wicked, by recompensing his way upon his own head; and by justifying the righteous, by giving him according to his righteousness.
11307	373	24	And if thy people Israel be put to the worse before the enemy, because they have sinned against thee; and shall return and confess thy name, and pray and make supplication before thee in this house;
11308	373	25	Then hear thou from the heavens, and forgive the sin of thy people Israel, and bring them again unto the land which thou gavest to them and to their fathers.
11309	373	26	When the heaven is shut up, and there is no rain, because they have sinned against thee; yet if they pray toward this place, and confess thy name, and turn from their sin, when thou dost afflict them;
11310	373	27	Then hear thou from heaven, and forgive the sin of thy servants, and of thy people Israel, when thou hast taught them the good way, wherein they should walk; and send rain upon thy land, which thou hast given unto thy people for an inheritance.
11311	373	28	If there be dearth in the land, if there be pestilence, if there be blasting, or mildew, locusts, or caterpillers; if their enemies besiege them in the cities of their land; whatsoever sore or whatsoever sickness there be:
11312	373	29	Then what prayer or what supplication soever shall be made of any man, or of all thy people Israel, when every one shall know his own sore and his own grief, and shall spread forth his hands in this house:
11313	373	30	Then hear thou from heaven thy dwelling place, and forgive, and render unto every man according unto all his ways, whose heart thou knowest; (for thou only knowest the hearts of the children of men:)
11314	373	31	That they may fear thee, to walk in thy ways, so long as they live in the land which thou gavest unto our fathers.
11315	373	32	Moreover concerning the stranger, which is not of thy people Israel, but is come from a far country for thy great name's sake, and thy mighty hand, and thy stretched out arm; if they come and pray in this house;
11316	373	33	Then hear thou from the heavens, even from thy dwelling place, and do according to all that the stranger calleth to thee for; that all people of the earth may know thy name, and fear thee, as doth thy people Israel, and may know that this house which I have built is called by thy name.
11317	373	34	If thy people go out to war against their enemies by the way that thou shalt send them, and they pray unto thee toward this city which thou hast chosen, and the house which I have built for thy name;
11318	373	35	Then hear thou from the heavens their prayer and their supplication, and maintain their cause.
11319	373	36	If they sin against thee, (for there is no man which sinneth not,) and thou be angry with them, and deliver them over before their enemies, and they carry them away captives unto a land far off or near;
11320	373	37	Yet if they bethink themselves in the land whither they are carried captive, and turn and pray unto thee in the land of their captivity, saying, We have sinned, we have done amiss, and have dealt wickedly;
11321	373	38	If they return to thee with all their heart and with all their soul in the land of their captivity, whither they have carried them captives, and pray toward their land, which thou gavest unto their fathers, and toward the city which thou hast chosen, and toward the house which I have built for thy name:
11322	373	39	Then hear thou from the heavens, even from thy dwelling place, their prayer and their supplications, and maintain their cause, and forgive thy people which have sinned against thee.
11323	373	40	Now, my God, let, I beseech thee, thine eyes be open, and let thine ears be attent unto the prayer that is made in this place.
11324	373	41	Now therefore arise, O LORD God, into thy resting place, thou, and the ark of thy strength: let thy priests, O LORD God, be clothed with salvation, and let thy saints rejoice in goodness.
11325	373	42	O LORD God, turn not away the face of thine anointed: remember the mercies of David thy servant.
11326	374	1	NOW when Solomon had made an end of praying, the fire came down from heaven, and consumed the burnt offering and the sacrifices; and the glory of the LORD filled the house.
11327	374	2	And the priests could not enter into the house of the LORD, because the glory of the LORD had filled the LORD's house.
11328	374	3	And when all the children of Israel saw how the fire came down, and the glory of the LORD upon the house, they bowed themselves with their faces to the ground upon the pavement, and worshipped, and praised the LORD, saying, For he is good; for his mercy endureth for ever.
11329	374	4	Then the king and all the people offered sacrifices before the LORD.
11330	374	5	And king Solomon offered a sacrifice of twenty and two thousand oxen, and an hundred and twenty thousand sheep: so the king and all the people dedicated the house of God.
11331	374	6	And the priests waited on their offices: the Levites also with instruments of musick of the LORD, which David the king had made to praise the LORD, because his mercy endureth for ever, when David praised by their ministry; and the priests sounded trumpets before them, and all Israel stood.
11332	374	7	Moreover Solomon hallowed the middle of the court that was before the house of the LORD: for there he offered burnt offerings, and the fat of the peace offerings, because the brasen altar which Solomon had made was not able to receive the burnt offerings, and the meat offerings, and the fat.
11333	374	8	Also at the same time Solomon kept the feast seven days, and all Israel with him, a very great congregation, from the entering in of Hamath unto the river of Egypt.
11334	374	9	And in the eighth day they made a solemn assembly: for they kept the dedication of the altar seven days, and the feast seven days.
11335	374	10	And on the three and twentieth day of the seventh month he sent the people away into their tents, glad and merry in heart for the goodness that the LORD had shewed unto David, and to Solomon, and to Israel his people.
11336	374	11	Thus Solomon finished the house of the LORD, and the king's house: and all that came into Solomon's heart to make in the house of the LORD, and in his own house, he prosperously effected.
11337	374	12	And the LORD appeared to Solomon by night, and said unto him, I have heard thy prayer, and have chosen this place to myself for an house of sacrifice.
11338	374	13	If I shut up heaven that there be no rain, or if I command the locusts to devour the land, or if I send pestilence among my people;
11339	374	14	If my people, which are called by my name, shall humble themselves, and pray, and seek my face, and turn from their wicked ways; then will I hear from heaven, and will forgive their sin, and will heal their land.
11340	374	15	Now mine eyes shall be open, and mine ears attent unto the prayer that is made in this place.
11341	374	16	For now have I chosen and sanctified this house, that my name may be there for ever: and mine eyes and mine heart shall be there perpetually.
11342	374	17	And as for thee, if thou wilt walk before me, as David thy father walked, and do according to all that I have commanded thee, and shalt observe my statues and my judgments;
11343	374	18	Then will I stablish the throne of thy kingdom, according as I have covenanted with David thy father, saying, There shall not fail thee a man to be ruler in Israel.
11344	374	19	But if ye turn away, and forsake my statutes and my commandments, which I have set before you, and shall go and serve other gods, and worship them;
11345	374	20	Then will I pluck them up by the roots out of my land which I have given them; and this house, which I have sanctified for my name, will I cast out of my sight, and will make it to be a proverb and a byword among all nations.
11346	374	21	And this house, which is high, shall be an astonishment to every one that passeth by it; so that he shall say, Why hath the LORD done thus unto this land, and unto this house?
11347	374	22	And it shall be answered, Because they forsook the LORD God of their fathers, which brought them forth out of the land of Egypt, and laid hold on other gods, and worshipped them, and served them: therefore hath he brought all this evil upon them.
11348	375	1	AND it came to pass at the end of twenty years, wherein Solomon had built the house of the LORD, and his own house,
11349	375	2	That the cities which Huram had restored to Solomon, Solomon built them, and caused the children of Israel to dwell there.
11350	375	3	And Solomon went to Hamath-zobah, and prevailed against it.
11351	375	4	And he built Tadmor in the wilderness, and all the store cities, which he built in Hamath.
11352	375	5	Also he built Beth-horon the upper, and Beth-horon the nether, fenced cities, with walls, gates, and bars;
11353	375	6	And Baalath, and all the store cities that Solomon had, and all the chariot cities, and the cities of the horsemen, and all that Solomon desired to build in Jerusalem, and in Lebanon, and throughout all the land of his dominion.
11354	375	7	As for all the people that were left of the Hittites, and the Amorites, and the Perizzites, and the Hivites, and the Jebusites, which were not of Israel,
11355	375	8	But of their children, who were left after them in the land, whom the children of Israel consumed not, them did Solomon make to pay tribute until this day.
11356	375	9	But of the children of Israel did Solomon make no servants for his work; but they were men of war, and chief of his captains, and captains of his chariots and horsemen.
11357	375	10	And these were the chief of king Solomon's officers, even two hundred and fifty, that bare rule over the people.
11358	375	11	And Solomon brought up the daughter of Pharaoh out of the city of David unto the house that he had built for her: for he said, My wife shall not dwell in the house of David king of Israel, because the places are holy, whereunto the ark of the LORD hath come.
11359	375	12	Then Solomon offered burnt offerings unto the LORD on the altar of the LORD, which he had built before the porch,
11360	375	13	Even after a certain rate every day, offering according to the commandment of Moses, on the sabbaths, and on the new moons, and on the solemn feasts, three times in the year, even in the feast of unleavened bread, and in the feast of weeks, and in the feast of tabernacles.
11361	375	14	And he appointed, according to the order of David his father, the courses of the priests to their service, and the Levites to their charges, to praise and minister before the priests, as the duty of every day required: the porters also by their courses at every gate: for so had David the man of God commanded.
11362	375	15	And they departed not from the commandment of the king unto the priests and Levites concerning any matter, or concerning the treasures.
11363	375	16	Now all the work of Solomon was prepared unto the day of the foundation of the house of the LORD, and until it was finished. So the house of the LORD was perfected.
11364	375	17	Then went Solomon to Ezion-geber, and to Eloth, at the sea side in the land of Edom.
11365	375	18	And Huram sent him by the hands of his servants ships, and servants that had knowledge of the sea; and they went with the servants of Solomon to Ophir, and took thence four hundred and fifty talents of gold, and brought them to king Solomon.
11366	376	1	AND when the queen of Sheba heard of the fame of Solomon, she came to prove Solomon with hard questions at Jerusalem, with a very great company, and camels that bare spices, and gold in abundance, and precious stones: and when she was come to Solomon, she communed with him of all that was in her heart.
11367	376	2	And Solomon told her all her questions: and there was nothing hid from Solomon which he told her not.
11368	376	3	And when the queen of Sheba had seen the wisdom of Solomon, and the house that he had built,
11369	376	4	And the meat of his table, and the sitting of his servants, and the attendance of his ministers, and their apparel; his cupbearers also, and their apparel; and his ascent by which he went up into the house of the LORD; there was no more spirit in her.
11370	376	5	And she said to the king, It was a true report which I heard in mine own land of thine acts, and of thy wisdom:
11371	376	6	Howbeit I believed not their words, until I came, and mine eyes had seen it: and, behold, the one half of the greatness of thy wisdom was not told me: for thou exceedest the fame that I heard.
11372	376	7	Happy are thy men, and happy are these thy servants, which stand continually before thee, and hear thy wisdom.
11373	376	8	Blessed be the LORD thy God, which delighted in thee to set thee on his throne, to be king for the LORD thy God: because thy God loved Israel, to establish them for ever, therefore made he thee king over them, to do judgment and justice.
11374	376	9	And she gave the king an hundred and twenty talents of gold, and of spices great abundance, and precious stones: neither was there any such spice as the queen of Sheba gave king Solomon.
11375	376	10	And the servants also of Huram, and the servants of Solomon, which brought gold from Ophir, brought algum trees and precious stones.
11376	376	11	And the king made of the algum trees terraces to the house of the LORD, and to the king's palace, and harps and psalteries for singers: and there were none such seen before in the land of Judah.
11377	376	12	And king Solomon gave to the queen of Sheba all her desire, whatsoever she asked, beside that which she had brought unto the king. So she turned, and went away to her own land, she and her servants.
11378	376	13	Now the weight of gold that came to Solomon in one year was six hundred and threescore and six talents of gold;
11379	376	14	Beside that which chapmen and merchants brought. And all the kings of Arabia and governors of the country brought gold and silver to Solomon.
11380	376	15	And king Solomon made two hundred targets of beaten gold: six hundred shekels of beaten gold went to one target.
11381	376	16	And three hundred shields made he of beaten gold: three hundred shekels of gold went to one shield. And the king put them in the house of the forest of Lebanon.
11382	376	17	Moreover the king made a great throne of ivory, and overlaid it with pure gold.
11383	376	18	And there were six steps to the throne, with a footstool of gold, which were fastened to the throne, and stays on each side of the sitting place, and two lions standing by the stays:
11384	376	19	And twelve lions stood there on the one side and on the other upon the six steps. There was not the like made in any kingdom.
11385	376	20	And all the drinking vessels of king Solomon were of gold, and all the vessels of the house of the forest of Lebanon were of pure gold: none were of silver; it was not any thing accounted of in the days of Solomon.
11386	376	21	For the king's ships went to Tarshish with the servants of Huram: every three years once came the ships of Tarshish bringing gold, and silver, ivory, and apes, and peacocks.
11387	376	22	And king Solomon passed all the kings of the earth in riches and wisdom.
11388	376	23	And all the kings of the earth sought the presence of Solomon, to hear his wisdom, that God had put in his heart.
11389	376	24	And they brought every man his present, vessels of silver, and vessels of gold, and raiment, harness, and spices, horses, and mules, a rate year by year.
11390	376	25	And Solomon had four thousand stalls for horses and chariots, and twelve thousand horsemen; whom he bestowed in the chariot cities, and with the king at Jerusalem.
11391	376	26	And he reigned over all the kings from the river even unto the land of the Philistines, and to the border of Egypt.
11392	376	27	And the king made silver in Jerusalem as stones, and cedar trees made he as the sycomore trees that are in the low plains in abundance.
11393	376	28	And they brought unto Solomon horses out of Egypt, and out of all lands.
11394	376	29	Now the rest of the acts of Solomon, first and last, are they not written in the book of Nathan the prophet, and in the prophecy of Ahijah the Shilonite, and in the visions of Iddo the seer against Jeroboam the son of Nebat?
11395	376	30	And Solomon reigned in Jerusalem over all Israel forty years.
11396	376	31	And Solomon slept with his fathers, and he was buried in the city of David his father: and Rehoboam his son reigned in his stead.
11397	377	1	AND Rehoboam went to Shechem: for to Shechem were all Israel come to make him king.
11398	377	2	And it came to pass, when Jeroboam the son of Nebat, who was in Egypt, whither he had fled from the presence of Solomon the king, heard it, that Jeroboam returned out of Egypt.
11399	377	3	And they sent and called him. So Jeroboam and all Israel came and spake to Rehoboam, saying,
11400	377	4	Thy father made our yoke grievous: now therefore ease thou somewhat the grievous servitude of thy father, and his heavy yoke that he put upon us, and we will serve thee.
11401	377	5	And he said unto them, Come again unto me after three days. And the people departed.
11402	377	6	And king Rehoboam took counsel with the old men that had stood before Solomon his father while he yet lived, saying, What counsel give ye me to return answer to this people?
11403	377	7	And they spake unto him, saying, If thou be kind to this people, and please them, and speak good words to them, they will be thy servants for ever.
11404	377	8	But he forsook the counsel which the old men gave him, and took counsel with the young men that were brought up with him, that stood before him.
11405	377	9	And he said unto them, What advice give ye that we may return answer to this people, which have spoken to me, saying, Ease somewhat the yoke that thy father did put upon us?
11406	377	10	And the young men that were brought up with him spake unto him, saying, Thus shalt thou answer the people that spake unto thee, saying, Thy father made our yoke heavy, but make thou it somewhat lighter for us; thus shalt thou say unto them, My little finger shall be thicker than my father's loins.
11407	377	11	For whereas my father put a heavy yoke upon you, I will put more to your yoke: my father chastised you with whips, but I will chastise you with scorpions.
11408	377	12	So Jeroboam and all the people came to Rehoboam on the third day, as the king bade, saying, Come again to me on the third day.
11409	377	13	And the king answered them roughly; and king Rehoboam forsook the counsel of the old men,
11410	377	14	And answered them after the advice of the young men, saying, My father made your yoke heavy, but I will add thereto: my father chastised you with whips, but I will chastise you with scorpions.
11411	377	15	So the king hearkened not unto the people: for the cause was of God, that the LORD might perform his word, which he spake by the hand of Ahijah the Shilonite to Jeroboam the son of Nebat.
11412	377	16	And when all Israel saw that the king would not hearken unto them, the people answered the king, saying, What portion have we in David? and we have none inheritance in the son of Jesse: every man to your tents, O Israel: and now, David, see to thine own house. So all Israel went to their tents.
11413	377	17	But as for the children of Israel that dwelt in the cities of Judah, Rehoboam reigned over them.
11414	377	18	Then king Rehoboam sent Hadoram that was over the tribute; and the children of Israel stoned him with stones, that he died. But king Rehoboam made speed to get him up to his chariot, to flee to Jerusalem.
11415	377	19	And Israel rebelled against the house of David unto this day.
11416	378	1	AND when Rehoboam was come to Jerusalem, he gathered of the house of Judah and Benjamin an hundred and fourscore thousand chosen men, which were warriors, to fight against Israel, that he might bring the kingdom again to Rehoboam.
11417	378	2	But the word of the LORD came to Shemaiah the man of God, saying,
11418	378	3	Speak unto Rehoboam the son of Solomon, king of Judah, and to all Israel in Judah and Benjamin, saying,
11419	378	4	Thus saith the LORD, Ye shall not go up, nor fight against your brethren: return every man to his house: for this thing is done of me. And they obeyed the words of the LORD, and returned from going against Jeroboam.
11420	378	5	And Rehoboam dwelt in Jerusalem, and built cities for defence in Judah.
11421	378	6	He built even Beth-lehem, and Etam, and Tekoa,
11422	378	7	And Beth-zur, and Shoco, and Adullam,
11423	378	8	And Gath, and Mareshah, and Ziph,
11424	378	9	And Adoraim, and Lachish, and Azekah,
11425	378	10	And Zorah, and Aijalon, and Hebron, which are in Judah and in Benjamin fenced cities.
11426	378	11	And he fortified the strong holds, and put captains in them, and store of victual, and of oil and wine.
11427	378	12	And in every several city he put shields and spears, and made them exceeding strong, having Judah and Benjamin on his side.
11428	378	13	And the priests and the Levites that were in all Israel resorted to him out of all their coasts.
11429	378	14	For the Levites left their suburbs and their possession, and came to Judah and Jerusalem: for Jeroboam and his sons had cast them off from executing the priest's office unto the LORD:
11430	378	15	And he ordained him priests for the high places, and for the devils, and for the calves which he had made.
11431	378	16	And after them out of all the tribes of Israel such as set their hearts to seek the LORD God of Israel came to Jerusalem, to sacrifice unto the LORD God of their fathers.
11432	378	17	So they strengthened the kingdom of Judah, and made Rehoboam the son of Solomon strong, three years: for three years they walked in the way of David and Solomon.
11433	378	18	And Rehoboam took him Mahalath the daughter of Jerimoth the son of David to wife, and Abihail the daughter of Eliab the son of Jesse;
11434	378	19	Which bare him children; Jeush, and Shamariah, and Zaham.
11435	378	20	And after her he took Maachah the daughter of Absalom; which bare him Abijah, and Attai, and Ziza, and Shelomith.
11436	378	21	And Rehoboam loved Maachah the daughter of Absalom above all his wives and his concubines: (for he took eighteen wives, and threescore concubines; and begat twenty and eight sons, and threescore daughters.)
11437	378	22	And Rehoboam made Abijah the son of Maachah the chief, to be ruler among his brethren: for he thought to make him king.
11438	378	23	And he dealt wisely, and dispersed of all his children throughout all the countries of Judah and Benjamin, unto every fenced city: and he gave them victual in abundance. And he desired many wives.
11439	379	1	AND it came to pass, when Rehoboam had established the kingdom, and had strengthened himself, he forsook the law of the LORD, and all Israel with him.
11440	379	2	And it came to pass, that in the fifth year of king Rehoboam Shishak king of Egypt came up against Jerusalem, because they had transgressed against the LORD,
11441	379	3	With twelve hundred chariots, and threescore thousand horsemen: and the people were without number that came with him out of Egypt; the Lubims, the Sukkiims, and the Ethiopians.
11442	379	4	And he took the fenced cities which pertained to Judah, and came to Jerusalem.
11443	379	5	Then came Shemaiah the prophet to Rehoboam, and to the princes of Judah, that were gathered together to Jerusalem because of Shishak, and said unto them, Thus saith the LORD, Ye have forsaken me, and therefore have I also left you in the hand of Shishak.
11444	379	6	Whereupon the princes of Israel and the king humbled themselves; and they said, The LORD is righteous.
11445	379	7	And when the LORD saw that they humbled themselves, the word of the LORD came to Shemaiah, saying, They have humbled themselves; therefore I will not destroy them, but I will grant them some deliverance; and my wrath shall not be poured out upon Jerusalem by the hand of Shishak.
11446	379	8	Nevertheless they shall be his servants; that they may know my service, and the service of the kingdoms of the countries.
11447	379	9	So Shishak king of Egypt came up against Jerusalem, and took away the treasures of the house of the LORD, and the treasures of the king's house; he took all: he carried away also the shields of gold which Solomon had made.
11448	379	10	Instead of which king Rehoboam made shields of brass, and committed them to the hands of the chief of the guard, that kept the entrance of the king's house.
11449	379	11	And when the king entered into the house of the LORD, the guard came and fetched them, and brought them again into the guard chamber.
11450	379	12	And when he humbled himself, the wrath of the LORD turned from him that he would not destroy him altogether: and also in Judah things went well.
11451	379	13	So king Rehoboam strengthened himself in Jerusalem, and reigned: for Rehoboam was one and forty years old when he began to reign, and he reigned seventeen years in Jerusalem, the city which the LORD had chosen out of all the tribes of Israel, to put his name there. And his mother's name was Naamah an Ammonitess.
11452	379	14	And he did evil, because he prepared not his heart to seek the LORD.
11453	379	15	Now the acts of Rehoboam, first and last, are they not written in the book of Shemaiah the prophet, and of Iddo the seer concerning genealogies? And there were wars between Rehoboam and Jeroboam continually.
11454	379	16	And Rehoboam slept with his fathers, and was buried in the city of David: and Abijah his son reigned in his stead.
11455	380	1	NOW in the eighteenth year of king Jeroboam began Abijah to reign over Judah.
11456	380	2	He reigned three years in Jerusalem. His mother's name also was Michaiah the daughter of Uriel of Gibeah. And there was war between Abijah and Jeroboam.
11457	380	3	And Abijah set the battle in array with an army of valiant men of war, even four hundred thousand chosen men: Jeroboam also set the battle in array against him with eight hundred thousand chosen men, being mighty men of valour.
11458	380	4	And Abijah stood up upon mount Zemaraim, which is in mount Ephraim, and said, Hear me, thou Jeroboam, and all Israel;
11459	380	5	Ought ye not to know that the LORD God of Israel gave the kingdom over Israel to David for ever, even to him and to his sons by a covenant of salt?
11460	380	6	Yet Jeroboam the son of Nebat, the servant of Solomon the son of David, is risen up, and hath rebelled against his lord.
11461	380	7	And there are gathered unto him vain men, the children of Belial, and have strengthened themselves against Rehoboam the son of Solomon, when Rehoboam was young and tenderhearted, and could not withstand them.
11462	380	8	And now ye think to withstand the kingdom of the LORD in the hand of the sons of David; and ye be a great multitude, and there are with you golden calves, which Jeroboam made you for gods.
11463	380	9	Have ye not cast out the priests of the LORD, the sons of Aaron, and the Levites, and have made you priests after the manner of the nations of other lands? so that whosoever cometh to consecrate himself with a young bullock and seven rams, the same may be a priest of them that are no gods.
11464	380	10	But as for us, the LORD is our God, and we have not forsaken him; and the priests, which minister unto the LORD, are the sons of Aaron, and the Levites wait upon their business:
11465	380	11	And they burn unto the LORD every morning and every evening burnt sacrifices and sweet incense: the shewbread also set they in order upon the pure table; and the candlestick of gold with the lamps thereof, to burn every evening: for we keep the charge of the LORD our God; but ye have forsaken him.
11466	380	12	And, behold, God himself is with us for our captain, and his priests with sounding trumpets to cry alarm against you. O children of Israel, fight ye not against the LORD God of your fathers; for ye shall not prosper.
11467	380	13	But Jeroboam caused an ambushment to come about behind them: so they were before Judah, and the ambushment was behind them.
11468	380	14	And when Judah looked back, behold, the battle was before and behind: and they cried unto the LORD, and the priests sounded with the trumpets.
11469	380	15	Then the men of Judah gave a shout: and as the men of Judah shouted, it came to pass, that God smote Jeroboam and all Israel before Abijah and Judah.
11470	380	16	And the children of Israel fled before Judah: and God delivered them into their hand.
11471	380	17	And Abijah and his people slew them with a great slaughter: so there fell down slain of Israel five hundred thousand chosen men.
11472	380	18	Thus the children of Israel were brought under at that time, and the children of Judah prevailed, because they relied upon the LORD God of their fathers.
11473	380	19	And Abijah pursued after Jeroboam, and took cities from him, Beth-el with the towns thereof, and Jeshanah with the towns thereof, and Ephrain with the towns thereof.
11474	380	20	Neither did Jeroboam recover strength again in the days of Abijah: and the LORD struck him, and he died.
11475	380	21	But Abijah waxed mighty, and married fourteen wives, and begat twenty and two sons, and sixteen daughters.
11476	380	22	And the rest of the acts of Abijah, and his ways, and his sayings, are written in the story of the prophet Iddo.
11477	381	1	SO Abijah slept with his fathers, and they buried him in the city of David: and Asa his son reigned in his stead. In his days the land was quiet ten years.
11478	381	2	And Asa did that which was good and right in the eyes of the LORD his God:
11479	381	3	For he took away the altars of the strange gods, and the high places, and brake down the images, and cut down the groves:
11480	381	4	And commanded Judah to seek the LORD God of their fathers, and to do the law and the commandment.
11481	381	5	Also he took away out of all the cities of Judah the high places and the images: and the kingdom was quiet before him.
11482	381	6	And he built fenced cities in Judah: for the land had rest, and he had no war in those years; because the LORD had given him rest.
11483	381	7	Therefore he said unto Judah, Let us build these cities, and make about them walls, and towers, gates, and bars, while the land is yet before us; because we have sought the LORD our God, we have sought him, and he hath given us rest on every side. So they built and prospered.
11484	381	8	And Asa had an army of men that bare targets and spears, out of Judah three hundred thousand; and out of Benjamin, that bare shields and drew bows, two hundred and fourscore thousand: all these were mighty men of valour.
11485	381	9	And there came out against them Zerah the Ethiopian with an host of a thousand thousand, and three hundred chariots; and came unto Mareshah.
11486	381	10	Then Asa went out against him, and they set the battle in array in the valley of Zephathah at Mareshah.
11487	381	11	And Asa cried unto the LORD his God, and said, LORD, it is nothing with thee to help, whether with many, or with them that have no power: help us, O LORD our God; for we rest on thee, and in thy name we go against this multitude. O LORD, thou art our God; let not man prevail against thee.
11488	381	12	So the LORD smote the Ethiopians before Asa and before Judah; and the Ethiopians fled.
11489	381	13	And Asa and the people that were with him pursued them unto Gerar: and the Ethiopians were overthrown, that they could not recover themselves; for they were destroyed before the LORD, and before his host; and they carried away very much spoil.
11490	381	14	And they smote all the cities round about Gerar; for the fear of the LORD came upon them: and they spoiled all the cities; for there was exceeding much spoil in them.
11491	381	15	They smote also the tents of cattle, and carried away sheep and camels in abundance, and returned to Jerusalem.
11492	382	1	AND the Spirit of God came upon Azariah the son of Oded:
11493	382	2	And he went out to meet Asa, and said unto him, Hear ye me, Asa, and all Judah and Benjamin; The LORD is with you, while ye be with him; and if ye seek him, he will be found of you; but if ye forsake him, he will forsake you.
11494	382	3	Now for a long season Israel hath been without the true God, and without a teaching priest, and without law.
11495	382	4	But when they in their trouble did turn unto the LORD God of Israel, and sought him, he was found of them.
11496	382	5	And in those times there was no peace to him that went out, nor to him that came in, but great vexations were upon all the inhabitants of the countries.
11497	382	6	And nation was destroyed of nation, and city of city: for God did vex them with all adversity.
11498	382	7	Be ye strong therefore, and let not your hands be weak: for your work shall be rewarded.
11499	382	8	And when Asa heard these words, and the prophecy of Oded the prophet, he took courage, and put away the abominable idols out of all the land of Judah and Benjamin, and out of the cities which he had taken from mount Ephraim, and renewed the altar of the LORD, that was before the porch of the LORD.
11500	382	9	And he gathered all Judah and Benjamin, and the strangers with them out of Ephraim and Manasseh, and out of Simeon: for they fell to him out of Israel in abundance, when they saw that the LORD his God was with him.
11501	382	10	So they gathered themselves together at Jerusalem in the third month, in the fifteenth year of the reign of Asa.
11502	382	11	And they offered unto the LORD the same time, of the spoil which they had brought, seven hundred oxen and seven thousand sheep.
11503	382	12	And they entered into a covenant to seek the LORD God of their fathers with all their heart and with all their soul;
11504	382	13	That whosoever would not seek the LORD God of Israel should be put to death, whether small or great, whether man or woman.
11505	382	14	And they sware unto the LORD with a loud voice, and with shouting, and with trumpets, and with cornets.
11506	382	15	And all Judah rejoiced at the oath: for they had sworn with all their heart, and sought him with their whole desire; and he was found of them: and the LORD gave them rest round about.
11507	382	16	And also concerning Maachah the mother of Asa the king, he removed her from being queen, because she had made an idol in a grove: and Asa cut down her idol, and stamped it, and burnt it at the brook Kidron.
11508	382	17	But the high places were not taken away out of Israel: nevertheless the heart of Asa was perfect all his days.
11509	382	18	And he brought into the house of God the things that his father had dedicated, and that he himself had dedicated, silver, and gold, and vessels.
11510	382	19	And there was no more war unto the five and thirtieth year of the reign of Asa.
11511	383	1	IN the six and thirtieth year of the reign of Asa Baasha king of Israel came up against Judah, and built Ramah, to the intent that he might let none go out or come in to Asa king of Judah.
11512	383	2	Then Asa brought out silver and gold out of the treasures of the house of the LORD and of the king's house, and sent to Ben-hadad king of Syria, that dwelt at Damascus, saying,
11513	383	3	There is a league between me and thee, as there was between my father and thy father: behold, I have sent thee silver and gold; go, break thy league with Baasha king of Israel, that he may depart from me.
11514	383	4	And Ben-hadad hearkened unto king Asa, and sent the captains of his armies against the cities of Israel; and they smote Ijon, and Dan, and Abel-maim, and all the store cities of Naphtali.
11515	383	5	And it came to pass, when Baasha heard it, that he left off building of Ramah, and let his work cease.
11516	383	6	Then Asa the king took all Judah; and they carried away the stones of Ramah, and the timber thereof, wherewith Baasha was building; and he built therewith Geba and Mizpah.
11517	383	7	And at that time Hanani the seer came to Asa king of Judah, and said unto him, Because thou hast relied on the king of Syria, and not relied on the LORD thy God, therefore is the host of the king of Syria escaped out of thine hand.
11518	383	8	Were not the Ethiopians and the Lubims a huge host, with very many chariots and horsemen? yet, because thou didst rely on the LORD, he delivered them into thine hand.
11519	383	9	For the eyes of the LORD run to and fro throughout the whole earth, to shew himself strong in the behalf of them whose heart is perfect toward him. Herein thou hast done foolishly: therefore from henceforth thou shalt have wars.
11520	383	10	Then Asa was wroth with the seer, and put him in a prison house; for he was in a rage with him because of this thing. And Asa oppressed some of the people the same time.
11521	383	11	And, behold, the acts of Asa, first and last, lo, they are written in the book of the kings of Judah and Israel.
11522	383	12	And Asa in the thirty and ninth year of his reign was diseased in his feet, until his disease was exceeding great: yet in his disease he sought not to the LORD, but to the physicians.
11523	383	13	And Asa slept with his fathers, and died in the one and fortieth year of his reign.
11524	383	14	And they buried him in his own sepulchres, which he had made for himself in the city of David, and laid him in the bed which was filled with sweet odours and divers kinds of spices prepared by the apothecaries' art: and they made a very great burning for him.
11525	384	1	AND Jehoshaphat his son reigned in his stead, and strengthened himself against Israel.
11526	384	2	And he placed forces in all the fenced cities of Judah, and set garrisons in the land of Judah, and in the cities of Ephraim, which Asa his father had taken.
11527	384	3	And the LORD was with Jehoshaphat, because he walked in the first ways of his father David, and sought not unto Baalim;
11528	384	4	But sought to the LORD God of his father, and walked in his commandments, and not after the doings of Israel.
11529	384	5	Therefore the LORD stablished the kingdom in his hand; and all Judah brought to Jehoshaphat presents; and he had riches and honour in abundance.
11530	384	6	And his heart was lifted up in the ways of the LORD: moreover he took away the high places and groves out of Judah.
11531	384	7	Also in the third year of his reign he sent to his princes, even to Ben-hail, and to Obadiah, and to Zechariah, and to Nethaneel, and to Michaiah, to teach in the cities of Judah.
11532	384	8	And with them he sent Levites, even Shemaiah, and Nethaniah, and Zebadiah, and Asahel, and Shemiramoth, and Jehonathan, and Adonijah, and Tobijah, and Tob-adonijah, Levites; and with them Elishama and Jehoram, priests.
11533	384	9	And they taught in Judah, and had the book of the law of the LORD with them, and went about throughout all the cities of Judah, and taught the people.
11534	384	10	And the fear of the LORD fell upon all the kingdoms of the lands that were round about Judah, so that they made no war against Jehoshaphat.
11535	384	11	Also some of the Philistines brought Jehoshaphat presents, and tribute silver; and the Arabians brought him flocks, seven thousand and seven hundred rams, and seven thousand and seven hundred he goats.
11536	384	12	And Jehoshaphat waxed great exceedingly; and he built in Judah castles, and cities of store.
11537	384	13	And he had much business in the cities of Judah: and the men of war, mighty men of valour, were in Jerusalem.
11538	384	14	And these are the numbers of them according to the house of their fathers: Of Judah, the captains of thousands; Adnah the chief, and with him mighty men of valour three hundred thousand.
11539	384	15	And next to him was Jehohanan the captain, and with him two hundred and fourscore thousand.
11540	384	16	And next him was Amasiah the son of Zichri, who willingly offered himself unto the LORD; and with him two hundred thousand mighty men of valour.
11541	384	17	And of Benjamin; Eliada a mighty man of valour, and with him armed men with bow and shield two hundred thousand.
11542	384	18	And next him was Jehozabad, and with him an hundred and fourscore thousand ready prepared for the war.
11543	384	19	These waited on the king, beside those whom the king put in the fenced cities throughout all Judah.
11544	385	1	NOW Jehoshaphat had riches and honour in abundance, and joined affinity with Ahab.
11545	385	2	And after certain years he went down to Ahab to Samaria. And Ahab killed sheep and oxen for him in abundance, and for the people that he had with him, and persuaded him to go up with him to Ramoth-gilead.
11546	385	3	And Ahab king of Israel said unto Jehoshaphat king of Judah, Wilt thou go with me to Ramoth-gilead? And he answered him, I am as thou art, and my people as thy people; and we will be with thee in the war.
11547	385	4	And Jehoshaphat said unto the king of Israel, Enquire, I pray thee, at the word of the LORD to day.
11548	385	5	Therefore the king of Israel gathered together of prophets four hundred men, and said unto them, Shall we go to Ramoth-gilead to battle, or shall I forbear? And they said, Go up; for God will deliver it into the king's hand.
11549	385	6	But Jehoshaphat said, Is there not here a prophet of the LORD besides, that we might enquire of him?
11550	385	7	And the king of Israel said unto Jehoshaphat, There is yet one man, by whom we may enquire of the LORD: but I hate him; for he never prophesied good unto me, but always evil: the same is Micaiah the son of Imla. And Jehoshaphat said, Let not the king say so.
11551	385	8	And the king of Israel called for one of his officers, and said, Fetch quickly Micaiah the son of Imla.
11552	385	9	And the king of Israel and Jehoshaphat king of Judah sat either of them on his throne, clothed in their robes, and they sat in a void place at the entering in of the gate of Samaria; and all the prophets prophesied before them.
11553	385	10	And Zedekiah the son of Chenaanah had made him horns of iron, and said, Thus saith the LORD, With these thou shalt push Syria until they be consumed.
11554	385	11	And all the prophets prophesied so, saying, Go up to Ramoth-gilead, and prosper: for the LORD shall deliver it into the hand of the king.
11555	385	12	And the messenger that went to call Micaiah spake to him, saying, Behold, the words of the prophets declare good to the king with one assent; let thy word therefore, I pray thee, be like one of theirs, and speak thou good.
11556	385	13	And Micaiah said, As the LORD liveth, even what my God saith, that will I speak.
11557	385	14	And when he was come to the king, the king said unto him, Micaiah, shall we go to Ramoth-gilead to battle, or shall I forbear? And he said, Go ye up, and prosper, and they shall be delivered into your hand.
11558	385	15	And the king said to him, How many times shall I adjure thee that thou say nothing but the truth to me in the name of the LORD?
11559	385	16	Then he said, I did see all Israel scattered upon the mountains, as sheep that have no shepherd: and the LORD said, These have no master; let them return therefore every man to his house in peace.
11560	385	17	And the king of Israel said to Jehoshaphat, Did I not tell thee that he would not prophesy good unto me, but evil?
11561	385	18	Again he said, Therefore hear the word of the LORD; I saw the LORD sitting upon his throne, and all the host of heaven standing on his right hand and on his left.
11562	385	19	And the LORD said, Who shall entice Ahab king of Israel, that he may go up and fall at Ramoth-gilead? And one spake saying after this manner, and another saying after that manner.
11563	385	20	Then there came out a spirit, and stood before the LORD, and said, I will entice him. And the LORD said unto him, Wherewith?
11564	385	21	And he said, I will go out, and be a lying spirit in the mouth of all his prophets. And the LORD said, Thou shalt entice him, and thou shalt also prevail: go out, and do even so.
11565	385	22	Now therefore, behold, the LORD hath put a lying spirit in the mouth of these thy prophets, and the LORD hath spoken evil against thee.
11566	385	23	Then Zedekiah the son of Chenaanah came near, and smote Micaiah upon the cheek, and said, Which way went the Spirit of the LORD from me to speak unto thee?
11567	385	24	And Micaiah said, Behold, thou shalt see on that day when thou shalt go into an inner chamber to hide thyself.
11568	385	25	Then the king of Israel said, Take ye Micaiah, and carry him back to Amon the governor of the city, and to Joash the king's son;
11569	385	26	And say, Thus saith the king, Put this fellow in the prison, and feed him with bread of affliction and with water of affliction, until I return in peace.
11570	385	27	And Micaiah said, If thou certainly return in peace, then hath not the LORD spoken by me. And he said, Hearken, all ye people.
11571	385	28	So the king of Israel and Jehoshaphat the king of Judah went up to Ramoth-gilead.
11572	385	29	And the king of Israel said unto Jehoshaphat, I will disguise myself, and will go to the battle; but put thou on thy robes. So the king of Israel disguised himself; and they went to the battle.
11573	385	30	Now the king of Syria had commanded the captains of the chariots that were with him, saying, Fight ye not with small or great, save only with the king of Israel.
11574	385	31	And it came to pass, when the captains of the chariots saw Jehoshaphat, that they said, It is the king of Israel. Therefore they compassed about him to fight: but Jehoshaphat cried out, and the LORD helped him; and God moved them to depart from him.
11575	385	32	For it came to pass, that, when the captains of the chariots perceived that it was not the king of Israel, they turned back again from pursuing him.
11576	385	33	And a certain man drew a bow at a venture, and smote the king of Israel between the joints of the harness: therefore he said to his chariot man, Turn thine hand, that thou mayest carry me out of the host; for I am wounded.
11577	385	34	And the battle increased that day: howbeit the king of Israel stayed himself up in his chariot against the Syrians until the even: and about the time of the sun going down he died.
11578	386	1	AND Jehoshaphat the king of Judah returned to his house in peace to Jerusalem.
11579	386	2	And Jehu the son of Hanani the seer went out to meet him, and said to king Jehoshaphat, Shouldest thou help the ungodly, and love them that hate the LORD? therefore is wrath upon thee from before the LORD.
11580	386	3	Nevertheless there are good things found in thee, in that thou hast taken away the groves out of the land, and hast prepared thine heart to seek God.
11581	386	4	And Jehoshaphat dwelt at Jerusalem: and he went out again through the people from Beer-sheba to mount Ephraim, and brought them back unto the LORD God of their fathers.
11582	386	5	And he set judges in the land throughout all the fenced cities of Judah, city by city,
11583	386	6	And said to the judges, Take heed what ye do: for ye judge not for man, but for the LORD, who is with you in the judgment.
11584	386	7	Wherefore now let the fear of the LORD be upon you; take heed and do it: for there is no iniquity with the LORD our God, nor respect of persons, nor taking of gifts.
11585	386	8	Moreover in Jerusalem did Jehoshaphat set of the Levites, and of the priests, and of the chief of the fathers of Israel, for the judgment of the LORD, and for controversies, when they returned to Jerusalem.
11586	386	9	And he charged them, saying, Thus shall ye do in the fear of the LORD, faithfully, and with a perfect heart.
11587	386	10	And what cause soever shall come to you of your brethren that dwell in their cities, between blood and blood, between law and commandment, statutes and judgments, ye shall even warn them that they trespass not against the LORD, and so wrath come upon you, and upon your brethren: this do, and ye shall not trespass.
11588	386	11	And, behold, Amariah the chief priest is over you in all matters of the LORD; and Zebadiah the son of Ishmael, the ruler of the house of Judah, for all the king's matters: also the Levites shall be officers before you. Deal courageously, and the LORD shall be with the good.
11589	387	1	IT came to pass after this also, that the children of Moab, and the children of Ammon, and with them other beside the Ammonites, came against Jehoshaphat to battle.
11590	387	2	Then there came some that told Jehoshaphat, saying, There cometh a great multitude against thee from beyond the sea on this side Syria; and, behold, they be in Hazazon-tamar, which is En-gedi.
11591	387	3	And Jehoshaphat feared, and set himself to seek the LORD, and proclaimed a fast throughout all Judah.
11592	387	4	And Judah gathered themselves together, to ask help of the LORD: even out of all the cities of Judah they came to seek the LORD.
11593	387	5	And Jehoshaphat stood in the congregation of Judah and Jerusalem, in the house of the LORD, before the new court,
11594	387	6	And said, O LORD God of our fathers, art not thou God in heaven? and rulest not thou over all the kingdoms of the heathen? and in thine hand is there not power and might, so that none is able to withstand thee?
11595	387	7	Art not thou our God, who didst drive out the inhabitants of this land before thy people Israel, and gavest it to the seed of Abraham thy friend for ever?
11596	387	8	And they dwelt therein, and have built thee a sanctuary therein for thy name, saying,
11597	387	9	If, when evil cometh upon us, as the sword, judgment, or pestilence, or famine, we stand before this house, and in thy presence, (for thy name is in this house,) and cry unto thee in our affliction, then thou wilt hear and help.
11598	387	10	And now, behold, the children of Ammon and Moab and mount Seir, whom thou wouldest not let Israel invade, when they came out of the land of Egypt, but they turned from them, and destroyed them not;
11599	387	11	Behold, I say, how they reward us, to come to cast us out of thy possession, which thou hast given us to inherit.
11600	387	12	O our God, wilt thou not judge them? for we have no might against this great company that cometh against us; neither know we what to do: but our eyes are upon thee.
11601	387	13	And all Judah stood before the LORD, with their little ones, their wives, and their children.
11602	387	14	Then upon Jahaziel the son of Zechariah, the son of Benaiah, the son of Jeiel, the son of Mattaniah, a Levite of the sons of Asaph, came the Spirit of the LORD in the midst of the congregation;
11603	387	15	And he said, Hearken ye, all Judah, and ye inhabitants of Jerusalem, and thou king Jehoshaphat, Thus saith the LORD unto you, Be not afraid nor dismayed by reason of this great multitude; for the battle is not yours, but God's.
11604	387	16	To morrow go ye down against them: behold, they come up by the cliff of Ziz; and ye shall find them at the end of the brook, before the wilderness of Jeruel.
11605	387	17	Ye shall not need to fight in this battle: set yourselves, stand ye still, and see the salvation of the LORD with you, O Judah and Jerusalem: fear not, nor be dismayed; to morrow go out against them: for the LORD will be with you.
11606	387	18	And Jehoshaphat bowed his head with his face to the ground: and all Judah and the inhabitants of Jerusalem fell before the LORD, worshipping the LORD.
11607	387	19	And the Levites, of the children of the Kohathites, and of the children of the Korhites, stood up to praise the LORD God of Israel with a loud voice on high.
11608	387	20	And they rose early in the morning, and went forth into the wilderness of Tekoa: and as they went forth, Jehoshaphat stood and said, Hear me, O Judah, and ye inhabitants of Jerusalem; Believe in the LORD your God, so shall ye be established; believe his prophets, so shall ye prosper.
11609	387	21	And when he had consulted with the people, he appointed singers unto the LORD, and that should praise the beauty of holiness, as they went out before the army, and to say, Praise the LORD; for his mercy endureth for ever.
11610	387	22	And when they began to sing and to praise, the LORD set ambushments against the children of Ammon, Moab, and mount Seir, which were come against Judah; and they were smitten.
11611	387	23	For the children of Ammon and Moab stood up against the inhabitants of mount Seir, utterly to slay and destroy them: and when they had made an end of the inhabitants of Seir, every one helped to destroy another.
11612	387	24	And when Judah came toward the watch tower in the wilderness, they looked unto the multitude, and, behold, they were dead bodies fallen to the earth, and none escaped.
11613	387	25	And when Jehoshaphat and his people came to take away the spoil of them, they found among them in abundance both riches with the dead bodies, and precious jewels, which they stripped off for themselves, more than they could carry away: and they were three days in gathering of the spoil, it was so much.
11614	387	26	And on the fourth day they assembled themselves in the valley of Berachah; for there they blessed the LORD: therefore the name of the same place was called, The valley of Berachah, unto this day.
11615	387	27	Then they returned, every man of Judah and Jerusalem, and Jehoshaphat in the forefront of them, to go again to Jerusalem with joy; for the LORD had made them to rejoice over their enemies.
11616	387	28	And they came to Jerusalem with psalteries and harps and trumpets unto the house of the LORD.
11617	387	29	And the fear of God was on all the kingdoms of those countries, when they had heard that the LORD fought against the enemies of Israel.
11618	387	30	So the realm of Jehoshaphat was quiet: for his God gave him rest round about.
11619	387	31	And Jehoshaphat reigned over Judah: he was thirty and five years old when he began to reign, and he reigned twenty and five years in Jerusalem. And his mother's name was Azubah the daughter of Shilhi.
11620	387	32	And he walked in the way of Asa his father, and departed not from it, doing that which was right in the sight of the LORD.
11621	387	33	Howbeit the high places were not taken away: for as yet the people had not prepared their hearts unto the God of their fathers.
11622	387	34	Now the rest of the acts of Jehoshaphat, first and last, behold, they are written in the book of Jehu the son of Hanani, who is mentioned in the book of the kings of Israel.
11623	387	35	And after this did Jehoshaphat king of Judah join himself with Ahaziah king of Israel, who did very wickedly:
11624	387	36	And he joined himself with him to make ships to go to Tarshish: and they made the ships in Ezion-geber.
11625	387	37	Then Eliezer the son of Dodavah of Mareshah prophesied against Jehoshaphat, saying, Because thou hast joined thyself with Ahaziah, the LORD hath broken thy works. And the ships were broken, that they were not able to go to Tarshish.
11626	388	1	NOW Jehoshaphat slept with his fathers, and was buried with his fathers in the city of David. And Jehoram his son reigned in his stead.
11627	388	2	And he had brethren the sons of Jehoshaphat, Azariah, and Jehiel, and Zechariah, and Azariah, and Michael, and Shephatiah: all these were the sons of Jehoshaphat king of Israel.
11628	388	3	And their father gave them great gifts of silver, and of gold, and of precious things, with fenced cities in Judah: but the kingdom gave he to Jehoram; because he was the firstborn.
11629	388	4	Now when Jehoram was risen up to the kingdom of his father, he strengthened himself, and slew all his brethren with the sword, and divers also of the princes of Israel.
11630	388	5	Jehoram was thirty and two years old when he began to reign, and he reigned eight years in Jerusalem.
11631	388	6	And he walked in the way of the kings of Israel, like as did the house of Ahab: for he had the daughter of Ahab to wife: and he wrought that which was evil in the eyes of the LORD.
11632	388	7	Howbeit the LORD would not destroy the house of David, because of the covenant that he had made with David, and as he promised to give a light to him and to his sons for ever.
11633	388	8	In his days the Edomites revolted from under the dominion of Judah, and made themselves a king.
11634	388	9	Then Jehoram went forth with his princes, and all his chariots with him: and he rose up by night, and smote the Edomites which compassed him in, and the captains of the chariots.
11635	388	10	So the Edomites revolted from under the hand of Judah unto this day. The same time also did Libnah revolt from under his hand; because he had forsaken the LORD God of his fathers.
11636	388	11	Moreover he made high places in the mountains of Judah, and caused the inhabitants of Jerusalem to commit fornication, and compelled Judah thereto.
11637	388	12	And there came a writing to him from Elijah the prophet, saying, Thus saith the LORD God of David thy father, Because thou hast not walked in the ways of Jehoshaphat thy father, nor in the ways of Asa king of Judah,
11638	388	13	But hast walked in the way of the kings of Israel, and hast made Judah and the inhabitants of Jerusalem to go a whoring, like to the whoredoms of the house of Ahab, and also hast slain thy brethren of thy father's house, which were better than thyself:
11639	388	14	Behold, with a great plague will the LORD smite thy people, and thy children, and thy wives, and all thy goods:
11640	388	15	And thou shalt have great sickness by disease of thy bowels, until thy bowels fall out by reason of the sickness day by day.
11641	388	16	Moreover the LORD stirred up against Jehoram the spirit of the Philistines, and of the Arabians, that were near the Ethiopians:
11642	388	17	And they came up into Judah, and brake into it, and carried away all the substance that was found in the king's house, and his sons also, and his wives; so that there was never a son left him, save Jehoahaz, the youngest of his sons.
11643	388	18	And after all this the LORD smote him in his bowels with an incurable disease.
11644	388	19	And it came to pass, that in process of time, after the end of two years, his bowels fell out by reason of his sickness: so he died of sore diseases. And his people made no burning for him, like the burning of his fathers.
11645	388	20	Thirty and two years old was he when he began to reign, and he reigned in Jerusalem eight years, and departed without being desired. Howbeit they buried him in the city of David, but not in the sepulchres of the kings.
11646	389	1	AND the inhabitants of Jerusalem made Ahaziah his youngest son king in his stead: for the band of men that came with the Arabians to the camp had slain all the eldest. So Ahaziah the son of Jehoram king of Judah reigned.
11647	389	2	Forty and two years old was Ahaziah when he began to reign, and he reigned one year in Jerusalem. His mother's name also was Athaliah the daughter of Omri.
11648	389	3	He also walked in the ways of the house of Ahab: for his mother was his counsellor to do wickedly.
11649	389	4	Wherefore he did evil in the sight of the LORD like the house of Ahab: for they were his counsellors after the death of his father to his destruction.
11650	389	5	He walked also after their counsel, and went with Jehoram the son of Ahab king of Israel to war against Hazael king of Syria at Ramoth-gilead: and the Syrians smote Joram.
11651	389	6	And he returned to be healed in Jezreel because of the wounds which were given him at Ramah, when he fought with Hazael king of Syria. And Azariah the son of Jehoram king of Judah went down to see Jehoram the son of Ahab at Jezreel, because he was sick.
11652	389	7	And the destruction of Ahaziah was of God by coming to Joram: for when he was come, he went out with Jehoram against Jehu the son of Nimshi, whom the LORD had anointed to cut off the house of Ahab.
11653	389	8	And it came to pass, that, when Jehu was executing judgment upon the house of Ahab, and found the princes of Judah, and the sons of the brethren of Ahaziah, that ministered to Ahaziah, he slew them.
11654	389	9	And he sought Ahaziah: and they caught him, (for he was hid in Samaria,) and brought him to Jehu: and when they had slain him, they buried him: Because, said they, he is the son of Jehoshaphat, who sought the LORD with all his heart. So the house of Ahaziah had no power to keep still the kingdom.
11655	389	10	But when Athaliah the mother of Ahaziah saw that her son was dead, she arose and destroyed all the seed royal of the house of Judah.
11656	389	11	But Jehoshabeath, the daughter of the king, took Joash the son of Ahaziah, and stole him from among the king's sons that were slain, and put him and his nurse in a bedchamber. So Jehoshabeath, the daughter of king Jehoram, the wife of Jehoiada the priest, (for she was the sister of Ahaziah,) hid him from Athaliah, so that she slew him not.
11657	389	12	And he was with them hid in the house of God six years: and Athaliah reigned over the land.
11658	390	1	AND in the seventh year Jehoiada strengthened himself, and took the captains of hundreds, Azariah the son of Jeroham, and Ishmael the son of Jehohanan, and Azariah the son of Obed, and Maaseiah the son of Adaiah, and Elishaphat the son of Zichri, into covenant with him.
11659	390	2	And they went about in Judah, and gathered the Levites out of all the cities of Judah, and the chief of the fathers of Israel, and they came to Jerusalem.
11660	390	3	And all the congregation made a covenant with the king in the house of God. And he said unto them, Behold, the king's son shall reign, as the LORD hath said of the sons of David.
11661	390	4	This is the thing that ye shall do; A third part of you entering on the sabbath, of the priests and of the Levites, shall be porters of the doors;
11662	390	5	And a third part shall be at the king's house; and a third part at the gate of the foundation: and all the people shall be in the courts of the house of the LORD.
11663	390	6	But let none come into the house of the LORD, save the priests, and they that minister of the Levites; they shall go in, for they are holy: but all the people shall keep the watch of the LORD.
11664	390	7	And the Levites shall compass the king round about, every man with his weapons in his hand; and whosoever else cometh into the house, he shall be put to death: but be ye with the king when he cometh in, and when he goeth out.
11665	390	8	So the Levites and all Judah did according to all things that Jehoiada the priest had commanded, and took every man his men that were to come in on the sabbath, with them that were to go out on the sabbath: for Jehoiada the priest dismissed not the courses.
11666	390	9	Moreover Jehoiada the priest delivered to the captains of hundreds spears, and bucklers, and shields, that had been king David's, which were in the house of God.
11667	390	10	And he set all the people, every man having his weapon in his hand, from the right side of the temple to the left side of the temple, along by the altar and the temple, by the king round about.
11668	390	11	Then they brought out the king's son, and put upon him the crown, and gave him the testimony, and made him king. And Jehoiada and his sons anointed him, and said, God save the king.
11669	390	12	Now when Athaliah heard the noise of the people running and praising the king, she came to the people into the house of the LORD:
11670	390	13	And she looked, and, behold, the king stood at his pillar at the entering in, and the princes and the trumpets by the king: and all the people of the land rejoiced, and sounded with trumpets, also the singers with instruments of musick, and such as taught to sing praise. Then Athaliah rent her clothes, and said, Treason, Treason.
11671	390	14	Then Jehoiada the priest brought out the captains of hundreds that were set over the host, and said unto them, Have her forth of the ranges: and whoso followeth her, let him be slain with the sword. For the priest said, Slay her not in the house of the LORD.
11672	390	15	So they laid hands on her; and when she was come to the entering of the horse gate by the king's house, they slew her there.
11673	390	16	And Jehoiada made a covenant between him, and between all the people, and between the king, that they should be the LORD's people.
11674	390	17	Then all the people went to the house of Baal, and brake it down, and brake his altars and his images in pieces, and slew Mattan the priest of Baal before the altars.
11675	390	18	Also Jehoiada appointed the offices of the house of the LORD by the hand of the priests the Levites, whom David had distributed in the house of the LORD, to offer the burnt offerings of the LORD, as it is written in the law of Moses, with rejoicing and with singing, as it was ordained by David.
11676	390	19	And he set the porters at the gates of the house of the LORD, that none which was unclean in any thing should enter in.
11677	390	20	And he took the captains of hundreds, and the nobles, and the governors of the people, and all the people of the land, and brought down the king from the house of the LORD: and they came through the high gate into the king's house, and set the king upon the throne of the kingdom.
11678	390	21	And all the people of the land rejoiced: and the city was quiet, after that they had slain Athaliah with the sword.
11679	391	1	JOASH was seven years old when he began to reign, and he reigned forty years in Jerusalem. His mother's name also was Zibiah of Beer-sheba.
11680	391	2	And Joash did that which was right in the sight of the LORD all the days of Jehoiada the priest.
11681	391	3	And Jehoiada took for him two wives; and he begat sons and daughters.
11682	391	4	And it came to pass after this, that Joash was minded to repair the house of the LORD.
11683	391	5	And he gathered together the priests and the Levites, and said to them, Go out unto the cities of Judah, and gather of all Israel money to repair the house of your God from year to year, and see that ye hasten the matter. Howbeit the Levites hastened it not.
11684	391	6	And the king called for Jehoiada the chief, and said unto him, Why hast thou not required of the Levites to bring in out of Judah and out of Jerusalem the collection, according to the commandment of Moses the servant of the LORD, and of the congregation of Israel, for the tabernacle of witness?
11685	391	7	For the sons of Athaliah, that wicked woman, had broken up the house of God; and also all the dedicated things of the house of the LORD did they bestow upon Baalim.
11686	391	8	And at the king's commandment they made a chest, and set it without at the gate of the house of the LORD.
11687	391	9	And they made a proclamation through Judah and Jerusalem, to bring in to the LORD the collection that Moses the servant of God laid upon Israel in the wilderness.
11688	391	10	And all the princes and all the people rejoiced, and brought in, and cast into the chest, until they had made an end.
11689	391	11	Now it came to pass, that at what time the chest was brought unto the king's office by the hand of the Levites, and when they saw that there was much money, the king's scribe and the high priest's officer came and emptied the chest, and took it, and carried it to his place again. Thus they did day by day, and gathered money in abundance.
11690	391	12	And the king and Jehoiada gave it to such as did the work of the service of the house of the LORD, and hired masons and carpenters to repair the house of the LORD, and also such as wrought iron and brass to mend the house of the LORD.
11691	391	13	So the workmen wrought, and the work was perfected by them, and they set the house of God in his state, and strengthened it.
11692	391	14	And when they had finished it, they brought the rest of the money before the king and Jehoiada, whereof were made vessels for the house of the LORD, even vessels to minister, and to offer withal, and spoons, and vessels of gold and silver. And they offered burnt offerings in the house of the LORD continually all the days of Jehoiada.
11693	391	15	But Jehoiada waxed old, and was full of days when he died; an hundred and thirty years old was he when he died.
11694	391	16	And they buried him in the city of David among the kings, because he had done good in Israel, both toward God, and toward his house.
11695	391	17	Now after the death of Jehoiada came the princes of Judah, and made obeisance to the king. Then the king hearkened unto them.
11696	391	18	And they left the house of the LORD God of their fathers, and served groves and idols: and wrath came upon Judah and Jerusalem for this their trespass.
11697	391	19	Yet he sent prophets to them, to bring them again unto the LORD; and they testified against them: but they would not give ear.
11698	391	20	And the Spirit of God came upon Zechariah the son of Jehoiada the priest, which stood above the people, and said unto them, Thus saith God, Why transgress ye the commandments of the LORD, that ye cannot prosper? because ye have forsaken the LORD, he hath also forsaken you.
11699	391	21	And they conspired against him, and stoned him with stones at the commandment of the king in the court of the house of the LORD.
11700	391	22	Thus Joash the king remembered not the kindness which Jehoiada his father had done to him, but slew his son. And when he died, he said, The LORD look upon it, and require it.
11701	391	23	And it came to pass at the end of the year, that the host of Syria came up against him: and they came to Judah and Jerusalem, and destroyed all the princes of the people from among the people, and sent all the spoil of them unto the king of Damascus.
11702	391	24	For the army of the Syrians came with a small company of men, and the LORD delivered a very great host into their hand, because they had forsaken the LORD God of their fathers. So they executed judgment against Joash.
11703	391	25	And when they were departed from him, (for they left him in great diseases,) his own servants conspired against him for the blood of the sons of Jehoiada the priest, and slew him on his bed, and he died: and they buried him in the city of David, but they buried him not in the sepulchres of the kings.
11704	391	26	And these are they that conspired against him; Zabad the son of Shimeath an Ammonitess, and Jehozabad the son of Shimrith a Moabitess.
11705	391	27	Now concerning his sons, and the greatness of the burdens laid upon him, and the repairing of the house of God, behold, they are written in the story of the book of the kings. And Amaziah his son reigned in his stead.
11706	392	1	AMAZIAH was twenty and five years old when he began to reign, and he reigned twenty and nine years in Jerusalem. And his mother's name was Jehoaddan of Jerusalem.
11707	392	2	And he did that which was right in the sight of the LORD, but not with a perfect heart.
11708	392	3	Now it came to pass, when the kingdom was established to him, that he slew his servants that had killed the king his father.
11709	392	4	But he slew not their children, but did as it is written in the law in the book of Moses, where the LORD commanded, saying, The fathers shall not die for the children, neither shall the children die for the fathers, but every man shall die for his own sin.
11710	392	5	Moreover Amaziah gathered Judah together, and made them captains over thousands, and captains over hundreds, according to the houses of their fathers, throughout all Judah and Benjamin: and he numbered them from twenty years old and above, and found them three hundred thousand choice men, able to go forth to war, that could handle spear and shield.
11711	392	6	He hired also an hundred thousand mighty men of valour out of Israel for an hundred talents of silver.
11712	392	7	But there came a man of God to him, saying, O king, let not the army of Israel go with thee; for the LORD is not with Israel, to wit, with all the children of Ephraim.
11713	392	8	But if thou wilt go, do it, be strong for the battle: God shall make thee fall before the enemy: for God hath power to help, and to cast down.
11714	392	9	And Amaziah said to the man of God, But what shall we do for the hundred talents which I have given to the army of Israel? And the man of God answered, The LORD is able to give thee much more than this.
11715	392	10	Then Amaziah separated them, to wit, the army that was come to him out of Ephraim, to go home again: wherefore their anger was greatly kindled against Judah, and they returned home in great anger.
11716	392	11	And Amaziah strengthened himself, and led forth his people, and went to the valley of salt, and smote of the chidren of Seir ten thousand.
11717	392	12	And other ten thousand left alive did the children of Judah carry away captive, and brought them unto the top of the rock, and cast them down from the top of the rock, that they all were broken in pieces.
11718	392	13	But the soldiers of the army which Amaziah sent back, that they should not go with him to battle, fell upon the cities of Judah, from Samaria even unto Beth-horon, and smote three thousand of them, and took much spoil.
11719	392	14	Now it came to pass, after that Amaziah was come from the slaughter of the Edomites, that he brought the gods of the children of Seir, and set them up to be his gods, and bowed down himself before them, and burned incense unto them.
11720	392	15	Wherefore the anger of the LORD was kindled against Amaziah, and he sent unto him a prophet, which said unto him, Why hast thou sought after the gods of the people, which could not deliver their own people out of thine hand?
11721	392	16	And it came to pass, as he talked with him, that the king said unto him, Art thou made of the king's counsel? forbear; why shouldest thou be smitten? Then the prophet forbare, and said, I know that God hath determined to destroy thee, because thou hast done this, and hast not hearkened unto my counsel.
11722	392	17	Then Amaziah king of Judah took advice, and sent to Joash, the son of Jehoahaz, the son of Jehu, king of Israel, saying, Come, let us see one another in the face.
11723	392	18	And Joash king of Israel sent to Amaziah king of Judah, saying, The thistle that was in Lebanon sent to the cedar that was in Lebanon, saying, Give thy daughter to my son to wife: and there passed by a wild beast that was in Lebanon, and trode down the thistle.
11724	392	19	Thou sayest, Lo, thou hast smitten the Edomites; and thine heart lifteth thee up to boast: abide now at home; why shouldest thou meddle to thine hurt, that thou shouldest fall, even thou, and Judah with thee?
11725	392	20	But Amaziah would not hear; for it came of God, that he might deliver them into the hand of their enemies, because they sought after the gods of Edom.
11726	392	21	So Joash the king of Israel went up; and they saw one another in the face, both he and Amaziah king of Judah, at Beth-shemesh, which belongeth to Judah.
11727	392	22	And Judah was put to the worse before Israel, and they fled every man to his tent.
11728	392	23	And Joash the king of Israel took Amaziah king of Judah, the son of Joash, the son of Jehoahaz, at Beth-shemesh, and brought him to Jerusalem, and brake down the wall of Jerusalem from the gate of Ephraim to the corner gate, four hundred cubits.
11729	392	24	And he took all the gold and the silver, and all the vessels that were found in the house of God with Obed-edom, and the treasures of the king's house, the hostages also, and returned to Samaria.
11730	392	25	And Amaziah the son of Joash king of Judah lived after the death of Joash son of Jehoahaz king of Israel fifteen years.
11731	392	26	Now the rest of the acts of Amaziah, first and last, behold, are they not written in the book of the kings of Judah and Israel?
11732	392	27	Now after the time that Amaziah did turn away from following the LORD they made a conspiracy against him in Jerusalem; and he fled to Lachish: but they sent to Lachish after him, and slew him there.
11733	392	28	And they brought him upon horses, and buried him with his fathers in the city of Judah.
11734	393	1	THEN all the people of Judah took Uzziah, who was sixteen years old, and made him king in the room of his father Amaziah.
11735	393	2	He built Eloth, and restored it to Judah, after that the king slept with his fathers.
11736	393	3	Sixteen years old was Uzziah when he began to reign, and he reigned fifty and two years in Jerusalem. His mother's name also was Jecoliah of Jerusalem.
11737	393	4	And he did that which was right in the sight of the LORD, according to all that his father Amaziah did.
11738	393	5	And he sought God in the days of Zechariah, who had understanding in the visions of God: and as long as he sought the LORD, God made him to prosper.
11739	393	6	And he went forth and warred against the Philistines, and brake down the wall of Gath, and the wall of Jabneh, and the wall of Ashdod, and built cities about Ashdod, and among the Philistines.
11740	393	7	And God helped him against the Philistines, and against the Arabians that dwelt in Gur-baal, and the Mehunims.
11741	393	8	And the Ammonites gave gifts to Uzziah: and his name spread abroad even to the entering in of Egypt; for he strengthened himself exceedingly.
11742	393	9	Moreover Uzziah built towers in Jerusalem at the corner gate, and at the valley gate, and at the turning of the wall, and fortified them.
11743	393	10	Also he built towers in the desert, and digged many wells: for he had much cattle, both in the low country, and in the plains: husbandmen also, and vine dressers in the mountains, and in Carmel: for he loved husbandry.
11744	393	11	Moreover Uzziah had an host of fighting men, that went out to war by bands, according to the number of their account by the hand of Jeiel the scribe and Maaseiah the ruler, under the hand of Hananiah, one of the king's captains.
11745	393	12	The whole number of the chief of the fathers of the mighty men of valour were two thousand and six hundred.
11746	393	13	And under their hand was an army, three hundred thousand and seven thousand and five hundred, that made war with mighty power, to help the king against the enemy.
11747	393	14	And Uzziah prepared for them throughout all the host shields, and spears, and helmets, and habergeons, and bows, and slings to cast stones.
11748	393	15	And he made in Jerusalem engines, invented by cunning men, to be on the towers and upon the bulwarks, to shoot arrows and great stones withal. And his name spread far abroad; for he was marvellously helped, till he was strong.
11749	393	16	But when he was strong, his heart was lifted up to his destruction: for he transgressed against the LORD his God, and went into the temple of the LORD to burn incense upon the altar of incense.
11750	393	17	And Azariah the priest went in after him, and with him fourscore priests of the LORD, that were valiant men:
11751	393	18	And they withstood Uzziah the king, and said unto him, It appertaineth not unto thee, Uzziah, to burn incense unto the LORD, but to the priests the sons of Aaron, that are consecrated to burn incense: go out of the sanctuary; for thou hast trespassed; neither shall it be for thine honour from the LORD God.
11752	393	19	Then Uzziah was wroth, and had a censer in his hand to burn incense: and while he was wroth with the priests, the leprosy even rose up in his forehead before the priests in the house of the LORD, from beside the incense altar.
11753	393	20	And Azariah the chief priest, and all the priests, looked upon him, and, behold, he was leprous in his forehead, and they thrust him out from thence; yea, himself hasted also to go out, because the LORD had smitten him.
11754	393	21	And Uzziah the king was a leper unto the day of his death, and dwelt in a several house, being a leper; for he was cut off from the house of the LORD: and Jotham his son was over the king's house, judging the people of the land.
11755	393	22	Now the rest of the acts of Uzziah, first and last, did Isaiah the prophet, the son of Amoz, write.
11756	393	23	So Uzziah slept with his fathers, and they buried him with his fathers in the field of the burial which belonged to the kings; for they said, He is a leper: and Jotham his son reigned in his stead.
11757	394	1	JOTHAM was twenty and five years old when he began to reign, and he reigned sixteen years in Jerusalem. His mother's name also was Jerushah, the daughter of Zadok.
11758	394	2	And he did that which was right in the sight of the LORD, according to all that his father Uzziah did: howbeit he entered not into the temple of the LORD. And the people did yet corruptly.
11759	394	3	He built the high gate of the house of the LORD, and on the wall of Ophel he built much.
11760	394	4	Moreover he built cities in the mountains of Judah, and in the forests he built castles and towers.
11761	394	5	He fought also with the king of the Ammonites, and prevailed against them. And the children of Ammon gave him the same year an hundred talents of silver, and ten thousand measures of wheat, and ten thousand of barley. So much did the children of Ammon pay unto him, both the second year, and the third.
11762	394	6	So Jotham became mighty, because he prepared his ways before the LORD his God.
11763	394	7	Now the rest of the acts of Jotham, and all his wars, and his ways, lo, they are written in the book of the kings of Israel and Judah.
11764	394	8	He was five and twenty years old when he began to reign, and reigned sixteen years in Jerusalem.
11765	394	9	And Jotham slept with his fathers, and they buried him in the city of David: and Ahaz his son reigned in his stead.
11766	395	1	AHAZ was twenty years old when he began to reign, and he reigned sixteen years in Jerusalem: but he did not that which was right in the sight of the LORD, like David his father:
11767	395	2	For he walked in the ways of the kings of Israel, and made also molten images for Baalim.
11768	395	3	Moreover he burnt incense in the valley of the son of Hinnom, and burnt his children in the fire, after the abominations of the heathen whom the LORD had cast out before the children of Israel.
11769	395	4	He sacrificed also and burnt incense in the high places, and on the hills, and under every green tree.
11770	395	5	Wherefore the LORD his God delivered him into the hand of the king of Syria; and they smote him, and carried away a great multitude of them captives, and brought them to Damascus. And he was also delivered into the hand of the king of Israel, who smote him with a great slaughter.
11771	395	6	For Pekah the son of Remaliah slew in Judah an hundred and twenty thousand in one day, which were all valiant men; because they had forsaken the LORD God of their fathers.
11772	395	7	And Zichri, a mighty man of Ephraim, slew Maaseiah the king's son, and Azrikam the governor of the house, and Elkanah that was next to the king.
11773	395	8	And the children of Israel carried away captive of their brethren two hundred thousand, women, sons, and daughters, and took also away much spoil from them, and brought the spoil to Samaria.
11774	395	9	But a prophet of the LORD was there, whose name was Oded: and he went out before the host that came to Samaria, and said unto them, Behold, because the LORD God of your fathers was wroth with Judah, he hath delivered them into your hand, and ye have slain them in a rage that reacheth up unto heaven.
11775	395	10	And now ye purpose to keep under the children of Judah and Jerusalem for bondmen and bondwomen unto you: but are there not with you, even with you, sins against the LORD your God?
11776	395	11	Now hear me therefore, and deliver the captives again, which ye have taken captive of your brethren: for the fierce wrath of the LORD is upon you.
11777	395	12	Then certain of the heads of the children of Ephraim, Azariah the son of Johanan, Berechiah the son of Meshillemoth, and Jehizkiah the son of Shallum, and Amasa the son of Hadlai, stood up against them that came from the war,
11778	395	13	And said unto them, Ye shall not bring in the captives hither: for whereas we have offended against the LORD already, ye intend to add more to our sins and to our trespass: for our trespass is great, and there is fierce wrath against Israel.
11779	395	14	So the armed men left the captives and the spoil before the princes and all the congregation.
11780	395	15	And the men which were expressed by name rose up, and took the captives, and with the spoil clothed all that were naked among them, and arrayed them, and shod them, and gave them to eat and to drink, and anointed them, and carried all the feeble of them upon asses, and brought them to Jericho, the city of palm trees, to their brethren: then they returned to Samaria.
11781	395	16	At that time did king Ahaz send unto the kings of Assyria to help him.
11782	395	17	For again the Edomites had come and smitten Judah, and carried away captives.
11783	395	18	The Philistines also had invaded the cities of the low country, and of the south of Judah, and had taken Beth-shemesh, and Ajalon, and Gederoth, and Shocho with the villages thereof, and Timnah with the villages thereof, Gimzo also and the villages thereof: and they dwelt there.
11784	395	19	For the LORD brought Judah low because of Ahaz king of Israel; for he made Judah naked, and transgressed sore against the LORD.
11785	395	20	And Tilgath-pilneser king of Assyria came unto him, and distressed him, but strengthened him not.
11786	395	21	For Ahaz took away a portion out of the house of the LORD, and out of the house of the king, and of the princes, and gave it unto the king of Assyria: but he helped him not.
11787	395	22	And in the time of his distress did he trespass yet more against the LORD: this is that king Ahaz.
11788	395	23	For he sacrificed unto the gods of Damascus, which smote him: and he said, Because the gods of the kings of Syria help them, therefore will I sacrifice to them, that they may help me. But they were the ruin of him, and of all Israel.
11789	395	24	And Ahaz gathered together the vessels of the house of God, and cut in pieces the vessels of the house of God, and shut up the doors of the house of the LORD, and he made him altars in every corner of Jerusalem.
11790	395	25	And in every several city of Judah he made high places to burn incense unto other gods, and provoked to anger the LORD God of his fathers.
11791	395	26	Now the rest of his acts and of all his ways, first and last, behold, they are written in the book of the kings of Judah and Israel.
11792	395	27	And Ahaz slept with his fathers, and they buried him in the city, even in Jerusalem: but they brought him not into the sepulchres of the kings of Israel: and Hezekiah his son reigned in his stead.
11793	396	1	HEZEKIAH began to reign when he was five and twenty years old, and he reigned nine and twenty years in Jerusalem. And his mother's name was Abijah, the daughter of Zechariah.
11794	396	2	And he did that which was right in the sight of the LORD, according to all that David his father had done.
11795	396	3	He in the first year of his reign, in the first month, opened the doors of the house of the LORD, and repaired them.
11796	396	4	And he brought in the priests and the Levites, and gathered them together into the east street,
11797	396	5	And said unto them, Hear me, ye Levites, sanctify now yourselves, and sanctify the house of the LORD God of your fathers, and carry forth the filthiness out of the holy place.
11798	396	6	For our fathers have trespassed, and done that which was evil in the eyes of the LORD our God, and have forsaken him, and have turned away their faces from the habitation of the LORD, and turned their backs.
11799	396	7	Also they have shut up the doors of the porch, and put out the lamps, and have not burned incense nor offered burnt offerings in the holy place unto the God of Israel.
11800	396	8	Wherefore the wrath of the LORD was upon Judah and Jerusalem, and he hath delivered them to trouble, to astonishment, and to hissing, as ye see with your eyes.
11801	396	9	For, lo, our fathers have fallen by the sword, and our sons and our daughters and our wives are in captivity for this.
11802	396	10	Now it is in mine heart to make a covenant with the LORD God of Israel, that his fierce wrath may turn away from us.
11803	396	11	My sons, be not now negligent: for the LORD hath chosen you to stand before him, to serve him, and that ye should minister unto him, and burn incense.
11804	396	12	Then the Levites arose, Mahath the son of Amasai, and Joel the son of Azariah, of the sons of the Kohathites: and of the sons of Merari, Kish the son of Abdi, and Azariah the son of Jehalelel: and of the Gershonites; Joah the son of Zimmah, and Eden the son of Joah:
11805	396	13	And of the sons of Elizaphan; Shimri, and Jeiel: and of the sons of Asaph; Zechariah, and Mattaniah:
11806	396	14	And of the sons of Heman; Jehiel, and Shimei: and of the sons of Jeduthun; Shemaiah, and Uzziel.
11807	396	15	And they gathered their brethren, and sanctified themselves, and came, according to the commandment of the king, by the words of the LORD, to cleanse the house of the LORD.
11808	396	16	And the priests went into the inner part of the house of the LORD, to cleanse it, and brought out all the uncleanness that they found in the temple of the LORD into the court of the house of the LORD. And the Levites took it, to carry it out abroad into the brook Kidron.
11809	396	17	Now they began on the first day of the first month to sanctify, and on the eighth day of the month came they to the porch of the LORD: so they sanctified the house of the LORD in eight days; and in the sixteenth day of the first month they made an end.
11810	396	18	Then they went in to Hezekiah the king, and said, We have cleansed all the house of the LORD, and the altar of burnt offering, with all the vessels thereof, and the shewbread table, with all the vessels thereof.
11811	396	19	Moreover all the vessels, which king Ahaz in his reign did cast away in his transgression, have we prepared and sanctified, and, behold, they are before the altar of the LORD.
11812	396	20	Then Hezekiah the king rose early, and gathered the rulers of the city, and went up to the house of the LORD.
11813	396	21	And they brought seven bullocks, and seven rams, and seven lambs, and seven he goats, for a sin offering for the kingdom, and for the sanctuary, and for Judah. And he commanded the priests the sons of Aaron to offer them on the altar of the LORD.
11814	396	22	So they killed the bullocks, and the priests received the blood, and sprinkled it on the altar: likewise, when they had killed the rams, they sprinkled the blood upon the altar: they killed also the lambs, and they sprinkled the blood upon the altar.
11815	396	23	And they brought forth the he goats for the sin offering before the king and the congregation; and they laid their hands upon them:
11816	396	24	And the priests killed them, and they made reconciliation with their blood upon the altar, to make an atonement for all Israel: for the king commanded that the burnt offering and the sin offering should be made for all Israel.
11817	396	25	And he set the Levites in the house of the LORD with cymbals, with psalteries, and with harps, according to the commandment of David, and of Gad the king's seer, and Nathan the prophet: for so was the commandment of the LORD by his prophets.
11818	396	26	And the Levites stood with the instruments of David, and the priests with the trumpets.
11819	396	27	And Hezekiah commanded to offer the burnt offering upon the altar. And when the burnt offering began, the song of the LORD began also with the trumpets, and with the instruments ordained by David king of Israel.
11820	396	28	And all the congregation worshipped, and the singers sang, and the trumpeters sounded: and all this continued until the burnt offering was finished.
11821	396	29	And when they had made an end of offering, the king and all that were present with him bowed themselves, and worshipped.
11822	396	30	Moreover Hezekiah the king and the princes commanded the Levites to sing praise unto the LORD with the words of David, and of Asaph the seer. And they sang praises with gladness, and they bowed their heads and worshipped.
11823	396	31	Then Hezekiah answered and said, Now ye have consecrated yourselves unto the LORD, come near and bring sacrifices and thank offerings into the house of the LORD. And the congregation brought in sacrifices and thank offerings; and as many as were of a free heart burnt offerings.
11824	396	32	And the number of the burnt offerings, which the congregation brought, was threescore and ten bullocks, an hundred rams, and two hundred lambs: all these were for a burnt offering to the LORD.
11825	396	33	And the consecrated things were six hundred oxen and three thousand sheep.
11826	396	34	But the priests were too few, so that they could not flay all the burnt offerings: wherefore their brethren the Levites did help them, till the work was ended, and until the other priests had sanctified themselves: for the Levites were more upright in heart to sanctify themselves than the priests.
11827	396	35	And also the burnt offerings were in abundance, with the fat of the peace offerings, and the drink offerings for every burnt offering. So the service of the house of the LORD was set in order.
11828	396	36	And Hezekiah rejoiced, and all the people, that God had prepared the people: for the thing was done suddenly.
11829	397	1	AND Hezekiah sent to all Israel and Judah, and wrote letters also to Ephraim and Manasseh, that they should come to the house of the LORD at Jerusalem, to keep the passover unto the LORD God of Israel.
11830	397	2	For the king had taken counsel, and his princes, and all the congregation in Jerusalem, to keep the passover in the second month.
11831	397	3	For they could not keep it at that time, because the priests had not sanctified themselves sufficiently, neither had the people gathered themselves together to Jerusalem.
11832	397	4	And the thing pleased the king and all the congregation.
11833	397	5	So they established a decree to make proclamation throughout all Israel, from Beer-sheba even to Dan, that they should come to keep the passover unto the LORD God of Israel at Jerusalem: for they had not done it of a long time in such sort as it was written.
11834	397	6	So the posts went with the letters from the king and his princes throughout all Israel and Judah, and according to the commandment of the king, saying, Ye children of Israel, turn again unto the LORD God of Abraham, Isaac, and Israel, and he will return to the remnant of you, that are escaped out of the hand of the kings of Assyria.
11835	397	7	And be not ye like your fathers, and like your brethren, which trespassed against the LORD God of their fathers, who therefore gave them up to desolation, as ye see.
11836	397	8	Now be ye not stiffnecked, as your fathers were, but yield yourselves unto the LORD, and enter into his sanctuary, which he hath sanctified for ever: and serve the LORD your God, that the fierceness of his wrath may turn away from you.
11837	397	9	For if ye turn again unto the LORD, your brethren and your children shall find compassion before them that lead them captive, so that they shall come again into this land: for the LORD your God is gracious and merciful, and will not turn away his face from you, if ye return unto him.
11838	397	10	So the posts passed from city to city through the country of Ephraim and Manasseh even unto Zebulun: but they laughed them to scorn, and mocked them.
11839	397	11	Nevertheless divers of Asher and Manasseh and of Zebulun humbled themselves, and came to Jerusalem.
11840	397	12	Also in Judah the hand of God was to give them one heart to do the commandment of the king and of the princes, by the word of the LORD.
11841	397	13	And there assembled at Jerusalem much people to keep the feast of unleavened bread in the second month, a very great congregation.
11842	397	14	And they arose and took away the altars that were in Jerusalem, and all the altars for incense took they away, and cast them into the brook Kidron.
11843	397	15	Then they killed the passover on the fourteenth day of the second month: and the priests and the Levites were ashamed, and sanctified themselves, and brought in the burnt offerings into the house of the LORD.
11844	397	16	And they stood in their place after their manner, according to the law of Moses the man of God: the priests sprinkled the blood, which they received of the hand of the Levites.
11845	397	17	For there were many in the congregation that were not sanctified: therefore the Levites had the charge of the killing of the passovers for every one that was not clean, to sanctify them unto the LORD.
11846	397	18	For a multitude of the people, even many of Ephraim, and Manasseh, Issachar, and Zebulun, had not cleansed themselves, yet did they eat the passover otherwise than it was written. But Hezekiah prayed for them, saying, The good LORD pardon every one
11847	397	19	That prepareth his heart to seek God, the LORD God of his fathers, though he be not cleansed according to the purification of the sanctuary.
11848	397	20	And the LORD hearkened to Hezekiah, and healed the people.
11849	397	21	And the children of Israel that were present at Jerusalem kept the feast of unleavened bread seven days with great gladness: and the Levites and the priests praised the LORD day by day, singing with loud instruments unto the LORD.
11850	397	22	And Hezekiah spake comfortably unto all the Levites that taught the good knowledge of the LORD: and they did eat throughout the feast seven days, offering peace offerings, and making confession to the LORD God of their fathers.
11851	397	23	And the whole assembly took counsel to keep other seven days: and they kept other seven days with gladness.
11852	397	24	For Hezekiah king of Judah did give to the congregation a thousand bullocks and seven thousand sheep; and the princes gave to the congregation a thousand bullocks and ten thousand sheep: and a great number of priests sanctified themselves.
11853	397	25	And all the congregation of Judah, with the priests and the Levites, and all the congregation that came out of Israel, and the strangers that came out of the land of Israel, and that dwelt in Judah, rejoiced.
11854	397	26	So there was great joy in Jerusalem: for since the time of Solomon the son of David king of Israel there was not the like in Jerusalem.
11855	397	27	Then the priests the Levites arose and blessed the people: and their voice was heard, and their prayer came up to his holy dwelling place, even unto heaven.
11856	398	1	NOW when all this was finished, all Israel that were present went out to the cities of Judah, and brake the images in pieces, and cut down the groves, and threw down the high places and the altars out of all Judah and Benjamin, in Ephraim also and Manasseh, until they had utterly destroyed them all. Then all the children of Israel returned, every man to his possession, into their own cities.
11857	398	2	And Hezekiah appointed the courses of the priests and the Levites after their courses, every man according to his service, the priests and Levites for burnt offerings and for peace offerings, to minister, and to give thanks, and to praise in the gates of the tents of the LORD.
11858	398	3	He appointed also the king's portion of his substance for the burnt offerings, to wit, for the morning and evening burnt offerings, and the burnt offerings for the sabbaths, and for the new moons, and for the set feasts, as it is written in the law of the LORD.
11859	398	4	Moreover he commanded the people that dwelt in Jerusalem to give the portion of the priests and the Levites, that they might be encouraged in the law of the LORD.
11860	398	5	And as soon as the commandment came abroad, the children of Israel brought in abundance the firstfruits of corn, wine, and oil, and honey, and of all the increase of the fields; and the tithe of all things brought they in abundantly.
11861	398	6	And concerning the children of Israel and Judah, that dwelt in the cities of Judah, they also brought in the tithe of oxen and sheep, and the tithe of holy things which were consecrated unto the LORD their God, and laid them by heaps.
11862	398	7	In the third month they began to lay the foundation of the heaps, and finished them in the seventh month.
11863	398	8	And when Hezekiah and the princes came and saw the heaps, they blessed the LORD, and his people Israel.
11864	398	9	Then Hezekiah questioned with the priests and the Levites concerning the heaps.
11865	398	10	And Azariah the chief priest of the house of Zadok answered him, and said, Since the people began to bring the offerings into the house of the LORD, we have had enough to eat, and have left plenty: for the LORD hath blessed his people; and that which is left is this great store.
11866	398	11	Then Hezekiah commanded to prepare chambers in the house of the LORD; and they prepared them,
11867	398	12	And brought in the offerings and the tithes and the dedicated things faithfully: over which Cononiah the Levite was ruler, and Shimei his brother was the next.
11868	398	13	And Jehiel, and Azaziah, and Nahath, and Asahel, and Jerimoth, and Jozabad, and Eliel, and Ismachiah, and Mahath, and Benaiah, were overseers under the hand of Cononiah and Shimei his brother, at the commandment of Hezekiah the king, and Azariah the ruler of the house of God.
11869	398	14	And Kore the son of Imnah the Levite, the porter toward the east, was over the freewill offerings of God, to distribute the oblations of the LORD, and the most holy things.
11870	398	15	And next him were Eden, and Miniamin, and Jeshua, and Shemaiah, Amariah, and Shecaniah, in the cities of the priests, in their set office, to give to their brethren by courses, as well to the great as to the small:
11871	398	16	Beside their genealogy of males, from three years old and upward, even unto every one that entereth into the house of the LORD, his daily portion for their service in their charges according to their courses;
11872	398	17	Both to the genealogy of the priests by the house of their fathers, and the Levites from twenty years old and upward, in their charges by their courses;
11873	398	18	And to the genealogy of all their little ones, their wives, and their sons, and their daughters, through all the congregation: for in their set office they sanctified themselves in holiness:
11874	398	19	Also of the sons of Aaron the priests, which were in the fields of the suburbs of their cities, in every several city, the men that were expressed by name, to give portions to all the males among the priests, and to all that were reckoned by genealogies among the Levites.
11875	398	20	And thus did Hezekiah throughout all Judah, and wrought that which was good and right and truth before the LORD his God.
11876	398	21	And in every work that he began in the service of the house of God, and in the law, and in the commandments, to seek his God, he did it with all his heart, and prospered.
11877	399	1	AFTER these things, and the establishment thereof, Sennacherib king of Assyria came, and entered into Judah, and encamped against the fenced cities, and thought to win them for himself.
11878	399	2	And when Hezekiah saw that Sennacherib was come, and that he was purposed to fight against Jerusalem,
11879	399	3	He took counsel with his princes and his mighty men to stop the waters of the fountains which were without the city: and they did help him.
11880	399	4	So there was gathered much people together, who stopped all the fountains, and the brook that ran through the midst of the land, saying, Why should the kings of Assyria come, and find much water?
11881	399	5	Also he strengthened himself, and built up all the wall that was broken, and raised it up to the towers, and another wall without, and repaired Millo in the city of David, and made darts and shields in abundance.
11882	399	6	And he set captains of war over the people, and gathered them together to him in the street of the gate of the city, and spake comfortably to them, saying,
11883	399	7	Be strong and courageous, be not afraid nor dismayed for the king of Assyria, nor for all the multitude that is with him: for there be more with us than with him:
11884	399	8	With him is an arm of flesh; but with us is the LORD our God to help us, and to fight our battles. And the people rested themselves upon the words of Hezekiah king of Judah.
11885	399	9	After this did Sennacherib king of Assyria send his servants to Jerusalem, (but he himself laid siege against Lachish, and all his power with him,) unto Hezekiah king of Judah, and unto all Judah that were at Jerusalem, saying,
11886	399	10	Thus saith Sennacherib king of Assyria, Whereon do ye trust, that ye abide in the siege in Jerusalem?
11887	399	11	Doth not Hezekiah persuade you to give over yourselves to die by famine and by thirst, saying, The LORD our God shall deliver us out of the hand of the king of Assyria?
11888	399	12	Hath not the same Hezekiah taken away his high places and his altars, and commanded Judah and Jerusalem, saying, Ye shall worship before one altar, and burn incense upon it?
11889	399	13	Know ye not what I and my fathers have done unto all the people of other lands? were the gods of the nations of those lands any ways able to deliver their lands out of mine hand?
11890	399	14	Who was there among all the gods of those nations that my fathers utterly destroyed, that could deliver his people out of mine hand, that your God should be able to deliver you out of mine hand?
11891	399	15	Now therefore let not Hezekiah deceive you, nor persuade you on this manner, neither yet believe him: for no god of any nation or kingdom was able to deliver his people out of mine hand, and out of the hand of my fathers: how much less shall your God deliver you out of mine hand?
11892	399	16	And his servants spake yet more against the LORD God, and against his servant Hezekiah.
11893	399	17	He wrote also letters to rail on the LORD God of Israel, and to speak against him, saying, As the gods of the nations of other lands have not delivered their people out of mine hand, so shall not the God of Hezekiah deliver his people out of mine hand.
11894	399	18	Then they cried with a loud voice in the Jews' speech unto the people of Jerusalem that were on the wall, to affright them, and to trouble them; that they might take the city.
11895	399	19	And they spake against the God of Jerusalem, as against the gods of the people of the earth, which were the work of the hands of man.
11896	399	20	And for this cause Hezekiah the king, and the prophet Isaiah the son of Amoz, prayed and cried to heaven.
11897	399	21	And the LORD sent an angel, which cut off all the mighty men of valour, and the leaders and captains in the camp of the king of Assyria. So he returned with shame of face to his own land. And when he was come into the house of his god, they that came forth of his own bowels slew him there with the sword.
11898	399	22	Thus the LORD saved Hezekiah and the inhabitants of Jerusalem from the hand of Sennacherib the king of Assyria, and from the hand of all other, and guided them on every side.
11899	399	23	And many brought gifts unto the LORD to Jerusalem, and presents to Hezekiah king of Judah: so that he was magnified in the sight of all nations from thenceforth.
11900	399	24	In those days Hezekiah was sick to the death, and prayed unto the LORD: and he spake unto him, and he gave him a sign.
11901	399	25	But Hezekiah rendered not again according to the benefit done unto him; for his heart was lifted up: therefore there was wrath upon him, and upon Judah and Jerusalem.
11902	399	26	Notwithstanding Hezekiah humbled himself for the pride of his heart, both he and the inhabitants of Jerusalem, so that the wrath of the LORD came not upon them in the days of Hezekiah.
11903	399	27	And Hezekiah had exceeding much riches and honour: and he made himself treasuries for silver, and for gold, and for precious stones, and for spices, and for shields, and for all manner of pleasant jewels;
11904	399	28	Storehouses also for the increase of corn, and wine, and oil; and stalls for all manner of beasts, and cotes for flocks.
11905	399	29	Moreover he provided him cities, and possessions of flocks and herds in abundance: for God had given him substance very much.
11906	399	30	This same Hezekiah also stopped the upper watercourse of Gihon, and brought it straight down to the west side of the city of David. And Hezekiah prospered in all his works.
11907	399	31	Howbeit in the business of the ambassadors of the princes of Babylon, who sent unto him to enquire of the wonder that was done in the land, God left him, to try him, that he might know all that was in his heart.
11908	399	32	Now the rest of the acts of Hezekiah, and his goodness, behold, they are written in the vision of Isaiah the prophet, the son of Amoz, and in the book of the kings of Judah and Israel.
11909	399	33	And Hezekiah slept with his fathers, and they buried him in the chiefest of the sepulchres of the sons of David: and all Judah and the inhabitants of Jerusalem did him honour at his death. And Manasseh his son reigned in his stead.
11910	400	1	MANASSEH began to reign, and he reigned fifty and five years in Jerusalem:
11911	400	2	But did that which was evil in the sight of the LORD, like unto the abominations of the heathen, whom the LORD had cast out before the children of Israel.
11912	400	3	For he built again the high places which Hezekiah his father had broken down, and he reared up altars for Baalim, and made groves, and worshipped all the host of heaven, and served them.
11913	400	4	Also he built altars in the house of the LORD, whereof the LORD had said, In Jerusalem shall my name be for ever.
11914	400	5	And he built altars for all the host of heaven in the two courts of the house of the LORD.
11915	400	6	And he caused his children to pass through the fire in the valley of the son of Hinnom: also he observed times, and used enchantments, and used witchcraft, and dealt with a familiar spirit, and with wizards: he wrought much evil in the sight of the LORD, to provoke him to anger.
11916	400	7	And he set a carved image, the idol which he had made, in the house of God, of which God had said to David and to Solomon his son, In this house, and in Jerusalem, which I have chosen before all the tribes of Israel, will I put my name for ever:
11917	400	8	Neither will I any more remove the foot of Israel from out of the land which I have appointed for your fathers; so that they will take heed to do all that I have commanded them, according to the whole law and the statutes and the ordinances by the hand of Moses.
11918	400	9	So Manasseh made Judah and the inhabitants of Jerusalem to err, and to do worse than the heathen, whom the LORD had destroyed before the children of Israel.
11919	400	10	And the LORD spake to Manasseh, and to his people: but they would not hearken.
11920	400	11	Wherefore the LORD brought upon them the captains of the host of the king of Assyria, which took Manasseh among the thorns, and bound him with fetters, and carried him to Babylon.
11921	400	12	And when he was in affliction, he besought the LORD his God, and humbled himself greatly before the God of his fathers,
11922	400	13	And prayed unto him: and he was intreated of him, and heard his supplication, and brought him again to Jerusalem into his kingdom. Then Manasseh knew that the LORD he was God.
11923	400	14	Now after this he built a wall without the city of David, on the west side of Gihon, in the valley, even to the entering in at the fish gate, and compassed about Ophel, and raised it up a very great height, and put captains of war in all the fenced cities of Judah.
11924	400	15	And he took away the strange gods, and the idol out of the house of the LORD, and all the altars that he had built in the mount of the house of the LORD, and in Jerusalem, and cast them out of the city.
11925	400	16	And he repaired the altar of the LORD, and sacrificed thereon peace offerings and thank offerings, and commanded Judah to serve the LORD God of Israel.
11926	400	17	Nevertheless the people did sacrifice still in the high places, yet unto the LORD their God only.
11927	400	18	Now the rest of the acts of Manasseh, and his prayer unto his God, and the words of the seers that spake to him in the name of the LORD God of Israel, behold, they are written in the book of the kings of Israel.
11928	400	19	His prayer also, and how God was intreated of him, and all his sin, and his trespass, and the places wherein he built high places, and set up groves and graven images, before he was humbled: behold, they are written among the sayings of the seers.
11929	400	20	So Manasseh slept with his fathers, and they buried him in his own house: and Amon his son reigned in his stead.
11930	400	21	Amon was two and twenty years old when he began to reign, and reigned two years in Jerusalem.
11931	400	22	But he did that which was evil in the sight of the LORD, as did Manasseh his father: for Amon sacrificed unto all the carved images which Manasseh his father had made, and served them;
11932	400	23	And humbled not himself before the LORD, as Manasseh his father had humbled himself; but Amon trespassed more and more.
11933	400	24	And his servants conspired against him, and slew him in his own house.
11934	400	25	But the people of the land slew all them that had conspired against king Amon; and the people of the land made Josiah his son king in his stead.
11935	401	1	JOSIAHbegan to reign, and he reigned in Jerusalem one and thirty years.
11936	401	2	And he did that which was right in the sight of the LORD, and walked in the ways of David his father, and declined neither to the right hand, nor to the left.
11937	401	3	For in the eighth year of his reign, while he was yet young, he began to seek after the God of David his father: and in the twelfth year he began to purge Judah and Jerusalem from the high places, and the groves, and the carved images, and the molten images.
11938	401	4	And they brake down the altars of Baalim in his presence; and the images, that were on high above them, he cut down; and the groves, and the carved images, and the molten images, he brake in pieces, and made dust of them, and strowed it upon the graves of them that had sacrificed unto them.
11939	401	5	And he burnt the bones of the priests upon their altars, and cleansed Judah and Jerusalem.
11940	401	6	And so did he in the cities of Manasseh, and Ephraim, and Simeon, even unto Naphtali, with their mattocks round about.
11941	401	7	And when he had broken down the altars and the groves, and had beaten the graven images into powder, and cut down all the idols throughout all the land of Israel, he returned to Jerusalem.
11942	401	8	Now in the eighteenth year of his reign, when he had purged the land, and the house, he sent Shaphan the son of Azaliah, and Maaseiah the governor of the city, and Joah the son of Joahaz the recorder, to repair the house of the LORD his God.
11943	401	9	And when they came to Hilkiah the high priest, they delivered the money that was brought into the house of God, which the Levites that kept the doors had gathered of the hand of Manasseh and Ephraim, and of all the remnant of Israel, and of all Judah and Benjamin; and they returned to Jerusalem.
11944	401	10	And they put it in the hand of the workmen that had the oversight of the house of the LORD, and they gave it to the workmen that wrought in the house of the LORD, to repair and amend the house:
11945	401	11	Even to the artificers and builders gave they it, to buy hewn stone, and timber for couplings, and to floor the houses which the kings of Judah had destroyed.
11946	401	12	And the men did the work faithfully: and the overseers of them were Jahath and Obadiah, the Levites, of the sons of Merari; and Zechariah and Meshullam, of the sons of the Kohathites, to set it forward; and other of the Levites, all that could skill of instruments of musick.
11947	401	13	Also they were over the bearers of burdens, and were overseers of all that wrought the work in any manner of service: and of the Levites there were scribes, and officers, and porters.
11948	401	14	And when they brought out the money that was brought into the house of the LORD, Hilkiah the priest found a book of the law of the LORD given by Moses.
11949	401	15	And Hilkiah answered and said to Shaphan the scribe, I have found the book of the law in the house of the LORD. And Hilkiah delivered the book to Shaphan.
11950	401	16	And Shaphan carried the book to the king, and brought the king word back again, saying, All that was committed to thy servants, they do it.
11951	401	17	And they have gathered together the money that was found in the house of the LORD, and have delivered it into the hand of the overseers, and to the hand of the workmen.
11952	401	18	Then Shaphan the scribe told the king, saying, Hilkiah the priest hath given me a book. And Shaphan read it before the king.
11953	401	19	And it came to pass, when the king had heard the words of the law, that he rent his clothes.
11954	401	20	And the king commanded Hilkiah, and Ahikam the son of Shaphan, and Abdon the son of Micah, and Shaphan the scribe, and Asaiah a servant of the king's, saying,
11955	401	21	Go, enquire of the LORD for me, and for them that are left in Israel and in Judah, concerning the words of the book that is found: for great is the wrath of the LORD that is poured out upon us, because our fathers have not kept the word of the LORD, to do after all that is written in this book.
11956	401	22	And Hilkiah, and they that the king had appointed, went to Huldah the prophetess, the wife of Shallum the son of Tikvath, the son of Hasrah, keeper of the wardrobe; (now she dwelt in Jerusalem in the college:) and they spake to her to that effect.
11957	401	23	And she answered them, Thus saith the LORD God of Israel, Tell ye the man that sent you to me,
11958	401	24	Thus saith the LORD, Behold, I will bring evil upon this place, and upon the inhabitants thereof, even all the curses that are written in the book which they have read before the king of Judah:
11959	401	25	Because they have forsaken me, and have burned incense unto other gods, that they might provoke me to anger with all the works of their hands; therefore my wrath shall be poured out upon this place, and shall not be quenched.
11960	401	26	And as for the king of Judah, who sent you to enquire of the LORD, so shall ye say unto him, Thus saith the LORD God of Israel concerning the words which thou hast heard;
11961	401	27	Because thine heart was tender, and thou didst humble thyself before God, when thou heardest his words against this place, and against the inhabitants thereof, and humbledst thyself before me, and didst rend thy clothes, and weep before me; I have even heard thee also, saith the LORD.
11962	401	28	Behold, I will gather thee to thy fathers, and thou shalt be gathered to thy grave in peace, neither shall thine eyes see all the evil that I will bring upon this place, and upon the inhabitants of the same. So they brought the king word again.
11963	401	29	Then the king sent and gathered together all the elders of Judah and Jerusalem.
11964	401	30	And the king went up into the house of the LORD, and all the men of Judah, and the inhabitants of Jerusalem, and the priests, and the Levites, and all the people, great and small: and he read in their ears all the words of the book of the covenant that was found in the house of the LORD.
11965	401	31	And the king stood in his place, and made a covenant before the LORD, to walk after the LORD, and to keep his commandments, and his testimonies, and his statutes, with all his heart, and with all his soul, to perform the words of the covenant which are written in this book.
11966	401	32	And he caused all that were present in Jerusalem and Benjamin to stand to it. And the inhabitants of Jerusalem did according to the covenant of God, the God of their fathers.
11967	401	33	And Josiah took away all the abominations out of all the countries that pertained to the children of Israel, and made all that were present in Israel to serve, even to serve the LORD their God. And all his days they departed not from following the LORD, the God of their fathers.
11968	402	1	MOREOVER Josiah kept a passover unto the LORD in Jerusalem: and they killed the passover on the fourteenth day of the first month.
11969	402	2	And he set the priests in their charges, and encouraged them to the service of the house of the LORD,
11970	402	3	And said unto the Levites that taught all Israel, which were holy unto the LORD, Put the holy ark in the house which Solomon the son of David king of Israel did build; it shall not be a burden upon your shoulders: serve now the LORD your God, and his people Israel,
11971	402	4	And prepare yourselves by the houses of your fathers, after your courses, according to the writing of David king of Israel, and according to the writing of Solomon his son.
11972	402	5	And stand in the holy place according to the divisions of the families of the fathers of your brethren the people, and after the division of the families of the Levites.
11973	402	6	So kill the passover, and sanctify yourselves, and prepare your brethren, that they may do according to the word of the LORD by the hand of Moses.
11974	402	7	And Josiah gave to the people, of the flock, lambs and kids, all for the passover offerings, for all that were present, to the number of thirty thousand, and three thousand bullocks: these were of the king's substance.
11975	402	8	And his princes gave willingly unto the people, to the priests, and to the Levites: Hilkiah and Zechariah and Jehiel, rulers of the house of God, gave unto the priests for the passover offerings two thousand and six hundred small cattle, and three hundred oxen.
11976	402	9	Conaniah also, and Shemaiah and Nethaneel, his brethren, and Hashabiah and Jeiel and Jozabad, chief of the Levites, gave unto the Levites for passover offerings five thousand small cattle, and five hundred oxen.
11977	402	10	So the service was prepared, and the priests stood in their place, and the Levites in their courses, according to the king's commandment.
11978	402	11	And they killed the passover, and the priests sprinkled the blood from their hands, and the Levites flayed them.
11979	402	12	And they removed the burnt offerings, that they might give according to the divisions of the families of the people, to offer unto the LORD, as it is written in the book of Moses. And so did they with the oxen.
11980	402	13	And they roasted the passover with fire according to the ordinance: but the other holy offerings sod they in pots, and in caldrons, and in pans, and divided them speedily among all the people.
11981	402	14	And afterward they made ready for themselves, and for the priests: because the priests the sons of Aaron were busied in offering of burnt offerings and the fat until night; therefore the Levites prepared for themselves, and for the priests the sons of Aaron.
11982	402	15	And the singers the sons of Asaph were in their place, according to the commandment of David, and Asaph, and Heman, and Jeduthun the king's seer; and the porters waited at every gate; they might not depart from their service; for their brethren the Levites prepared for them.
11983	402	16	So all the service of the LORD was prepared the same day, to keep the passover, and to offer burnt offerings upon the altar of the LORD, according to the commandment of king Josiah.
11984	402	17	And the children of Israel that were present kept the passover at that time, and the feast of unleavened bread seven days.
11985	402	18	And there was no passover like to that kept in Israel from the days of Samuel the prophet; neither did all the kings of Israel keep such a passover as Josiah kept, and the priests, and the Levites, and all Judah and Israel that were present, and the inhabitants of Jerusalem.
11986	402	19	In the eighteenth year of the reign of Josiah was this passover kept.
11987	402	20	After all this, when Josiah had prepared the temple, Necho king of Egypt came up to fight against Carchemish by Euphrates: and Josiah went out against him.
11988	402	21	But he sent ambassadors to him, saying, What have I to do with thee, thou king of Judah? I come not against thee this day, but against the house wherewith I have war: for God commanded me to make haste: forbear thee from meddling with God, who is with me, that he destroy thee not.
11989	402	22	Nevertheless Josiah would not turn his face from him, but disguised himself, that he might fight with him, and hearkened not unto the words of Necho from the mouth of God, and came to fight in the valley of Megiddo.
11990	402	23	And the archers shot at king Josiah; and the king said to his servants, Have me away; for I am sore wounded.
11991	402	24	His servants therefore took him out of that chariot, and put him in the second chariot that he had; and they brought him to Jerusalem, and he died, and was buried in one of the sepulchres of his fathers. And all Judah and Jerusalem mourned for Josiah.
11992	402	25	And Jeremiah lamented for Josiah: and all the singing men and the singing women spake of Josiah in their lamentations to this day, and made them an ordinance in Israel: and, behold, they are written in the lamentations.
11993	402	26	Now the rest of the acts of Josiah, and his goodness, according to that which was written in the law of the LORD,
11994	402	27	And his deeds, first and last, behold, they are written in the book of the kings of Israel and Judah.
11995	403	1	THEN the people of the land took Jehoahaz the son of Josiah, and made him king in his father's stead in Jerusalem.
11996	403	2	Jehoahaz was twenty and three years old when he began to reign, and he reigned three months in Jerusalem.
11997	403	3	And the king of Egypt put him down at Jerusalem, and condemned the land in an hundred talents of silver and a talent of gold.
11998	403	4	And the king of Egypt made Eliakim his brother king over Judah and Jerusalem, and turned his name to Jehoiakim. And Necho took Jehoahaz his brother, and carried him to Egypt.
11999	403	5	Jehoiakim was twenty and five years old when he began to reign, and he reigned eleven years in Jerusalem: and he did that which was evil in the sight of the LORD his God.
12000	403	6	Against him came up Nebuchadnezzar king of Babylon, and bound him in fetters, to carry him to Babylon.
12001	403	7	Nebuchadnezzar also carried of the vessels of the house of the LORD to Babylon, and put them in his temple at Babylon.
12002	403	8	Now the rest of the acts of Jehoiakim, and his abominations which he did, and that which was found in him, behold, they are written in the book of the kings of Israel and Judah: and Jehoiachin his son reigned in his stead.
12003	403	9	Jehoiachin was eight years old when he began to reign, and he reigned three months and ten days in Jerusalem: and he did that which was evil in the sight of the LORD.
12004	403	10	And when the year was expired, king Nebuchadnezzar sent, and brought him to Babylon, with the goodly vessels of the house of the LORD, and made Zedekiah his brother king over Judah and Jerusalem.
12005	403	11	Zedekiah was one and twenty years old when he began to reign, and reigned eleven years in Jerusalem.
12006	403	12	And he did that which was evil in the sight of the LORD his God, and humbled not himself before Jeremiah the prophet speaking from the mouth of the LORD.
12007	403	13	And he also rebelled against king Nebuchadnezzar, who had made him swear by God: but he stiffened his neck, and hardened his heart from turning unto the LORD God of Israel.
12008	403	14	Moreover all the chief of the priests, and the people, transgressed very much after all the abominations of the heathen; and polluted the house of the LORD which he had hallowed in Jerusalem.
12009	403	15	And the LORD God of their fathers sent to them by his messengers, rising up betimes, and sending; because he had compassion on his people, and on his dwelling place:
12010	403	16	But they mocked the messengers of God, and despised his words, and misused his prophets, until the wrath of the LORD arose against his people, till there was no remedy.
12011	403	17	Therefore he brought upon them the king of the Chaldees, who slew their young men with the sword in the house of their sanctuary, and had no compassion upon young man or maiden, old man, or him that stooped for age: he gave them all into his hand.
12012	403	18	And all the vessels of the house of God, great and small, and the treasures of the house of the LORD, and the treasures of the king, and of his princes; all these he brought to Babylon.
12013	403	19	And they burnt the house of God, and brake down the wall of Jerusalem, and burnt all the palaces thereof with fire, and destroyed all the goodly vessels thereof.
12014	403	20	And them that had escaped from the sword carried he away to Babylon; where they were servants to him and his sons until the reign of the kingdom of Persia:
12015	403	21	To fulfil the word of the LORD by the mouth of Jeremiah, until the land had enjoyed her sabbaths: for as long as she lay desolate she kept sabbath, to fulfil threescore and ten years.
12016	403	22	Now in the first year of Cyrus king of Persia, that the word of the LORD spoken by the mouth of Jeremiah might be accomplished, the LORD stirred up the spirit of Cyrus king of Persia, that he made a proclamation throughout all his kingdom, and put it also in writing, saying,
12017	403	23	Thus saith Cyrus king of Persia, All the kingdoms of the earth hath the LORD God of heaven given me; and he hath charged me to build him an house in Jerusalem, which is in Judah. Who is there among you of all his people? The LORD his God be with him, and let him go up.
12018	404	1	NOW in the first year of Cyrus king of Persia, that the word of the LORD by the mouth of Jeremiah might be fulfilled, the LORD stirred up the spirit of Cyrus king of Persia, that he made a proclamation throughout all his kingdom, and put it also in writing, saying,
12019	404	2	Thus saith Cyrus king of Persia, The LORD God of heaven hath given me all the kingdoms of the earth; and he hath charged me to build him an house at Jerusalem, which is in Judah.
12020	404	3	Who is there among you of all his people? his God be with him, and let him go up to Jerusalem, which is in Judah, and build the house of the LORD God of Israel, (he is the God,) which is in Jerusalem.
12021	404	4	And whosoever remaineth in any place where he sojourneth, let the men of his place help him with silver, and with gold, and with goods, and with beasts, beside the freewill offering for the house of God that is in Jerusalem.
12022	404	5	Then rose up the chief of the fathers of Judah and Benjamin, and the priests, and the Levites, with all them whose spirit God had raised, to go up to build the house of the LORD which is in Jerusalem.
12023	404	6	And all they that were about them strengthened their hands with vessels of silver, with gold, with goods, and with beasts, and with precious things, beside all that was willingly offered.
12024	404	7	Also Cyrus the king brought forth the vessels of the house of the LORD, which Nebuchadnezzar had brought forth out of Jerusalem, and had put them in the house of his gods;
12025	404	8	Even those did Cyrus king of Persia bring forth by the hand of Mithredath the treasurer, and numbered them unto Sheshbazzar, the prince of Judah.
12026	404	9	And this is the number of them: thirty chargers of gold, a thousand chargers of silver, nine and twenty knives,
12027	404	10	Thirty basons of gold, silver basons of a second sort four hundred and ten, and other vessels a thousand.
12028	404	11	All the vessels of gold and of silver were five thousand and four hundred. All these did Sheshbazzar bring up with them of the captivity that were brought up from Babylon unto Jerusalem.
12029	405	1	NOW these are the children of the province that went up out of the captivity, of those which had been carried away, whom Nebuchadnezzar the king of Babylon had carried away unto Babylon, and came again unto Jerusalem and Judah, every one unto his city;
12030	405	2	Which came with Zerubbabel: Jeshua, Nehemiah, Seraiah, Reelaiah, Mordecai, Bilshan, Mispar, Bigvai, Rehum, Baanah. The number of the men of the people of Israel:
12031	405	3	The children of Parosh, two thousand an hundred seventy and two.
12032	405	4	The children of Shephatiah, three hundred seventy and two.
12033	405	5	The children of Arah, seven hundred seventy and five.
12034	405	6	The children of Pahath-moab, of the children of Jeshua and Joab, two thousand eight hundred and twelve.
12035	405	7	The children of Elam, a thousand two hundred fifty and four.
12036	405	8	The children of Zattu, nine hundred forty and five.
12037	405	9	The children of Zaccai, seven hundred and threescore.
12038	405	10	The children of Bani, six hundred forty and two.
12039	405	11	The children of Bebai, six hundred twenty and three.
12040	405	12	The children of Azgad, a thousand two hundred twenty and two.
12041	405	13	The children of Adonikam, six hundred sixty and six.
12042	405	14	The children of Bigvai, two thousand fifty and six.
12043	405	15	The children of Adin, four hundred fifty and four.
12044	405	16	The children of Ater of Hezekiah, ninety and eight.
12045	405	17	The children of Bezai, three hundred twenty and three.
12046	405	18	The children of Jorah, an hundred and twelve.
12047	405	19	The children of Hashum, two hundred twenty and three.
12048	405	20	The children of Gibbar, ninety and five.
12049	405	21	The children of Beth-lehem, an hundred twenty and three.
12050	405	22	The men of Netophah, fifty and six.
12051	405	23	The men of Anathoth, an hundred twenty and eight.
12052	405	24	The children of Azmaveth, forty and two.
12053	405	25	The children of Kirjath-arim, Chephirah, and Beeroth, seven hundred and forty and three.
12054	405	26	The children of Ramah and Gaba, six hundred twenty and one.
12055	405	27	The men of Michmas, an hundred twenty and two.
12056	405	28	The men of Beth-el and Ai, two hundred twenty and three.
12057	405	29	The children of Nebo, fifty and two.
12058	405	30	The children of Magbish, an hundred fifty and six.
12059	405	31	The children of the other Elam, a thousand two hundred fifty and four.
12060	405	32	The children of Harim, three hundred and twenty.
12061	405	33	The children of Lod, Hadid, and Ono, seven hundred twenty and five.
12062	405	34	The children of Jericho, three hundred forty and five.
12063	405	35	The children of Senaah, three thousand and six hundred and thirty.
12064	405	36	The priests: the children of Jedaiah, of the house of Jeshua, nine hundred seventy and three.
12065	405	37	The children of Immer, a thousand fifty and two.
12066	405	38	The children of Pashur, a thousand two hundred forty and seven.
12067	405	39	The children of Harim, a thousand and seventeen.
12068	405	40	The Levites: the children of Jeshua and Kadmiel, of the children of Hodaviah, seventy and four.
12069	405	41	The singers: the children of Asaph, an hundred twenty and eight.
12070	405	42	The children of the porters: the children of Shallum, the children of Ater, the children of Talmon, the children of Akkub, the children of Hatita, the children of Shobai, in all an hundred thirty and nine.
12071	405	43	The Nethinims: the children of Ziha, the children of Hasupha, the children of Tabbaoth,
12072	405	44	The children of Keros, the children of Siaha, the children of Padon,
12073	405	45	The children of Lebanah, the children of Hagabah, the children of Akkub,
12074	405	46	The children of Hagab, the children of Shalmai, the children of Hanan,
12075	405	47	The children of Giddel, the children of Gahar, the children of Reaiah,
12076	405	48	The children of Rezin, the children of Nekoda, the children of Gazzam,
12077	405	49	The children of Uzza, the children of Paseah, the children of Besai,
12078	405	50	The children of Asnah, the children of Mehunim, the children of Nephusim,
12079	405	51	The children of Bakbuk, the children of Hakupha, the children of Harhur,
12080	405	52	The children of Bazluth, the children of Mehida, the children of Harsha,
12081	405	53	The children of Barkos, the children of Sisera, the children of Thamah,
12082	405	54	The children of Neziah, the children of Hatipha.
12083	405	55	The children of Solomon's servants: the children of Sotai, the children of Sophereth, the children of Peruda,
12084	405	56	The children of Jaalah, the children of Darkon, the children of Giddel,
12085	405	57	The children of Shephatiah, the children of Hattil, the children of Pochereth of Zebaim, the children of Ami.
12086	405	58	All the Nethinims, and the children of Solomon's servants, were three hundred ninety and two.
12087	405	59	And these were they which went up from Tel-melah, Tel-harsa, Cherub, Addan, and Immer: but they could not shew their father's house, and their seed, whether they were of Israel:
12088	405	60	The children of Delaiah, the children of Tobiah, the children of Nekoda, six hundred fifty and two.
12089	405	61	And of the children of the priests: the children of Habaiah, the children of Koz, the children of Barzillai; which took a wife of the daughters of Barzillai the Gileadite, and was called after their name:
12090	405	62	These sought their register among those that were reckoned by genealogy, but they were not found: therefore were they, as polluted, put from the priesthood.
12091	405	63	And the Tirshatha said unto them, that they should not eat of the most holy things, till there stood up a priest with Urim and with Thummim.
12092	405	64	The whole congregation together was forty and two thousand three hundred and threescore,
12093	405	65	Beside their servants and their maids, of whom there were seven thousand three hundred thirty and seven: and there were among them two hundred singing men and singing women.
12094	405	66	Their horses were seven hundred thirty and six; their mules, two hundred forty and five;
12095	405	67	Their camels, four hundred thirty and five; their asses, six thousand seven hundred and twenty.
12096	405	68	And some of the chief of the fathers, when they came to the house of the LORD which is at Jerusalem, offered freely for the house of God to set it up in his place:
12097	405	69	They gave after their ability unto the treasure of the work threescore and one thousand drams of gold, and five thousand pound of silver, and one hundred priests' garments.
12098	405	70	So the priests, and the Levites, and some of the people, and the singers, and the porters, and the Nethinims, dwelt in their cities, and all Israel in their cities.
12099	406	1	AND when the seventh month was come, and the children of Israel were in the cities, the people gathered themselves together as one man to Jerusalem.
12100	406	2	Then stood up Jeshua the son of Jozadak, and his brethren the priests, and Zerubbabel the son of Shealtiel, and his brethren, and builded the altar of the God of Israel, to offer burnt offerings thereon, as it is written in the law of Moses the man of God.
12101	406	3	And they set the altar upon his bases; for fear was upon them because of the people of those countries: and they offered burnt offerings thereon unto the LORD, even burnt offerings morning and evening.
12102	406	4	They kept also the feast of tabernacles, as it is written, and offered the daily burnt offerings by number, according to the custom, as the duty of every day required;
12103	406	5	And afterward offered the continual burnt offering, both of the new moons, and of all the set feasts of the LORD that were consecrated, and of every one that willingly offered a freewill offering unto the LORD.
12104	406	6	From the first day of the seventh month began they to offer burnt offerings unto the LORD. But the foundation of the temple of the LORD was not yet laid.
12105	406	7	They gave money also unto the masons, and to the carpenters; and meat, and drink, and oil, unto them of Zidon, and to them of Tyre, to bring cedar trees from Lebanon to the sea of Joppa, according to the grant that they had of Cyrus king of Persia.
12106	406	8	Now in the second year of their coming unto the house of God at Jerusalem, in the second month, began Zerubbabel the son of Shealtiel, and Jeshua the son of Jozadak, and the remnant of their brethren the priests and the Levites, and all they that were come out of the captivity unto Jerusalem; and appointed the Levites, from twenty years old and upward, to set forward the work of the house of the LORD.
12107	406	9	Then stood Jeshua with his sons and his brethren, Kadmiel and his sons, the sons of Judah, together, to set forward the workmen in the house of God: the sons of Henadad, with their sons and their brethren the Levites.
12108	406	10	And when the builders laid the foundation of the temple of the LORD, they set the priests in their apparel with trumpets, and the Levites the sons of Asaph with cymbals, to praise the LORD, after the ordinance of David king of Israel.
12109	406	11	And they sang together by course in praising and giving thanks unto the LORD; because he is good, for his mercy endureth for ever toward Israel. And all the people shouted with a great shout, when they praised the LORD, because the foundation of the house of the LORD was laid.
12110	406	12	But many of the priests and Levites and chief of the fathers, who were ancient men, that had seen the first house, when the foundation of this house was laid before their eyes, wept with a loud voice; and many shouted aloud for joy:
12111	406	13	So that the people could not discern the noise of the shout of joy from the noise of the weeping of the people: for the people shouted with a loud shout, and the noise was heard afar off.
12112	407	1	NOW when the adversaries of Judah and Benjamin heard that the children of the captivity builded the temple unto the LORD God of Israel;
12113	407	2	Then they came to Zerubbabel, and to the chief of the fathers, and said unto them, Let us build with you: for we seek your God, as ye do; and we do sacrifice unto him since the days of Esar-haddon king of Assur, which brought us up hither.
12114	407	3	But Zerubbabel, and Jeshua, and the rest of the chief of the fathers of Israel, said unto them, Ye have nothing to do with us to build an house unto our God; but we ourselves together will build unto the LORD God of Israel, as king Cyrus the king of Persia hath commanded us.
12115	407	4	Then the people of the land weakened the hands of the people of Judah, and troubled them in building,
12116	407	5	And hired counsellors against them, to frustrate their purpose, all the days of Cyrus king of Persia, even until the reign of Darius king of Persia.
12117	407	6	And in the reign of Ahasuerus, in the beginning of his reign, wrote they unto him an accusation against the inhabitants of Judah and Jerusalem.
12118	407	7	And in the days of Artaxerxes wrote Bishlam, Mithredath, Tabeel, and the rest of their companions, unto Artaxerxes king of Persia; and the writing of the letter was written in the Syrian tongue, and interpreted in the Syrian tongue.
12119	407	8	Rehum the chancellor and Shimshai the scribe wrote a letter against Jerusalem to Artaxerxes the king in this sort:
12120	407	9	Then wrote Rehum the chancellor, and Shimshai the scribe, and the rest of their companions; the Dinaites, the Apharsathchites, the Tarpelites, the Apharsites, the Archevites, the Babylonians, the Susanchites, the Dehavites, and the Elamites,
12121	407	10	And the rest of the nations whom the great and noble Asnappar brought over, and set in the cities of Samaria, and the rest that are on this side the river, and at such a time.
12122	407	11	This is the copy of the letter that they sent unto him, even unto Artaxerxes the king; Thy servants the men on this side the river, and at such a time.
12123	407	12	Be it known unto the king, that the Jews which came up from thee to us are come unto Jerusalem, building the rebellious and the bad city, and have set up the walls thereof, and joined the foundations.
12124	407	13	Be it known now unto the king, that, if this city be builded, and the walls set up again, then will they not pay toll, tribute, and custom, and so thou shalt endamage the revenue of the kings.
12125	407	14	Now because we have maintenance from the king's palace, and it was not meet for us to see the king's dishonour, therefore have we sent and certified the king;
12126	407	15	That search may be made in the book of the records of thy fathers: so shalt thou find in the book of the records, and know that this city is a rebellious city, and hurtful unto kings and provinces, and that they have moved sedition within the same of old time: for which cause was this city destroyed.
12127	407	16	We certify the king that, if this city be builded again, and the walls thereof set up, by this means thou shalt have no portion on this side the river.
12128	407	17	Then sent the king an answer unto Rehum the chancellor, and to Shimshai the scribe, and to the rest of their companions that dwell in Samaria, and unto the rest beyond the river, Peace, and at such a time.
12129	407	18	The letter which ye sent unto us hath been plainly read before me.
12130	407	19	And I commanded, and search hath been made, and it is found that this city of old time hath made insurrection against kings, and that rebellion and sedition have been made therein.
12131	407	20	There have been mighty kings also over Jerusalem, which have ruled over all countries beyond the river; and toll, tribute, and custom, was paid unto them.
12132	407	21	Give ye now commandment to cause these men to cease, and that this city be not builded, until another commandment shall be given from me.
12133	407	22	Take heed now that ye fail not to do this: why should damage grow to the hurt of the kings?
12134	407	23	Now when the copy of king Artaxerxes' letter was read before Rehum, and Shimshai the scribe, and their companions, they went up in haste to Jerusalem unto the Jews, and made them to cease by force and power.
12135	407	24	Then ceased the work of the house of God which is at Jerusalem. So it ceased unto the second year of the reign of Darius king of Persia.
12136	408	1	THEN the prophets, Haggai the prophet, and Zechariah the son of Iddo, prophesied unto the Jews that were in Judah and Jerusalem in the name of the God of Israel, even unto them.
12137	408	2	Then rose up Zerubbabel the son of Shealtiel, and Jeshua the son of Jozadak, and began to build the house of God which is at Jerusalem: and with them were the prophets of God helping them.
12138	408	3	At the same time came to them Tatnai, governor on this side the river, and Shethar-boznai, and their companions, and said thus unto them, Who hath commanded you to build this house, and to make up this wall?
12139	408	4	Then said we unto them after this manner, What are the names of the men that make this building?
12140	408	5	But the eye of their God was upon the elders of the Jews, that they could not cause them to cease, till the matter came to Darius: and then they returned answer by letter concerning this matter.
12141	408	6	The copy of the letter that Tatnai, governor on this side the river, and Shethar-boznai, and his companions the Apharsachites, which were on this side the river, sent unto Darius the king:
12142	408	7	They sent a letter unto him, wherein was written thus; Unto Darius the king, all peace.
12143	408	8	Be it known unto the king, that we went into the province of Judea, to the house of the great God, which is builded with great stones, and timber is laid in the walls, and this work goeth fast on, and prospereth in their hands.
12144	408	9	Then asked we those elders, and said unto them thus, Who commanded you to build this house, and to make up these walls?
12145	408	10	We asked their names also, to certify thee, that we might write the names of the men that were the chief of them.
12146	408	11	And thus they returned us answer, saying, We are the servants of the God of heaven and earth, and build the house that was builded these many years ago, which a great king of Israel builded and set up.
12147	408	12	But after that our fathers had provoked the God of heaven unto wrath, he gave them into the hand of Nebuchadnezzar the king of Babylon, the Chaldean, who destroyed this house, and carried the people away into Babylon.
12148	408	13	But in the first year of Cyrus the king of Babylon the same king Cyrus made a decree to build this house of God.
12149	408	14	And the vessels also of gold and silver of the house of God, which Nebuchadnezzar took out of the temple that was in Jerusalem, and brought them into the temple of Babylon, those did Cyrus the king take out of the temple of Babylon, and they were delivered unto one, whose name was Sheshbazzar, whom he had made governor;
12150	408	15	And said unto him, Take these vessels, go, carry them into the temple that is in Jerusalem, and let the house of God be builded in his place.
12151	408	16	Then came the same Sheshbazzar, and laid the foundation of the house of God which is in Jerusalem: and since that time even until now hath it been in building, and yet it is not finished.
12152	408	17	Now therefore, if it seem good to the king, let there be search made in the king's treasure house, which is there at Babylon, whether it be so, that a decree was made of Cyrus the king to build this house of God at Jerusalem, and let the king send his pleasure to us concerning this matter.
12153	409	1	THEN Darius the king made a decree, and search was made in the house of the rolls, where the treasures were laid up in Babylon.
12154	409	2	And there was found at Achmetha, in the palace that is in the province of the Medes, a roll, and therein was a record thus written:
12155	409	3	In the first year of Cyrus the king the same Cyrus the king made a decree concerning the house of God at Jerusalem, Let the house be builded, the place where they offered sacrifices, and let the foundations thereof be strongly laid; the height thereof threescore cubits, and the breadth thereof threescore cubits;
12156	409	4	With three rows of great stones, and a row of new timber: and let the expenses be given out of the king's house:
12157	409	5	And also let the golden and silver vessels of the house of God, which Nebuchadnezzar took forth out of the temple which is at Jerusalem, and brought unto Babylon, be restored, and brought again unto the temple which is at Jerusalem, every one to his place, and place them in the house of God.
12158	409	6	Now therefore, Tatnai, governor beyond the river, Shethar-boznai, and your companions the Apharsachites, which are beyond the river, be ye far from thence:
12159	409	7	Let the work of this house of God alone; let the governor of the Jews and the elders of the Jews build this house of God in his place.
12160	409	8	Moreover I make a decree what ye shall do to the elders of these Jews for the building of this house of God: that of the king's goods, even of the tribute beyond the river, forthwith expenses be given unto these men, that they be not hindered.
12161	409	9	And that which they have need of, both young bullocks, and rams, and lambs, for the burnt offerings of the God of heaven, wheat, salt, wine, and oil, according to the appointment of the priests which are at Jerusalem, let it be given them day by day without fail:
12162	409	10	That they may offer sacrifices of sweet savours unto the God of heaven, and pray for the life of the king, and of his sons.
12163	409	11	Also I have made a decree, that whosoever shall alter this word, let timber be pulled down from his house, and being set up, let him be hanged thereon; and let his house be made a dunghill for this.
12164	409	12	And the God that hath caused his name to dwell there destroy all kings and people, that shall put to their hand to alter and to destroy this house of God which is at Jerusalem. I Darius have made a decree; let it be done with speed.
12165	409	13	Then Tatnai, governor on this side the river, Shethar-boznai, and their companions, according to that which Darius the king had sent, so they did speedily.
12166	409	14	And the elders of the Jews builded, and they prospered through the prophesying of Haggai the prophet and Zechariah the son of Iddo. And they builded, and finished it, according to the commandment of the God of Israel, and according to the commandment of Cyrus, and Darius, and Artaxerxes king of Persia.
12167	409	15	And this house was finished on the third day of the month Adar, which was in the sixth year of the reign of Darius the king.
12168	409	16	And the children of Israel, the priests, and the Levites, and the rest of the children of the captivity, kept the dedication of this house of God with joy,
12169	409	17	And offered at the dedication of this house of God an hundred bullocks, two hundred rams, four hundred lambs; and for a sin offering for all Israel, twelve he goats, according to the number of the tribes of Israel.
12170	409	18	And they set the priests in their divisions, and the Levites in their courses, for the service of God, which is at Jerusalem; as it is written in the book of Moses.
12171	409	19	And the children of the captivity kept the passover upon the fourteenth day of the first month.
12172	409	20	For the priests and the Levites were purified together, all of them were pure, and killed the passover for all the children of the captivity, and for their brethren the priests, and for themselves.
12173	409	21	And the children of Israel, which were come again out of captivity, and all such as had separated themselves unto them from the filthiness of the heathen of the land, to seek the LORD God of Israel, did eat,
12174	409	22	And kept the feast of unleavened bread seven days with joy: for the LORD had made them joyful, and turned the heart of the king of Assyria unto them, to strengthen their hands in the work of the house of God, the God of Israel.
12175	410	1	NOW after these things, in the reign of Artaxerxes king of Persia, Ezra the son of Seraiah, the son of Azariah, the son of Hilkiah,
12176	410	2	The son of Shallum, the son of Zadok, the son of Ahitub,
12177	410	3	The son of Amariah, the son of Azariah, the son of Meraioth,
12178	410	4	The son of Zerahiah, the son of Uzzi, the son of Bukki,
12179	410	5	The son of Abishua, the son of Phinehas, the son of Eleazar, the son of Aaron the chief priest:
12180	410	6	This Ezra went up from Babylon; and he was a ready scribe in the law of Moses, which the LORD God of Israel had given: and the king granted him all his request, according to the hand of the LORD his God upon him.
12181	410	7	And there went up some of the children of Israel, and of the priests, and the Levites, and the singers, and the porters, and the Nethinims, unto Jerusalem, in the seventh year of Artaxerxes the king.
12182	410	8	And he came to Jerusalem in the fifth month, which was in the seventh year of the king.
12183	410	9	For upon the first day of the first month began he to go up from Babylon, and on the first day of the fifth month came he to Jerusalem, according to the good hand of his God upon him.
12184	410	10	For Ezra had prepared his heart to seek the law of the LORD, and to do it, and to teach in Israel statutes and judgments.
12185	410	11	Now this is the copy of the letter that the king Artaxerxes gave unto Ezra the priest, the scribe, even a scribe of the words of the commandments of the LORD, and of his statutes to Israel.
12186	410	12	Artaxerxes, king of kings, unto Ezra the priest, a scribe of the law of the God of heaven, perfect peace, and at such a time.
12187	410	13	I make a decree, that all they of the people of Israel, and of his priests and Levites, in my realm, which are minded of their own freewill to go up to Jerusalem, go with thee.
12188	410	14	Forasmuch as thou art sent of the king, and of his seven counsellors, to enquire concerning Judah and Jerusalem, according to the law of thy God which is in thine hand;
12189	410	15	And to carry the silver and gold, which the king and his counsellors have freely offered unto the God of Israel, whose habitation is in Jerusalem,
12190	410	16	And all the silver and gold that thou canst find in all the province of Babylon, with the freewill offering of the people, and of the priests, offering willingly for the house of their God which is in Jerusalem:
12191	410	17	That thou mayest buy speedily with this money bullocks, rams, lambs, with their meat offerings and their drink offerings, and offer them upon the altar of the house of your God which is in Jerusalem.
12192	410	18	And whatsoever shall seem good to thee, and to thy brethren, to do with the rest of the silver and the gold, that do after the will of your God.
12193	410	19	The vessels also that are given thee for the service of the house of thy God, those deliver thou before the God of Jerusalem.
12194	410	20	And whatsoever more shall be needful for the house of thy God, which thou shalt have occasion to bestow, bestow it out of the king's treasure house.
12195	410	21	And I, even I Artaxerxes the king, do make a decree to all the treasurers which are beyond the river, that whatsoever Ezra the priest, the scribe of the law of the God of heaven, shall require of you, it be done speedily,
12196	410	22	Unto an hundred talents of silver, and to an hundred measures of wheat, and to an hundred baths of wine, and to an hundred baths of oil, and salt without prescribing how much.
12197	410	23	Whatsoever is commanded by the God of heaven, let it be diligently done for the house of the God of heaven: for why should there be wrath against the realm of the king and his sons?
12198	410	24	Also we certify you, that touching any of the priests and Levites, singers, porters, Nethinims, or ministers of this house of God, it shall not be lawful to impose toll, tribute, or custom, upon them.
12199	410	25	And thou, Ezra, after the wisdom of thy God, that is in thine hand, set magistrates and judges, which may judge all the people that are beyond the river, all such as know the laws of thy God; and teach ye them that know them not.
12200	410	26	And whosoever will not do the law of thy God, and the law of the king, let judgment be executed speedily upon him, whether it be unto death, or to banishment, or to confiscation of goods, or to imprisonment.
12201	410	27	Blessed be the LORD God of our fathers, which hath put such a thing as this in the king's heart, to beautify the house of the LORD which is in Jerusalem:
12202	410	28	And hath extended mercy unto me before the king, and his counsellors, and before all the king's mighty princes. And I was strengthened as the hand of the LORD my God was upon me, and I gathered together out of Israel chief men to go up with me.
12203	411	1	THESE are now the chief of their fathers, and this is the genealogy of them that went up with me from Babylon, in the reign of Artaxerxes the king.
12204	411	2	Of the sons of Phinehas; Gershom: of the sons of Ithamar; Daniel: of the sons of David; Hattush.
12205	411	3	Of the sons of Shechaniah, of the sons of Pharosh; Zechariah: and with him were reckoned by genealogy of the males an hundred and fifty.
12206	411	4	Of the sons of Pahath-moab; Elihoenai the son of Zerahiah, and with him two hundred males.
12207	411	5	Of the sons of Shechaniah; the son of Jahaziel, and with him three hundred males.
12208	411	6	Of the sons also of Adin; Ebed the son of Jonathan, and with him fifty males.
12209	411	7	And of the sons of Elam; Jeshaiah the son of Athaliah, and with him seventy males.
12210	411	8	And of the sons of Shephatiah; Zebadiah the son of Michael, and with him fourscore males.
12211	411	9	Of the sons of Joab; Obadiah the son of Jehiel, and with him two hundred and eighteen males.
12212	411	10	And of the sons of Shelomith; the son of Josiphiah, and with him an hundred and threescore males.
12213	411	11	And of the sons of Bebai; Zechariah the son of Bebai, and with him twenty and eight males.
12214	411	12	And of the sons of Azgad; Johanan the son of Hakkatan, and with him an hundred and ten males.
12215	411	13	And of the last sons of Adonikam, whose names are these, Eliphelet, Jeiel, and Shemaiah, and with them threescore males.
12216	411	14	Of the sons also of Bigvai; Uthai, and Zabbud, and with them seventy males.
12217	411	15	And I gathered them together to the river that runneth to Ahava; and there abode we in tents three days: and I viewed the people, and the priests, and found there none of the sons of Levi.
12218	411	16	Then sent I for Eliezer, for Ariel, for Shemaiah, and for Elnathan, and for Jarib, and for Elnathan, and for Nathan, and for Zechariah, and for Meshullam, chief men; also for Joiarib, and for Elnathan, men of understanding.
12219	411	17	And I sent them with commandment unto Iddo the chief at the place Casiphia, and I told them what they should say unto Iddo, and to his brethren the Nethinims, at the place Casiphia, that they should bring unto us ministers for the house of our God.
12220	411	18	And by the good hand of our God upon us they brought us a man of understanding, of the sons of Mahli, the son of Levi, the son of Israel; and Sherebiah, with his sons and his brethren, eighteen;
12221	411	19	And Hashabiah, and with him Jeshaiah of the sons of Merari, his brethren and their sons, twenty;
12222	411	20	Also of the Nethinims, whom David and the princes had appointed for the service of the Levites, two hundred and twenty Nethinims: all of them were expressed by name.
12223	411	21	Then I proclaimed a fast there, at the river of Ahava, that we might afflict ourselves before our God, to seek of him a right way for us, and for our little ones, and for all our substance.
12224	411	22	For I was ashamed to require of the king a band of soldiers and horsemen to help us against the enemy in the way: because we had spoken unto the king, saying, The hand of our God is upon all them for good that seek him; but his power and his wrath is against all them that forsake him.
12225	411	23	So we fasted and besought our God for this: and he was intreated of us.
12226	411	24	Then I separated twelve of the chief of the priests, Sherebiah, Hashabiah, and ten of their brethren with them,
12227	411	25	And weighed unto them the silver, and the gold, and the vessels, even the offering of the house of our God, which the king, and his counsellors, and his lords, and all Israel there present, had offered:
12228	411	26	I even weighed unto their hand six hundred and fifty talents of silver, and silver vessels an hundred talents, and of gold an hundred talents;
12229	411	27	Also twenty basons of gold, of a thousand drams; and two vessels of fine copper, precious as gold.
12230	411	28	And I said unto them, Ye are holy unto the LORD; the vessels are holy also; and the silver and the gold are a freewill offering unto the LORD God of your fathers.
12231	411	29	Watch ye, and keep them, until ye weigh them before the chief of the priests and the Levites, and chief of the fathers of Israel, at Jerusalem, in the chambers of the house of the LORD.
12232	411	30	So took the priests and the Levites the weight of the silver, and the gold, and the vessels, to bring them to Jerusalem unto the house of our God.
12233	411	31	Then we departed from the river of Ahava on the twelfth day of the first month, to go unto Jerusalem: and the hand of our God was upon us, and he delivered us from the hand of the enemy, and of such as lay in wait by the way.
12234	411	32	And we came to Jerusalem, and abode there three days.
12235	411	33	Now on the fourth day was the silver and the gold and the vessels weighed in the house of our God by the hand of Meremoth the son of Uriah the priest; and with him was Eleazar the son of Phinehas; and with them was Jozabad the son of Jeshua, and Noadiah the son of Binnui, Levites;
12236	411	34	By number and by weight of every one: and all the weight was written at that time.
12237	411	35	Also the children of those that had been carried away, which were come out of the captivity, offered burnt offerings unto the God of Israel, twelve bullocks for all Israel, ninety and six rams, seventy and seven lambs, twelve he goats for a sin offering: all this was a burnt offering unto the LORD.
12238	411	36	And they delivered the king's commissions unto the king's lieutenants, and to the governors on this side the river: and they furthered the people, and the house of God.
12239	412	1	NOW when these things were done, the princes came to me, saying, The people of Israel, and the priests, and the Levites, have not separated themselves from the people of the lands, doing according to their abominations, even of the Canaanites, the Hittites, the Perizzites, the Jebusites, the Ammonites, the Moabites, the Egyptians, and the Amorites.
12240	412	2	For they have taken of their daughters for themselves, and for their sons: so that the holy seed have mingled themselves with the people of those lands: yea, the hand of the princes and rulers hath been chief in this trespass.
12241	412	3	And when I heard this thing, I rent my garment and my mantle, and plucked off the hair of my head and of my beard, and sat down astonied.
12242	412	4	Then were assembled unto me every one that trembled at the words of the God of Israel, because of the transgression of those that had been carried away; and I sat astonied until the evening sacrifice.
12243	412	5	And at the evening sacrifice I arose up from my heaviness; and having rent my garment and my mantle, I fell upon my knees, and spread out my hands unto the LORD my God,
12244	412	6	And said, O my God, I am ashamed and blush to lift up my face to thee, my God: for our iniquities are increased over our head, and our trespass is grown up unto the heavens.
12245	412	7	Since the days of our fathers have we been in a great trespass unto this day; and for our iniquities have we, our kings, and our priests, been delivered into the hand of the kings of the lands, to the sword, to captivity, and to a spoil, and to confusion of face, as it is this day.
12246	412	8	And now for a little space grace hath been shewed from the LORD our God, to leave us a remnant to escape, and to give us a nail in his holy place, that our God may lighten our eyes, and give us a little reviving in our bondage.
12247	412	9	For we were bondmen; yet our God hath not forsaken us in our bondage, but hath extended mercy unto us in the sight of the kings of Persia, to give us a reviving, to set up the house of our God, and to repair the desolations thereof, and to give us a wall in Judah and in Jerusalem.
12248	412	10	And now, O our God, what shall we say after this? for we have forsaken thy commandments,
12249	412	11	Which thou hast commanded by thy servants the prophets, saying, The land, unto which ye go to possess it, is an unclean land with the filthiness of the people of the lands, with their abominations, which have filled it from one end to another with their uncleanness.
12250	412	12	Now therefore give not your daughters unto their sons, neither take their daughters unto your sons, nor seek their peace or their wealth for ever: that ye may be strong, and eat the good of the land, and leave it for an inheritance to your children for ever.
12251	412	13	And after all that is come upon us for our evil deeds, and for our great trespass, seeing that thou our God hast punished us less than our iniquities deserve, and hast given us such deliverance as this;
12252	412	14	Should we again break thy commandments, and join in affinity with the people of these abominations? wouldest not thou be angry with us till thou hadst consumed us, so that there should be no remnant nor escaping?
12253	412	15	O LORD God of Israel, thou art righteous: for we remain yet escaped, as it is this day: behold, we are before thee in our trespasses: for we cannot stand before thee because of this.
12254	413	1	NOW when Ezra had prayed, and when he had confessed, weeping and casting himself down before the house of God, there assembled unto him out of Israel a very great congregation of men and women and children: for the people wept very sore.
12255	413	2	And Shechaniah the son of Jehiel, one of the sons of Elam, answered and said unto Ezra, We have trespassed against our God, and have taken strange wives of the people of the land: yet now there is hope in Israel concerning this thing.
12256	413	3	Now therefore let us make a covenant with our God to put away all the wives, and such as are born of them, according to the counsel of my lord, and of those that tremble at the commandment of our God; and let it be done according to the law.
12257	413	4	Arise; for this matter belongeth unto thee: we also will be with thee: be of good courage, and do it.
12258	413	5	Then arose Ezra, and made the chief priests, the Levites, and all Israel, to swear that they should do according to this word. And they sware.
12259	413	6	Then Ezra rose up from before the house of God, and went into the chamber of Johanan the son of Eliashib: and when he came thither, he did eat no bread, nor drink water: for he mourned because of the transgression of them that had been carried away.
12260	413	7	And they made proclamation throughout Judah and Jerusalem unto all the children of the captivity, that they should gather themselves together unto Jerusalem;
12261	413	8	And that whosoever would not come within three days, according to the counsel of the princes and the elders, all his substance should be forfeited, and himself separated from the congregation of those that had been carried away.
12262	413	9	Then all the men of Judah and Benjamin gathered themselves together unto Jerusalem within three days. It was the ninth month, on the twentieth day of the month; and all the people sat in the street of the house of God, trembling because of this matter, and for the great rain.
12263	413	10	And Ezra the priest stood up, and said unto them, Ye have transgressed, and have taken strange wives, to increase the trespass of Israel.
12264	413	11	Now therefore make confession unto the LORD God of your fathers, and do his pleasure: and separate yourselves from the people of the land, and from the strange wives.
12265	413	12	Then all the congregation answered and said with a loud voice, As thou hast said, so must we do.
12266	413	13	But the people are many, and it is a time of much rain, and we are not able to stand without, neither is this a work of one day or two: for we are many that have transgressed in this thing.
12267	413	14	Let now our rulers of all the congregation stand, and let all them which have taken strange wives in our cities come at appointed times, and with them the elders of every city, and the judges thereof, until the fierce wrath of our God for this matter be turned from us.
12268	413	15	Only Jonathan the son of Asahel and Jahaziah the son of Tikvah were employed about this matter: and Meshullam and Shabbethai the Levite helped them.
12269	413	16	And the children of the captivity did so. And Ezra the priest, with certain chief of the fathers, after the house of their fathers, and all of them by their names, were separated, and sat down in the first day of the tenth month to examine the matter.
12270	413	17	And they made an end with all the men that had taken strange wives by the first day of the first month.
12271	413	18	And among the sons of the priests there were found that had taken strange wives: namely, of the sons of Jeshua the son of Jozadak, and his brethren; Maaseiah, and Eliezer, and Jarib, and Gedaliah.
12272	413	19	And they gave their hands that they would put away their wives; and being guilty, they offered a ram of the flock for their trespass.
12273	413	20	And of the sons of Immer; Hanani, and Zebadiah.
12274	413	21	And of the sons of Harim; Maaseiah, and Elijah, and Shemaiah, and Jehiel, and Uzziah.
12275	413	22	And of the sons of Pashur; Elioenai, Maaseiah, Ishmael, Nethaneel, Jozabad, and Elasah.
12276	413	23	Also of the Levites; Jozabad, and Shimei, and Kelaiah, (the same is Kelita,) Pethahiah, Judah, and Eliezer.
12277	413	24	Of the singers also; Eliashib: and of the porters; Shallum, and Telem, and Uri.
12278	413	25	Moreover of Israel: of the sons of Parosh; Ramiah, and Jeziah, and Malchiah, and Miamin, and Eleazar, and Malchijah, and Benaiah.
12279	413	26	And of the sons of Elam; Mattaniah, Zechariah, and Jehiel, and Abdi, and Jeremoth, and Eliah.
12280	413	27	And of the sons of Zattu; Elioenai, Eliashib, Mattaniah, and Jeremoth, and Zabad, and Aziza.
12281	413	28	Of the sons also of Bebai; Jehohanan, Hananiah, Zabbai, and Athlai.
12282	413	29	And of the sons of Bani; Meshullam, Malluch, and Adaiah, Jashub, and Sheal, and Ramoth.
12283	413	30	And of the sons of Pahath-moab; Adna, and Chelal, Benaiah, Maaseiah, Mattaniah, Bezaleel, and Binnui, and Manasseh.
12284	413	31	And of the sons of Harim; Eliezer, Ishijah, Malchiah, Shemaiah, Shimeon,
12285	413	32	Benjamin, Malluch, and Shemariah.
12286	413	33	Of the sons of Hashum; Mattenai, Mattathah, Zabad, Eliphelet, Jeremai, Manasseh, and Shimei.
12287	413	34	Of the sons of Bani; Maadai, Amram, and Uel,
12288	413	35	Benaiah, Bedeiah, Chelluh,
12289	413	36	Vaniah, Meremoth, Eliashib,
12290	413	37	Mattaniah, Mattenai, and Jaasau,
12291	413	38	And Bani, and Binnui, Shimei,
12292	413	39	And Shelemiah, and Nathan, and Adaiah,
12293	413	40	Machnadebai, Shashai, Sharai,
12294	413	41	Azareel, and Shelemiah, Shemariah,
12295	413	42	Shallum, Amariah, and Joseph.
12296	413	43	Of the sons of Nebo; Jeiel, Mattithiah, Zabad, Zebina, Jadau, and Joel, Benaiah.
12297	413	44	All these had taken strange wives: and some of them had wives by whom they had children.
12298	414	1	THE words of Nehemiah the son of Hachaliah. And it came to pass in the month Chisleu, in the twentieth year, as I was in Shushan the palace,
12299	414	2	That Hanani, one of my brethren, came, he and certain men of Judah; and I asked them concerning the Jews that had escaped, which were left of the captivity, and concerning Jerusalem.
12300	414	3	And they said unto me, The remnant that are left of the captivity there in the province are in great affliction and reproach: the wall of Jerusalem also is broken down, and the gates thereof are burned with fire.
12301	414	4	And it came to pass, when I heard these words, that I sat down and wept, and mourned certain days, and fasted, and prayed before the God of heaven,
12302	414	5	And said, I beseech thee, O LORD God of heaven, the great and terrible God, that keepeth covenant and mercy for them that love him and observe his commandments:
12303	414	6	Let thine ear now be attentive, and thine eyes open, that thou mayest hear the prayer of thy servant, which I pray before thee now, day and night, for the children of Israel thy servants, and confess the sins of the children of Israel, which we have sinned against thee: both I and my father's house have sinned.
12304	414	7	We have dealt very corruptly against thee, and have not kept the commandments, nor the statutes, nor the judgments, which thou commandedst thy servant Moses.
12305	414	8	Remember, I beseech thee, the word that thou commandedst thy servant Moses, saying, If ye transgress, I will scatter you abroad among the nations:
12306	414	9	But if ye turn unto me, and keep my commandments, and do them; though there were of you cast out unto the uttermost part of the heaven, yet will I gather them from thence, and will bring them unto the place that I have chosen to set my name there.
12307	414	10	Now these are thy servants and thy people, whom thou hast redeemed by thy great power, and by thy strong hand.
12308	414	11	O Lord, I beseech thee, let now thine ear be attentive to the prayer of thy servant, and to the prayer of thy servants, who desire to fear thy name: and prosper, I pray thee, thy servant this day, and grant him mercy in the sight of this man. For I was the king's cupbearer.
12309	415	1	AND it came to pass in the month Nisan, in the twentieth year of Artaxerxes the king, that wine was before him: and I took up the wine, and gave it unto the king. Now I had not been beforetime sad in his presence.
12310	415	2	Wherefore the king said unto me, Why is thy countenance sad, seeing thou art not sick? this is nothing else but sorrow of heart. Then I was very sore afraid,
12311	415	3	And said unto the king, Let the king live for ever: why should not my countenance be sad, when the city, the place of my fathers' sepulchres, lieth waste, and the gates thereof are consumed with fire?
12312	415	4	Then the king said unto me, For what dost thou make request? So I prayed to the God of heaven.
12313	415	5	And I said unto the king, If it please the king, and if thy servant have found favour in thy sight, that thou wouldest send me unto Judah, unto the city of my fathers' sepulchres, that I may build it.
12314	415	6	And the king said unto me, (the queen also sitting by him,) For how long shall thy journey be? and when wilt thou return? So it pleased the king to send me; and I set him a time.
12315	415	7	Moreover I said unto the king, If it please the king, let letters be given me to the governors beyond the river, that they may convey me over till I come into Judah;
12316	415	8	And a letter unto Asaph the keeper of the king's forest, that he may give me timber to make beams for the gates of the palace which appertained to the house, and for the wall of the city, and for the house that I shall enter into. And the king granted me, according to the good hand of my God upon me.
12317	415	9	Then I came to the governors beyond the river, and gave them the king's letters. Now the king had sent captains of the army and horsemen with me.
12318	415	10	When Sanballat the Horonite, and Tobiah the servant, the Ammonite, heard of it, it grieved them exceedingly that there was come a man to seek the welfare of the children of Israel.
12319	415	11	So I came to Jerusalem, and was there three days.
12320	415	12	And I arose in the night, I and some few men with me; neither told I any man what my God had put in my heart to do at Jerusalem: neither was there any beast with me, save the beast that I rode upon.
12321	415	13	And I went out by night by the gate of the valley, even before the dragon well, and to the dung port, and viewed the walls of Jerusalem, which were broken down, and the gates thereof were consumed with fire.
12322	415	14	Then I went on to the gate of the fountain, and to the king's pool: but there was no place for the beast that was under me to pass.
12323	415	15	Then went I up in the night by the brook, and viewed the wall, and turned back, and entered by the gate of the valley, and so returned.
12324	415	16	And the rulers knew not whither I went, or what I did; neither had I as yet told it to the Jews, nor to the priests, nor to the nobles, nor to the rulers, nor to the rest that did the work.
12325	415	17	Then said I unto them, Ye see the distress that we are in, how Jerusalem lieth waste, and the gates thereof are burned with fire: come, and let us build up the wall of Jerusalem, that we be no more a reproach.
12326	415	18	Then I told them of the hand of my God which was good upon me; as also the king's words that he had spoken unto me. And they said, Let us rise up and build. So they strengthened their hands for this good work.
12327	415	19	But when Sanballat the Horonite, and Tobiah the servant, the Ammonite, and Geshem the Arabian, heard it, they laughed us to scorn, and despised us, and said, What is this thing that ye do? will ye rebel against the king?
12328	415	20	Then answered I them, and said unto them, The God of heaven, he will prosper us; therefore we his servants will arise and build: but ye have no portion, nor right, nor memorial, in Jerusalem.
12329	416	1	THEN Eliashib the high priest rose up with his brethren the priests, and they builded the sheep gate; they sanctified it, and set up the doors of it; even unto the tower of Meah they sanctified it, unto the tower of Hananeel.
12330	416	2	And next unto him builded the men of Jericho. And next to them builded Zaccur the son of Imri.
12331	416	3	But the fish gate did the sons of Hassenaah build, who also laid the beams thereof, and set up the doors thereof, the locks thereof, and the bars thereof.
12332	416	4	And next unto them repaired Meremoth the son of Urijah, the son of Koz. And next unto them repaired Meshullam the son of Berechiah, the son of Meshezabeel. And next unto them repaired Zadok the son of Baana.
12333	416	5	And next unto them the Tekoites repaired; but their nobles put not their necks to the work of their Lord.
12334	416	6	Moreover the old gate repaired Jehoiada the son of Paseah, and Meshullam the son of Besodeiah; they laid the beams thereof, and set up the doors thereof, and the locks thereof, and the bars thereof.
12335	416	7	And next unto them repaired Melatiah the Gibeonite, and Jadon the Meronothite, the men of Gibeon, and of Mizpah, unto the throne of the governor on this side the river.
12336	416	8	Next unto him repaired Uzziel the son of Harhaiah, of the goldsmiths. Next unto him also repaired Hananiah the son of one of the apothecaries, and they fortified Jerusalem unto the broad wall.
12337	416	9	And next unto them repaired Rephaiah the son of Hur, the ruler of the half part of Jerusalem.
12338	416	10	And next unto them repaired Jedaiah the son of Harumaph, even over against his house. And next unto him repaired Hattush the son of Hashabniah.
12339	416	11	Malchijah the son of Harim, and Hashub the son of Pahath-moab, repaired the other piece, and the tower of the furnaces.
12340	416	12	And next unto him repaired Shallum the son of Halohesh, the ruler of the half part of Jerusalem, he and his daughters.
12341	416	13	The valley gate repaired Hanun, and the inhabitants of Zanoah; they built it, and set up the doors thereof, the locks thereof, and the bars thereof, and a thousand cubits on the wall unto the dung gate.
12342	416	14	But the dung gate repaired Malchiah the son of Rechab, the ruler of part of Beth-haccerem; he built it, and set up the doors thereof, the locks thereof, and the bars thereof.
12343	416	15	But the gate of the fountain repaired Shallun the son of Col-hozeh, the ruler of part of Mizpah; he built it, and covered it, and set up the doors thereof, the locks thereof, and the bars thereof, and the wall of the pool of Siloah by the king's garden, and unto the stairs that go down from the city of David.
12344	416	16	After him repaired Nehemiah the son of Azbuk, the ruler of the half part of Beth-zur, unto the place over against the sepulchres of David, and to the pool that was made, and unto the house of the mighty.
12345	416	17	After him repaired the Levites, Rehum the son of Bani. Next unto him repaired Hashabiah, the ruler of the half part of Keilah, in his part.
12346	416	18	After him repaired their brethren, Bavai the son of Henadad, the ruler of the half part of Keilah.
12347	416	19	And next to him repaired Ezer the son of Jeshua, the ruler of Mizpah, another piece over against the going up to the armoury at the turning of the wall.
12348	416	20	After him Baruch the son of Zabbai earnestly repaired the other piece, from the turning of the wall unto the door of the house of Eliashib the high priest.
12349	416	21	After him repaired Meremoth the son of Urijah the son of Koz another piece, from the door of the house of Eliashib even to the end of the house of Eliashib.
12350	416	22	And after him repaired the priests, the men of the plain.
12351	416	23	After him repaired Benjamin and Hashub over against their house. After him repaired Azariah the son of Maaseiah the son of Ananiah by his house.
12352	416	24	After him repaired Binnui the son of Henadad another piece, from the house of Azariah unto the turning of the wall, even unto the corner.
12353	416	25	Palal the son of Uzai, over against the turning of the wall, and the tower which lieth out from the king's high house, that was by the court of the prison. After him Pedaiah the son of Parosh.
12354	416	26	Moreover the Nethinims dwelt in Ophel, unto the place over against the water gate toward the east, and the tower that lieth out.
12355	416	27	After them the Tekoites repaired another piece, over against the great tower that lieth out, even unto the wall of Ophel.
12356	416	28	From above the horse gate repaired the priests, every one over against his house.
12357	416	29	After them repaired Zadok the son of Immer over against his house. After him repaired also Shemaiah the son of Shechaniah, the keeper of the east gate.
12358	416	30	After him repaired Hananiah the son of Shelemiah, and Hanun the sixth son of Zalaph, another piece. After him repaired Meshullam the son of Berechiah over against his chamber.
12359	416	31	After him repaired Malchiah the goldsmith's son unto the place of the Nethinims, and of the merchants, over against the gate Miphkad, and to the going up of the corner.
12360	416	32	And between the going up of the corner unto the sheep gate repaired the goldsmiths and the merchants.
12361	417	1	BUT it came to pass, that when Sanballat heard that we builded the wall, he was wroth, and took great indignation, and mocked the Jews.
12362	417	2	And he spake before his brethren and the army of Samaria, and said, What do these feeble Jews? will they fortify themselves? will they sacrifice? will they make an end in a day? will they revive the stones out of the heaps of the rubbish which are burned?
12363	417	3	Now Tobiah the Ammonite was by him, and he said, Even that which they build, if a fox go up, he shall even break down their stone wall.
12364	417	4	Hear, O our God; for we are despised: and turn their reproach upon their own head, and give them for a prey in the land of captivity:
12365	417	5	And cover not their iniquity, and let not their sin be blotted out from before thee: for they have provoked thee to anger before the builders.
12366	417	6	So built we the wall; and all the wall was joined together unto the half thereof: for the people had a mind to work.
12367	417	7	But it came to pass, that when Sanballat, and Tobiah, and the Arabians, and the Ammonites, and the Ashdodites, heard that the walls of Jerusalem were made up, and that the breaches began to be stopped, then they were very wroth,
12368	417	8	And conspired all of them together to come and to fight against Jerusalem, and to hinder it.
12369	417	9	Nevertheless we made our prayer unto our God, and set a watch against them day and night, because of them.
12370	417	10	And Judah said, The strength of the bearers of burdens is decayed, and there is much rubbish; so that we are not able to build the wall.
12371	417	11	And our adversaries said, They shall not know, neither see, till we come in the midst among them, and slay them, and cause the work to cease.
12372	417	12	And it came to pass, that when the Jews which dwelt by them came, they said unto us ten times, From all places whence ye shall return unto us they will be upon you.
12373	417	13	Therefore set I in the lower places behind the wall, and on the higher places, I even set the people after their families with their swords, their spears, and their bows.
12374	417	14	And I looked, and rose up, and said unto the nobles, and to the rulers, and to the rest of the people, Be not ye afraid of them: remember the Lord, which is great and terrible, and fight for your brethren, your sons, and your daughters, your wives, and your houses.
12375	417	15	And it came to pass, when our enemies heard that it was known unto us, and God had brought their counsel to nought, that we returned all of us to the wall, every one unto his work.
12376	417	16	And it came to pass from that time forth, that the half of my servants wrought in the work, and the other half of them held both the spears, the shields, and the bows, and the habergeons; and the rulers were behind all the house of Judah.
12377	417	17	They which builded on the wall, and they that bare burdens, with those that laded, every one with one of his hands wrought in the work, and with the other hand held a weapon.
12378	417	18	For the builders, every one had his sword girded by his side, and so builded. And he that sounded the trumpet was by me.
12379	417	19	And I said unto the nobles, and to the rulers, and to the rest of the people, The work is great and large, and we are separated upon the wall, one far from another.
12380	417	20	In what place therefore ye hear the sound of the trumpet, resort ye thither unto us: our God shall fight for us.
12381	417	21	So we laboured in the work: and half of them held the spears from the rising of the morning till the stars appeared.
12382	417	22	Likewise at the same time said I unto the people, Let every one with his servant lodge within Jerusalem, that in the night they may be a guard to us, and labour on the day.
12383	417	23	So neither I, nor my brethren, nor my servants, nor the men of the guard which followed me, none of us put off our clothes, saving that every one put them off for washing.
12384	418	1	AND there was a great cry of the people and of their wives against their brethren the Jews.
12385	418	2	For there were that said, We, our sons, and our daughters, are many: therefore we take up corn for them, that we may eat, and live.
12386	418	3	Some also there were that said, We have mortgaged our lands, vineyards, and houses, that we might buy corn, because of the dearth.
12387	418	4	There were also that said, We have borrowed money for the king's tribute, and that upon our lands and vineyards.
12388	418	5	Yet now our flesh is as the flesh of our brethren, our children as their children: and, lo, we bring into bondage our sons and our daughters to be servants, and some of our daughters are brought unto bondage already: neither is it in our power to redeem them; for other men have our lands and vineyards.
12389	418	6	And I was very angry when I heard their cry and these words.
12390	418	7	Then I consulted with myself, and I rebuked the nobles, and the rulers, and said unto them, Ye exact usury, every one of his brother. And I set a great assembly against them.
12391	418	8	And I said unto them, We after our ability have redeemed our brethren the Jews, which were sold unto the heathen; and will ye even sell your brethren? or shall they be sold unto us? Then held they their peace, and found nothing to answer.
12392	418	9	Also I said, It is not good that ye do: ought ye not to walk in the fear of our God because of the reproach of the heathen our enemies?
12393	418	10	I likewise, and my brethren, and my servants, might exact of them money and corn: I pray you, let us leave off this usury.
12394	418	11	Restore, I pray you, to them, even this day, their lands, their vineyards, their oliveyards, and their houses, also the hundredth part of the money, and of the corn, the wine, and the oil, that ye exact of them.
12395	418	12	Then said they, We will restore them, and will require nothing of them; so will we do as thou sayest. Then I called the priests, and took an oath of them, that they should do according to this promise.
12396	418	13	Also I shook my lap, and said, So God shake out every man from his house, and from his labour, that performeth not this promise, even thus be he shaken out, and emptied. And all the congregation said, Amen, and praised the LORD. And the people did according to this promise.
12397	418	14	Moreover from the time that I was appointed to be their governor in the land of Judah, from the twentieth year even unto the two and thirtieth year of Artaxerxes the king, that is, twelve years, I and my brethren have not eaten the bread of the governor.
12398	418	15	But the former governors that had been before me were chargeable unto the people, and had taken of them bread and wine, beside forty shekels of silver; yea, even their servants bare rule over the people: but so did not I, because of the fear of God.
12399	418	16	Yea, also I continued in the work of this wall, neither bought we any land: and all my servants were gathered thither unto the work.
12400	418	17	Moreover there were at my table an hundred and fifty of the Jews and rulers, beside those that came unto us from among the heathen that are about us.
12401	418	18	Now that which was prepared for me daily was one ox and six choice sheep; also fowls were prepared for me, and once in ten days store of all sorts of wine: yet for all this required not I the bread of the governor, because the bondage was heavy upon this people.
12402	418	19	Think upon me, my God, for good, according to all that I have done for this people.
12403	419	1	NOW it came to pass, when Sanballat, and Tobiah, and Geshem the Arabian, and the rest of our enemies, heard that I had builded the wall, and that there was no breach left therein; (though at that time I had not set up the doors upon the gates;)
12404	419	2	That Sanballat and Geshem sent unto me, saying, Come, let us meet together in some one of the villages in the plain of Ono. But they thought to do me mischief.
12405	419	3	And I sent messengers unto them, saying, I am doing a great work, so that I cannot come down: why should the work cease, whilst I leave it, and come down to you?
12406	419	4	Yet they sent unto me four times after this sort; and I answered them after the same manner.
12407	419	5	Then sent Sanballat his servant unto me in like manner the fifth time with an open letter in his hand;
12408	419	6	Wherein was written, It is reported among the heathen, and Gashmu saith it, that thou and the Jews think to rebel: for which cause thou buildest the wall, that thou mayest be their king, according to these words.
12409	419	7	And thou hast also appointed prophets to preach of thee at Jerusalem, saying, There is a king in Judah: and now shall it be reported to the king according to these words. Come now therefore, and let us take counsel together.
12410	419	8	Then I sent unto him, saying, There are no such things done as thou sayest, but thou feignest them out of thine own heart.
12411	419	9	For they all made us afraid, saying, Their hands shall be weakened from the work, that it be not done. Now therefore, O God, strengthen my hands.
12412	419	10	Afterward I came unto the house of Shemaiah the son of Delaiah the son of Mehetabeel, who was shut up; and he said, Let us meet together in the house of God, within the temple, and let us shut the doors of the temple: for they will come to slay thee; yea, in the night will they come to slay thee.
12413	419	11	And I said, Should such a man as I flee? and who is there, that, being as I am, would go into the temple to save his life? I will not go in.
12414	419	12	And, lo, I perceived that God had not sent him; but that he pronounced this prophecy against me: for Tobiah and Sanballat had hired him.
12415	419	13	Therefore was he hired, that I should be afraid, and do so, and sin, and that they might have matter for an evil report, that they might reproach me.
12416	419	14	My God, think thou upon Tobiah and Sanballat according to these their works, and on the prophetess Noadiah, and the rest of the prophets, that would have put me in fear.
12417	419	15	So the wall was finished in the twenty and fifth day of the month Elul, in fifty and two days.
12418	419	16	And it came to pass, that when all our enemies heard thereof, and all the heathen that were about us saw these things, they were much cast down in their own eyes: for they perceived that this work was wrought of our God.
12419	419	17	Moreover in those days the nobles of Judah sent many letters unto Tobiah, and the letters of Tobiah came unto them.
12420	419	18	For there were many in Judah sworn unto him, because he was the son in law of Shechaniah the son of Arah; and his son Johanan had taken the daughter of Meshullam the son of Berechiah.
12421	419	19	Also they reported his good deeds before me, and uttered my words to him. And Tobiah sent letters to put me in fear.
12422	420	1	NOW it came to pass, when the wall was built, and I had set up the doors, and the porters and the singers and the Levites were appointed,
12423	420	2	That I gave my brother Hanani, and Hananiah the ruler of the palace, charge over Jerusalem: for he was a faithful man, and feared God above many.
12424	420	3	And I said unto them, Let not the gates of Jerusalem be opened until the sun be hot; and while they stand by, let them shut the doors, and bar them: and appoint watches of the inhabitants of Jerusalem, every one in his watch, and every one to be over against his house.
12425	420	4	Now the city was large and great: but the people were few therein, and the houses were not builded.
12426	420	5	And my God put into mine heart to gather together the nobles, and the rulers, and the people, that they might be reckoned by genealogy. And I found a register of the genealogy of them which came up at the first, and found written therein,
12427	420	6	These are the children of the province, that went up out of the captivity, of those that had been carried away, whom Nebuchadnezzar the king of Babylon had carried away, and came again to Jerusalem and to Judah, every one unto his city;
12428	420	7	Who came with Zerubbabel, Jeshua, Nehemiah, Azariah, Raamiah, Nahamani, Mordecai, Bilshan, Mispereth, Bigvai, Nehum, Baanah. The number, I say, of the men of the people of Israel was this;
12429	420	8	The children of Parosh, two thousand an hundred seventy and two.
12430	420	9	The children of Shephatiah, three hundred seventy and two.
12431	420	10	The children of Arah, six hundred fifty and two.
12432	420	11	The children of Pahath-moab, of the children of Jeshua and Joab, two thousand and eight hundred and eighteen.
12433	420	12	The children of Elam, a thousand two hundred fifty and four.
12434	420	13	The children of Zattu, eight hundred forty and five.
12435	420	14	The children of Zaccai, seven hundred and threescore.
12436	420	15	The children of Binnui, six hundred forty and eight.
12437	420	16	The children of Bebai, six hundred twenty and eight.
12438	420	17	The children of Azgad, two thousand three hundred twenty and two.
12439	420	18	The children of Adonikam, six hundred threescore and seven.
12440	420	19	The children of Bigvai, two thousand threescore and seven.
12441	420	20	The children of Adin, six hundred fifty and five.
12442	420	21	The children of Ater of Hezekiah, ninety and eight.
12443	420	22	The children of Hashum, three hundred twenty and eight.
12444	420	23	The children of Bezai, three hundred twenty and four.
12445	420	24	The children of Hariph, an hundred and twelve.
12446	420	25	The children of Gibeon, ninety and five.
12447	420	26	The men of Beth-lehem and Netophah, an hundred fourscore and eight.
12448	420	27	The men of Anathoth, an hundred twenty and eight.
12449	420	28	The men of Beth-azmaveth, forty and two.
12450	420	29	The men of Kirjath-jearim, Chephirah, and Beeroth, seven hundred forty and three.
12451	420	30	The men of Ramah and Geba, six hundred twenty and one.
12452	420	31	The men of Michmas, an hundred and twenty and two.
12453	420	32	The men of Beth-el and Ai, an hundred twenty and three.
12454	420	33	The men of the other Nebo, fifty and two.
12455	420	34	The children of the other Elam, a thousand two hundred fifty and four.
12456	420	35	The children of Harim, three hundred and twenty.
12457	420	36	The children of Jericho, three hundred forty and five.
12458	420	37	The children of Lod, Hadid, and Ono, seven hundred twenty and one.
12459	420	38	The children of Senaah, three thousand nine hundred and thirty.
12460	420	39	The priests: the children of Jedaiah, of the house of Jeshua, nine hundred seventy and three.
12461	420	40	The children of Immer, a thousand fifty and two.
12462	420	41	The children of Pashur, a thousand two hundred forty and seven.
12463	420	42	The children of Harim, a thousand and seventeen.
12464	420	43	The Levites: the children of Jeshua, of Kadmiel, and of the children of Hodevah, seventy and four.
12465	420	44	The singers: the children of Asaph, an hundred forty and eight.
12466	420	45	The porters: the children of Shallum, the children of Ater, the children of Talmon, the children of Akkub, the children of Hatita, the children of Shobai, an hundred thirty and eight.
12467	420	46	The Nethinims: the children of Ziha, the children of Hashupha, the children of Tabbaoth,
12468	420	47	The children of Keros, the children of Sia, the children of Padon,
12469	420	48	The children of Lebana, the children of Hagaba, the children of Shalmai,
12470	420	49	The children of Hanan, the children of Giddel, the children of Gahar,
12471	420	50	The children of Reaiah, the children of Rezin, the children of Nekoda,
12472	420	51	The children of Gazzam, the children of Uzza, the children of Phaseah,
12473	420	52	The children of Besai, the children of Meunim, the children of Nephishesim,
12474	420	53	The children of Bakbuk, the children of Hakupha, the children of Harhur,
12475	420	54	The children of Bazlith, the children of Mehida, the children of Harsha,
12476	420	55	The children of Barkos, the children of Sisera, the children of Tamah,
12477	420	56	The children of Neziah, the children of Hatipha.
12478	420	57	The children of Solomon's servants: the children of Sotai, the children of Sophereth, the children of Perida,
12479	420	58	The children of Jaala, the children of Darkon, the children of Giddel,
12480	420	59	The children of Shephatiah, the children of Hattil, the children of Pochereth of Zebaim, the children of Amon.
12481	420	60	All the Nethinims, and the children of Solomon's servants, were three hundred ninety and two.
12482	420	61	And these were they which went up also from Tel-melah, Tel-haresha, Cherub, Addon, and Immer: but they could not shew their father's house, nor their seed, whether they were of Israel.
12483	420	62	The children of Delaiah, the children of Tobiah, the children of Nekoda, six hundred forty and two.
12484	420	63	And of the priests: the children of Habaiah, the children of Koz, the children of Barzillai, which took one of the daughters of Barzillai the Gileadite to wife, and was called after their name.
12485	420	64	These sought their register among those that were reckoned by genealogy, but it was not found: therefore were they, as polluted, put from the priesthood.
12486	420	65	And the Tirshatha said unto them, that they should not eat of the most holy things, till there stood up a priest with Urim and Thummim.
12487	420	66	The whole congregation together was forty and two thousand three hundred and threescore,
12488	420	67	Beside their manservants and their maidservants, of whom there were seven thousand three hundred thirty and seven: and they had two hundred forty and five singing men and singing women.
12489	420	68	Their horses, seven hundred thirty and six: their mules, two hundred forty and five:
12490	420	69	Their camels, four hundred thirty and five: six thousand seven hundred and twenty asses.
12491	420	70	And some of the chief of the fathers gave unto the work. The Tirshatha gave to the treasure a thousand drams of gold, fifty basons, five hundred and thirty priests' garments.
12492	420	71	And some of the chief of the fathers gave to the treasure of the work twenty thousand drams of gold, and two thousand and two hundred pound of silver.
12493	420	72	And that which the rest of the people gave was twenty thousand drams of gold, and two thousand pound of silver, and threescore and seven priests' garments.
12494	420	73	So the priests, and the Levites, and the porters, and the singers, and some of the people, and the Nethinims, and all Israel, dwelt in their cities; and when the seventh month came, the children of Israel were in their cities.
12495	421	1	AND all the people gathered themselves together as one man into the street that was before the water gate; and they spake unto Ezra the scribe to bring the book of the law of Moses, which the LORD had commanded to Israel.
12496	421	2	And Ezra the priest brought the law before the congregation both of men and women, and all that could hear with understanding, upon the first day of the seventh month.
12497	421	3	And he read therein before the street that was before the water gate from the morning until midday, before the men and the women, and those that could understand; and the ears of all the people were attentive unto the book of the law.
12498	421	4	And Ezra the scribe stood upon a pulpit of wood, which they had made for the purpose; and beside him stood Mattithiah, and Shema, and Anaiah, and Urijah, and Hilkiah, and Maaseiah, on his right hand; and on his left hand, Pedaiah, and Mishael, and Malchiah, and Hashum, and Hashbadana, Zechariah, and Meshullam.
12499	421	5	And Ezra opened the book in the sight of all the people; (for he was above all the people;) and when he opened it, all the people stood up:
12500	421	6	And Ezra blessed the LORD, the great God. And all the people answered, Amen, Amen, with lifting up their hands: and they bowed their heads, and worshipped the LORD with their faces to the ground.
12501	421	7	Also Jeshua, and Bani, and Sherebiah, Jamin, Akkub, Shabbethai, Hodijah, Maaseiah, Kelita, Azariah, Jozabad, Hanan, Pelaiah, and the Levites, caused the people to understand the law: and the people stood in their place.
12502	421	8	So they read in the book in the law of God distinctly, and gave the sense, and caused them to understand the reading.
12503	421	9	And Nehemiah, which is the Tirshatha, and Ezra the priest the scribe, and the Levites that taught the people, said unto all the people, This day is holy unto the LORD your God; mourn not, nor weep. For all the people wept, when they heard the words of the law.
12504	421	10	Then he said unto them, Go your way, eat the fat, and drink the sweet, and send portions unto them for whom nothing is prepared: for this day is holy unto our Lord: neither be ye sorry; for the joy of the LORD is your strength.
12505	421	11	So the Levites stilled all the people, saying, Hold your peace, for the day is holy; neither be ye grieved.
12506	421	12	And all the people went their way to eat, and to drink, and to send portions, and to make great mirth, because they had understood the words that were declared unto them.
12507	421	13	And on the second day were gathered together the chief of the fathers of all the people, the priests, and the Levites, unto Ezra the scribe, even to understand the words of the law.
12508	421	14	And they found written in the law which the LORD had commanded by Moses, that the children of Israel should dwell in booths in the feast of the seventh month:
12509	421	15	And that they should publish and proclaim in all their cities, and in Jerusalem, saying, Go forth unto the mount, and fetch olive branches, and pine branches, and myrtle branches, and palm branches, and branches of thick trees, to make booths, as it is written.
12510	421	16	So the people went forth, and brought them, and made themselves booths, every one upon the roof of his house, and in their courts, and in the courts of the house of God, and in the street of the water gate, and in the street of the gate of Ephraim.
12511	421	17	And all the congregation of them that were come again out of the captivity made booths, and sat under the booths: for since the days of Jeshua the son of Nun unto that day had not the children of Israel done so. And there was very great gladness.
12512	421	18	Also day by day, from the first day unto the last day, he read in the book of the law of God. And they kept the feast seven days; and on the eighth day was a solemn assembly, according unto the manner.
12513	422	1	NOW in the twenty and fourth day of this month the children of Israel were assembled with fasting, and with sackclothes, and earth upon them.
12514	422	2	And the seed of Israel separated themselves from all strangers, and stood and confessed their sins, and the iniquities of their fathers.
12515	422	3	And they stood up in their place, and read in the book of the law of the LORD their God one fourth part of the day; and another fourth part they confessed, and worshipped the LORD their God.
12516	422	4	Then stood up upon the stairs, of the Levites, Jeshua, and Bani, Kadmiel, Shebaniah, Bunni, Sherebiah, Bani, and Chenani, and cried with a loud voice unto the LORD their God.
12517	422	5	Then the Levites, Jeshua, and Kadmiel, Bani, Hashabniah, Sherebiah, Hodijah, Shebaniah, and Pethahiah, said, Stand up and bless the LORD your God for ever and ever: and blessed be thy glorious name, which is exalted above all blessing and praise.
12518	422	6	Thou, even thou, art LORD alone; thou hast made heaven, the heaven of heavens, with all their host, the earth, and all things that are therein, the seas, and all that is therein, and thou preservest them all; and the host of heaven worshippeth thee.
12519	422	7	Thou art the LORD the God, who didst choose Abram, and broughtest him forth out of Ur of the Chaldees, and gavest him the name of Abraham;
12520	422	8	And foundest his heart faithful before thee, and madest a covenant with him to give the land of the Canaanites, the Hittites, the Amorites, and the Perizzites, and the Jebusites, and the Girgashites, to give it, I say, to his seed, and hast performed thy words; for thou art righteous:
12521	422	9	And didst see the affliction of our fathers in Egypt, and heardest their cry by the Red sea;
12522	422	10	And shewedst signs and wonders upon Pharaoh, and on all his servants, and on all the people of his land: for thou knewest that they dealt proudly against them. So didst thou get thee a name, as it is this day.
12523	422	11	And thou didst divide the sea before them, so that they went through the midst of the sea on the dry land; and their persecutors thou threwest into the deeps, as a stone into the mighty waters.
12524	422	12	Moreover thou leddest them in the day by a cloudy pillar; and in the night by a pillar of fire, to give them light in the way wherein they should go.
12525	422	13	Thou camest down also upon mount Sinai, and spakest with them from heaven, and gavest them right judgments, and true laws, good statutes and commandments:
12526	422	14	And madest known unto them thy holy sabbath, and commandedst them precepts, statutes, and laws, by the hand of Moses thy servant:
12527	422	15	And gavest them bread from heaven for their hunger, and broughtest forth water for them out of the rock for their thirst, and promisedst them that they should go in to possess the land which thou hadst sworn to give them.
12528	422	16	But they and our fathers dealt proudly, and hardened their necks, and hearkened not to thy commandments,
12529	422	17	And refused to obey, neither were mindful of thy wonders that thou didst among them; but hardened their necks, and in their rebellion appointed a captain to return to their bondage: but thou art a God ready to pardon, gracious and merciful, slow to anger, and of great kindness, and forsookest them not.
12530	422	18	Yea, when they had made them a molten calf, and said, This is thy God that brought thee up out of Egypt, and had wrought great provocations;
12531	422	19	Yet thou in thy manifold mercies forsookest them not in the wilderness: the pillar of the cloud departed not from them by day, to lead them in the way; neither the pillar of fire by night, to shew them light, and the way wherein they should go.
12532	422	20	Thou gavest also thy good spirit to instruct them, and withheldest not thy manna from their mouth, and gavest them water for their thirst.
12533	422	21	Yea, forty years didst thou sustain them in the wilderness, so that they lacked nothing; their clothes waxed not old, and their feet swelled not.
12534	422	22	Moreover thou gavest them kingdoms and nations, and didst divide them into corners: so they possessed the land of Sihon, and the land of the king of Heshbon, and the land of Og king of Bashan.
12535	422	23	Their children also multipliedst thou as the stars of heaven, and broughtest them into the land, concerning which thou hadst promised to their fathers, that they should go in to possess it.
12536	422	24	So the children went in and possessed the land, and thou subduedst before them the inhabitants of the land, the Canaanites, and gavest them into their hands, with their kings, and the people of the land, that they might do with them as they would.
12537	422	25	And they took strong cities, and a fat land, and possessed houses full of all goods, wells digged, vineyards, and oliveyards, and fruit trees in abundance: so they did eat, and were filled, and became fat, and delighted themselves in thy great goodness.
12538	422	26	Nevertheless they were disobedient, and rebelled against thee, and cast thy law behind their backs, and slew thy prophets which testified against them to turn them to thee, and they wrought great provocations.
12539	422	27	Therefore thou deliveredst them into the hand of their enemies, who vexed them: and in the time of their trouble, when they cried unto thee, thou heardest them from heaven; and according to thy manifold mercies thou gavest them saviours, who saved them out of the hand of their enemies.
12540	422	28	But after they had rest, they did evil again before thee: therefore leftest thou them in the hand of their enemies, so that they had the dominion over them: yet when they returned, and cried unto thee, thou heardest them from heaven; and many times didst thou deliver them according to thy mercies;
12541	422	29	And testifiedst against them, that thou mightest bring them again unto thy law: yet they dealt proudly, and hearkened not unto thy commandments, but sinned against thy judgments, (which if a man do, he shall live in them;) and withdrew the shoulder, and hardened their neck, and would not hear.
12542	422	30	Yet many years didst thou forbear them, and testifiedst against them by thy spirit in thy prophets: yet would they not give ear: therefore gavest thou them into the hand of the people of the lands.
12543	422	31	Nevertheless for thy great mercies' sake thou didst not utterly consume them, nor forsake them; for thou art a gracious and merciful God.
12544	422	32	Now therefore, our God, the great, the mighty, and the terrible God, who keepest covenant and mercy, let not all the trouble seem little before thee, that hath come upon us, on our kings, on our princes, and on our priests, and on our prophets, and on our fathers, and on all thy people, since the time of the kings of Assyria unto this day.
12545	422	33	Howbeit thou art just in all that is brought upon us; for thou hast done right, but we have done wickedly:
12546	422	34	Neither have our kings, our princes, our priests, nor our fathers, kept thy law, nor hearkened unto thy commandments and thy testimonies, wherewith thou didst testify against them.
12547	422	35	For they have not served thee in their kingdom, and in thy great goodness that thou gavest them, and in the large and fat land which thou gavest before them, neither turned they from their wicked works.
12548	422	36	Behold, we are servants this day, and for the land that thou gavest unto our fathers to eat the fruit thereof and the good thereof, behold, we are servants in it:
12549	422	37	And it yieldeth much increase unto the kings whom thou hast set over us because of our sins: also they have dominion over our bodies, and over our cattle, at their pleasure, and we are in great distress.
12550	422	38	And because of all this we make a sure covenant, and write it; and our princes, Levites, and priests, seal unto it.
12551	423	1	NOW those that sealed were, Nehemiah, the Tirshatha, the son of Hachaliah, and Zidkijah,
12552	423	2	Seraiah, Azariah, Jeremiah,
12553	423	3	Pashur, Amariah, Malchijah,
12554	423	4	Hattush, Shebaniah, Malluch,
12555	423	5	Harim, Meremoth, Obadiah,
12556	423	6	Daniel, Ginnethon, Baruch,
12557	423	7	Meshullam, Abijah, Mijamin,
12558	423	8	Maaziah, Bilgai, Shemaiah: these were the priests.
12559	423	9	And the Levites: both Jeshua the son of Azaniah, Binnui of the sons of Henadad, Kadmiel;
12560	423	10	And their brethren, Shebaniah, Hodijah, Kelita, Pelaiah, Hanan,
12561	423	11	Micha, Rehob, Hashabiah,
12562	423	12	Zaccur, Sherebiah, Shebaniah,
12563	423	13	Hodijah, Bani, Beninu.
12564	423	14	The chief of the people; Parosh, Pahath-moab, Elam, Zatthu, Bani,
12565	423	15	Bunni, Azgad, Bebai,
12566	423	16	Adonijah, Bigvai, Adin,
12567	423	17	Ater, Hizkijah, Azzur,
12568	423	18	Hodijah, Hashum, Bezai,
12569	423	19	Hariph, Anathoth, Nebai,
12570	423	20	Magpiash, Meshullam, Hezir,
12571	423	21	Meshezabeel, Zadok, Jaddua,
12572	423	22	Pelatiah, Hanan, Anaiah,
12573	423	23	Hoshea, Hananiah, Hashub,
12574	423	24	Hallohesh, Pileha, Shobek,
12575	423	25	Rehum, Hashabnah, Maaseiah,
12576	423	26	And Ahijah, Hanan, Anan,
12577	423	27	Malluch, Harim, Baanah.
12578	423	28	And the rest of the people, the priests, the Levites, the porters, the singers, the Nethinims, and all they that had separated themselves from the people of the lands unto the law of God, their wives, their sons, and their daughters, every one having knowledge, and having understanding;
12579	423	29	They clave to their brethren, their nobles, and entered into a curse, and into an oath, to walk in God's law, which was given by Moses the servant of God, and to observe and do all the commandments of the LORD our Lord, and his judgments and his statutes;
12580	423	30	And that we would not give our daughters unto the people of the land, nor take their daughters for our sons:
12581	423	31	And if the people of the land bring ware or any victuals on the sabbath day to sell, that we would not buy it of them on the sabbath, or on the holy day: and that we would leave the seventh year, and the exaction of every debt.
12582	423	32	Also we made ordinances for us, to charge ourselves yearly with the third part of a shekel for the service of the house of our God;
12583	423	33	For the shewbread, and for the continual meat offering, and for the continual burnt offering, of the sabbaths, of the new moons, for the set feasts, and for the holy things, and for the sin offerings to make an atonement for Israel, and for all the work of the house of our God.
12584	423	34	And we cast the lots among the priests, the Levites, and the people, for the wood offering, to bring it into the house of our God, after the houses of our fathers, at times appointed year by year, to burn upon the altar of the LORD our God, as it is written in the law:
12585	423	35	And to bring the firstfruits of our ground, and the firstfruits of all fruit of all trees, year by year, unto the house of the LORD:
12586	423	36	Also the firstborn of our sons, and of our cattle, as it is written in the law, and the firstlings of our herds and of our flocks, to bring to the house of our God, unto the priests that minister in the house of our God:
12587	423	37	And that we should bring the firstfruits of our dough, and our offerings, and the fruit of all manner of trees, of wine and of oil, unto the priests, to the chambers of the house of our God; and the tithes of our ground unto the Levites, that the same Levites might have the tithes in all the cities of our tillage.
12588	423	38	And the priest the son of Aaron shall be with the Levites, when the Levites take tithes: and the Levites shall bring up the tithe of the tithes unto the house of our God, to the chambers, into the treasure house.
12589	423	39	For the children of Israel and the children of Levi shall bring the offering of the corn, of the new wine, and the oil, unto the chambers, where are the vessels of the sanctuary, and the priests that minister, and the porters, and the singers: and we will not forsake the house of our God.
12590	424	1	AND the rulers of the people dwelt at Jerusalem: the rest of the people also cast lots, to bring one of ten to dwell in Jerusalem the holy city, and nine parts to dwell in other cities.
12591	424	2	And the people blessed all the men, that willingly offered themselves to dwell at Jerusalem.
12592	424	3	Now these are the chief of the province that dwelt in Jerusalem: but in the cities of Judah dwelt every one in his possession in their cities, to wit, Israel, the priests, and the Levites, and the Nethinims, and the children of Solomon's servants.
12593	424	4	And at Jerusalem dwelt certain of the children of Judah, and of the children of Benjamin. Of the children of Judah; Athaiah the son of Uzziah, the son of Zechariah, the son of Amariah, the son of Shephatiah, the son of Mahalaleel, of the children of Perez;
12594	424	5	And Maaseiah the son of Baruch, the son of Col-hozeh, the son of Hazaiah, the son of Adaiah, the son of Joiarib, the son of Zechariah, the son of Shiloni.
12595	424	6	All the sons of Perez that dwelt at Jerusalem were four hundred threescore and eight valiant men.
12596	424	7	And these are the sons of Benjamin; Sallu the son of Meshullam, the son of Joed, the son of Pedaiah, the son of Kolaiah, the son of Maaseiah, the son of Ithiel, the son of Jesaiah.
12597	424	8	And after him Gabbai, Sallai, nine hundred twenty and eight.
12598	424	9	And Joel the son of Zichri was their overseer: and Judah the son of Senuah was second over the city.
12599	424	10	Of the priests: Jedaiah the son of Joiarib, Jachin.
12600	424	11	Seraiah the son of Hilkiah, the son of Meshullam, the son of Zadok, the son of Meraioth, the son of Ahitub, was the ruler of the house of God.
12601	424	12	And their brethren that did the work of the house were eight hundred twenty and two: and Adaiah the son of Jeroham, the son of Pelaliah, the son of Amzi, the son of Zechariah, the son of Pashur, the son of Malchiah,
12602	424	13	And his brethren, chief of the fathers, two hundred forty and two: and Amashai the son of Azareel, the son of Ahasai, the son of Meshillemoth, the son of Immer,
12603	424	14	And their brethren, mighty men of valour, an hundred twenty and eight: and their overseer was Zabdiel, the son of one of the great men.
12604	424	15	Also of the Levites: Shemaiah the son of Hashub, the son of Azrikam, the son of Hashabiah, the son of Bunni;
12605	424	16	And Shabbethai and Jozabad, of the chief of the Levites, had the oversight of the outward business of the house of God.
12606	424	17	And Mattaniah the son of Micha, the son of Zabdi, the son of Asaph, was the principal to begin the thanksgiving in prayer: and Bakbukiah the second among his brethren, and Abda the son of Shammua, the son of Galal, the son of Jeduthun.
12607	424	18	All the Levites in the holy city were two hundred fourscore and four.
12608	424	19	Moreover the porters, Akkub, Talmon, and their brethren that kept the gates, were an hundred seventy and two.
12609	424	20	And the residue of Israel, of the priests, and the Levites, were in all the cities of Judah, every one in his inheritance.
12610	424	21	But the Nethinims dwelt in Ophel: and Ziha and Gispa were over the Nethinims.
12611	424	22	The overseer also of the Levites at Jerusalem was Uzzi the son of Bani, the son of Hashabiah, the son of Mattaniah, the son of Micha. Of the sons of Asaph, the singers were over the business of the house of God.
12612	424	23	For it was the king's commandment concerning them, that a certain portion should be for the singers, due for every day.
12613	424	24	And Pethahiah the son of Meshezabeel, of the children of Zerah the son of Judah, was at the king's hand in all matters concerning the people.
12614	424	25	And for the villages, with their fields, some of the children of Judah dwelt at Kirjath-arba, and in the villages thereof, and at Dibon, and in the villages thereof, and at Jekabzeel, and in the villages thereof,
12615	424	26	And at Jeshua, and at Moladah, and at Beth-phelet,
12616	424	27	And at Hazar-shual, and at Beer-sheba, and in the villages thereof,
12617	424	28	And at Ziklag, and at Mekonah, and in the villages thereof,
12618	424	29	And at En-rimmon, and at Zareah, and at Jarmuth,
12619	424	30	Zanoah, Adullam, and in their villages, at Lachish, and the fields thereof, at Azekah, and in the villages thereof. And they dwelt from Beer-sheba unto the valley of Hinnom.
12620	424	31	The children also of Benjamin from Geba dwelt at Michmash, and Aija, and Beth-el, and in their villages,
12621	424	32	And at Anathoth, Nob, Ananiah,
12622	424	33	Hazor, Ramah, Gittaim,
12623	424	34	Hadid, Zeboim, Neballat,
12624	424	35	Lod, and Ono, the valley of craftsmen.
12625	424	36	And of the Levites were divisions in Judah, and in Benjamin.
12626	425	1	NOW these are the priests and the Levites that went up with Zerubbabel the son of Shealtiel, and Jeshua: Seraiah, Jeremiah, Ezra,
12627	425	2	Amariah, Malluch, Hattush,
12628	425	3	Shechaniah, Rehum, Meremoth,
12629	425	4	Iddo, Ginnetho, Abijah,
12630	425	5	Miamin, Maadiah, Bilgah,
12631	425	6	Shemaiah, and Joiarib, Jedaiah,
12632	425	7	Sallu, Amok, Hilkiah, Jedaiah. These were the chief of the priests and of their brethren in the days of Jeshua.
12633	425	8	Moreover the Levites: Jeshua, Binnui, Kadmiel, Sherebiah, Judah, and Mattaniah, which was over the thanksgiving, he and his brethren.
12634	425	9	Also Bakbukiah and Unni, their brethren, were over against them in the watches.
12635	425	10	And Jeshua begat Joiakim, Joiakim also begat Eliashib, and Eliashib begat Joiada,
12636	425	11	And Joiada begat Jonathan, and Jonathan begat Jaddua.
12637	425	12	And in the days of Joiakim were priests, the chief of the fathers: of Seraiah, Meraiah; of Jeremiah, Hananiah;
12638	425	13	Of Ezra, Meshullam; of Amariah, Jehohanan;
12639	425	14	Of Melicu, Jonathan; of Shebaniah, Joseph;
12640	425	15	Of Harim, Adna; of Meraioth, Helkai;
12641	425	16	Of Iddo, Zechariah; of Ginnethon, Meshullam;
12642	425	17	Of Abijah, Zichri; of Miniamin, of Moadiah, Piltai;
12643	425	18	Of Bilgah, Shammua; of Shemaiah, Jehonathan;
12644	425	19	And of Joiarib, Mattenai; of Jedaiah, Uzzi;
12645	425	20	Of Sallai, Kallai; of Amok, Eber;
12646	425	21	Of Hilkiah, Hashabiah; of Jedaiah, Nethaneel.
12647	425	22	The Levites in the days of Eliashib, Joiada, and Johanan, and Jaddua, were recorded chief of the fathers: also the priests, to the reign of Darius the Persian.
12648	425	23	The sons of Levi, the chief of the fathers, were written in the book of the chronicles, even until the days of Johanan the son of Eliashib.
12649	425	24	And the chief of the Levites: Hashabiah, Sherebiah, and Jeshua the son of Kadmiel, with their brethren over against them, to praise and to give thanks, according to the commandment of David the man of God, ward over against ward.
12650	425	25	Mattaniah, and Bakbukiah, Obadiah, Meshullam, Talmon, Akkub, were porters keeping the ward at the thresholds of the gates.
12651	425	26	These were in the days of Joiakim the son of Jeshua, the son of Jozadak, and in the days of Nehemiah the governor, and of Ezra the priest, the scribe.
12652	425	27	And at the dedication of the wall of Jerusalem they sought the Levites out of all their places, to bring them to Jerusalem, to keep the dedication with gladness, both with thanksgivings, and with singing, with cymbals, psalteries, and with harps.
12653	425	28	And the sons of the singers gathered themselves together, both out of the plain country round about Jerusalem, and from the villages of Netophathi;
12654	425	29	Also from the house of Gilgal, and out of the fields of Geba and Azmaveth: for the singers had builded them villages round about Jerusalem.
12655	425	30	And the priests and the Levites purified themselves, and purified the people, and the gates, and the wall.
12656	425	31	Then I brought up the princes of Judah upon the wall, and appointed two great companies of them that gave thanks, whereof one went on the right hand upon the wall toward the dung gate:
12657	425	32	And after them went Hoshaiah, and half of the princes of Judah,
12658	425	33	And Azariah, Ezra, and Meshullam,
12659	425	34	Judah, and Benjamin, and Shemaiah, and Jeremiah,
12660	425	35	And certain of the priests' sons with trumpets; namely, Zechariah the son of Jonathan, the son of Shemaiah, the son of Mattaniah, the son of Michaiah, the son of Zaccur, the son of Asaph:
12661	425	36	And his brethren, Shemaiah, and Azarael, Milalai, Gilalai, Maai, Nethaneel, and Judah, Hanani, with the musical instruments of David the man of God, and Ezra the scribe before them.
12662	425	37	And at the fountain gate, which was over against them, they went up by the stairs of the city of David, at the going up of the wall, above the house of David, even unto the water gate eastward.
12663	425	38	And the other company of them that gave thanks went over against them, and I after them, and the half of the people upon the wall, from beyond the tower of the furnaces even unto the broad wall;
12664	425	39	And from above the gate of Ephraim, and above the old gate, and above the fish gate, and the tower of Hananeel, and the tower of Meah, even unto the sheep gate: and they stood still in the prison gate.
12665	425	40	So stood the two companies of them that gave thanks in the house of God, and I, and the half of the rulers with me:
12666	425	41	And the priests; Eliakim, Maaseiah, Miniamin, Michaiah, Elioenai, Zechariah, and Hananiah, with trumpets;
12667	425	42	And Maaseiah, and Shemaiah, and Eleazar, and Uzzi, and Jehohanan, and Malchijah, and Elam, and Ezer. And the singers sang loud, with Jezrahiah their overseer.
12668	425	43	Also that day they offered great sacrifices, and rejoiced: for God had made them rejoice with great joy: the wives also and the children rejoiced: so that the joy of Jerusalem was heard even afar off.
12669	425	44	And at that time were some appointed over the chambers for the treasures, for the offerings, for the firstfruits, and for the tithes, to gather into them out of the fields of the cities the portions of the law for the priests and Levites: for Judah rejoiced for the priests and for the Levites that waited.
12670	425	45	And both the singers and the porters kept the ward of their God, and the ward of the purification, according to the commandment of David, and of Solomon his son.
12671	425	46	For in the days of David and Asaph of old there were chief of the singers, and songs of praise and thanksgiving unto God.
12672	425	47	And all Israel in the days of Zerubbabel, and in the days of Nehemiah, gave the portions of the singers and the porters, every day his portion: and they sanctified holy things unto the Levites; and the Levites sanctified them unto the children of Aaron.
12673	426	1	ON that day they read in the book of Moses in the audience of the people; and therein was found written, that the Ammonite and the Moabite should not come into the congregation of God for ever;
12674	426	2	Because they met not the children of Israel with bread and with water, but hired Balaam against them, that he should curse them: howbeit our God turned the curse into a blessing.
12675	426	3	Now it came to pass, when they had heard the law, that they separated from Israel all the mixed multitude.
12676	426	4	And before this, Eliashib the priest, having the oversight of the chamber of the house of our God, was allied unto Tobiah:
12677	426	5	And he had prepared for him a great chamber, where aforetime they laid the meat offerings, the frankincense, and the vessels, and the tithes of the corn, the new wine, and the oil, which was commanded to be given to the Levites, and the singers, and the porters; and the offerings of the priests.
12678	426	6	But in all this time was not I at Jerusalem: for in the two and thirtieth year of Artaxerxes king of Babylon came I unto the king, and after certain days obtained I leave of the king:
12679	426	7	And I came to Jerusalem, and understood of the evil that Eliashib did for Tobiah, in preparing him a chamber in the courts of the house of God.
12680	426	8	And it grieved me sore: therefore I cast forth all the household stuff of Tobiah out of the chamber.
12681	426	9	Then I commanded, and they cleansed the chambers: and thither brought I again the vessels of the house of God, with the meat offering and the frankincense.
12682	426	10	And I perceived that the portions of the Levites had not been given them: for the Levites and the singers, that did the work, were fled every one to his field.
12683	426	11	Then contended I with the rulers, and said, Why is the house of God forsaken? And I gathered them together, and set them in their place.
12684	426	12	Then brought all Judah the tithe of the corn and the new wine and the oil unto the treasuries.
12685	426	13	And I made treasurers over the treasuries, Shelemiah the priest, and Zadok the scribe, and of the Levites, Pedaiah: and next to them was Hanan the son of Zaccur, the son of Mattaniah: for they were counted faithful, and their office was to distribute unto their brethren.
12686	426	14	Remember me, O my God, concerning this, and wipe not out my good deeds that I have done for the house of my God, and for the offices thereof.
12687	426	15	In those days saw I in Judah some treading wine presses on the sabbath, and bringing in sheaves, and lading asses; as also wine, grapes, and figs, and all manner of burdens, which they brought into Jerusalem on the sabbath day: and I testified against them in the day wherein they sold victuals.
12688	426	16	There dwelt men of Tyre also therein, which brought fish, and all manner of ware, and sold on the sabbath unto the children of Judah, and in Jerusalem.
12689	426	17	Then I contended with the nobles of Judah, and said unto them, What evil thing is this that ye do, and profane the sabbath day?
12690	426	18	Did not your fathers thus, and did not our God bring all this evil upon us, and upon this city? yet ye bring more wrath upon Israel by profaning the sabbath.
12691	426	19	And it came to pass, that when the gates of Jerusalem began to be dark before the sabbath, I commanded that the gates should be shut, and charged that they should not be opened till after the sabbath: and some of my servants set I at the gates, that there should no burden be brought in on the sabbath day.
12692	426	20	So the merchants and sellers of all kind of ware lodged without Jerusalem once or twice.
12693	426	21	Then I testified against them, and said unto them, Why lodge ye about the wall? if ye do so again, I will lay hands on you. From that time forth came they no more on the sabbath.
12694	426	22	And I commanded the Levites that they should cleanse themselves, and that they should come and keep the gates, to sanctify the sabbath day. Remember me, O my God, concerning this also, and spare me according to the greatness of thy mercy.
12695	426	23	In those days also saw I Jews that had married wives of Ashdod, of Ammon, and of Moab:
12696	426	24	And their children spake half in the speech of Ashdod, and could not speak in the Jews' language, but according to the language of each people.
12697	426	25	And I contended with them, and cursed them, and smote certain of them, and plucked off their hair, and made them swear by God, saying, Ye shall not give your daughters unto their sons, nor take their daughters unto your sons, or for yourselves.
12698	426	26	Did not Solomon king of Israel sin by these things? yet among many nations was there no king like him, who was beloved of his God, and God made him king over all Israel: nevertheless even him did outlandish women cause to sin.
12699	426	27	Shall we then hearken unto you to do all this great evil, to transgress against our God in marrying strange wives?
12700	426	28	And one of the sons of Joiada, the son of Eliashib the high priest, was son in law to Sanballat the Horonite: therefore I chased him from me.
12701	426	29	Remember them, O my God, because they have defiled the priesthood, and the covenant of the priesthood, and of the Levites.
12702	426	30	Thus cleansed I them from all strangers, and appointed the wards of the priests and the Levites, every one in his business;
12703	426	31	And for the wood offering, at times appointed, and for the firstfruits. Remember me, O my God, for good.
12704	427	1	NOW it came to pass in the days of Ahasuerus, (this is Ahasuerus which reigned, from India even unto Ethiopia, over an hundred and seven and twenty provinces:)
12705	427	2	That in those days, when the king Ahasuerus sat on the throne of his kingdom, which was in Shushan the palace,
12706	427	3	In the third year of his reign, he made a feast unto all his princes and his servants; the power of Persia and Media, the nobles and princes of the provinces, being before him:
12707	427	4	When he shewed the riches of his glorious kingdom and the honour of his excellent majesty many days, even an hundred and fourscore days.
12708	427	5	And when these days were expired, the king made a feast unto all the people that were present in Shushan the palace, both unto great and small, seven days, in the court of the garden of the king's palace;
12709	427	6	Where were white, green, and blue, hangings, fastened with cords of fine linen and purple to silver rings and pillars of marble: the beds were of gold and silver, upon a pavement of red, and blue, and white, and black, marble.
12710	427	7	And they gave them drink in vessels of gold, (the vessels being diverse one from another,) and royal wine in abundance, according to the state of the king.
12711	427	8	And the drinking was according to the law; none did compel: for so the king had appointed to all the officers of his house, that they should do according to every man's pleasure.
12712	427	9	Also Vashti the queen made a feast for the women in the royal house which belonged to king Ahasuerus.
12713	427	10	On the seventh day, when the heart of the king was merry with wine, he commanded Mehuman, Biztha, Harbona, Bigtha, and Abagtha, Zethar, and Carcas, the seven chamberlains that served in the presence of Ahasuerus the king,
12714	427	11	To bring Vashti the queen before the king with the crown royal, to shew the people and the princes her beauty: for she was fair to look on.
12715	427	12	But the queen Vashti refused to come at the king's commandment by his chamberlains: therefore was the king very wroth, and his anger burned in him.
12716	427	13	Then the king said to the wise men, which knew the times, (for so was the king's manner toward all that knew law and judgment:
12717	427	14	And the next unto him was Carshena, Shethar, Admatha, Tarshish, Meres, Marsena, and Memucan, the seven princes of Persia and Media, which saw the king's face, and which sat the first in the kingdom;)
12718	427	15	What shall we do unto the queen Vashti according to law, because she hath not performed the commandment of the king Ahasuerus by the chamberlains?
12719	427	16	And Memucan answered before the king and the princes, Vashti the queen hath not done wrong to the king only, but also to all the princes, and to all the people that are in all the provinces of the king Ahasuerus.
12720	427	17	For this deed of the queen shall come abroad unto all women, so that they shall despise their husbands in their eyes, when it shall be reported, The king Ahasuerus commanded Vashti the queen to be brought in before him, but she came not.
12721	427	18	Likewise shall the ladies of Persia and Media say this day unto all the king's princes, which have heard of the deed of the queen. Thus shall there arise too much contempt and wrath.
12722	427	19	If it please the king, let there go a royal commandment from him, and let it be written among the laws of the Persians and the Medes, that it be not altered, That Vashti come no more before king Ahasuerus; and let the king give her royal estate unto another that is better than she.
12723	427	20	And when the king's decree which he shall make shall be published throughout all his empire, (for it is great,) all the wives shall give to their husbands honour, both to great and small.
12724	427	21	And the saying pleased the king and the princes; and the king did according to the word of Memucan:
12725	427	22	For he sent letters into all the king's provinces, into every province according to the writing thereof, and to every people after their language, that every man should bear rule in his own house, and that it should be published according to the language of every people.
12726	428	1	AFTER these things, when the wrath of king Ahasuerus was appeased, he remembered Vashti, and what she had done, and what was decreed against her.
12727	428	2	Then said the king's servants that ministered unto him, Let there be fair young virgins sought for the king:
12728	428	3	And let the king appoint officers in all the provinces of his kingdom, that they may gather together all the fair young virgins unto Shushan the palace, to the house of the women, unto the custody of Hege the king's chamberlain, keeper of the women; and let their things for purification be given them:
12729	428	4	And let the maiden which pleaseth the king be queen instead of Vashti. And the thing pleased the king; and he did so.
12730	428	5	Now in Shushan the palace there was a certain Jew, whose name was Mordecai, the son of Jair, the son of Shimei, the son of Kish, a Benjamite;
12731	428	6	Who had been carried away from Jerusalem with the captivity which had been carried away with Jeconiah king of Judah, whom Nebuchadnezzar the king of Babylon had carried away.
12732	428	7	And he brought up Hadassah, that is, Esther, his uncle's daughter: for she had neither father nor mother, and the maid was fair and beautiful; whom Mordecai, when her father and mother were dead, took for his own daughter.
12733	428	8	So it came to pass, when the king's commandment and his decree was heard, and when many maidens were gathered together unto Shushan the palace, to the custody of Hegai, that Esther was brought also unto the king's house, to the custody of Hegai, keeper of the women.
12734	428	9	And the maiden pleased him, and she obtained kindness of him; and he speedily gave her her things for purification, with such things as belonged to her, and seven maidens, which were meet to be given her, out of the king's house: and he preferred her and her maids unto the best place of the house of the women.
12735	428	10	Esther had not shewed her people nor her kindred: for Mordecai had charged her that she should not shew it.
12736	428	11	And Mordecai walked every day before the court of the women's house, to know how Esther did, and what should become of her.
12737	428	12	Now when every maid's turn was come to go in to king Ahasuerus, after that she had been twelve months, according to the manner of the women, (for so were the days of their purifications accomplished, to wit, six months with oil of myrrh, and six months with sweet odours, and with other things for the purifying of the women;)
12738	428	13	Then thus came every maiden unto the king; whatsoever she desired was given her to go with her out of the house of the women unto the king's house.
12739	428	14	In the evening she went, and on the morrow she returned into the second house of the women, to the custody of Shaashgaz, the king's chamberlain, which kept the concubines: she came in unto the king no more, except the king delighted in her, and that she were called by name.
12740	428	15	Now when the turn of Esther, the daughter of Abihail the uncle of Mordecai, who had taken her for his daughter, was come to go in unto the king, she required nothing but what Hegai the king's chamberlain, the keeper of the women, appointed. And Esther obtained favour in the sight of all them that looked upon her.
12741	428	16	So Esther was taken unto king Ahasuerus into his house royal in the tenth month, which is the month Tebeth, in the seventh year of his reign.
12742	428	17	And the king loved Esther above all the women, and she obtained grace and favour in his sight more than all the virgins; so that he set the royal crown upon her head, and made her queen instead of Vashti.
12743	428	18	Then the king made a great feast unto all his princes and his servants, even Esther's feast; and he made a release to the provinces, and gave gifts, according to the state of the king.
12744	428	19	And when the virgins were gathered together the second time, then Mordecai sat in the king's gate.
12745	428	20	Esther had not yet shewed her kindred nor her people; as Mordecai had charged her: for Esther did the commandment of Mordecai, like as when she was brought up with him.
12746	428	21	In those days, while Mordecai sat in the king's gate, two of the king's chamberlains, Bigthan and Teresh, of those which kept the door, were wroth, and sought to lay hand on the king Ahasuerus.
12747	428	22	And the thing was known to Mordecai, who told it unto Esther the queen; and Esther certified the king thereof in Mordecai's name.
12748	428	23	And when inquisition was made of the matter, it was found out; therefore they were both hanged on a tree: and it was written in the book of the chronicles before the king.
12749	429	1	AFTER these things did king Ahasuerus promote Haman the son of Hammedatha the Agagite, and advanced him, and set his seat above all the princes that were with him.
12750	429	2	And all the king's servants, that were in the king's gate, bowed, and reverenced Haman: for the king had so commanded concerning him. But Mordecai bowed not, nor did him reverence.
12751	429	3	Then the king's servants, which were in the king's gate, said unto Mordecai, Why transgressest thou the king's commandment?
12752	429	4	Now it came to pass, when they spake daily unto him, and he hearkened not unto them, that they told Haman, to see whether Mordecai's matters would stand: for he had told them that he was a Jew.
12753	429	5	And when Haman saw that Mordecai bowed not, nor did him reverence, then was Haman full of wrath.
12754	429	6	And he thought scorn to lay hands on Mordecai alone; for they had shewed him the people of Mordecai: wherefore Haman sought to destroy all the Jews that were throughout the whole kingdom of Ahasuerus, even the people of Mordecai.
12755	429	7	In the first month, that is, the month Nisan, in the twelfth year of king Ahasuerus, they cast Pur, that is, the lot, before Haman from day to day, and from month to month, to the twelfth month, that is, the month Adar.
12756	429	8	And Haman said unto king Ahasuerus, There is a certain people scattered abroad and dispersed among the people in all the provinces of thy kingdom; and their laws are diverse from all people; neither keep they the king's laws: therefore it is not for the king's profit to suffer them.
12757	429	9	If it please the king, let it be written that they may be destroyed: and I will pay ten thousand talents of silver to the hands of those that have the charge of the business, to bring it into the king's treasuries.
12758	429	10	And the king took his ring from his hand, and gave it unto Haman the son of Hammedatha the Agagite, the Jews' enemy.
12759	429	11	And the king said unto Haman, The silver is given to thee, the people also, to do with them as it seemeth good to thee.
12760	429	12	Then were the king's scribes called on the thirteenth day of the first month, and there was written according to all that Haman had commanded unto the king's lieutenants, and to the governors that were over every province, and to the rulers of every people of every province according to the writing thereof, and to every people after their language; in the name of king Ahasuerus was it written, and sealed with the king's ring.
12761	429	13	And the letters were sent by posts into all the king's provinces, to destroy, to kill, and to cause to perish, all Jews, both young and old, little children and women, in one day, even upon the thirteenth day of the twelfth month, which is the month Adar, and to take the spoil of them for a prey.
12762	429	14	The copy of the writing for a commandment to be given in every province was published unto all people, that they should be ready against that day.
12763	429	15	The posts went out, being hastened by the king's commandment, and the decree was given in Shushan the palace. And the king and Haman sat down to drink; but the city Shushan was perplexed.
12764	430	1	WHEN Mordecai perceived all that was done, Mordecai rent his clothes, and put on sackcloth with ashes, and went out into the midst of the city, and cried with a loud and a bitter cry;
12765	430	2	And came even before the king's gate: for none might enter into the king's gate clothed with sackcloth.
12766	430	3	And in every province, whithersoever the king's commandment and his decree came, there was great mourning among the Jews, and fasting, and weeping, and wailing; and many lay in sackcloth and ashes.
12767	430	4	So Esther's maids and her chamberlains came and told it her. Then was the queen exceedingly grieved; and she sent raiment to clothe Mordecai, and to take away his sackcloth from him: but he received it not.
12768	430	5	Then called Esther for Hatach, one of the king's chamberlains, whom he had appointed to attend upon her, and gave him a commandment to Mordecai, to know what it was, and why it was.
12769	430	6	So Hatach went forth to Mordecai unto the street of the city, which was before the king's gate.
12770	430	7	And Mordecai told him of all that had happened unto him, and of the sum of the money that Haman had promised to pay to the king's treasuries for the Jews, to destroy them.
12771	430	8	Also he gave him the copy of the writing of the decree that was given at Shushan to destroy them, to shew it unto Esther, and to declare it unto her, and to charge her that she should go in unto the king, to make supplication unto him, and to make request before him for her people.
12772	430	9	And Hatach came and told Esther the words of Mordecai.
12773	430	10	Again Esther spake unto Hatach, and gave him commandment unto Mordecai;
12774	430	11	All the king's servants, and the people of the king's provinces, do know, that whosoever, whether man or woman, shall come unto the king into the inner court, who is not called, there is one law of his to put him to death, except such to whom the king shall hold out the golden sceptre, that he may live: but I have not been called to come in unto the king these thirty days.
12775	430	12	And they told to Mordecai Esther's words.
12776	430	13	Then Mordecai commanded to answer Esther, Think not with thyself that thou shalt escape in the king's house, more than all the Jews.
12777	430	14	For if thou altogether holdest thy peace at this time, then shall there enlargement and deliverance arise to the Jews from another place; but thou and thy father's house shall be destroyed: and who knoweth whether thou art come to the kingdom for such a time as this?
12778	430	15	Then Esther bade them return Mordecai this answer,
12779	430	16	Go, gather together all the Jews that are present in Shushan, and fast ye for me, and neither eat nor drink three days, night or day: I also and my maidens will fast likewise; and so will I go in unto the king, which is not according to the law: and if I perish, I perish.
12780	430	17	So Mordecai went his way, and did according to all that Esther had commanded him.
12781	431	1	NOW it came to pass on the third day, that Esther put on her royal apparel, and stood in the inner court of the king's house, over against the king's house: and the king sat upon his royal throne in the royal house, over against the gate of the house.
12782	431	2	And it was so, when the king saw Esther the queen standing in the court, that she obtained favour in his sight: and the king held out to Esther the golden sceptre that was in his hand. So Esther drew near, and touched the top of the sceptre.
12783	431	3	Then said the king unto her, What wilt thou, queen Esther? and what is thy request? it shall be even given thee to the half of the kingdom.
12784	431	4	And Esther answered, If it seem good unto the king, let the king and Haman come this day unto the banquet that I have prepared for him.
12785	431	5	Then the king said, Cause Haman to make haste, that he may do as Esther hath said. So the king and Haman came to the banquet that Esther had prepared.
12786	431	6	And the king said unto Esther at the banquet of wine, What is thy petition? and it shall be granted thee: and what is thy request? even to the half of the kingdom it shall be performed.
12787	431	7	Then answered Esther, and said, My petition and my request is;
12788	431	8	If I have found favour in the sight of the king, and if it please the king to grant my petition, and to perform my request, let the king and Haman come to the banquet that I shall prepare for them, and I will do to morrow as the king hath said.
12789	431	9	Then went Haman forth that day joyful and with a glad heart: but when Haman saw Mordecai in the king's gate, that he stood not up, nor moved for him, he was full of indignation against Mordecai.
12790	431	10	Nevertheless Haman refrained himself: and when he came home, he sent and called for his friends, and Zeresh his wife.
12791	431	11	And Haman told them of the glory of his riches, and the multitude of his children, and all the things wherein the king had promoted him, and how he had advanced him above the princes and servants of the king.
12792	431	12	Haman said moreover, Yea, Esther the queen did let no man come in with the king unto the banquet that she had prepared but myself; and to morrow am I invited unto her also with the king.
12793	431	13	Yet all this availeth me nothing, so long as I see Mordecai the Jew sitting at the king's gate.
12794	431	14	Then said Zeresh his wife and all his friends unto him, Let a gallows be made of fifty cubits high, and tomorrow speak thou unto the king that Mordecai may be hanged thereon: then go thou in merrily with the king unto the banquet. And the thing pleased Haman; and he caused the gallows to be made.
12795	432	1	ON that night could not the king sleep, and he commanded to bring the book of records of the chronicles; and they were read before the king.
12796	432	2	And it was found written, that Mordecai had told of Bigthana and Teresh, two of the king's chamberlains, the keepers of the door, who sought to lay hand on the king Ahasuerus.
12797	432	3	And the king said, What honour and dignity hath been done to Mordecai for this? Then said the king's servants that ministered unto him, There is nothing done for him.
12798	432	4	And the king said, Who is in the court? Now Haman was come into the outward court of the king's house, to speak unto the king to hang Mordecai on the gallows that he had prepared for him.
12799	432	5	And the king's servants said unto him, Behold, Haman standeth in the court. And the king said, Let him come in.
12800	432	6	So Haman came in. And the king said unto him, What shall be done unto the man whom the king delighteth to honour? Now Haman thought in his heart, To whom would the king delight to do honour more than to myself?
12801	432	7	And Haman answered the king, For the man whom the king delighteth to honour,
12802	432	8	Let the royal apparel be brought which the king useth to wear, and the horse that the king rideth upon, and the crown royal which is set upon his head:
12803	432	9	And let this apparel and horse be delivered to the hand of one of the king's most noble princes, that they may array the man withal whom the king delighteth to honour, and bring him on horseback through the street of the city, and proclaim before him, Thus shall it be done to the man whom the king delighteth to honour.
12804	432	10	Then the king said to Haman, Make haste, and take the apparel and the horse, as thou hast said, and do even so to Mordecai the Jew, that sitteth at the king's gate: let nothing fail of all that thou has spoken.
12805	432	11	Then took Haman the apparel and the horse, and arrayed Mordecai, and brought him on horseback through the street of the city, and proclaimed before him, Thus shall it be done unto the man whom the king delighteth to honour.
12806	432	12	And Mordecai came again to the king's gate. But Haman hasted to his house mourning, and having his head covered.
12807	432	13	And Haman told Zeresh his wife and all his friends every thing that had befallen him. Then said his wise men and Zeresh his wife unto him, If Mordecai be of the seed of the Jews, before whom thou hast begun to fall, thou shalt not prevail against him, but shalt surely fall before him.
12808	432	14	And while they were yet talking with him, came the king's chamberlains, and hasted to bring Haman unto the banquet that Esther had prepared.
12809	433	1	SO the king and Haman came to banquet with Esther the queen.
12810	433	2	And the king said again unto Esther on the second day at the banquet of wine, What is thy petition, queen Esther? and it shall be granted thee: and what is thy request? and it shall be performed, even to the half of the kingdom.
12811	433	3	Then Esther the queen answered and said, If I have found favour in thy sight, O king, and if it please the king, let my life be given me at my petition, and my people at my request:
12812	433	4	For we are sold, I and my people, to be destroyed, to be slain, and to perish. But if we had been sold for bondmen and bondwomen, I had held my tongue, although the enemy could not countervail the king's damage.
12813	433	5	Then the king Ahasuerus answered and said unto Esther the queen, Who is he, and where is he, that durst presume in his heart to do so?
12814	433	6	And Esther said, The adversary and enemy is this wicked Haman. Then Haman was afraid before the king and the queen.
12815	433	7	And the king arising from the banquet of wine in his wrath went into the palace garden: and Haman stood up to make request for his life to Esther the queen; for he saw that there was evil determined against him by the king.
12816	433	8	Then the king returned out of the palace garden into the place of the banquet of wine; and Haman was fallen upon the bed whereon Esther was. Then said the king, Will he force the queen also before me in the house? As the word went out of the king's mouth, they covered Haman's face.
12817	433	9	And Harbonah, one of the chamberlains, said before the king, Behold also, the gallows fifty cubits high, which Haman had made for Mordecai, who had spoken good for the king, standeth in the house of Haman. Then the king said, Hang him thereon.
12818	433	10	So they hanged Haman on the gallows that he had prepared for Mordecai. Then was the king's wrath pacified.
12819	434	1	ON that day did the king Ahasuerus give the house of Haman the Jews' enemy unto Esther the queen. And Mordecai came before the king; for Esther had told what he was unto her.
12820	434	2	And the king took off his ring, which he had taken from Haman, and gave it unto Mordecai. And Esther set Mordecai over the house of Haman.
12821	434	3	And Esther spake yet again before the king, and fell down at his feet, and besought him with tears to put away the mischief of Haman the Agagite, and his device that he had devised against the Jews.
12822	434	4	Then the king held out the golden sceptre toward Esther. So Esther arose, and stood before the king.
12823	434	5	And said, If it please the king, and if I have found favour in his sight, and the thing seem right before the king, and I be pleasing in his eyes, let it be written to reverse the letters devised by Haman the son of Hammedatha the Agagite, which he wrote to destroy the Jews which are in all the king's provinces:
12824	434	6	For how can I endure to see the evil that shall come unto my people? or how can I endure to see the destruction of my kindred?
12825	434	7	Then the king Ahasuerus said unto Esther the queen and to Mordecai the Jew, Behold, I have given Esther the house of Haman, and him they have hanged upon the gallows, because he laid his hand upon the Jews.
12826	434	8	Write ye also for the Jews, as it liketh you, in the king's name, and seal it with the king's ring: for the writing which is written in the king's name, and sealed with the king's ring, may no man reverse.
12827	434	9	Then were the king's scribes called at that time in the third month, that is, the month Sivan, on the three and twentieth day thereof; and it was written according to all that Mordecai commanded unto the Jews, and to the lieutenants, and the deputies and rulers of the provinces which are from India unto Ethiopia, an hundred twenty and seven provinces, unto every province according to the writing thereof, and unto every people after their language, and to the Jews according to their writing, and according to their language.
12828	434	10	And he wrote in the king Ahasuerus' name, and sealed it with the king's ring, and sent letters by posts on horseback, and riders on mules, camels, and young dromedaries:
12829	434	11	Wherein the king granted the Jews which were in every city to gather themselves together, and to stand for their life, to destroy, to slay, and to cause to perish, all the power of the people and province that would assault them, both little ones and women, and to take the spoil of them for a prey,
12830	434	12	Upon one day in all the provinces of king Ahasuerus, namely, upon the thirteenth day of the twelfth month, which is the month Adar.
12831	434	13	The copy of the writing for a commandment to be given in every province was published unto all people, and that the Jews should be ready against that day to avenge themselves on their enemies.
12832	434	14	So the posts that rode upon mules and camels went out, being hastened and pressed on by the king's commandment. And the decree was given at Shushan the palace.
12833	434	15	And Mordecai went out from the presence of the king in royal apparel of blue and white, and with a great crown of gold, and with a garment of fine linen and purple: and the city of Shushan rejoiced and was glad.
12834	434	16	The Jews had light, and gladness, and joy, and honour.
12835	434	17	And in every province, and in every city, whithersoever the king's commandment and his decree came, the Jews had joy and gladness, a feast and a good day. And many of the people of the land became Jews; for the fear of the Jews fell upon them.
12836	435	1	NOW in the twelfth month, that is, the month Adar, on the thirteenth day of the same, when the king's commandment and his decree drew near to be put in execution, in the day that the enemies of the Jews hoped to have power over them, (though it was turned to the contrary, that the Jews had rule over them that hated them;)
12837	435	2	The Jews gathered themselves together in their cities throughout all the provinces of the king Ahasuerus, to lay hand on such as sought their hurt: and no man could withstand them; for the fear of them fell upon all people.
12838	435	3	And all the rulers of the provinces, and the lieutenants, and the deputies, and officers of the king, helped the Jews; because the fear of Mordecai fell upon them.
12839	435	4	For Mordecai was great in the king's house, and his fame went out throughout all the provinces: for this man Mordecai waxed greater and greater.
12840	435	5	Thus the Jews smote all their enemies with the stroke of the sword, and slaughter, and destruction, and did what they would unto those that hated them.
12841	435	6	And in Shushan the palace the Jews slew and destroyed five hundred men.
12842	435	7	And Parshandatha, and Dalphon, and Aspatha,
12843	435	8	And Poratha, and Adalia, and Aridatha,
12844	435	9	And Parmashta, and Arisai, and Aridai, and Vajezatha,
12845	435	10	The ten sons of Haman the son of Hammedatha, the enemy of the Jews, slew they; but on the spoil laid they not their hand.
12846	435	11	On that day the number of those that were slain in Shushan the palace was brought before the king.
12847	435	12	And the king said unto Esther the queen, The Jews have slain and destroyed five hundred men in Shushan the palace, and the ten sons of Haman; what have they done in the rest of the king's provinces? now what is thy petition? and it shall be granted thee: or what is thy request further? and it shall be done.
12848	435	13	Then said Esther, If it please the king, let it be granted to the Jews which are in Shushan to do to morrow also according unto this day's decree, and let Haman's ten sons be hanged upon the gallows.
12849	435	14	And the king commanded it so to be done: and the decree was given at Shushan; and they hanged Haman's ten sons.
12850	435	15	For the Jews that were in Shushan gathered themselves together on the fourteenth day also of the month Adar, and slew three hundred men at Shushan; but on the prey they laid not their hand.
12851	435	16	But the other Jews that were in the king's provinces gathered themselves together, and stood for their lives, and had rest from their enemies, and slew of their foes seventy and five thousand, but they laid not their hands on the prey,
12852	435	17	On the thirteenth day of the month Adar; and on the fourteenth day of the same rested they, and made it a day of feasting and gladness.
12853	435	18	But the Jews that were at Shushan assembled together on the thirteenth day thereof, and on the fourteenth thereof; and on the fifteenth day of the same they rested, and made it a day of feasting and gladness.
12854	435	19	Therefore the Jews of the villages, that dwelt in the unwalled towns, made the fourteenth day of the month Adar a day of gladness and feasting, and a good day, and of sending portions one to another.
12855	435	20	And Mordecai wrote these things, and sent letters unto all the Jews that were in all the provinces of the king Ahasuerus, both nigh and far,
12856	435	21	To stablish this among them, that they should keep the fourteenth day of the month Adar, and the fifteenth day of the same, yearly,
12857	435	22	As the days wherein the Jews rested from their enemies, and the month which was turned unto them from sorrow to joy, and from mourning into a good day: that they should make them days of feasting and joy, and of sending portions one to another, and gifts to the poor.
12858	435	23	And the Jews undertook to do as they had begun, and as Mordecai had written unto them;
12859	435	24	Because Haman the son of Hammedatha, the Agagite, the enemy of all the Jews, had devised against the Jews to destroy them, and had cast Pur, that is, the lot, to consume them, and to destroy them;
12860	435	25	But when Esther came before the king, he commanded by letters that his wicked device, which he devised against the Jews, should return upon his own head, and that he and his sons should be hanged on the gallows.
12861	435	26	Wherefore they called these days Purim after the name of Pur. Therefore for all the words of this letter, and of that which they had seen concerning this matter, and which had come unto them,
12862	435	27	The Jews ordained, and took upon them, and upon their seed, and upon all such as joined themselves unto them, so as it should not fail, that they would keep these two days according to their writing, and according to their appointed time every year;
12863	435	28	And that these days should be remembered and kept throughout every generation, every family, every province, and every city; and that these days of Purim should not fail from among the Jews, nor the memorial of them perish from their seed.
12864	435	29	Then Esther the queen, the daughter of Abihail, and Mordecai the Jew, wrote with all authority, to confirm this second letter of Purim.
12865	435	30	And he sent the letters unto all the Jews, to the hundred twenty and seven provinces of the kingdom of Ahasuerus, with words of peace and truth,
12866	435	31	To confirm these days of Purim in their times appointed, according as Mordecai the Jew and Esther the queen had enjoined them, and as they had decreed for themselves and for their seed, the matters of the fastings and their cry.
12867	435	32	And the decree of Esther confirmed these matters of Purim; and it was written in the book.
12868	436	1	AND the king Ahasuerus laid a tribute upon the land, and upon the isles of the sea.
12869	436	2	And all the acts of his power and of his might, and the declaration of the greatness of Mordecai, whereunto the king advanced him, are they not written in the book of the chronicles of the kings of Media and Persia?
12870	436	3	For Mordecai the Jew was next unto king Ahasuerus, and great among the Jews, and accepted of the multitude of his brethren, seeking the wealth of his people, and speaking peace to all his seed.
12871	437	1	THERE was a man in the land of Uz, whose name was Job; and that man was perfect and upright, and one that feared God, and eschewed evil.
12872	437	2	And there were born unto him seven sons and three daughters.
12873	437	3	His substance also was seven thousand sheep, and three thousand camels, and five hundred yoke of oxen, and five hundred she asses, and a very great household; so that this man was the greatest of all the men of the east.
12874	437	4	And his sons went and feasted in their houses, every one his day; and sent and called for their three sisters to eat and to drink with them.
12875	437	5	And it was so, when the days of their feasting were gone about, that Job sent and sanctified them, and rose up early in the morning, and offered burnt offerings according to the number of them all: for Job said, It may be that my sons have sinned, and cursed God in their hearts. Thus did Job continually.
12876	437	6	Now there was a day when the sons of God came to present themselves before the LORD, and Satan came also among them.
12877	437	7	And the LORD said unto Satan, Whence comest thou? Then Satan answered the LORD, and said, From going to and fro in the earth, and from walking up and down in it.
12878	437	8	And the LORD said unto Satan, Hast thou considered my servant Job, that there is none like him in the earth, a perfect and an upright man, one that feareth God, and escheweth evil?
12879	437	9	Then Satan answered the LORD, and said, Doth Job fear God for nought?
12880	437	10	Hast not thou made an hedge about him, and about his house, and about all that he hath on every side? thou hast blessed the work of his hands, and his substance is increased in the land.
12881	437	11	But put forth thine hand now, and touch all that he hath, and he will curse thee to thy face.
12882	437	12	And the LORD said unto Satan, Behold, all that he hath is in thy power; only upon himself put not forth thine hand. So Satan went forth from the presence of the LORD.
12883	437	13	And there was a day when his sons and his daughters were eating and drinking wine in their eldest brother's house:
12884	437	14	And there came a messenger unto Job, and said, The oxen were plowing, and the asses feeding beside them:
12885	437	15	And the Sabeans fell upon them, and took them away; yea, they have slain the servants with the edge of the sword; and I only am escaped alone to tell thee.
12886	437	16	While he was yet speaking, there came also another, and said, The fire of God is fallen from heaven, and hath burned up the sheep, and the servants, and consumed them; and I only am escaped alone to tell thee.
12887	437	17	While he was yet speaking, there came also another, and said, The Chaldeans made out three bands, and fell upon the camels, and have carried them away, yea, and slain the servants with the edge of the sword; and I only am escaped alone to tell thee.
12888	437	18	While he was yet speaking, there came also another, and said, Thy sons and thy daughters were eating and drinking wine in their eldest brother's house:
12889	437	19	And, behold, there came a great wind from the wilderness, and smote the four corners of the house, and it fell upon the young men, and they are dead; and I only am escaped alone to tell thee.
12890	437	20	Then Job arose, and rent his mantle, and shaved his head, and fell down upon the ground, and worshipped,
12891	437	21	And said, Naked came I out of my mother's womb, and naked shall I return thither: the LORD gave, and the LORD hath taken away; blessed be the name of the LORD.
12892	437	22	In all this Job sinned not, nor charged God foolishly.
12893	438	1	AGAIN there was a day when the sons of God came to present themselves before the LORD, and Satan came also among them to present himself before the LORD.
12894	438	2	And the LORD said unto Satan, From whence comest thou? And Satan answered the LORD, and said, From going to and fro in the earth, and from walking up and down in it.
12895	438	3	And the LORD said unto Satan, Hast thou considered my servant Job, that there is none like him in the earth, a perfect and an upright man, one that feareth God, and escheweth evil? and still he holdeth fast his integrity, although thou movedst me against him, to destroy him without cause.
12896	438	4	And Satan answered the LORD, and said, Skin for skin, yea, all that a man hath will he give for his life.
12897	438	5	But put forth thine hand now, and touch his bone and his flesh, and he will curse thee to thy face.
12898	438	6	And the LORD said unto Satan, Behold, he is in thine hand; but save his life.
12899	438	7	So went Satan forth from the presence of the LORD, and smote Job with sore boils from the sole of his foot unto his crown.
12900	438	8	And he took him a potsherd to scrape himself withal; and he sat down among the ashes.
12901	438	9	Then said his wife unto him, Dost thou still retain thine integrity? curse God, and die.
12902	438	10	But he said unto her, Thou speakest as one of the foolish women speaketh. What? shall we receive good at the hand of God, and shall we not receive evil? In all this did not Job sin with his lips.
12903	438	11	Now when Job's three friends heard of all this evil that was come upon him, they came every one from his own place; Eliphaz the Temanite, and Bildad the Shuhite, and Zophar the Naamathite: for they had made an appointment together to come to mourn with him and to comfort him.
12904	438	12	And when they lifted up their eyes afar off, and knew him not, they lifted up their voice, and wept; and they rent every one his mantle, and sprinkled dust upon their heads toward heaven.
12905	438	13	So they sat down with him upon the ground seven days and seven nights, and none spake a word unto him: for they saw that his grief was very great.
12906	439	1	AFTER this opened Job his mouth, and cursed his day.
12907	439	2	And Job spake, and said,
12908	439	3	Let the day perish wherein I was born, and the night in which it was said, There is a man child conceived.
12909	439	4	Let that day be darkness; let not God regard it from above, neither let the light shine upon it.
12910	439	5	Let darkness and the shadow of death stain it; let a cloud dwell upon it; let the blackness of the day terrify it.
12911	439	6	As for that night, let darkness seize upon it; let it not be joined unto the days of the year, let it not come into the number of the months.
12912	439	7	Lo, let that night be solitary, let no joyful voice come therein.
12913	439	8	Let them curse it that curse the day, who are ready to raise up their mourning.
12914	439	9	Let the stars of the twilight thereof be dark; let it look for light, but have none; neither let it see the dawning of the day:
12915	439	10	Because it shut not up the doors of my mother's womb, nor hid sorrow from mine eyes.
12916	439	11	Why died I not from the womb? why did I not give up the ghost when I came out of the belly?
12917	439	12	Why did the knees prevent me? or why the breasts that I should suck?
12918	439	13	For now should I have lain still and been quiet, I should have slept: then had I been at rest,
12919	439	14	With kings and counsellers of the earth, which built desolate places for themselves;
12920	439	15	Or with princes that had gold, who filled their houses with silver:
12921	439	16	Or as an hidden untimely birth I had not been; as infants which never saw light.
12922	439	17	There the wicked cease from troubling; and there the weary be at rest.
12923	439	18	There the prisoners rest together; they hear not the voice of the oppressor.
12924	439	19	The small and great are there; and the servant is free from his master.
12925	439	20	Wherefore is light given to him that is in misery, and life unto the bitter in soul;
12926	439	21	Which long for death, but it cometh not; and dig for it more than for hid treasures;
12927	439	22	Which rejoice exceedingly, and are glad, when they can find the grave?
12928	439	23	Why is light given to a man whose way is hid, and whom God hath hedged in?
12929	439	24	For my sighing cometh before I eat, and my roarings are poured out like the waters.
12930	439	25	For the thing which I greatly feared is come upon me, and that which I was afraid of is come unto me.
12931	439	26	I was not in safety, neither had I rest, neither was I quiet; yet trouble came.
12932	440	1	THEN Eliphaz the Temanite answered and said,
12933	440	2	If we assay to commune with thee, wilt thou be grieved? but who can withhold himself from speaking?
12934	440	3	Behold, thou hast instructed many, and thou hast strengthened the weak hands.
12935	440	4	Thy words have upholden him that was falling, and thou hast strengthened the feeble knees.
12936	440	5	But now it is come upon thee, and thou faintest; it toucheth thee, and thou art troubled.
12937	440	6	Is not this thy fear, thy confidence, thy hope, and the uprightness of thy ways?
12938	440	7	Remember, I pray thee, who ever perished, being innocent? or where were the righteous cut off?
12939	440	8	Even as I have seen, they that plow iniquity, and sow wickedness, reap the same.
12940	440	9	By the blast of God they perish, and by the breath of his nostrils are they consumed.
12941	440	10	The roaring of the lion, and the voice of the fierce lion, and the teeth of the young lions, are broken.
12942	440	11	The old lion perisheth for lack of prey, and the stout lion's whelps are scattered abroad.
12943	440	12	Now a thing was secretly brought to me, and mine ear received a little thereof.
12944	440	13	In thoughts from the visions of the night, when deep sleep falleth on men,
12945	440	14	Fear came upon me, and trembling, which made all my bones to shake.
12946	440	15	Then a spirit passed before my face; the hair of my flesh stood up:
12947	440	16	It stood still, but I could not discern the form thereof: an image was before mine eyes, there was silence, and I heard a voice, saying,
12948	440	17	Shall mortal man be more just than God? shall a man be more pure than his maker?
12949	440	18	Behold, he put no trust in his servants; and his angels he charged with folly:
12950	440	19	How much less in them that dwell in houses of clay, whose foundation is in the dust, which are crushed before the moth?
12951	440	20	They are destroyed from morning to evening: they perish for ever without any regarding it.
12952	440	21	Doth not their excellency which is in them go away? they die, even without wisdom.
12953	441	1	CALL now, if there be any that will answer thee; and to which of the saints wilt thou turn?
12954	441	2	For wrath killeth the foolish man, and envy slayeth the silly one.
12955	441	3	I have seen the foolish taking root: but suddenly I cursed his habitation.
12956	441	4	His children are far from safety, and they are crushed in the gate, neither is there any to deliver them.
12957	441	5	Whose harvest the hungry eateth up, and taketh it even out of the thorns, and the robber swalloweth up their substance.
12958	441	6	Although affliction cometh not forth of the dust, neither doth trouble spring out of the ground;
12959	441	7	Yet man is born unto trouble, as the sparks fly upward.
12960	441	8	I would seek unto God, and unto God would I commit my cause:
12961	441	9	Which doeth great things and unsearchable; marvellous things without number:
12962	441	10	Who giveth rain upon the earth, and sendeth waters upon the fields:
12963	441	11	To set up on high those that be low; that those which mourn may be exalted to safety.
12964	441	12	He disappointeth the devices of the crafty, so that their hands cannot perform their enterprise.
12965	441	13	He taketh the wise in their own craftiness: and the counsel of the froward is carried headlong.
12966	441	14	They meet with darkness in the daytime, and grope in the noonday as in the night.
12967	441	15	But he saveth the poor from the sword, from their mouth, and from the hand of the mighty.
12968	441	16	So the poor hath hope, and iniquity stoppeth her mouth.
12969	441	17	Behold, happy is the man whom God correcteth: therefore despise not thou the chastening of the Almighty:
12970	441	18	For he maketh sore, and bindeth up: he woundeth, and his hands make whole.
12971	441	19	He shall deliver thee in six troubles: yea, in seven there shall no evil touch thee.
12972	441	20	In famine he shall redeem thee from death: and in war from the power of the sword.
12973	441	21	Thou shalt be hid from the scourge of the tongue: neither shalt thou be afraid of destruction when it cometh.
12974	441	22	At destruction and famine thou shalt laugh: neither shalt thou be afraid of the beasts of the earth.
12975	441	23	For thou shalt be in league with the stones of the field: and the beasts of the field shall be at peace with thee.
12976	441	24	And thou shalt know that thy tabernacle shall be in peace; and thou shalt visit thy habitation, and shalt not sin.
12977	441	25	Thou shalt know also that thy seed shall be great, and thine offspring as the grass of the earth.
12978	441	26	Thou shalt come to thy grave in a full age, like as a shock of corn cometh in in his season.
12979	441	27	Lo this, we have searched it, so it is; hear it, and know thou it for thy good.
12980	442	1	BUT Job answered and said,
12981	442	2	Oh that my grief were throughly weighed, and my calamity laid in the balances together!
12982	442	3	For now it would be heavier than the sand of the sea: therefore my words are swallowed up.
12983	442	4	For the arrows of the Almighty are within me, the poison whereof drinketh up my spirit: the terrors of God do set themselves in array against me.
12984	442	5	Doth the wild ass bray when he hath grass? or loweth the ox over his fodder?
12985	442	6	Can that which is unsavoury be eaten without salt? or is there any taste in the white of an egg?
12986	442	7	The things that my soul refused to touch are as my sorrowful meat.
12987	442	8	Oh that I might have my request; and that God would grant me the thing that I long for!
12988	442	9	Even that it would please God to destroy me; that he would let loose his hand, and cut me off!
12989	442	10	Then should I yet have comfort; yea, I would harden myself in sorrow: let him not spare; for I have not concealed the words of the Holy One.
12990	442	11	What is my strength, that I should hope? and what is mine end, that I should prolong my life?
12991	442	12	Is my strength the strength of stones? or is my flesh of brass?
12992	442	13	Is not my help in me? and is wisdom driven quite from me?
12993	442	14	To him that is afflicted pity should be shewed from his friend; but he forsaketh the fear of the Almighty.
12994	442	15	My brethren have dealt deceitfully as a brook, and as the stream of brooks they pass away;
12995	442	16	Which are blackish by reason of the ice, and wherein the snow is hid:
12996	442	17	What time they wax warm, they vanish: when it is hot, they are consumed out of their place.
12997	442	18	The paths of their way are turned aside; they go to nothing, and perish.
12998	442	19	The troops of Tema looked, the companies of Sheba waited for them.
12999	442	20	They were confounded because they had hoped; they came thither, and were ashamed.
13000	442	21	For now ye are nothing; ye see my casting down, and are afraid.
13001	442	22	Did I say, Bring unto me? or, Give a reward for me of your substance?
13002	442	23	Or, Deliver me from the enemy's hand? or, Redeem me from the hand of the mighty?
13003	442	24	Teach me, and I will hold my tongue: and cause me to understand wherein I have erred.
13004	442	25	How forcible are right words! but what doth your arguing reprove?
13005	442	26	Do ye imagine to reprove words, and the speeches of one that is desperate, which are as wind?
13006	442	27	Yea, ye overwhelm the fatherless, and ye dig a pit for your friend.
13007	442	28	Now therefore be content, look upon me; for it is evident unto you if I lie.
13008	442	29	Return, I pray you, let it not be iniquity; yea, return again, my righteousness is in it.
13009	442	30	Is there iniquity in my tongue? cannot my taste discern perverse things?
13010	443	1	IS there not an appointed time to man upon earth? are not his days also like the days of an hireling?
13011	443	2	As a servant earnestly desireth the shadow, and as an hireling looketh for the reward of his work:
13012	443	3	So am I made to possess months of vanity, and wearisome nights are appointed to me.
13013	443	4	When I lie down, I say, When shall I arise, and the night be gone? and I am full of tossings to and fro unto the dawning of the day.
13014	443	5	My flesh is clothed with worms and clods of dust; my skin is broken, and become loathsome.
13015	443	6	My days are swifter than a weaver's shuttle, and are spent without hope.
13016	443	7	O remember that my life is wind: mine eye shall no more see good.
13017	443	8	The eye of him that hath seen me shall see me no more: thine eyes are upon me, and I am not.
13018	443	9	As the cloud is consumed and vanisheth away: so he that goeth down to the grave shall come up no more.
13019	443	10	He shall return no more to his house, neither shall his place know him any more.
13020	443	11	Therefore I will not refrain my mouth; I will speak in the anguish of my spirit; I will complain in the bitterness of my soul.
13021	443	12	Am I a sea, or a whale, that thou settest a watch over me?
13022	443	13	When I say, My bed shall comfort me, my couch shall ease my complaint;
13023	443	14	Then thou scarest me with dreams, and terrifiest me through visions:
13024	443	15	So that my soul chooseth strangling, and death rather than my life.
13025	443	16	I loathe it; I would not live alway: let me alone; for my days are vanity.
13026	443	17	What is man, that thou shouldest magnify him? and that thou shouldest set thine heart upon him?
13027	443	18	And that thou shouldest visit him every morning, and try him every moment?
13028	443	19	How long wilt thou not depart from me, nor let me alone till I swallow down my spittle?
13029	443	20	I have sinned; what shall I do unto thee, O thou preserver of men? why hast thou set me as a mark against thee, so that I am a burden to myself?
13030	443	21	And why dost thou not pardon my transgression, and take away mine iniquity? for now shall I sleep in the dust; and thou shalt seek me in the morning, but I shall not be.
13031	444	1	THEN answered Bildad the Shuhite, and said,
13032	444	2	How long wilt thou speak these things? and how long shall the words of thy mouth be like a strong wind?
13033	444	3	Doth God pervert judgment? or doth the Almighty pervert justice?
13034	444	4	If thy children have sinned against him, and he have cast them away for their transgression;
13035	444	5	If thou wouldest seek unto God betimes, and make thy supplication to the Almighty;
13036	444	6	If thou wert pure and upright; surely now he would awake for thee, and make the habitation of thy righteousness prosperous.
13037	444	7	Though thy beginning was small, yet thy latter end should greatly increase.
13038	444	8	For enquire, I pray thee, of the former age, and prepare thyself to the search of their fathers:
13039	444	9	(For we are but of yesterday, and know nothing, because our days upon earth are a shadow:)
13040	444	10	Shall not they teach thee, and tell thee, and utter words out of their heart?
13041	444	11	Can the rush grow up without mire? can the flag grow without water?
13042	444	12	Whilst it is yet in his greenness, and not cut down, it withereth before any other herb.
13043	444	13	So are the paths of all that forget God; and the hypocrite's hope shall perish:
13044	444	14	Whose hope shall be cut off, and whose trust shall be a spider's web.
13045	444	15	He shall lean upon his house, but it shall not stand: he shall hold it fast, but it shall not endure.
13046	444	16	He is green before the sun, and his branch shooteth forth in his garden.
13047	444	17	His roots are wrapped about the heap, and seeth the place of stones.
13048	444	18	If he destroy him from his place, then it shall deny him, saying, I have not seen thee.
13049	444	19	Behold, this is the joy of his way, and out of the earth shall others grow.
13050	444	20	Behold, God will not cast away a perfect man, neither will he help the evil doers:
13051	444	21	Till he fill thy mouth with laughing, and thy lips with rejoicing.
13052	444	22	They that hate thee shall be clothed with shame; and the dwelling place of the wicked shall come to nought.
13053	445	1	THEN Job answered and said,
13054	445	2	I know it is so of a truth: but how should man be just with God?
13055	445	3	If he will contend with him, he cannot answer him one of a thousand.
13056	445	4	He is wise in heart, and mighty in strength: who hath hardened himself against him, and hath prospered?
13057	445	5	Which removeth the mountains, and they know not: which overturneth them in his anger.
13058	445	6	Which shaketh the earth out of her place, and the pillars thereof tremble.
13059	445	7	Which commandeth the sun, and it riseth not; and sealeth up the stars.
13060	445	8	Which alone spreadeth out the heavens, and treadeth upon the waves of the sea.
13061	445	9	Which maketh Arcturus, Orion, and Pleiades, and the chambers of the south.
13062	445	10	Which doeth great things past finding out; yea, and wonders without number.
13063	445	11	Lo, he goeth by me, and I see him not: he passeth on also, but I perceive him not.
13064	445	12	Behold, he taketh away, who can hinder him? who will say unto him, What doest thou?
13065	445	13	If God will not withdraw his anger, the proud helpers do stoop under him.
13066	445	14	How much less shall I answer him, and choose out my words to reason with him?
13067	445	15	Whom, though I were righteous, yet would I not answer, but I would make supplication to my judge.
13068	445	16	If I had called, and he had answered me; yet would I not believe that he had hearkened unto my voice.
13069	445	17	For he breaketh me with a tempest, and multiplieth my wounds without cause.
13070	445	18	He will not suffer me to take my breath, but filleth me with bitterness.
13071	445	19	If I speak of strength, lo, he is strong: and if of judgment, who shall set me a time to plead?
13072	445	20	If I justify myself, mine own mouth shall condemn me: if I say, I am perfect, it shall also prove me perverse.
13073	445	21	Though I were perfect, yet would I not know my soul: I would despise my life.
13074	445	22	This is one thing, therefore I said it, He destroyeth the perfect and the wicked.
13075	445	23	If the scourge slay suddenly, he will laugh at the trial of the innocent.
13076	445	24	The earth is given into the hand of the wicked: he covereth the faces of the judges thereof, if not, where, and who is he?
13077	445	25	Now my days are swifter than a post: they flee away, they see no good.
13078	445	26	They are passed away as the swift ships: as the eagle that hasteth to the prey.
13079	445	27	If I say, I will forget my complaint, I will leave off my heaviness, and comfort myself:
13080	445	28	I am afraid of all my sorrows, I know that thou wilt not hold me innocent.
13081	445	29	If I be wicked, why then labour I in vain?
13082	445	30	If I wash myself with snow water, and make my hands never so clean;
13083	445	31	Yet shalt thou plunge me in the ditch, and mine own clothes shall abhor me.
13084	445	32	For he is not a man, as I am, that I should answer him, and we should come together in judgment.
13085	445	33	Neither is there any daysman betwixt us, that might lay his hand upon us both.
13086	445	34	Let him take his rod away from me, and let not his fear terrify me:
13087	445	35	Then would I speak, and not fear him; but it is not so with me.
13088	446	1	MY soul is weary of my life; I will leave my complaint upon myself; I will speak in the bitterness of my soul.
13089	446	2	I will say unto God, Do not condemn me; shew me wherefore thou contendest with me.
13090	446	3	Is it good unto thee that thou shouldest oppress, that thou shouldest despise the work of thine hands, and shine upon the counsel of the wicked?
13091	446	4	Hast thou eyes of flesh? or seest thou as man seeth?
13092	446	5	Are thy days as the days of man? are thy years as man's days,
13093	446	6	That thou enquirest after mine iniquity, and searchest after my sin?
13094	446	7	Thou knowest that I am not wicked; and there is none that can deliver out of thine hand.
13095	446	8	Thine hands have made me and fashioned me together round about; yet thou dost destroy me.
13096	446	9	Remember, I beseech thee, that thou hast made me as the clay; and wilt thou bring me into dust again?
13097	446	10	Hast thou not poured me out as milk, and curdled me like cheese?
13098	446	11	Thou hast clothed me with skin and flesh, and hast fenced me with bones and sinews.
13099	446	12	Thou hast granted me life and favour, and thy visitation hath preserved my spirit.
13100	446	13	And these things hast thou hid in thine heart: I know that this is with thee.
13101	446	14	If I sin, then thou markest me, and thou wilt not acquit me from mine iniquity.
13102	446	15	If I be wicked, woe unto me; and if I be righteous, yet will I not lift up my head. I am full of confusion; therefore see thou mine affliction;
13103	446	16	For it increaseth. Thou huntest me as a fierce lion: and again thou shewest thyself marvellous upon me.
13104	446	17	Thou renewest thy witnesses against me, and increasest thine indignation upon me; changes and war are against me.
13105	446	18	Wherefore then hast thou brought me forth out of the womb? Oh that I had given up the ghost, and no eye had seen me!
13106	446	19	I should have been as though I had not been; I should have been carried from the womb to the grave.
13107	446	20	Are not my days few? cease then, and let me alone, that I may take comfort a little,
13108	446	21	Before I go whence I shall not return, even to the land of darkness and the shadow of death;
13109	446	22	A land of darkness, as darkness itself; and of the shadow of death, without any order, and where the light is as darkness.
13110	447	1	THEN answered Zophar the Naamathite, and said,
13111	447	2	Should not the multitude of words be answered? and should a man full of talk be justified?
13112	447	3	Should thy lies make men hold their peace? and when thou mockest, shall no man make thee ashamed?
13113	447	4	For thou hast said, My doctrine is pure, and I am clean in thine eyes.
13114	447	5	But oh that God would speak, and open his lips against thee;
13115	447	6	And that he would shew thee the secrets of wisdom, that they are double to that which is! Know therefore that God exacteth of thee less than thine iniquity deserveth.
13116	447	7	Canst thou by searching find out God? canst thou find out the Almighty unto perfection?
13117	447	8	It is as high as heaven; what canst thou do? deeper than hell; what canst thou know?
13118	447	9	The measure thereof is longer than the earth, and broader than the sea.
13119	447	10	If he cut off, and shut up, or gather together, then who can hinder him?
13120	447	11	For he knoweth vain men: he seeth wickedness also; will he not then consider it?
13121	447	12	For vain man would be wise, though man be born like a wild ass's colt.
13122	447	13	If thou prepare thine heart, and stretch out thine hands toward him;
13123	447	14	If iniquity be in thine hand, put it far away, and let not wickedness dwell in thy tabernacles.
13124	447	15	For then shalt thou lift up thy face without spot; yea, thou shalt be stedfast, and shalt not fear:
13125	447	16	Because thou shalt forget thy misery, and remember it as waters that pass away:
13126	447	17	And thine age shall be clearer than the noonday; thou shalt shine forth, thou shalt be as the morning.
13127	447	18	And thou shalt be secure, because there is hope; yea, thou shalt dig about thee, and thou shalt take thy rest in safety.
13128	447	19	Also thou shalt lie down, and none shall make thee afraid; yea, many shall make suit unto thee.
13129	447	20	But the eyes of the wicked shall fail, and they shall not escape, and their hope shall be as the giving up of the ghost.
13130	448	1	AND Job answered and said,
13131	448	2	No doubt but ye are the people, and wisdom shall die with you.
13132	448	3	But I have understanding as well as you; I am not inferior to you: yea, who knoweth not such things as these?
13133	448	4	I am as one mocked of his neighbour, who calleth upon God, and he answereth him: the just upright man is laughed to scorn.
13134	448	5	He that is ready to slip with his feet is as a lamp despised in the thought of him that is at ease.
13135	448	6	The tabernacles of robbers prosper, and they that provoke God are secure; into whose hand God bringeth abundantly.
13136	448	7	But ask now the beasts, and they shall teach thee; and the fowls of the air, and they shall tell thee:
13137	448	8	Or speak to the earth, and it shall teach thee: and the fishes of the sea shall declare unto thee.
13138	448	9	Who knoweth not in all these that the hand of the LORD hath wrought this?
13139	448	10	In whose hand is the soul of every living thing, and the breath of all mankind.
13140	448	11	Doth not the ear try words? and the mouth taste his meat?
13141	448	12	With the ancient is wisdom; and in length of days understanding.
13142	448	13	With him is wisdom and strength, he hath counsel and understanding.
13143	448	14	Behold, he breaketh down, and it cannot be built again: he shutteth up a man, and there can be no opening.
13144	448	15	Behold, he withholdeth the waters, and they dry up: also he sendeth them out, and they overturn the earth.
13145	448	16	With him is strength and wisdom: the deceived and the deceiver are his.
13146	448	17	He leadeth counsellors away spoiled, and maketh the judges fools.
13147	448	18	He looseth the bond of kings, and girdeth their loins with a girdle.
13148	448	19	He leadeth princes away spoiled, and overthroweth the mighty.
13149	448	20	He removeth away the speech of the trusty, and taketh away the understanding of the aged.
13150	448	21	He poureth contempt upon princes, and weakeneth the strength of the mighty.
13151	448	22	He discovereth deep things out of darkness, and bringeth out to light the shadow of death.
13152	448	23	He increaseth the nations, and destroyeth them: he enlargeth the nations, and straiteneth them again.
13153	448	24	He taketh away the heart of the chief of the people of the earth, and causeth them to wander in a wilderness where there is no way.
13154	448	25	They grope in the dark without light, and he maketh them to stagger like a drunken man.
13155	449	1	LO, mine eye hath seen all this, mine ear hath heard and understood it.
13156	449	2	What ye know, the same do I know also: I am not inferior unto you.
13157	449	3	Surely I would speak to the Almighty, and I desire to reason with God.
13158	449	4	But ye are forgers of lies, ye are all physicians of no value.
13159	449	5	O that ye would altogether hold your peace! and it should be your wisdom.
13160	449	6	Hear now my reasoning, and hearken to the pleadings of my lips.
13161	449	7	Will ye speak wickedly for God? and talk deceitfully for him?
13162	449	8	Will ye accept his person? will ye contend for God?
13163	449	9	Is it good that he should search you out? or as one man mocketh another, do ye so mock him?
13164	449	10	He will surely reprove you, if ye do secretly accept persons.
13165	449	11	Shall not his excellency make you afraid? and his dread fall upon you?
13166	449	12	Your remembrances are like unto ashes, your bodies to bodies of clay.
13167	449	13	Hold your peace, let me alone, that I may speak, and let come on me what will.
13168	449	14	Wherefore do I take my flesh in my teeth, and put my life in mine hand?
13169	449	15	Though he slay me, yet will I trust in him: but I will maintain mine own ways before him.
13170	449	16	He also shall be my salvation: for an hypocrite shall not come before him.
13171	449	17	Hear diligently my speech, and my declaration with your ears.
13172	449	18	Behold now, I have ordered my cause; I know that I shall be justified.
13173	449	19	Who is he that will plead with me? for now, if I hold my tongue, I shall give up the ghost.
13174	449	20	Only do not two things unto me: then will I not hide myself from thee.
13175	449	21	Withdraw thine hand far from me: and let not thy dread make me afraid.
13176	449	22	Then call thou, and I will answer: or let me speak, and answer thou me.
13177	449	23	How many are mine iniquities and sins? make me to know my transgression and my sin.
13178	449	24	Wherefore hidest thou thy face, and holdest me for thine enemy?
13179	449	25	Wilt thou break a leaf driven to and fro? and wilt thou pursue the dry stubble?
13180	449	26	For thou writest bitter things against me, and makest me to possess the iniquities of my youth.
13181	449	27	Thou puttest my feet also in the stocks, and lookest narrowly unto all my paths; thou settest a print upon the heels of my feet.
13182	449	28	And he, as a rotten thing, consumeth, as a garment that is moth eaten.
13183	450	1	MAN that is born of a woman is of few days, and full of trouble.
13184	450	2	He cometh forth like a flower, and is cut down: he fleeth also as a shadow, and continueth not.
13185	450	3	And dost thou open thine eyes upon such an one, and bringest me into judgment with thee?
13186	450	4	Who can bring a clean thing out of an unclean? not one.
13187	450	5	Seeing his days are determined, the number of his months are with thee, thou hast appointed his bounds that he cannot pass;
13188	450	6	Turn from him, that he may rest, till he shall accomplish, as an hireling, his day.
13189	450	7	For there is hope of a tree, if it be cut down, that it will sprout again, and that the tender branch thereof will not cease.
13190	450	8	Though the root thereof wax old in the earth, and the stock thereof die in the ground;
13191	450	9	Yet through the scent of water it will bud, and bring forth boughs like a plant.
13192	450	10	But man dieth, and wasteth away: yea, man giveth up the ghost, and where is he?
13193	450	11	As the waters fail from the sea, and the flood decayeth and drieth up:
13194	450	12	So man lieth down, and riseth not: till the heavens be no more, they shall not awake, nor be raised out of their sleep.
13195	450	13	O that thou wouldest hide me in the grave, that thou wouldest keep me secret, until thy wrath be past, that thou wouldest appoint me a set time, and remember me!
13196	450	14	If a man die, shall he live again? all the days of my appointed time will I wait, till my change come.
13197	450	15	Thou shalt call, and I will answer thee: thou wilt have a desire to the work of thine hands.
13198	450	16	For now thou numberest my steps: dost thou not watch over my sin?
13199	450	17	My transgression is sealed up in a bag, and thou sewest up mine iniquity.
13200	450	18	And surely the mountain falling cometh to nought, and the rock is removed out of his place.
13201	450	19	The waters wear the stones: thou washest away the things which grow out of the dust of the earth; and thou destroyest the hope of man.
13202	450	20	Thou prevailest for ever against him, and he passeth: thou changest his countenance, and sendest him away.
13203	450	21	His sons come to honour, and he knoweth it not; and they are brought low, but he perceiveth it not of them.
13204	450	22	But his flesh upon him shall have pain, and his soul within him shall mourn.
13205	451	1	THEN answered Eliphaz the Temanite, and said,
13206	451	2	Should a wise man utter vain knowledge, and fill his belly with the east wind?
13207	451	3	Should he reason with unprofitable talk? or with speeches wherewith he can do no good?
13208	451	4	Yea, thou castest off fear, and restrainest prayer before God.
13209	451	5	For thy mouth uttereth thine iniquity, and thou choosest the tongue of the crafty.
13210	451	6	Thine own mouth condemneth thee, and not I: yea, thine own lips testify against thee.
13211	451	7	Art thou the first man that was born? or wast thou made before the hills?
13212	451	8	Hast thou heard the secret of God? and dost thou restrain wisdom to thyself?
13213	451	9	What knowest thou, that we know not? what understandest thou, which is not in us?
13214	451	10	With us are both the grayheaded and very aged men, much elder than thy father.
13215	451	11	Are the consolations of God small with thee? is there any secret thing with thee?
13216	451	12	Why doth thine heart carry thee away? and what do thy eyes wink at,
13217	451	13	That thou turnest thy spirit against God, and lettest such words go out of thy mouth?
13218	451	14	What is man, that he should be clean? and he which is born of a woman, that he should be righteous?
13219	451	15	Behold, he putteth no trust in his saints; yea, the heavens are not clean in his sight.
13220	451	16	How much more abominable and filthy is man, which drinketh iniquity like water?
13221	451	17	I will shew thee, hear me; and that which I have seen I will declare;
13222	451	18	Which wise men have told from their fathers, and have not hid it:
13223	451	19	Unto whom alone the earth was given, and no stranger passed among them.
13224	451	20	The wicked man travaileth with pain all his days, and the number of years is hidden to the oppressor.
13225	451	21	A dreadful sound is in his ears: in prosperity the destroyer shall come upon him.
13226	451	22	He believeth not that he shall return out of darkness, and he is waited for of the sword.
13227	451	23	He wandereth abroad for bread, saying, Where is it? he knoweth that the day of darkness is ready at his hand.
13228	451	24	Trouble and anguish shall make him afraid; they shall prevail against him, as a king ready to the battle.
13229	451	25	For he stretcheth out his hand against God, and strengtheneth himself against the Almighty.
13230	451	26	He runneth upon him, even on his neck, upon the thick bosses of his bucklers:
13231	451	27	Because he covereth his face with his fatness, and maketh collops of fat on his flanks.
13232	451	28	And he dwelleth in desolate cities, and in houses which no man inhabiteth, which are ready to become heaps.
13233	451	29	He shall not be rich, neither shall his substance continue, neither shall he prolong the perfection thereof upon the earth.
13234	451	30	He shall not depart out of darkness; the flame shall dry up his branches, and by the breath of his mouth shall he go away.
13235	451	31	Let not him that is deceived trust in vanity: for vanity shall be his recompence.
13236	451	32	It shall be accomplished before his time, and his branch shall not be green.
13237	451	33	He shall shake off his unripe grape as the vine, and shall cast off his flower as the olive.
13238	451	34	For the congregation of hypocrites shall be desolate, and fire shall consume the tabernacles of bribery.
13239	451	35	They conceive mischief, and bring forth vanity, and their belly prepareth deceit.
13240	452	1	THEN Job answered and said,
13241	452	2	I have heard many such things: miserable comforters are ye all.
13242	452	3	Shall vain words have an end? or what emboldeneth thee that thou answerest?
13243	452	4	I also could speak as ye do: if your soul were in my soul's stead, I could heap up words against you, and shake mine head at you.
13244	452	5	But I would strengthen you with my mouth, and the moving of my lips should asswage your grief.
13245	452	6	Though I speak, my grief is not asswaged: and though I forbear, what am I eased?
13246	452	7	But now he hath made me weary: thou hast made desolate all my company.
13247	452	8	And thou hast filled me with wrinkles, which is a witness against me: and my leanness rising up in me beareth witness to my face.
13248	452	9	He teareth me in his wrath, who hateth me: he gnasheth upon me with his teeth; mine enemy sharpeneth his eyes upon me.
13249	452	10	They have gaped upon me with their mouth; they have smitten me upon the cheek reproachfully; they have gathered themselves together against me.
13250	452	11	God hath delivered me to the ungodly, and turned me over into the hands of the wicked.
13251	452	12	I was at ease, but he hath broken me asunder: he hath also taken me by my neck, and shaken me to pieces, and set me up for his mark.
13252	452	13	His archers compass me round about, he cleaveth my reins asunder, and doth not spare; he poureth out my gall upon the ground.
13253	452	14	He breaketh me with breach upon breach, he runneth upon me like a giant.
13254	452	15	I have sewed sackcloth upon my skin, and defiled my horn in the dust.
13255	452	16	My face is foul with weeping, and on my eyelids is the shadow of death;
13256	452	17	Not for any injustice in mine hands: also my prayer is pure.
13257	452	18	O earth, cover not thou my blood, and let my cry have no place.
13258	452	19	Also now, behold, my witness is in heaven, and my record is on high.
13259	452	20	My friends scorn me: but mine eye poureth out tears unto God.
13260	452	21	O that one might plead for a man with God, as a man pleadeth for his neighbour!
13261	452	22	When a few years are come, then I shall go the way whence I shall not return.
13262	453	1	MY breath is corrupt, my days are extinct, the graves are ready for me.
13263	453	2	Are there not mockers with me? and doth not mine eye continue in their provocation?
13264	453	3	Lay down now, put me in a surety with thee; who is he that will strike hands with me?
13265	453	4	For thou hast hid their heart from understanding: therefore shalt thou not exalt them.
13266	453	5	He that speaketh flattery to his friends, even the eyes of his children shall fail.
13267	453	6	He hath made me also a byword of the people; and aforetime I was as a tabret.
13268	453	7	Mine eye also is dim by reason of sorrow, and all my members are as a shadow.
13269	453	8	Upright men shall be astonied at this, and the innocent shall stir up himself against the hypocrite.
13270	453	9	The righteous also shall hold on his way, and he that hath clean hands shall be stronger and stronger.
13271	453	10	But as for you all, do ye return, and come now: for I cannot find one wise man among you.
13272	453	11	My days are past, my purposes are broken off, even the thoughts of my heart.
13273	453	12	They change the night into day: the light is short because of darkness.
13274	453	13	If I wait, the grave is mine house: I have made my bed in the darkness.
13275	453	14	I have said to corruption, Thou art my father: to the worm, Thou art my mother, and my sister.
13276	453	15	And where is now my hope? as for my hope, who shall see it?
13277	453	16	They shall go down to the bars of the pit, when our rest together is in the dust.
13278	454	1	THEN answered Bildad the Shuhite, and said,
13279	454	2	How long will it be ere ye make an end of words? mark, and afterwards we will speak.
13280	454	3	Wherefore are we counted as beasts, and reputed vile in your sight?
13281	454	4	He teareth himself in his anger: shall the earth be forsaken for thee? and shall the rock be removed out of his place?
13282	454	5	Yea, the light of the wicked shall be put out, and the spark of his fire shall not shine.
13283	454	6	The light shall be dark in his tabernacle, and his candle shall be put out with him.
13284	454	7	The steps of his strength shall be straitened, and his own counsel shall cast him down.
13285	454	8	For he is cast into a net by his own feet, and he walketh upon a snare.
13286	454	9	The gin shall take him by the heel, and the robber shall prevail against him.
13287	454	10	The snare is laid for him in the ground, and a trap for him in the way.
13288	454	11	Terrors shall make him afraid on every side, and shall drive him to his feet.
13289	454	12	His strength shall be hungerbitten, and destruction shall be ready at his side.
13290	454	13	It shall devour the strength of his skin: even the firstborn of death shall devour his strength.
13291	454	14	His confidence shall be rooted out of his tabernacle, and it shall bring him to the king of terrors.
13292	454	15	It shall dwell in his tabernacle, because it is none of his: brimstone shall be scattered upon his habitation.
13293	454	16	His roots shall be dried up beneath, and above shall his branch be cut off.
13294	454	17	His remembrance shall perish from the earth, and he shall have no name in the street.
13295	454	18	He shall be driven from light into darkness, and chased out of the world.
13296	454	19	He shall neither have son nor nephew among his people, nor any remaining in his dwellings.
13297	454	20	They that come after him shall be astonied at his day, as they that went before were affrighted.
13298	454	21	Surely such are the dwellings of the wicked, and this is the place of him that knoweth not God.
13299	455	1	THEN Job answered and said,
13300	455	2	How long will ye vex my soul, and break me in pieces with words?
13301	455	3	These ten times have ye reproached me: ye are not ashamed that ye make yourselves strange to me.
13302	455	4	And be it indeed that I have erred, mine error remaineth with myself.
13303	455	5	If indeed ye will magnify yourselves against me, and plead against me my reproach:
13304	455	6	Know now that God hath overthrown me, and hath compassed me with his net.
13305	455	7	Behold, I cry out of wrong, but I am not heard: I cry aloud, but there is no judgment.
13306	455	8	He hath fenced up my way that I cannot pass, and he hath set darkness in my paths.
13307	455	9	He hath stripped me of my glory, and taken the crown from my head.
13308	455	10	He hath destroyed me on every side, and I am gone: and mine hope hath he removed like a tree.
13309	455	11	He hath also kindled his wrath against me, and he counteth me unto him as one of his enemies.
13310	455	12	His troops come together, and raise up their way against me, and encamp round about my tabernacle.
13311	455	13	He hath put my brethren far from me, and mine acquaintance are verily estranged from me.
13312	455	14	My kinsfolk have failed, and my familiar friends have forgotten me.
13313	455	15	They that dwell in mine house, and my maids, count me for a stranger: I am an alien in their sight.
13314	455	16	I called my servant, and he gave me no answer; I intreated him with my mouth.
13315	455	17	My breath is strange to my wife, though I intreated for the children's sake of mine own body.
13316	455	18	Yea, young children despised me; I arose, and they spake against me.
13317	455	19	All my inward friends abhorred me: and they whom I loved are turned against me.
13318	455	20	My bone cleaveth to my skin and to my flesh, and I am escaped with the skin of my teeth.
13319	455	21	Have pity upon me, have pity upon me, O ye my friends; for the hand of God hath touched me.
13320	455	22	Why do ye persecute me as God, and are not satisfied with my flesh?
13321	455	23	Oh that my words were now written! oh that they were printed in a book!
13322	455	24	That they were graven with an iron pen and lead in the rock for ever!
13323	455	25	For I know that my redeemer liveth, and that he shall stand at the latter day upon the earth:
13324	455	26	And though after my skin worms destroy this body, yet in my flesh shall I see God:
13325	455	27	Whom I shall see for myself, and mine eyes shall behold, and not another; though my reins be consumed within me.
13326	455	28	But ye should say, Why persecute we him, seeing the root of the matter is found in me?
13327	455	29	Be ye afraid of the sword: for wrath bringeth the punishments of the sword, that ye may know there is a judgment.
13328	456	1	THEN answered Zophar the Naamathite, and said,
13329	456	2	Therefore do my thoughts cause me to answer, and for this I make haste.
13330	456	3	I have heard the check of my reproach, and the spirit of my understanding causeth me to answer.
13331	456	4	Knowest thou not this of old, since man was placed upon earth,
13332	456	5	That the triumphing of the wicked is short, and the joy of the hypocrite but for a moment?
13333	456	6	Though his excellency mount up to the heavens, and his head reach unto the clouds;
13334	456	7	Yet he shall perish for ever like his own dung: they which have seen him shall say, Where is he?
13335	456	8	He shall fly away as a dream, and shall not be found: yea, he shall be chased away as a vision of the night.
13336	456	9	The eye also which saw him shall see him no more; neither shall his place any more behold him.
13337	456	10	His children shall seek to please the poor, and his hands shall restore their goods.
13338	456	11	His bones are full of the sin of his youth, which shall lie down with him in the dust.
13339	456	12	Though wickedness be sweet in his mouth, though he hide it under his tongue;
13340	456	13	Though he spare it, and forsake it not; but keep it still within his mouth:
13341	456	14	Yet his meat in his bowels is turned, it is the gall of asps within him.
13342	456	15	He hath swallowed down riches, and he shall vomit them up again: God shall cast them out of his belly.
13343	456	16	He shall suck the poison of asps: the viper's tongue shall slay him.
13344	456	17	He shall not see the rivers, the floods, the brooks of honey and butter.
13345	456	18	That which he laboured for shall he restore, and shall not swallow it down: according to his substance shall the restitution be, and he shall not rejoice therein.
13346	456	19	Because he hath oppressed and hath forsaken the poor; because he hath violently taken away an house which he builded not;
13347	456	20	Surely he shall not feel quietness in his belly, he shall not save of that which he desired.
13348	456	21	There shall none of his meat be left; therefore shall no man look for his goods.
13349	456	22	In the fulness of his sufficiency he shall be in straits: every hand of the wicked shall come upon him.
13350	456	23	When he is about to fill his belly, God shall cast the fury of his wrath upon him, and shall rain it upon him while he is eating.
13351	456	24	He shall flee from the iron weapon, and the bow of steel shall strike him through.
13352	456	25	It is drawn, and cometh out of the body; yea, the glittering sword cometh out of his gall: terrors are upon him.
13353	456	26	All darkness shall be hid in his secret places: a fire not blown shall consume him; it shall go ill with him that is left in his tabernacle.
13354	456	27	The heaven shall reveal his iniquity; and the earth shall rise up against him.
13355	456	28	The increase of his house shall depart, and his goods shall flow away in the day of his wrath.
13356	456	29	This is the portion of a wicked man from God, and the heritage appointed unto him by God.
13357	457	1	BUT Job answered and said,
13358	457	2	Hear diligently my speech, and let this be your consolations.
13359	457	3	Suffer me that I may speak; and after that I have spoken, mock on.
13360	457	4	As for me, is my complaint to man? and if it were so, why should not my spirit be troubled?
13361	457	5	Mark me, and be astonished, and lay your hand upon your mouth.
13362	457	6	Even when I remember I am afraid, and trembling taketh hold on my flesh.
13363	457	7	Wherefore do the wicked live, become old, yea, are mighty in power?
13364	457	8	Their seed is established in their sight with them, and their offspring before their eyes.
13365	457	9	Their houses are safe from fear, neither is the rod of God upon them.
13366	457	10	Their bull gendereth, and faileth not; their cow calveth, and casteth not her calf.
13367	457	11	They send forth their little ones like a flock, and their children dance.
13368	457	12	They take the timbrel and harp, and rejoice at the sound of the organ.
13369	457	13	They spend their days in wealth, and in a moment go down to the grave.
13370	457	14	Therefore they say unto God, Depart from us; for we desire not the knowledge of thy ways.
13371	457	15	What is the Almighty, that we should serve him? and what profit should we have, if we pray unto him?
13372	457	16	Lo, their good is not in their hand: the counsel of the wicked is far from me.
13373	457	17	How oft is the candle of the wicked put out! and how oft cometh their destruction upon them! God distributeth sorrows in his anger.
13374	457	18	They are as stubble before the wind, and as chaff that the storm carrieth away.
13375	457	19	God layeth up his iniquity for his children: he rewardeth him, and he shall know it.
13376	457	20	His eyes shall see his destruction, and he shall drink of the wrath of the Almighty.
13377	457	21	For what pleasure hath he in his house after him, when the number of his months is cut off in the midst?
13378	457	22	Shall any teach God knowledge? seeing he judgeth those that are high.
13379	457	23	One dieth in his full strength, being wholly at ease and quiet.
13380	457	24	His breasts are full of milk, and his bones are moistened with marrow.
13381	457	25	And another dieth in the bitterness of his soul, and never eateth with pleasure.
13382	457	26	They shall lie down alike in the dust, and the worms shall cover them.
13383	457	27	Behold, I know your thoughts, and the devices which ye wrongfully imagine against me.
13384	457	28	For ye say, Where is the house of the prince? and where are the dwelling places of the wicked?
13385	457	29	Have ye not asked them that go by the way? and do ye not know their tokens,
13386	457	30	That the wicked is reserved to the day of destruction? they shall be brought forth to the day of wrath.
13387	457	31	Who shall declare his way to his face? and who shall repay him what he hath done?
13388	457	32	Yet shall he be brought to the grave, and shall remain in the tomb.
13389	457	33	The clods of the valley shall be sweet unto him, and every man shall draw after him, as there are innumerable before him.
13390	457	34	How then comfort ye me in vain, seeing in your answers there remaineth falsehood?
13391	458	1	THEN Eliphaz the Temanite answered and said,
13392	458	2	Can a man be profitable unto God, as he that is wise may be profitable unto himself?
13393	458	3	Is it any pleasure to the Almighty, that thou art righteous? or is it gain to him, that thou makest thy ways perfect?
13394	458	4	Will he reprove thee for fear of thee? will he enter with thee into judgment?
13395	458	5	Is not thy wickedness great? and thine iniquities infinite?
13396	458	6	For thou hast taken a pledge from thy brother for nought, and stripped the naked of their clothing.
13397	458	7	Thou hast not given water to the weary to drink, and thou hast withholden bread from the hungry.
13398	458	8	But as for the mighty man, he had the earth; and the honourable man dwelt in it.
13399	458	9	Thou hast sent widows away empty, and the arms of the fatherless have been broken.
13400	458	10	Therefore snares are round about thee, and sudden fear troubleth thee;
13401	458	11	Or darkness, that thou canst not see; and abundance of waters cover thee.
13402	458	12	Is not God in the height of heaven? and behold the height of the stars, how high they are!
13403	458	13	And thou sayest, How doth God know? can he judge through the dark cloud?
13404	458	14	Thick clouds are a covering to him, that he seeth not; and he walketh in the circuit of heaven.
13405	458	15	Hast thou marked the old way which wicked men have trodden?
13406	458	16	Which were cut down out of time, whose foundation was overflown with a flood:
13407	458	17	Which said unto God, Depart from us: and what can the Almighty do for them?
13408	458	18	Yet he filled their houses with good things: but the counsel of the wicked is far from me.
13409	458	19	The righteous see it, and are glad: and the innocent laugh them to scorn.
13410	458	20	Whereas our substance is not cut down, but the remnant of them the fire consumeth.
13411	458	21	Acquaint now thyself with him, and be at peace: thereby good shall come unto thee.
13412	458	22	Receive, I pray thee, the law from his mouth, and lay up his words in thine heart.
13413	458	23	If thou return to the Almighty, thou shalt be built up, thou shalt put away iniquity far from thy tabernacles.
13414	458	24	Then shalt thou lay up gold as dust, and the gold of Ophir as the stones of the brooks.
13415	458	25	Yea, the Almighty shall be thy defence, and thou shalt have plenty of silver.
13416	458	26	For then shalt thou have thy delight in the Almighty, and shalt lift up thy face unto God.
13417	458	27	Thou shalt make thy prayer unto him, and he shall hear thee, and thou shalt pay thy vows.
13418	458	28	Thou shalt also decree a thing, and it shall be established unto thee: and the light shall shine upon thy ways.
13419	458	29	When men are cast down, then thou shalt say, There is lifting up; and he shall save the humble person.
13420	458	30	He shall deliver the island of the innocent: and it is delivered by the pureness of thine hands.
13421	459	1	THEN Job answered and said,
13422	459	2	Even to day is my complaint bitter: my stroke is heavier than my groaning.
13423	459	3	Oh that I knew where I might find him! that I might come even to his seat!
13424	459	4	I would order my cause before him, and fill my mouth with arguments.
13425	459	5	I would know the words which he would answer me, and understand what he would say unto me.
13426	459	6	Will he plead against me with his great power? No; but he would put strength in me.
13427	459	7	There the righteous might dispute with him; so should I be delivered for ever from my judge.
13428	459	8	Behold, I go forward, but he is not there; and backward, but I cannot perceive him:
13429	459	9	On the left hand, where he doth work, but I cannot behold him: he hideth himself on the right hand, that I cannot see him:
13430	459	10	But he knoweth the way that I take: when he hath tried me, I shall come forth as gold.
13431	459	11	My foot hath held his steps, his way have I kept, and not declined.
13432	459	12	Neither have I gone back from the commandment of his lips; I have esteemed the words of his mouth more than my necessary food.
13433	459	13	But he is in one mind, and who can turn him? and what his soul desireth, even that he doeth.
13434	459	14	For he performeth the thing that is appointed for me: and many such things are with him.
13435	459	15	Therefore am I troubled at his presence: when I consider, I am afraid of him.
13436	459	16	For God maketh my heart soft, and the Almighty troubleth me:
13437	459	17	Because I was not cut off before the darkness, neither hath he covered the darkness from my face.
13438	460	1	WHY, seeing times are not hidden from the Almighty, do they that know him not see his days?
13439	460	2	Some remove the landmarks; they violently take away flocks, and feed thereof.
13440	460	3	They drive away the ass of the fatherless, they take the widow's ox for a pledge.
13441	460	4	They turn the needy out of the way: the poor of the earth hide themselves together.
13442	460	5	Behold, as wild asses in the desert, go they forth to their work; rising betimes for a prey: the wilderness yieldeth food for them and for their children.
13443	460	6	They reap every one his corn in the field: and they gather the vintage of the wicked.
13444	460	7	They cause the naked to lodge without clothing, that they have no covering in the cold.
13445	460	8	They are wet with the showers of the mountains, and embrace the rock for want of a shelter.
13446	460	9	They pluck the fatherless from the breast, and take a pledge of the poor.
13447	460	10	They cause him to go naked without clothing, and they take away the sheaf from the hungry;
13448	460	11	Which make oil within their walls, and tread their winepresses, and suffer thirst.
13449	460	12	Men groan from out of the city, and the soul of the wounded crieth out: yet God layeth not folly to them.
13450	460	13	They are of those that rebel against the light; they know not the ways thereof, nor abide in the paths thereof.
13451	460	14	The murderer rising with the light killeth the poor and needy, and in the night is as a thief.
13452	460	15	The eye also of the adulterer waiteth for the twilight, saying, No eye shall see me: and disguiseth his face.
13453	460	16	In the dark they dig through houses, which they had marked for themselves in the daytime: they know not the light.
13454	460	17	For the morning is to them even as the shadow of death: if one know them, they are in the terrors of the shadow of death.
13455	460	18	He is swift as the waters; their portion is cursed in the earth: he beholdeth not the way of the vineyards.
13456	460	19	Drought and heat consume the snow waters: so doth the grave those which have sinned.
13457	460	20	The womb shall forget him; the worm shall feed sweetly on him; he shall be no more remembered; and wickedness shall be broken as a tree.
13458	460	21	He evil entreateth the barren that beareth not: and doeth not good to the widow.
13459	460	22	He draweth also the mighty with his power: he riseth up, and no man is sure of life.
13460	460	23	Though it be given him to be in safety, whereon he resteth; yet his eyes are upon their ways.
13461	460	24	They are exalted for a little while, but are gone and brought low; they are taken out of the way as all other, and cut off as the tops of the ears of corn.
13462	460	25	And if it be not so now, who will make me a liar, and make my speech nothing worth?
13463	461	1	THEN answered Bildad the Shuhite, and said,
13464	461	2	Dominion and fear are with him, he maketh peace in his high places.
13465	461	3	Is there any number of his armies? and upon whom doth not his light arise?
13466	461	4	How then can man be justified with God? or how can he be clean that is born of a woman?
13467	461	5	Behold even to the moon, and it shineth not; yea, the stars are not pure in his sight.
13468	461	6	How much less man, that is a worm? and the son of man, which is a worm?
13469	462	1	BUT Job answered and said,
13470	462	2	How hast thou helped him that is without power? how savest thou the arm that hath no strength?
13471	462	3	How hast thou counselled him that hath no wisdom? and how hast thou plentifully declared the thing as it is?
13472	462	4	To whom hast thou uttered words? and whose spirit came from thee?
13473	462	5	Dead things are formed from under the waters, and the inhabitants thereof.
13474	462	6	Hell is naked before him, and destruction hath no covering.
13475	462	7	He stretcheth out the north over the empty place, and hangeth the earth upon nothing.
13476	462	8	He bindeth up the waters in his thick clouds; and the cloud is not rent under them.
13477	462	9	He holdeth back the face of his throne, and spreadeth his cloud upon it.
13478	462	10	He hath compassed the waters with bounds, until the day and night come to an end.
13479	462	11	The pillars of heaven tremble and are astonished at his reproof.
13480	462	12	He divideth the sea with his power, and by his understanding he smiteth through the proud.
13481	462	13	By his spirit he hath garnished the heavens; his hand hath formed the crooked serpent.
13482	462	14	Lo, these are parts of his ways: but how little a portion is heard of him? but the thunder of his power who can understand?
13483	463	1	MOREOVER Job continued his parable, and said,
13484	463	2	As God liveth, who hath taken away my judgment; and the Almighty, who hath vexed my soul;
13485	463	3	All the while my breath is in me, and the spirit of God is in my nostrils;
13486	463	4	My lips shall not speak wickedness, nor my tongue utter deceit.
13487	463	5	God forbid that I should justify you: till I die I will not remove mine integrity from me.
13488	463	6	My righteousness I hold fast, and will not let it go: my heart shall not reproach me so long as I live.
13489	463	7	Let mine enemy be as the wicked, and he that riseth up against me as the unrighteous.
13490	463	8	For what is the hope of the hypocrite, though he hath gained, when God taketh away his soul?
13491	463	9	Will God hear his cry when trouble cometh upon him?
13492	463	10	Will he delight himself in the Almighty? will he always call upon God?
13493	463	11	I will teach you by the hand of God: that which is with the Almighty will I not conceal.
13494	463	12	Behold, all ye yourselves have seen it; why then are ye thus altogether vain?
13495	463	13	This is the portion of a wicked man with God, and the heritage of oppressors, which they shall receive of the Almighty.
13496	463	14	If his children be multiplied, it is for the sword: and his offspring shall not be satisfied with bread.
13497	463	15	Those that remain of him shall be buried in death: and his widows shall not weep.
13498	463	16	Though he heap up silver as the dust, and prepare raiment as the clay;
13499	463	17	He may prepare it, but the just shall put it on, and the innocent shall divide the silver.
13500	463	18	He buildeth his house as a moth, and as a booth that the keeper maketh.
13501	463	19	The rich man shall lie down, but he shall not be gathered: he openeth his eyes, and he is not.
13502	463	20	Terrors take hold on him as waters, a tempest stealeth him away in the night.
13503	463	21	The east wind carrieth him away, and he departeth: and as a storm hurleth him out of his place.
13504	463	22	For God shall cast upon him, and not spare: he would fain flee out of his hand.
13505	463	23	Men shall clap their hands at him, and shall hiss him out of his place.
13506	464	1	SURELY there is a vein for the silver, and a place for gold where they fine it.
13507	464	2	Iron is taken out of the earth, and brass is molten out of the stone.
13508	464	3	He setteth an end to darkness, and searcheth out all perfection: the stones of darkness, and the shadow of death.
13509	464	4	The flood breaketh out from the inhabitant; even the waters forgotten of the foot: they are dried up, they are gone away from men.
13510	464	5	As for the earth, out of it cometh bread: and under it is turned up as it were fire.
13511	464	6	The stones of it are the place of sapphires: and it hath dust of gold.
13512	464	7	There is a path which no fowl knoweth, and which the vulture's eye hath not seen:
13513	464	8	The lion's whelps have not trodden it, nor the fierce lion passed by it.
13514	464	9	He putteth forth his hand upon the rock; he overturneth the mountains by the roots.
13515	464	10	He cutteth out rivers among the rocks; and his eye seeth every precious thing.
13516	464	11	He bindeth the floods from overflowing; and the thing that is hid bringeth he forth to light.
13517	464	12	But where shall wisdom be found? and where is the place of understanding?
13518	464	13	Man knoweth not the price thereof; neither is it found in the land of the living.
13519	464	14	The depth saith, It is not in me: and the sea saith, It is not with me.
13520	464	15	It cannot be gotten for gold, neither shall silver be weighed for the price thereof.
13521	464	16	It cannot be valued with the gold of Ophir, with the precious onyx, or the sapphire.
13522	464	17	The gold and the crystal cannot equal it: and the exchange of it shall not be for jewels of fine gold.
13523	464	18	No mention shall be made of coral, or of pearls: for the price of wisdom is above rubies.
13524	464	19	The topaz of Ethiopia shall not equal it, neither shall it be valued with pure gold.
13525	464	20	Whence then cometh wisdom? and where is the place of understanding?
13526	464	21	Seeing it is hid from the eyes of all living, and kept close from the fowls of the air.
13527	464	22	Destruction and death say, We have heard the fame thereof with our ears.
13528	464	23	God understandeth the way thereof, and he knoweth the place thereof.
13529	464	24	For he looketh to the ends of the earth, and seeth under the whole heaven;
13530	464	25	To make the weight for the winds; and he weigheth the waters by measure.
13531	464	26	When he made a decree for the rain, and a way for the lightning of the thunder:
13532	464	27	Then did he see it, and declare it; he prepared it, yea, and searched it out.
13533	464	28	And unto man he said, Behold, the fear of the Lord, that is wisdom; and to depart from evil is understanding.
13534	465	1	MOREOVER Job continued his parable, and said,
13535	465	2	Oh that I were as in months past, as in the days when God preserved me;
13536	465	3	When his candle shined upon my head, and when by his light I walked through darkness;
13537	465	4	As I was in the days of my youth, when the secret of God was upon my tabernacle;
13538	465	5	When the Almighty was yet with me, when my children were about me;
13539	465	6	When I washed my steps with butter, and the rock poured me out rivers of oil;
13540	465	7	When I went out to the gate through the city, when I prepared my seat in the street!
13541	465	8	The young men saw me, and hid themselves: and the aged arose, and stood up.
13542	465	9	The princes refrained talking, and laid their hand on their mouth.
13543	465	10	The nobles held their peace, and their tongue cleaved to the roof of their mouth.
13544	465	11	When the ear heard me, then it blessed me; and when the eye saw me, it gave witness to me:
13545	465	12	Because I delivered the poor that cried, and the fatherless, and him that had none to help him.
13546	465	13	The blessing of him that was ready to perish came upon me: and I caused the widow's heart to sing for joy.
13547	465	14	I put on righteousness, and it clothed me: my judgment was as a robe and a diadem.
13548	465	15	I was eyes to the blind, and feet was I to the lame.
13549	465	16	I was a father to the poor: and the cause which I knew not I searched out.
13550	465	17	And I brake the jaws of the wicked, and plucked the spoil out of his teeth.
13551	465	18	Then I said, I shall die in my nest, and I shall multiply my days as the sand.
13552	465	19	My root was spread out by the waters, and the dew lay all night upon my branch.
13553	465	20	My glory was fresh in me, and my bow was renewed in my hand.
13554	465	21	Unto me men gave ear, and waited, and kept silence at my counsel.
13555	465	22	After my words they spake not again; and my speech dropped upon them.
13556	465	23	And they waited for me as for the rain; and they opened their mouth wide as for the latter rain.
13557	465	24	If I laughed on them, they believed it not; and the light of my countenance they cast not down.
13558	465	25	I chose out their way, and sat chief, and dwelt as a king in the army, as one that comforteth the mourners.
13559	466	1	BUT now they that are younger than I have me in derision, whose fathers I would have disdained to have set with the dogs of my flock.
13560	466	2	Yea, whereto might the strength of their hands profit me, in whom old age was perished?
13561	466	3	For want and famine they were solitary; fleeing into the wilderness in former time desolate and waste.
13562	466	4	Who cut up mallows by the bushes, and juniper roots for their meat.
13563	466	5	They were driven forth from among men, (they cried after them as after a thief;)
13564	466	6	To dwell in the clifts of the valleys, in caves of the earth, and in the rocks.
13565	466	7	Among the bushes they brayed; under the nettles they were gathered together.
13566	466	8	They were children of fools, yea, children of base men: they were viler than the earth.
13567	466	9	And now am I their song, yea, I am their byword.
13568	466	10	They abhor me, they flee far from me, and spare not to spit in my face.
13569	466	11	Because he hath loosed my cord, and afflicted me, they have also let loose the bridle before me.
13570	466	12	Upon my right hand rise the youth; they push away my feet, and they raise up against me the ways of their destruction.
13571	466	13	They mar my path, they set forward my calamity, they have no helper.
13572	466	14	They came upon me as a wide breaking in of waters: in the desolation they rolled themselves upon me.
13573	466	15	Terrors are turned upon me: they pursue my soul as the wind: and my welfare passeth away as a cloud.
13574	466	16	And now my soul is poured out upon me; the days of affliction have taken hold upon me.
13575	466	17	My bones are pierced in me in the night season: and my sinews take no rest.
13576	466	18	By the great force of my disease is my garment changed: it bindeth me about as the collar of my coat.
13577	466	19	He hath cast me into the mire, and I am become like dust and ashes.
13578	466	20	I cry unto thee, and thou dost not hear me: I stand up, and thou regardest me not.
13579	466	21	Thou art become cruel to me: with thy strong hand thou opposest thyself against me.
13580	466	22	Thou liftest me up to the wind; thou causest me to ride upon it, and dissolvest my substance.
13581	466	23	For I know that thou wilt bring me to death, and to the house appointed for all living.
13582	466	24	Howbeit he will not stretch out his hand to the grave, though they cry in his destruction.
13583	466	25	Did not I weep for him that was in trouble? was not my soul grieved for the poor?
13584	466	26	When I looked for good, then evil came unto me: and when I waited for light, there came darkness.
13585	466	27	My bowels boiled, and rested not: the days of affliction prevented me.
13586	466	28	I went mourning without the sun: I stood up, and I cried in the congregation.
13587	466	29	I am a brother to dragons, and a companion to owls.
13588	466	30	My skin is black upon me, and my bones are burned with heat.
13589	466	31	My harp also is turned to mourning, and my organ into the voice of them that weep.
13590	467	1	I made a covenant with mine eyes; why then should I think upon a maid?
13591	467	2	For what portion of God is there from above? and what inheritance of the Almighty from on high?
13592	467	3	Is not destruction to the wicked? and a strange punishment to the workers of iniquity?
13593	467	4	Doth not he see my ways, and count all my steps?
13594	467	5	If I have walked with vanity, or if my foot hath hasted to deceit;
13595	467	6	Let me be weighed in an even balance, that God may know mine integrity.
13596	467	7	If my step hath turned out of the way, and mine heart walked after mine eyes, and if any blot hath cleaved to mine hands;
13597	467	8	Then let me sow, and let another eat; yea, let my offspring be rooted out.
13598	467	9	If mine heart have been deceived by a woman, or if I have laid wait at my neighbour's door;
13599	467	10	Then let my wife grind unto another, and let others bow down upon her.
13600	467	11	For this is an heinous crime; yea, it is an iniquity to be punished by the judges.
13601	467	12	For it is a fire that consumeth to destruction, and would root out all mine increase.
13602	467	13	If I did despise the cause of my manservant or of my maidservant, when they contended with me;
13603	467	14	What then shall I do when God riseth up? and when he visiteth, what shall I answer him?
13604	467	15	Did not he that made me in the womb make him? and did not one fashion us in the womb?
13605	467	16	If I have withheld the poor from their desire, or have caused the eyes of the widow to fail;
13606	467	17	Or have eaten my morsel myself alone, and the fatherless hath not eaten thereof;
13607	467	18	(For from my youth he was brought up with me, as with a father, and I have guided her from my mother's womb;)
13608	467	19	If I have seen any perish for want of clothing, or any poor without covering;
13609	467	20	If his loins have not blessed me, and if he were not warmed with the fleece of my sheep;
13610	467	21	If I have lifted up my hand against the fatherless, when I saw my help in the gate:
13611	467	22	Then let mine arm fall from my shoulder blade, and mine arm be broken from the bone.
13612	467	23	For destruction from God was a terror to me, and by reason of his highness I could not endure.
13613	467	24	If I have made gold my hope, or have said to the fine gold, Thou art my confidence;
13614	467	25	If I rejoiced because my wealth was great, and because mine hand had gotten much;
13615	467	26	If I beheld the sun when it shined, or the moon walking in brightness;
13616	467	27	And my heart hath been secretly enticed, or my mouth hath kissed my hand:
13617	467	28	This also were an iniquity to be punished by the judge: for I should have denied the God that is above.
13618	467	29	If I rejoiced at the destruction of him that hated me, or lifted up myself when evil found him:
13619	467	30	Neither have I suffered my mouth to sin by wishing a curse to his soul.
13620	467	31	If the men of my tabernacle said not, Oh that we had of his flesh! we cannot be satisfied.
13621	467	32	The stranger did not lodge in the street: but I opened my doors to the traveller.
13622	467	33	If I covered my transgressions as Adam, by hiding mine iniquity in my bosom:
13623	467	34	Did I fear a great multitude, or did the contempt of families terrify me, that I kept silence, and went not out of the door?
13624	467	35	Oh that one would hear me! behold, my desire is, that the Almighty would answer me, and that mine adversary had written a book.
13625	467	36	Surely I would take it upon my shoulder, and bind it as a crown to me.
13626	467	37	I would declare unto him the number of my steps; as a prince would I go near unto him.
13627	467	38	If my land cry against me, or that the furrows likewise thereof complain;
13628	467	39	If I have eaten the fruits thereof without money, or have caused the owners thereof to lose their life:
13629	467	40	Let thistles grow instead of wheat, and cockle instead of barley. The words of Job are ended.
13630	468	1	SO these three men ceased to answer Job, because he was righteous in his own eyes.
13631	468	2	Then was kindled the wrath of Elihu the son of Barachel the Buzite, of the kindred of Ram: against Job was his wrath kindled, because he justified himself rather than God.
13632	468	3	Also against his three friends was his wrath kindled, because they had found no answer, and yet had condemned Job.
13633	468	4	Now Elihu had waited till Job had spoken, because they were elder than he.
13634	468	5	When Elihu saw that there was no answer in the mouth of these three men, then his wrath was kindled.
13635	468	6	And Elihu the son of Barachel the Buzite answered and said, I am young, and ye are very old; wherefore I was afraid, and durst not shew you mine opinion.
13636	468	7	I said, Days should speak, and multitude of years should teach wisdom.
13637	468	8	But there is a spirit in man: and the inspiration of the Almighty giveth them understanding.
13638	468	9	Great men are not always wise: neither do the aged understand judgment.
13639	468	10	Therefore I said, Hearken to me; I also will shew mine opinion.
13640	468	11	Behold, I waited for your words; I gave ear to your reasons, whilst ye searched out what to say.
13641	468	12	Yea, I attended unto you, and, behold, there was none of you that convinced Job, or that answered his words:
13642	468	13	Lest ye should say, We have found out wisdom: God thrusteth him down, not man.
13643	468	14	Now he hath not directed his words against me: neither will I answer him with your speeches.
13644	468	15	They were amazed, they answered no more: they left off speaking.
13645	468	16	When I had waited, (for they spake not, but stood still, and answered no more;)
13646	468	17	I said, I will answer also my part, I also will shew mine opinion.
13647	468	18	For I am full of matter, the spirit within me constraineth me.
13648	468	19	Behold, my belly is as wine which hath no vent; it is ready to burst like new bottles.
13649	468	20	I will speak, that I may be refreshed: I will open my lips and answer.
13650	468	21	Let me not, I pray you, accept any man's person, neither let me give flattering titles unto man.
13651	468	22	For I know not to give flattering titles; in so doing my maker would soon take me away.
13652	469	1	WHEREFORE, Job, I pray thee, hear my speeches, and hearken to all my words.
13653	469	2	Behold, now I have opened my mouth, my tongue hath spoken in my mouth.
13654	469	3	My words shall be of the uprightness of my heart: and my lips shall utter knowledge clearly.
13655	469	4	The Spirit of God hath made me, and the breath of the Almighty hath given me life.
13656	469	5	If thou canst answer me, set thy words in order before me, stand up.
13657	469	6	Behold, I am according to thy wish in God's stead: I also am formed out of the clay.
13658	469	7	Behold, my terror shall not make thee afraid, neither shall my hand be heavy upon thee.
13659	469	8	Surely thou hast spoken in mine hearing, and I have heard the voice of thy words, saying,
13660	469	9	I am clean without transgression, I am innocent; neither is there iniquity in me.
13661	469	10	Behold, he findeth occasions against me, he counteth me for his enemy,
13662	469	11	He putteth my feet in the stocks, he marketh all my paths.
13663	469	12	Behold, in this thou art not just: I will answer thee, that God is greater than man.
13664	469	13	Why dost thou strive against him? for he giveth not account of any of his matters.
13665	469	14	For God speaketh once, yea twice, yet man perceiveth it not.
13666	469	15	In a dream, in a vision of the night, when deep sleep falleth upon men, in slumberings upon the bed;
13667	469	16	Then he openeth the ears of men, and sealeth their instruction,
13668	469	17	That he may withdraw man from his purpose, and hide pride from man.
13669	469	18	He keepeth back his soul from the pit, and his life from perishing by the sword.
13670	469	19	He is chastened also with pain upon his bed, and the multitude of his bones with strong pain:
13671	469	20	So that his life abhorreth bread, and his soul dainty meat.
13672	469	21	His flesh is consumed away, that it cannot be seen; and his bones that were not seen stick out.
13673	469	22	Yea, his soul draweth near unto the grave, and his life to the destroyers.
13674	469	23	If there be a messenger with him, an interpreter, one among a thousand, to shew unto man his uprightness:
13675	469	24	Then he is gracious unto him, and saith, Deliver him from going down to the pit: I have found a ransom.
13676	469	25	His flesh shall be fresher than a child's: he shall return to the days of his youth:
13677	469	26	He shall pray unto God, and he will be favourable unto him: and he shall see his face with joy: for he will render unto man his righteousness.
13678	469	27	He looketh upon men, and if any say, I have sinned, and perverted that which was right, and it profited me not;
13679	469	28	He will deliver his soul from going into the pit, and his life shall see the light.
13680	469	29	Lo, all these things worketh God oftentimes with man,
13681	469	30	To bring back his soul from the pit, to be enlightened with the light of the living.
13682	469	31	Mark well, O Job, hearken unto me: hold thy peace, and I will speak.
13683	469	32	If thou hast any thing to say, answer me: speak, for I desire to justify thee.
13684	469	33	If not, hearken unto me: hold thy peace, and I shall teach thee wisdom.
13685	470	1	FURTHERMORE Elihu answered and said,
13686	470	2	Hear my words, O ye wise men; and give ear unto me, ye that have knowledge.
13687	470	3	For the ear trieth words, as the mouth tasteth meat.
13688	470	4	Let us choose to us judgment: let us know among ourselves what is good.
13689	470	5	For Job hath said, I am righteous: and God hath taken away my judgment.
13690	470	6	Should I lie against my right? my wound is incurable without transgression.
13691	470	7	What man is like Job, who drinketh up scorning like water?
13692	470	8	Which goeth in company with the workers of iniquity, and walketh with wicked men.
13693	470	9	For he hath said, It profiteth a man nothing that he should delight himself with God.
13694	470	10	Therefore hearken unto me, ye men of understanding: far be it from God, that he should do wickedness; and from the Almighty, that he should commit iniquity.
13695	470	11	For the work of a man shall he render unto him, and cause every man to find according to his ways.
13696	470	12	Yea, surely God will not do wickedly, neither will the Almighty pervert judgment.
13697	470	13	Who hath given him a charge over the earth? or who hath disposed the whole world?
13698	470	14	If he set his heart upon man, if he gather unto himself his spirit and his breath;
13699	470	15	All flesh shall perish together, and man shall turn again unto dust.
13700	470	16	If now thou hast understanding, hear this: hearken to the voice of my words.
13701	470	17	Shall even he that hateth right govern? and wilt thou condemn him that is most just?
13702	470	18	Is it fit to say to a king, Thou art wicked? and to princes, Ye are ungodly?
13703	470	19	How much less to him that accepteth not the persons of princes, nor regardeth the rich more than the poor? for they all are the work of his hands.
13704	470	20	In a moment shall they die, and the people shall be troubled at midnight, and pass away: and the mighty shall be taken away without hand.
13705	470	21	For his eyes are upon the ways of man, and he seeth all his goings.
13706	470	22	There is no darkness, nor shadow of death, where the workers of iniquity may hide themselves.
13707	470	23	For he will not lay upon man more than right; that he should enter into judgment with God.
13708	470	24	He shall break in pieces mighty men without number, and set others in their stead.
13709	470	25	Therefore he knoweth their works, and he overturneth them in the night, so that they are destroyed.
13710	470	26	He striketh them as wicked men in the open sight of others;
13711	470	27	Because they turned back from him, and would not consider any of his ways:
13712	470	28	So that they cause the cry of the poor to come unto him, and he heareth the cry of the afflicted.
13713	470	29	When he giveth quietness, who then can make trouble? and when he hideth his face, who then can behold him? whether it be done against a nation, or against a man only:
13714	470	30	That the hypocrite reign not, lest the people be ensnared.
13715	470	31	Surely it is meet to be said unto God, I have borne chastisement, I will not offend any more:
13716	470	32	That which I see not teach thou me: if I have done iniquity, I will do no more.
13717	470	33	Should it be according to thy mind? he will recompense it, whether thou refuse, or whether thou choose; and not I: therefore speak what thou knowest.
13718	470	34	Let men of understanding tell me, and let a wise man hearken unto me.
13719	470	35	Job hath spoken without knowledge, and his words were without wisdom.
13720	470	36	My desire is that Job may be tried unto the end because of his answers for wicked men.
13721	470	37	For he addeth rebellion unto his sin, he clappeth his hands among us, and multiplieth his words against God.
13722	471	1	ELIHU spake moreover, and said,
13723	471	2	Thinkest thou this to be right, that thou saidst, My righteousness is more than God's?
13724	471	3	For thou saidst, What advantage will it be unto thee? and, What profit shall I have, if I be cleansed from my sin?
13725	471	4	I will answer thee, and thy companions with thee.
13726	471	5	Look unto the heavens, and see; and behold the clouds which are higher than thou.
13727	471	6	If thou sinnest, what doest thou against him? or if thy transgressions be multiplied, what doest thou unto him?
13728	471	7	If thou be righteous, what givest thou him? or what receiveth he of thine hand?
13729	471	8	Thy wickedness may hurt a man as thou art; and thy righteousness may profit the son of man.
13730	471	9	By reason of the multitude of oppressions they make the oppressed to cry: they cry out by reason of the arm of the mighty.
13731	471	10	But none saith, Where is God my maker, who giveth songs in the night;
13732	471	11	Who teacheth us more than the beasts of the earth, and maketh us wiser than the fowls of heaven?
13733	471	12	There they cry, but none giveth answer, because of the pride of evil men.
13734	471	13	Surely God will not hear vanity, neither will the Almighty regard it.
13735	471	14	Although thou sayest thou shalt not see him, yet judgment is before him; therefore trust thou in him.
13736	471	15	But now, because it is not so, he hath visited in his anger; yet he knoweth it not in great extremity:
13737	471	16	Therefore doth Job open his mouth in vain; he multiplieth words without knowledge.
13738	472	1	ELIHU also proceeded, and said,
13739	472	2	Suffer me a little, and I will shew thee that I have yet to speak on God's behalf.
13740	472	3	I will fetch my knowledge from afar, and will ascribe righteousness to my Maker.
13741	472	4	For truly my words shall not be false: he that is perfect in knowledge is with thee.
13742	472	5	Behold, God is mighty, and despiseth not any: he is mighty in strength and wisdom.
13743	472	6	He preserveth not the life of the wicked: but giveth right to the poor.
13744	472	7	He withdraweth not his eyes from the righteous: but with kings are they on the throne; yea, he doth establish them for ever, and they are exalted.
13745	472	8	And if they be bound in fetters, and be holden in cords of affliction;
13746	472	9	Then he sheweth them their work, and their transgressions that they have exceeded.
13747	472	10	He openeth also their ear to discipline, and commandeth that they return from iniquity.
13748	472	11	If they obey and serve him, they shall spend their days in prosperity, and their years in pleasures.
13749	472	12	But if they obey not, they shall perish by the sword, and they shall die without knowledge.
13750	472	13	But the hypocrites in heart heap up wrath: they cry not when he bindeth them.
13751	472	14	They die in youth, and their life is among the unclean.
13752	472	15	He delivereth the poor in his affliction, and openeth their ears in oppression.
13753	472	16	Even so would he have removed thee out of the strait into a broad place, where there is no straitness; and that which should be set on thy table should be full of fatness.
13754	472	17	But thou hast fulfilled the judgment of the wicked: judgment and justice take hold on thee.
13755	472	18	Because there is wrath, beware lest he take thee away with his stroke: then a great ransom cannot deliver thee.
13756	472	19	Will he esteem thy riches? no, not gold, nor all the forces of strength.
13757	472	20	Desire not the night, when people are cut off in their place.
13758	472	21	Take heed, regard not iniquity: for this hast thou chosen rather than affliction.
13759	472	22	Behold, God exalteth by his power: who teacheth like him?
13760	472	23	Who hath enjoined him his way? or who can say, Thou hast wrought iniquity?
13761	472	24	Remember that thou magnify his work, which men behold.
13762	472	25	Every man may see it; man may behold it afar off.
13763	472	26	Behold, God is great, and we know him not, neither can the number of his years be searched out.
13764	472	27	For he maketh small the drops of water: they pour down rain according to the vapour thereof:
13765	472	28	Which the clouds do drop and distil upon man abundantly.
13766	472	29	Also can any understand the spreadings of the clouds, or the noise of his tabernacle?
13767	472	30	Behold, he spreadeth his light upon it, and covereth the bottom of the sea.
13768	472	31	For by them judgeth he the people; he giveth meat in abundance.
13769	472	32	With clouds he covereth the light; and commandeth it not to shine by the cloud that cometh betwixt.
13770	472	33	The noise thereof sheweth concerning it, the cattle also concerning the vapour.
13771	473	1	AT this also my heart trembleth, and is moved out of his place.
13772	473	2	Hear attentively the noise of his voice, and the sound that goeth out of his mouth.
13773	473	3	He directeth it under the whole heaven, and his lightning unto the ends of the earth.
13774	473	4	After it a voice roareth: he thundereth with the voice of his excellency; and he will not stay them when his voice is heard.
13775	473	5	God thundereth marvellously with his voice; great things doeth he, which we cannot comprehend.
13776	473	6	For he saith to the snow, Be thou on the earth; likewise to the small rain, and to the great rain of his strength.
13777	473	7	He sealeth up the hand of every man; that all men may know his work.
13778	473	8	Then the beasts go into dens, and remain in their places.
13779	473	9	Out of the south cometh the whirlwind: and cold out of the north.
13780	473	10	By the breath of God frost is given: and the breadth of the waters is straitened.
13781	473	11	Also by watering he wearieth the thick cloud: he scattereth his bright cloud:
13782	473	12	And it is turned round about by his counsels: that they may do whatsoever he commandeth them upon the face of the world in the earth.
13783	473	13	He causeth it to come, whether for correction, or for his land, or for mercy.
13784	473	14	Hearken unto this, O Job: stand still, and consider the wondrous works of God.
13785	473	15	Dost thou know when God disposed them, and caused the light of his cloud to shine?
13786	473	16	Dost thou know the balancings of the clouds, the wondrous works of him which is perfect in knowledge?
13787	473	17	How thy garments are warm, when he quieteth the earth by the south wind?
13788	473	18	Hast thou with him spread out the sky, which is strong, and as a molten looking glass?
13789	473	19	Teach us what we shall say unto him; for we cannot order our speech by reason of darkness.
13790	473	20	Shall it be told him that I speak? if a man speak, surely he shall be swallowed up.
13791	473	21	And now men see not the bright light which is in the clouds: but the wind passeth, and cleanseth them.
13792	473	22	Fair weather cometh out of the north: with God is terrible majesty.
13793	473	23	Touching the Almighty, we cannot find him out: he is excellent in power, and in judgment, and in plenty of justice: he will not afflict.
13794	473	24	Men do therefore fear him: he respecteth not any that are wise of heart.
13795	474	1	THEN the LORD answered Job out of the whirlwind, and said,
13796	474	2	Who is this that darkeneth counsel by words without knowledge?
13797	474	3	Gird up now thy loins like a man; for I will demand of thee, and answer thou me.
13798	474	4	Where wast thou when I laid the foundations of the earth? declare, if thou hast understanding.
13799	474	5	Who hath laid the measures thereof, if thou knowest? or who hath stretched the line upon it?
13800	474	6	Whereupon are the foundations thereof fastened? or who laid the corner stone thereof;
13801	474	7	When the morning stars sang together, and all the sons of God shouted for joy?
13802	474	8	Or who shut up the sea with doors, when it brake forth, as if it had issued out of the womb?
13803	474	9	When I made the cloud the garment thereof, and thick darkness a swaddlingband for it,
13804	474	10	And brake up for it my decreed place, and set bars and doors,
13805	474	11	And said, Hitherto shalt thou come, but no further: and here shall thy proud waves be stayed?
13806	474	12	Hast thou commanded the morning since thy days; and caused the dayspring to know his place;
13807	474	13	That it might take hold of the ends of the earth, that the wicked might be shaken out of it?
13808	474	14	It is turned as clay to the seal; and they stand as a garment.
13809	474	15	And from the wicked their light is withholden, and the high arm shall be broken.
13810	474	16	Hast thou entered into the springs of the sea? or hast thou walked in the search of the depth?
13811	474	17	Have the gates of death been opened unto thee? or hast thou seen the doors of the shadow of death?
13812	474	18	Hast thou perceived the breadth of the earth? declare if thou knowest it all.
13813	474	19	Where is the way where light dwelleth? and as for darkness, where is the place thereof,
13814	474	20	That thou shouldest take it to the bound thereof, and that thou shouldest know the paths to the house thereof?
13815	474	21	Knowest thou it, because thou wast then born? or because the number of thy days is great?
13816	474	22	Hast thou entered into the treasures of the snow? or hast thou seen the treasures of the hail,
13817	474	23	Which I have reserved against the time of trouble, against the day of battle and war?
13818	474	24	By what way is the light parted, which scattereth the east wind upon the earth?
13819	474	25	Who hath divided a watercourse for the overflowing of waters, or a way for the lightning of thunder;
13820	474	26	To cause it to rain on the earth, where no man is; on the wilderness, wherein there is no man;
13821	474	27	To satisfy the desolate and waste ground; and to cause the bud of the tender herb to spring forth?
13822	474	28	Hath the rain a father? or who hath begotten the drops of dew?
13823	474	29	Out of whose womb came the ice? and the hoary frost of heaven, who hath gendered it?
13824	474	30	The waters are hid as with a stone, and the face of the deep is frozen.
13825	474	31	Canst thou bind the sweet influences of Pleiades, or loose the bands of Orion?
13826	474	32	Canst thou bring forth Mazzaroth in his season? or canst thou guide Arcturus with his sons?
13827	474	33	Knowest thou the ordinances of heaven? canst thou set the dominion thereof in the earth?
13828	474	34	Canst thou lift up thy voice to the clouds, that abundance of waters may cover thee?
13829	474	35	Canst thou send lightnings, that they may go, and say unto thee, Here we are?
13830	474	36	Who hath put wisdom in the inward parts? or who hath given understanding to the heart?
13831	474	37	Who can number the clouds in wisdom? or who can stay the bottles of heaven,
13832	474	38	When the dust groweth into hardness, and the clods cleave fast together?
13833	474	39	Wilt thou hunt the prey for the lion? or fill the appetite of the young lions,
13834	474	40	When they couch in their dens, and abide in the covert to lie in wait?
13835	474	41	Who provideth for the raven his food? when his young ones cry unto God, they wander for lack of meat.
13836	475	1	KNOWEST thou the time when the wild goats of the rock bring forth? or canst thou mark when the hinds do calve?
13837	475	2	Canst thou number the months that they fulfil? or knowest thou the time when they bring forth?
13838	475	3	They bow themselves, they bring forth their young ones, they cast out their sorrows.
13839	475	4	Their young ones are in good liking, they grow up with corn; they go forth, and return not unto them.
13840	475	5	Who hath sent out the wild ass free? or who hath loosed the bands of the wild ass?
13841	475	6	Whose house I have made the wilderness, and the barren land his dwellings.
13842	475	7	He scorneth the multitude of the city, neither regardeth he the crying of the driver.
13843	475	8	The range of the mountains is his pasture, and he searcheth after every green thing.
13844	475	9	Will the unicorn be willing to serve thee, or abide by thy crib?
13845	475	10	Canst thou bind the unicorn with his band in the furrow? or will he harrow the valleys after thee?
13846	475	11	Wilt thou trust him, because his strength is great? or wilt thou leave thy labour to him?
13847	475	12	Wilt thou believe him, that he will bring home thy seed, and gather it into thy barn?
13848	475	13	Gavest thou the goodly wings unto the peacocks? or wings and feathers unto the ostrich?
13849	475	14	Which leaveth her eggs in the earth, and warmeth them in dust,
13850	475	15	And forgetteth that the foot may crush them, or that the wild beast may break them.
13851	475	16	She is hardened against her young ones, as though they were not hers: her labour is in vain without fear;
13852	475	17	Because God hath deprived her of wisdom, neither hath he imparted to her understanding.
13853	475	18	What time she lifteth up herself on high, she scorneth the horse and his rider.
13854	475	19	Hast thou given the horse strength? hast thou clothed his neck with thunder?
13855	475	20	Canst thou make him afraid as a grasshopper? the glory of his nostrils is terrible.
13856	475	21	He paweth in the valley, and rejoiceth in his strength: he goeth on to meet the armed men.
13857	475	22	He mocketh at fear, and is not affrighted; neither turneth he back from the sword.
13858	475	23	The quiver rattleth against him, the glittering spear and the shield.
13859	475	24	He swalloweth the ground with fierceness and rage: neither believeth he that it is the sound of the trumpet.
13860	475	25	He saith among the trumpets, Ha, ha; and he smelleth the battle afar off, the thunder of the captains, and the shouting.
13861	475	26	Doth the hawk fly by thy wisdom, and stretch her wings toward the south?
13862	475	27	Doth the eagle mount up at thy command, and make her nest on high?
13863	475	28	She dwelleth and abideth on the rock, upon the crag of the rock, and the strong place.
13864	475	29	From thence she seeketh the prey, and her eyes behold afar off.
13865	475	30	Her young ones also suck up blood: and where the slain are, there is she.
13866	476	1	MOREOVER the LORD answered Job, and said,
13867	476	2	Shall he that contendeth with the Almighty instruct him? he that reproveth God, let him answer it.
13868	476	3	Then Job answered the LORD, and said,
13869	476	4	Behold, I am vile; what shall I answer thee? I will lay mine hand upon my mouth.
13870	476	5	Once have I spoken; but I will not answer: yea, twice; but I will proceed no further.
13871	476	6	Then answered the LORD unto Job out of the whirlwind, and said,
13872	476	7	Gird up thy loins now like a man: I will demand of thee, and declare thou unto me.
13873	476	8	Wilt thou also disannul my judgment? wilt thou condemn me, that thou mayest be righteous?
13874	476	9	Hast thou an arm like God? or canst thou thunder with a voice like him?
13875	476	10	Deck thyself now with majesty and excellency; and array thyself with glory and beauty.
13876	476	11	Cast abroad the rage of thy wrath: and behold every one that is proud, and abase him.
13877	476	12	Look on every one that is proud, and bring him low; and tread down the wicked in their place.
13878	476	13	Hide them in the dust together; and bind their faces in secret.
13879	476	14	Then will I also confess unto thee that thine own right hand can save thee.
13880	476	15	Behold now behemoth, which I made with thee; he eateth grass as an ox.
13881	476	16	Lo now, his strength is in his loins, and his force is in the navel of his belly.
13882	476	17	He moveth his tail like a cedar: the sinews of his stones are wrapped together.
13883	476	18	His bones are as strong pieces of brass; his bones are like bars of iron.
13884	476	19	He is the chief of the ways of God: he that made him can make his sword to approach unto him.
13885	476	20	Surely the mountains bring him forth food, where all the beasts of the field play.
13886	476	21	He lieth under the shady trees, in the covert of the reed, and fens.
13887	476	22	The shady trees cover him with their shadow; the willows of the brook compass him about.
13888	476	23	Behold, he drinketh up a river, and hasteth not: he trusteth that he can draw up Jordan into his mouth.
13889	476	24	He taketh it with his eyes: his nose pierceth through snares.
13890	477	1	CANST thou draw out leviathan with an hook? or his tongue with a cord which thou lettest down?
13891	477	2	Canst thou put an hook into his nose? or bore his jaw through with a thorn?
13892	477	3	Will he make many supplications unto thee? will he speak soft words unto thee?
13893	477	4	Will he make a covenant with thee? wilt thou take him for a servant for ever?
13894	477	5	Wilt thou play with him as with a bird? or wilt thou bind him for thy maidens?
13895	477	6	Shall the companions make a banquet of him? shall they part him among the merchants?
13896	477	7	Canst thou fill his skin with barbed iron? or his head with fish spears?
13897	477	8	Lay thine hand upon him, remember the battle, do no more.
13898	477	9	Behold, the hope of him is in vain: shall not one be cast down even at the sight of him?
13899	477	10	None is so fierce that dare stir him up: who then is able to stand before me?
13900	477	11	Who hath prevented me, that I should repay him? whatsoever is under the whole heaven is mine.
13901	477	12	I will not conceal his parts, nor his power, nor his comely proportion.
13902	477	13	Who can discover the face of his garment? or who can come to him with his double bridle?
13903	477	14	Who can open the doors of his face? his teeth are terrible round about.
13904	477	15	His scales are his pride, shut up together as with a close seal.
13905	477	16	One is so near to another, that no air can come between them.
13906	477	17	They are joined one to another, they stick together, that they cannot be sundered.
13907	477	18	By his neesings a light doth shine, and his eyes are like the eyelids of the morning.
13908	477	19	Out of his mouth go burning lamps, and sparks of fire leap out.
13909	477	20	Out of his nostrils goeth smoke, as out of a seething pot or caldron.
13910	477	21	His breath kindleth coals, and a flame goeth out of his mouth.
13911	477	22	In his neck remaineth strength, and sorrow is turned into joy before him.
13912	477	23	The flakes of his flesh are joined together: they are firm in themselves; they cannot be moved.
13913	477	24	His heart is as firm as a stone; yea, as hard as a piece of the nether millstone.
13914	477	25	When he raiseth up himself, the mighty are afraid: by reason of breakings they purify themselves.
13915	477	26	The sword of him that layeth at him cannot hold: the spear, the dart, nor the habergeon.
13916	477	27	He esteemeth iron as straw, and brass as rotten wood.
13917	477	28	The arrow cannot make him flee: slingstones are turned with him into stubble.
13918	477	29	Darts are counted as stubble: he laugheth at the shaking of a spear.
13919	477	30	Sharp stones are under him: he spreadeth sharp pointed things upon the mire.
13920	477	31	He maketh the deep to boil like a pot: he maketh the sea like a pot of ointment.
13921	477	32	He maketh a path to shine after him; one would think the deep to be hoary.
13922	477	33	Upon earth there is not his like, who is made without fear.
13923	477	34	He beholdeth all high things: he is a king over all the children of pride.
13924	478	1	THEN Job answered the LORD, and said,
13925	478	2	I know that thou canst do every thing, and that no thought can be withholden from thee.
13926	478	3	Who is he that hideth counsel without knowledge? therefore have I uttered that I understood not; things too wonderful for me, which I knew not.
13927	478	4	Hear, I beseech thee, and I will speak: I will demand of thee, and declare thou unto me.
13928	478	5	I have heard of thee by the hearing of the ear: but now mine eye seeth thee.
13929	478	6	Wherefore I abhor myself, and repent in dust and ashes.
13930	478	7	And it was so, that after the LORD had spoken these words unto Job, the LORD said to Eliphaz the Temanite, My wrath is kindled against thee, and against thy two friends: for ye have not spoken of me the thing that is right, as my servant Job hath.
13931	478	8	Therefore take unto you now seven bullocks and seven rams, and go to my servant Job, and offer up for yourselves a burnt offering; and my servant Job shall pray for you: for him will I accept: lest I deal with you after your folly, in that ye have not spoken of me the thing which is right, like my servant Job.
13932	478	9	So Eliphaz the Temanite and Bildad the Shuhite and Zophar the Naamathite went, and did according as the LORD commanded them: the LORD also accepted Job.
13933	478	10	And the LORD turned the captivity of Job, when he prayed for his friends: also the LORD gave Job twice as much as he had before.
13934	478	11	Then came there unto him all his brethren, and all his sisters, and all they that had been of his acquaintance before, and did eat bread with him in his house: and they bemoaned him, and comforted him over all the evil that the LORD had brought upon him: every man also gave him a piece of money, and every one an earring of gold.
13935	478	12	So the LORD blessed the latter end of Job more than his beginning: for he had fourteen thousand sheep, and six thousand camels, and a thousand yoke of oxen, and a thousand she asses.
13936	478	13	He had also seven sons and three daughters.
13937	478	14	And he called the name of the first, Jemima; and the name of the second, Kezia; and the name of the third, Keren-happuch.
13938	478	15	And in all the land were no women found so fair as the daughters of Job: and their father gave them inheritance among their brethren.
13939	478	16	After this lived Job an hundred and forty years, and saw his sons, and his sons' sons, even four generations.
13940	478	17	So Job died, being old and full of days.
13941	479	1	BLESSED is the man that walketh not in the counsel of the ungodly, nor standeth in the way of sinners, nor sitteth in the seat of the scornful.
13942	479	2	But his delight is in the law of the LORD; and in his law doth he meditate day and night.
13943	479	3	And he shall be like a tree planted by the rivers of water, that bringeth forth his fruit in his season; his leaf also shall not wither; and whatsoever he doeth shall prosper.
13944	479	4	The ungodly are not so: but are like the chaff which the wind driveth away.
13945	479	5	Therefore the ungodly shall not stand in the judgment, nor sinners in the congregation of the righteous.
13946	479	6	For the LORD knoweth the way of the righteous: but the way of the ungodly shall perish.
13947	480	1	WHY do the heathen rage, and the people imagine a vain thing?
13948	480	2	The kings of the earth set themselves, and the rulers take counsel together, against the LORD, and against his anointed, saying,
13949	480	3	Let us break their bands asunder, and cast away their cords from us.
13950	480	4	He that sitteth in the heavens shall laugh: the Lord shall have them in derision.
13951	480	5	Then shall he speak unto them in his wrath, and vex them in his sore displeasure.
13952	480	6	Yet have I set my king upon my holy hill of Zion.
13953	480	7	I will declare the decree: the LORD hath said unto me, Thou art my Son; this day have I begotten thee.
13954	480	8	Ask of me, and I shall give thee the heathen for thine inheritance, and the uttermost parts of the earth for thy possession.
13955	480	9	Thou shalt break them with a rod of iron; thou shalt dash them in pieces like a potter's vessel.
13956	480	10	Be wise now therefore, O ye kings: be instructed, ye judges of the earth.
13957	480	11	Serve the LORD with fear, and rejoice with trembling.
13958	480	12	Kiss the Son, lest he be angry, and ye perish from the way, when his wrath is kindled but a little. Blessed are all they that put their trust in him.
13959	481	1	LORD, how are they increased that trouble me! many are they that rise up against me.
13960	481	2	Many there be which say of my soul, There is no help for him in God. Selah.
13961	481	3	But thou, O LORD, art a shield for me; my glory, and the lifter up of mine head.
13962	481	4	I cried unto the LORD with my voice, and he heard me out of his holy hill. Selah.
13963	481	5	I laid me down and slept; I awaked; for the LORD sustained me.
13964	481	6	I will not be afraid of ten thousands of people, that have set themselves against me round about.
13965	481	7	Arise, O LORD; save me, O my God: for thou hast smitten all mine enemies upon the cheek bone; thou hast broken the teeth of the ungodly.
13966	481	8	Salvation belongeth unto the LORD: thy blessing is upon thy people. Selah.
13967	482	1	HEAR me when I call, O God of my righteousness: thou hast enlarged me when I was in distress; have mercy upon me, and hear my prayer.
13968	482	2	O ye sons of men, how long will ye turn my glory into shame? how long will ye love vanity, and seek after leasing? Selah.
13969	482	3	But know that the LORD hath set apart him that is godly for himself: the LORD will hear when I call unto him.
13970	482	4	Stand in awe, and sin not: commune with your own heart upon your bed, and be still. Selah.
13971	482	5	Offer the sacrifices of righteousness, and put your trust in the LORD.
13972	482	6	There be many that say, Who will shew us any good? LORD, lift thou up the light of thy countenance upon us.
13973	482	7	Thou hast put gladness in my heart, more than in the time that their corn and their wine increased.
13974	482	8	I will both lay me down in peace, and sleep: for thou, LORD, only makest me dwell in safety.
13975	483	1	GIVE ear to my words, O LORD, consider my meditation.
13976	483	2	Hearken unto the voice of my cry, my King, and my God: for unto thee will I pray.
13977	483	3	My voice shalt thou hear in the morning, O LORD; in the morning will I direct my prayer unto thee, and will look up.
13978	483	4	For thou art not a God that hath pleasure in wickedness: neither shall evil dwell with thee.
13979	483	5	The foolish shall not stand in thy sight: thou hatest all workers of iniquity.
13980	483	6	Thou shalt destroy them that speak leasing: the LORD will abhor the bloody and deceitful man.
13981	483	7	But as for me, I will come into thy house in the multitude of thy mercy: and in thy fear will I worship toward thy holy temple.
13982	483	8	Lead me, O LORD, in thy righteousness because of mine enemies; make thy way straight before my face.
13983	483	9	For there is no faithfulness in their mouth; their inward part is very wickedness; their throat is an open sepulchre; they flatter with their tongue.
13984	483	10	Destroy thou them, O God; let them fall by their own counsels; cast them out in the multitude of their transgressions; for they have rebelled against thee.
13985	483	11	But let all those that put their trust in thee rejoice: let them ever shout for joy, because thou defendest them: let them also that love thy name be joyful in thee.
13986	483	12	For thou, LORD, wilt bless the righteous; with favour wilt thou compass him as with a shield.
13987	484	1	O LORD, rebuke me not in thine anger, neither chasten me in thy hot displeasure.
13988	484	2	Have mercy upon me, O LORD; for I am weak: O LORD, heal me; for my bones are vexed.
13989	484	3	My soul is also sore vexed: but thou, O LORD, how long?
13990	484	4	Return, O LORD, deliver my soul: oh save me for thy mercies' sake.
13991	484	5	For in death there is no remembrance of thee: in the grave who shall give thee thanks?
13992	484	6	I am weary with my groaning; all the night make I my bed to swim; I water my couch with my tears.
13993	484	7	Mine eye is consumed because of grief; it waxeth old because of all mine enemies.
13994	484	8	Depart from me, all ye workers of iniquity; for the LORD hath heard the voice of my weeping.
13995	484	9	The LORD hath heard my supplication; the LORD will receive my prayer.
13996	484	10	Let all mine enemies be ashamed and sore vexed: let them return and be ashamed suddenly.
13997	485	1	O LORD my God, in thee do I put my trust: save me from all them that persecute me, and deliver me:
13998	485	2	Lest he tear my soul like a lion, rending it in pieces, while there is none to deliver.
13999	485	3	O LORD my God, if I have done this; if there be iniquity in my hands;
14000	485	4	If I have rewarded evil unto him that was at peace with me; (yea, I have delivered him that without cause is mine enemy:)
14001	485	5	Let the enemy persecute my soul, and take it; yea, let him tread down my life upon the earth, and lay mine honour in the dust. Selah.
14002	485	6	Arise, O LORD, in thine anger, lift up thyself because of the rage of mine enemies: and awake for me to the judgment that thou hast commanded.
14003	485	7	So shall the congregation of the people compass thee about: for their sakes therefore return thou on high.
14004	485	8	The LORD shall judge the people: judge me, O LORD, according to my righteousness, and according to mine integrity that is in me.
14005	485	9	Oh let the wickedness of the wicked come to an end; but establish the just: for the righteous God trieth the hearts and reins.
14006	485	10	My defence is of God, which saveth the upright in heart.
14007	485	11	God judgeth the righteous, and God is angry with the wicked every day.
14008	485	12	If he turn not, he will whet his sword; he hath bent his bow, and made it ready.
14009	485	13	He hath also prepared for him the instruments of death; he ordaineth his arrows against the persecutors.
14010	485	14	Behold, he travaileth with iniquity, and hath conceived mischief, and brought forth falsehood.
14011	485	15	He made a pit, and digged it, and is fallen into the ditch which he made.
14012	485	16	His mischief shall return upon his own head, and his violent dealing shall come down upon his own pate.
14013	485	17	I will praise the LORD according to his righteousness: and will sing praise to the name of the LORD most high.
14014	486	1	O LORD our Lord, how excellent is thy name in all the earth! who hast set thy glory above the heavens.
14015	486	2	Out of the mouth of babes and sucklings hast thou ordained strength because of thine enemies, that thou mightest still the enemy and the avenger.
14016	486	3	When I consider thy heavens, the work of thy fingers, the moon and the stars, which thou hast ordained;
14017	486	4	What is man, that thou art mindful of him? and the son of man, that thou visitest him?
14018	486	5	For thou hast made him a little lower than the angels, and hast crowned him with glory and honour.
14019	486	6	Thou madest him to have dominion over the works of thy hands; thou hast put all things under his feet:
14020	486	7	All sheep and oxen, yea, and the beasts of the field;
14021	486	8	The fowl of the air, and the fish of the sea, and whatsoever passeth through the paths of the seas.
14022	486	9	O LORD our Lord, how excellent is thy name in all the earth!
14023	487	1	I WILL praise thee, O LORD, with my whole heart; I will shew forth all thy marvellous works.
14024	487	2	I will be glad and rejoice in thee: I will sing praise to thy name, O thou most High.
14025	487	3	When mine enemies are turned back, they shall fall and perish at thy presence.
14026	487	4	For thou hast maintained my right and my cause; thou satest in the throne judging right.
14027	487	5	Thou hast rebuked the heathen, thou hast destroyed the wicked, thou hast put out their name for ever and ever.
14028	487	6	O thou enemy, destructions are come to a perpetual end: and thou hast destroyed cities; their memorial is perished with them.
14029	487	7	But the LORD shall endure for ever: he hath prepared his throne for judgment.
14030	487	8	And he shall judge the world in righteousness, he shall minister judgment to the people in uprightness.
14031	487	9	The LORD also will be a refuge for the oppressed, a refuge in times of trouble.
14032	487	10	And they that know thy name will put their trust in thee: for thou, LORD, hast not forsaken them that seek thee.
14033	487	11	Sing praises to the LORD, which dwelleth in Zion: declare among the people his doings.
14034	487	12	When he maketh inquisition for blood, he remembereth them: he forgetteth not the cry of the humble.
14035	487	13	Have mercy upon me, O LORD; consider my trouble which I suffer of them that hate me, thou that liftest me up from the gates of death:
14036	487	14	That I may shew forth all thy praise in the gates of the daughter of Zion: I will rejoice in thy salvation.
14037	487	15	The heathen are sunk down in the pit that they made: in the net which they hid is their own foot taken.
14038	487	16	The LORD is known by the judgment which he executeth: the wicked is snared in the work of his own hands. Higgaion. Selah.
14039	487	17	The wicked shall be turned into hell, and all the nations that forget God.
14040	487	18	For the needy shall not alway be forgotten: the expectation of the poor shall not perish for ever.
14041	487	19	Arise, O LORD; let not man prevail: let the heathen be judged in thy sight.
14042	487	20	Put them in fear, O LORD: that the nations may know themselves to be but men. Selah.
14043	488	1	WHY standest thou afar off, O LORD? why hidest thou thyself in times of trouble?
14044	488	2	The wicked in his pride doth persecute the poor: let them be taken in the devices that they have imagined.
14045	488	3	For the wicked boasteth of his heart's desire, and blesseth the covetous, whom the LORD abhorreth.
14046	488	4	The wicked, through the pride of his countenance, will not seek after God: God is not in all his thoughts.
14047	488	5	His ways are always grievous; thy judgments are far above out of his sight: as for all his enemies, he puffeth at them.
14048	488	6	He hath said in his heart, I shall not be moved: for I shall never be in adversity.
14049	488	7	His mouth is full of cursing and deceit and fraud: under his tongue is mischief and vanity.
14050	488	8	He sitteth in the lurking places of the villages: in the secret places doth he murder the innocent: his eyes are privily set against the poor.
14051	488	9	He lieth in wait secretly as a lion in his den: he lieth in wait to catch the poor: he doth catch the poor, when he draweth him into his net.
14052	488	10	He croucheth, and humbleth himself, that the poor may fall by his strong ones.
14053	488	11	He hath said in his heart, God hath forgotten: he hideth his face; he will never see it.
14054	488	12	Arise, O LORD; O God, lift up thine hand: forget not the humble.
14055	488	13	Wherefore doth the wicked contemn God? he hath said in his heart, Thou wilt not require it.
14056	488	14	Thou hast seen it; for thou beholdest mischief and spite, to requite it with thy hand: the poor committeth himself unto thee; thou art the helper of the fatherless.
14057	488	15	Break thou the arm of the wicked and the evil man: seek out his wickedness till thou find none.
14058	488	16	The LORD is King for ever and ever: the heathen are perished out of his land.
14059	488	17	LORD, thou hast heard the desire of the humble: thou wilt prepare their heart, thou wilt cause thine ear to hear:
14060	488	18	To judge the fatherless and the oppressed, that the man of the earth may no more oppress.
14061	489	1	IN the LORD put I my trust: How say ye to my soul, Flee as a bird to your mountain?
14062	489	2	For, lo, the wicked bend their bow, they make ready their arrow upon the string, that they may privily shoot at the upright in heart.
14063	489	3	If the foundations be destroyed, what can the righteous do?
14064	489	4	The LORD is in his holy temple, the LORD's throne is in heaven: his eyes behold, his eyelids try, the children of men.
14065	489	5	The LORD trieth the righteous: but the wicked and him that loveth violence his soul hateth.
14066	489	6	Upon the wicked he shall rain snares, fire and brimstone, and an horrible tempest: this shall be the portion of their cup.
14067	489	7	For the righteous LORD loveth righteousness; his countenance doth behold the upright.
14068	490	1	HELP, LORD; for the godly man ceaseth; for the faithful fail from among the children of men.
14069	490	2	They speak vanity every one with his neighbour: with flattering lips and with a double heart do they speak.
14070	490	3	The LORD shall cut off all flattering lips, and the tongue that speaketh proud things:
14071	490	4	Who have said, With our tongue will we prevail; our lips are our own: who is lord over us?
14072	490	5	For the oppression of the poor, for the sighing of the needy, now will I arise, saith the LORD; I will set him in safety from him that puffeth at him.
14073	490	6	The words of the LORD are pure words: as silver tried in a furnace of earth, purified seven times.
14074	490	7	Thou shalt keep them, O LORD, thou shalt preserve them from this generation for ever.
14075	490	8	The wicked walk on every side, when the vilest men are exalted.
14076	491	1	HOW long wilt thou forget me, O LORD? for ever? how long wilt thou hide thy face from me?
14077	491	2	How long shall I take counsel in my soul, having sorrow in my heart daily? how long shall mine enemy be exalted over me?
14078	491	3	Consider and hear me, O LORD my God: lighten mine eyes, lest I sleep the sleep of death;
14079	491	4	Lest mine enemy say, I have prevailed against him; and those that trouble me rejoice when I am moved.
14080	491	5	But I have trusted in thy mercy; my heart shall rejoice in thy salvation.
14081	491	6	I will sing unto the LORD, because he hath dealt bountifully with me.
14082	492	1	THE fool hath said in his heart, There is no God. They are corrupt, they have done abominable works, there is none that doeth good.
14083	492	2	The LORD looked down from heaven upon the children of men, to see if there were any that did understand, and seek God.
14084	492	3	They are all gone aside, they are all together become filthy: there is none that doeth good, no, not one.
14085	492	4	Have all the workers of iniquity no knowledge? who eat up my people as they eat bread, and call not upon the LORD.
14086	492	5	There were they in great fear: for God is in the generation of the righteous.
14087	492	6	Ye have shamed the counsel of the poor, because the LORD is his refuge.
14088	492	7	Oh that the salvation of Israel were come out of Zion! when the LORD bringeth back the captivity of his people, Jacob shall rejoice, and Israel shall be glad.
14089	493	1	LORD, who shall abide in thy tabernacle? who shall dwell in thy holy hill?
14090	493	2	He that walketh uprightly, and worketh righteousness, and speaketh the truth in his heart.
14091	493	3	He that backbiteth not with his tongue, nor doeth evil to his neighbour, nor taketh up a reproach against his neighbour.
14092	493	4	In whose eyes a vile person is contemned; but he honoureth them that fear the LORD. He that sweareth to his own hurt, and changeth not.
14093	493	5	He that putteth not out his money to usury, nor taketh reward against the innocent. He that doeth these things shall never be moved.
14094	494	1	PRESERVE me, O God: for in thee do I put my trust.
14095	494	2	O my soul, thou hast said unto the LORD, Thou art my Lord: my goodness extendeth not to thee;
14096	494	3	But to the saints that are in the earth, and to the excellent, in whom is all my delight.
14097	494	4	Their sorrows shall be multiplied that hasten after another god: their drink offerings of blood will I not offer, nor take up their names into my lips.
14098	494	5	The LORD is the portion of mine inheritance and of my cup: thou maintainest my lot.
14099	494	6	The lines are fallen unto me in pleasant places; yea, I have a goodly heritage.
14100	494	7	I will bless the LORD, who hath given me counsel: my reins also instruct me in the night seasons.
14101	494	8	I have set the LORD always before me: because he is at my right hand, I shall not be moved.
14102	494	9	Therefore my heart is glad, and my glory rejoiceth: my flesh also shall rest in hope.
14103	494	10	For thou wilt not leave my soul in hell; neither wilt thou suffer thine Holy One to see corruption.
14104	494	11	Thou wilt shew me the path of life: in thy presence is fulness of joy; at thy right hand there are pleasures for evermore.
14105	495	1	HEAR the right, O LORD, attend unto my cry, give ear unto my prayer, that goeth not out of feigned lips.
14106	495	2	Let my sentence come forth from thy presence; let thine eyes behold the things that are equal.
14107	495	3	Thou has proved mine heart; thou hast visited me in the night; thou has tried me, and shalt find nothing; I am purposed that my mouth shall not transgress.
14108	495	4	Concerning the works of men, by the word of thy lips I have kept me from the paths of the destroyer.
14109	495	5	Hold up my goings in thy paths, that my footsteps slip not.
14110	495	6	I have called upon thee, for thou wilt hear me, O God: incline thine ear unto me, and hear my speech.
14111	495	7	Shew thy marvellous lovingkindness, O thou that savest by thy right hand them which put their trust in thee from those that rise up against them.
14112	495	8	Keep me as the apple of the eye, hide me under the shadow of thy wings,
14113	495	9	From the wicked that oppress me, from my deadly enemies, who compass me about.
14114	495	10	They are inclosed in their own fat: with their mouth they speak proudly.
14115	495	11	They have now compassed us in our steps: they have set their eyes bowing down to the earth;
14116	495	12	Like as a lion that is greedy of his prey, and as it were a young lion lurking in secret places.
14117	495	13	Arise, O LORD, disappoint him, cast him down: deliver my soul from the wicked, which is thy sword:
14118	495	14	From men which are thy hand, O LORD, from men of the world, which have their portion in this life, and whose belly thou fillest with thy hid treasure: they are full of children, and leave the rest of their substance to their babes.
14119	495	15	As for me, I will behold thy face in righteousness: I shall be satisfied, when I awake, with thy likeness.
14120	496	1	I WILL love thee, O LORD, my strength.
14121	496	2	The LORD is my rock, and my fortress, and my deliverer; my God, my strength, in whom I will trust; my buckler, and the horn of my salvation, and my high tower.
14122	496	3	I will call upon the LORD, who is worthy to be praised: so shall I be saved from mine enemies.
14123	496	4	The sorrows of death compassed me, and the floods of ungodly men made me afraid.
14124	496	5	The sorrows of hell compassed me about: the snares of death prevented me.
14125	496	6	In my distress I called upon the LORD, and cried unto my God: he heard my voice out of his temple, and my cry came before him, even into his ears.
14126	496	7	Then the earth shook and trembled; the foundations also of the hills moved and were shaken, because he was wroth.
14127	496	8	There went up a smoke out of his nostrils, and fire out of his mouth devoured: coals were kindled by it.
14128	496	9	He bowed the heavens also, and came down: and darkness was under his feet.
14129	496	10	And he rode upon a cherub, and did fly: yea, he did fly upon the wings of the wind.
14130	496	11	He made darkness his secret place; his pavilion round about him were dark waters and thick clouds of the skies.
14131	496	12	At the brightness that was before him his thick clouds passed, hail stones and coals of fire.
14132	496	13	The LORD also thundered in the heavens, and the Highest gave his voice; hail stones and coals of fire.
14133	496	14	Yea, he sent out his arrows, and scattered them; and he shot out lightnings, and discomfited them.
14134	496	15	Then the channels of waters were seen, and the foundations of the world were discovered at thy rebuke, O LORD, at the blast of the breath of thy nostrils.
14135	496	16	He sent from above, he took me, he drew me out of many waters.
14136	496	17	He delivered me from my strong enemy, and from them which hated me: for they were too strong for me.
14137	496	18	They prevented me in the day of my calamity: but the LORD was my stay.
14138	496	19	He brought me forth also into a large place; he delivered me, because he delighted in me.
14139	496	20	The LORD rewarded me according to my righteousness; according to the cleanness of my hands hath he recompensed me.
14140	496	21	For I have kept the ways of the LORD, and have not wickedly departed from my God.
14141	496	22	For all his judgments were before me, and I did not put away his statutes from me.
14142	496	23	I was also upright before him, and I kept myself from mine iniquity.
14143	496	24	Therefore hath the LORD recompensed me according to my righteousness, according to the cleanness of my hands in his eyesight.
14144	496	25	With the merciful thou wilt shew thyself merciful; with an upright man thou wilt shew thyself upright;
14145	496	26	With the pure thou wilt shew thyself pure; and with the froward thou wilt shew thyself froward.
14146	496	27	For thou wilt save the afflicted people; but wilt bring down high looks.
14147	496	28	For thou wilt light my candle: the LORD my God will enlighten my darkness.
14148	496	29	For by thee I have run through a troop; and by my God have I leaped over a wall.
14149	496	30	As for God, his way is perfect: the word of the LORD is tried: he is a buckler to all those that trust in him.
14150	496	31	For who is God save the LORD? or who is a rock save our God?
14151	496	32	It is God that girdeth me with strength, and maketh my way perfect.
14152	496	33	He maketh my feet like hinds' feet, and setteth me upon my high places.
14153	496	34	He teacheth my hands to war, so that a bow of steel is broken by mine arms.
14154	496	35	Thou hast also given me the shield of thy salvation: and thy right hand hath holden me up, and thy gentleness hath made me great.
14155	496	36	Thou hast enlarged my steps under me, that my feet did not slip.
14156	496	37	I have pursued mine enemies, and overtaken them: neither did I turn again till they were consumed.
14157	496	38	I have wounded them that they were not able to rise: they are fallen under my feet.
14158	496	39	For thou hast girded me with strength unto the battle: thou hast subdued under me those that rose up against me.
14159	496	40	Thou hast also given me the necks of mine enemies; that I might destroy them that hate me.
14160	496	41	They cried, but there was none to save them: even unto the LORD, but he answered them not.
14161	496	42	Then did I beat them small as the dust before the wind: I did cast them out as the dirt in the streets.
14162	496	43	Thou hast delivered me from the strivings of the people; and thou hast made me the head of the heathen: a people whom I have not known shall serve me.
14163	496	44	As soon as they hear of me, they shall obey me: the strangers shall submit themselves unto me.
14164	496	45	The strangers shall fade away, and be afraid out of their close places.
14165	496	46	The LORD liveth; and blessed be my rock; and let the God of my salvation be exalted.
14166	496	47	It is God that avengeth me, and subdueth the people under me.
14167	496	48	He delivereth me from mine enemies: yea, thou liftest me up above those that rise up against me: thou hast delivered me from the violent man.
14168	496	49	Therefore will I give thanks unto thee, O LORD, among the heathen, and sing praises unto thy name.
14169	496	50	Great deliverance giveth he to his king; and sheweth mercy to his anointed, to David, and to his seed for evermore.
14170	497	1	THE heavens declare the glory of God; and the firmament sheweth his handywork.
14171	497	2	Day unto day uttereth speech, and night unto night sheweth knowledge.
14172	497	3	There is no speech nor language, where their voice is not heard.
14173	497	4	Their line is gone out through all the earth, and their words to the end of the world. In them hath he set a tabernacle for the sun,
14174	497	5	Which is as a bridegroom coming out of his chamber, and rejoiceth as a strong man to run a race.
14175	497	6	His going forth is from the end of the heaven, and his circuit unto the ends of it: and there is nothing hid from the heat thereof.
14176	497	7	The law of the LORD is perfect, converting the soul: the testimony of the LORD is sure, making wise the simple.
14177	497	8	The statutes of the LORD are right, rejoicing the heart: the commandment of the LORD is pure, enlightening the eyes.
14178	497	9	The fear of the LORD is clean, enduring for ever: the judgments of the LORD are true and righteous altogether.
14179	497	10	More to be desired are they than gold, yea, than much fine gold: sweeter also than honey and the honeycomb.
14180	497	11	Moreover by them is thy servant warned: and in keeping of them there is great reward.
14181	497	12	Who can understand his errors? cleanse thou me from secret faults.
14182	497	13	Keep back thy servant also from presumptuous sins; let them not have dominion over me: then shall I be upright, and I shall be innocent from the great transgression.
14183	497	14	Let the words of my mouth, and the meditation of my heart, be acceptable in thy sight, O LORD, my strength, and my redeemer.
14184	498	1	THE LORD hear thee in the day of trouble; the name of the God of Jacob defend thee;
14185	498	2	Send thee help from the sanctuary, and strengthen thee out of Zion;
14186	498	3	Remember all thy offerings, and accept thy burnt sacrifice; Selah.
14187	498	4	Grant thee according to thine own heart, and fulfil all thy counsel.
14188	498	5	We will rejoice in thy salvation, and in the name of our God we will set up our banners: the LORD fulfil all thy petitions.
14189	498	6	Now know I that the LORD saveth his anointed; he will hear him from his holy heaven with the saving strength of his right hand.
14190	498	7	Some trust in chariots, and some in horses: but we will remember the name of the LORD our God.
14191	498	8	They are brought down and fallen: but we are risen, and stand upright.
14192	498	9	Save, LORD: let the king hear us when we call.
14193	499	1	THE king shall joy in thy strength, O LORD; and in thy salvation how greatly shall he rejoice!
14194	499	2	Thou hast given him his heart's desire, and hast not withholden the request of his lips. Selah.
14195	499	3	For thou preventest him with the blessings of goodness: thou settest a crown of pure gold on his head.
14196	499	4	He asked life of thee, and thou gavest it him, even length of days for ever and ever.
14197	499	5	His glory is great in thy salvation: honour and majesty hast thou laid upon him.
14198	499	6	For thou hast made him most blessed for ever: thou hast made him exceeding glad with thy countenance.
14199	499	7	For the king trusteth in the LORD, and through the mercy of the most High he shall not be moved.
14200	499	8	Thine hand shall find out all thine enemies: thy right hand shall find out those that hate thee.
14201	499	9	Thou shalt make them as a fiery oven in the time of thine anger: the LORD shall swallow them up in his wrath, and the fire shall devour them.
14202	499	10	Their fruit shalt thou destroy from the earth, and their seed from among the children of men.
14203	499	11	For they intended evil against thee: they imagined a mischievous device, which they are not able to perform.
14204	499	12	Therefore shalt thou make them turn their back, when thou shalt make ready thine arrows upon thy strings against the face of them.
14205	499	13	Be thou exalted, LORD, in thine own strength: so will we sing and praise thy power.
14206	500	1	MY God, my God, why hast thou forsaken me? why art thou so far from helping me, and from the words of my roaring?
14207	500	2	O my God, I cry in the daytime, but thou hearest not; and in the night season, and am not silent.
14208	500	3	But thou art holy, O thou that inhabitest the praises of Israel.
14209	500	4	Our fathers trusted in thee: they trusted, and thou didst deliver them.
14210	500	5	They cried unto thee, and were delivered: they trusted in thee, and were not confounded.
14211	500	6	But I am a worm, and no man; a reproach of men, and despised of the people.
14212	500	7	All they that see me laugh me to scorn: they shoot out the lip, they shake the head, saying,
14213	500	8	He trusted on the LORD that he would deliver him: let him deliver him, seeing he delighted in him.
14214	500	9	But thou art he that took me out of the womb: thou didst make me hope when I was upon my mother's breasts.
14215	500	10	I was cast upon thee from the womb: thou art my God from my mother's belly.
14216	500	11	Be not far from me; for trouble is near; for there is none to help.
14217	500	12	Many bulls have compassed me: strong bulls of Bashan have beset me round.
14218	500	13	They gaped upon me with their mouths, as a ravening and a roaring lion.
14219	500	14	I am poured out like water, and all my bones are out of joint: my heart is like wax; it is melted in the midst of my bowels.
14220	500	15	My strength is dried up like a potsherd; and my tongue cleaveth to my jaws; and thou hast brought me into the dust of death.
14221	500	16	For dogs have compassed me: the assembly of the wicked have inclosed me: they pierced my hands and my feet.
14222	500	17	I may tell all my bones: they look and stare upon me.
14223	500	18	They part my garments among them, and cast lots upon my vesture.
14224	500	19	But be not thou far from me, O LORD: O my strength, haste thee to help me.
14225	500	20	Deliver my soul from the sword; my darling from the power of the dog.
14226	500	21	Save me from the lion's mouth: for thou hast heard me from the horns of the unicorns.
14227	500	22	I will declare thy name unto my brethren: in the midst of the congregation will I praise thee.
14228	500	23	Ye that fear the LORD, praise him; all ye the seed of Jacob, glorify him; and fear him, all ye the seed of Israel.
14229	500	24	For he hath not despised nor abhorred the affliction of the afflicted; neither hath he hid his face from him; but when he cried unto him, he heard.
14230	500	25	My praise shall be of thee in the great congregation: I will pay my vows before them that fear him.
14231	500	26	The meek shall eat and be satisfied: they shall praise the LORD that seek him: your heart shall live for ever.
14232	500	27	All the ends of the world shall remember and turn unto the LORD: and all the kindreds of the nations shall worship before thee.
14233	500	28	For the kingdom is the LORD's: and he is the governor among the nations.
14234	500	29	All they that be fat upon earth shall eat and worship: all they that go down to the dust shall bow before him: and none can keep alive his own soul.
14235	500	30	A seed shall serve him; it shall be accounted to the Lord for a generation.
14236	500	31	They shall come, and shall declare his righteousness unto a people that shall be born, that he hath done this.
14237	501	1	THE LORD is my shepherd; I shall not want.
14238	501	2	He maketh me to lie down in green pastures: he leadeth me beside the still waters.
14239	501	3	He restoreth my soul: he leadeth me in the paths of righteousness for his name's sake.
14240	501	4	Yea, though I walk through the valley of the shadow of death, I will fear no evil: for thou art with me; thy rod and thy staff they comfort me.
14241	501	5	Thou preparest a table before me in the presence of mine enemies: thou anointest my head with oil; my cup runneth over.
14242	501	6	Surely goodness and mercy shall follow me all the days of my life: and I will dwell in the house of the LORD for ever.
14243	502	1	THE earth is the LORD's, and the fulness thereof; the world, and they that dwell therein.
14244	502	2	For he hath founded it upon the seas, and established it upon the floods.
14245	502	3	Who shall ascend into the hill of the LORD? or who shall stand in his holy place?
14246	502	4	He that hath clean hands, and a pure heart; who hath not lifted up his soul unto vanity, nor sworn deceitfully.
14247	502	5	He shall receive the blessing from the LORD, and righteousness from the God of his salvation.
14248	502	6	This is the generation of them that seek him, that seek thy face, O Jacob. Selah.
14249	502	7	Lift up your head, O ye gates; and be ye lift up, ye everlasting doors; and the King of glory shall come in.
14250	502	8	Who is this King of glory? The LORD strong and mighty, the LORD mighty in battle.
14251	502	9	Lift up your heads, O ye gates; even lift them up, ye everlasting doors; and the King of glory shall come in.
14252	502	10	Who is this King of glory? The LORD of hosts, he is the King of glory. Selah.
14253	503	1	UNTO thee, O LORD, do I lift up my soul.
14254	503	2	O my God, I trust in thee: let me not be ashamed, let not mine enemies triumph over me.
14255	503	3	Yea, let none that wait on thee be ashamed: let them be ashamed which transgress without cause.
14256	503	4	Shew me thy ways, O LORD; teach me thy paths.
14257	503	5	Lead me in thy truth, and teach me: for thou art the God of my salvation; on thee do I wait all the day.
14258	503	6	Remember, O LORD, thy tender mercies and thy lovingkindnesses; for they have been ever of old.
14259	503	7	Remember not the sins of my youth, nor my transgressions: according to thy mercy remember thou me for thy goodness' sake, O LORD.
14260	503	8	Good and upright is the LORD: therefore will he teach sinners in the way.
14261	503	9	The meek will he guide in judgment: and the meek will he teach his way.
14262	503	10	All the paths of the LORD are mercy and truth unto such as keep his covenant and his testimonies.
14263	503	11	For thy name's sake, O LORD, pardon mine iniquity; for it is great.
14264	503	12	What man is he that feareth the LORD? him shall he teach in the way that he shall choose.
14265	503	13	His soul shall dwell at ease; and his seed shall inherit the earth.
14266	503	14	The secret of the LORD is with them that fear him; and he will shew them his covenant.
14267	503	15	Mine eyes are ever toward the LORD; for he shall pluck my feet out of the net.
14268	503	16	Turn thee unto me, and have mercy upon me; for I am desolate and afflicted.
14269	503	17	The troubles of my heart are enlarged: O bring thou me out of my distresses.
14270	503	18	Look upon mine affliction and my pain; and forgive all my sins.
14271	503	19	Consider mine enemies; for they are many; and they hate me with cruel hatred.
14272	503	20	O keep my soul, and deliver me: let me not be ashamed; for I put my trust in thee.
14273	503	21	Let integrity and uprightness preserve me; for I wait on thee.
14274	503	22	Redeem Israel, O God, out of all his troubles.
14275	504	1	JUDGE me, O LORD; for I have walked in mine integrity: I have trusted also in the LORD; therefore I shall not slide.
14276	504	2	Examine me, O LORD, and prove me; try my reins and my heart.
14277	504	3	For thy lovingkindness is before mine eyes: and I have walked in thy truth.
14278	504	4	I have not sat with vain persons, neither will I go in with dissemblers.
14279	504	5	I have hated the congregation of evil doers; and will not sit with the wicked.
14280	504	6	I will wash mine hands in innocency: so will I compass thine altar, O LORD:
14281	504	7	That I may publish with the voice of thanksgiving, and tell of all thy wondrous works.
14282	504	8	LORD, I have loved the habitation of thy house, and the place where thine honour dwelleth.
14283	504	9	Gather not my soul with sinners, nor my life with bloody men:
14284	504	10	In whose hands is mischief, and their right hand is full of bribes.
14285	504	11	But as for me, I will walk in mine integrity: redeem me, and be merciful unto me.
14286	504	12	My foot standeth in an even place: in the congregations will I bless the LORD.
14287	505	1	THE LORD is my light and my salvation; whom shall I fear? the LORD is the strength of my life; of whom shall I be afraid?
14288	505	2	When the wicked, even mine enemies and my foes, came upon me to eat up my flesh, they stumbled and fell.
14289	505	3	Though an host should encamp against me, my heart shall not fear: though war should rise against me, in this will I be confident.
14290	505	4	One thing have I desired of the LORD, that will I seek after; that I may dwell in the house of the LORD all the days of my life, to behold the beauty of the LORD, and to enquire in his temple.
14291	505	5	For in the time of trouble he shall hide me in his pavilion: in the secret of his tabernacle shall he hide me; he shall set me up upon a rock.
14292	505	6	And now shall mine head be lifted up above mine enemies round about me: therefore will I offer in his tabernacle sacrifices of joy; I will sing, yea, I will sing praises unto the LORD.
14293	505	7	Hear, O LORD, when I cry with my voice: have mercy also upon me, and answer me.
14294	505	8	When thou saidst, Seek ye my face; my heart said unto thee, Thy face, LORD, will I seek.
14295	505	9	Hide not thy face far from me; put not thy servant away in anger: thou hast been my help; leave me not, neither forsake me, O God of my salvation.
14296	505	10	When my father and my mother forsake me, then the LORD will take me up.
14297	505	11	Teach me thy way, O LORD, and lead me in a plain path, because of mine enemies.
14298	505	12	Deliver me not over unto the will of mine enemies: for false witnesses are risen up against me, and such as breathe out cruelty.
14299	505	13	I had fainted, unless I had believed to see the goodness of the LORD in the land of the living.
14300	505	14	Wait on the LORD: be of good courage, and he shall strengthen thine heart: wait, I say, on the LORD.
14301	506	1	UNTO thee will I cry, O LORD my rock; be not silent to me: lest, if thou be silent to me, I become like them that go down into the pit.
14302	506	2	Hear the voice of my supplications, when I cry unto thee, when I lift up my hands toward thy holy oracle.
14303	506	3	Draw me not away with the wicked, and with the workers of iniquity, which speak peace to their neighbours, but mischief is in their hearts.
14304	506	4	Give them according to their deeds, and according to the wickedness of their endeavours: give them after the work of their hands; render to them their desert.
14305	506	5	Because they regard not the works of the LORD, nor the operation of his hands, he shall destroy them, and not build them up.
14306	506	6	Blessed be the LORD, because he hath heard the voice of my supplications.
14307	506	7	The LORD is my strength and my shield; my heart trusted in him, and I am helped: therefore my heart greatly rejoiceth; and with my song will I praise him.
14308	506	8	The LORD is their strength, and he is the saving strength of his anointed.
14309	506	9	Save thy people, and bless thine inheritance: feed them also, and lift them up for ever.
14310	507	1	GIVE unto the LORD, O ye mighty, give unto the LORD glory and strength.
14311	507	2	Give unto the LORD the glory due unto his name; worship the LORD in the beauty of holiness.
14312	507	3	The voice of the LORD is upon the waters: the God of glory thundereth: the LORD is upon many waters.
14313	507	4	The voice of the LORD is powerful; the voice of the LORD is full of majesty.
14314	507	5	The voice of the LORD breaketh the cedars; yea, the LORD breaketh the cedars of Lebanon.
14315	507	6	He maketh them also to skip like a calf; Lebanon and Sirion like a young unicorn.
14316	507	7	The voice of the LORD divideth the flames of fire.
14317	507	8	The voice of the LORD shaketh the wilderness; the LORD shaketh the wilderness of Kadesh.
14318	507	9	The voice of the LORD maketh the hinds to calve, and discovereth the forests: and in his temple doth every one speak of his glory.
14319	507	10	The LORD sitteth upon the flood; yea, the LORD sitteth King for ever.
14320	507	11	The LORD will give strength unto his people; the LORD will bless his people with peace.
14321	508	1	I WILL extol thee, O LORD; for thou hast lifted me up, and hast not made my foes to rejoice over me.
14322	508	2	O LORD my God, I cried unto thee, and thou hast healed me.
14323	508	3	O LORD, thou hast brought up my soul from the grave: thou hast kept me alive, that I should not go down to the pit.
14324	508	4	Sing unto the LORD, O ye saints of his, and give thanks at the remembrance of his holiness.
14325	508	5	For his anger endureth but a moment; in his favour is life: weeping may endure for a night, but joy cometh in the morning.
14326	508	6	And in my prosperity I said, I shall never be moved.
14327	508	7	LORD, by thy favour thou hast made my mountain to stand strong: thou didst hide thy face, and I was troubled.
14328	508	8	I cried to thee, O LORD; and unto the LORD I made supplication.
14329	508	9	What profit is there in my blood, when I go down to the pit? Shall the dust praise thee? shall it declare thy truth?
14330	508	10	Hear, O LORD, and have mercy upon me: LORD, be thou my helper.
14331	508	11	Thou hast turned for me my mourning into dancing: thou hast put off my sackcloth, and girded me with gladness;
14332	508	12	To the end that my glory may sing praise to thee, and not be silent. O LORD my God, I will give thanks unto thee for ever.
14333	509	1	IN thee, O LORD, do I put my trust; let me never be ashamed: deliver me in thy righteousness.
14334	509	2	Bow down thine ear to me; deliver me speedily: be thou my strong rock, for an house of defence to save me.
14335	509	3	For thou art my rock and my fortress; therefore for thy name's sake lead me, and guide me.
14336	509	4	Pull me out of the net that they have laid privily for me: for thou art my strength.
14337	509	5	Into thine hand I commit my spirit: thou hast redeemed me, O LORD God of truth.
14338	509	6	I have hated them that regard lying vanities: but I trust in the LORD.
14339	509	7	I will be glad and rejoice in thy mercy: for thou hast considered my trouble; thou hast known my soul in adversities;
14340	509	8	And hast not shut me up into the hand of the enemy: thou hast set my feet in a large room.
14341	509	9	Have mercy upon me, O LORD, for I am in trouble: mine eye is consumed with grief, yea, my soul and my belly.
14342	509	10	For my life is spent with grief, and my years with sighing: my strength faileth because of mine iniquity, and my bones are consumed.
14343	509	11	I was a reproach among all mine enemies, but especially among my neighbours, and a fear to mine acquaintance: they that did see me without fled from me.
14344	509	12	I am forgotten as a dead man out of mind: I am like a broken vessel.
14345	509	13	For I have heard the slander of many: fear was on every side: while they took counsel together against me, they devised to take away my life.
14346	509	14	But I trusted in thee, O LORD: I said, Thou art my God.
14347	509	15	My times are in thy hand: deliver me from the hand of mine enemies, and from them that persecute me.
14348	509	16	Make thy face to shine upon thy servant: save me for thy mercies' sake.
14349	509	17	Let me not be ashamed, O LORD; for I have called upon thee: let the wicked be ashamed, and let them be silent in the grave.
14350	509	18	Let the lying lips be put to silence; which speak grievous things proudly and contemptuously against the righteous.
14351	509	19	Oh how great is thy goodness, which thou hast laid up for them that fear thee; which thou hast wrought for them that trust in thee before the sons of men!
14352	509	20	Thou shalt hide them in the secret of thy presence from the pride of man: thou shalt keep them secretly in a pavilion from the strife of tongues.
14353	509	21	Blessed be the LORD: for he hath shewed me his marvellous kindness in a strong city.
14354	509	22	For I said in my haste, I am cut off from before thine eyes: nevertheless thou heardest the voice of my supplications when I cried unto thee.
14355	509	23	O love the LORD, all ye his saints: for the LORD preserveth the faithful, and plentifully rewardeth the proud doer.
14356	509	24	Be of good courage, and he shall strengthen your heart, all ye that hope in the LORD.
14357	510	1	BLESSED is he whose transgression is forgiven, whose sin is covered.
14358	510	2	Blessed is the man unto whom the LORD imputeth not iniquity, and in whose spirit there is no guile.
14359	510	3	When I kept silence, my bones waxed old through my roaring all the day long.
14360	510	4	For day and night thy hand was heavy upon me: my moisture is turned into the drought of summer. Selah.
14361	510	5	I acknowledged my sin unto thee, and mine iniquity have I not hid. I said, I will confess my transgressions unto the LORD; and thou forgavest the iniquity of my sin. Selah.
14362	510	6	For this shall every one that is godly pray unto thee in a time when thou mayest be found: surely in the floods of great waters they shall not come nigh unto him.
14363	510	7	Thou art my hiding place; thou shalt preserve me from trouble; thou shalt compass me about with songs of deliverance. Selah.
14364	510	8	I will instruct thee and teach thee in the way which thou shalt go: I will guide thee with mine eye.
14365	510	9	Be ye not as the horse, or as the mule, which have no understanding: whose mouth must be held in with bit and bridle, lest they come near unto thee.
14366	510	10	Many sorrows shall be to the wicked: but he that trusteth in the LORD, mercy shall compass him about.
14367	510	11	Be glad in the LORD, and rejoice, ye righteous: and shout for joy, all ye that are upright in heart.
14368	511	1	REJOICE in the LORD, O ye righteous: for praise is comely for the upright.
14369	511	2	Praise the LORD with harp: sing unto him with the psaltery and an instrument of ten strings.
14370	511	3	Sing unto him a new song; play skilfully with a loud noise.
14371	511	4	For the word of the LORD is right; and all his works are done in truth.
14372	511	5	He loveth righteousness and judgment: the earth is full of the goodness of the LORD.
14373	511	6	By the word of the LORD were the heavens made; and all the host of them by the breath of his mouth.
14374	511	7	He gathereth the waters of the sea together as an heap: he layeth up the depth in storehouses.
14375	511	8	Let all the earth fear the LORD: let all the inhabitants of the world stand in awe of him.
14376	511	9	For he spake, and it was done; he commanded, and it stood fast.
14377	511	10	The LORD bringeth the counsel of the heathen to nought: he maketh the devices of the people of none effect.
14378	511	11	The counsel of the LORD standeth for ever, the thoughts of his heart to all generations.
14379	511	12	Blessed is the nation whose God is the LORD: and the people whom he hath chosen for his own inheritance.
14380	511	13	The LORD looketh from heaven; he beholdeth all the sons of men.
14381	511	14	From the place of his habitation he looketh upon all the inhabitants of the earth.
14382	511	15	He fashioneth their hearts alike; he considereth all their works.
14383	511	16	There is no king saved by the multitude of an host: a mighty man is not delivered by much strength.
14384	511	17	An horse is a vain thing for safety: neither shall he deliver any by his great strength.
14385	511	18	Behold, the eye of the LORD is upon them that fear him, upon them that hope in his mercy;
14386	511	19	To deliver their soul from death, and to keep them alive in famine.
14387	511	20	Our soul waiteth for the LORD: he is our help and our shield.
14388	511	21	For our heart shall rejoice in him, because we have trusted in his holy name.
14389	511	22	Let thy mercy, O LORD, be upon us, according as we hope in thee.
14390	512	1	I WILL bless the LORD at all times: his praise shall continually be in my mouth.
14391	512	2	My soul shall make her boast in the LORD: the humble shall hear thereof, and be glad.
14392	512	3	O magnify the LORD with me, and let us exalt his name together.
14393	512	4	I sought the LORD, and he heard me, and delivered me from all my fears.
14394	512	5	They looked unto him, and were lightened: and their faces were not ashamed.
14395	512	6	This poor man cried, and the LORD heard him, and saved him out of all his troubles.
14396	512	7	The angel of the LORD encampeth round about them that fear him, and delivereth them.
14397	512	8	O taste and see that the LORD is good: blessed is the man that trusteth in him.
14398	512	9	O fear the LORD, ye his saints: for there is no want to them that fear him.
14399	512	10	The young lions do lack, and suffer hunger: but they that seek the LORD shall not want any good thing.
14400	512	11	Come, ye children, hearken unto me: I will teach you the fear of the LORD.
14401	512	12	What man is he that desireth life, and loveth many days, that he may see good?
14402	512	13	Keep thy tongue from evil, and thy lips from speaking guile.
14403	512	14	Depart from evil, and do good; seek peace, and pursue it.
14404	512	15	The eyes of the LORD are upon the righteous, and his ears are open unto their cry.
14405	512	16	The face of the LORD is against them that do evil, to cut off the remembrance of them from the earth.
14406	512	17	The righteous cry, and the LORD heareth, and delivereth them out of all their troubles.
14407	512	18	The LORD is nigh unto them that are of a broken heart; and saveth such as be of a contrite spirit.
14408	512	19	Many are the afflictions of the righteous: but the LORD delivereth him out of them all.
14409	512	20	He keepeth all his bones: not one of them is broken.
14410	512	21	Evil shall slay the wicked: and they that hate the righteous shall be desolate.
14411	512	22	The LORD redeemeth the soul of his servants: and none of them that trust in him shall be desolate.
14412	513	1	PLEAD my cause, O LORD, with them that strive with me: fight against them that fight against me.
14413	513	2	Take hold of shield and buckler, and stand up for mine help.
14414	513	3	Draw out also the spear, and stop the way against them that persecute me: say unto my soul, I am thy salvation.
14415	513	4	Let them be confounded and put to shame that seek after my soul: let them be turned back and brought to confusion that devise my hurt.
14416	513	5	Let them be as chaff before the wind: and let the angel of the LORD chase them.
14417	513	6	Let their way be dark and slippery: and let the angel of the LORD persecute them.
14418	513	7	For without cause have they hid for me their net in a pit, which without cause they have digged for my soul.
14419	513	8	Let destruction come upon him at unawares; and let his net that he hath hid catch himself: into that very destruction let him fall.
14420	513	9	And my soul shall be joyful in the LORD: it shall rejoice in his salvation.
14421	513	10	All my bones shall say, LORD, who is like unto thee, which deliverest the poor from him that is too strong for him, yea, the poor and the needy from him that spoileth him?
14422	513	11	False witnesses did rise up; they laid to my charge things that I knew not.
14423	513	12	They rewarded me evil for good to the spoiling of my soul.
14424	513	13	But as for me, when they were sick, my clothing was sackcloth: I humbled my soul with fasting; and my prayer returned into mine own bosom.
14425	513	14	I behaved myself as though he had been my friend or brother: I bowed down heavily, as one that mourneth for his mother.
14426	513	15	But in mine adversity they rejoiced, and gathered themselves together: yea, the abjects gathered themselves together against me, and I knew it not; they did tear me, and ceased not:
14427	513	16	With hypocritical mockers in feasts, they gnashed upon me with their teeth.
14428	513	17	Lord, how long wilt thou look on? rescue my soul from their destructions, my darling from the lions.
14429	513	18	I will give thee thanks in the great congregation: I will praise thee among much people.
14430	513	19	Let not them that are mine enemies wrongfully rejoice over me: neither let them wink with the eye that hate me without a cause.
14431	513	20	For they speak not peace: but they devise deceitful matters against them that are quiet in the land.
14432	513	21	Yea, they opened their mouth wide against me, and said, Aha, aha, our eye hath seen it.
14433	513	22	This thou hast seen, O LORD: keep not silence: O Lord, be not far from me.
14434	513	23	Stir up thyself, and awake to my judgment, even unto my cause, my God and my Lord.
14435	513	24	Judge me, O LORD my God, according to thy righteousness; and let them not rejoice over me.
14436	513	25	Let them not say in their hearts, Ah, so would we have it: let them not say, We have swallowed him up.
14437	513	26	Let them be ashamed and brought to confusion together that rejoice at mine hurt: let them be clothed with shame and dishonour that magnify themselves against me.
14438	513	27	Let them shout for joy, and be glad, that favour my righteous cause: yea, let them say continually, Let the LORD be magnified, which hath pleasure in the prosperity of his servant.
14439	513	28	And my tongue shall speak of thy righteousness and of thy praise all the day long.
14440	514	1	THE transgression of the wicked saith within my heart, that there is no fear of God before his eyes.
14441	514	2	For he flattereth himself in his own eyes, until his iniquity be found to be hateful.
14442	514	3	The words of his mouth are iniquity and deceit: he hath left off to be wise, and to do good.
14443	514	4	He deviseth mischief upon his bed; he setteth himself in a way that is not good; he abhorreth not evil.
14444	514	5	Thy mercy, O LORD, is in the heavens; and thy faithfulness reacheth unto the clouds.
14445	514	6	Thy righteousness is like the great mountains; thy judgments are a great deep: O LORD, thou preservest man and beast.
14446	514	7	How excellent is thy lovingkindness, O God! therefore the children of men put their trust under the shadow of thy wings.
14447	514	8	They shall be abundantly satisfied with the fatness of thy house; and thou shalt make them drink of the river of thy pleasures.
14448	514	9	For with thee is the fountain of life: in thy light shall we see light.
14449	514	10	O continue thy lovingkindness unto them that know thee; and thy righteousness to the upright in heart.
14450	514	11	Let not the foot of pride come against me, and let not the hand of the wicked remove me.
14451	514	12	There are the workers of iniquity fallen: they are cast down, and shall not be able to rise.
14452	515	1	FRET not thyself because of evildoers, neither be thou envious against the workers of iniquity.
14453	515	2	For they shall soon be cut down like the grass, and wither as the green herb.
14454	515	3	Trust in the LORD, and do good; so shalt thou dwell in the land, and verily thou shalt be fed.
14455	515	4	Delight thyself also in the LORD; and he shall give thee the desires of thine heart.
14456	515	5	Commit thy way unto the LORD; trust also in him; and he shall bring it to pass.
14457	515	6	And he shall bring forth thy righteousness as the light, and thy judgment as the noonday.
14458	515	7	Rest in the LORD, and wait patiently for him: fret not thyself because of him who prospereth in his way, because of the man who bringeth wicked devices to pass.
14459	515	8	Cease from anger, and forsake wrath: fret not thyself in any wise to do evil.
14460	515	9	For evildoers shall be cut off: but those that wait upon the LORD, they shall inherit the earth.
14461	515	10	For yet a little while, and the wicked shall not be: yea, thou shalt diligently consider his place, and it shall not be.
14462	515	11	But the meek shall inherit the earth; and shall delight themselves in the abundance of peace.
14463	515	12	The wicked plotteth against the just, and gnasheth upon him with his teeth.
14464	515	13	The Lord shall laugh at him: for he seeth that his day is coming.
14465	515	14	The wicked have drawn out the sword, and have bent their bow, to cast down the poor and needy, and to slay such as be of upright conversation.
14466	515	15	Their sword shall enter into their own heart, and their bows shall be broken.
14467	515	16	A little that a righteous man hath is better than the riches of many wicked.
14468	515	17	For the arms of the wicked shall be broken: but the LORD upholdeth the righteous.
14469	515	18	The LORD knoweth the days of the upright: and their inheritance shall be for ever.
14470	515	19	They shall not be ashamed in the evil time: and in the days of famine they shall be satisfied.
14471	515	20	But the wicked shall perish, and the enemies of the LORD shall be as the fat of lambs: they shall consume; into smoke shall they consume away.
14472	515	21	The wicked borroweth, and payeth not again: but the righteous sheweth mercy, and giveth.
14473	515	22	For such as be blessed of him shall inherit the earth; and they that be cursed of him shall be cut off.
14474	515	23	The steps of a good man are ordered by the LORD: and he delighteth in his way.
14475	515	24	Though he fall, he shall not be utterly cast down: for the LORD upholdeth him with his hand.
14476	515	25	I have been young, and now am old; yet have I not seen the righteous forsaken, nor his seed begging bread.
14477	515	26	He is ever merciful, and lendeth; and his seed is blessed.
14478	515	27	Depart from evil, and do good; and dwell for evermore.
14479	515	28	For the LORD loveth judgment, and forsaketh not his saints; they are preserved for ever: but the seed of the wicked shall be cut off.
14480	515	29	The righteous shall inherit the land, and dwell therein for ever.
14481	515	30	The mouth of the righteous speaketh wisdom, and his tongue talketh of judgment.
14482	515	31	The law of his God is in his heart; none of his steps shall slide.
14483	515	32	The wicked watcheth the righteous, and seeketh to slay him.
14484	515	33	The LORD will not leave him in his hand, nor condemn him when he is judged.
14485	515	34	Wait on the LORD, and keep his way, and he shall exalt thee to inherit the land: when the wicked are cut off, thou shalt see it.
14486	515	35	I have seen the wicked in great power, and spreading himself like a green bay tree.
14487	515	36	Yet he passed away, and, lo, he was not: yea, I sought him, but he could not be found.
14488	515	37	Mark the perfect man, and behold the upright: for the end of that man is peace.
14489	515	38	But the transgressors shall be destroyed together: the end of the wicked shall be cut off.
14490	515	39	But the salvation of the righteous is of the LORD: he is their strength in the time of trouble.
14491	515	40	And the LORD shall help them, and deliver them: he shall deliver them from the wicked, and save them, because they trust in him.
14492	516	1	O LORD, rebuke me not in thy wrath: neither chasten me in thy hot displeasure.
14493	516	2	For thine arrows stick fast in me, and thy hand presseth me sore.
14494	516	3	There is no soundness in my flesh because of thine anger; neither is there any rest in my bones because of my sin.
14495	516	4	For mine iniquities are gone over mine head: as an heavy burden they are too heavy for me.
14496	516	5	My wounds stink and are corrupt because of my foolishness.
14497	516	6	I am troubled; I am bowed down greatly; I go mourning all the day long.
14498	516	7	For my loins are filled with a loathsome disease: and there is no soundness in my flesh.
14499	516	8	I am feeble and sore broken: I have roared by reason of the disquietness of my heart.
14500	516	9	Lord, all my desire is before thee; and my groaning is not hid from thee.
14501	516	10	My heart panteth, my strength faileth me: as for the light of mine eyes, it also is gone from me.
14502	516	11	My lovers and my friends stand aloof from my sore; and my kinsmen stand afar off.
14503	516	12	They also that seek after my life lay snares for me: and they that seek my hurt speak mischievous things, and imagine deceits all the day long.
14504	516	13	But I, as a deaf man, heard not; and I was as a dumb man that openeth not his mouth.
14505	516	14	Thus I was as a man that heareth not, and in whose mouth are no reproofs.
14506	516	15	For in thee, O LORD, do I hope: thou wilt hear, O Lord my God.
14507	516	16	For I said, Hear me, lest otherwise they should rejoice over me: when my foot slippeth, they magnify themselves against me.
14508	516	17	For I am ready to halt, and my sorrow is continually before me.
14509	516	18	For I will declare mine iniquity; I will be sorry for my sin.
14510	516	19	But mine enemies are lively, and they are strong: and they that hate me wrongfully are multiplied.
14511	516	20	They also that render evil for good are mine adversaries; because I follow the thing that good is.
14512	516	21	Forsake me not, O LORD: O my God, be not far from me.
14513	516	22	Make haste to help me, O Lord my salvation.
14514	517	1	I SAID, I will take heed to my ways, that I sin not with my tongue: I will keep my mouth with a bridle, while the wicked is before me.
14515	517	2	I was dumb with silence, I held my peace, even from good; and my sorrow was stirred.
14516	517	3	My heart was hot within me, while I was musing the fire burned: then spake I with my tongue,
14517	517	4	LORD, make me to know mine end, and the measure of my days, what it is; that I may know how frail I am.
14518	517	5	Behold, thou hast made my days as an handbreadth; and mine age is as nothing before thee: verily every man at his best state is altogether vanity. Selah.
14519	517	6	Surely every man walketh in a vain shew: surely they are disquieted in vain: he heapeth up riches, and knoweth not who shall gather them.
14520	517	7	And now, Lord, what wait I for? my hope is in thee.
14521	517	8	Deliver me from all my transgressions: make me not the reproach of the foolish.
14522	517	9	I was dumb, I opened not my mouth; because thou didst it.
14523	517	10	Remove thy stroke away from me: I am consumed by the blow of thine hand.
14524	517	11	When thou with rebukes dost correct man for iniquity, thou makest his beauty to consume away like a moth: surely every man is vanity. Selah.
14525	517	12	Hear my prayer, O LORD, and give ear unto my cry; hold not thy peace at my tears: for I am a stranger with thee, and a sojourner, as all my fathers were.
14526	517	13	O spare me, that I may recover strength, before I go hence, and be no more.
14527	518	1	I WAITED patiently for the LORD; and he inclined unto me, and heard my cry.
14528	518	2	He brought me up also out of an horrible pit, out of the miry clay, and set my feet upon a rock, and established my goings.
14529	518	3	And he hath put a new song in my mouth, even praise unto our God: many shall see it, and fear, and shall trust in the LORD.
14530	518	4	Blessed is that man that maketh the LORD his trust, and respecteth not the proud, nor such as turn aside to lies.
14531	518	5	Many, O LORD my God, are thy wonderful works which thou hast done, and thy thoughts which are to us-ward: they cannot be reckoned up in order unto thee: if I would declare and speak of them, they are more than can be numbered.
14532	518	6	Sacrifice and offering thou didst not desire; mine ears hast thou opened: burnt offering and sin offering hast thou not required.
14533	518	7	Then said I, Lo, I come: in the volume of the book it is written of me,
14534	518	8	I delight to do thy will, O my God: yea, thy law is within my heart.
14535	518	9	I have preached righteousness in the great congregation: lo, I have not refrained my lips, O LORD, thou knowest.
14536	518	10	I have not hid thy righteousness within my heart; I have declared thy faithfulness and thy salvation: I have not concealed thy lovingkindness and thy truth from the great congregation.
14537	518	11	Withhold not thou thy tender mercies from me, O LORD: let thy lovingkindness and thy truth continually preserve me.
14538	518	12	For innumerable evils have compassed me about: mine iniquities have taken hold upon me, so that I am not able to look up; they are more than the hairs of mine head: therefore my heart faileth me.
14539	518	13	Be pleased, O LORD, to deliver me: O LORD, make haste to help me.
14540	518	14	Let them be ashamed and confounded together that seek after my soul to destroy it; let them be driven backward and put to shame that wish me evil.
14541	518	15	Let them be desolate for a reward of their shame that say unto me, Aha, aha.
14542	518	16	Let all those that seek thee rejoice and be glad in thee: let such as love thy salvation say continually, The LORD be magnified.
14543	518	17	But I am poor and needy; yet the Lord thinketh upon me: thou art my help and my deliverer; make no tarrying, O my God.
14544	519	1	BLESSED is he that considereth the poor: the LORD will deliver him in time of trouble.
14545	519	2	The LORD will preserve him, and keep him alive; and he shall be blessed upon the earth: and thou wilt not deliver him unto the will of his enemies.
14546	519	3	The LORD will strengthen him upon the bed of languishing: thou wilt make all his bed in his sickness.
14547	519	4	I said, LORD, be merciful unto me: heal my soul; for I have sinned against thee.
14548	519	5	Mine enemies speak evil of me, When shall he die, and his name perish?
14549	519	6	And if he come to see me, he speaketh vanity: his heart gathereth iniquity to itself; when he goeth abroad, he telleth it.
14550	519	7	All that hate me whisper together against me: against me do they devise my hurt.
14551	519	8	An evil disease, say they, cleaveth fast unto him: and nowthat he lieth he shall rise up no more.
14552	519	9	Yea, mine own familiar friend, in whom I trusted, which did eat of my bread, hath lifted up his heel against me.
14553	519	10	But thou, O LORD, be merciful unto me, and raise me up, that I may requite them.
14554	519	11	By this I know that thou favourest me, because mine enemy doth not triumph over me.
14555	519	12	And as for me, thou upholdest me in mine integrity, and settest me before thy face for ever.
14556	519	13	Blessed be the LORD God of Israel from everlasting, and to everlasting. Amen, and Amen.
14557	520	1	AS the hart panteth after the water brooks, so panteth my soul after thee, O God.
14558	520	2	My soul thirsteth for God, for the living God: when shall I come and appear before God?
14559	520	3	My tears have been my meat day and night, while they continually say unto me, Where is thy God?
14560	520	4	When I remember these things, I pour out my soul in me: for I had gone with the multitude, I went with them to the house of God, with the voice of joy and praise, with a multitude that kept holyday.
14561	520	5	Why art thou cast down, O my soul? and why art thou disquieted in me? hope thou in God: for I shall yet praise him for the help of his countenance.
14562	520	6	O my God, my soul is cast down within me: therefore will I remember thee from the land of Jordan, and of the Hermonites, from the hill Mizar.
14563	520	7	Deep calleth unto deep at the noise of thy waterspouts: all thy waves and thy billows are gone over me.
14564	520	8	Yet the LORD will command his lovingkindness in the daytime, and in the night his song shall be with me, and my prayer unto the God of my life.
14565	520	9	I will say unto God my rock, Why hast thou forgotten me? why go I mourning because of the oppression of the enemy?
14566	520	10	As with a sword in my bones, mine enemies reproach me; while they say daily unto me, Where is thy God?
14567	520	11	Why art thou cast down, O my soul? and why art thou disquieted within me? hope thou in God: for I shall yet praise him, who is the health of my countenance, and my God.
14568	521	1	JUDGE me, O God, and plead my cause against an ungodly nation: O deliver me from the deceitful and unjust man.
14569	521	2	For thou art the God of my strength: why dost thou cast me off? why go I mourning because of the oppression of the enemy?
14570	521	3	O send out thy light and thy truth: let them lead me; let them bring me unto thy holy hill, and to thy tabernacles.
14571	521	4	Then will I go unto the altar of God, unto God my exceeding joy: yea, upon the harp will I praise thee, O God my God.
14572	521	5	Why art thou cast down, O my soul? and why art thou disquieted within me? hope in God: for I shall yet praise him, who is the health of my countenance, and my God.
14573	522	1	WE have heard with our ears, O God, our fathers have told us, what work thou didst in their days, in the times of old.
14574	522	2	How thou didst drive out the heathen with thy hand, and plantedst them; how thou didst afflict the people, and cast them out.
14575	522	3	For they got not the land in possession by their own sword, neither did their own arm save them: but thy right hand, and thine arm, and the light of thy countenance, because thou hadst a favour unto them.
14576	522	4	Thou art my King, O God: command deliverances for Jacob.
14577	522	5	Through thee will we push down our enemies: through thy name will we tread them under that rise up against us.
14578	522	6	For I will not trust in my bow, neither shall my sword save me.
14579	522	7	But thou hast saved us from our enemies, and hast put them to shame that hated us.
14580	522	8	In God we boast all the day long, and praise thy name for ever. Selah.
14581	522	9	But thou hast cast off, and put us to shame; and goest not forth with our armies.
14582	522	10	Thou makest us to turn back from the enemy: and they which hate us spoil for themselves.
14583	522	11	Thou hast given us like sheep appointed for meat; and hast scattered us among the heathen.
14584	522	12	Thou sellest thy people for nought, and dost not increase thy wealth by their price.
14585	522	13	Thou makest us a reproach to our neighbours, a scorn and a derision to them that are round about us.
14586	522	14	Thou makest us a byword among the heathen, a shaking of the head among the people.
14587	522	15	My confusion is continually before me, and the shame of my face hath covered me,
14588	522	16	For the voice of him that reproacheth and blasphemeth; by reason of the enemy and avenger.
14589	522	17	All this is come upon us; yet have we not forgotten thee, neither have we dealt falsely in thy covenant.
14590	522	18	Our heart is not turned back, neither have our steps declined from thy way;
14591	522	19	Though thou hast sore broken us in the place of dragons, and covered us with the shadow of death.
14592	522	20	If we have forgotten the name of our God, or stretched out our hands to a strange god;
14593	522	21	Shall not God search this out? for he knoweth the secrets of the heart.
14594	522	22	Yea, for thy sake are we killed all the day long; we are counted as sheep for the slaughter.
14595	522	23	Awake, why sleepest thou, O Lord? arise, cast us not off for ever.
14596	522	24	Wherefore hidest thou thy face, and forgettest our affliction and our oppression?
14597	522	25	For our soul is bowed down to the dust: our belly cleaveth unto the earth.
14598	522	26	Arise for our help, and redeem us for thy mercies' sake.
14599	523	1	MY heart is inditing a good matter: I speak of the things which I have made touching the king: my tongue is the pen of a ready writer.
14600	523	2	Thou art fairer than the children of men: grace is poured into thy lips: therefore God hath blessed thee for ever.
14601	523	3	Gird thy sword upon thy thigh, O most mighty, with thy glory and thy majesty.
14602	523	4	And in thy majesty ride prosperously because of truth and meekness and righteousness; and thy right hand shall teach thee terrible things.
14603	523	5	Thine arrows are sharp in the heart of the king's enemies; whereby the people fall under thee.
14604	523	6	Thy throne, O God, is for ever and ever: the sceptre of thy kingdom is a right sceptre.
14605	523	7	Thou lovest righteousness, and hatest wickedness: therefore God, thy God, hath anointed thee with the oil of gladness above thy fellows.
14606	523	8	All thy garments smell of myrrh, and aloes, and cassia, out of the ivory palaces, whereby they have made thee glad.
14607	523	9	Kings' daughters were among thy honourable women: upon thy right hand did stand the queen in gold of Ophir.
14608	523	10	Hearken, O daughter, and consider, and incline thine ear; forget also thine own people, and thy father's house;
14609	523	11	So shall the king greatly desire thy beauty: for he is thy Lord; and worship thou him.
14610	523	12	And the daughter of Tyre shall be there with a gift; even the rich among the people shall intreat thy favour.
14611	523	13	The king's daughter is all glorious within: her clothing is of wrought gold.
14612	523	14	She shall be brought unto the king in raiment of needlework: the virgins her companions that follow her shall be brought unto thee.
14613	523	15	With gladness and rejoicing shall they be brought: they shall enter into the king's palace.
14614	523	16	Instead of thy fathers shall be thy children, whom thou mayest make princes in all the earth.
14615	523	17	I will make thy name to be remembered in all generations: therefore shall the people praise thee for ever and ever.
14616	524	1	GOD is our refuge and strength, a very present help in trouble.
14617	524	2	Therefore will not we fear, though the earth be removed, and though the mountains be carried into the midst of the sea;
14618	524	3	Though the waters thereof roar and be troubled, though the mountains shake with the swelling thereof. Selah.
14619	524	4	There is a river, the streams whereof shall make glad the city of God, the holy place of the tabernacles of the most High.
14620	524	5	God is in the midst of her; she shall not be moved: God shall help her, and that right early.
14621	524	6	The heathen raged, the kingdoms were moved: he uttered his voice, the earth melted.
14622	524	7	The LORD of hosts is with us; the God of Jacob is our refuge. Selah.
14623	524	8	Come, behold the works of the LORD, what desolations he hath made in the earth.
14624	524	9	He maketh wars to cease unto the end of the earth; he breaketh the bow, and cutteth the spear in sunder; he burneth the chariot in the fire.
14625	524	10	Be still, and know that I am God: I will be exalted among the heathen, I will be exalted in the earth.
14626	524	11	The LORD of hosts is with us; the God of Jacob is our refuge. Selah.
14627	525	1	O CLAP your hands, all ye people; shout unto God with the voice of triumph.
14628	525	2	For the LORD most high is terrible; he is a great King over all the earth.
14629	525	3	He shall subdue the people under us, and the nations under our feet.
14630	525	4	He shall choose our inheritance for us, the excellency of Jacob whom he loved. Selah.
14631	525	5	God is gone up with a shout, the LORD with the sound of a trumpet.
14632	525	6	Sing praises to God, sing praises: sing praises unto our King, sing praises.
14633	525	7	For God is the King of all the earth: sing ye praises with understanding.
14634	525	8	God reigneth over the heathen: God sitteth upon the throne of his holiness.
14635	525	9	The princes of the people are gathered together, even the people of the God of Abraham: for the shields of the earth belong unto God: he is greatly exalted.
14636	526	1	GREAT is the LORD, and greatly to be praised in the city of our God, in the mountain of his holiness.
14637	526	2	Beautiful for situation, the joy of the whole earth, is mount Zion, on the sides of the north, the city of the great King.
14638	526	3	God is known in her palaces for a refuge.
14639	526	4	For, lo, the kings were assembled, they passed by together.
14640	526	5	They saw it, and so they marvelled; they were troubled, and hasted away.
14641	526	6	Fear took hold upon them there, and pain, as of a woman in travail.
14642	526	7	Thou breakest the ships of Tarshish with an east wind.
14643	526	8	As we have heard, so have we seen in the city of the LORD of hosts, in the city of our God: God will establish it for ever. Selah.
14644	526	9	We have thought of thy lovingkindness, O God, in the midst of thy temple.
14645	526	10	According to thy name, O God, so is thy praise unto the ends of the earth: thy right hand is full of righteousness.
14646	526	11	Let mount Zion rejoice, let the daughters of Judah be glad, because of thy judgments.
14647	526	12	Walk about Zion, and go round about her: tell the towers thereof.
14648	526	13	Mark ye well her bulwarks, consider her palaces; that ye may tell it to the generation following.
14649	526	14	For this God is our God for ever and ever: he will be our guide even unto death.
14650	527	1	HEAR this, all ye people; give ear, all ye inhabitants of the world:
14651	527	2	Both low and high, rich and poor, together.
14652	527	3	My mouth shall speak of wisdom; and the meditation of my heart shall be of understanding.
14653	527	4	I will incline mine ear to a parable: I will open my dark saying upon the harp.
14654	527	5	Wherefore should I fear in the days of evil, when the iniquity of my heels shall compass me about?
14655	527	6	They that trust in their wealth, and boast themselves in the multitude of their riches;
14656	527	7	None of them can by any means redeem his brother, nor give to God a ransom for him:
14657	527	8	(For the redemption of their soul is precious, and it ceaseth for ever:)
14658	527	9	That he should still live for ever, and not see corruption.
14659	527	10	For he seeth that wise men die, likewise the fool and the brutish person perish, and leave their wealth to others.
14660	527	11	Their inward thought is, that their houses shall continue for ever, and their dwelling places to all generations; they call their lands after their own names.
14661	527	12	Nevertheless man being in honour abideth not: he is like the beasts that perish.
14662	527	13	This their way is their folly: yet their posterity approve their sayings. Selah.
14663	527	14	Like sheep they are laid in the grave; death shall feed on them; and the upright shall have dominion over them in the morning; and their beauty shall consume in the grave from their dwelling.
14664	527	15	But God will redeem my soul from the power of the grave: for he shall receive me. Selah.
14665	527	16	Be not thou afraid when one is made rich, when the glory of his house is increased;
14666	527	17	For when he dieth he shall carry nothing away: his glory shall not descend after him.
14667	527	18	Though while he lived he blessed his soul: and men will praise thee, when thou doest well to thyself.
14668	527	19	He shall go to the generation of his fathers; they shall never see light.
14669	527	20	Man that is in honour, and understandeth not, is like the beasts that perish.
14670	528	1	THE mighty God, even the LORD, hath spoken, and called the earth from the rising of the sun unto the going down thereof.
14671	528	2	Out of Zion, the perfection of beauty, God hath shined.
14672	528	3	Our God shall come, and shall not keep silence: a fire shall devour before him, and it shall be very tempestuous round about him.
14673	528	4	He shall call to the heavens from above, and to the earth, that he may judge his people.
14674	528	5	Gather my saints together unto me; those that have made a covenant with me by sacrifice.
14675	528	6	And the heavens shall declare his righteousness: for God is judge himself. Selah.
14676	528	7	Hear, O my people, and I will speak; O Israel, and I will testify against thee: I am God, even thy God.
14677	528	8	I will not reprove thee for thy sacrifices or thy burnt offerings, to have been continually before me.
14678	528	9	I will take no bullock out of thy house, nor he goats out of thy folds.
14679	528	10	For every beast of the forest is mine, and the cattle upon a thousand hills.
14680	528	11	I know all the fowls of the mountains: and the wild beasts of the field are mine.
14681	528	12	If I were hungry, I would not tell thee: for the world is mine, and the fulness thereof.
14682	528	13	Will I eat the flesh of bulls, or drink the blood of goats?
14683	528	14	Offer unto God thanksgiving; and pay thy vows unto the most High:
14684	528	15	And call upon me in the day of trouble: I will deliver thee, and thou shalt glorify me.
14685	528	16	But unto the wicked God saith, What hast thou to do to declare my statutes, or that thou shouldest take my covenant in thy mouth?
14686	528	17	Seeing thou hatest instruction, and castest my words behind thee.
14687	528	18	When thou sawest a thief, then thou consentedst with him, and hast been partaker with adulterers.
14688	528	19	Thou givest thy mouth to evil, and thy tongue frameth deceit.
14689	528	20	Thou sittest and speakest against thy brother; thou slanderest thine own mother's son.
14690	528	21	These things hast thou done, and I kept silence; thou thoughtest that I was altogether such an one as thyself: but I will reprove thee, and set them in order before thine eyes.
14691	528	22	Now consider this, ye that forget God, lest I tear you in pieces, and there be none to deliver.
14692	528	23	Whoso offereth praise glorifieth me: and to him that ordereth his conversation aright will I shew the salvation of God.
14693	529	1	HAVE mercy upon me, O God, according to thy lovingkindness: according unto the multitude of thy tender mercies blot out my transgressions.
14694	529	2	Wash me throughly from mine iniquity, and cleanse me from my sin.
14695	529	3	For I acknowledge my transgressions: and my sin is ever before me.
14696	529	4	Against thee, thee only, have I sinned, and done this evil in thy sight: that thou mightest be justified when thou speakest, and be clear when thou judgest.
14697	529	5	Behold, I was shapen in iniquity; and in sin did my mother conceive me.
14698	529	6	Behold, thou desirest truth in the inward parts: and in the hidden part thou shalt make me to know wisdom.
14699	529	7	Purge me with hyssop, and I shall be clean: wash me, and I shall be whiter than snow.
14700	529	8	Make me to hear joy and gladness; that the bones which thou hast broken may rejoice.
14701	529	9	Hide thy face from my sins, and blot out all mine iniquities.
14702	529	10	Create in me a clean heart, O God; and renew a right spirit within me.
14703	529	11	Cast me not away from thy presence; and take not thy holy spirit from me.
14704	529	12	Restore unto me the joy of thy salvation; and uphold me with thy free spirit.
14705	529	13	Then will I teach transgressors thy ways; and sinners shall be converted unto thee.
14706	529	14	Deliver me from bloodguiltiness, O God, thou God of my salvation: and my tongue shall sing aloud of thy righteousness.
14707	529	15	O Lord, open thou my lips; and my mouth shall shew forth thy praise.
14708	529	16	For thou desirest not sacrifice; else would I give it: thou delightest not in burnt offering.
14709	529	17	The sacrifices of God are a broken spirit: a broken and a contrite heart, O God, thou wilt not despise.
14710	529	18	Do good in thy good pleasure unto Zion: build thou the walls of Jerusalem.
14711	529	19	Then shalt thou be pleased with the sacrifices of righteousness, with burnt offering and whole burnt offering: then shall they offer bullocks upon thine altar.
14712	530	1	WHY boastest thou thyself in mischief, O mighty man? the goodness of God endureth continually.
14713	530	2	Thy tongue deviseth mischiefs; like a sharp razor, working deceitfully.
14714	530	3	Thou lovest evil more than good; and lying rather than to speak righteousness. Selah.
14715	530	4	Thou lovest all devouring words, O thou deceitful tongue.
14716	530	5	God shall likewise destroy thee for ever, he shall take thee away, and pluck thee out of thy dwelling place, and root thee out of the land of the living. Selah.
14717	530	6	The righteous also shall see, and fear, and shall laugh at him:
14718	530	7	Lo, this is the man that made not God his strength; but trusted in the abundance of his riches, and strengthened himself in his wickedness.
14719	530	8	But I am like a green olive tree in the house of God: I trust in the mercy of God for ever and ever.
14720	530	9	I will praise thee for ever, because thou hast done it: and I will wait on thy name; for it is good before thy saints.
14721	531	1	THE fool hath said in his heart, There is no God. Corrupt are they, and have done abominable iniquity: there is none that doeth good.
14722	531	2	God looked down from heaven upon the children of men, to see if there were any that did understand, that did seek God.
14723	531	3	Every one of them is gone back: they are altogether become filthy; there is none that doeth good, no, not one.
14724	531	4	Have the workers of iniquity no knowledge? who eat up my people as they eat bread: they have not called upon God.
14725	531	5	There were they in great fear, where no fear was: for God hath scattered the bones of him that encampeth against thee: thou hast put them to shame, because God hath despised them.
14726	531	6	Oh that the salvation of Israel were come out of Zion! When God bringeth back the captivity of his people, Jacob shall rejoice, and Israel shall be glad.
14727	532	1	SAVE me, O God, by thy name, and judge me by thy strength.
14728	532	2	Hear my prayer, O God; give ear to the words of my mouth.
14729	532	3	For strangers are risen up against me, and oppressors seek after my soul: they have not set God before them. Selah.
14730	532	4	Behold, God is mine helper: the Lord is with them that uphold my soul.
14731	532	5	He shall reward evil unto mine enemies: cut them off in thy truth.
14732	532	6	I will freely sacrifice unto thee: I will praise thy name, O LORD; for it is good.
14733	532	7	For he hath delivered me out of all trouble: and mine eye hath seen his desire upon mine enemies.
14734	533	1	GIVE ear to my prayer, O God; and hide not thyself from my supplication.
14735	533	2	Attend unto me, and hear me: I mourn in my complaint, and make a noise;
14736	533	3	Because of the voice of the enemy, because of the oppression of the wicked: for they cast iniquity upon me, and in wrath they hate me.
14737	533	4	My heart is sore pained within me: and the terrors of death are fallen upon me.
14738	533	5	Fearfulness and trembling are come upon me, and horror hath overwhelmed me.
14739	533	6	And I said, Oh that I had wings like a dove! for then would I fly away, and be at rest.
14740	533	7	Lo, then would I wander far off, and remain in the wilderness. Selah.
14741	533	8	I would hasten my escape from the windy storm and tempest.
14742	533	9	Destroy, O Lord, and divide their tongues: for I have seen violence and strife in the city.
14743	533	10	Day and night they go about it upon the walls thereof: mischief also and sorrow are in the midst of it.
14744	533	11	Wickedness is in the midst thereof: deceit and guile depart not from her streets.
14745	533	12	For it was not an enemy that reproached me; then I could have borne it: neither was it he that hated me that did magnify himself against me; then I would have hid myself from him:
14746	533	13	But it was thou, a man mine equal, my guide, and mine acquaintance.
14747	533	14	We took sweet counsel together, and walked unto the house of God in company.
14748	533	15	Let death seize upon them, and let them go down quick into hell: for wickedness is in their dwellings, and among them.
14749	533	16	As for me, I will call upon God; and the LORD shall save me.
14750	533	17	Evening, and morning, and at noon, will I pray, and cry aloud: and he shall hear my voice.
14751	533	18	He hath delivered my soul in peace from the battle that was against me: for there were many with me.
14752	533	19	God shall hear, and afflict them, even he that abideth of old. Selah. Because they have no changes, therefore they fear not God.
14753	533	20	He hath put forth his hands against such as be at peace with him: he hath broken his covenant.
14754	533	21	The words of his mouth were smoother than butter, but war was in his heart: his words were softer than oil, yet were they drawn swords.
14755	533	22	Cast thy burden upon the LORD, and he shall sustain thee: he shall never suffer the righteous to be moved.
14756	533	23	But thou, O God, shalt bring them down into the pit of destruction: bloody and deceitful men shall not live out half their days; but I will trust in thee.
14757	534	1	BE merciful unto me, O God: for man would swallow me up; he fighting daily oppresseth me.
14758	534	2	Mine enemies would daily swallow me up: for they be many that fight against me, O thou most High.
14759	534	3	What time I am afraid, I will trust in thee.
14760	534	4	In God I will praise his word, in God I have put my trust; I will not fear what flesh can do unto me.
14761	534	5	Every day they wrest my words: all their thoughts are against me for evil.
14762	534	6	They gather themselves together, they hide themselves, they mark my steps, when they wait for my soul.
14763	534	7	Shall they escape by iniquity? in thine anger cast down the people, O God.
14764	534	8	Thou tellest my wanderings: put thou my tears into thy bottle: are they not in thy book?
14765	534	9	When I cry unto thee, then shall mine enemies turn back: this I know; for God is for me.
14766	534	10	In God will I praise his word: in the LORD will I praise his word.
14767	534	11	In God have I put my trust: I will not be afraid what man can do unto me.
14768	534	12	Thy vows are upon me, O God: I will render praises unto thee.
14769	534	13	For thou hast delivered my soul from death: wilt not thou deliver my feet from falling, that I may walk before God in the light of the living?
14770	535	1	BE merciful unto me, O God, be merciful unto me: for my soul trusteth in thee: yea, in the shadow of thy wings will I make my refuge, until these calamities be overpast.
14771	535	2	I will cry unto God most high; unto God that performeth all things for me.
14772	535	3	He shall send from heaven, and save me from the reproach of him that would swallow me up. Selah. God shall send forth his mercy and his truth.
14773	535	4	My soul is among lions: and I lie even among them that are set on fire, even the sons of men, whose teeth are spears and arrows, and their tongue a sharp sword.
14774	535	5	Be thou exalted, O God, above the heavens; let thy glory be above all the earth.
14775	535	6	They have prepared a net for my steps; my soul is bowed down: they have digged a pit before me, into the midst whereof they are fallen themselves. Selah.
14776	535	7	My heart is fixed, O God, my heart is fixed: I will sing and give praise.
14777	535	8	Awake up, my glory; awake, psaltery and harp: I myself will awake early.
14778	535	9	I will praise thee, O Lord, among the people: I will sing unto thee among the nations.
14779	535	10	For thy mercy is great unto the heavens, and thy truth unto the clouds.
14780	535	11	Be thou exalted, O God, above the heavens: let thy glory be above all the earth.
14781	536	1	DO ye indeed speak righteousness, O congregation? do ye judge uprightly, O ye sons of men?
14782	536	2	Yea, in heart ye work wickedness; ye weigh the violence of your hands in the earth.
14783	536	3	The wicked are estranged from the womb: they go astray as soon as they be born, speaking lies.
14784	536	4	Their poison is like the poison of a serpent: they are like the deaf adder that stoppeth her ear;
14785	536	5	Which will not hearken to the voice of charmers, charming never so wisely.
14786	536	6	Break their teeth, O God, in their mouth: break out the great teeth of the young lions, O LORD.
14787	536	7	Let them melt away as waters which run continually: when he bendeth his bow to shoot his arrows, let them be as cut in pieces.
14788	536	8	As a snail which melteth, let every one of them pass away: like the untimely birth of a woman, that they may not see the sun.
14789	536	9	Before your pots can feel the thorns, he shall take them away as with a whirlwind, both living, and in his wrath.
14790	536	10	The righteous shall rejoice when he seeth the vengeance: he shall wash his feet in the blood of the wicked.
14791	536	11	So that a man shall say, Verily there is a reward for the righteous: verily he is a God that judgeth in the earth.
14792	537	1	DELIVER me from mine enemies, O my God: defend me from them that rise up against me.
14793	537	2	Deliver me from the workers of iniquity, and save me from bloody men.
14794	537	3	For, lo, they lie in wait for my soul: the mighty are gathered against me; not for my transgression, nor for my sin, O LORD.
14795	537	4	They run and prepare themselves without my fault: awake to help me, and behold.
14796	537	5	Thou therefore, O LORD God of hosts, the God of Israel, awake to visit all the heathen: be not merciful to any wicked transgressors. Selah.
14797	537	6	They return at evening: they make a noise like a dog, and go round about the city.
14798	537	7	Behold, they belch out with their mouth: swords are in their lips: for who, say they, doth hear?
14799	537	8	But thou, O LORD, shalt laugh at them; thou shalt have all the heathen in derision.
14800	537	9	Because of his strength will I wait upon thee: for God is my defence.
14801	537	10	The God of my mercy shall prevent me: God shall let me see my desire upon mine enemies.
14802	537	11	Slay them not, lest my people forget: scatter them by thy power; and bring them down, O Lord our shield.
14803	537	12	For the sin of their mouth and the words of their lips let them even be taken in their pride: and for cursing and lying which they speak.
14804	537	13	Consume them in wrath, consume them, that they may not be: and let them know that God ruleth in Jacob unto the ends of the earth. Selah.
14805	537	14	And at evening let them return; and let them make a noise like a dog, and go round about the city.
14806	537	15	Let them wander up and down for meat, and grudge if they be not satisfied.
14807	537	16	But I will sing of thy power; yea, I will sing aloud of thy mercy in the morning: for thou hast been my defence and refuge in the day of my trouble.
14808	537	17	Unto thee, O my strength, will I sing: for God is my defence, and the God of my mercy.
14809	538	1	O GOD, thou hast cast us off, thou hast scattered us, thou hast been displeased; O turn thyself to us again.
14810	538	2	Thou hast made the earth to tremble; thou hast broken it: heal the breaches thereof; for it shaketh.
14811	538	3	Thou hast shewed thy people hard things: thou hast made us to drink the wine of astonishment.
14812	538	4	Thou hast given a banner to them that fear thee, that it may be displayed because of the truth. Selah.
14813	538	5	That thy beloved may be delivered; save with thy right hand, and hear me.
14814	538	6	God hath spoken in his holiness; I will rejoice, I will divide Shechem, and mete out the valley of Succoth.
14815	538	7	Gilead is mine, and Manasseh is mine; Ephraim also is the strength of mine head; Judah is my lawgiver;
14816	538	8	Moab is my washpot; over Edom will I cast out my shoe: Philistia, triumph thou because of me.
14817	538	9	Who will bring me into the strong city? who will lead me into Edom?
14818	538	10	Wilt not thou, O God, which hadst cast us off? and thou, O God, which didst not go out with our armies?
14819	538	11	Give us help from trouble: for vain is the help of man.
14820	538	12	Through God we shall do valiantly: for he it is that shall tread down our enemies.
14821	539	1	HEAR my cry, O God; attend unto my prayer.
14822	539	2	From the end of the earth will I cry unto thee, when my heart is overwhelmed: lead me to the rock that is higher than I.
14823	539	3	For thou hast been a shelter for me, and a strong tower from the enemy.
14824	539	4	I will abide in thy tabernacle for ever: I will trust in the covert of thy wings. Selah.
14825	539	5	For thou, O God, hast heard my vows: thou hast given me the heritage of those that fear thy name.
14826	539	6	Thou wilt prolong the king's life: and his years as many generations.
14827	539	7	He shall abide before God for ever: O prepare mercy and truth, which may preserve him.
14828	539	8	So will I sing praise unto thy name for ever, that I may daily perform my vows.
14829	540	1	TRULY my soul waiteth upon God: from him cometh my salvation.
14830	540	2	He only is my rock and my salvation; he is my defence; I shall not be greatly moved.
14831	540	3	How long will ye imagine mischief against a man? ye shall be slain all of you: as a bowing wall shall ye be, and as a tottering fence.
14832	540	4	They only consult to cast him down from his excellency: they delight in lies: they bless with their mouth, but they curse inwardly. Selah.
14833	540	5	My soul, wait thou only upon God; for my expectation is from him.
14834	540	6	He only is my rock and my salvation: he is my defence; I shall not be moved.
14835	540	7	In God is my salvation and my glory: the rock of my strength, and my refuge, is in God.
14836	540	8	Trust in him at all times; ye people, pour out your heart before him: God is a refuge for us. Selah.
14837	540	9	Surely men of low degree are vanity, and men of high degree are a lie: to be laid in the balance, they are altogether lighter than vanity.
14838	540	10	Trust not in oppression, and become not vain in robbery: if riches increase, set not your heart upon them.
14839	540	11	God hath spoken once; twice have I heard this; that power belongeth unto God.
14840	540	12	Also unto thee, O Lord, belongeth mercy: for thou renderest to every man according to his work.
14841	541	1	O GOD, thou art my God; early will I seek thee: my soul thirsteth for thee, my flesh longeth for thee in a dry and thirsty land, where no water is;
14842	541	2	To see thy power and thy glory, so as I have seen thee in the sanctuary.
14843	541	3	Because thy lovingkindness is better than life, my lips shall praise thee.
14844	541	4	Thus will I bless thee while I live: I will lift up my hands in thy name.
14845	541	5	My soul shall be satisfied as with marrow and fatness; and my mouth shall praise thee with joyful lips:
14846	541	6	When I remember thee upon my bed, and meditate on thee in the night watches.
14847	541	7	Because thou hast been my help, therefore in the shadow of thy wings will I rejoice.
14848	541	8	My soul followeth hard after thee: thy right hand upholdeth me.
14849	541	9	But those that seek my soul, to destroy it, shall go into the lower parts of the earth.
14850	541	10	They shall fall by the sword: they shall be a portion for foxes.
14851	541	11	But the king shall rejoice in God; every one that sweareth by him shall glory: but the mouth of them that speak lies shall be stopped.
14852	542	1	HEAR my voice, O God, in my prayer: preserve my life from fear of the enemy.
14853	542	2	Hide me from the secret counsel of the wicked; from the insurrection of the workers of iniquity:
14854	542	3	Who whet their tongue like a sword, and bend their bows to shoot their arrows, even bitter words:
14855	542	4	That they may shoot in secret at the perfect: suddenly do they shoot at him, and fear not.
14856	542	5	They encourage themselves in an evil matter: they commune of laying snares privily; they say, Who shall see them?
14857	542	6	They search out iniquities; they accomplish a diligent search: both the inward thought of every one of them, and the heart, is deep.
14858	542	7	But God shall shoot at them with an arrow; suddenly shall they be wounded.
14859	542	8	So they shall make their own tongue to fall upon themselves: all that see them shall flee away.
14860	542	9	And all men shall fear, and shall declare the work of God; for they shall wisely consider of his doing.
14861	542	10	The righteous shall be glad in the LORD, and shall trust in him; and all the upright in heart shall glory.
14862	543	1	PRAISE waiteth for thee, O God, in Sion: and unto thee shall the vow be performed.
14863	543	2	O thou that hearest prayer, unto thee shall all flesh come.
14864	543	3	Iniquities prevail against me: as for our transgressions, thou shalt purge them away.
14865	543	4	Blessed is the man whom thou choosest, and causest to approach unto thee, that he may dwell in thy courts: we shall be satisfied with the goodness of thy house, even of thy holy temple.
14866	543	5	By terrible things in righteousness wilt thou answer us, O God of our salvation; who art the confidence of all the ends of the earth, and of them that are afar off upon the sea:
14867	543	6	Which by his strength setteth fast the mountains; being girded with power:
14868	543	7	Which stilleth the noise of the seas, the noise of their waves, and the tumult of the people.
14869	543	8	They also that dwell in the uttermost parts are afraid at thy tokens: thou makest the outgoings of the morning and evening to rejoice.
14870	543	9	Thou visitest the earth, and waterest it: thou greatly enrichest it with the river of God, which is full of water: thou preparest them corn, when thou hast so provided for it.
14871	543	10	Thou waterest the ridges thereof abundantly: thou settlest the furrows thereof: thou makest it soft with showers: thou blessest the springing thereof.
14872	543	11	Thou crownest the year with thy goodness; and thy paths drop fatness.
14873	543	12	They drop upon the pastures of the wilderness: and the little hills rejoice on every side.
14874	543	13	The pastures are clothed with flocks; the valleys also are covered over with corn; they shout for joy, they also sing.
14875	544	1	MAKE a joyful noise unto God, all ye lands:
14876	544	2	Sing forth the honour of his name: make his praise glorious.
14877	544	3	Say unto God, How terrible art thou in thy works! through the greatness of thy power shall thine enemies submit themselves unto thee.
14878	544	4	All the earth shall worship thee, and shall sing unto thee; they shall sing to thy name. Selah.
14879	544	5	Come and see the works of God: he is terrible in his doing toward the children of men.
14880	544	6	He turned the sea into dry land: they went through the flood on foot: there did we rejoice in him.
14881	544	7	He ruleth by his power for ever; his eyes behold the nations: let not the rebellious exalt themselves. Selah.
14882	544	8	O bless our God, ye people, and make the voice of his praise to be heard:
14883	544	9	Which holdeth our soul in life, and suffereth not our feet to be moved.
14884	544	10	For thou, O God, hast proved us: thou hast tried us, as silver is tried.
14885	544	11	Thou broughtest us into the net; thou laidst affliction upon our loins.
14886	544	12	Thou hast caused men to ride over our heads; we went through fire and through water: but thou broughtest us out into a wealthy place.
14887	544	13	I will go into thy house with burnt offerings: I will pay thee my vows,
14888	544	14	Which my lips have uttered, and my mouth hath spoken, when I was in trouble.
14889	544	15	I will offer unto thee burnt sacrifices of fatlings, with the incense of rams; I will offer bullocks with goats. Selah.
14890	544	16	Come and hear, all ye that fear God, and I will declare what he hath done for my soul.
14891	544	17	I cried unto him with my mouth, and he was extolled with my tongue.
14892	544	18	If I regard iniquity in my heart, the Lord will not hear me:
14893	544	19	But verily God hath heard me; he hath attended to the voice of my prayer.
14894	544	20	Blessed be God, which hath not turned away my prayer, nor his mercy from me.
14895	545	1	GOD be merciful unto us, and bless us; and cause his face to shine upon us; Selah.
14896	545	2	That thy way may be known upon earth, thy saving health among all nations.
14897	545	3	Let the people praise thee, O God; let all the people praise thee.
14898	545	4	O let the nations be glad and sing for joy: for thou shalt judge the people righteously, and govern the nations upon earth. Selah.
14899	545	5	Let the people praise thee, O God; let all the people praise thee.
14900	545	6	Then shall the earth yield her increase; and God, even our own God, shall bless us.
14901	545	7	God shall bless us; and all the ends of the earth shall fear him.
14902	546	1	LET God arise, let his enemies be scattered: let them also that hate him flee before him.
14903	546	2	As smoke is driven away, so drive them away: as wax melteth before the fire, so let the wicked perish at the presence of God.
14904	546	3	But let the righteous be glad; let them rejoice before God: yea, let them exceedingly rejoice.
14905	546	4	Sing unto God, sing praises to his name: extol him that rideth upon the heavens by his name JAH, and rejoice before him.
14906	546	5	A father of the fatherless, and a judge of the widows, is God in his holy habitation.
14907	546	6	God setteth the solitary in families: he bringeth out those which are bound with chains: but the rebellious dwell in a dry land.
14908	546	7	O God, when thou wentest forth before thy people, when thou didst march through the wilderness; Selah:
14909	546	8	The earth shook, the heavens also dropped at the presence of God: even Sinai itself was moved at the presence of God, the God of Israel.
14910	546	9	Thou, O God, didst send a plentiful rain, whereby thou didst confirm thine inheritance, when it was weary.
14911	546	10	Thy congregation hath dwelt therein: thou, O God, hast prepared of thy goodness for the poor.
14912	546	11	The Lord gave the word: great was the company of those that published it.
14913	546	12	Kings of armies did flee apace: and she that tarried at home divided the spoil.
14914	546	13	Though ye have lien among the pots, yet shall ye be as the wings of a dove covered with silver, and her feathers with yellow gold.
14915	546	14	When the Almighty scattered kings in it, it was white as snow in Salmon.
14916	546	15	The hill of God is as the hill of Bashan; an high hill as the hill of Bashan.
14917	546	16	Why leap ye, ye high hills? this is the hill which God desireth to dwell in; yea, the LORD will dwell in it for ever.
14918	546	17	The chariots of God are twenty thousand, even thousands of angels: the Lord is among them, as in Sinai, in the holy place.
14919	546	18	Thou hast ascended on high, thou hast led captivity captive: thou hast received gifts for men; yea, for the rebellious also, that the LORD God might dwell among them.
14920	546	19	Blessed be the Lord, who daily loadeth us with benefits, even the God of our salvation. Selah.
14921	546	20	He that is our God is the God of salvation; and unto GOD the Lord belong the issues from death.
14922	546	21	But God shall wound the head of his enemies, and the hairy scalp of such an one as goeth on still in his trespasses.
14923	546	22	The Lord said, I will bring again from Bashan, I will bring my people again from the depths of the sea:
14924	546	23	That thy foot may be dipped in the blood of thine enemies, and the tongue of thy dogs in the same.
14925	546	24	They have seen thy goings, O God; even the goings of my God, my King, in the sanctuary.
14926	546	25	The singers went before, the players on instruments followed after; among them were the damsels playing with timbrels.
14927	546	26	Bless ye God in the congregations, even the Lord, from the fountain of Israel.
14928	546	27	There is little Benjamin with their ruler, the princes of Judah and their council, the princes of Zebulun, and the princes of Naphtali.
14929	546	28	Thy God hath commanded thy strength: strengthen, O God, that which thou hast wrought for us.
14930	546	29	Because of thy temple at Jerusalem shall kings bring presents unto thee.
14931	546	30	Rebuke the company of spearmen, the multitude of the bulls, with the calves of the people, till every one submit himself with pieces of silver: scatter thou the people that delight in war.
14932	546	31	Princes shall come out of Egypt; Ethiopia shall soon stretch out her hands unto God.
14933	546	32	Sing unto God, ye kingdoms of the earth; O sing praises unto the Lord; Selah:
14934	546	33	To him that rideth upon the heavens of heavens, which were of old; lo, he doth send out his voice, and that a mighty voice.
14935	546	34	Ascribe ye strength unto God: his excellency is over Israel, and his strength is in the clouds.
14936	546	35	O God, thou art terrible out of thy holy places: the God of Israel is he that giveth strength and power unto his people. Blessed be God.
14937	547	1	SAVE me, O God; for the waters are come in unto my soul.
14938	547	2	I sink in deep mire, where there is no standing: I am come into deep waters, where the floods overflow me.
14939	547	3	I am weary of my crying: my throat is dried: mine eyes fail while I wait for my God.
14940	547	4	They that hate me without a cause are more than the hairs of mine head: they that would destroy me, being mine enemies wrongfully, are mighty: then I restored that which I took not away.
14941	547	5	O God, thou knowest my foolishness; and my sins are not hid from thee.
14942	547	6	Let not them that wait on thee, O Lord GOD of hosts, be ashamed for my sake: let not those that seek thee be confounded for my sake, O God of Israel.
14943	547	7	Because for thy sake I have borne reproach; shame hath covered my face.
14944	547	8	I am become a stranger unto my brethren, and an alien unto my mother's children.
14945	547	9	For the zeal of thine house hath eaten me up; and the reproaches of them that reproached thee are fallen upon me.
14946	547	10	When I wept, and chastened my soul with fasting, that was to my reproach.
14947	547	11	I made sackcloth also my garment; and I become a proverb to them.
14948	547	12	They that sit in the gate speak against me; and I was the song of the drunkards.
14949	547	13	But as for me, my prayer is unto thee, O LORD, in an acceptable time: O God, in the multitude of thy mercy hear me, in the truth of thy salvation.
14950	547	14	Deliver me out of the mire, and let me not sink: let me be delivered from them that hate me, and out of the deep waters.
14951	547	15	Let not the waterflood overflow me, neither let the deep swallow me up, and let not the pit shut her mouth upon me.
14952	547	16	Hear me, O LORD; for thy lovingkindness is good: turn unto me according to the multitude of thy tender mercies.
14953	547	17	And hide not thy face from thy servant; for I am in trouble: hear me speedily.
14954	547	18	Draw nigh unto my soul, and redeem it: deliver me because of mine enemies.
14955	547	19	Thou hast known my reproach, and my shame, and my dishonour: mine adversaries are all before thee.
14956	547	20	Reproach hath broken my heart; and I am full of heaviness: and I looked for some to take pity, but there was none; and for comforters, but I found none.
14957	547	21	They gave me also gall for my meat; and in my thirst they gave me vinegar to drink.
14958	547	22	Let their table become a snare before them: and that which should have been for their welfare, let it become a trap.
14959	547	23	Let their eyes be darkened, that they see not; and make their loins continually to shake.
14960	547	24	Pour out thine indignation upon them, and let thy wrathful anger take hold of them.
14961	547	25	Let their habitation be desolate; and let none dwell in their tents.
14962	547	26	For they persecute him whom thou hast smitten; and they talk to the grief of those whom thou hast wounded.
14963	547	27	Add iniquity unto their iniquity: and let them not come into thy righteousness.
14964	547	28	Let them be blotted out of the book of the living, and not be written with the righteous.
14965	547	29	But I am poor and sorrowful: let thy salvation, O God, set me up on high.
14966	547	30	I will praise the name of God with a song, and will magnify him with thanksgiving.
14967	547	31	This also shall please the LORD better than an ox or bullock that hath horns and hoofs.
14968	547	32	The humble shall see this, and be glad: and your heart shall live that seek God.
14969	547	33	For the LORD heareth the poor, and despiseth not his prisoners.
14970	547	34	Let the heaven and earth praise him, the seas, and everything that moveth therein.
14971	547	35	For God will save Zion, and will build the cities of Judah: that they may dwell there, and have it in possession.
14972	547	36	The seed also of his servants shall inherit it: and they that love his name shall dwell therein.
14973	548	1	MAKE haste, O God, to deliver me; make haste to help me, O LORD.
14974	548	2	Let them be ashamed and confounded that seek after my soul: let them be turned backward, and put to confusion, that desire my hurt.
14975	548	3	Let them be turned back for a reward of their shame that say, Aha, aha.
14976	548	4	Let all those that seek thee rejoice and be glad in thee: and let such as love thy salvation say continually, Let God be magnified.
14977	548	5	But I am poor and needy: make haste unto me, O God: thou art my help and my deliverer; O LORD, make no tarrying.
14978	549	1	IN thee, O LORD, do I put my trust: let me never be put to confusion.
14979	549	2	Deliver me in thy righteousness, and cause me to escape: incline thine ear unto me, and save me.
14980	549	3	Be thou my strong habitation, whereunto I may continually resort: thou hast given commandment to save me; for thou art my rock and my fortress.
14981	549	4	Deliver me, O my God, out of the hand of the wicked, out of the hand of the unrighteous and cruel man.
14982	549	5	For thou art my hope, O Lord GOD: thou art my trust from my youth.
14983	549	6	By thee have I been holden up from the womb: thou art he that took me out of my mother's bowels: my praise shall be continually of thee.
14984	549	7	I am as a wonder unto many; but thou art my strong refuge.
14985	549	8	Let my mouth be filled with thy praise and with thy honour all the day.
14986	549	9	Cast me not off in the time of old age; forsake me not when my strength faileth.
14987	549	10	For mine enemies speak against me; and they that lay wait for my soul take counsel together,
14988	549	11	Saying, God hath forsaken him: persecute and take him; for there is none to deliver him.
14989	549	12	O God, be not far from me: O my God, make haste for my help.
14990	549	13	Let them be confounded and consumed that are adversaries to my soul; let them be covered with reproach and dishonour that seek my hurt.
14991	549	14	But I will hope continually, and will yet praise thee more and more.
14992	549	15	My mouth shall shew forth thy righteousness and thy salvation all the day; for I know not the numbers thereof.
14993	549	16	I will go in the strength of the Lord GOD: I will make mention of thy righteousness, even of thine only.
14994	549	17	O God, thou hast taught me from my youth: and hitherto have I declared thy wondrous works.
14995	549	18	Now also when I am old and grayheaded, O God, forsake me not; until I have shewed thy strength unto this generation, and thy power to every one that is to come.
14996	549	19	Thy righteousness also, O God, is very high, who hast done great things: O God, who is like unto thee!
14997	549	20	Thou, which hast shewed me great and sore troubles, shalt quicken me again, and shalt bring me up again from the depths of the earth.
14998	549	21	Thou shalt increase my greatness, and comfort me on every side.
14999	549	22	I will also praise thee with the psaltery, even thy truth, O my God: unto thee will I sing with the harp, O thou Holy One of Israel.
15000	549	23	My lips shall greatly rejoice when I sing unto thee; and my soul, which thou hast redeemed.
15001	549	24	My tongue also shall talk of thy righteousness all the day long: for they are confounded, for they are brought unto shame, that seek my hurt.
15002	550	1	GIVE the king thy judgments, O God, and thy righteousness unto the king's son.
15003	550	2	He shall judge thy people with righteousness, and thy poor with judgment.
15004	550	3	The mountains shall bring peace to the people, and the little hills, by righteousness.
15005	550	4	He shall judge the poor of the people, he shall save the children of the needy, and shall break in pieces the oppressor.
15006	550	5	They shall fear thee as long as the sun and moon endure, throughout all generations.
15007	550	6	He shall come down like rain upon the mown grass: as showers that water the earth.
15008	550	7	In his days shall the righteous flourish; and abundance of peace so long as the moon endureth.
15009	550	8	He shall have dominion also from sea to sea, and from the river unto the ends of the earth.
15010	550	9	They that dwell in the wilderness shall bow before him; and his enemies shall lick the dust.
15011	550	10	The kings of Tarshish and of the isles shall bring presents: the kings of Sheba and Seba shall offer gifts.
15012	550	11	Yea, all kings shall fall down before him: all nations shall serve him.
15013	550	12	For he shall deliver the needy when he crieth; the poor also, and him that hath no helper.
15014	550	13	He shall spare the poor and needy, and shall save the souls of the needy.
15015	550	14	He shall redeem their soul from deceit and violence: and precious shall their blood be in his sight.
15016	550	15	And he shall live, and to him shall be given of the gold of Sheba: prayer also shall be made for him continually; and daily shall he be praised.
15017	550	16	There shall be an handful of corn in the earth upon the top of the mountains; the fruit thereof shall shake like Lebanon: and they of the city shall flourish like grass of the earth.
15018	550	17	His name shall endure for ever: his name shall be continued as long as the sun: and men shall be blessed in him: all nations shall call him blessed.
15019	550	18	Blessed be the LORD God, the God of Israel, who only doeth wondrous things.
15020	550	19	And blessed be his glorious name for ever: and let the whole earth be filled with his glory; Amen, and Amen.
15021	550	20	The prayers of David the son of Jesse are ended.
15022	551	1	TRULY God is good to Israel, even to such as are of a clean heart.
15023	551	2	But as for me, my feet were almost gone; my steps had well nigh slipped.
15024	551	3	For I was envious at the foolish, when I saw the prosperity of the wicked.
15025	551	4	For there are no bands in their death: but their strength is firm.
15026	551	5	They are not in trouble as other men; neither are they plagued like other men.
15027	551	6	Therefore pride compasseth them about as a chain; violence covereth them as a garment.
15028	551	7	Their eyes stand out with fatness: they have more than heart could wish.
15029	551	8	They are corrupt, and speak wickedly concerning oppression: they speak loftily.
15030	551	9	They set their mouth against the heavens, and their tongue walketh through the earth.
15031	551	10	Therefore his people return hither: and waters of a full cup are wrung out to them.
15032	551	11	And they say, How doth God know? and is there knowledge in the most High?
15033	551	12	Behold, these are the ungodly, who prosper in the world; they increase in riches.
15034	551	13	Verily I have cleansed my heart in vain, and washed my hands in innocency.
15035	551	14	For all the day long have I been plagued, and chastened every morning.
15036	551	15	If I say, I will speak thus; behold, I should offend against the generation of thy children.
15037	551	16	When I thought to know this, it was too painful for me;
15038	551	17	Until I went into the sanctuary of God; then understood I their end.
15039	551	18	Surely thou didst set them in slippery places: thou castedst them down into destruction.
15040	551	19	How are they brought into desolation, as in a moment! they are utterly consumed with terrors.
15041	551	20	As a dream when one awaketh; so, O Lord, when thou awakest, thou shalt despise their image.
15042	551	21	Thus my heart was grieved, and I was pricked in my reins.
15043	551	22	So foolish was I, and ignorant: I was as a beast before thee.
15044	551	23	Nevertheless I am continually with thee: thou hast holden me by my right hand.
15045	551	24	Thou shalt guide me with thy counsel, and afterward receive me to glory.
15046	551	25	Whom have I in heaven but thee? and there is none upon earth that I desire beside thee.
15047	551	26	My flesh and my heart faileth: but God is the strength of my heart, and my portion for ever.
15048	551	27	For, lo, they that are far from thee shall perish: thou hast destroyed all them that go a whoring from thee.
15049	551	28	But it is good for me to draw near to God: I have put my trust in the Lord GOD, that I may declare all thy works.
15050	552	1	O GOD, why hast thou cast us off for ever? why doth thine anger smoke against the sheep of thy pasture?
15051	552	2	Remember thy congregation, which thou hast purchased of old; the rod of thine inheritance, which thou hast redeemed; this mount Zion, wherein thou hast dwelt.
15052	552	3	Lift up thy feet unto the perpetual desolations; even all that the enemy hath done wickedly in the sanctuary.
15053	552	4	Thine enemies roar in the midst of thy congregations; they set up their ensigns for signs.
15054	552	5	A man was famous according as he had lifted up axes upon the thick trees.
15055	552	6	But now they break down the carved work thereof at once with axes and hammers.
15056	552	7	They have cast fire into thy sanctuary, they have defiled by casting down the dwelling place of thy name to the ground.
15057	552	8	They said in their hearts, Let us destroy them together: they have burned up all the synagogues of God in the land.
15058	552	9	We see not our signs: there is no more any prophet: neither is there among us any that knoweth how long.
15059	552	10	O God, how long shall the adversary reproach? shall the enemy blaspheme thy name for ever?
15060	552	11	Why withdrawest thou thy hand, even thy right hand? pluck it out of thy bosom.
15061	552	12	For God is my King of old, working salvation in the midst of the earth.
15062	552	13	Thou didst divide the sea by thy strength: thou brakest the heads of the dragons in the waters.
15063	552	14	Thou brakest the heads of leviathan in pieces, and gavest him to be meat to the people inhabiting the wilderness.
15064	552	15	Thou didst cleave the fountain and the flood: thou driedst up mighty rivers.
15065	552	16	The day is thine, the night also is thine: thou hast prepared the light and the sun.
15066	552	17	Thou hast set all the borders of the earth: thou hast made summer and winter.
15067	552	18	Remember this, that the enemy hath reproached, O LORD, and that the foolish people have blasphemed thy name.
15068	552	19	O deliver not the soul of thy turtledove unto the multitude of the wicked: forget not the congregation of thy poor for ever.
15069	552	20	Have respect unto the covenant: for the dark places of the earth are full of the habitations of cruelty.
15070	552	21	O let not the oppressed return ashamed: let the poor and needy praise thy name.
15071	552	22	Arise, O God, plead thine own cause: remember how the foolish man reproacheth thee daily.
15072	552	23	Forget not the voice of thine enemies: the tumult of those that rise up against thee increaseth continually.
15073	553	1	UNTO thee, O God, do we give thanks, unto thee do we give thanks: for that thy name is near thy wondrous works declare.
15074	553	2	When I shall receive the congregation I will judge uprightly.
15075	553	3	The earth and all the inhabitants thereof are dissolved: I bear up the pillars of it. Selah.
15076	553	4	I said unto the fools, Deal not foolishly: and to the wicked, Lift not up the horn:
15077	553	5	Lift not up your horn on high: speak not with a stiff neck.
15078	553	6	For promotion cometh neither from the east, nor from the west, nor from the south.
15079	553	7	But God is the judge: he putteth down one, and setteth up another.
15080	553	8	For in the hand of the LORD there is a cup, and the wine is red; it is full of mixture; and he poureth out of the same: but the dregs thereof, all the wicked of the earth shall wring them out, and drink them.
15081	553	9	But I will declare for ever; I will sing praises to the God of Jacob.
15082	553	10	All the horns of the wicked also will I cut off; but the horns of the righteous shall be exalted.
15083	554	1	IN Judah is God known: his name is great in Israel.
15084	554	2	In Salem also is his tabernacle, and his dwelling place in Zion.
15085	554	3	There brake he the arrows of the bow, the shield, and the sword, and the battle. Selah.
15086	554	4	Thou art more glorious and excellent than the mountains of prey.
15087	554	5	The stouthearted are spoiled, they have slept their sleep: and none of the men of might have found their hands.
15088	554	6	At thy rebuke, O God of Jacob, both the chariot and horse are cast into a dead sleep.
15089	554	7	Thou, even thou, art to be feared: and who may stand in thy sight when once thou art angry?
15090	554	8	Thou didst cause judgment to be heard from heaven; the earth feared, and was still,
15091	554	9	When God arose to judgment, to save all the meek of the earth. Selah.
15092	554	10	Surely the wrath of man shall praise thee: the remainder of wrath shalt thou restrain.
15093	554	11	Vow, and pay unto the LORD your God: let all that be round about him bring presents unto him that ought to be feared.
15094	554	12	He shall cut off the spirit of princes: he is terrible to the kings of the earth.
15095	555	1	I CRIED unto God with my voice, even unto God with my voice; and he gave ear unto me.
15096	555	2	In the day of my trouble I sought the Lord: my sore ran in the night, and ceased not: my soul refused to be comforted.
15097	555	3	I remembered God, and was troubled: I complained, and my spirit was overwhelmed. Selah.
15098	555	4	Thou holdest mine eyes waking: I am so troubled that I cannot speak.
15099	555	5	I have considered the days of old, the years of ancient times.
15100	555	6	I call to remembrance my song in the night: I commune with mine own heart: and my spirit made diligent search.
15101	555	7	Will the Lord cast off for ever? and will he be favourable no more?
15102	555	8	Is his mercy clean gone for ever? doth his promise fail for evermore?
15103	555	9	Hath God forgotten to be gracious? hath he in anger shut up his tender mercies? Selah.
15104	555	10	And I said, This is my infirmity: but I will remember the years of the right hand of the most High.
15105	555	11	I will remember the works of the LORD: surely I will remember thy wonders of old.
15106	555	12	I will meditate also of all thy work, and talk of thy doings.
15107	555	13	Thy way, O God, is in the sanctuary: who is so great a God as our God?
15108	555	14	Thou art the God that doest wonders: thou hast declared thy strength among the people.
15109	555	15	Thou hast with thine arm redeemed thy people, the sons of Jacob and Joseph. Selah.
15110	555	16	The waters saw thee, O God, the waters saw thee; they were afraid: the depths also were troubled.
15111	555	17	The clouds poured out water: the skies sent out a sound: thine arrows also went abroad.
15112	555	18	The voice of thy thunder was in the heaven: the lightnings lightened the world: the earth trembled and shook.
15113	555	19	Thy way is in the sea, and thy path in the great waters, and thy footsteps are not known.
15114	555	20	Thou leddest thy people like a flock by the hand of Moses and Aaron.
15115	556	1	GIVE ear, O my people, to my law: incline your ears to the words of my mouth.
15116	556	2	I will open my mouth in a parable: I will utter dark sayings of old:
15117	556	3	Which we have heard and known, and our fathers have told us.
15118	556	4	We will not hide them from their children, shewing to the generation to come the praises of the LORD, and his strength, and his wonderful works that he hath done.
15119	556	5	For he established a testimony in Jacob, and appointed a law in Israel, which he commanded our fathers, that they should make them known to their children:
15120	556	6	That the generation to come might know them, even the children which should be born; who should arise and declare them to their children:
15121	556	7	That they might set their hope in God, and not forget the works of God, but keep his commandments:
15122	556	8	And might not be as their fathers, a stubborn and rebellious generation; a generation that set not their heart aright, and whose spirit was not stedfast with God.
15123	556	9	The children of Ephraim, being armed, and carrying bows, turned back in the day of battle.
15124	556	10	They kept not the covenant of God, and refused to walk in his law;
15125	556	11	And forgat his works, and his wonders that he had shewed them.
15126	556	12	Marvellous things did he in the sight of their fathers, in the land of Egypt, in the field of Zoan.
15127	556	13	He divided the sea, and caused them to pass through; and he made the waters to stand as an heap.
15128	556	14	In the daytime also he led them with a cloud, and all the night with a light of fire.
15129	556	15	He clave the rocks in the wilderness, and gave them drink as out of the great depths.
15130	556	16	He brought streams also out of the rock, and caused waters to run down like rivers.
15131	556	17	And they sinned yet more against him by provoking the most High in the wilderness.
15132	556	18	And they tempted God in their heart by asking meat for their lust.
15133	556	19	Yea, they spake against God; they said, Can God furnish a table in the wilderness?
15134	556	20	Behold, he smote the rock, that the waters gushed out, and the streams overflowed; can he give bread also? can he provide flesh for his people?
15135	556	21	Therefore the LORD heard this, and was wroth: so a fire was kindled against Jacob, and anger also came up against Israel;
15136	556	22	Because they believed not in God, and trusted not in his salvation:
15137	556	23	Though he had commanded the clouds from above, and opened the doors of heaven,
15138	556	24	And had rained down manna upon them to eat, and had given them of the corn of heaven.
15139	556	25	Man did eat angels' food: he sent them meat to the full.
15140	556	26	He caused an east wind to blow in the heaven: and by his power he brought in the south wind.
15141	556	27	He rained flesh also upon them as dust, and feathered fowls like as the sand of the sea:
15142	556	28	And he let it fall in the midst of their camp, round about their habitations.
15143	556	29	So they did eat, and were well filled: for he gave them their own desire;
15144	556	30	They were not estranged from their lust. But while their meat was yet in their mouths,
15145	556	31	The wrath of God came upon them, and slew the fattest of them, and smote down the chosen men of Israel.
15146	556	32	For all this they sinned still, and believed not for his wondrous works.
15147	556	33	Therefore their days did he consume in vanity, and their years in trouble.
15148	556	34	When he slew them, then they sought him: and they returned and enquired early after God.
15149	556	35	And they remembered that God was their rock, and the high God their redeemer.
15150	556	36	Nevertheless they did flatter him with their mouth, and they lied unto him with their tongues.
15151	556	37	For their heart was not right with him, neither were they stedfast in his covenant.
15152	556	38	But he, being full of compassion, forgave their iniquity, and destroyed them not: yea, many a time turned he his anger away, and did not stir up all his wrath.
15153	556	39	For he remembered that they were but flesh; a wind that passeth away, and cometh not again.
15154	556	40	How oft did they provoke him in the wilderness, and grieve him in the desert!
15155	556	41	Yea, they turned back and tempted God, and limited the Holy One of Israel.
15156	556	42	They remembered not his hand, nor the day when he delivered them from the enemy.
15157	556	43	How he had wrought his signs in Egypt, and his wonders in the field of Zoan:
15158	556	44	And had turned their rivers into blood; and their floods, that they could not drink.
15159	556	45	He sent divers sorts of flies among them, which devoured them; and frogs, which destroyed them.
15160	556	46	He gave also their increase unto the caterpiller, and their labour unto the locust.
15161	556	47	He destroyed their vines with hail, and their sycomore trees with frost.
15162	556	48	He gave up their cattle also to the hail, and their flocks to hot thunderbolts.
15163	556	49	He cast upon them the fierceness of his anger, wrath, and indignation, and trouble, by sending evil angels among them.
15164	556	50	He made a way to his anger; he spared not their soul from death, but gave their life over to the pestilence;
15165	556	51	And smote all the firstborn in Egypt; the chief of their strength in the tabernacles of Ham:
15166	556	52	But made his own people to go forth like sheep, and guided them in the wilderness like a flock.
15167	556	53	And he led them on safely, so that they feared not: but the sea overwhelmed their enemies.
15168	556	54	And he brought them to the border of his sanctuary, even to this mountain, which his right hand had purchased.
15169	556	55	He cast out the heathen also before them, and divided them an inheritance by line, and made the tribes of Israel to dwell in their tents.
15170	556	56	Yet they tempted and provoked the most high God, and kept not his testimonies:
15171	556	57	But turned back, and dealt unfaithfully like their fathers: they were turned aside like a deceitful bow.
15172	556	58	For they provoked him to anger with their high places, and moved him to jealousy with their graven images.
15173	556	59	When God heard this, he was wroth, and greatly abhorred Israel:
15174	556	60	So that he forsook the tabernacle of Shiloh, the tent which he placed among men;
15175	556	61	And delivered his strength into captivity, and his glory into the enemy's hand.
15176	556	62	He gave his people over also unto the sword; and was wroth with his inheritance.
15177	556	63	The fire consumed their young men; and their maidens were not given to marriage.
15178	556	64	Their priests fell by the sword; and their widows made no lamentation.
15179	556	65	Then the Lord awaked as one out of sleep, and like a mighty man that shouteth by reason of wine.
15180	556	66	And he smote his enemies in the hinder parts: he put them to a perpetual reproach.
15181	556	67	Moreover he refused the tabernacle of Joseph, and chose not the tribe of Ephraim:
15182	556	68	But chose the tribe of Judah, the mount Zion which he loved.
15183	556	69	And he built his sanctuary like high palaces, like the earth which he hath established for ever.
15184	556	70	He chose David also his servant, and took him from the sheepfolds:
15185	556	71	From following the ewes great with young he brought him to feed Jacob his people, and Israel his inheritance.
15186	556	72	So he fed them according to the integrity of his heart; and guided them by the skilfulness of his hands.
15187	557	1	O GOD, the heathen are come into thine inheritance; thy holy temple have they defiled; they have laid Jerusalem on heaps.
15188	557	2	The dead bodies of thy servants have they given to be meat unto the fowls of the heaven, the flesh of thy saints unto the beasts of the earth.
15189	557	3	Their blood have they shed like water round about Jerusalem; and there was none to bury them.
15190	557	4	We are become a reproach to our neighbours, a scorn and derision to them that are round about us.
15191	557	5	How long, LORD? wilt thou be angry for ever? shall thy jealousy burn like fire?
15192	557	6	Pour out thy wrath upon the heathen that have not known thee, and upon the kingdoms that have not called upon thy name.
15193	557	7	For they have devoured Jacob, and laid waste his dwelling place.
15194	557	8	O remember not against us former iniquities: let thy tender mercies speedily prevent us: for we are brought very low.
15195	557	9	Help us, O God of our salvation, for the glory of thy name: and deliver us, and purge away our sins, for thy name's sake.
15196	557	10	Wherefore should the heathen say, Where is their God? let him be known among the heathen in our sight by the revenging of the blood of thy servants which is shed.
15197	557	11	Let the sighing of the prisoner come before thee; according to the greatness of thy power preserve thou those that are appointed to die;
15198	557	12	And render unto our neighbours sevenfold into their bosom their reproach, wherewith they have reproached thee, O Lord.
15199	557	13	So we thy people and sheep of thy pasture will give thee thanks for ever: we will shew forth thy praise to all generations.
15200	558	1	GIVE ear, O Shepherd of Israel, thou that leadest Joseph like a flock; thou that dwellest between the cherubims, shine forth.
15201	558	2	Before Ephraim and Benjamin and Manasseh stir up thy strength, and come and save us.
15202	558	3	Turn us again, O God, and cause thy face to shine; and we shall be saved.
15203	558	4	O LORD God of hosts, how long wilt thou be angry against the prayer of thy people?
15204	558	5	Thou feedest them with the bread of tears; and givest them tears to drink in great measure.
15205	558	6	Thou makest us a strife unto our neighbours: and our enemies laugh among themselves.
15206	558	7	Turn us again, O God of hosts, and cause thy face to shine; and we shall be saved.
15207	558	8	Thou hast brought a vine out of Egypt: thou hast cast out the heathen, and planted it.
15208	558	9	Thou preparedst room before it, and didst cause it to take deep root, and it filled the land.
15209	558	10	The hills were covered with the shadow of it, and the boughs thereof were like the goodly cedars.
15210	558	11	She sent out her boughs unto the sea, and her branches unto the river.
15211	558	12	Why hast thou then broken down her hedges, so that all they which pass by the way do pluck her?
15212	558	13	The boar out of the wood doth waste it, and the wild beast of the field doth devour it.
15213	558	14	Return, we beseech thee, O God of hosts: look down from heaven, and behold, and visit this vine;
15214	558	15	And the vineyard which thy right hand hath planted, and the branch that thou madest strong for thyself.
15215	558	16	It is burned with fire, it is cut down: they perish at the rebuke of thy countenance.
15216	558	17	Let thy hand be upon the man of thy right hand, upon the son of man whom thou madest strong for thyself.
15217	558	18	So will not we go back from thee: quicken us, and we will call upon thy name.
15218	558	19	Turn us again, O LORD God of hosts, cause thy face to shine; and we shall be saved.
15219	559	1	SING aloud unto God our strength: make a joyful noise unto the God of Jacob.
15220	559	2	Take a psalm, and bring hither the timbrel, the pleasant harp with the psaltery.
15221	559	3	Blow up the trumpet in the new moon, in the time appointed, on our solemn feast day.
15222	559	4	For this was a statute for Israel, and a law of the God of Jacob.
15223	559	5	This he ordained in Joseph for a testimony, when he went out through the land of Egypt: where I heard a language that I understood not.
15224	559	6	I removed his shoulder from the burden: his hands were delivered from the pots.
15225	559	7	Thou calledst in trouble, and I delivered thee; I answered thee in the secret place of thunder: I proved thee at the waters of Meribah. Selah.
15226	559	8	Hear, O my people, and I will testify unto thee: O Israel, if thou wilt hearken unto me;
15227	559	9	There shall no strange god be in thee; neither shalt thou worship any strange god.
15228	559	10	I am the LORD thy God, which brought thee out of the land of Egypt: open thy mouth wide, and I will fill it.
15229	559	11	But my people would not hearken to my voice; and Israel would none of me.
15230	559	12	So I gave them up unto their own hearts' lust: and they walked in their own counsels.
15231	559	13	Oh that my people had hearkened unto me, and Israel had walked in my ways!
15232	559	14	I should soon have subdued their enemies, and turned my hand against their adversaries.
15233	559	15	The haters of the LORD should have submitted themselves unto him: but their time should have endured for ever.
15234	559	16	He should have fed them also with the finest of the wheat: and with honey out of the rock should I have satisfied thee.
15235	560	1	GOD standeth in the congregation of the mighty; he judgeth among the gods.
15236	560	2	How long will ye judge unjustly, and accept the persons of the wicked? Selah.
15237	560	3	Defend the poor and fatherless: do justice to the afflicted and needy.
15238	560	4	Deliver the poor and needy: rid them out of the hand of the wicked.
15239	560	5	They know not, neither will they understand; they walk on in darkness: all the foundations of the earth are out of course.
15240	560	6	I have said, Ye are gods; and all of you are children of the most High.
15241	560	7	But ye shall die like men, and fall like one of the princes.
15242	560	8	Arise, O God, judge the earth: for thou shalt inherit all nations.
15243	561	1	KEEP not thou silence, O God: hold not thy peace, and be not still, O God.
15244	561	2	For, lo, thine enemies make a tumult: and they that hate thee have lifted up the head.
15245	561	3	They have taken crafty counsel against thy people, and consulted against thy hidden ones.
15246	561	4	They have said, Come, and let us cut them off from being a nation; that the name of Israel may be no more in remembrance.
15247	561	5	For they have consulted together with one consent: they are confederate against thee:
15248	561	6	The tabernacles of Edom, and the Ishmaelites; of Moab, and the Hagarenes;
15249	561	7	Gebal, and Ammon, and Amalek; the Philistines with the inhabitants of Tyre;
15250	561	8	Assur also is joined with them: they have holpen the children of Lot. Selah.
15251	561	9	Do unto them as unto the Midianites; as to Sisera, as to Jabin, at the brook of Kison:
15252	561	10	Which perished at En-dor: they became as dung for the earth.
15253	561	11	Make their nobles like Oreb, and like Zeeb: yea, all their princes as Zebah, and as Zalmunna:
15254	561	12	Who said, Let us take to ourselves the houses of God in possession.
15255	561	13	O my God, make them like a wheel; as the stubble before the wind.
15256	561	14	As the fire burneth a wood, and as the flame setteth the mountains on fire;
15257	561	15	So persecute them with thy tempest, and make them afraid with thy storm.
15258	561	16	Fill their faces with shame; that they may seek thy name, O LORD.
15259	561	17	Let them be confounded and troubled for ever; yea, let them be put to shame, and perish:
15260	561	18	That men may know that thou, whose name alone is JEHOVAH, art the most high over all the earth.
15261	562	1	HOW amiable are thy tabernacles, O LORD of hosts!
15262	562	2	My soul longeth, yea, even fainteth for the courts of the LORD: my heart and my flesh crieth out for the living God.
15263	562	3	Yea, the sparrow hath found an house, and the swallow a nest for herself, where she may lay her young, even thine altars, O LORD of hosts, my King, and my God.
15264	562	4	Blessed are they that dwell in thy house: they will be still praising thee. Selah.
15265	562	5	Blessed is the man whose strength is in thee; in whose heart are the ways of them.
15266	562	6	Who passing through the valley of Baca make it a well; the rain also filleth the pools.
15267	562	7	They go from strength to strength, every one of them in Zion appeareth before God.
15268	562	8	O LORD God of hosts, hear my prayer: give ear, O God of Jacob. Selah.
15269	562	9	Behold, O God our shield, and look upon the face of thine anointed.
15270	562	10	For a day in thy courts is better than a thousand. I had rather be a doorkeeper in the house of my God, than to dwell in the tents of wickedness.
15271	562	11	For the LORD God is a sun and shield: the LORD will give grace and glory: no good thing will he withhold from them that walk uprightly.
15272	562	12	O LORD of hosts, blessed is the man that trusteth in thee.
15273	563	1	LORD, thou hast been favourable unto thy land: thou hast brought back the captivity of Jacob.
15274	563	2	Thou hast forgiven the iniquity of thy people, thou hast covered all their sin. Selah.
15275	563	3	Thou hast taken away all thy wrath: thou hast turned thyself from the fierceness of thine anger.
15276	563	4	Turn us, O God of our salvation, and cause thine anger toward us to cease.
15277	563	5	Wilt thou be angry with us for ever? wilt thou draw out thine anger to all generations?
15278	563	6	Wilt thou not revive us again: that thy people may rejoice in thee?
15279	563	7	Shew us thy mercy, O LORD, and grant us thy salvation.
15280	563	8	I will hear what God the LORD will speak: for he will speak peace unto his people, and to his saints: but let them not turn again to folly.
15281	563	9	Surely his salvation is nigh them that fear him; that glory may dwell in our land.
15282	563	10	Mercy and truth are met together; righteousness and peace have kissed each other.
15283	563	11	Truth shall spring out of the earth; and righteousness shall look down from heaven.
15284	563	12	Yea, the LORD shall give that which is good; and our land shall yield her increase.
15285	563	13	Righteousness shall go before him; and shall set us in the way of his steps.
15286	564	1	BOW down thine ear, O LORD, hear me: for I am poor and needy.
15287	564	2	Preserve my soul; for I am holy: O thou my God, save thy servant that trusteth in thee.
15288	564	3	Be merciful unto me, O Lord: for I cry unto thee daily.
15289	564	4	Rejoice the soul of thy servant: for unto thee, O Lord, do I lift up my soul.
15290	564	5	For thou, Lord, art good, and ready to forgive; and plenteous in mercy unto all them that call upon thee.
15291	564	6	Give ear, O LORD, unto my prayer; and attend to the voice of my supplications.
15292	564	7	In the day of my trouble I will call upon thee: for thou wilt answer me.
15293	564	8	Among the gods there is none like unto thee, O Lord; neither are there any works like unto thy works.
15294	564	9	All nations whom thou hast made shall come and worship before thee, O Lord; and shall glorify thy name.
15295	564	10	For thou art great, and doest wondrous things: thou art God alone.
15296	564	11	Teach me thy way, O LORD; I will walk in thy truth: unite my heart to fear thy name.
15297	564	12	I will praise thee, O Lord my God, with all my heart: and I will glorify thy name for evermore.
15298	564	13	For great is thy mercy toward me: and thou hast delivered my soul from the lowest hell.
15299	564	14	O God, the proud are risen against me, and the assemblies of violent men have sought after my soul; and have not set thee before them.
15300	564	15	But thou, O Lord, art a God full of compassion, and gracious, longsuffering, and plenteous in mercy and truth.
15301	564	16	O turn unto me, and have mercy upon me; give thy strength unto thy servant, and save the son of thine handmaid.
15302	564	17	Shew me a token for good; that they which hate me may see it, and be ashamed: because thou, LORD, hast holpen me, and comforted me.
15303	565	1	HIS foundation is in the holy mountains.
15304	565	2	The LORD loveth the gates of Zion more than all the dwellings of Jacob.
15305	565	3	Glorious things are spoken of thee, O city of God. Selah.
15306	565	4	I will make mention of Rahab and Babylon to them that know me: behold Philistia, and Tyre, with Ethiopia; this man was born there.
15307	565	5	And of Zion it shall be said, This and that man was born in her: and the highest himself shall establish her.
15308	565	6	The LORD shall count, when he writeth up the people, that this man was born there. Selah.
15309	565	7	As well the singers as the players on instruments shall be there: all my springs are in thee.
15310	566	1	O LORD God of my salvation, I have cried day and night before thee:
15311	566	2	Let my prayer come before thee: incline thine ear unto my cry;
15312	566	3	For my soul is full of troubles: and my life draweth nigh unto the grave.
15313	566	4	I am counted with them that go down into the pit: I am as a man that hath no strength:
15314	566	5	Free among the dead, like the slain that lie in the grave, whom thou rememberest no more: and they are cut off from thy hand.
15315	566	6	Thou hast laid me in the lowest pit, in darkness, in the deeps.
15316	566	7	Thy wrath lieth hard upon me, and thou hast afflicted me with all thy waves. Selah.
15317	566	8	Thou hast put away mine acquaintance far from me; thou hast made me an abomination unto them: I am shut up, and I cannot come forth.
15318	566	9	Mine eye mourneth by reason of affliction: LORD, I have called daily upon thee, I have stretched out my hands unto thee.
15319	566	10	Wilt thou shew wonders to the dead? shall the dead arise and praise thee? Selah.
15320	566	11	Shall thy lovingkindness be declared in the grave? or thy faithfulness in destruction?
15321	566	12	Shall thy wonders be known in the dark? and thy righteousness in the land of forgetfulness?
15322	566	13	But unto thee have I cried, O LORD; and in the morning shall my prayer prevent thee.
15323	566	14	LORD, why castest thou off my soul? why hidest thou thy face from me?
15324	566	15	I am afflicted and ready to die from my youth up: while I suffer thy terrors I am distracted.
15325	566	16	Thy fierce wrath goeth over me; thy terrors have cut me off.
15326	566	17	They came round about me daily like water; they compassed me about together.
15327	566	18	Lover and friend hast thou put far from me, and mine acquaintance into darkness.
15328	567	1	I WILL sing of the mercies of the LORD for ever: with my mouth will I make known thy faithfulness to all generations.
15329	567	2	For I have said, Mercy shall be built up for ever: thy faithfulness shalt thou establish in the very heavens.
15330	567	3	I have made a covenant with my chosen, I have sworn unto David my servant,
15331	567	4	Thy seed will I establish for ever, and build up thy throne to all generations. Selah.
15332	567	5	And the heavens shall praise thy wonders, O LORD: thy faithfulness also in the congregation of the saints.
15333	567	6	For who in the heaven can be compared unto the LORD? who among the sons of the mighty can be likened unto the LORD?
15334	567	7	God is greatly to be feared in the assembly of the saints, and to be had in reverence of all them that are about him.
15335	567	8	O LORD God of hosts, who is a strong LORD like unto thee? or to thy faithfulness round about thee?
15336	567	9	Thou rulest the raging of the sea: when the waves thereof arise, thou stillest them.
15337	567	10	Thou hast broken Rahab in pieces, as one that is slain; thou hast scattered thine enemies with thy strong arm.
15338	567	11	The heavens are thine, the earth also is thine: as for the world and the fulness thereof, thou hast founded them.
15339	567	12	The north and the south thou hast created them: Tabor and Hermon shall rejoice in thy name.
15340	567	13	Thou hast a mighty arm: strong is thy hand, and high is thy right hand.
15341	567	14	Justice and judgment are the habitation of thy throne: mercy and truth shall go before thy face.
15342	567	15	Blessed is the people that know the joyful sound: they shall walk, O LORD, in the light of thy countenance.
15343	567	16	In thy name shall they rejoice all the day: and in thy righteousness shall they be exalted.
15344	567	17	For thou art the glory of their strength: and in thy favour our horn shall be exalted.
15345	567	18	For the LORD is our defence; and the Holy One of Israel is our king.
15346	567	19	Then thou spakest in vision to thy holy one, and saidst, I have laid help upon one that is mighty; I have exalted one chosen out of the people.
15347	567	20	I have found David my servant; with my holy oil have I anointed him:
15348	567	21	With whom my hand shall be established: mine arm also shall strengthen him.
15349	567	22	The enemy shall not exact upon him; nor the son of wickedness afflict him.
15350	567	23	And I will beat down his foes before his face, and plague them that hate him.
15351	567	24	But my faithfulness and my mercy shall be with him: and in my name shall his horn be exalted.
15352	567	25	I will set his hand also in the sea, and his right hand in the rivers.
15353	567	26	He shall cry unto me, Thou art my father, my God, and the rock of my salvation.
15354	567	27	Also I will make him my firstborn, higher than the kings of the earth.
15355	567	28	My mercy will I keep for him for evermore, and my covenant shall stand fast with him.
15356	567	29	His seed also will I make to endure for ever, and his throne as the days of heaven.
15357	567	30	If his children forsake my law, and walk not in my judgments;
15358	567	31	If they break my statutes, and keep not my commandments;
15359	567	32	Then will I visit their transgression with the rod, and their iniquity with stripes.
15360	567	33	Nevertheless my lovingkindness will I not utterly take from him, nor suffer my faithfulness to fail.
15361	567	34	My covenant will I not break, nor alter the thing that is gone out of my lips.
15362	567	35	Once have I sworn by my holiness that I will not lie unto David.
15363	567	36	His seed shall endure for ever, and his throne as the sun before me.
15364	567	37	It shall be established for ever as the moon, and as a faithful witness in heaven. Selah.
15365	567	38	But thou hast cast off and abhorred, thou hast been wroth with thine anointed.
15366	567	39	Thou hast made void the covenant of thy servant: thou hast profaned his crown by casting it to the ground.
15367	567	40	Thou hast broken down all his hedges; thou hast brought his strong holds to ruin.
15368	567	41	All that pass by the way spoil him: he is a reproach to his neighbours.
15369	567	42	Thou hast set up the right hand of his adversaries; thou hast made all his enemies to rejoice.
15370	567	43	Thou hast also turned the edge of his sword, and hast not made him to stand in the battle.
15371	567	44	Thou hast made his glory to cease, and cast his throne down to the ground.
15372	567	45	The days of his youth hast thou shortened: thou hast covered him with shame. Selah.
15373	567	46	How long, LORD? wilt thou hide thyself for ever? shall thy wrath burn like fire?
15374	567	47	Remember how short my time is: wherefore hast thou made all men in vain?
15375	567	48	What man is he that liveth, and shall not see death? shall he deliver his soul from the hand of the grave? Selah.
15376	567	49	Lord, where are thy former lovingkindnesses, which thou swarest unto David in thy truth?
15377	567	50	Remember, Lord, the reproach of thy servants; how I do bear in my bosom the reproach of all the mighty people;
15378	567	51	Wherewith thine enemies have reproached, O LORD; wherewith they have reproached the footsteps of thine anointed.
15379	567	52	Blessed be the LORD for evermore. Amen, and Amen.
15380	568	1	LORD, thou hast been our dwelling place in all generations.
15381	568	2	Before the mountains were brought forth, or ever thou hadst formed the earth and the world, even from everlasting to everlasting, thou art God.
15382	568	3	Thou turnest man to destruction; and sayest, Return, ye children of men.
15383	568	4	For a thousand years in thy sight are but as yesterday when it is past, and as a watch in the night.
15384	568	5	Thou carriest them away as with a flood; they are as a sleep: in the morning they are like grass which groweth up.
15385	568	6	In the morning it flourisheth, and groweth up; in the evening it is cut down, and withereth.
15386	568	7	For we are consumed by thine anger, and by thy wrath are we troubled.
15387	568	8	Thou hast set our iniquities before thee, our secret sins in the light of thy countenance.
15388	568	9	For all our days are passed away in thy wrath: we spend our years as a tale that is told.
15389	568	10	The days of our years are threescore years and ten; and if by reason of strength they be fourscore years, yet is their strength labour and sorrow; for it is soon cut off, and we fly away.
15390	568	11	Who knoweth the power of thine anger? even according to thy fear, so is thy wrath.
15391	568	12	So teach us to number our days, that we may apply our hearts unto wisdom.
15392	568	13	Return, O LORD, how long? and let it repent thee concerning thy servants.
15393	568	14	O satisfy us early with thy mercy; that we may rejoice and be glad all our days.
15394	568	15	Make us glad according to the days wherein thou hast afflicted us, and the years wherein we have seen evil.
15395	568	16	Let thy work appear unto thy servants, and thy glory unto their children.
15396	568	17	And let the beauty of the LORD our God be upon us: and establish thou the work of our hands upon us; yea, the work of our hands establish thou it.
15397	569	1	HE that dwelleth in the secret place of the most High shall abide under the shadow of the Almighty.
15398	569	2	I will say of the LORD, He is my refuge and my fortress: my God; in him will I trust.
15399	569	3	Surely he shall deliver thee from the snare of the fowler, and from the noisome pestilence.
15400	569	4	He shall cover thee with his feathers, and under his wings shalt thou trust: his truth shall be thy shield and buckler.
15401	569	5	Thou shalt not be afraid for the terror by night; nor for the arrow that flieth by day;
15402	569	6	Nor for the pestilence that walketh in darkness; nor for the destruction that wasteth at noonday.
15403	569	7	A thousand shall fall at thy side, and ten thousand at thy right hand; but it shall not come nigh thee.
15404	569	8	Only with thine eyes shalt thou behold and see the reward of the wicked.
15405	569	9	Because thou hast made the LORD, which is my refuge, even the most High, thy habitation;
15406	569	10	There shall no evil befall thee, neither shall any plague come nigh thy dwelling.
15407	569	11	For he shall give his angels charge over thee, to keep thee in all thy ways.
15408	569	12	They shall bear thee up in their hands, lest thou dash thy foot against a stone.
15409	569	13	Thou shalt tread upon the lion and adder: the young lion and the dragon shalt thou trample under feet.
15410	569	14	Because he hath set his love upon me, therefore will I deliver him: I will set him on high, because he hath known my name.
15411	569	15	He shall call upon me, and I will answer him: I will be with him in trouble; I will deliver him, and honour him.
15412	569	16	With long life will I satisfy him, and shew him my salvation.
15413	570	1	IT is a good thing to give thanks unto the LORD, and to sing praises unto thy name, O most High:
15414	570	2	To shew forth thy lovingkindness in the morning, and thy faithfulness every night,
15415	570	3	Upon an instrument of ten strings, and upon the psaltery; upon the harp with a solemn sound.
15416	570	4	For thou, LORD, hast made me glad through thy work: I will triumph in the works of thy hands.
15417	570	5	O LORD, how great are thy works! and thy thoughts are very deep.
15418	570	6	A brutish man knoweth not; neither doth a fool understand this.
15419	570	7	When the wicked spring as the grass, and when all the workers of iniquity do flourish; it is that they shall be destroyed for ever:
15420	570	8	But thou, LORD, art most high for evermore.
15421	570	9	For, lo, thine enemies, O LORD, for, lo, thine enemies shall perish; all the workers of iniquity shall be scattered.
15422	570	10	But my horn shalt thou exalt like the horn of an unicorn: I shall be anointed with fresh oil.
15423	570	11	Mine eye also shall see my desire on mine enemies, and mine ears shall hear my desire of the wicked that rise up against me.
15424	570	12	The righteous shall flourish like the palm tree: he shall grow like a cedar in Lebanon.
15425	570	13	Those that be planted in the house of the LORD shall flourish in the courts of our God.
15426	570	14	They shall still bring forth fruit in old age; they shall be fat and flourishing;
15427	570	15	To shew that the LORD is upright: he is my rock, and there is no unrighteousness in him.
15428	571	1	THE LORD reigneth, he is clothed with majesty; the LORD is clothed with strength, wherewith he hath girded himself: the world also is stablished, that it cannot be moved.
15429	571	2	Thy throne is established of old: thou art from everlasting.
15430	571	3	The floods have lifted up, O LORD, the floods have lifted up their voice; the floods lift up their waves.
15431	571	4	The LORD on high is mightier than the noise of many waters, yea, than the mighty waves of the sea.
15432	571	5	Thy testimonies are very sure: holiness becometh thine house, O LORD, for ever.
15433	572	1	O LORD God, to whom vengeance belongeth; O God, to whom vengeance belongeth, shew thyself.
15434	572	2	Lift up thyself, thou judge of the earth: render a reward to the proud.
15435	572	3	LORD, how long shall the wicked, how long shall the wicked triumph?
15436	572	4	How long shall they utter and speak hard things? and all the workers of iniquity boast themselves?
15437	572	5	They break in pieces thy people, O LORD, and afflict thine heritage.
15438	572	6	They slay the widow and the stranger, and murder the fatherless.
15439	572	7	Yet they say, The LORD shall not see, neither shall the God of Jacob regard it.
15440	572	8	Understand, ye brutish among the people: and ye fools, when will ye be wise?
15441	572	9	He that planted the ear, shall he not hear? he that formed the eye, shall he not see?
15442	572	10	He that chastiseth the heathen, shall not he correct? he that teacheth man knowledge, shall not he know?
15443	572	11	The LORD knoweth the thoughts of man, that they are vanity.
15444	572	12	Blessed is the man whom thou chastenest, O LORD, and teachest him out of thy law;
15445	572	13	That thou mayest give him rest from the days of adversity, until the pit be digged for the wicked.
15446	572	14	For the LORD will not cast off his people, neither will he forsake his inheritance.
15447	572	15	But judgment shall return unto righteousness: and all the upright in heart shall follow it.
15448	572	16	Who will rise up for me against the evildoers? or who will stand up for me against the workers of iniquity?
15449	572	17	Unless the LORD had been my help, my soul had almost dwelt in silence.
15450	572	18	When I said, My foot slippeth; thy mercy, O LORD, held me up.
15451	572	19	In the multitude of my thoughts within me thy comforts delight my soul.
15452	572	20	Shall the throne of iniquity have fellowship with thee, which frameth mischief by a law?
15453	572	21	They gather themselves together against the soul of the righteous, and condemn the innocent blood.
15454	572	22	But the LORD is my defence; and my God is the rock of my refuge.
15455	572	23	And he shall bring upon them their own iniquity, and shall cut them off in their own wickedness; yea, the LORD our God shall cut them off.
15456	573	1	O COME, let us sing unto the LORD: let us make a joyful noise to the rock of our salvation.
15457	573	2	Let us come before his presence with thanksgiving, and make a joyful noise unto him with psalms.
15458	573	3	For the LORD is a great God, and a great King above all gods.
15459	573	4	In his hand are the deep places of the earth: the strength of the hills is his also.
15460	573	5	The sea is his, and he made it: and his hands formed the dry land.
15461	573	6	O come, let us worship and bow down: let us kneel before the LORD our maker.
15462	573	7	For he is our God; and we are the people of his pasture, and the sheep of his hand. To day if ye will hear his voice,
15463	573	8	Harden not your heart, as in the provocation, and as in the day of temptation in the wilderness:
15464	573	9	When your fathers tempted me, proved me, and saw my work.
15465	573	10	Forty years long was I grieved with this generation, and said, It is a people that do err in their heart, and they have not known my ways:
15466	573	11	Unto whom I sware in my wrath that they should not enter into my rest.
15467	574	1	O SING unto the LORD a new song: sing unto the LORD, all the earth.
15468	574	2	Sing unto the LORD, bless his name; shew forth his salvation from day to day.
15469	574	3	Declare his glory among the heathen, his wonders among all people.
15470	574	4	For the LORD is great, and greatly to be praised: he is to be feared above all gods.
15471	574	5	For all the gods of the nations are idols: but the LORD made the heavens.
15472	574	6	Honour and majesty are before him: strength and beauty are in his sanctuary.
15473	574	7	Give unto the LORD, O ye kindreds of the people, give unto the LORD glory and strength.
15474	574	8	Give unto the LORD the glory due unto his name: bring an offering, and come into his courts.
15475	574	9	O worship the LORD in the beauty of holiness: fear before him, all the earth.
15476	574	10	Say among the heathen that the LORD reigneth: the world also shall be established that it shall not be moved: he shall judge the people righteously.
15477	574	11	Let the heavens rejoice, and let the earth be glad; let the sea roar, and the fulness thereof.
15478	574	12	Let the field be joyful, and all that is therein: then shall all the trees of the wood rejoice
15479	574	13	Before the LORD: for he cometh, for he cometh to judge the earth: he shall judge the world with righteousness, and the people with his truth.
15480	575	1	THE LORD reigneth; let the earth rejoice; let the multitude of isles be glad thereof.
15481	575	2	Clouds and darkness are round about him: righteousness and judgment are the habitation of his throne.
15482	575	3	A fire goeth before him, and burneth up his enemies round about.
15483	575	4	His lightnings enlightened the world: the earth saw, and trembled.
15484	575	5	The hills melted like wax at the presence of the LORD, at the presence of the Lord of the whole earth.
15485	575	6	The heavens declare his righteousness, and all the people see his glory.
15486	575	7	Confounded be all they that serve graven images, that boast themselves of idols: worship him, all ye gods.
15487	575	8	Zion heard, and was glad; and the daughters of Judah rejoiced because of thy judgments, O LORD.
15488	575	9	For thou, LORD, art high above all the earth: thou art exalted far above all gods.
15489	575	10	Ye that love the LORD, hate evil: he preserveth the souls of his saints; he delivereth them out of the hand of the wicked.
15490	575	11	Light is sown for the righteous, and gladness for the upright in heart.
15491	575	12	Rejoice in the LORD, ye righteous; and give thanks at the remembrance of his holiness.
15492	576	1	O SING unto the LORD a new song; for he hath done marvellous things: his right hand, and his holy arm, hath gotten him the victory.
15493	576	2	The LORD hath made known his salvation: his righteousness hath he openly shewed in the sight of the heathen.
15494	576	3	He hath remembered his mercy and his truth toward the house of Israel: all the ends of the earth have seen the salvation of our God.
15495	576	4	Make a joyful noise unto the LORD, all the earth: make a loud noise, and rejoice, and sing praise.
15496	576	5	Sing unto the LORD with the harp; with the harp, and the voice of a psalm.
15497	576	6	With trumpets and sound of cornet make a joyful noise before the LORD, the King.
15498	576	7	Let the sea roar, and the fulness thereof; the world, and they that dwell therein.
15499	576	8	Let the floods clap their hands: let the hills be joyful together
15500	576	9	Before the LORD; for he cometh to judge the earth: with righteousness shall he judge the world, and the people with equity.
15501	577	1	THE LORD reigneth; let the people tremble: he sitteth between the cherubims; let the earth be moved.
15502	577	2	The LORD is great in Zion; and he is high above all the people.
15503	577	3	Let them praise thy great and terrible name; for it is holy.
15504	577	4	The king's strength also loveth judgment; thou dost establish equity, thou executest judgment and righteousness in Jacob.
15505	577	5	Exalt ye the LORD our God, and worship at his footstool; for he is holy.
15506	577	6	Moses and Aaron among his priests, and Samuel among them that call upon his name; they called upon the LORD, and he answered them.
15507	577	7	He spake unto them in the cloudy pillar: they kept his testimonies, and the ordinance that he gave them.
15508	577	8	Thou answeredst them, O LORD our God: thou wast a God that forgavest them, though thou tookest vengeance of their inventions.
15509	577	9	Exalt the LORD our God, and worship at his holy hill; for the LORD our God is holy.
15510	578	1	MAKE a joyful noise unto the LORD, all ye lands.
15511	578	2	Serve the LORD with gladness: come before his presence with singing.
15512	578	3	Know ye that the LORD he is God: it is he that hath made us, and not we ourselves; we are his people, and the sheep of his pasture.
15513	578	4	Enter into his gates with thanksgiving, and into his courts with praise: be thankful unto him, and bless his name.
15514	578	5	For the LORD is good; his mercy is everlasting; and his truth endureth to all generations.
15515	579	1	I WILL sing of mercy and judgment: unto thee, O LORD, will I sing.
15516	579	2	I will behave myself wisely in a perfect way. O when wilt thou come unto me? I will walk within my house with a perfect heart.
15517	579	3	I will set no wicked thing before mine eyes: I hate the work of them that turn aside; it shall not cleave to me.
15518	579	4	A froward heart shall depart from me: I will not know a wicked person.
15519	579	5	Whoso privily slandereth his neighbour, him will I cut off: him that hath an high look and a proud heart will not I suffer.
15520	579	6	Mine eyes shall be upon the faithful of the land, that they may dwell with me: he that walketh in a perfect way, he shall serve me.
15521	579	7	He that worketh deceit shall not dwell within my house: he that telleth lies shall not tarry in my sight.
15522	579	8	I will early destroy all the wicked of the land; that I may cut off all wicked doers from the city of the LORD.
15523	580	1	HEAR my prayer, O LORD, and let my cry come unto thee.
15524	580	2	Hide not thy face from me in the day when I am in trouble; incline thine ear unto me: in the day when I call answer me speedily.
15525	580	3	For my days are consumed like smoke, and my bones are burned as an hearth.
15526	580	4	My heart is smitten, and withered like grass; so that I forget to eat my bread.
15527	580	5	By reason of the voice of my groaning my bones cleave to my skin.
15528	580	6	I am like a pelican of the wilderness: I am like an owl of the desert.
15529	580	7	I watch, and am as a sparrow alone upon the house top.
15530	580	8	Mine enemies reproach me all the day; and they that are mad against me are sworn against me.
15531	580	9	For I have eaten ashes like bread, and mingled my drink with weeping,
15532	580	10	Because of thine indignation and thy wrath: for thou hast lifted me up, and cast me down.
15533	580	11	My days are like a shadow that declineth; and I am withered like grass.
15534	580	12	But thou, O LORD, shalt endure for ever; and thy remembrance unto all generations.
15535	580	13	Thou shalt arise, and have mercy upon Zion: for the time to favour her, yea, the set time, is come.
15536	580	14	For thy servants take pleasure in her stones, and favour the dust thereof.
15537	580	15	So the heathen shall fear the name of the LORD, and all the kings of the earth thy glory.
15538	580	16	When the LORD shall build up Zion, he shall appear in his glory.
15539	580	17	He will regard the prayer of the destitute, and not despise their prayer.
15540	580	18	This shall be written for the generation to come: and the people which shall be created shall praise the LORD.
15541	580	19	For he hath looked down from the height of his sanctuary; from heaven did the LORD behold the earth;
15542	580	20	To hear the groaning of the prisoner; to loose those that are appointed to death;
15543	580	21	To declare the name of the LORD in Zion, and his praise in Jerusalem;
15544	580	22	When the people are gathered together, and the kingdoms, to serve the LORD.
15545	580	23	He weakened my strength in the way; he shortened my days.
15546	580	24	I said, O my God, take me not away in the midst of my days: thy years are throughout all generations.
15547	580	25	Of old hast thou laid the foundation of the earth: and the heavens are the work of thy hands.
15548	580	26	They shall perish, but thou shalt endure: yea, all of them shall wax old like a garment; as a vesture shalt thou change them, and they shall be changed:
15549	580	27	But thou art the same, and thy years shall have no end.
15550	580	28	The children of thy servants shall continue, and their seed shall be established before thee.
15551	581	1	BLESS the LORD, O my soul: and all that is within me, bless his holy name.
15552	581	2	Bless the LORD, O my soul, and forget not all his benefits:
15553	581	3	Who forgiveth all thine iniquities; who healeth all thy diseases;
15554	581	4	Who redeemeth thy life from destruction; who crowneth thee with lovingkindness and tender mercies;
15555	581	5	Who satisfieth thy mouth with good things; so that thy youth is renewed like the eagle's.
15556	581	6	The LORD executeth righteousness and judgment for all that are oppressed.
15557	581	7	He made known his ways unto Moses, his acts unto the children of Israel.
15558	581	8	The LORD is merciful and gracious, slow to anger, and plenteous in mercy.
15559	581	9	He will not always chide: neither will he keep his anger for ever.
15560	581	10	He hath not dealt with us after our sins; nor rewarded us according to our iniquities.
15561	581	11	For as the heaven is high above the earth, so great is his mercy toward them that fear him.
15562	581	12	As far as the east is from the west, so far hath he removed our transgressions from us.
15563	581	13	Like as a father pitieth his children, so the LORD pitieth them that fear him.
15564	581	14	For he knoweth our frame; he remembereth that we are dust.
15565	581	15	As for man, his days are as grass: as a flower of the field, so he flourisheth.
15566	581	16	For the wind passeth over it, and it is gone; and the place thereof shall know it no more.
15567	581	17	But the mercy of the LORD is from everlasting to everlasting upon them that fear him, and his righteousness unto children's children;
15568	581	18	To such as keep his covenant, and to those that remember his commandments to do them.
15569	581	19	The LORD hath prepared his throne in the heavens; and his kingdom ruleth over all.
15570	581	20	Bless the LORD, ye his angels, that excel in strength, that do his commandments, hearkening unto the voice of his word.
15571	581	21	Bless ye the LORD, all ye his hosts; ye ministers of his, that do his pleasure.
15572	581	22	Bless the LORD, all his works in all places of his dominion: bless the LORD, O my soul.
15573	582	1	BLESS the LORD, O my soul. O LORD my God, thou art very great; thou art clothed with honour and majesty.
15574	582	2	Who coverest thyself with light as with a garment: who stretchest out the heavens like a curtain:
15575	582	3	Who layeth the beams of his chambers in the waters: who maketh the clouds his chariot: who walketh upon the wings of the wind:
15576	582	4	Who maketh his angels spirits; his ministers a flaming fire:
15577	582	5	Who laid the foundations of the earth, that it should not be removed for ever.
15578	582	6	Thou coveredst it with the deep as with a garment: the waters stood above the mountains.
15579	582	7	At thy rebuke they fled; at the voice of thy thunder they hasted away.
15580	582	8	They go up by the mountains; they go down by the valleys unto the place which thou hast founded for them.
15581	582	9	Thou hast set a bound that they may not pass over; that they turn not again to cover the earth.
15582	582	10	He sendeth the springs into the valleys, which run among the hills.
15583	582	11	They give drink to every beast of the field: the wild asses quench their thirst.
15584	582	12	By them shall the fowls of the heaven have their habitation, which sing among the branches.
15585	582	13	He watereth the hills from his chambers: the earth is satisfied with the fruit of thy works.
15586	582	14	He causeth the grass to grow for the cattle, and herb for the service of man: that he may bring forth food out of the earth;
15587	582	15	And wine that maketh glad the heart of man, and oil to make his face to shine, and bread which strengtheneth man's heart.
15588	582	16	The trees of the LORD are full of sap; the cedars of Lebanon, which he hath planted;
15589	582	17	Where the birds make their nests: as for the stork, the fir trees are her house.
15590	582	18	The high hills are a refuge for the wild goats; and the rocks for the conies.
15591	582	19	He appointed the moon for seasons: the sun knoweth his going down.
15592	582	20	Thou makest darkness, and it is night: wherein all the beasts of the forest do creep forth.
15593	582	21	The young lions roar after their prey, and seek their meat from God.
15594	582	22	The sun ariseth, they gather themselves together, and lay them down in their dens.
15595	582	23	Man goeth forth unto his work and to his labour until the evening.
15596	582	24	O LORD, how manifold are thy works! in wisdom hast thou made them all: the earth is full of thy riches.
15597	582	25	So is this great and wide sea, wherein are things creeping innumerable, both small and great beasts.
15598	582	26	There go the ships: there is that leviathan, whom thou hast made to play therein.
15599	582	27	These wait all upon thee; that thou mayest give them their meat in due season.
15600	582	28	That thou givest them they gather: thou openest thine hand, they are filled with good.
15601	582	29	Thou hidest thy face, they are troubled: thou takest away their breath, they die, and return to their dust.
15602	582	30	Thou sendest forth thy spirit, they are created: and thou renewest the face of the earth.
15603	582	31	The glory of the LORD shall endure for ever: the LORD shall rejoice in his works.
15604	582	32	He looketh on the earth, and it trembleth: he toucheth the hills, and they smoke.
15605	582	33	I will sing unto the LORD as long as I live: I will sing praise to my God while I have my being.
15606	582	34	My meditation of him shall be sweet: I will be glad in the LORD.
15607	582	35	Let the sinners be consumed out of the earth, and let the wicked be no more. Bless thou the LORD, O my soul. Praise ye the LORD.
15608	583	1	O GIVE thanks unto the LORD; call upon his name: make known his deeds among the people.
15609	583	2	Sing unto him, sing psalms unto him: talk ye of all his wondrous works.
15610	583	3	Glory ye in his holy name: let the heart of them rejoice that seek the LORD.
15611	583	4	Seek the LORD, and his strength: seek his face evermore.
15612	583	5	Remember his marvellous works that he hath done; his wonders, and the judgments of his mouth;
15613	583	6	O ye seed of Abraham his servant, ye children of Jacob his chosen.
15614	583	7	He is the LORD our God: his judgments are in all the earth.
15615	583	8	He hath remembered his covenant for ever, the word which he commanded to a thousand generations.
15616	583	9	Which covenant he made with Abraham, and his oath unto Isaac;
15617	583	10	And confirmed the same unto Jacob for a law, and to Israel for an everlasting covenant:
15618	583	11	Saying, Unto thee will I give the land of Canaan, the lot of your inheritance:
15619	583	12	When they were but a few men in number; yea, very few, and strangers in it.
15620	583	13	When they went from one nation to another, from one kingdom to another people;
15621	583	14	He suffered no man to do them wrong: yea, he reproved kings for their sakes;
15622	583	15	Saying, Touch not mine anointed, and do my prophets no harm.
15623	583	16	Moreover he called for a famine upon the land: he brake the whole staff of bread.
15624	583	17	He sent a man before them, even Joseph, who was sold for a servant:
15625	583	18	Whose feet they hurt with fetters: he was laid in iron:
15626	583	19	Until the time that his word came: the word of the LORD tried him.
15627	583	20	The king sent and loosed him; even the ruler of the people, and let him go free.
15628	583	21	He made him lord of his house, and ruler of all his substance:
15629	583	22	To bind his princes at his pleasure; and teach his senators wisdom.
15630	583	23	Israel also came into Egypt; and Jacob sojourned in the land of Ham.
15631	583	24	And he increased his people greatly; and made them stronger than their enemies.
15632	583	25	He turned their heart to hate his people, to deal subtilly with his servants.
15633	583	26	He sent Moses his servant; and Aaron whom he had chosen.
15634	583	27	They shewed his signs among them, and wonders in the land of Ham.
15635	583	28	He sent darkness, and made it dark; and they rebelled not against his word.
15636	583	29	He turned their waters into blood, and slew their fish.
15637	583	30	Their land brought forth frogs in abundance, in the chambers of their kings.
15638	583	31	He spake, and there came divers sorts of flies, and lice in all their coasts.
15639	583	32	He gave them hail for rain, and flaming fire in their land.
15640	583	33	He smote their vines also and their fig trees; and brake the trees of their coasts.
15641	583	34	He spake, and the locusts came, and caterpillers, and that without number,
15642	583	35	And did eat up all the herbs in their land, and devoured the fruit of their ground.
15643	583	36	He smote also all the firstborn in their land, the chief of all their strength.
15644	583	37	He brought them forth also with silver and gold: and there was not one feeble person among their tribes.
15645	583	38	Egypt was glad when they departed: for the fear of them fell upon them.
15646	583	39	He spread a cloud for a covering; and fire to give light in the night.
15647	583	40	The people asked, and he brought quails, and satisfied them with the bread of heaven.
15648	583	41	He opened the rock, and the waters gushed out; they ran in the dry places like a river.
15649	583	42	For he remembered his holy promise, and Abraham his servant.
15650	583	43	And he brought forth his people with joy, and his chosen with gladness:
15651	583	44	And gave them the lands of the heathen: and they inherited the labour of the people;
15652	583	45	That they might observe his statutes, and keep his laws. Praise ye the LORD.
15653	584	1	PRAISE ye the LORD. O give thanks unto the LORD; for he is good: for his mercy endureth for ever.
15654	584	2	Who can utter the mighty acts of the LORD? who can shew forth all his praise?
15655	584	3	Blessed are they that keep judgment, and he that doeth righteousness at all times.
15656	584	4	Remember me, O LORD, with the favour that thou bearest unto thy people: O visit me with thy salvation;
15657	584	5	That I may see the good of thy chosen, that I may rejoice in the gladness of thy nation, that I may glory with thine inheritance.
15658	584	6	We have sinned with our fathers, we have committed iniquity, we have done wickedly.
15659	584	7	Our fathers understood not thy wonders in Egypt; they remembered not the multitude of thy mercies; but provoked him at the sea, even at the Red sea.
15660	584	8	Nevertheless he saved them for his name's sake, that he might make his mighty power to be known.
15661	584	9	He rebuked the Red sea also, and it was dried up: so he led them through the depths, as through the wilderness.
15662	584	10	And he saved them from the hand of him that hated them, and redeemed them from the hand of the enemy.
15663	584	11	And the waters covered their enemies: there was not one of them left.
15664	584	12	Then believed they his words; they sang his praise.
15665	584	13	They soon forgat his works; they waited not for his counsel:
15666	584	14	But lusted exceedingly in the wilderness, and tempted God in the desert.
15667	584	15	And he gave them their request; but sent leanness into their soul.
15668	584	16	They envied Moses also in the camp, and Aaron the saint of the LORD.
15669	584	17	The earth opened and swallowed up Dathan, and covered the company of Abiram.
15670	584	18	And a fire was kindled in their company; the flame burned up the wicked.
15671	584	19	They made a calf in Horeb, and worshipped the molten image.
15672	584	20	Thus they changed their glory into the similitude of an ox that eateth grass.
15673	584	21	They forgat God their saviour, which had done great things in Egypt;
15674	584	22	Wondrous works in the land of Ham, and terrible things by the Red sea.
15675	584	23	Therefore he said that he would destroy them, had not Moses his chosen stood before him in the breach, to turn away his wrath, lest he should destroy them.
15676	584	24	Yea, they despised the pleasant land, they believed not his word:
15677	584	25	But murmured in their tents, and hearkened not unto the voice of the LORD.
15678	584	26	Therefore he lifted up his hand against them, to overthrow them in the wilderness:
15679	584	27	To overthrow their seed also among the nations, and to scatter them in the lands.
15680	584	28	They joined themselves also unto Baal-peor, and ate the sacrifices of the dead.
15681	584	29	Thus they provoked him to anger with their inventions: and the plague brake in upon them.
15682	584	30	Then stood up Phinehas, and executed judgment: and so the plague was stayed.
15683	584	31	And that was counted unto him for righteousness unto all generations for evermore.
15684	584	32	They angered him also at the waters of strife, so that it went ill with Moses for their sakes:
15685	584	33	Because they provoked his spirit, so that he spake unadvisedly with his lips.
15686	584	34	They did not destroy the nations, concerning whom the LORD commanded them:
15687	584	35	But were mingled among the heathen, and learned their works.
15688	584	36	And they served their idols: which were a snare unto them.
15689	584	37	Yea, they sacrificed their sons and their daughters unto devils,
15690	584	38	And shed innocent blood, even the blood of their sons and of their daughters, whom they sacrificed unto the idols of Canaan: and the land was polluted with blood.
15691	584	39	Thus were they defiled with their own works, and went a whoring with their own inventions.
15692	584	40	Therefore was the wrath of the LORD kindled against his people, insomuch that he abhorred his own inheritance.
15693	584	41	And he gave them into the hand of the heathen; and they that hated them ruled over them.
15694	584	42	Their enemies also oppressed them, and they were brought into subjection under their hand.
15695	584	43	Many times did he deliver them; but they provoked him with their counsel, and were brought low for their iniquity.
15696	584	44	Nevertheless he regarded their affliction, when he heard their cry:
15697	584	45	And he remembered for them his covenant, and repented according to the multitude of his mercies.
15698	584	46	He made them also to be pitied of all those that carried them captives.
15699	584	47	Save us, O LORD our God, and gather us from among the heathen, to give thanks unto thy holy name, and to triumph in thy praise.
15700	584	48	Blessed be the LORD God of Israel from everlasting to everlasting: and let all the people say, Amen. Praise ye the LORD.
15701	585	1	O GIVE thanks unto the LORD, for he is good: for his mercy endureth for ever.
15702	585	2	Let the redeemed of the LORD say so, whom he hath redeemed from the hand of the enemy;
15703	585	3	And gathered them out of the lands, from the east, and from the west, from the north, and from the south.
15704	585	4	They wandered in the wilderness in a solitary way; they found no city to dwell in.
15705	585	5	Hungry and thirsty, their soul fainted in them.
15706	585	6	Then they cried unto the LORD in their trouble, and he delivered them out of their distresses.
15707	585	7	And he led them forth by the right way, that they might go to a city of habitation.
15708	585	8	Oh that men would praise the LORD for his goodness, and for his wonderful works to the children of men!
15709	585	9	For he satisfieth the longing soul, and filleth the hungry soul with goodness.
15710	585	10	Such as sit in darkness and in the shadow of death, being bound in affliction and iron;
15711	585	11	Because they rebelled against the words of God, and contemned the counsel of the most High:
15712	585	12	Therefore he brought down their heart with labour; they fell down, and there was none to help.
15713	585	13	Then they cried unto the LORD in their trouble, and he saved them out of their distresses.
15714	585	14	He brought them out of darkness and the shadow of death, and brake their bands in sunder.
15715	585	15	Oh that men would praise the LORD for his goodness, and for his wonderful works to the children of men!
15716	585	16	For he hath broken the gates of brass, and cut the bars of iron in sunder.
15717	585	17	Fools because of their transgression, and because of their iniquities, are afflicted.
15718	585	18	Their soul abhorreth all manner of meat; and they draw near unto the gates of death.
15719	585	19	Then they cry unto the LORD in their trouble, and he saveth them out of their distresses.
15720	585	20	He sent his word, and healed them, and delivered them from their destructions.
15721	585	21	Oh that men would praise the LORD for his goodness, and for his wonderful works to the children of men!
15722	585	22	And let them sacrifice the sacrifices of thanksgiving, and declare his works with rejoicing.
15723	585	23	They that go down to the sea in ships, that do business in great waters;
15724	585	24	These see the works of the LORD, and his wonders in the deep.
15725	585	25	For he commandeth, and raiseth the stormy wind, which lifteth up the waves thereof.
15726	585	26	They mount up to the heaven, they go down again to the depths: their soul is melted because of trouble.
15727	585	27	They reel to and fro, and stagger like a drunken man, and are at their wits' end.
15728	585	28	Then they cry unto the LORD in their trouble, and he bringeth them out of their distresses.
15729	585	29	He maketh the storm a calm, so that the waves thereof are still.
15730	585	30	Then are they glad because they be quiet; so he bringeth them unto their desired haven.
15731	585	31	Oh that men would praise the LORD for his goodness, and for his wonderful works to the children of men!
15732	585	32	Let them exalt him also in the congregation of the people, and praise him in the assembly of the elders.
15733	585	33	He turneth rivers into a wilderness, and the watersprings into dry ground;
15734	585	34	A fruitful land into barrenness, for the wickedness of them that dwell therein.
15735	585	35	He turneth the wilderness into a standing water, and dry ground into watersprings.
15736	585	36	And there he maketh the hungry to dwell, that they may prepare a city for habitation;
15737	585	37	And sow the fields, and plant vineyards, which may yield fruits of increase.
15738	585	38	He blesseth them also, so that they are multiplied greatly; and suffereth not their cattle to decrease.
15739	585	39	Again, they are minished and brought low through oppression, affliction, and sorrow.
15740	585	40	He poureth contempt upon princes, and causeth them to wander in the wilderness, where there is no way.
15741	585	41	Yet setteth he the poor on high from affliction, and maketh him families like a flock.
15742	585	42	The righteous shall see it, and rejoice: and all iniquity shall stop her mouth.
15743	585	43	Whoso is wise, and will observe these things, even they shall understand the lovingkindness of the LORD.
15744	586	1	O GOD, my heart is fixed; I will sing and give praise, even with my glory.
15745	586	2	Awake, psaltery and harp: I myself will awake early.
15746	586	3	I will praise thee, O LORD, among the people: and I will sing praises unto thee among the nations.
15747	586	4	For thy mercy is great above the heavens: and thy truth reacheth unto the clouds.
15748	586	5	Be thou exalted, O God, above the heavens: and thy glory above all the earth;
15749	586	6	That thy beloved may be delivered: save with thy right hand, and answer me.
15750	586	7	God hath spoken in his holiness; I will rejoice, I will divide Shechem, and mete out the valley of Succoth.
15751	586	8	Gilead is mine; Manasseh is mine; Ephraim also is the strength of mine head; Judah is my lawgiver;
15752	586	9	Moab is my washpot; over Edom will I cast out my shoe; over Philistia will I triumph.
15753	586	10	Who will bring me into the strong city? who will lead me into Edom?
15754	586	11	Wilt not thou, O God, who hast cast us off? and wilt not thou, O God, go forth with our hosts?
15755	586	12	Give us help from trouble: for vain is the help of man.
15756	586	13	Through God we shall do valiantly: for he it is that shall tread down our enemies.
15757	587	1	HOLD not thy peace, O God of my praise;
15758	587	2	For the mouth of the wicked and the mouth of the deceitful are opened against me: they have spoken against me with a lying tongue.
15759	587	3	They compassed me about also with words of hatred; and fought against me without a cause.
15760	587	4	For my love they are my adversaries: but I give myself unto prayer.
15761	587	5	And they have rewarded me evil for good, and hatred for my love.
15762	587	6	Set thou a wicked man over him: and let Satan stand at his right hand.
15763	587	7	When he shall be judged, let him be condemned: and let his prayer become sin.
15764	587	8	Let his days be few; and let another take his office.
15765	587	9	Let his children be fatherless, and his wife a widow.
15766	587	10	Let his children be continually vagabonds, and beg: let them seek their bread also out of their desolate places.
15767	587	11	Let the extortioner catch all that he hath; and let the strangers spoil his labour.
15768	587	12	Let there be none to extend mercy unto him: neither let there be any to favour his fatherless children.
15769	587	13	Let his posterity be cut off; and in the generation following let their name be blotted out.
15770	587	14	Let the iniquity of his fathers be remembered with the LORD; and let not the sin of his mother be blotted out.
15771	587	15	Let them be before the LORD continually, that he may cut off the memory of them from the earth.
15772	587	16	Because that he remembered not to shew mercy, but persecuted the poor and needy man, that he might even slay the broken in heart.
15773	587	17	As he loved cursing, so let it come unto him: as he delighted not in blessing, so let it be far from him.
15774	587	18	As he clothed himself with cursing like as with his garment, so let it come into his bowels like water, and like oil into his bones.
15775	587	19	Let it be unto him as the garment which covereth him, and for a girdle wherewith he is girded continually.
15776	587	20	Let this be the reward of mine adversaries from the LORD, and of them that speak evil against my soul.
15777	587	21	But do thou for me, O GOD the Lord, for thy name's sake: because thy mercy is good, deliver thou me.
15778	587	22	For I am poor and needy, and my heart is wounded within me.
15779	587	23	I am gone like the shadow when it declineth: I am tossed up and down as the locust.
15780	587	24	My knees are weak through fasting; and my flesh faileth of fatness.
15781	587	25	I became also a reproach unto them: when they looked upon me they shaked their heads.
15782	587	26	Help me, O LORD my God: O save me according to thy mercy:
15783	587	27	That they may know that this is thy hand; that thou, LORD, hast done it.
15784	587	28	Let them curse, but bless thou: when they arise, let them be ashamed; but let thy servant rejoice.
15785	587	29	Let mine adversaries be clothed with shame, and let them cover themselves with their own confusion, as with a mantle.
15786	587	30	I will greatly praise the LORD with my mouth; yea, I will praise him among the multitude.
15787	587	31	For he shall stand at the right hand of the poor, to save him from those that condemn his soul.
15788	588	1	THE LORD said unto my Lord, Sit thou at my right hand, until I make thine enemies thy footstool.
15789	588	2	The LORD shall send the rod of thy strength out of Zion: rule thou in the midst of thine enemies.
15790	588	3	Thy people shall be willing in the day of thy power, in the beauties of holiness from the womb of the morning: thou hast the dew of thy youth.
15791	588	4	The LORD hath sworn, and will not repent, Thou art a priest for ever after the order of Melchizedek.
15792	588	5	The Lord at thy right hand shall strike through kings in the day of his wrath.
15793	588	6	He shall judge among the heathen, he shall fill the places with the dead bodies; he shall wound the heads over many countries.
15794	588	7	He shall drink of the brook in the way: therefore shall he lift up the head.
15795	589	1	PRAISE ye the LORD. I will praise the LORD with my whole heart, in the assembly of the upright, and in the congregation.
15796	589	2	The works of the LORD are great, sought out of all them that have pleasure therein.
15797	589	3	His work is honourable and glorious: and his righteousness endureth for ever.
15798	589	4	He hath made his wonderful works to be remembered: the LORD is gracious and full of compassion.
15799	589	5	He hath given meat unto them that fear him: he will ever be mindful of his covenant.
15800	589	6	He hath shewed his people the power of his works, that he may give them the heritage of the heathen.
15801	589	7	The works of his hands are verity and judgment; all his commandments are sure.
15802	589	8	They stand fast for ever and ever, and are done in truth and uprightness.
15803	589	9	He sent redemption unto his people: he hath commanded his covenant for ever: holy and reverend is his name.
15804	589	10	The fear of the LORD is the beginning of wisdom: a good understanding have all they that do his commandments: his praise endureth for ever.
15805	590	1	PRAISE ye the LORD. Blessed is the man that feareth the LORD, that delighteth greatly in his commandments.
15806	590	2	His seed shall be mighty upon earth: the generation of the upright shall be blessed.
15807	590	3	Wealth and riches shall be in his house: and his righteousness endureth for ever.
15808	590	4	Unto the upright there ariseth light in the darkness: he is gracious, and full of compassion, and righteous.
15809	590	5	A good man sheweth favour, and lendeth: he will guide his affairs with discretion.
15810	590	6	Surely he shall not be moved for ever: the righteous shall be in everlasting remembrance.
15811	590	7	He shall not be afraid of evil tidings: his heart is fixed, trusting in the LORD.
15812	590	8	His heart is established, he shall not be afraid, until he see his desire upon his enemies.
15813	590	9	He hath dispersed, he hath given to the poor; his righteousness endureth for ever; his horn shall be exalted with honour.
15814	590	10	The wicked shall see it, and be grieved; he shall gnash with his teeth, and melt away: the desire of the wicked shall perish.
15815	591	1	PRAISE ye the LORD. Praise, O ye servants of the LORD, praise the name of the LORD.
15816	591	2	Blessed be the name of the LORD from this time forth and for evermore.
15817	591	3	From the rising of the sun unto the going down of the same the LORD's name is to be praised.
15818	591	4	The LORD is high above all nations, and his glory above the heavens.
15819	591	5	Who is like unto the LORD our God, who dwelleth on high,
15820	591	6	Who humbleth himself to behold the things that are in heaven, and in the earth!
15821	591	7	He raiseth up the poor out of the dust, and lifteth the needy out of the dunghill;
15822	591	8	That he may set him with princes, even with the princes of his people.
15823	591	9	He maketh the barren woman to keep house, and to be a joyful mother of children. Praise ye the LORD.
15824	592	1	WHEN Israel went out of Egypt, the house of Jacob from a people of strange language;
15825	592	2	Judah was his sanctuary, and Israel his dominion.
15826	592	3	The sea saw it, and fled: Jordan was driven back.
15827	592	4	The mountains skipped like rams, and the little hills like lambs.
15828	592	5	What ailed thee, O thou sea, that thou fleddest? thou Jordan, that thou wast driven back?
15829	592	6	Ye mountains, that ye skipped like rams; and ye little hills, like lambs?
15830	592	7	Tremble, thou earth, at the presence of the Lord, at the presence of the God of Jacob;
15831	592	8	Which turned the rock into a standing water, the flint into a fountain of waters.
15832	593	1	NOT unto us, O LORD, not unto us, but unto thy name give glory, for thy mercy, and for thy truth's sake.
15833	593	2	Wherefore should the heathen say, Where is now their God?
15834	593	3	But our God is in the heavens: he hath done whatsoever he hath pleased.
15835	593	4	Their idols are silver and gold, the work of men's hands.
15836	593	5	They have mouths, but they speak not: eyes have they, but they see not:
15837	593	6	They have ears, but they hear not: noses have they, but they smell not:
15838	593	7	They have hands, but they handle not: feet have they, but they walk not: neither speak they through their throat.
15839	593	8	They that make them are like unto them; so is every one that trusteth in them.
15840	593	9	O Israel, trust thou in the LORD: he is their help and their shield.
15841	593	10	O house of Aaron, trust in the LORD: he is their help and their shield.
15842	593	11	Ye that fear the LORD, trust in the LORD: he is their help and their shield.
15843	593	12	The LORD hath been mindful of us: he will bless us; he will bless the house of Israel; he will bless the house of Aaron.
15844	593	13	He will bless them that fear the LORD, both small and great.
15845	593	14	The LORD shall increase you more and more, you and your children.
15846	593	15	Ye are blessed of the LORD which made heaven and earth.
15847	593	16	The heaven, even the heavens, are the LORD's: but the earth hath he given to the children of men.
15848	593	17	The dead praise not the LORD, neither any that go down into silence.
15849	593	18	But we will bless the LORD from this time forth and for evermore. Praise the LORD.
15850	594	1	I LOVE the LORD, because he hath heard my voice and my supplications.
15851	594	2	Because he hath inclined his ear unto me, therefore will I call upon him as long as I live.
15852	594	3	The sorrows of death compassed me, and the pains of hell gat hold upon me: I found trouble and sorrow.
15853	594	4	Then called I upon the name of the LORD; O LORD, I beseech thee, deliver my soul.
15854	594	5	Gracious is the LORD, and righteous; yea, our God is merciful.
15855	594	6	The LORD preserveth the simple: I was brought low, and he helped me.
15856	594	7	Return unto thy rest, O my soul; for the LORD hath dealt bountifully with thee.
15857	594	8	For thou hast delivered my soul from death, mine eyes from tears, and my feet from falling.
15858	594	9	I will walk before the LORD in the land of the living.
15859	594	10	I believed, therefore have I spoken: I was greatly afflicted:
15860	594	11	I said in my haste, All men are liars.
15861	594	12	What shall I render unto the LORD for all his benefits toward me?
15862	594	13	I will take the cup of salvation, and call upon the name of the LORD.
15863	594	14	I will pay my vows unto the LORD now in the presence of all his people.
15864	594	15	Precious in the sight of the LORD is the death of his saints.
15865	594	16	O LORD, truly I am thy servant; I am thy servant, and the son of thine handmaid: thou hast loosed my bonds.
15866	594	17	I will offer to thee the sacrifice of thanksgiving, and will call upon the name of the LORD.
15867	594	18	I will pay my vows unto the LORD now in the presence of all his people,
15868	594	19	In the courts of the LORD's house, in the midst of thee, O Jerusalem. Praise ye the LORD.
15869	595	1	O PRAISE the LORD, all ye nations: praise him, all ye people.
15870	595	2	For his merciful kindness is great toward us: and the truth of the LORD endureth for ever. Praise ye the LORD.
15871	596	1	O GIVE thanks unto the LORD; for he is good: because his mercy endureth for ever.
15872	596	2	Let Israel now say, that his mercy endureth for ever.
15873	596	3	Let the house of Aaron now say, that his mercy endureth for ever.
15874	596	4	Let them now that fear the LORD say, that his mercy endureth for ever.
15875	596	5	I called upon the LORD in distress: the LORD answered me, and set me in a large place.
15876	596	6	The LORD is on my side; I will not fear: what can man do unto me?
15877	596	7	The LORD taketh my part with them that help me: therefore shall I see my desire upon them that hate me.
15878	596	8	It is better to trust in the LORD than to put confidence in man.
15879	596	9	It is better to trust in the LORD than to put confidence in princes.
15880	596	10	All nations compassed me about: but in the name of the LORD will I destroy them.
15881	596	11	They compassed me about; yea, they compassed me about: but in the name of the LORD I will destroy them.
15882	596	12	They compassed me about like bees; they are quenched as the fire of thorns: for in the name of the LORD I will destroy them.
15883	596	13	Thou hast thrust sore at me that I might fall: but the LORD helped me.
15884	596	14	The LORD is my strength and song, and is become my salvation.
15885	596	15	The voice of rejoicing and salvation is in the tabernacles of the righteous: the right hand of the LORD doeth valiantly.
15886	596	16	The right hand of the LORD is exalted: the right hand of the LORD doeth valiantly.
15887	596	17	I shall not die, but live, and declare the works of the LORD.
15888	596	18	The LORD hath chastened me sore: but he hath not given me over unto death.
15889	596	19	Open to me the gates of righteousness: I will go into them, and I will praise the LORD:
15890	596	20	This gate of the LORD, into which the righteous shall enter.
15891	596	21	I will praise thee: for thou hast heard me, and art become my salvation.
15892	596	22	The stone which the builders refused is become the head stone of the corner.
15893	596	23	This is the LORD's doing; it is marvellous in our eyes.
15894	596	24	This is the day which the LORD hath made; we will rejoice and be glad in it.
15895	596	25	Save now, I beseech thee, O LORD: O LORD, I beseech thee, send now prosperity.
15896	596	26	Blessed be he that cometh in the name of the LORD: we have blessed you out of the house of the LORD.
15897	596	27	God is the LORD, which hath shewed us light: bind the sacrifice with cords, even unto the horns of the altar.
15898	596	28	Thou art my God, and I will praise thee: thou art my God, I will exalt thee.
15899	596	29	O give thanks unto the LORD; for he is good: for his mercy endureth for ever.
15900	597	1	BLESSED are the undefiled in the way, who walk in the law of the LORD.
15901	597	2	Blessed are they that keep his testimonies, and that seek him with the whole heart.
15902	597	3	They also do no iniquity: they walk in his ways.
15903	597	4	Thou hast commanded us to keep thy precepts diligently.
15904	597	5	O that my ways were directed to keep thy statutes!
15905	597	6	Then shall I not be ashamed, when I have respect unto all thy commandments.
15906	597	7	I will praise thee with uprightness of heart, when I shall have learned thy righteous judgments.
15907	597	8	I will keep thy statutes: O forsake me not utterly.
15908	597	9	Wherewithal shall a young man cleanse his way? by taking heed thereto according to thy word.
15909	597	10	With my whole heart have I sought thee: O let me not wander from thy commandments.
15910	597	11	Thy word have I hid in mine heart, that I might not sin against thee.
15911	597	12	Blessed art thou, O LORD: teach me thy statutes.
15912	597	13	With my lips have I declared all the judgments of thy mouth.
15913	597	14	I have rejoiced in the way of thy testimonies, as much as in all riches.
15914	597	15	I will meditate in thy precepts, and have respect unto thy ways.
15915	597	16	I will delight myself in thy statutes: I will not forget thy word.
15916	597	17	Deal bountifully with thy servant, that I may live, and keep thy word.
15917	597	18	Open thou mine eyes, that I may behold wondrous things out of thy law.
15918	597	19	I am a stranger in the earth: hide not thy commandments from me.
15919	597	20	My soul breaketh for the longing that it hath unto thy judgments at all times.
15920	597	21	Thou hast rebuked the proud that are cursed, which do err from thy commandments.
15921	597	22	Remove from me reproach and contempt; for I have kept thy testimonies.
15922	597	23	Princes also did sit and speak against me: but thy servant did meditate in thy statutes.
15923	597	24	Thy testimonies also are my delight and my counsellors.
15924	597	25	My soul cleaveth unto the dust: quicken thou me according to thy word.
15925	597	26	I have declared my ways, and thou heardest me: teach me thy statutes.
15926	597	27	Make me to understand the way of thy precepts: so shall I talk of thy wondrous works.
15927	597	28	My soul melteth for heaviness: strengthen thou me according unto thy word.
15928	597	29	Remove from me the way of lying: and grant me thy law graciously.
15929	597	30	I have chosen the way of truth: thy judgments have I laid before me.
15930	597	31	I have stuck unto thy testimonies: O LORD, put me not to shame.
15931	597	32	I will run the way of thy commandments, when thou shalt enlarge my heart.
15932	597	33	Teach me, O LORD, the way of thy statutes; and I shall keep it unto the end.
15933	597	34	Give me understanding, and I shall keep thy law; yea, I shall observe it with my whole heart.
15934	597	35	Make me to go in the path of thy commandments; for therein do I delight.
15935	597	36	Incline my heart unto thy testimonies, and not to covetousness.
15936	597	37	Turn away mine eyes from beholding vanity; and quicken thou me in thy way.
15937	597	38	Stablish thy word unto thy servant, who is devoted to thy fear.
15938	597	39	Turn away my reproach which I fear: for thy judgments are good.
15939	597	40	Behold, I have longed after thy precepts: quicken me in thy righteousness.
15940	597	41	Let thy mercies come also unto me, O LORD, even thy salvation, according to thy word.
15941	597	42	So shall I have wherewith to answer him that reproacheth me: for I trust in thy word.
15942	597	43	And take not the word of truth utterly out of my mouth; for I have hoped in thy judgments.
15943	597	44	So shall I keep thy law continually for ever and ever.
15944	597	45	And I will walk at liberty: for I seek thy precepts.
15945	597	46	I will speak of thy testimonies also before kings, and will not be ashamed.
15946	597	47	And I will delight myself in thy commandments, which I have loved.
15947	597	48	My hands also will I lift up unto thy commandments, which I have loved; and I will meditate in thy statutes.
15948	597	49	Remember the word unto thy servant, upon which thou hast caused me to hope.
15949	597	50	This is my comfort in my affliction: for thy word hath quickened me.
15950	597	51	The proud have had me greatly in derision: yet have I not declined from thy law.
15951	597	52	I remembered thy judgments of old, O LORD; and have comforted myself.
15952	597	53	Horror hath taken hold upon me because of the wicked that forsake thy law.
15953	597	54	Thy statutes have been my songs in the house of my pilgrimage.
15954	597	55	I have remembered thy name, O LORD, in the night, and have kept thy law.
15955	597	56	This I had, because I kept thy precepts.
15956	597	57	Thou art my portion, O LORD: I have said that I would keep thy words.
15957	597	58	I intreated thy favour with my whole heart: be merciful unto me according to thy word.
15958	597	59	I thought on my ways, and turned my feet unto thy testimonies.
15959	597	60	I made haste, and delayed not to keep thy commandments.
15960	597	61	The bands of the wicked have robbed me: but I have not forgotten thy law.
15961	597	62	At midnight I will rise to give thanks unto thee because of thy righteous judgments.
15962	597	63	I am a companion of all them that fear thee, and of them that keep thy precepts.
15963	597	64	The earth, O LORD, is full of thy mercy: teach me thy statutes.
15964	597	65	Thou hast dealt well with thy servant, O LORD, according unto thy word.
15965	597	66	Teach me good judgment and knowledge: for I have believed thy commandments.
15966	597	67	Before I was afflicted I went astray: but now have I kept thy word.
15967	597	68	Thou art good, and doest good; teach me thy statutes.
15968	597	69	The proud have forged a lie against me: but I will keep thy precepts with my whole heart.
15969	597	70	Their heart is as fat as grease; but I delight in thy law.
15970	597	71	It is good for me that I have been afflicted; that I might learn thy statutes.
15971	597	72	The law of thy mouth is better unto me than thousands of gold and silver.
15972	597	73	Thy hands have made me and fashioned me: give me understanding, that I may learn thy commandments.
15973	597	74	They that fear thee will be glad when they see me; because I have hoped in thy word.
15974	597	75	I know, O LORD, that thy judgments are right, and that thou in faithfulness hast afflicted me.
15975	597	76	Let, I pray thee, thy merciful kindness be for my comfort, according to thy word unto thy servant.
15976	597	77	Let thy tender mercies come unto me, that I may live: for thy law is my delight.
15977	597	78	Let the proud be ashamed; for they dealt perversely with me without a cause: but I will meditate in thy precepts.
15978	597	79	Let those that fear thee turn unto me, and those that have known thy testimonies.
15979	597	80	Let my heart be sound in thy statutes; that I be not ashamed.
15980	597	81	My soul fainteth for thy salvation: but I hope in thy word.
15981	597	82	Mine eyes fail for thy word, saying, When wilt thou comfort me?
15982	597	83	For I am become like a bottle in the smoke; yet do I not forget thy statutes.
15983	597	84	How many are the days of thy servant? when wilt thou execute judgment on them that persecute me?
15984	597	85	The proud have digged pits for me, which are not after thy law.
15985	597	86	All thy commandments are faithful: they persecute me wrongfully; help thou me.
15986	597	87	They had almost consumed me upon earth; but I forsook not thy precepts.
15987	597	88	Quicken me after thy lovingkindness; so shall I keep the testimony of thy mouth.
15988	597	89	For ever, O LORD, thy word is settled in heaven.
15989	597	90	Thy faithfulness is unto all generations: thou hast established the earth, and it abideth.
15990	597	91	They continue this day according to thine ordinances: for all are thy servants.
15991	597	92	Unless thy law had been my delights, I should then have perished in mine affliction.
15992	597	93	I will never forget thy precepts: for with them thou hast quickened me.
15993	597	94	I am thine, save me; for I have sought thy precepts.
15994	597	95	The wicked have waited for me to destroy me: but I will consider thy testimonies.
15995	597	96	I have seen an end of all perfection: but thy commandment is exceeding broad.
15996	597	97	O how love I thy law! it is my meditation all the day.
15997	597	98	Thou through thy commandments hast made me wiser than mine enemies: for they are ever with me.
15998	597	99	I have more understanding than all my teachers: for thy testimonies are my meditation.
15999	597	100	I understand more than the ancients, because I keep thy precepts.
16000	597	101	I have refrained my feet from every evil way, that I might keep thy word.
16001	597	102	I have not departed from thy judgments: for thou hast taught me.
16002	597	103	How sweet are thy words unto my taste! yea, sweeter than honey to my mouth!
16003	597	104	Through thy precepts I get understanding: therefore I hate every false way.
16004	597	105	Thy word is a lamp unto my feet, and a light unto my path.
16005	597	106	I have sworn, and I will perform it, that I will keep thy righteous judgments.
16006	597	107	I am afflicted very much: quicken me, O LORD, according unto thy word.
16007	597	108	Accept, I beseech thee, the freewill offerings of my mouth, O LORD, and teach me thy judgments.
16008	597	109	My soul is continually in my hand: yet do I not forget thy law.
16009	597	110	The wicked have laid a snare for me: yet I erred not from thy precepts.
16010	597	111	Thy testimonies have I taken as an heritage for ever: for they are the rejoicing of my heart.
16011	597	112	I have inclined mine heart to perform thy statutes alway, even unto the end.
16012	597	113	I hate vain thoughts: but thy law do I love.
16013	597	114	Thou art my hiding place and my shield: I hope in thy word.
16014	597	115	Depart from me, ye evildoers: for I will keep the commandments of my God.
16015	597	116	Uphold me according unto thy word, that I may live: and let me not be ashamed of my hope.
16016	597	117	Hold thou me up, and I shall be safe: and I will have respect unto thy statutes continually.
16017	597	118	Thou hast trodden down all them that err from thy statutes: for their deceit is falsehood.
16018	597	119	Thou puttest away all the wicked of the earth like dross: therefore I love thy testimonies.
16019	597	120	My flesh trembleth for fear of thee; and I am afraid of thy judgments.
16020	597	121	I have done judgment and justice: leave me not to mine oppressors.
16021	597	122	Be surety for thy servant for good: let not the proud oppress me.
16022	597	123	Mine eyes fail for thy salvation, and for the word of thy righteousness.
16023	597	124	Deal with thy servant according unto thy mercy, and teach me thy statutes.
16024	597	125	I am thy servant; give me understanding, that I may know thy testimonies.
16025	597	126	It is time for thee, LORD, to work: for they have made void thy law.
16026	597	127	Therefore I love thy commandments above gold; yea, above fine gold.
16027	597	128	Therefore I esteem all thy precepts concerning all things to be right; and I hate every false way.
16028	597	129	Thy testimonies are wonderful: therefore doth my soul keep them.
16029	597	130	The entrance of thy words giveth light; it giveth understanding unto the simple.
16030	597	131	I opened my mouth, and panted: for I longed for thy commandments.
16031	597	132	Look thou upon me, and be merciful unto me, as thou usest to do unto those that love thy name.
16032	597	133	Order my steps in thy word: and let not any iniquity have dominion over me.
16033	597	134	Deliver me from the oppression of man: so will I keep thy precepts.
16034	597	135	Make thy face to shine upon thy servant; and teach me thy statutes.
16035	597	136	Rivers of waters run down mine eyes, because they keep not thy law.
16036	597	137	Righteous art thou, O LORD, and upright are thy judgments.
16037	597	138	Thy testimonies that thou hast commanded are righteous and very faithful.
16038	597	139	My zeal hath consumed me, because mine enemies have forgotten thy words.
16039	597	140	Thy word is very pure: therefore thy servant loveth it.
16040	597	141	I am small and despised: yet do not I forget thy precepts.
16041	597	142	Thy righteousness is an everlasting righteousness, and thy law is the truth.
16042	597	143	Trouble and anguish have taken hold on me: yet thy commandments are my delights.
16043	597	144	The righteousness of thy testimonies is everlasting: give me understanding, and I shall live.
16044	597	145	I cried with my whole heart; hear me, O LORD: I will keep thy statutes.
16045	597	146	I cried unto thee; save me, and I shall keep thy testimonies.
16046	597	147	I prevented the dawning of the morning, and cried: I hoped in thy word.
16047	597	148	Mine eyes prevent the night watches, that I might meditate in thy word.
16048	597	149	Hear my voice according unto thy lovingkindness: O LORD, quicken me according to thy judgment.
16049	597	150	They draw nigh that follow after mischief: they are far from thy law.
16050	597	151	Thou art near, O LORD; and all thy commandments are truth.
16051	597	152	Concerning thy testimonies, I have known of old that thou hast founded them for ever.
16052	597	153	Consider mine affliction, and deliver me: for I do not forget thy law.
16053	597	154	Plead my cause, and deliver me: quicken me according to thy word.
16054	597	155	Salvation is far from the wicked: for they seek not thy statutes.
16055	597	156	Great are thy tender mercies, O LORD: quicken me according to thy judgments.
16056	597	157	Many are my persecutors and mine enemies; yet do I not decline from thy testimonies.
16057	597	158	I beheld the transgressors, and was grieved; because they kept not thy word.
16058	597	159	Consider how I love thy precepts: quicken me, O LORD, according to thy lovingkindness.
16059	597	160	Thy word is true from the beginning: and every one of thy righteous judgments endureth for ever.
16060	597	161	Princes have persecuted me without a cause: but my heart standeth in awe of thy word.
16061	597	162	I rejoice at thy word, as one that findeth great spoil.
16062	597	163	I hate and abhor lying: but thy law do I love.
16063	597	164	Seven times a day do I praise thee because of thy righteous judgments.
16064	597	165	Great peace have they which love thy law: and nothing shall offend them.
16065	597	166	LORD, I have hoped for thy salvation, and done thy commandments.
16066	597	167	My soul hath kept thy testimonies; and I love them exceedingly.
16067	597	168	I have kept thy precepts and thy testimonies: for all my ways are before thee.
16068	597	169	Let my cry come near before thee, O LORD: give me understanding according to thy word.
16069	597	170	Let my supplication come before thee: deliver me according to thy word.
16070	597	171	My lips shall utter praise, when thou hast taught me thy statutes.
16071	597	172	My tongue shall speak of thy word: for all thy commandments are righteousness.
16072	597	173	Let thine hand help me; for I have chosen thy precepts.
16073	597	174	I have longed for thy salvation, O LORD; and thy law is my delight.
16074	597	175	Let my soul live, and it shall praise thee; and let thy judgments help me.
16075	597	176	I have gone astray like a lost sheep; seek thy servant; for I do not forget thy commandments.
16076	598	1	IN my distress I cried unto the LORD, and he heard me.
16077	598	2	Deliver my soul, O LORD, from lying lips, and from a deceitful tongue.
16078	598	3	What shall be given unto thee? or what shall be done unto thee, thou false tongue?
16079	598	4	Sharp arrows of the mighty, with coals of juniper.
16080	598	5	Woe is me, that I sojourn in Mesech, that I dwell in the tents of Kedar!
16081	598	6	My soul hath long dwelt with him that hateth peace.
16082	598	7	I am for peace: but when I speak, they are for war.
16083	599	1	I WILL lift up mine eyes unto the hills, from whence cometh my help.
16084	599	2	My help cometh from the LORD, which made heaven and earth.
16085	599	3	He will not suffer thy foot to be moved: he that keepeth thee will not slumber.
16086	599	4	Behold, he that keepeth Israel shall neither slumber nor sleep.
16087	599	5	The LORD is thy keeper: the LORD is thy shade upon thy right hand.
16088	599	6	The sun shall not smite thee by day, nor the moon by night.
16089	599	7	The LORD shall preserve thee from all evil: he shall preserve thy soul.
16090	599	8	The LORD shall preserve thy going out and thy coming in from this time forth, and even for evermore.
16091	600	1	I WAS glad when they said unto me, Let us go into the house of the LORD.
16092	600	2	Our feet shall stand within thy gates, O Jerusalem.
16093	600	3	Jerusalem is builded as a city that is compact together:
16094	600	4	Whither the tribes go up, the tribes of the LORD, unto the testimony of Israel, to give thanks unto the name of the LORD.
16095	600	5	For there are set thrones of judgment, the thrones of the house of David.
16096	600	6	Pray for the peace of Jerusalem: they shall prosper that love thee.
16097	600	7	Peace be within thy walls, and prosperity within thy palaces.
16098	600	8	For my brethren and companions' sakes, I will now say, Peace be within thee.
16099	600	9	Because of the house of the LORD our God I will seek thy good.
16100	601	1	UNTO thee lift I up mine eyes, O thou that dwellest in the heavens.
16101	601	2	Behold, as the eyes of servants look unto the hand of their masters, and as the eyes of a maiden unto the hand of her mistress; so our eyes wait upon the LORD our God, until that he have mercy upon us.
16102	601	3	Have mercy upon us, O LORD, have mercy upon us: for we are exceedingly filled with contempt.
16103	601	4	Our soul is exceedingly filled with the scorning of those that are at ease, and with the contempt of the proud.
16104	602	1	IF it had not been the LORD who was on our side, now may Israel say;
16105	602	2	If it had not been the LORD who was on our side, when men rose up against us:
16106	602	3	Then they had swallowed us up quick, when their wrath was kindled against us:
16107	602	4	Then the waters had overwhelmed us, the stream had gone over our soul:
16108	602	5	Then the proud waters had gone over our soul.
16109	602	6	Blessed be the LORD, who hath not given us as a prey to their teeth.
16110	602	7	Our soul is escaped as a bird out of the snare of the fowlers: the snare is broken, and we are escaped.
16111	602	8	Our help is in the name of the LORD, who made heaven and earth.
16112	603	1	THEY that trust in the LORD shall be as mount Zion, which cannot be removed, but abideth for ever.
16113	603	2	As the mountains are round about Jerusalem, so the LORD is round about his people from henceforth even for ever.
16114	603	3	For the rod of the wicked shall not rest upon the lot of the righteous; lest the righteous put forth their hands unto iniquity.
16115	603	4	Do good, O LORD, unto those that be good, and to them that are upright in their hearts.
16116	603	5	As for such as turn aside unto their crooked ways, the LORD shall lead them forth with the workers of iniquity: but peace shall be upon Israel.
16117	604	1	WHEN the LORD turned again the captivity of Zion, we were like them that dream.
16118	604	2	Then was our mouth filled with laughter, and our tongue with singing: then said they among the heathen, The LORD hath done great things for them.
16119	604	3	The LORD hath done great things for us; whereof we are glad.
16120	604	4	Turn again our captivity, O LORD, as the streams in the south.
16121	604	5	They that sow in tears shall reap in joy.
16122	604	6	He that goeth forth and weepeth, bearing precious seed, shall doubtless come again with rejoicing, bringing his sheaves with him.
16123	605	1	EXCEPT the LORD build the house, they labour in vain that build it: except the LORD keep the city, the watchman waketh but in vain.
16124	605	2	It is vain for you to rise up early, to sit up late, to eat the bread of sorrows: for so he giveth his beloved sleep.
16125	605	3	Lo, children are an heritage of the LORD: and the fruit of the womb is his reward.
16126	605	4	As arrows are in the hand of a mighty man; so are children of the youth.
16127	605	5	Happy is the man that hath his quiver full of them: they shall not be ashamed, but they shall speak with the enemies in the gate.
16128	606	1	BLESSED is every one that feareth the LORD; that walketh in his ways.
16129	606	2	For thou shalt eat the labour of thine hands: happy shalt thou be, and it shall be well with thee.
16130	606	3	Thy wife shall be as a fruitful vine by the sides of thine house: thy children like olive plants round about thy table.
16131	606	4	Behold, that thus shall the man be blessed that feareth the LORD.
16132	606	5	The LORD shall bless thee out of Zion: and thou shalt see the good of Jerusalem all the days of thy life.
16133	606	6	Yea, thou shalt see thy children's children, and peace upon Israel.
16134	607	1	MANY a time have they afflicted me from my youth, may Israel now say:
16135	607	2	Many a time have they afflicted me from my youth: yet they have not prevailed against me.
16136	607	3	The plowers plowed upon my back: they made long their furrows.
16137	607	4	The LORD is righteous: he hath cut asunder the cords of the wicked.
16138	607	5	Let them all be confounded and turned back that hate Zion.
16139	607	6	Let them be as the grass upon the housetops, which withereth afore it groweth up:
16140	607	7	Wherewith the mower filleth not his hand; nor he that bindeth sheaves his bosom.
16141	607	8	Neither do they which go by say, The blessing of the LORD be upon you: we bless you in the name of the LORD.
16142	608	1	OUT of the depths have I cried unto thee, O LORD.
16143	608	2	Lord, hear my voice: let thine ears be attentive to the voice of my supplications.
16144	608	3	If thou, LORD, shouldest mark iniquities, O Lord, who shall stand?
16145	608	4	But there is forgiveness with thee, that thou mayest be feared.
16146	608	5	I wait for the LORD, my soul doth wait, and in his word do I hope.
16147	608	6	My soul waiteth for the Lord more than they that watch for the morning: I say, more than they that watch for the morning.
16148	608	7	Let Israel hope in the LORD: for with the LORD there is mercy, and with him is plenteous redemption.
16149	608	8	And he shall redeem Israel from all his iniquities.
16150	609	1	LORD, my heart is not haughty, nor mine eyes lofty: neither do I exercise myself in great matters, or in things too high for me.
16151	609	2	Surely I have behaved and quieted myself, as a child that is weaned of his mother: my soul is even as a weaned child.
16152	609	3	Let Israel hope in the LORD from henceforth and for ever.
16153	610	1	LORD, remember David, and all his afflictions:
16154	610	2	How he sware unto the LORD, and vowed unto the mighty God of Jacob;
16155	610	3	Surely I will not come into the tabernacle of my house, nor go up into my bed;
16156	610	4	I will not give sleep to mine eyes, or slumber to mine eyelids,
16157	610	5	Until I find out a place for the LORD, an habitation for the mighty God of Jacob.
16158	610	6	Lo, we heard of it at Ephratah: we found it in the fields of the wood.
16159	610	7	We will go into his tabernacles: we will worship at his footstool.
16160	610	8	Arise, O LORD, into thy rest; thou, and the ark of thy strength.
16161	610	9	Let thy priests be clothed with righteousness; and let thy saints shout for joy.
16162	610	10	For thy servant David's sake turn not away the face of thine anointed.
16163	610	11	The LORD hath sworn in truth unto David; he will not turn from it; Of the fruit of thy body will I set upon thy throne.
16164	610	12	If thy children will keep my covenant and my testimony that I shall teach them, their children shall also sit upon thy throne for evermore.
16165	610	13	For the LORD hath chosen Zion; he hath desired it for his habitation.
16166	610	14	This is my rest for ever: here will I dwell; for I have desired it.
16167	610	15	I will abundantly bless her provision: I will satisfy her poor with bread.
16168	610	16	I will also clothe her priests with salvation: and her saints shall shout aloud for joy.
16169	610	17	There will I make the horn of David to bud: I have ordained a lamp for mine anointed.
16170	610	18	His enemies will I clothe with shame: but upon himself shall his crown flourish.
16171	611	1	BEHOLD, how good and how pleasant it is for brethren to dwell together in unity!
16172	611	2	It is like the precious ointment upon the head, that ran down upon the beard, even Aaron's beard: that went down to the skirts of his garments;
16173	611	3	As the dew of Hermon, and as the dew that descended upon the mountains of Zion: for there the LORD commanded the blessing, even life for evermore.
16174	612	1	BEHOLD, bless ye the LORD, all ye servants of the LORD, which by night stand in the house of the LORD.
16175	612	2	Lift up your hands in the sanctuary, and bless the LORD.
16176	612	3	The LORD that made heaven and earth bless thee out of Zion.
16177	613	1	PRAISE ye the LORD. Praise ye the name of the LORD; praise him, O ye servants of the LORD.
16178	613	2	Ye that stand in the house of the LORD, in the courts of the house of our God,
16179	613	3	Praise the LORD; for the LORD is good: sing praises unto his name; for it is pleasant.
16180	613	4	For the LORD hath chosen Jacob unto himself, and Israel for his peculiar treasure.
16181	613	5	For I know that the LORD is great, and that our Lord is above all gods.
16182	613	6	Whatsoever the LORD pleased, that did he in heaven, and in earth, in the seas, and all deep places.
16183	613	7	He causeth the vapours to ascend from the ends of the earth; he maketh lightnings for the rain; he bringeth the wind out of his treasuries.
16184	613	8	Who smote the firstborn of Egypt, both of man and beast.
16185	613	9	Who sent tokens and wonders into the midst of thee, O Egypt, upon Pharaoh, and upon all his servants.
16186	613	10	Who smote great nations, and slew mighty kings;
16187	613	11	Sihon king of the Amorites, and Og king of Bashan, and all the kingdoms of Canaan:
16188	613	12	And gave their land for an heritage, an heritage unto Israel his people.
16189	613	13	Thy name, O LORD, endureth for ever; and thy memorial, O LORD, throughout all generations.
16190	613	14	For the LORD will judge his people, and he will repent himself concerning his servants.
16191	613	15	The idols of the heathen are silver and gold, the work of men's hands.
16192	613	16	They have mouths, but they speak not; eyes have they, but they see not;
16193	613	17	They have ears, but they hear not; neither is there any breath in their mouths.
16194	613	18	They that make them are like unto them: so is every one that trusteth in them.
16195	613	19	Bless the LORD, O house of Israel: bless the LORD, O house of Aaron:
16196	613	20	Bless the LORD, O house of Levi: ye that fear the LORD, bless the LORD.
16197	613	21	Blessed be the LORD out of Zion, which dwelleth at Jerusalem. Praise ye the LORD.
16198	614	1	O GIVE thanks unto the LORD; for he is good: for his mercy endureth for ever.
16199	614	2	O give thanks unto the God of gods: for his mercy endureth for ever.
16200	614	3	O give thanks to the Lord of lords: for his mercy endureth for ever.
16201	614	4	To him who alone doeth great wonders: for his mercy endureth for ever.
16202	614	5	To him that by wisdom made the heavens: for his mercy endureth for ever.
16203	614	6	To him that stretched out the earth above the waters: for his mercy endureth for ever.
16204	614	7	To him that made great lights: for his mercy endureth for ever:
16205	614	8	The sun to rule by day: for his mercy endureth for ever:
16206	614	9	The moon and stars to rule by night: for his mercy endureth for ever.
16207	614	10	To him that smote Egypt in their firstborn: for his mercy endureth for ever:
16208	614	11	And brought out Israel from among them: for his mercy endureth for ever:
16209	614	12	With a strong hand, and with a stretched out arm: for his mercy endureth for ever.
16210	614	13	To him which divided the Red sea into parts: for his mercy endureth for ever:
16211	614	14	And made Israel to pass through the midst of it: for his mercy endureth for ever:
16212	614	15	But overthrew Pharaoh and his host in the Red sea: for his mercy endureth for ever.
16213	614	16	To him which led his people through the wilderness: for his mercy endureth for ever.
16214	614	17	To him which smote great kings: for his mercy endureth for ever:
16215	614	18	And slew famous kings: for his mercy endureth for ever:
16216	614	19	Sihon king of the Amorites: for his mercy endureth for ever:
16217	614	20	And Og the king of Bashan: for his mercy endureth for ever:
16218	614	21	And gave their land for an heritage: for his mercy endureth for ever:
16219	614	22	Even an heritage unto Israel his servant: for his mercy endureth for ever.
16220	614	23	Who remembered us in our low estate: for his mercy endureth for ever:
16221	614	24	And hath redeemed us from our enemies: for his mercy endureth for ever.
16222	614	25	Who giveth food to all flesh: for his mercy endureth for ever.
16223	614	26	O give thanks unto the God of heaven: for his mercy endureth for ever.
16224	615	1	BY the rivers of Babylon, there we sat down, yea, we wept, when we remembered Zion.
16225	615	2	We hanged our harps upon the willows in the midst thereof.
16226	615	3	For there they that carried us away captive required of us a song; and they that wasted us required of us mirth, saying, Sing us one of the songs of Zion.
16227	615	4	How shall we sing the LORD's song in a strange land?
16228	615	5	If I forget thee, O Jerusalem, let my right hand forget her cunning.
16229	615	6	If I do not remember thee, let my tongue cleave to the roof of my mouth; if I prefer not Jerusalem above my chief joy.
16230	615	7	Remember, O LORD, the children of Edom in the day of Jerusalem; who said, Rase it, rase it, even to the foundation thereof.
16231	615	8	O daughter of Babylon, who art to be destroyed; happy shall he be, that rewardeth thee as thou hast served us.
16232	615	9	Happy shall he be, that taketh and dasheth thy little ones against the stones.
16233	616	1	I WILL praise thee with my whole heart: before the gods will I sing praise unto thee.
16234	616	2	I will worship toward thy holy temple, and praise thy name for thy lovingkindness and for thy truth: for thou hast magnified thy word above all thy name.
16235	616	3	In the day when I cried thou answeredst me, and strengthenedst me with strength in my soul.
16236	616	4	All the kings of the earth shall praise thee, O LORD, when they hear the words of thy mouth.
16237	616	5	Yea, they shall sing in the ways of the LORD: for great is the glory of the LORD.
16238	616	6	Though the LORD be high, yet hath he respect unto the lowly: but the proud he knoweth afar off.
16239	616	7	Though I walk in the midst of trouble, thou wilt revive me: thou shalt stretch forth thine hand against the wrath of mine enemies, and thy right hand shall save me.
16240	616	8	The LORD will perfect that which concerneth me: thy mercy, O LORD, endureth for ever: forsake not the works of thine own hands.
16241	617	1	O LORD, thou hast searched me, and known me.
16242	617	2	Thou knowest my downsitting and mine uprising, thou understandest my thought afar off.
16243	617	3	Thou compassest my path and my lying down, and art acquainted with all my ways.
16244	617	4	For there is not a word in my tongue, but, lo, O LORD, thou knowest it altogether.
16245	617	5	Thou hast beset me behind and before, and laid thine hand upon me.
16246	617	6	Such knowledge is too wonderful for me; it is high, I cannot attain unto it.
16247	617	7	Whither shall I go from thy spirit? or whither shall I flee from thy presence?
16248	617	8	If I ascend up into heaven, thou art there: if I make my bed in hell, behold, thou art there.
16249	617	9	If I take the wings of the morning, and dwell in the uttermost parts of the sea;
16250	617	10	Even there shall thy hand lead me, and thy right hand shall hold me.
16251	617	11	If I say, Surely the darkness shall cover me; even the night shall be light about me.
16252	617	12	Yea, the darkness hideth not from thee; but the night shineth as the day: the darkness and the light are both alike to thee.
16253	617	13	For thou hast possessed my reins: thou hast covered me in my mother's womb.
16254	617	14	I will praise thee; for I am fearfully and wonderfully made: marvellous are thy works; and that my soul knoweth right well.
16255	617	15	My substance was not hid from thee, when I was made in secret, and curiously wrought in the lowest parts of the earth.
16256	617	16	Thine eyes did see my substance, yet being unperfect; and in thy book all my members were written, which in continuance were fashioned, when as yet there was none of them.
16257	617	17	How precious also are thy thoughts unto me, O God! how great is the sum of them!
16258	617	18	If I should count them, they are more in number than the sand: when I awake, I am still with thee.
16259	617	19	Surely thou wilt slay the wicked, O God: depart from me therefore, ye bloody men.
16260	617	20	For they speak against thee wickedly, and thine enemies take thy name in vain.
16261	617	21	Do not I hate them, O LORD, that hate thee? and am not I grieved with those that rise up against thee?
16262	617	22	I hate them with perfect hatred: I count them mine enemies.
16263	617	23	Search me, O God, and know my heart: try me, and know my thoughts:
16264	617	24	And see if there be any wicked way in me, and lead me in the way everlasting.
16265	618	1	DELIVER me, O LORD, from the evil man: preserve me from the violent man;
16266	618	2	Which imagine mischiefs in their heart; continually are they gathered together for war.
16267	618	3	They have sharpened their tongues like a serpent; adders' poison is under their lips. Selah.
16268	618	4	Keep me, O LORD, from the hands of the wicked; preserve me from the violent man; who have purposed to overthrow my goings.
16269	618	5	The proud have hid a snare for me, and cords; they have spread a net by the wayside; they have set gins for me. Selah.
16270	618	6	I said unto the LORD, Thou art my God: hear the voice of my supplications, O LORD.
16271	618	7	O GOD the Lord, the strength of my salvation, thou hast covered my head in the day of battle.
16272	618	8	Grant not, O LORD, the desires of the wicked: further not his wicked device; lest they exalt themselves. Selah.
16273	618	9	As for the head of those that compass me about, let the mischief of their own lips cover them.
16274	618	10	Let burning coals fall upon them: let them be cast into the fire; into deep pits, that they rise not up again.
16275	618	11	Let not an evil speaker be established in the earth: evil shall hunt the violent man to overthrow him.
16276	618	12	I know that the LORD will maintain the cause of the afflicted, and the right of the poor.
16277	618	13	Surely the righteous shall give thanks unto thy name: the upright shall dwell in thy presence.
16278	619	1	LORD, I cry unto thee: make haste unto me; give ear unto my voice, when I cry unto thee.
16279	619	2	Let my prayer be set forth before thee as incense; and the lifting up of my hands as the evening sacrifice.
16280	619	3	Set a watch, O LORD, before my mouth; keep the door of my lips.
16281	619	4	Incline not my heart to any evil thing, to practise wicked works with men that work iniquity: and let me not eat of their dainties.
16282	619	5	Let the righteous smite me; it shall be a kindness: and let him reprove me; it shall be an excellent oil, which shall not break my head: for yet my prayer also shall be in their calamities.
16283	619	6	When their judges are overthrown in stony places, they shall hear my words; for they are sweet.
16284	619	7	Our bones are scattered at the grave's mouth, as when one cutteth and cleaveth wood upon the earth.
16285	619	8	But mine eyes are unto thee, O GOD the Lord: in thee is my trust; leave not my soul destitute.
16286	619	9	Keep me from the snares which they have laid for me, and the gins of the workers of iniquity.
16287	619	10	Let the wicked fall into their own nets, whilst that I withal escape.
16288	620	1	I CRIED unto the LORD with my voice; with my voice unto the LORD did I make my supplication.
16289	620	2	I poured out my complaint before him; I shewed before him my trouble.
16290	620	3	When my spirit was overwhelmed within me, then thou knewest my path. In the way wherein I walked have they privily laid a snare for me.
16291	620	4	I looked on my right hand, and beheld, but there was no man that would know me: refuge failed me; no man cared for my soul.
16292	620	5	I cried unto thee, O LORD: I said, Thou art my refuge and my portion in the land of the living.
16293	620	6	Attend unto my cry; for I am brought very low: deliver me from my persecutors; for they are stronger than I.
16294	620	7	Bring my soul out of prison, that I may praise thy name: the righteous shall compass me about; for thou shalt deal bountifully with me.
16295	621	1	HEAR my prayer, O LORD, give ear to my supplications: in thy faithfulness answer me, and in thy righteousness.
16296	621	2	And enter not into judgment with thy servant: for in thy sight shall no man living be justified.
16297	621	3	For the enemy hath persecuted my soul; he hath smitten my life down to the ground; he hath made me to dwell in darkness, as those that have been long dead.
16298	621	4	Therefore is my spirit overwhelmed within me; my heart within me is desolate.
16299	621	5	I remember the days of old; I meditate on all thy works; I muse on the work of thy hands.
16300	621	6	I stretch forth my hands unto thee: my soul thirsteth after thee, as a thirsty land. Selah.
16301	621	7	Hear me speedily, O LORD: my spirit faileth: hide not thy face from me, lest I be like unto them that go down into the pit.
16302	621	8	Cause me to hear thy lovingkindness in the morning; for in thee do I trust: cause me to know the way wherein I should walk; for I lift up my soul unto thee.
16303	621	9	Deliver me, O LORD, from mine enemies: I flee unto thee to hide me.
16304	621	10	Teach me to do thy will; for thou art my God: thy spirit is good; lead me into the land of uprightness.
16305	621	11	Quicken me, O LORD, for thy name's sake: for thy righteousness' sake bring my soul out of trouble.
16306	621	12	And of thy mercy cut off mine enemies, and destroy all them that afflict my soul: for I am thy servant.
16307	622	1	BLESSED be the LORD my strength, which teacheth my hands to war, and my fingers to fight:
16308	622	2	My goodness, and my fortress; my high tower, and my deliverer; my shield, and he in whom I trust; who subdueth my people under me.
16309	622	3	LORD, what is man, that thou takest knowledge of him! or the son of man, that thou makest account of him!
16310	622	4	Man is like to vanity: his days are as a shadow that passeth away.
16311	622	5	Bow thy heavens, O LORD, and come down: touch the mountains, and they shall smoke.
16312	622	6	Cast forth lightning, and scatter them: shoot out thine arrows, and destroy them.
16313	622	7	Send thine hand from above; rid me, and deliver me out of great waters, from the hand of strange children;
16314	622	8	Whose mouth speaketh vanity, and their right hand is a right hand of falsehood.
16315	622	9	I will sing a new song unto thee, O God: upon a psaltery and an instrument of ten strings will I sing praises unto thee.
16316	622	10	It is he that giveth salvation unto kings: who delivereth David his servant from the hurtful sword.
16317	622	11	Rid me, and deliver me from the hand of strange children, whose mouth speaketh vanity, and their right hand is a right hand of falsehood:
16318	622	12	That our sons may be as plants grown up in their youth; that our daughters may be as corner stones, polished after the similitude of a palace:
16319	622	13	That our garners may be full, affording all manner of store: that our sheep may bring forth thousands and ten thousands in our streets:
16320	622	14	That our oxen may be strong to labour; that there be no breaking in, nor going out; that there be no complaining in our streets.
16321	622	15	Happy is that people, that is in such a case: yea, happy is that people, whose God is the LORD.
16322	623	1	I WILL extol thee, my God, O king; and I will bless thy name for ever and ever.
16323	623	2	Every day will I bless thee; and I will praise thy name for ever and ever.
16324	623	3	Great is the LORD, and greatly to be praised; and his greatness is unsearchable.
16325	623	4	One generation shall praise thy works to another, and shall declare thy mighty acts.
16326	623	5	I will speak of the glorious honour of thy majesty, and of thy wondrous works.
16327	623	6	And men shall speak of the might of thy terrible acts: and I will declare thy greatness.
16328	623	7	They shall abundantly utter the memory of thy great goodness, and shall sing of thy righteousness.
16329	623	8	The LORD is gracious, and full of compassion; slow to anger, and of great mercy.
16330	623	9	The LORD is good to all: and his tender mercies are over all his works.
16331	623	10	All thy works shall praise thee, O LORD; and thy saints shall bless thee.
16332	623	11	They shall speak of the glory of thy kingdom, and talk of thy power;
16333	623	12	To make known to the sons of men his mighty acts, and the glorious majesty of his kingdom.
16334	623	13	Thy kingdom is an everlasting kingdom, and thy dominion endureth throughout all generations.
16335	623	14	The LORD upholdeth all that fall, and raiseth up all those that be bowed down.
16336	623	15	The eyes of all wait upon thee; and thou givest them their meat in due season.
16337	623	16	Thou openest thine hand, and satisfiest the desire of every living thing.
16338	623	17	The LORD is righteous in all his ways, and holy in all his works.
16339	623	18	The LORD is nigh unto all them that call upon him, to all that call upon him in truth.
16340	623	19	He will fulfil the desire of them that fear him: he also will hear their cry, and will save them.
16341	623	20	The LORD preserveth all them that love him: but all the wicked will he destroy.
16342	623	21	My mouth shall speak the praise of the LORD: and let all flesh bless his holy name for ever and ever.
16343	624	1	PRAISE ye the LORD. Praise the LORD, O my soul.
16344	624	2	While I live will I praise the LORD: I will sing praises unto my God while I have any being.
16345	624	3	Put not your trust in princes, nor in the son of man, in whom there is no help.
16346	624	4	His breath goeth forth, he returneth to his earth; in that very day his thoughts perish.
16347	624	5	Happy is he that hath the God of Jacob for his help, whose hope is in the LORD his God:
16348	624	6	Which made heaven, and earth, the sea, and all that therein is: which keepeth truth for ever:
16349	624	7	Which executeth judgment for the oppressed: which giveth food to the hungry. The LORD looseth the prisoners:
16350	624	8	The LORD openeth the eyes of the blind: the LORD raiseth them that are bowed down: the LORD loveth the righteous:
16351	624	9	The LORD preserveth the strangers; he relieveth the fatherless and widow: but the way of the wicked he turneth upside down.
16352	624	10	The LORD shall reign for ever, even thy God, O Zion, unto all generations. Praise ye the LORD.
16353	625	1	PRAISE ye the LORD: for it is good to sing praises unto our God; for it is pleasant; and praise is comely.
16354	625	2	The LORD doth build up Jerusalem: he gathereth together the outcasts of Israel.
16355	625	3	He healeth the broken in heart, and bindeth up their wounds.
16356	625	4	He telleth the number of the stars; he calleth them all by their names.
16357	625	5	Great is our Lord, and of great power: his understanding is infinite.
16358	625	6	The LORD lifteth up the meek: he casteth the wicked down to the ground.
16359	625	7	Sing unto the LORD with thanksgiving; sing praise upon the harp unto our God:
16360	625	8	Who covereth the heaven with clouds, who prepareth rain for the earth, who maketh grass to grow upon the mountains.
16361	625	9	He giveth to the beast his food, and to the young ravens which cry.
16362	625	10	He delighteth not in the strength of the horse: he taketh not pleasure in the legs of a man.
16363	625	11	The LORD taketh pleasure in them that fear him, in those that hope in his mercy.
16364	625	12	Praise the LORD, O Jerusalem; praise thy God, O Zion.
16365	625	13	For he hath strengthened the bars of thy gates; he hath blessed thy children within thee.
16366	625	14	He maketh peace in thy borders, and filleth thee with the finest of the wheat.
16367	625	15	He sendeth forth his commandment upon earth: his word runneth very swiftly.
16368	625	16	He giveth snow like wool: he scattereth the hoarfrost like ashes.
16369	625	17	He casteth forth his ice like morsels: who can stand before his cold?
16370	625	18	He sendeth out his word, and melteth them: he causeth his wind to blow, and the waters flow.
16371	625	19	He sheweth his word unto Jacob, his statutes and his judgments unto Israel.
16372	625	20	He hath not dealt so with any nation: and as for his judgments, they have not known them. Praise ye the LORD.
16373	626	1	PRAISE ye the LORD. Praise ye the LORD from the heavens: praise him in the heights.
16374	626	2	Praise ye him, all his angels: praise ye him, all his hosts.
16375	626	3	Praise ye him, sun and moon: praise him, all ye stars of light.
16376	626	4	Praise him, ye heavens of heavens, and ye waters that be above the heavens.
16377	626	5	Let them praise the name of the LORD: for he commanded, and they were created.
16378	626	6	He hath also stablished them for ever and ever: he hath made a decree which shall not pass.
16379	626	7	Praise the LORD from the earth, ye dragons, and all deeps:
16380	626	8	Fire, and hail; snow, and vapour; stormy wind fulfilling his word:
16381	626	9	Mountains, and all hills; fruitful trees, and all cedars:
16382	626	10	Beasts, and all cattle; creeping things, and flying fowl:
16383	626	11	Kings of the earth, and all people; princes, and all judges of the earth:
16384	626	12	Both young men, and maidens; old men, and children:
16385	626	13	Let them praise the name of the LORD: for his name alone is excellent; his glory is above the earth and heaven.
16386	626	14	He also exalteth the horn of his people, the praise of all his saints; even of the children of Israel, a people near unto him. Praise ye the LORD.
16387	627	1	PRAISE ye the LORD. Sing unto the LORD a new song, and his praise in the congregation of saints.
16388	627	2	Let Israel rejoice in him that made him: let the children of Zion be joyful in their King.
16389	627	3	Let them praise his name in the dance: let them sing praises unto him with the timbrel and harp.
16390	627	4	For the LORD taketh pleasure in his people: he will beautify the meek with salvation.
16391	627	5	Let the saints be joyful in glory: let them sing aloud upon their beds.
16392	627	6	Let the high praises of God be in their mouth, and a twoedged sword in their hand;
16393	627	7	To execute vengeance upon the heathen, and punishments upon the people;
16394	627	8	To bind their kings with chains, and their nobles with fetters of iron;
16395	627	9	To execute upon them the judgment written: this honour have all his saints. Praise ye the LORD.
16396	628	1	PRAISE ye the LORD. Praise God in his sanctuary: praise him in the firmament of his power.
16397	628	2	Praise him for his mighty acts: praise him according to his excellent greatness.
16398	628	3	Praise him with the sound of the trumpet: praise him with the psaltery and harp.
16399	628	4	Praise him with the timbrel and dance: praise him with stringed instruments and organs.
16400	628	5	Praise him upon the loud cymbals: praise him upon the high sounding cymbals.
16401	628	6	Let every thing that hath breath praise the LORD. Praise ye the LORD.
16402	629	1	THE proverbs of Solomon the son of David, king of Israel;
16403	629	2	To know wisdom and instruction; to perceive the words of understanding;
16404	629	3	To receive the instruction of wisdom, justice, and judgment, and equity;
16405	629	4	To give subtilty to the simple, to the young man knowledge and discretion.
16406	629	5	A wise man will hear, and will increase learning; and a man of understanding shall attain unto wise counsels:
16407	629	6	To understand a proverb, and the interpretation; the words of the wise, and their dark sayings.
16408	629	7	The fear of the LORD is the beginning of knowledge: but fools despise wisdom and instruction.
16409	629	8	My son, hear the instruction of thy father, and forsake not the law of thy mother:
16410	629	9	For they shall be an ornament of grace unto thy head, and chains about thy neck.
16411	629	10	My son, if sinners entice thee, consent thou not.
16412	629	11	If they say, Come with us, let us lay wait for blood, let us lurk privily for the innocent without cause:
16413	629	12	Let us swallow them up alive as the grave; and whole, as those that go down into the pit:
16414	629	13	We shall find all precious substance, we shall fill our houses with spoil:
16415	629	14	Cast in thy lot among us; let us all have one purse:
16416	629	15	My son, walk not thou in the way with them; refrain thy foot from their path:
16417	629	16	For their feet run to evil, and make haste to shed blood.
16418	629	17	Surely in vain the net is spread in the sight of any bird.
16419	629	18	And they lay wait for their own blood; they lurk privily for their own lives.
16420	629	19	So are the ways of every one that is greedy of gain; which taketh away the life of the owners thereof.
16421	629	20	Wisdom crieth without; she uttereth her voice in the streets:
16422	629	21	She crieth in the chief place of concourse, in the openings of the gates: in the city she uttereth her words, saying,
16423	629	22	How long, ye simple ones, will ye love simplicity? and the scorners delight in their scorning, and fools hate knowledge?
16424	629	23	Turn you at my reproof: behold, I will pour out my spirit unto you, I will make known my words unto you.
16425	629	24	Because I have called, and ye refused; I have stretched out my hand, and no man regarded;
16426	629	25	But ye have set at nought all my counsel, and would none of my reproof:
16427	629	26	I also will laugh at your calamity; I will mock when your fear cometh;
16428	629	27	When your fear cometh as desolation, and your destruction cometh as a whirlwind; when distress and anguish cometh upon you.
16429	629	28	Then shall they call upon me, but I will not answer; they shall seek me early, but they shall not find me:
16430	629	29	For that they hated knowledge, and did not choose the fear of the LORD:
16431	629	30	They would none of my counsel: they despised all my reproof.
16432	629	31	Therefore shall they eat of the fruit of their own way, and be filled with their own devices.
16433	629	32	For the turning away of the simple shall slay them, and the prosperity of fools shall destroy them.
16434	629	33	But whoso hearkeneth unto me shall dwell safely, and shall be quiet from fear of evil.
16435	630	1	MY son, if thou wilt receive my words, and hide my commandments with thee;
16436	630	2	So that thou incline thine ear unto wisdom, and apply thine heart to understanding;
16437	630	3	Yea, if thou criest after knowledge, and liftest up thy voice for understanding;
16438	630	4	If thou seekest her as silver, and searchest for her as for hid treasures;
16439	630	5	Then shalt thou understand the fear of the LORD, and find the knowledge of God.
16440	630	6	For the LORD giveth wisdom: out of his mouth cometh knowledge and understanding.
16441	630	7	He layeth up sound wisdom for the righteous: he is a buckler to them that walk uprightly.
16442	630	8	He keepeth the paths of judgment, and preserveth the way of his saints.
16443	630	9	Then shalt thou understand righteousness, and judgment, and equity; yea, every good path.
16444	630	10	When wisdom entereth into thine heart, and knowledge is pleasant unto thy soul;
16445	630	11	Discretion shall preserve thee, understanding shall keep thee:
16446	630	12	To deliver thee from the way of the evil man, from the man that speaketh froward things;
16447	630	13	Who leave the paths of uprightness, to walk in the ways of darkness;
16448	630	14	Who rejoice to do evil, and delight in the frowardness of the wicked;
16449	630	15	Whose ways are crooked, and they froward in their paths:
16450	630	16	To deliver thee from the strange woman, even from the stranger which flattereth with her words;
16451	630	17	Which forsaketh the guide of her youth, and forgetteth the covenant of her God.
16452	630	18	For her house inclineth unto death, and her paths unto the dead.
16453	630	19	None that go unto her return again, neither take they hold of the paths of life.
16454	630	20	That thou mayest walk in the way of good men, and keep the paths of the righteous.
16455	630	21	For the upright shall dwell in the land, and the perfect shall remain in it.
16456	630	22	But the wicked shall be cut off from the earth, and the transgressors shall be rooted out of it.
16457	631	1	MY son, forget not my law; but let thine heart keep my commandments:
16458	631	2	For length of days, and long life, and peace, shall they add to thee.
16459	631	3	Let not mercy and truth forsake thee: bind them about thy neck; write them upon the table of thine heart:
16460	631	4	So shalt thou find favour and good understanding in the sight of God and man.
16461	631	5	Trust in the LORD with all thine heart; and lean not unto thine own understanding.
16462	631	6	In all thy ways acknowledge him, and he shall direct thy paths.
16463	631	7	Be not wise in thine own eyes: fear the LORD, and depart from evil.
16464	631	8	It shall be health to thy navel, and marrow to thy bones.
16465	631	9	Honour the LORD with thy substance, and with the firstfruits of all thine increase:
16466	631	10	So shall thy barns be filled with plenty, and thy presses shall burst out with new wine.
16467	631	11	My son, despise not the chastening of the LORD; neither be weary of his correction:
16468	631	12	For whom the LORD loveth he correcteth; even as a father the son in whom he delighteth.
16469	631	13	Happy is the man that findeth wisdom, and the man that getteth understanding.
16470	631	14	For the merchandise of it is better than the merchandise of silver, and the gain thereof than fine gold.
16471	631	15	She is more precious than rubies: and all the things thou canst desire are not to be compared unto her.
16472	631	16	Length of days is in her right hand; and in her left hand riches and honour.
16473	631	17	Her ways are ways of pleasantness, and all her paths are peace.
16474	631	18	She is a tree of life to them that lay hold upon her: and happy is every one that retaineth her.
16475	631	19	The LORD by wisdom hath founded the earth; by understanding hath he established the heavens.
16476	631	20	By his knowledge the depths are broken up, and the clouds drop down the dew.
16477	631	21	My son, let not them depart from thine eyes: keep sound wisdom and discretion:
16478	631	22	So shall they be life unto thy soul, and grace to thy neck.
16479	631	23	Then shalt thou walk in thy way safely, and thy foot shall not stumble.
16480	631	24	When thou liest down, thou shalt not be afraid: yea, thou shalt lie down, and thy sleep shall be sweet.
16481	631	25	Be not afraid of sudden fear, neither of the desolation of the wicked, when it cometh.
16482	631	26	For the LORD shall be thy confidence, and shall keep thy foot from being taken.
16483	631	27	Withhold not good from them to whom it is due, when it is in the power of thine hand to do it.
16484	631	28	Say not unto thy neighbour, Go, and come again, and to morrow I will give; when thou hast it by thee.
16485	631	29	Devise not evil against thy neighbour, seeing he dwelleth securely by thee.
16486	631	30	Strive not with a man without cause, if he have done thee no harm.
16487	631	31	Envy thou not the oppressor, and choose none of his ways.
16488	631	32	For the froward is abomination to the LORD: but his secret is with the righteous.
16489	631	33	The curse of the LORD is in the house of the wicked: but he blesseth the habitation of the just.
16490	631	34	Surely he scorneth the scorners: but he giveth grace unto the lowly.
16491	631	35	The wise shall inherit glory: but shame shall be the promotion of fools.
16492	632	1	HEAR, ye children, the instruction of a father, and attend to know understanding.
16493	632	2	For I give you good doctrine, forsake ye not my law.
16494	632	3	For I was my father's son, tender and only beloved in the sight of my mother.
16495	632	4	He taught me also, and said unto me, Let thine heart retain my words: keep my commandments, and live.
16496	632	5	Get wisdom, get understanding: forget it not; neither decline from the words of my mouth.
16497	632	6	Forsake her not, and she shall preserve thee: love her, and she shall keep thee.
16498	632	7	Wisdom is the principal thing; therefore get wisdom: and with all thy getting get understanding.
16499	632	8	Exalt her, and she shall promote thee: she shall bring thee to honour, when thou dost embrace her.
16500	632	9	She shall give to thine head an ornament of grace: a crown of glory shall she deliver to thee.
16501	632	10	Hear, O my son, and receive my sayings; and the years of thy life shall be many.
16502	632	11	I have taught thee in the way of wisdom; I have led thee in right paths.
16503	632	12	When thou goest, thy steps shall not be straitened; and when thou runnest, thou shalt not stumble.
16504	632	13	Take fast hold of instruction; let her not go: keep her; for she is thy life.
16505	632	14	Enter not into the path of the wicked, and go not in the way of evil men.
16506	632	15	Avoid it, pass not by it, turn from it, and pass away.
16507	632	16	For they sleep not, except they have done mischief; and their sleep is taken away, unless they cause some to fall.
16508	632	17	For they eat the bread of wickedness, and drink the wine of violence.
16509	632	18	But the path of the just is as the shining light, that shineth more and more unto the perfect day.
16510	632	19	The way of the wicked is as darkness: they know not at what they stumble.
16511	632	20	My son, attend to my words; incline thine ear unto my sayings.
16512	632	21	Let them not depart from thine eyes; keep them in the midst of thine heart.
16513	632	22	For they are life unto those that find them, and health to all their flesh.
16514	632	23	Keep thy heart with all diligence; for out of it are the issues of life.
16515	632	24	Put away from thee a froward mouth, and perverse lips put far from thee.
16516	632	25	Let thine eyes look right on, and let thine eyelids look straight before thee.
16517	632	26	Ponder the path of thy feet, and let all thy ways be established.
16518	632	27	Turn not to the right hand nor to the left: remove thy foot from evil.
16519	633	1	MY son, attend unto my wisdom, and bow thine ear to my understanding:
16520	633	2	That thou mayest regard discretion, and that thy lips may keep knowledge.
16521	633	3	For the lips of a strange woman drop as an honeycomb, and her mouth is smoother than oil:
16522	633	4	But her end is bitter as wormwood, sharp as a twoedged sword.
16523	633	5	Her feet go down to death; her steps take hold on hell.
16524	633	6	Lest thou shouldest ponder the path of life, her ways are moveable, that thou canst not know them.
16525	633	7	Hear me now therefore, O ye children, and depart not from the words of my mouth.
16526	633	8	Remove thy way far from her, and come not nigh the door of her house:
16527	633	9	Lest thou give thine honour unto others, and thy years unto the cruel:
16528	633	10	Lest strangers be filled with thy wealth; and thy labours be in the house of a stranger;
16529	633	11	And thou mourn at the last, when thy flesh and thy body are consumed,
16530	633	12	And say, How have I hated instruction, and my heart despised reproof;
16531	633	13	And have not obeyed the voice of my teachers, nor inclined mine ear to them that instructed me!
16532	633	14	I was almost in all evil in the midst of the congregation and assembly.
16533	633	15	Drink waters out of thine own cistern, and running waters out of thine own well.
16534	633	16	Let thy fountains be dispersed abroad, and rivers of waters in the streets.
16535	633	17	Let them be only thine own, and not strangers' with thee.
16536	633	18	Let thy fountain be blessed: and rejoice with the wife of thy youth.
16537	633	19	Let her be as the loving hind and pleasant roe; let her breasts satisfy thee at all times; and be thou ravished always with her love.
16538	633	20	And why wilt thou, my son, be ravished with a strange woman, and embrace the bosom of a stranger?
16539	633	21	For the ways of man are before the eyes of the LORD, and he pondereth all his goings.
16540	633	22	His own iniquities shall take the wicked himself, and he shall be holden with the cords of his sins.
16541	633	23	He shall die without instruction; and in the greatness of his folly he shall go astray.
16542	634	1	MY son, if thou be surety for thy friend, if thou hast stricken thy hand with a stranger,
16543	634	2	Thou art snared with the words of thy mouth, thou art taken with the words of thy mouth.
16544	634	3	Do this now, my son, and deliver thyself, when thou art come into the hand of thy friend; go, humble thyself, and make sure thy friend.
16545	634	4	Give not sleep to thine eyes, nor slumber to thine eyelids.
16546	634	5	Deliver thyself as a roe from the hand of the hunter, and as a bird from the hand of the fowler.
16547	634	6	Go to the ant, thou sluggard; consider her ways, and be wise:
16548	634	7	Which having no guide, overseer, or ruler,
16549	634	8	Provideth her meat in the summer, and gathereth her food in the harvest.
16550	634	9	How long wilt thou sleep, O sluggard? when wilt thou arise out of thy sleep?
16551	634	10	Yet a little sleep, a little slumber, a little folding of the hands to sleep:
16552	634	11	So shall thy poverty come as one that travelleth, and thy want as an armed man.
16553	634	12	A naughty person, a wicked man, walketh with a froward mouth.
16554	634	13	He winketh with his eyes, he speaketh with his feet, he teacheth with his fingers;
16555	634	14	Frowardness is in his heart, he deviseth mischief continually; he soweth discord.
16556	634	15	Therefore shall his calamity come suddenly; suddenly shall he be broken without remedy.
16557	634	16	These six things doth the LORD hate: yea, seven are an abomination unto him:
16558	634	17	A proud look, a lying tongue, and hands that shed innocent blood,
16559	634	18	An heart that deviseth wicked imaginations, feet that be swift in running to mischief,
16560	634	19	A false witness that speaketh lies, and he that soweth discord among brethren.
16561	634	20	My son, keep thy father's commandment, and forsake not the law of thy mother:
16562	634	21	Bind them continually upon thine heart, and tie them about thy neck.
16563	634	22	When thou goest, it shall lead thee; when thou sleepest, it shall keep thee; and when thou awakest, it shall talk with thee.
16564	634	23	For the commandment is a lamp; and the law is light; and reproofs of instruction are the way of life:
16565	634	24	To keep thee from the evil woman, from the flattery of the tongue of a strange woman.
16566	634	25	Lust not after her beauty in thine heart; neither let her take thee with her eyelids.
16567	634	26	For by means of a whorish woman a man is brought to a piece of bread: and the adulteress will hunt for the precious life.
16568	634	27	Can a man take fire in his bosom, and his clothes not be burned?
16569	634	28	Can one go upon hot coals, and his feet not be burned?
16570	634	29	So he that goeth in to his neighbour's wife; whosoever toucheth her shall not be innocent.
16571	634	30	Men do not despise a thief, if he steal to satisfy his soul when he is hungry;
16572	634	31	But if he be found, he shall restore sevenfold; he shall give all the substance of his house.
16573	634	32	But whoso committeth adultery with a woman lacketh understanding: he that doeth it destroyeth his own soul.
16574	634	33	A wound and dishonour shall he get; and his reproach shall not be wiped away.
16575	634	34	For jealousy is the rage of a man: therefore he will not spare in the day of vengeance.
16576	634	35	He will not regard any ransom; neither will he rest content, though thou givest many gifts.
16577	635	1	MY son, keep my words, and lay up my commandments with thee.
16578	635	2	Keep my commandments, and live; and my law as the apple of thine eye.
16579	635	3	Bind them upon thy fingers, write them upon the table of thine heart.
16580	635	4	Say unto wisdom, Thou art my sister; and call understanding thy kinswoman:
16581	635	5	That they may keep thee from the strange woman, from the stranger which flattereth with her words.
16582	635	6	For at the window of my house I looked through my casement,
16583	635	7	And beheld among the simple ones, I discerned among the youths, a young man void of understanding,
16584	635	8	Passing through the street near her corner; and he went the way to her house,
16585	635	9	In the twilight, in the evening, in the black and dark night:
16586	635	10	And, behold, there met him a woman with the attire of an harlot, and subtil of heart.
16587	635	11	(She is loud and stubborn; her feet abide not in her house:
16588	635	12	Now is she without, now in the streets, and lieth in wait at every corner.)
16589	635	13	So she caught him, and kissed him, and with an impudent face said unto him,
16590	635	14	I have peace offerings with me; this day have I payed my vows.
16591	635	15	Therefore came I forth to meet thee, diligently to seek thy face, and I have found thee.
16592	635	16	I have decked my bed with coverings of tapestry, with carved works, with fine linen of Egypt.
16593	635	17	I have perfumed my bed with myrrh, aloes, and cinnamon.
16594	635	18	Come, let us take our fill of love until the morning: let us solace ourselves with loves.
16595	635	19	For the goodman is not at home, he is gone a long journey:
16596	635	20	He hath taken a bag of money with him, and will come home at the day appointed.
16597	635	21	With her much fair speech she caused him to yield, with the flattering of her lips she forced him.
16598	635	22	He goeth after her straightway, as an ox goeth to the slaughter, or as a fool to the correction of the stocks;
16599	635	23	Till a dart strike through his liver; as a bird hasteth to the snare, and knoweth not that it is for his life.
16600	635	24	Hearken unto me now therefore, O ye children, and attend to the words of my mouth.
16601	635	25	Let not thine heart decline to her ways, go not astray in her paths.
16602	635	26	For she hath cast down many wounded: yea, many strong men have been slain by her.
16603	635	27	Her house is the way to hell, going down to the chambers of death.
16604	636	1	DOTH not wisdom cry? and understanding put forth her voice?
16605	636	2	She standeth in the top of high places, by the way in the places of the paths.
16606	636	3	She crieth at the gates, at the entry of the city, at the coming in at the doors.
16607	636	4	Unto you, O men, I call; and my voice is to the sons of man.
16608	636	5	O ye simple, understand wisdom: and, ye fools, be ye of an understanding heart.
16609	636	6	Hear; for I will speak of excellent things; and the opening of my lips shall be right things.
16610	636	7	For my mouth shall speak truth; and wickedness is an abomination to my lips.
16611	636	8	All the words of my mouth are in righteousness; there is nothing froward or perverse in them.
16612	636	9	They are all plain to him that understandeth, and right to them that find knowledge.
16613	636	10	Receive my instruction, and not silver; and knowledge rather than choice gold.
16614	636	11	For wisdom is better than rubies; and all the things that may be desired are not to be compared to it.
16615	636	12	I wisdom dwell with prudence, and find out knowledge of witty inventions.
16616	636	13	The fear of the LORD is to hate evil: pride, and arrogancy, and the evil way, and the froward mouth, do I hate.
16617	636	14	Counsel is mine, and sound wisdom: I am understanding; I have strength.
16618	636	15	By me kings reign, and princes decree justice.
16619	636	16	By me princes rule, and nobles, even all the judges of the earth.
16620	636	17	I love them that love me; and those that seek me early shall find me.
16621	636	18	Riches and honour are with me; yea, durable riches and righteousness.
16622	636	19	My fruit is better than gold, yea, than fine gold; and my revenue than choice silver.
16623	636	20	I lead in the way of righteousness, in the midst of the paths of judgment:
16624	636	21	That I may cause those that love me to inherit substance; and I will fill their treasures.
16625	636	22	The LORD possessed me in the beginning of his way, before his works of old.
16626	636	23	I was set up from everlasting, from the beginning, or ever the earth was.
16627	636	24	When there were no depths, I was brought forth; when there were no fountains abounding with water.
16628	636	25	Before the mountains were settled, before the hills was I brought forth:
16629	636	26	While as yet he had not made the earth, nor the fields, nor the highest part of the dust of the world.
16630	636	27	When he prepared the heavens, I was there: when he set a compass upon the face of the depth:
16631	636	28	When he established the clouds above: when he strengthened the fountains of the deep:
16632	636	29	When he gave to the sea his decree, that the waters should not pass his commandment: when he appointed the foundations of the earth:
16633	636	30	Then I was by him, as one brought up with him: and I was daily his delight, rejoicing always before him;
16634	636	31	Rejoicing in the habitable part of his earth; and my delights were with the sons of men.
16635	636	32	Now therefore hearken unto me, O ye children: for blessed are they that keep my ways.
16636	636	33	Hear instruction, and be wise, and refuse it not.
16637	636	34	Blessed is the man that heareth me, watching daily at my gates, waiting at the posts of my doors.
16638	636	35	For whoso findeth me findeth life, and shall obtain favour of the LORD.
16639	636	36	But he that sinneth against me wrongeth his own soul: all they that hate me love death.
16640	637	1	WISDOM hath builded her house, she hath hewn out her seven pillars:
16641	637	2	She hath killed her beasts; she hath mingled her wine; she hath also furnished her table.
16642	637	3	She hath sent forth her maidens: she crieth upon the highest places of the city,
16643	637	4	Whoso is simple, let him turn in hither: as for him that wanteth understanding, she saith to him,
16644	637	5	Come, eat of my bread, and drink of the wine which I have mingled.
16645	637	6	Forsake the foolish, and live; and go in the way of understanding.
16646	637	7	He that reproveth a scorner getteth to himself shame: and he that rebuketh a wicked man getteth himself a blot.
16647	637	8	Reprove not a scorner, lest he hate thee: rebuke a wise man, and he will love thee.
16648	637	9	Give instruction to a wise man, and he will be yet wiser: teach a just man, and he will increase in learning.
16649	637	10	The fear of the LORD is the beginning of wisdom: and the knowledge of the holy is understanding.
16650	637	11	For by me thy days shall be multiplied, and the years of thy life shall be increased.
16651	637	12	If thou be wise, thou shalt be wise for thyself: but if thou scornest, thou alone shalt bear it.
16652	637	13	A foolish woman is clamourous: she is simple, and knoweth nothing.
16653	637	14	For she sitteth at the door of her house, on a seat in the high places of the city,
16654	637	15	To call passengers who go right on their ways:
16655	637	16	Whoso is simple, let him turn in hither: and as for him that wanteth understanding, she saith to him,
16656	637	17	Stolen waters are sweet, and bread eaten in secret is pleasant.
16657	637	18	But he knoweth not that the dead are there; and that her guests are in the depths of hell.
16658	638	1	THE proverbs of Solomon. A wise son maketh a glad father: but a foolish son is the heaviness of his mother.
16659	638	2	Treasures of wickedness profit nothing: but righteousness delivereth from death.
16660	638	3	The LORD will not suffer the soul of the righteous to famish: but he casteth away the substance of the wicked.
16661	638	4	He becometh poor that dealeth with a slack hand: but the hand of the diligent maketh rich.
16662	638	5	He that gathereth in summer is a wise son: but he that sleepeth in harvest is a son that causeth shame.
16663	638	6	Blessings are upon the head of the just: but violence covereth the mouth of the wicked.
16664	638	7	The memory of the just is blessed: but the name of the wicked shall rot.
16665	638	8	The wise in heart will receive commandments: but a prating fool shall fall.
16666	638	9	He that walketh uprightly walketh surely: but he that perverteth his ways shall be known.
16667	638	10	He that winketh with the eye causeth sorrow: but a prating fool shall fall.
16668	638	11	The mouth of a righteous man is a well of life: but violence covereth the mouth of the wicked.
16669	638	12	Hatred stirreth up strifes: but love covereth all sins.
16670	638	13	In the lips of him that hath understanding wisdom is found: but a rod is for the back of him that is void of understanding.
16671	638	14	Wise men lay up knowledge: but the mouth of the foolish is near destruction.
16672	638	15	The rich man's wealth is his strong city: the destruction of the poor is their poverty.
16673	638	16	The labour of the righteous tendeth to life: the fruit of the wicked to sin.
16674	638	17	He is in the way of life that keepeth instruction: but he that refuseth reproof erreth.
16675	638	18	He that hideth hatred with lying lips, and he that uttereth a slander, is a fool.
16676	638	19	In the multitude of words there wanteth not sin: but he that refraineth his lips is wise.
16677	638	20	The tongue of the just is as choice silver: the heart of the wicked is little worth.
16678	638	21	The lips of the righteous feed many: but fools die for want of wisdom.
16679	638	22	The blessing of the LORD, it maketh rich, and he addeth no sorrow with it.
16680	638	23	It is as sport to a fool to do mischief: but a man of understanding hath wisdom.
16681	638	24	The fear of the wicked, it shall come upon him: but the desire of the righteous shall be granted.
16682	638	25	As the whirlwind passeth, so is the wicked no more: but the righteous is an everlasting foundation.
16683	638	26	As vinegar to the teeth, and as smoke to the eyes, so is the sluggard to them that send him.
16684	638	27	The fear of the LORD prolongeth days: but the years of the wicked shall be shortened.
16685	638	28	The hope of the righteous shall be gladness: but the expectation of the wicked shall perish.
16686	638	29	The way of the LORD is strength to the upright: but destruction shall be to the workers of iniquity.
16687	638	30	The righteous shall never be removed: but the wicked shall not inhabit the earth.
16688	638	31	The mouth of the just bringeth forth wisdom: but the froward tongue shall be cut out.
16689	638	32	The lips of the righteous know what is acceptable: but the mouth of the wicked speaketh frowardness.
16690	639	1	A FALSE balance is abomination to the LORD: but a just weight is his delight.
16691	639	2	When pride cometh, then cometh shame: but with the lowly is wisdom.
16692	639	3	The integrity of the upright shall guide them: but the perverseness of transgressors shall destroy them.
16693	639	4	Riches profit not in the day of wrath: but righteousness delivereth from death.
16694	639	5	The righteousness of the perfect shall direct his way: but the wicked shall fall by his own wickedness.
16695	639	6	The righteousness of the upright shall deliver them: but transgressors shall be taken in their own naughtiness.
16696	639	7	When a wicked man dieth, his expectation shall perish: and the hope of unjust men perisheth.
16697	639	8	The righteous is delivered out of trouble, and the wicked cometh in his stead.
16698	639	9	An hypocrite with his mouth destroyeth his neighbour: but through knowledge shall the just be delivered.
16699	639	10	When it goeth well with the righteous, the city rejoiceth: and when the wicked perish, there is shouting.
16700	639	11	By the blessing of the upright the city is exalted: but it is overthrown by the mouth of the wicked.
16701	639	12	He that is void of wisdom despiseth his neighbour: but a man of understanding holdeth his peace.
16702	639	13	A talebearer revealeth secrets: but he that is of a faithful spirit concealeth the matter.
16703	639	14	Where no counsel is, the people fall: but in the multitude of counsellors there is safety.
16704	639	15	He that is surety for a stranger shall smart for it: and he that hateth suretiship is sure.
16705	639	16	A gracious woman retaineth honour: and strong men retain riches.
16706	639	17	The merciful man doeth good to his own soul: but he that is cruel troubleth his own flesh.
16707	639	18	The wicked worketh a deceitful work: but to him that soweth righteousness shall be a sure reward.
16708	639	19	As righteousness tendeth to life: so he that pursueth evil pursueth it to his own death.
16709	639	20	They that are of a froward heart are abomination to the LORD: but such as are upright in their way are his delight.
16710	639	21	Though hand join in hand, the wicked shall not be unpunished: but the seed of the righteous shall be delivered.
16711	639	22	As a jewel of gold in a swine's snout, so is a fair woman which is without discretion.
16712	639	23	The desire of the righteous is only good: but the expectation of the wicked is wrath.
16713	639	24	There is that scattereth, and yet increaseth; and there is that withholdeth more than is meet, but it tendeth to poverty.
16714	639	25	The liberal soul shall be made fat: and he that watereth shall be watered also himself.
16715	639	26	He that withholdeth corn, the people shall curse him: but blessing shall be upon the head of him that selleth it.
16716	639	27	He that diligently seeketh good procureth favour: but he that seeketh mischief, it shall come unto him.
16717	639	28	He that trusteth in his riches shall fall: but the righteous shall flourish as a branch.
16718	639	29	He that troubleth his own house shall inherit the wind: and the fool shall be servant to the wise of heart.
16719	639	30	The fruit of the righteous is a tree of life; and he that winneth souls is wise.
16720	639	31	Behold, the righteous shall be recompensed in the earth: much more the wicked and the sinner.
16721	640	1	WHOSO loveth instruction loveth knowledge: but he that hateth reproof is brutish.
16722	640	2	A good man obtaineth favour of the LORD: but a man of wicked devices will he condemn.
16723	640	3	A man shall not be established by wickedness: but the root of the righteous shall not be moved.
16724	640	4	A virtuous woman is a crown to her husband: but she that maketh ashamed is as rottenness in his bones.
16725	640	5	The thoughts of the righteous are right: but the counsels of the wicked are deceit.
16726	640	6	The words of the wicked are to lie in wait for blood: but the mouth of the upright shall deliver them.
16727	640	7	The wicked are overthrown, and are not: but the house of the righteous shall stand.
16728	640	8	A man shall be commended according to his wisdom: but he that is of a perverse heart shall be despised.
16729	640	9	He that is despised, and hath a servant, is better than he that honoureth himself, and lacketh bread.
16730	640	10	A righteous man regardeth the life of his beast: but the tender mercies of the wicked are cruel.
16731	640	11	He that tilleth his land shall be satisfied with bread: but he that followeth vain persons is void of understanding.
16732	640	12	The wicked desireth the net of evil men: but the root of the righteous yieldeth fruit.
16733	640	13	The wicked is snared by the transgression of his lips: but the just shall come out of trouble.
16734	640	14	A man shall be satisfied with good by the fruit of his mouth: and the recompence of a man's hands shall be rendered unto him.
16735	640	15	The way of a fool is right in his own eyes: but he that hearkeneth unto counsel is wise.
16736	640	16	A fool's wrath is presently known: but a prudent man covereth shame.
16737	640	17	He that speaketh truth sheweth forth righteousness: but a false witness deceit.
16738	640	18	There is that speaketh like the piercings of a sword: but the tongue of the wise is health.
16739	640	19	The lip of truth shall be established for ever: but a lying tongue is but for a moment.
16740	640	20	Deceit is in the heart of them that imagine evil: but to the counsellors of peace is joy.
16741	640	21	There shall no evil happen to the just: but the wicked shall be filled with mischief.
16742	640	22	Lying lips are abomination to the LORD: but they that deal truly are his delight.
16743	640	23	A prudent man concealeth knowledge: but the heart of fools proclaimeth foolishness.
16744	640	24	The hand of the diligent shall bear rule: but the slothful shall be under tribute.
16745	640	25	Heaviness in the heart of man maketh it stoop: but a good word maketh it glad.
16746	640	26	The righteous is more excellent than his neighbour: but the way of the wicked seduceth them.
16747	640	27	The slothful man roasteth not that which he took in hunting: but the substance of a diligent man is precious.
16748	640	28	In the way of righteousness is life; and in the pathway thereof there is no death.
16749	641	1	A WISE son heareth his father's instruction: but a scorner heareth not rebuke.
16750	641	2	A man shall eat good by the fruit of his mouth: but the soul of the transgressors shall eat violence.
16751	641	3	He that keepeth his mouth keepeth his life: but he that openeth wide his lips shall have destruction.
16752	641	4	The soul of the sluggard desireth, and hath nothing: but the soul of the diligent shall be made fat.
16753	641	5	A righteous man hateth lying: but a wicked man is loathsome, and cometh to shame.
16754	641	6	Righteousness keepeth him that is upright in the way: but wickedness overthroweth the sinner.
16755	641	7	There is that maketh himself rich, yet hath nothing: there is that maketh himself poor, yet hath great riches.
16756	641	8	The ransom of a man's life are his riches: but the poor heareth not rebuke.
16757	641	9	The light of the righteous rejoiceth: but the lamp of the wicked shall be put out.
16758	641	10	Only by pride cometh contention: but with the well advised is wisdom.
16759	641	11	Wealth gotten by vanity shall be diminished: but he that gathereth by labour shall increase.
16760	641	12	Hope deferred maketh the heart sick: but when the desire cometh, it is a tree of life.
16761	641	13	Whoso despiseth the word shall be destroyed: but he that feareth the commandment shall be rewarded.
16762	641	14	The law of the wise is a fountain of life, to depart from the snares of death.
16763	641	15	Good understanding giveth favour: but the way of transgressors is hard.
16764	641	16	Every prudent man dealeth with knowledge: but a fool layeth open his folly.
16765	641	17	A wicked messenger falleth into mischief: but a faithful ambassador is health.
16766	641	18	Poverty and shame shall be to him that refuseth instruction: but he that regardeth reproof shall be honoured.
16767	641	19	The desire accomplished is sweet to the soul: but it is abomination to fools to depart from evil.
16768	641	20	He that walketh with wise men shall be wise: but a companion of fools shall be destroyed.
16769	641	21	Evil pursueth sinners: but to the righteous good shall be repayed.
16770	641	22	A good man leaveth an inheritance to his children's children: and the wealth of the sinner is laid up for the just.
16771	641	23	Much food is in the tillage of the poor: but there is that is destroyed for want of judgment.
16772	641	24	He that spareth his rod hateth his son: but he that loveth him chasteneth him betimes.
16773	641	25	The righteous eateth to the satisfying of his soul: but the belly of the wicked shall want.
16774	642	1	EVERY wise woman buildeth her house: but the foolish plucketh it down with her hands.
16775	642	2	He that walketh in his uprightness feareth the LORD: but he that is perverse in his ways despiseth him.
16776	642	3	In the mouth of the foolish is a rod of pride: but the lips of the wise shall preserve them.
16777	642	4	Where no oxen are, the crib is clean: but much increase is by the strength of the ox.
16778	642	5	A faithful witness will not lie: but a false witness will utter lies.
16779	642	6	A scorner seeketh wisdom, and findeth it not: but knowledge is easy unto him that understandeth.
16780	642	7	Go from the presence of a foolish man, when thou perceivest not in him the lips of knowledge.
16781	642	8	The wisdom of the prudent is to understand his way: but the folly of fools is deceit.
16782	642	9	Fools make a mock at sin: but among the righteous there is favour.
16783	642	10	The heart knoweth his own bitterness; and a stranger doth not intermeddle with his joy.
16784	642	11	The house of the wicked shall be overthrown: but the tabernacle of the upright shall flourish.
16785	642	12	There is a way which seemeth right unto a man, but the end thereof are the ways of death.
16786	642	13	Even in laughter the heart is sorrowful; and the end of that mirth is heaviness.
16787	642	14	The backslider in heart shall be filled with his own ways: and a good man shall be satisfied from himself.
16788	642	15	The simple believeth every word: but the prudent man looketh well to his going.
16789	642	16	A wise man feareth, and departeth from evil: but the fool rageth, and is confident.
16790	642	17	He that is soon angry dealeth foolishly: and a man of wicked devices is hated.
16791	642	18	The simple inherit folly: but the prudent are crowned with knowledge.
16792	642	19	The evil bow before the good; and the wicked at the gates of the righteous.
16793	642	20	The poor is hated even of his own neighbour: but the rich hath many friends.
16794	642	21	He that despiseth his neighbour sinneth: but he that hath mercy on the poor, happy is he.
16795	642	22	Do they not err that devise evil? but mercy and truth shall be to them that devise good.
16796	642	23	In all labour there is profit: but the talk of the lips tendeth only to penury.
16797	642	24	The crown of the wise is their riches: but the foolishness of fools is folly.
16798	642	25	A true witness delivereth souls: but a deceitful witness speaketh lies.
16799	642	26	In the fear of the LORD is strong confidence: and his children shall have a place of refuge.
16800	642	27	The fear of the LORD is a fountain of life, to depart from the snares of death.
16801	642	28	In the multitude of people is the king's honour: but in the want of people is the destruction of the prince.
16802	642	29	He that is slow to wrath is of great understanding: but he that is hasty of spirit exalteth folly.
16803	642	30	A sound heart is the life of the flesh: but envy the rottenness of the bones.
16804	642	31	He that oppresseth the poor reproacheth his Maker: but he that honoureth him hath mercy on the poor.
16805	642	32	The wicked is driven away in his wickedness: but the righteous hath hope in his death.
16806	642	33	Wisdom resteth in the heart of him that hath understanding: but that which is in the midst of fools is made known.
16807	642	34	Righteousness exalteth a nation: but sin is a reproach to any people.
16808	642	35	The king's favour is toward a wise servant: but his wrath is against him that causeth shame.
16809	643	1	A SOFT answer turneth away wrath: but grievous words stir up anger.
16810	643	2	The tongue of the wise useth knowledge aright: but the mouth of fools poureth out foolishness.
16811	643	3	The eyes of the LORD are in every place, beholding the evil and the good.
16812	643	4	A wholesome tongue is a tree of life: but perverseness therein is a breach in the spirit.
16813	643	5	A fool despiseth his father's instruction: but he that regardeth reproof is prudent.
16814	643	6	In the house of the righteous is much treasure: but in the revenues of the wicked is trouble.
16815	643	7	The lips of the wise disperse knowledge: but the heart of the foolish doeth not so.
16816	643	8	The sacrifice of the wicked is an abomination to the LORD: but the prayer of the upright is his delight.
16817	643	9	The way of the wicked is an abomination unto the LORD: but he loveth him that followeth after righteousness.
16818	643	10	Correction is grievous unto him that forsaketh the way: and he that hateth reproof shall die.
16819	643	11	Hell and destruction are before the LORD: how much more then the hearts of the children of men?
16820	643	12	A scorner loveth not one that reproveth him: neither will he go unto the wise.
16821	643	13	A merry heart maketh a cheerful countenance: but by sorrow of the heart the spirit is broken.
16822	643	14	The heart of him that hath understanding seeketh knowledge: but the mouth of fools feedeth on foolishness.
16823	643	15	All the days of the afflicted are evil: but he that is of a merry heart hath a continual feast.
16824	643	16	Better is little with the fear of the LORD than great treasure and trouble therewith.
16825	643	17	Better is a dinner of herbs where love is, than a stalled ox and hatred therewith.
16826	643	18	A wrathful man stirreth up strife: but he that is slow to anger appeaseth strife.
16827	643	19	The way of the slothful man is as an hedge of thorns: but the way of the righteous is made plain.
16828	643	20	A wise son maketh a glad father: but a foolish man despiseth his mother.
16829	643	21	Folly is joy to him that is destitute of wisdom: but a man of understanding walketh uprightly.
16830	643	22	Without counsel purposes are disappointed: but in the multitude of counsellors they are established.
16831	643	23	A man hath joy by the answer of his mouth: and a word spoken in due season, how good is it!
16832	643	24	The way of life is above to the wise, that he may depart from hell beneath.
16833	643	25	The LORD will destroy the house of the proud: but he will establish the border of the widow.
16834	643	26	The thoughts of the wicked are an abomination to the LORD: but the words of the pure are pleasant words.
16835	643	27	He that is greedy of gain troubleth his own house; but he that hateth gifts shall live.
16836	643	28	The heart of the righteous studieth to answer: but the mouth of the wicked poureth out evil things.
16837	643	29	The LORD is far from the wicked: but he heareth the prayer of the righteous.
16838	643	30	The light of the eyes rejoiceth the heart: and a good report maketh the bones fat.
16839	643	31	The ear that heareth the reproof of life abideth among the wise.
16840	643	32	He that refuseth instruction despiseth his own soul: but he that heareth reproof getteth understanding.
16841	643	33	The fear of the LORD is the instruction of wisdom; and before honour is humility.
16842	644	1	THE preparations of the heart in man, and the answer of the tongue, is from the LORD.
16843	644	2	All the ways of a man are clean in his own eyes; but the LORD weigheth the spirits.
16844	644	3	Commit thy works unto the LORD, and thy thoughts shall be established.
16845	644	4	The LORD hath made all things for himself: yea, even the wicked for the day of evil.
16846	644	5	Every one that is proud in heart is an abomination to the LORD: though hand join in hand, he shall not be unpunished.
16847	644	6	By mercy and truth iniquity is purged: and by the fear of the LORD men depart from evil.
16848	644	7	When a man's ways please the LORD, he maketh even his enemies to be at peace with him.
16849	644	8	Better is a little with righteousness than great revenues without right.
16850	644	9	A man's heart deviseth his way: but the LORD directeth his steps.
16851	644	10	A divine sentence is in the lips of the king: his mouth transgresseth not in judgment.
16852	644	11	A just weight and balance are the LORD's: all the weights of the bag are his work.
16853	644	12	It is an abomination to kings to commit wickedness: for the throne is established by righteousness.
16854	644	13	Righteous lips are the delight of kings; and they love him that speaketh right.
16855	644	14	The wrath of a king is as messengers of death: but a wise man will pacify it.
16856	644	15	In the light of the king's countenance is life; and his favour is as a cloud of the latter rain.
16857	644	16	How much better is it to get wisdom than gold! and to get understanding rather to be chosen than silver!
16858	644	17	The highway of the upright is to depart from evil: he that keepeth his way preserveth his soul.
16859	644	18	Pride goeth before destruction, and an haughty spirit before a fall.
16860	644	19	Better it is to be of an humble spirit with the lowly, than to divide the spoil with the proud.
16861	644	20	He that handleth a matter wisely shall find good: and whoso trusteth in the LORD, happy is he.
16862	644	21	The wise in heart shall be called prudent: and the sweetness of the lips increaseth learning.
16863	644	22	Understanding is a wellspring of life unto him that hath it: but the instruction of fools is folly.
16864	644	23	The heart of the wise teacheth his mouth, and addeth learning to his lips.
16865	644	24	Pleasant words are as an honeycomb, sweet to the soul, and health to the bones.
16866	644	25	There is a way that seemeth right unto a man, but the end thereof are the ways of death.
16867	644	26	He that laboureth laboureth for himself; for his mouth craveth it of him.
16868	644	27	An ungodly man diggeth up evil: and in his lips there is as a burning fire.
16869	644	28	A froward man soweth strife: and a whisperer separateth chief friends.
16870	644	29	A violent man enticeth his neighbour, and leadeth him into the way that is not good.
16871	644	30	He shutteth his eyes to devise froward things: moving his lips he bringeth evil to pass.
16872	644	31	The hoary head is a crown of glory, if it be found in the way of righteousness.
16873	644	32	He that is slow to anger is better than the mighty; and he that ruleth his spirit than he that taketh a city.
16874	644	33	The lot is cast into the lap; but the whole disposing thereof is of the LORD.
16875	645	1	BETTER is a dry morsel, and quietness therewith, than an house full of sacrifices with strife.
16876	645	2	A wise servant shall have rule over a son that causeth shame, and shall have part of the inheritance among the brethren.
16877	645	3	The fining pot is for silver, and the furnace for gold: but the LORD trieth the hearts.
16878	645	4	A wicked doer giveth heed to false lips; and a liar giveth ear to a naughty tongue.
16879	645	5	Whoso mocketh the poor reproacheth his Maker: and he that is glad at calamities shall not be unpunished.
16880	645	6	Children's children are the crown of old men; and the glory of children are their fathers.
16881	645	7	Excellent speech becometh not a fool: much less do lying lips a prince.
16882	645	8	A gift is as a precious stone in the eyes of him that hath it: whithersoever it turneth, it prospereth.
16883	645	9	He that covereth a transgression seeketh love; but he that repeateth a matter separateth very friends.
16884	645	10	A reproof entereth more into a wise man than an hundred stripes into a fool.
16885	645	11	An evil man seeketh only rebellion: therefore a cruel messenger shall be sent against him.
16886	645	12	Let a bear robbed of her whelps meet a man, rather than a fool in his folly.
16887	645	13	Whoso rewardeth evil for good, evil shall not depart from his house.
16888	645	14	The beginning of strife is as when one letteth out water: therefore leave off contention, before it be meddled with.
16889	645	15	He that justifieth the wicked, and he that condemneth the just, even they both are abomination to the LORD.
16890	645	16	Wherefore is there a price in the hand of a fool to get wisdom, seeing he hath no heart to it?
16891	645	17	A friend loveth at all times, and a brother is born for adversity.
16892	645	18	A man void of understanding striketh hands, and becometh surety in the presence of his friend.
16893	645	19	He loveth transgression that loveth strife: and he that exalteth his gate seeketh destruction.
16894	645	20	He that hath a froward heart findeth no good: and he that hath a perverse tongue falleth into mischief.
16895	645	21	He that begetteth a fool doeth it to his sorrow: and the father of a fool hath no joy.
16896	645	22	A merry heart doeth good like a medicine: but a broken spirit drieth the bones.
16897	645	23	A wicked man taketh a gift out of the bosom to pervert the ways of judgment.
16898	645	24	Wisdom is before him that hath understanding; but the eyes of a fool are in the ends of the earth.
16899	645	25	A foolish son is a grief to his father, and bitterness to her that bare him.
16900	645	26	Also to punish the just is not good, nor to strike princes for equity.
16901	645	27	He that hath knowledge spareth his words: and a man of understanding is of an excellent spirit.
16902	645	28	Even a fool, when he holdeth his peace, is counted wise: and he that shutteth his lips is esteemed a man of understanding.
16903	646	1	THROUGH desire a man, having separated himself, seeketh and intermeddleth with all wisdom.
16904	646	2	A fool hath no delight in understanding, but that his heart may discover itself.
16905	646	3	When the wicked cometh, then cometh also contempt, and with ignominy reproach.
16906	646	4	The words of a man's mouth are as deep waters, and the wellspring of wisdom as a flowing brook.
16907	646	5	It is not good to accept the person of the wicked, to overthrow the righteous in judgment.
16908	646	6	A fool's lips enter into contention, and his mouth calleth for strokes.
16909	646	7	A fool's mouth is his destruction, and his lips are the snare of his soul.
16910	646	8	The words of a talebearer are as wounds, and they go down into the innermost parts of the belly.
16911	646	9	He also that is slothful in his work is brother to him that is a great waster.
16912	646	10	The name of the LORD is a strong tower: the righteous runneth into it, and is safe.
16913	646	11	The rich man's wealth is his strong city, and as an high wall in his own conceit.
16914	646	12	Before destruction the heart of man is haughty, and before honour is humility.
16915	646	13	He that answereth a matter before he heareth it, it is folly and shame unto him.
16916	646	14	The spirit of a man will sustain his infirmity; but a wounded spirit who can bear?
16917	646	15	The heart of the prudent getteth knowledge; and the ear of the wise seeketh knowledge.
16918	646	16	A man's gift maketh room for him, and bringeth him before great men.
16919	646	17	He that is first in his own cause seemeth just; but his neighbour cometh and searcheth him.
16920	646	18	The lot causeth contentions to cease, and parteth between the mighty.
16921	646	19	A brother offended is harder to be won than a strong city: and their contentions are like the bars of a castle.
16922	646	20	A man's belly shall be satisfied with the fruit of his mouth; and with the increase of his lips shall he be filled.
16923	646	21	Death and life are in the power of the tongue: and they that love it shall eat the fruit thereof.
16924	646	22	Whoso findeth a wife findeth a good thing, and obtaineth favour of the LORD.
16925	646	23	The poor useth intreaties; but the rich answereth roughly.
16926	646	24	A man that hath friends must shew himself friendly: and there is a friend that sticketh closer than a brother.
16927	647	1	BETTER is the poor that walketh in his integrity, than he that is perverse in his lips, and is a fool.
16928	647	2	Also, that the soul be without knowledge, it is not good; and he that hasteth with his feet sinneth.
16929	647	3	The foolishness of man perverteth his way: and his heart fretteth against the LORD.
16930	647	4	Wealth maketh many friends; but the poor is separated from his neighbour.
16931	647	5	A false witness shall not be unpunished, and he that speaketh lies shall not escape.
16932	647	6	Many will intreat the favour of the prince: and every man is a friend to him that giveth gifts.
16933	647	7	All the brethren of the poor do hate him: how much more do his friends go far from him? he pursueth them with words, yet they are wanting to him.
16934	647	8	He that getteth wisdom loveth his own soul: he that keepeth understanding shall find good.
16935	647	9	A false witness shall not be unpunished, and he that speaketh lies shall perish.
16936	647	10	Delight is not seemly for a fool; much less for a servant to have rule over princes.
16937	647	11	The discretion of a man deferreth his anger; and it is his glory to pass over a transgression.
16938	647	12	The king's wrath is as the roaring of a lion; but his favour is as dew upon the grass.
16939	647	13	A foolish son is the calamity of his father: and the contentions of a wife are a continual dropping.
16940	647	14	House and riches are the inheritance of fathers: and a prudent wife is from the LORD.
16941	647	15	Slothfulness casteth into a deep sleep; and an idle soul shall suffer hunger.
16942	647	16	He that keepeth the commandment keepeth his own soul; but he that despiseth his ways shall die.
16943	647	17	He that hath pity upon the poor lendeth unto the LORD; and that which he hath given will he pay him again.
16944	647	18	Chasten thy son while there is hope, and let not thy soul spare for his crying.
16945	647	19	A man of great wrath shall suffer punishment: for if thou deliver him, yet thou must do it again.
16946	647	20	Hear counsel, and receive instruction, that thou mayest be wise in thy latter end.
16947	647	21	There are many devices in a man's heart; nevertheless the counsel of the LORD, that shall stand.
16948	647	22	The desire of a man is his kindness: and a poor man is better than a liar.
16949	647	23	The fear of the LORD tendeth to life: and he that hath it shall abide satisfied; he shall not be visited with evil.
16950	647	24	A slothful man hideth his hand in his bosom, and will not so much as bring it to his mouth again.
16951	647	25	Smite a scorner, and the simple will beware: and reprove one that hath understanding, and he will understand knowledge.
16952	647	26	He that wasteth his father, and chaseth away his mother, is a son that causeth shame, and bringeth reproach.
16953	647	27	Cease, my son, to hear the instruction that causeth to err from the words of knowledge.
16954	647	28	An ungodly witness scorneth judgment: and the mouth of the wicked devoureth iniquity.
16955	647	29	Judgments are prepared for scorners, and stripes for the back of fools.
16956	648	1	WINE is a mocker, strong drink is raging: and whosoever is deceived thereby is not wise.
16957	648	2	The fear of a king is as the roaring of a lion: whoso provoketh him to anger sinneth against his own soul.
16958	648	3	It is an honour for a man to cease from strife: but every fool will be meddling.
16959	648	4	The sluggard will not plow by reason of the cold; therefore shall he beg in harvest, and have nothing.
16960	648	5	Counsel in the heart of man is like deep water; but a man of understanding will draw it out.
16961	648	6	Most men will proclaim every one his own goodness: but a faithful man who can find?
16962	648	7	The just man walketh in his integrity: his children are blessed after him.
16963	648	8	A king that sitteth in the throne of judgment scattereth away all evil with his eyes.
16964	648	9	Who can say, I have made my heart clean, I am pure from my sin?
16965	648	10	Divers weights, and divers measures, both of them are alike abomination to the LORD.
16966	648	11	Even a child is known by his doings, whether his work be pure, and whether it be right.
16967	648	12	The hearing ear, and the seeing eye, the LORD hath made even both of them.
16968	648	13	Love not sleep, lest thou come to poverty; open thine eyes, and thou shalt be satisfied with bread.
16969	648	14	It is naught, it is naught, saith the buyer: but when he is gone his way, then he boasteth.
16970	648	15	There is gold, and a multitude of rubies: but the lips of knowledge are a precious jewel.
16971	648	16	Take his garment that is surety for a stranger: and take a pledge of him for a strange woman.
16972	648	17	Bread of deceit is sweet to a man; but afterwards his mouth shall be filled with gravel.
16973	648	18	Every purpose is established by counsel: and with good advice make war.
16974	648	19	He that goeth about as a talebearer revealeth secrets: therefore meddle not with him that flattereth with his lips.
16975	648	20	Whoso curseth his father or his mother, his lamp shall be put out in obscure darkness.
16976	648	21	An inheritance may be gotten hastily at the beginning; but the end thereof shall not be blessed.
16977	648	22	Say not thou, I will recompense evil; but wait on the LORD, and he shall save thee.
16978	648	23	Divers weights are an abomination unto the LORD; and a false balance is not good.
16979	648	24	Man's goings are of the LORD; how can a man then understand his own way?
16980	648	25	It is a snare to the man who devoureth that which is holy, and after vows to make inquiry.
16981	648	26	A wise king scattereth the wicked, and bringeth the wheel over them.
16982	648	27	The spirit of man is the candle of the LORD, searching all the inward parts of the belly.
16983	648	28	Mercy and truth preserve the king: and his throne is upholden by mercy.
16984	648	29	The glory of young men is their strength: and the beauty of old men is the gray head.
16985	648	30	The blueness of a wound cleanseth away evil: so do stripes the inward parts of the belly.
16986	649	1	THE king's heart is in the hand of the LORD, as the rivers of water: he turneth it whithersoever he will.
16987	649	2	Every way of a man is right in his own eyes: but the LORD pondereth the hearts.
16988	649	3	To do justice and judgment is more acceptable to the LORD than sacrifice.
16989	649	4	An high look, and a proud heart, and the plowing of the wicked, is sin.
16990	649	5	The thoughts of the diligent tend only to plenteousness; but of every one that is hasty only to want.
16991	649	6	The getting of treasures by a lying tongue is a vanity tossed to and fro of them that seek death.
16992	649	7	The robbery of the wicked shall destroy them; because they refuse to do judgment.
16993	649	8	The way of man is froward and strange: but as for the pure, his work is right.
16994	649	9	It is better to dwell in a corner of the housetop, than with a brawling woman in a wide house.
16995	649	10	The soul of the wicked desireth evil: his neighbour findeth no favour in his eyes.
16996	649	11	When the scorner is punished, the simple is made wise: and when the wise is instructed, he receiveth knowledge.
16997	649	12	The righteous man wisely considereth the house of the wicked: but God overthroweth the wicked for their wickedness.
16998	649	13	Whoso stoppeth his ears at the cry of the poor, he also shall cry himself, but shall not be heard.
16999	649	14	A gift in secret pacifieth anger: and a reward in the bosom strong wrath.
17000	649	15	It is joy to the just to do judgment: but destruction shall be to the workers of iniquity.
17001	649	16	The man that wandereth out of the way of understanding shall remain in the congregation of the dead.
17002	649	17	He that loveth pleasure shall be a poor man: he that loveth wine and oil shall not be rich.
17003	649	18	The wicked shall be a ransom for the righteous, and the transgressor for the upright.
17004	649	19	It is better to dwell in the wilderness, than with a contentious and an angry woman.
17005	649	20	There is treasure to be desired and oil in the dwelling of the wise; but a foolish man spendeth it up.
17006	649	21	He that followeth after righteousness and mercy findeth life, righteousness, and honour.
17007	649	22	A wise man scaleth the city of the mighty, and casteth down the strength of the confidence thereof.
17008	649	23	Whoso keepeth his mouth and his tongue keepeth his soul from troubles.
17009	649	24	Proud and haughty scorner is his name, who dealeth in proud wrath.
17010	649	25	The desire of the slothful killeth him; for his hands refuse to labour.
17011	649	26	He coveteth greedily all the day long: but the righteous giveth and spareth not.
17012	649	27	The sacrifice of the wicked is abomination: how much more, when he bringeth it with a wicked mind?
17013	649	28	A false witness shall perish: but the man that heareth speaketh constantly.
17014	649	29	A wicked man hardeneth his face: but as for the upright, he directeth his way.
17015	649	30	There is no wisdom nor understanding nor counsel against the LORD.
17016	649	31	The horse is prepared against the day of battle: but safety is of the LORD.
17017	650	1	A GOOD name is rather to be chosen than great riches, and loving favour rather than silver and gold.
17018	650	2	The rich and poor meet together: the LORD is the maker of them all.
17019	650	3	A prudent man foreseeth the evil, and hideth himself: but the simple pass on, and are punished.
17020	650	4	By humility and the fear of the LORD are riches, and honour, and life.
17021	650	5	Thorns and snares are in the way of the froward: he that doth keep his soul shall be far from them.
17022	650	6	Train up a child in the way he should go: and when he is old, he will not depart from it.
17023	650	7	The rich ruleth over the poor, and the borrower is servant to the lender.
17024	650	8	He that soweth iniquity shall reap vanity: and the rod of his anger shall fail.
17025	650	9	He that hath a bountiful eye shall be blessed; for he giveth of his bread to the poor.
17026	650	10	Cast out the scorner, and contention shall go out; yea, strife and reproach shall cease.
17027	650	11	He that loveth pureness of heart, for the grace of his lips the king shall be his friend.
17028	650	12	The eyes of the LORD preserve knowledge, and he overthroweth the words of the transgressor.
17029	650	13	The slothful man saith, There is a lion without, I shall be slain in the streets.
17030	650	14	The mouth of strange women is a deep pit: he that is abhorred of the LORD shall fall therein.
17031	650	15	Foolishness is bound in the heart of a child; but the rod of correction shall drive it far from him.
17032	650	16	He that oppresseth the poor to increase his riches, and he that giveth to the rich, shall surely come to want.
17033	650	17	Bow down thine ear, and hear the words of the wise, and apply thine heart unto my knowledge.
17034	650	18	For it is a pleasant thing if thou keep them within thee; they shall withal be fitted in thy lips.
17035	650	19	That thy trust may be in the LORD, I have made known to thee this day, even to thee.
17036	650	20	Have not I written to thee excellent things in counsels and knowledge,
17037	650	21	That I might make thee know the certainty of the words of truth; that thou mightest answer the words of truth to them that send unto thee?
17038	650	22	Rob not the poor, because he is poor: neither oppress the afflicted in the gate:
17039	650	23	For the LORD will plead their cause, and spoil the soul of those that spoiled them.
17040	650	24	Make no friendship with an angry man; and with a furious man thou shalt not go:
17041	650	25	Lest thou learn his ways, and get a snare to thy soul.
17042	650	26	Be not thou one of them that strike hands, or of them that are sureties for debts.
17043	650	27	If thou hast nothing to pay, why should he take away thy bed from under thee?
17044	650	28	Remove not the ancient landmark, which thy fathers have set.
17045	650	29	Seest thou a man diligent in his business? he shall stand before kings; he shall not stand before mean men.
17046	651	1	WHEN thou sittest to eat with a ruler, consider diligently what is before thee:
17047	651	2	And put a knife to thy throat, if thou be a man given to appetite.
17048	651	3	Be not desirous of his dainties: for they are deceitful meat.
17049	651	4	Labour not to be rich: cease from thine own wisdom.
17050	651	5	Wilt thou set thine eyes upon that which is not? for riches certainly make themselves wings; they fly away as an eagle toward heaven.
17051	651	6	Eat thou not the bread of him that hath an evil eye, neither desire thou his dainty meats:
17052	651	7	For as he thinketh in his heart, so is he: Eat and drink, saith he to thee; but his heart is not with thee.
17053	651	8	The morsel which thou hast eaten shalt thou vomit up, and lose thy sweet words.
17054	651	9	Speak not in the ears of a fool: for he will despise the wisdom of thy words.
17055	651	10	Remove not the old landmark; and enter not into the fields of the fatherless:
17056	651	11	For their redeemer is mighty; he shall plead their cause with thee.
17057	651	12	Apply thine heart unto instruction, and thine ears to the words of knowledge.
17058	651	13	Withhold not correction from the child: for if thou beatest him with the rod, he shall not die.
17059	651	14	Thou shalt beat him with the rod, and shalt deliver his soul from hell.
17060	651	15	My son, if thine heart be wise, my heart shall rejoice, even mine.
17061	651	16	Yea, my reins shall rejoice, when thy lips speak right things.
17062	651	17	Let not thine heart envy sinners: but be thou in the fear of the LORD all the day long.
17063	651	18	For surely there is an end; and thine expectation shall not be cut off.
17064	651	19	Hear thou, my son, and be wise, and guide thine heart in the way.
17065	651	20	Be not among winebibbers; among riotous eaters of flesh:
17066	651	21	For the drunkard and the glutton shall come to poverty: and drowsiness shall clothe a man with rags.
17067	651	22	Hearken unto thy father that begat thee, and despise not thy mother when she is old.
17068	651	23	Buy the truth, and sell it not; also wisdom, and instruction, and understanding.
17069	651	24	The father of the righteous shall greatly rejoice: and he that begetteth a wise child shall have joy of him.
17070	651	25	Thy father and thy mother shall be glad, and she that bare thee shall rejoice.
17071	651	26	My son, give me thine heart, and let thine eyes observe my ways.
17072	651	27	For a whore is a deep ditch; and a strange woman is a narrow pit.
17073	651	28	She also lieth in wait as for a prey, and increaseth the transgressors among men.
17074	651	29	Who hath woe? who hath sorrow? who hath contentions? who hath babbling? who hath wounds without cause? who hath redness of eyes?
17075	651	30	They that tarry long at the wine; they that go to seek mixed wine.
17076	651	31	Look not thou upon the wine when it is red, when it giveth his colour in the cup, when it moveth itself aright.
17077	651	32	At the last it biteth like a serpent, and stingeth like an adder.
17078	651	33	Thine eyes shall behold strange women, and thine heart shall utter perverse things.
17079	651	34	Yea, thou shalt be as he that lieth down in the midst of the sea, or as he that lieth upon the top of a mast.
17080	651	35	They have stricken me, shalt thou say, and I was not sick; they have beaten me, and I felt it not: when shall I awake? I will seek it yet again.
17081	652	1	BE not thou envious against evil men, neither desire to be with them.
17082	652	2	For their heart studieth destruction, and their lips talk of mischief.
17083	652	3	Through wisdom is an house builded; and by understanding it is established:
17084	652	4	And by knowledge shall the chambers be filled with all precious and pleasant riches.
17085	652	5	A wise man is strong; yea, a man of knowledge increaseth strength.
17086	652	6	For by wise counsel thou shalt make thy war: and in multitude of counsellors there is safety.
17087	652	7	Wisdom is too high for a fool: he openeth not his mouth in the gate.
17088	652	8	He that deviseth to do evil shall be called a mischievous person.
17089	652	9	The thought of foolishness is sin: and the scorner is an abomination to men.
17090	652	10	If thou faint in the day of adversity, thy strength is small.
17091	652	11	If thou forbear to deliver them that are drawn unto death, and those that are ready to be slain;
17092	652	12	If thou sayest, Behold, we knew it not; doth not he that pondereth the heart consider it? and he that keepeth thy soul, doth not he know it? and shall not he render to every man according to his works?
17093	652	13	My son, eat thou honey, because it is good; and the honeycomb, which is sweet to thy taste:
17094	652	14	So shall the knowledge of wisdom be unto thy soul: when thou hast found it, then there shall be a reward, and thy expectation shall not be cut off.
17095	652	15	Lay not wait, O wicked man, against the dwelling of the righteous; spoil not his resting place:
17096	652	16	For a just man falleth seven times, and riseth up again: but the wicked shall fall into mischief.
17097	652	17	Rejoice not when thine enemy falleth, and let not thine heart be glad when he stumbleth:
17098	652	18	Lest the LORD see it, and it displease him, and he turn away his wrath from him.
17099	652	19	Fret not thyself because of evil men, neither be thou envious at the wicked;
17100	652	20	For there shall be no reward to the evil man; the candle of the wicked shall be put out.
17101	652	21	My son, fear thou the LORD and the king: and meddle not with them that are given to change:
17102	652	22	For their calamity shall rise suddenly; and who knoweth the ruin of them both?
17103	652	23	These things also belong to the wise. It is not good to have respect of persons in judgment.
17104	652	24	He that saith unto the wicked, Thou art righteous; him shall the people curse, nations shall abhor him:
17105	652	25	But to them that rebuke him shall be delight, and a good blessing shall come upon them.
17106	652	26	Every man shall kiss his lips that giveth a right answer.
17107	652	27	Prepare thy work without, and make it fit for thyself in the field; and afterwards build thine house.
17108	652	28	Be not a witness against thy neighbour without cause; and deceive not with thy lips.
17109	652	29	Say not, I will do so to him as he hath done to me: I will render to the man according to his work.
17110	652	30	I went by the field of the slothful, and by the vineyard of the man void of understanding;
17111	652	31	And, lo, it was all grown over with thorns, and nettles had covered the face thereof, and the stone wall thereof was broken down.
17112	652	32	Then I saw, and considered it well: I looked upon it, and received instruction.
17113	652	33	Yet a little sleep, a little slumber, a little folding of the hands to sleep:
17114	652	34	So shall thy poverty come as one that travelleth; and thy want as an armed man.
17115	653	1	THESE are also proverbs of Solomon, which the men of Hezekiah king of Judah copied out.
17116	653	2	It is the glory of God to conceal a thing: but the honour of kings is to search out a matter.
17117	653	3	The heaven for height, and the earth for depth, and the heart of kings is unsearchable.
17118	653	4	Take away the dross from the silver, and there shall come forth a vessel for the finer.
17119	653	5	Take away the wicked from before the king, and his throne shall be established in righteousness.
17120	653	6	Put not forth thyself in the presence of the king, and stand not in the place of great men:
17121	653	7	For better it is that it be said unto thee, Come up hither; than that thou shouldest be put lower in the presence of the prince whom thine eyes have seen.
17122	653	8	Go not forth hastily to strive, lest thou know not what to do in the end thereof, when thy neighbour hath put thee to shame.
17123	653	9	Debate thy cause with thy neighbour himself; and discover not a secret to another:
17124	653	10	Lest he that heareth it put thee to shame, and thine infamy turn not away.
17125	653	11	A word fitly spoken is like apples of gold in pictures of silver.
17126	653	12	As an earring of gold, and an ornament of fine gold, so is a wise reprover upon an obedient ear.
17127	653	13	As the cold of snow in the time of harvest, so is a faithful messenger to them that send him: for he refresheth the soul of his masters.
17128	653	14	Whoso boasteth himself of a false gift is like clouds and wind without rain.
17129	653	15	By long forbearing is a prince persuaded, and a soft tongue breaketh the bone.
17130	653	16	Hast thou found honey? eat so much as is sufficient for thee, lest thou be filled therewith, and vomit it.
17131	653	17	Withdraw thy foot from thy neighbour's house; lest he be weary of thee, and so hate thee.
17132	653	18	A man that beareth false witness against his neighbour is a maul, and a sword, and a sharp arrow.
17133	653	19	Confidence in an unfaithful man in time of trouble is like a broken tooth, and a foot out of joint.
17134	653	20	As he that taketh away a garment in cold weather, and as vinegar upon nitre, so is he that singeth songs to an heavy heart.
17135	653	21	If thine enemy be hungry, give him bread to eat; and if he be thirsty, give him water to drink:
17136	653	22	For thou shalt heap coals of fire upon his head, and the LORD shall reward thee.
17137	653	23	The north wind driveth away rain: so doth an angry countenance a backbiting tongue.
17138	653	24	It is better to dwell in the corner of the housetop, than with a brawling woman and in a wide house.
17139	653	25	As cold waters to a thirsty soul, so is good news from a far country.
17140	653	26	A righteous man falling down before the wicked is as a troubled fountain, and a corrupt spring.
17141	653	27	It is not good to eat much honey: so for men to search their own glory is not glory.
17142	653	28	He that hath no rule over his own spirit is like a city that is broken down, and without walls.
17143	654	1	AS snow in summer, and as rain in harvest, so honour is not seemly for a fool.
17144	654	2	As the bird by wandering, as the swallow by flying, so the curse causeless shall not come.
17145	654	3	A whip for the horse, a bridle for the ass, and a rod for the fool's back.
17146	654	4	Answer not a fool according to his folly, lest thou also be like unto him.
17147	654	5	Answer a fool according to his folly, lest he be wise in his own conceit.
17148	654	6	He that sendeth a message by the hand of a fool cutteth off the feet, and drinketh damage.
17149	654	7	The legs of the lame are not equal: so is a parable in the mouth of fools.
17150	654	8	As he that bindeth a stone in a sling, so is he that giveth honour to a fool.
17151	654	9	As a thorn goeth up into the hand of a drunkard, so is a parable in the mouth of fools.
17152	654	10	The great God that formed all things both rewardeth the fool, and rewardeth transgressors.
17153	654	11	As a dog returneth to his vomit, so a fool returneth to his folly.
17154	654	12	Seest thou a man wise in his own conceit? there is more hope of a fool than of him.
17155	654	13	The slothful man saith, There is a lion in the way; a lion is in the streets.
17156	654	14	As the door turneth upon his hinges, so doth the slothful upon his bed.
17157	654	15	The slothful hideth his hand in his bosom; it grieveth him to bring it again to his mouth.
17158	654	16	The sluggard is wiser in his own conceit than seven men that can render a reason.
17159	654	17	He that passeth by, and meddleth with strife belonging not to him, is like one that taketh a dog by the ears.
17160	654	18	As a mad man who casteth firebrands, arrows, and death,
17161	654	19	So is the man that deceiveth his neighbour, and saith, Am not I in sport?
17162	654	20	Where no wood is, there the fire goeth out: so where there is no talebearer, the strife ceaseth.
17163	654	21	As coals are to burning coals, and wood to fire; so is a contentious man to kindle strife.
17164	654	22	The words of a talebearer are as wounds, and they go down into the innermost parts of the belly.
17165	654	23	Burning lips and a wicked heart are like a potsherd covered with silver dross.
17166	654	24	He that hateth dissembleth with his lips, and layeth up deceit within him;
17167	654	25	When he speaketh fair, believe him not: for there are seven abominations in his heart.
17168	654	26	Whose hatred is covered by deceit, his wickedness shall be shewed before the whole congregation.
17169	654	27	Whoso diggeth a pit shall fall therein: and he that rolleth a stone, it will return upon him.
17170	654	28	A lying tongue hateth those that are afflicted by it; and a flattering mouth worketh ruin.
17171	655	1	BOAST not thyself of to morrow; for thou knowest not what a day may bring forth.
17172	655	2	Let another man praise thee, and not thine own mouth; a stranger, and not thine own lips.
17173	655	3	A stone is heavy, and the sand weighty; but a fool's wrath is heavier than them both.
17174	655	4	Wrath is cruel, and anger is outrageous; but who is able to stand before envy?
17175	655	5	Open rebuke is better than secret love.
17176	655	6	Faithful are the wounds of a friend; but the kisses of an enemy are deceitful.
17177	655	7	The full soul loatheth an honeycomb; but to the hungry soul every bitter thing is sweet.
17178	655	8	As a bird that wandereth from her nest, so is a man that wandereth from his place.
17179	655	9	Ointment and perfume rejoice the heart: so doth the sweetness of a man's friend by hearty counsel.
17180	655	10	Thine own friend, and thy father's friend, forsake not; neither go into thy brother's house in the day of thy calamity: for better is a neighbour that is near than a brother far off.
17181	655	11	My son, be wise, and make my heart glad, that I may answer him that reproacheth me.
17182	655	12	A prudent man foreseeth the evil, and hideth himself; but the simple pass on, and are punished.
17183	655	13	Take his garment that is surety for a stranger, and take a pledge of him for a strange woman.
17184	655	14	He that blesseth his friend with a loud voice, rising early in the morning, it shall be counted a curse to him.
17185	655	15	A continual dropping in a very rainy day and a contentious woman are alike.
17186	655	16	Whosoever hideth her hideth the wind, and the ointment of his right hand, which bewrayeth itself.
17187	655	17	Iron sharpeneth iron; so a man sharpeneth the countenance of his friend.
17188	655	18	Whoso keepeth the fig tree shall eat the fruit thereof: so he that waiteth on his master shall be honoured.
17189	655	19	As in water face answereth to face, so the heart of man to man.
17190	655	20	Hell and destruction are never full; so the eyes of man are never satisfied.
17191	655	21	As the fining pot for silver, and the furnace for gold; so is a man to his praise.
17192	655	22	Though thou shouldest bray a fool in a mortar among wheat with a pestle, yet will not his foolishness depart from him.
17193	655	23	Be thou diligent to know the state of thy flocks, and look well to thy herds.
17194	655	24	For riches are not for ever: and doth the crown endure to every generation?
17195	655	25	The hay appeareth, and the tender grass sheweth itself, and herbs of the mountains are gathered.
17196	655	26	The lambs are for thy clothing, and the goats are the price of the field.
17197	655	27	And thou shalt have goats' milk enough for thy food, for the food of thy household, and for the maintenance for thy maidens.
17198	656	1	THE wicked flee when no man pursueth: but the righteous are bold as a lion.
17199	656	2	For the transgression of a land many are the princes thereof: but by a man of understanding and knowledge the state thereof shall be prolonged.
17200	656	3	A poor man that oppresseth the poor is like a sweeping rain which leaveth no food.
17201	656	4	They that forsake the law praise the wicked: but such as keep the law contend with them.
17202	656	5	Evil men understand not judgment: but they that seek the LORD understand all things.
17203	656	6	Better is the poor that walketh in his uprightness, than he that is perverse in his ways, though he be rich.
17204	656	7	Whoso keepeth the law is a wise son: but he that is a companion of riotous men shameth his father.
17205	656	8	He that by usury and unjust gain increaseth his substance, he shall gather it for him that will pity the poor.
17206	656	9	He that turneth away his ear from hearing the law, even his prayer shall be abomination.
17207	656	10	Whoso causeth the righteous to go astray in an evil way, he shall fall himself into his own pit: but the upright shall have good things in possession.
17208	656	11	The rich man is wise in his own conceit; but the poor that hath understanding searcheth him out.
17209	656	12	When righteous men do rejoice, there is great glory: but when the wicked rise, a man is hidden.
17210	656	13	He that covereth his sins shall not prosper: but whoso confesseth and forsaketh them shall have mercy.
17211	656	14	Happy is the man that feareth alway: but he that hardeneth his heart shall fall into mischief.
17212	656	15	As a roaring lion, and a ranging bear; so is a wicked ruler over the poor people.
17213	656	16	The prince that wanteth understanding is also a great oppressor: but he that hateth covetousness shall prolong his days.
17214	656	17	A man that doeth violence to the blood of any person shall flee to the pit; let no man stay him.
17215	656	18	Whoso walketh uprightly shall be saved: but he that is perverse in his ways shall fall at once.
17216	656	19	He that tilleth his land shall have plenty of bread: but he that followeth after vain persons shall have poverty enough.
17217	656	20	A faithful man shall abound with blessings: but he that maketh haste to be rich shall not be innocent.
17218	656	21	To have respect of persons is not good: for for a piece of bread that man will transgress.
17219	656	22	He that hasteth to be rich hath an evil eye, and considereth not that poverty shall come upon him.
17220	656	23	He that rebuketh a man afterwards shall find more favour than he that flattereth with the tongue.
17221	656	24	Whoso robbeth his father or his mother, and saith, It is no transgression; the same is the companion of a destroyer.
17222	656	25	He that is of a proud heart stirreth up strife: but he that putteth his trust in the LORD shall be made fat.
17223	656	26	He that trusteth in his own heart is a fool: but whoso walketh wisely, he shall be delivered.
17224	656	27	He that giveth unto the poor shall not lack: but he that hideth his eyes shall have many a curse.
17225	656	28	When the wicked rise, men hide themselves: but when they perish, the righteous increase.
17226	657	1	HE, that being often reproved hardeneth his neck, shall suddenly be destroyed, and that without remedy.
17227	657	2	When the righteous are in authority, the people rejoice: but when the wicked beareth rule, the people mourn.
17228	657	3	Whoso loveth wisdom rejoiceth his father: but he that keepeth company with harlots spendeth his substance.
17229	657	4	The king by judgment establisheth the land: but he that receiveth gifts overthroweth it.
17230	657	5	A man that flattereth his neighbour spreadeth a net for his feet.
17231	657	6	In the transgression of an evil man there is a snare: but the righteous doth sing and rejoice.
17232	657	7	The righteous considereth the cause of the poor: but the wicked regardeth not to know it.
17233	657	8	Scornful men bring a city into a snare: but wise men turn away wrath.
17234	657	9	If a wise man contendeth with a foolish man, whether he rage or laugh, there is no rest.
17235	657	10	The bloodthirsty hate the upright: but the just seek his soul.
17236	657	11	A fool uttereth all his mind: but a wise man keepeth it in till afterwards.
17237	657	12	If a ruler hearken to lies, all his servants are wicked.
17238	657	13	The poor and the deceitful man meet together: the LORD lighteneth both their eyes.
17239	657	14	The king that faithfully judgeth the poor, his throne shall be established for ever.
17240	657	15	The rod and reproof give wisdom: but a child left to himself bringeth his mother to shame.
17241	657	16	When the wicked are multiplied, transgression increaseth: but the righteous shall see their fall.
17242	657	17	Correct thy son, and he shall give thee rest; yea, he shall give delight unto thy soul.
17243	657	18	Where there is no vision, the people perish: but he that keepeth the law, happy is he.
17244	657	19	A servant will not be corrected by words: for though he understand he will not answer.
17245	657	20	Seest thou a man that is hasty in his words? there is more hope of a fool than of him.
17246	657	21	He that delicately bringeth up his servant from a child shall have him become his son at the length.
17247	657	22	An angry man stirreth up strife, and a furious man aboundeth in transgression.
17248	657	23	A man's pride shall bring him low: but honour shall uphold the humble in spirit.
17249	657	24	Whoso is partner with a thief hateth his own soul: he heareth cursing, and bewrayeth it not.
17250	657	25	The fear of man bringeth a snare: but whoso putteth his trust in the LORD shall be safe.
17251	657	26	Many seek the ruler's favour; but every man's judgment cometh from the LORD.
17252	657	27	An unjust man is an abomination to the just: and he that is upright in the way is abomination to the wicked.
17253	658	1	THE words of Agur the son of Jakeh, even the prophecy: the man spake unto Ithiel, even unto Ithiel and Ucal,
17254	658	2	Surely I am more brutish than any man, and have not the understanding of a man.
17255	658	3	I neither learned wisdom, nor have the knowledge of the holy.
17256	658	4	Who hath ascended up into heaven, or descended? who hath gathered the wind in his fists? who hath bound the waters in a garment? who hath established all the ends of the earth? what is his name, and what is his son's name, if thou canst tell?
17257	658	5	Every word of God is pure: he is a shield unto them that put their trust in him.
17258	658	6	Add thou not unto his words, lest he reprove thee, and thou be found a liar.
17259	658	7	Two things have I required of thee; deny me them not before I die:
17260	658	8	Remove far from me vanity and lies: give me neither poverty nor riches; feed me with food convenient for me:
17261	658	9	Lest I be full, and deny thee, and say, Who is the LORD? or lest I be poor, and steal, and take the name of my God in vain.
17262	658	10	Accuse not a servant unto his master, lest he curse thee, and thou be found guilty.
17263	658	11	There is a generation that curseth their father, and doth not bless their mother.
17264	658	12	There is a generation that are pure in their own eyes, and yet is not washed from their filthiness.
17265	658	13	There is a generation, O how lofty are their eyes! and their eyelids are lifted up.
17266	658	14	There is a generation, whose teeth are as swords, and their jaw teeth as knives, to devour the poor from off the earth, and the needy from among men.
17267	658	15	The horseleach hath two daughters, crying, Give, give. There are three things that are never satisfied, yea, four things say not, It is enough:
17268	658	16	The grave; and the barren womb; the earth that is not filled with water; and the fire that saith not, It is enough.
17269	658	17	The eye that mocketh at his father, and despiseth to obey his mother, the ravens of the valley shall pick it out, and the young eagles shall eat it.
17270	658	18	There be three things which are too wonderful for me, yea, four which I know not:
17271	658	19	The way of an eagle in the air; the way of a serpent upon a rock; the way of a ship in the midst of the sea; and the way of a man with a maid.
17272	658	20	Such is the way of an adulterous woman; she eateth, and wipeth her mouth, and saith, I have done no wickedness.
17273	658	21	For three things the earth is disquieted, and for four which it cannot bear:
17274	658	22	For a servant when he reigneth; and a fool when he is filled with meat;
17275	658	23	For an odious woman when she is married; and an handmaid that is heir to her mistress.
17276	658	24	There be four things which are little upon the earth, but they are exceeding wise:
17277	658	25	The ants are a people not strong, yet they prepare their meat in the summer;
17278	658	26	The conies are but a feeble folk, yet make they their houses in the rocks;
17279	658	27	The locusts have no king, yet go they forth all of them by bands;
17280	658	28	The spider taketh hold with her hands, and is in kings' palaces.
17281	658	29	There be three things which go well, yea, four are comely in going:
17282	658	30	A lion which is strongest among beasts, and turneth not away for any;
17283	658	31	A greyhound; an he goat also; and a king, against whom there is no rising up.
17284	658	32	If thou hast done foolishly in lifting up thyself, or if thou hast thought evil, lay thine hand upon thy mouth.
17285	658	33	Surely the churning of milk bringeth forth butter, and the wringing of the nose bringeth forth blood: so the forcing of wrath bringeth forth strife.
17286	659	1	THE words of king Lemuel, the prophecy that his mother taught him.
17287	659	2	What, my son? and what, the son of my womb? and what, the son of my vows?
17288	659	3	Give not thy strength unto women, nor thy ways to that which destroyeth kings.
17289	659	4	It is not for kings, O Lemuel, it is not for kings to drink wine; nor for princes strong drink:
17290	659	5	Lest they drink, and forget the law, and pervert the judgment of any of the afflicted.
17291	659	6	Give strong drink unto him that is ready to perish, and wine unto those that be of heavy hearts.
17292	659	7	Let him drink, and forget his poverty, and remember his misery no more.
17293	659	8	Open thy mouth for the dumb in the cause of all such as are appointed to destruction.
17294	659	9	Open thy mouth, judge righteously, and plead the cause of the poor and needy.
17295	659	10	Who can find a virtuous woman? for her price is far above rubies.
17296	659	11	The heart of her husband doth safely trust in her, so that he shall have no need of spoil.
17297	659	12	She will do him good and not evil all the days of her life.
17298	659	13	She seeketh wool, and flax, and worketh willingly with her hands.
17299	659	14	She is like the merchants' ships; she bringeth her food from afar.
17300	659	15	She riseth also while it is yet night, and giveth meat to her household, and a portion to her maidens.
17301	659	16	She considereth a field, and buyeth it: with the fruit of her hands she planteth a vineyard.
17302	659	17	She girdeth her loins with strength, and strengtheneth her arms.
17303	659	18	She perceiveth that her merchandise is good: her candle goeth not out by night.
17304	659	19	She layeth her hands to the spindle, and her hands hold the distaff.
17305	659	20	She stretcheth out her hand to the poor; yea, she reacheth forth her hands to the needy.
17306	659	21	She is not afraid of the snow for her household: for all her household are clothed with scarlet.
17307	659	22	She maketh herself coverings of tapestry; her clothing is silk and purple.
17308	659	23	Her husband is known in the gates, when he sitteth among the elders of the land.
17309	659	24	She maketh fine linen, and selleth it; and delivereth girdles unto the merchant.
17310	659	25	Strength and honour are her clothing; and she shall rejoice in time to come.
17311	659	26	She openeth her mouth with wisdom; and in her tongue is the law of kindness.
17312	659	27	She looketh well to the ways of her household, and eateth not the bread of idleness.
17313	659	28	Her children arise up, and call her blessed; her husband also, and he praiseth her.
17314	659	29	Many daughters have done virtuously, but thou excellest them all.
17315	659	30	Favour is deceitful, and beauty is vain: but a woman that feareth the LORD, she shall be praised.
17316	659	31	Give her of the fruit of her hands; and let her own works praise her in the gates.
17317	660	1	THE words of the Preacher, the son of David, king in Jerusalem.
17318	660	2	Vanity of vanities, saith the Preacher, vanity of vanities; all is vanity.
17319	660	3	What profit hath a man of all his labour which he taketh under the sun?
17320	660	4	One generation passeth away, and another generation cometh: but the earth abideth for ever.
17321	660	5	The sun also ariseth, and the sun goeth down, and hasteth to his place where he arose.
17322	660	6	The wind goeth toward the south, and turneth about unto the north; it whirleth about continually, and the wind returneth again according to his circuits.
17323	660	7	All the rivers run into the sea; yet the sea is not full; unto the place from whence the rivers come, thither they return again.
17324	660	8	All things are full of labour; man cannot utter it: the eye is not satisfied with seeing, nor the ear filled with hearing.
17325	660	9	The thing that hath been, it is that which shall be; and that which is done is that which shall be done: and there is no new thing under the sun.
17326	660	10	Is there any thing whereof it may be said, See, this is new? it hath been already of old time, which was before us.
17327	660	11	There is no remembrance of former things; neither shall there be any remembrance of things that are to come with those that shall come after.
17328	660	12	I the Preacher was king over Israel in Jerusalem.
17329	660	13	And I gave my heart to seek and search out by wisdom concerning all things that are done under heaven: this sore travail hath God given to the sons of man to be exercised therewith.
17330	660	14	I have seen all the works that are done under the sun; and, behold, all is vanity and vexation of spirit.
17331	660	15	That which is crooked cannot be made straight: and that which is wanting cannot be numbered.
17332	660	16	I communed with mine own heart, saying, Lo, I am come to great estate, and have gotten more wisdom than all they that have been before me in Jerusalem: yea, my heart had great experience of wisdom and knowledge.
17333	660	17	And I gave my heart to know wisdom, and to know madness and folly: I perceived that this also is vexation of spirit.
17334	660	18	For in much wisdom is much grief: and he that increaseth knowledge increaseth sorrow.
17335	661	1	I SAID in mine heart, Go to now, I will prove thee with mirth, therefore enjoy pleasure: and, behold, this also is vanity.
17336	661	2	I said of laughter, It is mad: and of mirth, What doeth it?
17337	661	3	I sought in mine heart to give myself unto wine, yet acquainting mine heart with wisdom; and to lay hold on folly, till I might see what was that good for the sons of men, which they should do under the heaven all the days of their life.
17338	661	4	I made me great works; I builded me houses; I planted me vineyards:
17339	661	5	I made me gardens and orchards, and I planted trees in them of all kind of fruits:
17340	661	6	I made me pools of water, to water therewith the wood that bringeth forth trees:
17341	661	7	I got me servants and maidens, and had servants born in my house; also I had great possessions of great and small cattle above all that were in Jerusalem before me:
17342	661	8	I gathered me also silver and gold, and the peculiar treasure of kings and of the provinces: I gat me men singers and women singers, and the delights of the sons of men, as musical instruments, and that of all sorts.
17343	661	9	So I was great, and increased more than all that were before me in Jerusalem: also my wisdom remained with me.
17344	661	10	And whatsoever mine eyes desired I kept not from them, I withheld not my heart from any joy; for my heart rejoiced in all my labour: and this was my portion of all my labour.
17345	661	11	Then I looked on all the works that my hands had wrought, and on the labour that I had laboured to do: and, behold, all was vanity and vexation of spirit, and there was no profit under the sun.
17346	661	12	And I turned myself to behold wisdom, and madness, and folly: for what can the man do that cometh after the king? even that which hath been already done.
17347	661	13	Then I saw that wisdom excelleth folly, as far as light excelleth darkness.
17348	661	14	The wise man's eyes are in his head; but the fool walketh in darkness: and I myself perceived also that one event happeneth to them all.
17349	661	15	Then said I in my heart, As it happeneth to the fool, so it happeneth even to me; and why was I then more wise? Then I said in my heart, that this also is vanity.
17350	661	16	For there is no remembrance of the wise more than of the fool for ever; seeing that which now is in the days to come shall all be forgotten. And how dieth the wise man? as the fool.
17351	661	17	Therefore I hated life; because the work that is wrought under the sun is grievous unto me: for all is vanity and vexation of spirit.
17352	661	18	Yea, I hated all my labour which I had taken under the sun: because I should leave it unto the man that shall be after me.
17353	661	19	And who knoweth whether he shall be a wise man or a fool? yet shall he have rule over all my labour wherein I have laboured, and wherein I have shewed myself wise under the sun. This is also vanity.
17354	661	20	Therefore I went about to cause my heart to despair of all the labour which I took under the sun.
17355	661	21	For there is a man whose labour is in wisdom, and in knowledge, and in equity; yet to a man that hath not laboured therein shall he leave it for his portion. This also is vanity and a great evil.
17356	661	22	For what hath man of all his labour, and of the vexation of his heart, wherein he hath laboured under the sun?
17357	661	23	For all his days are sorrows, and his travail grief; yea, his heart taketh not rest in the night. This is also vanity.
17358	661	24	There is nothing better for a man, than that he should eat and drink, and that he should make his soul enjoy good in his labour. This also I saw, that it was from the hand of God.
17359	661	25	For who can eat, or who else can hasten hereunto, more than I?
17360	661	26	For God giveth to a man that is good in his sight wisdom, and knowledge, and joy: but to the sinner he giveth travail, to gather and to heap up, that he may give to him that is good before God. This also is vanity and vexation of spirit.
17361	662	1	TO every thing there is a season, and a time to every purpose under the heaven:
17362	662	2	A time to be born, and a time to die; a time to plant, and a time to pluck up that which is planted;
17363	662	3	A time to kill, and a time to heal; a time to break down, and a time to build up;
17364	662	4	A time to weep, and a time to laugh; a time to mourn, and a time to dance;
17365	662	5	A time to cast away stones, and a time to gather stones together; a time to embrace, and a time to refrain from embracing;
17366	662	6	A time to get, and a time to lose; a time to keep, and a time to cast away;
17367	662	7	A time to rend, and a time to sew; a time to keep silence, and a time to speak;
17368	662	8	A time to love, and a time to hate; a time of war, and a time of peace.
17369	662	9	What profit hath he that worketh in that wherein he laboureth?
17370	662	10	I have seen the travail, which God hath given to the sons of men to be exercised in it.
17371	662	11	He hath made every thing beautiful in his time: also he hath set the world in their heart, so that no man can find out the work that God maketh from the beginning to the end.
17372	662	12	I know that there is no good in them, but for a man to rejoice, and to do good in his life.
17373	662	13	And also that every man should eat and drink, and enjoy the good of all his labour, it is the gift of God.
17374	662	14	I know that, whatsoever God doeth, it shall be for ever: nothing can be put to it, nor any thing taken from it: and God doeth it, that men should fear before him.
17375	662	15	That which hath been is now; and that which is to be hath already been; and God requireth that which is past.
17376	662	16	And moreover I saw under the sun the place of judgment, that wickedness was there; and the place of righteousness, that iniquity was there.
17377	662	17	I said in mine heart, God shall judge the righteous and the wicked: for there is a time there for every purpose and for every work.
17378	662	18	I said in mine heart concerning the estate of the sons of men, that God might manifest them, and that they might see that they themselves are beasts.
17379	662	19	For that which befalleth the sons of men befalleth beasts; even one thing befalleth them: as the one dieth, so dieth the other; yea, they have all one breath; so that a man hath no preeminence above a beast: for all is vanity.
17380	662	20	All go unto one place; all are of the dust, and all turn to dust again.
17381	662	21	Who knoweth the spirit of man that goeth upward, and the spirit of the beast that goeth downward to the earth?
17382	662	22	Wherefore I perceive that there is nothing better, than that a man should rejoice in his own works; for that is his portion: for who shall bring him to see what shall be after him?
17383	663	1	SO I returned, and considered all the oppressions that are done under the sun: and behold the tears of such as were oppressed, and they had no comforter; and on the side of their oppressors there was power; but they had no comforter.
17384	663	2	Wherefore I praised the dead which are already dead more than the living which are yet alive.
17385	663	3	Yea, better is he than both they, which hath not yet been, who hath not seen the evil work that is done under the sun.
17386	663	4	Again, I considered all travail, and every right work, that for this a man is envied of his neighbour. This is also vanity and vexation of spirit.
17387	663	5	The fool foldeth his hands together, and eateth his own flesh.
17388	663	6	Better is an handful with quietness, than both the hands full with travail and vexation of spirit.
17389	663	7	Then I returned, and I saw vanity under the sun.
17390	663	8	There is one alone, and there is not a second; yea, he hath neither child nor brother: yet is there no end of all his labour; neither is his eye satisfied with riches; neither saith he, For whom do I labour, and bereave my soul of good? This is also vanity, yea, it is a sore travail.
17391	663	9	Two are better than one; because they have a good reward for their labour.
17392	663	10	For if they fall, the one will lift up his fellow: but woe to him that is alone when he falleth; for he hath not another to help him up.
17393	663	11	Again, if two lie together, then they have heat: but how can one be warm alone?
17394	663	12	And if one prevail against him, two shall withstand him; and a threefold cord is not quickly broken.
17395	663	13	Better is a poor and a wise child than an old and foolish king, who will no more be admonished.
17396	663	14	For out of prison he cometh to reign; whereas also he that is born in his kingdom becometh poor.
17397	663	15	I considered all the living which walk under the sun, with the second child that shall stand up in his stead.
17398	663	16	There is no end of all the people, even of all that have been before them: they also that come after shall not rejoice in him. Surely this also is vanity and vexation of spirit.
17399	664	1	KEEP thy foot when thou goest to the house of God, and be more ready to hear, than to give the sacrifice of fools: for they consider not that they do evil.
17400	664	2	Be not rash with thy mouth, and let not thine heart be hasty to utter any thing before God: for God is in heaven, and thou upon earth: therefore let thy words be few.
17401	664	3	For a dream cometh through the multitude of business; and a fool's voice is known by multitude of words.
17402	664	4	When thou vowest a vow unto God, defer not to pay it; for he hath no pleasure in fools: pay that which thou hast vowed.
17403	664	5	Better is it that thou shouldest not vow, than that thou shouldest vow and not pay.
17404	664	6	Suffer not thy mouth to cause thy flesh to sin; neither say thou before the angel, that it was an error: wherefore should God be angry at thy voice, and destroy the work of thine hands?
17405	664	7	For in the multitude of dreams and many words there are also divers vanities: but fear thou God.
17406	664	8	If thou seest the oppression of the poor, and violent perverting of judgment and justice in a province, marvel not at the matter: for he that is higher than the highest regardeth; and there be higher than they.
17407	664	9	Moreover the profit of the earth is for all: the king himself is served by the field.
17408	664	10	He that loveth silver shall not be satisfied with silver; nor he that loveth abundance with increase: this is also vanity.
17409	664	11	When goods increase, they are increased that eat them: and what good is there to the owners thereof, saving the beholding of them with their eyes?
17410	664	12	The sleep of a labouring man is sweet, whether he eat little or much: but the abundance of the rich will not suffer him to sleep.
17411	664	13	There is a sore evil which I have seen under the sun, namely, riches kept for the owners thereof to their hurt.
17412	664	14	But those riches perish by evil travail: and he begetteth a son, and there is nothing in his hand.
17413	664	15	As he came forth of his mother's womb, naked shall he return to go as he came, and shall take nothing of his labour, which he may carry away in his hand.
17414	664	16	And this also is a sore evil, that in all points as he came, so shall he go: and what profit hath he that hath laboured for the wind?
17415	664	17	All his days also he eateth in darkness, and he hath much sorrow and wrath with his sickness.
17416	664	18	Behold that which I have seen: it is good and comely for one to eat and to drink, and to enjoy the good of all his labour that he taketh under the sun all the days of his life, which God giveth him: for it is his portion.
17417	664	19	Every man also to whom God hath given riches and wealth, and hath given him power to eat thereof, and to take his portion, and to rejoice in his labour; this is the gift of God.
17418	664	20	For he shall not much remember the days of his life; because God answereth him in the joy of his heart.
17419	665	1	THERE is an evil which I have seen under the sun, and it is common among men:
17420	665	2	A man to whom God hath given riches, wealth, and honour, so that he wanteth nothing for his soul of all that he desireth, yet God giveth him not power to eat thereof, but a stranger eateth it: this is vanity, and it is an evil disease.
17421	665	3	If a man beget an hundred children, and live many years, so that the days of his years be many, and his soul be not filled with good, and also that he have no burial; I say, that an untimely birth is better than he.
17422	665	4	For he cometh in with vanity, and departeth in darkness, and his name shall be covered with darkness.
17423	665	5	Moreover he hath not seen the sun, nor known any thing: this hath more rest than the other.
17424	665	6	Yea, though he live a thousand years twice told, yet hath he seen no good: do not all go to one place?
17425	665	7	All the labour of man is for his mouth, and yet the appetite is not filled.
17426	665	8	For what hath the wise more than the fool? what hath the poor, that knoweth to walk before the living?
17427	665	9	Better is the sight of the eyes than the wandering of the desire: this is also vanity and vexation of spirit.
17428	665	10	That which hath been is named already, and it is known that it is man: neither may he contend with him that is mightier than he.
17429	665	11	Seeing there be many things that increase vanity, what is man the better?
17430	665	12	For who knoweth what is good for man in this life, all the days of his vain life which he spendeth as a shadow? for who can tell a man what shall be after him under the sun?
17431	666	1	A GOOD name is better than precious ointment; and the day of death than the day of one's birth.
17432	666	2	It is better to go to the house of mourning, than to go to the house of feasting: for that is the end of all men; and the living will lay it to his heart.
17433	666	3	Sorrow is better than laughter: for by the sadness of the countenance the heart is made better.
17434	666	4	The heart of the wise is in the house of mourning; but the heart of fools is in the house of mirth.
17435	666	5	It is better to hear the rebuke of the wise, than for a man to hear the song of fools.
17436	666	6	For as the crackling of thorns under a pot, so is the laughter of the fool: this also is vanity.
17437	666	7	Surely oppression maketh a wise man mad; and a gift destroyeth the heart.
17438	666	8	Better is the end of a thing than the beginning thereof: and the patient in spirit is better than the proud in spirit.
17439	666	9	Be not hasty in thy spirit to be angry: for anger resteth in the bosom of fools.
17440	666	10	Say not thou, What is the cause that the former days were better than these? for thou dost not enquire wisely concerning this.
17441	666	11	Wisdom is good with an inheritance: and by it there is profit to them that see the sun.
17442	666	12	For wisdom is a defence, and money is a defence: but the excellency of knowledge is, that wisdom giveth life to them that have it.
17443	666	13	Consider the work of God: for who can make that straight, which he hath made crooked?
17444	666	14	In the day of prosperity be joyful, but in the day of adversity consider: God also hath set the one over against the other, to the end that man should find nothing after him.
17445	666	15	All things have I seen in the days of my vanity: there is a just man that perisheth in his righteousness, and there is a wicked man that prolongeth his life in his wickedness.
17446	666	16	Be not righteous over much; neither make thyself over wise: why shouldest thou destroy thyself?
17447	666	17	Be not over much wicked, neither be thou foolish: why shouldest thou die before thy time?
17448	666	18	It is good that thou shouldest take hold of this; yea, also from this withdraw not thine hand: for he that feareth God shall come forth of them all.
17449	666	19	Wisdom strengtheneth the wise more than ten mighty men which are in the city.
17450	666	20	For there is not a just man upon earth, that doeth good, and sinneth not.
17451	666	21	Also take no heed unto all words that are spoken; lest thou hear thy servant curse thee:
17452	666	22	For oftentimes also thine own heart knoweth that thou thyself likewise hast cursed others.
17453	666	23	All this have I proved by wisdom: I said, I will be wise; but it was far from me.
17454	666	24	That which is far off, and exceeding deep, who can find it out?
17455	666	25	I applied mine heart to know, and to search, and to seek out wisdom, and the reason of things, and to know the wickedness of folly, even of foolishness and madness:
17456	666	26	And I find more bitter than death the woman, whose heart is snares and nets, and her hands as bands: whoso pleaseth God shall escape from her; but the sinner shall be taken by her.
17457	666	27	Behold, this have I found, saith the preacher, counting one by one, to find out the account:
17458	666	28	Which yet my soul seeketh, but I find not: one man among a thousand have I found; but a woman among all those have I not found.
17459	666	29	Lo, this only have I found, that God hath made man upright; but they have sought out many inventions.
17460	667	1	WHO is as the wise man? and who knoweth the interpretation of a thing? a man's wisdom maketh his face to shine, and the boldness of his face shall be changed.
17461	667	2	I counsel thee to keep the king's commandment, and that in regard of the oath of God.
17462	667	3	Be not hasty to go out of his sight: stand not in an evil thing; for he doeth whatsoever pleaseth him.
17463	667	4	Where the word of a king is, there is power: and who may say unto him, What doest thou?
17464	667	5	Whoso keepeth the commandment shall feel no evil thing: and a wise man's heart discerneth both time and judgment.
17465	667	6	Because to every purpose there is time and judgment, therefore the misery of man is great upon him.
17466	667	7	For he knoweth not that which shall be: for who can tell him when it shall be?
17467	667	8	There is no man that hath power over the spirit to retain the spirit; neither hath he power in the day of death: and there is no discharge in that war; neither shall wickedness deliver those that are given to it.
17468	667	9	All this have I seen, and applied my heart unto every work that is done under the sun: there is a time wherein one man ruleth over another to his own hurt.
17469	667	10	And so I saw the wicked buried, who had come and gone from the place of the holy, and they were forgotten in the city where they had so done: this is also vanity.
17470	667	11	Because sentence against an evil work is not executed speedily, therefore the heart of the sons of men is fully set in them to do evil.
17471	667	12	Though a sinner do evil an hundred times, and his days be prolonged, yet surely I know that it shall be well with them that fear God, which fear before him:
17472	667	13	But it shall not be well with the wicked, neither shall he prolong his days, which are as a shadow; because he feareth not before God.
17473	667	14	There is a vanity which is done upon the earth; that there be just men, unto whom it happeneth according to the work of the wicked; again, there be wicked men, to whom it happeneth according to the work of the righteous: I said that this also is vanity.
17474	667	15	Then I commended mirth, because a man hath no better thing under the sun, than to eat, and to drink, and to be merry: for that shall abide with him of his labour the days of his life, which God giveth him under the sun.
17475	667	16	When I applied mine heart to know wisdom, and to see the business that is done upon the earth: (for also there is that neither day nor night seeth sleep with his eyes:)
17476	667	17	Then I beheld all the work of God, that a man cannot find out the work that is done under the sun: because though a man labour to seek it out, yet he shall not find it; yea further; though a wise man think to know it, yet shall he not be able to find it.
17477	668	1	FOR all this I considered in my heart even to declare all this, that the righteous, and the wise, and their works, are in the hand of God: no man knoweth either love or hatred by all that is before them.
17478	668	2	All things come alike to all: there is one event to the righteous, and to the wicked; to the good and to the clean, and to the unclean; to him that sacrificeth, and to him that sacrificeth not: as is the good, so is the sinner; and he that sweareth, as he that feareth an oath.
17479	668	3	This is an evil among all things that are done under the sun, that there is one event unto all: yea, also the heart of the sons of men is full of evil, and madness is in their heart while they live, and after that they go to the dead.
17480	668	4	For to him that is joined to all the living there is hope: for a living dog is better than a dead lion.
17481	668	5	For the living know that they shall die: but the dead know not any thing, neither have they any more a reward; for the memory of them is forgotten.
17482	668	6	Also their love, and their hatred, and their envy, is now perished; neither have they any more a portion for ever in any thing that is done under the sun.
17483	668	7	Go thy way, eat thy bread with joy, and drink thy wine with a merry heart; for God now accepteth thy works.
17484	668	8	Let thy garments be always white; and let thy head lack no ointment.
17485	668	9	Live joyfully with the wife whom thou lovest all the days of the life of thy vanity, which he hath given thee under the sun, all the days of thy vanity: for that is thy portion in this life, and in thy labour which thou takest under the sun.
17486	668	10	Whatsoever thy hand findeth to do, do it with thy might; for there is no work, nor device, nor knowledge, nor wisdom, in the grave, whither thou goest.
17487	668	11	I returned, and saw under the sun, that the race is not to the swift, nor the battle to the strong, neither yet bread to the wise, nor yet riches to men of understanding, nor yet favour to men of skill; but time and chance happeneth to them all.
17488	668	12	For man also knoweth not his time: as the fishes that are taken in an evil net, and as the birds that are caught in the snare; so are the sons of men snared in an evil time, when it falleth suddenly upon them.
17489	668	13	This wisdom have I seen also under the sun, and it seemed great unto me:
17490	668	14	There was a little city, and few men within it; and there came a great king against it, and besieged it, and built great bulwarks against it:
17491	668	15	Now there was found in it a poor wise man, and he by his wisdom delivered the city; yet no man remembered that same poor man.
17492	668	16	Then said I, Wisdom is better than strength: nevertheless the poor man's wisdom is despised, and his words are not heard.
17493	668	17	The words of wise men are heard in quiet more than the cry of him that ruleth among fools.
17494	668	18	Wisdom is better than weapons of war: but one sinner destroyeth much good.
17495	669	1	DEAD flies cause the ointment of the apothecary to send forth a stinking savour: so doth a little folly him that is in reputation for wisdom and honour.
17496	669	2	A wise man's heart is at his right hand; but a fool's heart at his left.
17497	669	3	Yea also, when he that is a fool walketh by the way, his wisdom faileth him, and he saith to every one that he is a fool.
17498	669	4	If the spirit of the ruler rise up against thee, leave not thy place; for yielding pacifieth great offences.
17499	669	5	There is an evil which I have seen under the sun, as an error which proceedeth from the ruler:
17500	669	6	Folly is set in great dignity, and the rich sit in low place.
17501	669	7	I have seen servants upon horses, and princes walking as servants upon the earth.
17502	669	8	He that diggeth a pit shall fall into it; and whoso breaketh an hedge, a serpent shall bite him.
17503	669	9	Whoso removeth stones shall be hurt therewith; and he that cleaveth wood shall be endangered thereby.
17504	669	10	If the iron be blunt, and he do not whet the edge, then must he put to more strength: but wisdom is profitable to direct.
17505	669	11	Surely the serpent will bite without enchantment; and a babbler is no better.
17506	669	12	The words of a wise man's mouth are gracious; but the lips of a fool will swallow up himself.
17507	669	13	The beginning of the words of his mouth is foolishness: and the end of his talk is mischievous madness.
17508	669	14	A fool also is full of words: a man cannot tell what shall be; and what shall be after him, who can tell him?
17509	669	15	The labour of the foolish wearieth every one of them, because he knoweth not how to go to the city.
17510	669	16	Woe to thee, O land, when thy king is a child, and thy princes eat in the morning!
17511	669	17	Blessed art thou, O land, when thy king is the son of nobles, and thy princes eat in due season, for strength, and not for drunkenness!
17512	669	18	By much slothfulness the building decayeth; and through idleness of the hands the house droppeth through.
17513	669	19	A feast is made for laughter, and wine maketh merry: but money answereth all things.
17514	669	20	Curse not the king, no not in thy thought; and curse not the rich in thy bedchamber: for a bird of the air shall carry the voice, and that which hath wings shall tell the matter.
17515	670	1	CAST thy bread upon the waters: for thou shalt find it after many days.
17516	670	2	Give a portion to seven, and also to eight; for thou knowest not what evil shall be upon the earth.
17517	670	3	If the clouds be full of rain, they empty themselves upon the earth: and if the tree fall toward the south, or toward the north, in the place where the tree falleth, there it shall be.
17518	670	4	He that observeth the wind shall not sow; and he that regardeth the clouds shall not reap.
17519	670	5	As thou knowest not what is the way of the spirit, nor how the bones do grow in the womb of her that is with child: even so thou knowest not the works of God who maketh all.
17520	670	6	In the morning sow thy seed, and in the evening withhold not thine hand: for thou knowest not whether shall prosper, either this or that, or whether they both shall be alike good.
17521	670	7	Truly the light is sweet, and a pleasant thing it is for the eyes to behold the sun:
17522	670	8	But if a man live many years, and rejoice in them all; yet let him remember the days of darkness; for they shall be many. All that cometh is vanity.
17523	670	9	Rejoice, O young man, in thy youth; and let thy heart cheer thee in the days of thy youth, and walk in the ways of thine heart, and in the sight of thine eyes: but know thou, that for all these things God will bring thee into judgment.
17524	670	10	Therefore remove sorrow from thy heart, and put away evil from thy flesh: for childhood and youth are vanity.
17525	671	1	REMEMBER now thy Creator in the days of thy youth, while the evil days come not, nor the years draw nigh, when thou shalt say, I have no pleasure in them;
17526	671	2	While the sun, or the light, or the moon, or the stars, be not darkened, nor the clouds return after the rain:
17527	671	3	In the day when the keepers of the house shall tremble, and the strong men shall bow themselves, and the grinders cease because they are few, and those that look out of the windows be darkened,
17528	671	4	And the doors shall be shut in the streets, when the sound of the grinding is low, and he shall rise up at the voice of the bird, and all the daughters of musick shall be brought low;
17529	671	5	Also when they shall be afraid of that which is high, and fears shall be in the way, and the almond tree shall flourish, and the grasshopper shall be a burden, and desire shall fail: because man goeth to his long home, and the mourners go about the streets:
17530	671	6	Or ever the silver cord be loosed, or the golden bowl be broken, or the pitcher be broken at the fountain, or the wheel broken at the cistern.
17531	671	7	Then shall the dust return to the earth as it was: and the spirit shall return unto God who gave it.
17532	671	8	Vanity of vanities, saith the preacher; all is vanity.
17533	671	9	And moreover, because the preacher was wise, he still taught the people knowledge; yea, he gave good heed, and sought out, and set in order many proverbs.
17534	671	10	The preacher sought to find out acceptable words: and that which was written was upright, even words of truth.
17535	671	11	The words of the wise are as goads, and as nails fastened by the masters of assemblies, which are given from one shepherd.
17536	671	12	And further, by these, my son, be admonished: of making many books there is no end; and much study is a weariness of the flesh.
17537	671	13	Let us hear the conclusion of the whole matter: Fear God, and keep his commandments: for this is the whole duty of man.
17538	671	14	For God shall bring every work into judgment, with every secret thing, whether it be good, or whether it be evil.
17539	672	1	THE song of songs, which is Solomon's.
17540	672	2	Let him kiss me with the kisses of his mouth: for thy love is better than wine.
17541	672	3	Because of the savour of thy good ointments thy name is as ointment poured forth, therefore do the virgins love thee.
17542	672	4	Draw me, we will run after thee: the king hath brought me into his chambers: we will be glad and rejoice in thee, we will remember thy love more than wine: the upright love thee.
17543	672	5	I am black, but comely, O ye daughters of Jerusalem, as the tents of Kedar, as the curtains of Solomon.
17544	672	6	Look not upon me, because I am black, because the sun hath looked upon me: my mother's children were angry with me; they made me the keeper of the vineyards; but mine own vineyard have I not kept.
17545	672	7	Tell me, O thou whom my soul loveth, where thou feedest, where thou makest thy flock to rest at noon: for why should I be as one that turneth aside by the flocks of thy companions?
17546	672	8	If thou know not, O thou fairest among women, go thy way forth by the footsteps of the flock, and feed thy kids beside the shepherds' tents.
17547	672	9	I have compared thee, O my love, to a company of horses in Pharaoh's chariots.
17548	672	10	Thy cheeks are comely with rows of jewels, thy neck with chains of gold.
17549	672	11	We will make thee borders of gold with studs of silver.
17550	672	12	While the king sitteth at his table, my spikenard sendeth forth the smell thereof.
17551	672	13	A bundle of myrrh is my wellbeloved unto me; he shall lie all night betwixt my breasts.
17552	672	14	My beloved is unto me as a cluster of camphire in the vineyards of En-gedi.
17553	672	15	Behold, thou art fair, my love; behold, thou art fair; thou hast doves' eyes.
17554	672	16	Behold, thou art fair, my beloved, yea, pleasant: also our bed is green.
17555	672	17	The beams of our house are cedar, and our rafters of fir.
17556	673	1	I AM the rose of Sharon, and the lily of the valleys.
17557	673	2	As the lily among thorns, so is my love among the daughters.
17558	673	3	As the apple tree among the trees of the wood, so is my beloved among the sons. I sat down under his shadow with great delight, and his fruit was sweet to my taste.
17559	673	4	He brought me to the banqueting house, and his banner over me was love.
17560	673	5	Stay me with flagons, comfort me with apples: for I am sick of love.
17561	673	6	His left hand is under my head, and his right hand doth embrace me.
17562	673	7	I charge you, O ye daughters of Jerusalem, by the roes, and by the hinds of the field, that ye stir not up, nor awake my love, till he please.
17563	673	8	The voice of my beloved! behold, he cometh leaping upon the mountains, skipping upon the hills.
17564	673	9	My beloved is like a roe or a young hart: behold, he standeth behind our wall, he looketh forth at the windows, shewing himself through the lattice.
17565	673	10	My beloved spake, and said unto me, Rise up, my love, my fair one, and come away.
17566	673	11	For, lo, the winter is past, the rain is over and gone;
17567	673	12	The flowers appear on the earth; the time of the singing of birds is come, and the voice of the turtle is heard in our land;
17568	673	13	The fig tree putteth forth her green figs, and the vines with the tender grape give a good smell. Arise, my love, my fair one, and come away.
17569	673	14	O my dove, that art in the clefts of the rock, in the secret places of the stairs, let me see thy countenance, let me hear thy voice; for sweet is thy voice, and thy countenance is comely.
17570	673	15	Take us the foxes, the little foxes, that spoil the vines: for our vines have tender grapes.
17571	673	16	My beloved is mine, and I am his: he feedeth among the lilies.
17572	673	17	Until the day break, and the shadows flee away, turn, my beloved, and be thou like a roe or a young hart upon the mountains of Bether.
17573	674	1	BY night on my bed I sought him whom my soul loveth: I sought him, but I found him not.
17574	674	2	I will rise now, and go about the city in the streets, and in the broad ways I will seek him whom my soul loveth: I sought him, but I found him not.
17575	674	3	The watchmen that go about the city found me: to whom I said, Saw ye him whom my soul loveth?
17576	674	4	It was but a little that I passed from them, but I found him whom my soul loveth: I held him, and would not let him go, until I had brought him into my mother's house, and into the chamber of her that conceived me.
17577	674	5	I charge you, O ye daughters of Jerusalem, by the roes, and by the hinds of the field, that ye stir not up, nor awake my love, till he please.
17578	674	6	Who is this that cometh out of the wilderness like pillars of smoke, perfumed with myrrh and frankincense, with all powders of the merchant?
17579	674	7	Behold his bed, which is Solomon's; threescore valiant men are about it, of the valiant of Israel.
17580	674	8	They all hold swords, being expert in war: every man hath his sword upon his thigh because of fear in the night.
17581	674	9	King Solomon made himself a chariot of the wood of Lebanon.
17582	674	10	He made the pillars thereof of silver, the bottom thereof of gold, the covering of it of purple, the midst thereof being paved with love, for the daughters of Jerusalem.
17583	674	11	Go forth, O ye daughters of Zion, and behold king Solomon with the crown wherewith his mother crowned him in the day of his espousals, and in the day of the gladness of his heart.
17584	675	1	BEHOLD, thou art fair, my love; behold, thou art fair; thou hast doves' eyes within thy locks: thy hair is as a flock of goats, that appear from mount Gilead.
17585	675	2	Thy teeth are like a flock of sheep that are even shorn, which came up from the washing; whereof every one bear twins, and none is barren among them.
17586	675	3	Thy lips are like a thread of scarlet, and thy speech is comely: thy temples are like a piece of a pomegranate within thy locks.
17587	675	4	Thy neck is like the tower of David builded for an armoury, whereon there hang a thousand bucklers, all shields of mighty men.
17588	675	5	Thy two breasts are like two young roes that are twins, which feed among the lilies.
17589	675	6	Until the day break, and the shadows flee away, I will get me to the mountain of myrrh, and to the hill of frankincense.
17590	675	7	Thou art all fair, my love; there is no spot in thee.
17591	675	8	Come with me from Lebanon, my spouse, with me from Lebanon: look from the top of Amana, from the top of Shenir and Hermon, from the lions' dens, from the mountains of the leopards.
17592	675	9	Thou hast ravished my heart, my sister, my spouse; thou hast ravished my heart with one of thine eyes, with one chain of thy neck.
17593	675	10	How fair is thy love, my sister, my spouse! how much better is thy love than wine! and the smell of thine ointments than all spices!
17594	675	11	Thy lips, O my spouse, drop as the honeycomb: honey and milk are under thy tongue; and the smell of thy garments is like the smell of Lebanon.
17595	675	12	A garden inclosed is my sister, my spouse; a spring shut up, a fountain sealed.
17596	675	13	Thy plants are an orchard of pomegranates, with pleasant fruits; camphire, with spikenard,
17597	675	14	Spikenard and saffron; calamus and cinnamon, with all trees of frankincense; myrrh and aloes, with all the chief spices:
17598	675	15	A fountain of gardens, a well of living waters, and streams from Lebanon.
17599	675	16	Awake, O north wind; and come, thou south; blow upon my garden, that the spices thereof may flow out. Let my beloved come into his garden, and eat his pleasant fruits.
17600	676	1	I AM come into my garden, my sister, my spouse: I have gathered my myrrh with my spice; I have eaten my honeycomb with my honey; I have drunk my wine with my milk: eat, O friends; drink, yea, drink abundantly, O beloved.
17601	676	2	I sleep, but my heart waketh: it is the voice of my beloved that knocketh, saying, Open to me, my sister, my love, my dove, my undefiled: for my head is filled with dew, and my locks with the drops of the night.
17602	676	3	I have put off my coat; how shall I put it on? I have washed my feet; how shall I defile them?
17603	676	4	My beloved put in his hand by the hole of the door, and my bowels were moved for him.
17604	676	5	I rose up to open to my beloved; and my hands dropped with myrrh, and my fingers with sweet smelling myrrh, upon the handles of the lock.
17605	676	6	I opened to my beloved; but my beloved had withdrawn himself, and was gone: my soul failed when he spake: I sought him, but I could not find him; I called him, but he gave me no answer.
17606	676	7	The watchmen that went about the city found me, they smote me, they wounded me; the keepers of the walls took away my veil from me.
17607	676	8	I charge you, O daughters of Jerusalem, if ye find my beloved, that ye tell him, that I am sick of love.
17608	676	9	What is thy beloved more than another beloved, O thou fairest among women? what is thy beloved more than another beloved, that thou dost so charge us?
17609	676	10	My beloved is white and ruddy, the chiefest among ten thousand.
17610	676	11	His head is as the most fine gold, his locks are bushy, and black as a raven.
17611	676	12	His eyes are as the eyes of doves by the rivers of waters, washed with milk, and fitly set.
17612	676	13	His cheeks are as a bed of spices, as sweet flowers: his lips like lilies, dropping sweet smelling myrrh.
17613	676	14	His hands are as gold rings set with the beryl: his belly is as bright ivory overlaid with sapphires.
17614	676	15	His legs are as pillars of marble, set upon sockets of fine gold: his countenance is as Lebanon, excellent as the cedars.
17615	676	16	His mouth is most sweet: yea, he is altogether lovely. This is my beloved, and this is my friend, O daughters of Jerusalem.
17616	677	1	WHITHER is thy beloved gone, O thou fairest among women? whither is thy beloved turned aside? that we may seek him with thee.
17617	677	2	My beloved is gone down into his garden, to the beds of spices, to feed in the gardens, and to gather lilies.
17618	677	3	I am my beloved's, and my beloved is mine: he feedeth among the lilies.
17619	677	4	Thou art beautiful, O my love, as Tirzah, comely as Jerusalem, terrible as an army with banners.
17620	677	5	Turn away thine eyes from me, for they have overcome me: thy hair is as a flock of goats that appear from Gilead.
17621	677	6	Thy teeth are as a flock of sheep which go up from the washing, whereof every one beareth twins, and there is not one barren among them.
17622	677	7	As a piece of a pomegranate are thy temples within thy locks.
17623	677	8	There are threescore queens, and fourscore concubines, and virgins without number.
17624	677	9	My dove, my undefiled is but one; she is the only one of her mother, she is the choice one of her that bare her. The daughters saw her, and blessed her; yea, the queens and the concubines, and they praised her.
17625	677	10	Who is she that looketh forth as the morning, fair as the moon, clear as the sun, and terrible as an army with banners?
17626	677	11	I went down into the garden of nuts to see the fruits of the valley, and to see whether the vine flourished, and the pomegranates budded.
17627	677	12	Or ever I was aware, my soul made me like the chariots of Amminadib.
17628	677	13	Return, return, O Shulamite; return, return, that we may look upon thee. What will ye see in the Shulamite? As it were the company of two armies.
17629	678	1	HOW beautiful are thy feet with shoes, O prince's daughter! the joints of thy thighs are like jewels, the work of the hands of a cunning workman.
17630	678	2	Thy navel is like a round goblet, which wanteth not liquor: thy belly is like an heap of wheat set about with lilies.
17631	678	3	Thy two breasts are like two young roes that are twins.
17632	678	4	Thy neck is as a tower of ivory; thine eyes like the fishpools in Heshbon, by the gate of Bath-rabbim: thy nose is as the tower of Lebanon which looketh toward Damascus.
17633	678	5	Thine head upon thee is like Carmel, and the hair of thine head like purple; the king is held in the galleries.
17634	678	6	How fair and how pleasant art thou, O love, for delights!
17635	678	7	This thy stature is like to a palm tree, and thy breasts to clusters of grapes.
17636	678	8	I said, I will go up to the palm tree, I will take hold of the boughs thereof: now also thy breasts shall be as clusters of the vine, and the smell of thy nose like apples;
17637	678	9	And the roof of thy mouth like the best wine for my beloved, that goeth down sweetly, causing the lips of those that are asleep to speak.
17638	678	10	I am my beloved's, and his desire is toward me.
17639	678	11	Come, my beloved, let us go forth into the field; let us lodge in the villages.
17640	678	12	Let us get up early to the vineyards; let us see if the vine flourish, whether the tender grape appear, and the pomegranates bud forth: there will I give thee my loves.
17641	678	13	The mandrakes give a smell, and at our gates are all manner of pleasant fruits, new and old, which I have laid up for thee, O my beloved.
17642	679	1	O THAT thou wert as my brother, that sucked the breasts of my mother! when I should find thee without, I would kiss thee; yea, I should not be despised.
17643	679	2	I would lead thee, and bring thee into my mother's house, who would instruct me: I would cause thee to drink of spiced wine of the juice of my pomegranate.
17644	679	3	His left hand should be under my head, and his right hand should embrace me.
17645	679	4	I charge you, O daughters of Jerusalem, that ye stir not up, nor awake my love, until he please.
17646	679	5	Who is this that cometh up from the wilderness, leaning upon her beloved? I raised thee up under the apple tree: there thy mother brought thee forth: there she brought thee forth that bare thee.
17647	679	6	Set me as a seal upon thine heart, as a seal upon thine arm: for love is strong as death; jealousy is cruel as the grave: the coals thereof are coals of fire, which hath a most vehement flame.
17648	679	7	Many waters cannot quench love, neither can the floods drown it: if a man would give all the substance of his house for love, it would utterly be contemned.
17649	679	8	We have a little sister, and she hath no breasts: what shall we do for our sister in the day when she shall be spoken for?
17650	679	9	If she be a wall, we will build upon her a palace of silver: and if she be a door, we will inclose her with boards of cedar.
17651	679	10	I am a wall, and my breasts like towers: then was I in his eyes as one that found favour.
17652	679	11	Solomon had a vineyard at Baal-hamon; he let out the vineyard unto keepers; every one for the fruit thereof was to bring a thousand pieces of silver.
17653	679	12	My vineyard, which is mine, is before me: thou, O Solomon, must have a thousand, and those that keep the fruit thereof two hundred.
17654	679	13	Thou that dwellest in the gardens, the companions hearken to thy voice: cause me to hear it.
17655	679	14	Make haste, my beloved, and be thou like to a roe or to a young hart upon the mountains of spices.
17656	680	1	THE vision of Isaiah the son of Amoz, which he saw concerning Judah and Jerusalem in the days of Uzziah, Jotham, Ahaz, and Hezekiah, kings of Judah.
17657	680	2	Hear, O heavens, and give ear, O earth: for the LORD hath spoken, I have nourished and brought up children, and they have rebelled against me.
17658	680	3	The ox knoweth his owner, and the ass his master's crib: but Israel doth not know, my people doth not consider.
17659	680	4	Ah sinful nation, a people laden with iniquity, a seed of evildoers, children that are corrupters: they have forsaken the LORD, they have provoked the Holy One of Israel unto anger, they are gone away backward.
17660	680	5	Why should ye be stricken any more? ye will revolt more and more: the whole head is sick, and the whole heart faint.
17661	680	6	From the sole of the foot even unto the head there is no soundness in it; but wounds, and bruises, and putrifying sores: they have not been closed, neither bound up, neither mollified with ointment.
17662	680	7	Your country is desolate, your cities are burned with fire: your land, strangers devour it in your presence, and it is desolate, as overthrown by strangers.
17663	680	8	And the daughter of Zion is left as a cottage in a vineyard, as a lodge in a garden of cucumbers, as a besieged city.
17664	680	9	Except the LORD of hosts had left unto us a very small remnant, we should have been as Sodom, and we should have been like unto Gomorrah.
17665	680	10	Hear the word of the LORD, ye rulers of Sodom; give ear unto the law of our God, ye people of Gomorrah.
17666	680	11	To what purpose is the multitude of your sacrifices unto me? saith the LORD: I am full of the burnt offerings of rams, and the fat of fed beasts; and I delight not in the blood of bullocks, or of lambs, or of he goats.
17667	680	12	When ye come to appear before me, who hath required this at your hand, to tread my courts?
17668	680	13	Bring no more vain oblations; incense is an abomination unto me; the new moons and sabbaths, the calling of assemblies, I cannot away with; it is iniquity, even the solemn meeting.
17669	680	14	Your new moons and your appointed feasts my soul hateth: they are a trouble unto me; I am weary to bear them.
17670	680	15	And when ye spread forth your hands, I will hide mine eyes from you: yea, when ye make many prayers, I will not hear: your hands are full of blood.
17671	680	16	Wash you, make you clean; put away the evil of your doings from before mine eyes; cease to do evil;
17672	680	17	Learn to do well; seek judgment, relieve the oppressed, judge the fatherless, plead for the widow.
17673	680	18	Come now, and let us reason together, saith the LORD: though your sins be as scarlet, they shall be as white as snow; though they be red like crimson, they shall be as wool.
17674	680	19	If ye be willing and obedient, ye shall eat the good of the land:
17675	680	20	But if ye refuse and rebel, ye shall be devoured with the sword: for the mouth of the LORD hath spoken it.
17676	680	21	How is the faithful city become an harlot! it was full of judgment; righteousness lodged in it; but now murderers.
17677	680	22	Thy silver is become dross, thy wine mixed with water:
17678	680	23	Thy princes are rebellious, and companions of thieves: every one loveth gifts, and followeth after rewards: they judge not the fatherless, neither doth the cause of the widow come unto them.
17679	680	24	Therefore saith the Lord, the LORD of hosts, the mighty One of Israel, Ah, I will ease me of mine adversaries, and avenge me of mine enemies:
17680	680	25	And I will turn my hand upon thee, and purely purge away thy dross, and take away all thy tin:
17681	680	26	And I will restore thy judges as at the first, and thy counsellors as at the beginning: afterward thou shalt be called, The city of righteousness, the faithful city.
17682	680	27	Zion shall be redeemed with judgment, and her converts with righteousness.
17683	680	28	And the destruction of the transgressors and of the sinners shall be together, and they that forsake the LORD shall be consumed.
17684	680	29	For they shall be ashamed of the oaks which ye have desired, and ye shall be confounded for the gardens that ye have chosen.
17685	680	30	For ye shall be as an oak whose leaf fadeth, and as a garden that hath no water.
17686	680	31	And the strong shall be as tow, and the maker of it as a spark, and they shall both burn together, and none shall quench them.
17687	681	1	THE word that Isaiah the son of Amoz saw concerning Judah and Jerusalem.
17688	681	2	And it shall come to pass in the last days, that the mountain of the LORD's house shall be established in the top of the mountains, and shall be exalted above the hills; and all nations shall flow unto it.
17689	681	3	And many people shall go and say, Come ye, and let us go up to the mountain of the LORD, to the house of the God of Jacob; and he will teach us of his ways, and we will walk in his paths: for out of Zion shall go forth the law, and the word of the LORD from Jerusalem.
17690	681	4	And he shall judge among the nations, and shall rebuke many people: and they shall beat their swords into plowshares, and their spears into pruninghooks: nation shall not lift up sword against nation, neither shall they learn war any more.
17691	681	5	O house of Jacob, come ye, and let us walk in the light of the LORD.
17692	681	6	Therefore thou hast forsaken thy people the house of Jacob, because they be replenished from the east, and are soothsayers like the Philistines, and they please themselves in the children of strangers.
17693	681	7	Their land also is full of silver and gold, neither is there any end of their treasures; their land is also full of horses, neither is there any end of their chariots:
17694	681	8	Their land also is full of idols; they worship the work of their own hands, that which their own fingers have made:
17695	681	9	And the mean man boweth down, and the great man humbleth himself: therefore forgive them not.
17696	681	10	Enter into the rock, and hide thee in the dust, for fear of the LORD, and for the glory of his majesty.
17697	681	11	The lofty looks of man shall be humbled, and the haughtiness of men shall be bowed down, and the LORD alone shall be exalted in that day.
17698	681	12	For the day of the LORD of hosts shall be upon every one that is proud and lofty, and upon every one that is lifted up; and he shall be brought low:
17699	681	13	And upon all the cedars of Lebanon, that are high and lifted up, and upon all the oaks of Bashan,
17700	681	14	And upon all the high mountains, and upon all the hills that are lifted up,
17701	681	15	And upon every high tower, and upon every fenced wall,
17702	681	16	And upon all the ships of Tarshish, and upon all pleasant pictures.
17703	681	17	And the loftiness of man shall be bowed down, and the haughtiness of men shall be made low: and the LORD alone shall be exalted in that day.
17704	681	18	And the idols he shall utterly abolish.
17705	681	19	And they shall go into the holes of the rocks, and into the caves of the earth, for fear of the LORD, and for the glory of his majesty, when he ariseth to shake terribly the earth.
17706	681	20	In that day a man shall cast his idols of silver, and his idols of gold, which they made each one for himself to worship, to the moles and to the bats;
17707	681	21	To go into the clefts of the rocks, and into the tops of the ragged rocks, for fear of the LORD, and for the glory of his majesty, when he ariseth to shake terribly the earth.
17708	681	22	Cease ye from man, whose breath is in his nostrils: for wherein is he to be accounted of?
17709	682	1	FOR, behold, the Lord, the LORD of hosts, doth take away from Jerusalem and from Judah the stay and the staff, the whole stay of bread, and the whole stay of water,
17710	682	2	The mighty man, and the man of war, the judge, and the prophet, and the prudent, and the ancient,
17711	682	3	The captain of fifty, and the honourable man, and the counsellor, and the cunning artificer, and the eloquent orator.
17712	682	4	And I will give children to be their princes, and babes shall rule over them.
17713	682	5	And the people shall be oppressed, every one by another, and every one by his neighbour: the child shall behave himself proudly against the ancient, and the base against the honourable.
17714	682	6	When a man shall take hold of his brother of the house of his father, saying, Thou hast clothing, be thou our ruler, and let this ruin be under thy hand:
17715	682	7	In that day shall he swear, saying, I will not be an healer; for in my house is neither bread nor clothing: make me not a ruler of the people.
17716	682	8	For Jerusalem is ruined, and Judah is fallen: because their tongue and their doings are against the LORD, to provoke the eyes of his glory.
17717	682	9	The shew of their countenance doth witness against them; and they declare their sin as Sodom, they hide it not. Woe unto their soul! for they have rewarded evil unto themselves.
17718	682	10	Say ye to the righteous, that it shall be well with him: for they shall eat the fruit of their doings.
17719	682	11	Woe unto the wicked! it shall be ill with him: for the reward of his hands shall be given him.
17720	682	12	As for my people, children are their oppressors, and women rule over them. O my people, they which lead thee cause thee to err, and destroy the way of thy paths.
17721	682	13	The LORD standeth up to plead, and standeth to judge the people.
17722	682	14	The LORD will enter into judgment with the ancients of his people, and the princes thereof: for ye have eaten up the vineyard; the spoil of the poor is in your houses.
17723	682	15	What mean ye that ye beat my people to pieces, and grind the faces of the poor? saith the Lord GOD of hosts.
17724	682	16	Moreover the LORD saith, Because the daughters of Zion are haughty, and walk with stretched forth necks and wanton eyes, walking and mincing as they go, and making a tinkling with their feet:
17725	682	17	Therefore the Lord will smite with a scab the crown of the head of the daughters of Zion, and the LORD will discover their secret parts.
17726	682	18	In that day the Lord will take away the bravery of their tinkling ornaments about their feet, and their cauls, and their round tires like the moon,
17727	682	19	The chains, and the bracelets, and the mufflers,
17728	682	20	The bonnets, and the ornaments of the legs, and the headbands, and the tablets, and the earrings,
17729	682	21	The rings, and nose jewels,
17730	682	22	The changeable suits of apparel, and the mantles, and the wimples, and the crisping pins,
17731	682	23	The glasses, and the fine linen, and the hoods, and the vails.
17732	682	24	And it shall come to pass, that instead of sweet smell there shall be stink; and instead of a girdle a rent; and instead of well set hair baldness; and instead of a stomacher a girding of sackcloth; and burning instead of beauty.
17733	682	25	Thy men shall fall by the sword, and thy mighty in the war.
17734	682	26	And her gates shall lament and mourn; and she being desolate shall sit upon the ground.
17735	683	1	AND in that day seven women shall take hold of one man, saying, We will eat our own bread, and wear our own apparel: only let us be called by thy name, to take away our reproach.
17736	683	2	In that day shall the branch of the LORD be beautiful and glorious, and the fruit of the earth shall be excellent and comely for them that are escaped of Israel.
17737	683	3	And it shall come to pass, that he that is left in Zion, and he that remaineth in Jerusalem, shall be called holy, even every one that is written among the living in Jerusalem:
17738	683	4	When the Lord shall have washed away the filth of the daughters of Zion, and shall have purged the blood of Jerusalem from the midst thereof by the spirit of judgment, and by the spirit of burning.
17739	683	5	And the LORD will create upon every dwelling place of mount Zion, and upon her assemblies, a cloud and smoke by day, and the shining of a flaming fire by night: for upon all the glory shall be a defence.
17740	683	6	And there shall be a tabernacle for a shadow in the daytime from the heat, and for a place of refuge, and for a covert from storm and from rain.
17741	684	1	Now will I sing to my wellbeloved a song of my beloved touching his vineyard. My wellbeloved hath a vineyard in a very fruitful hill:
17742	684	2	And he fenced it, and gathered out the stones thereof, and planted it with the choicest vine, and built a tower in the midst of it, and also made a winepress therein: and he looked that it should bring forth grapes, and it brought forth wild grapes.
17743	684	3	And now, O inhabitants of Jerusalem, and men of Judah, judge, I pray you, betwixt me and my vineyard.
17744	684	4	What could have been done more to my vineyard, that I have not done in it? wherefore, when I looked that it should bring forth grapes, brought it forth wild grapes?
17745	684	5	And now go to; I will tell you what I will do to my vineyard: I will take away the hedge thereof, and it shall be eaten up; and break down the wall thereof, and it shall be trodden down:
17746	684	6	And I will lay it waste: it shall not be pruned, nor digged; but there shall come up briers and thorns: I will also command the clouds that they rain no rain upon it.
17747	684	7	For the vineyard of the LORD of hosts is the house of Israel, and the men of Judah his pleasant plant: and he looked for judgment, but behold oppression; for righteousness, but behold a cry.
17748	684	8	Woe unto them that join house to house, that lay field to field, till there be no place, that they may be placed alone in the midst of the earth!
17749	684	9	In mine ears said the LORD of hosts, Of a truth many houses shall be desolate, even great and fair, without inhabitant.
17750	684	10	Yea, ten acres of vineyard shall yield one bath, and the seed of an homer shall yield an ephah.
17751	684	11	Woe unto them that rise up early in the morning, that they may follow strong drink; that continue until night, till wine inflame them!
17752	684	12	And the harp, and the viol, the tabret, and pipe, and wine, are in their feasts: but they regard not the work of the LORD, neither consider the operation of his hands.
17753	684	13	Therefore my people are gone into captivity, because they have no knowledge: and their honourable men are famished, and their multitude dried up with thirst.
17754	684	14	Therefore hell hath enlarged herself, and opened her mouth without measure: and their glory, and their multitude, and their pomp, and he that rejoiceth, shall descend into it.
17755	684	15	And the mean man shall be brought down, and the mighty man shall be humbled, and the eyes of the lofty shall be humbled:
17756	684	16	But the LORD of hosts shall be exalted in judgment, and God that is holy shall be sanctified in righteousness.
17757	684	17	Then shall the lambs feed after their manner, and the waste places of the fat ones shall strangers eat.
17758	684	18	Woe unto them that draw iniquity with cords of vanity, and sin as it were with a cart rope:
17759	684	19	That say, Let him make speed, and hasten his work, that we may see it: and let the counsel of the Holy One of Israel draw nigh and come, that we may know it!
17760	684	20	Woe unto them that call evil good, and good evil; that put darkness for light, and light for darkness; that put bitter for sweet, and sweet for bitter!
17761	684	21	Woe unto them that are wise in their own eyes, and prudent in their own sight!
17762	684	22	Woe unto them that are mighty to drink wine, and men of strength to mingle strong drink:
17763	684	23	Which justify the wicked for reward, and take away the righteousness of the righteous from him!
17764	684	24	Therefore as the fire devoureth the stubble, and the flame consumeth the chaff, so their root shall be as rottenness, and their blossom shall go up as dust: because they have cast away the law of the LORD of hosts, and despised the word of the Holy One of Israel.
17765	684	25	Therefore is the anger of the LORD kindled against his people, and he hath stretched forth his hand against them, and hath smitten them: and the hills did tremble, and their carcases were torn in the midst of the streets. For all this his anger is not turned away, but his hand is stretched out still.
17766	684	26	And he will lift up an ensign to the nations from far, and will hiss unto them from the end of the earth: and, behold, they shall come with speed swiftly:
17767	684	27	None shall be weary nor stumble among them; none shall slumber nor sleep; neither shall the girdle of their loins be loosed, nor the latchet of their shoes be broken:
17768	684	28	Whose arrows are sharp, and all their bows bent, their horses' hoofs shall be counted like flint, and their wheels like a whirlwind:
17769	684	29	Their roaring shall be like a lion, they shall roar like young lions: yea, they shall roar, and lay hold of the prey, and shall carry it away safe, and none shall deliver it.
17770	684	30	And in that day they shall roar against them like the roaring of the sea: and if one look unto the land, behold darkness and sorrow, and the light is darkened in the heavens thereof.
17771	685	1	IN the year that king Uzziah died I saw also the Lord sitting upon a throne, high and lifted up, and his train filled the temple.
17772	685	2	Above it stood the seraphims: each one had six wings; with twain he covered his face, and with twain he covered his feet, and with twain he did fly.
17773	685	3	And one cried unto another, and said, Holy, holy, holy, is the LORD of hosts: the whole earth is full of his glory.
17774	685	4	And the posts of the door moved at the voice of him that cried, and the house was filled with smoke.
17775	685	5	Then said I, Woe is me! for I am undone; because I am a man of unclean lips, and I dwell in the midst of a people of unclean lips: for mine eyes have seen the King, the LORD of hosts.
17776	685	6	Then flew one of the seraphims unto me, having a live coal in his hand, which he had taken with the tongs from off the altar:
17777	685	7	And he laid it upon my mouth, and said, Lo, this hath touched thy lips; and thine iniquity is taken away, and thy sin purged.
17778	685	8	Also I heard the voice of the Lord, saying, Whom shall I send, and who will go for us? Then said I, Here am I; send me.
17779	685	9	And he said, Go, and tell this people, Hear ye indeed, but understand not; and see ye indeed, but perceive not.
17780	685	10	Make the heart of this people fat, and make their ears heavy, and shut their eyes; lest they see with their eyes, and hear with their ears, and understand with their heart, and convert, and be healed.
17781	685	11	Then said I, Lord, how long? And he answered, Until the cities be wasted without inhabitant, and the houses without man, and the land be utterly desolate,
17782	685	12	And the LORD have removed men far away, and there be a great forsaking in the midst of the land.
17783	685	13	But yet in it shall be a tenth, and it shall return, and shall be eaten: as a teil tree, and as an oak, whose substance is in them, when they cast their leaves: so the holy seed shall be the substance thereof.
17784	686	1	AND it came to pass in the days of Ahaz the son of Jotham, the son of Uzziah, king of Judah, that Rezin the king of Syria, and Pekah the son of Remaliah, king of Israel, went up toward Jerusalem to war against it, but could not prevail against it.
17785	686	2	And it was told the house of David, saying, Syria is confederate with Ephraim. And his heart was moved, and the heart of his people, as the trees of the wood are moved with the wind.
17786	686	3	Then said the LORD unto Isaiah, Go forth now to meet Ahaz, thou, and Shear-jashub thy son, at the end of the conduit of the upper pool in the highway of the fuller's field;
17787	686	4	And say unto him, Take heed, and be quiet; fear not, neither be fainthearted for the two tails of these smoking firebrands, for the fierce anger of Rezin with Syria, and of the son of Remaliah.
17788	686	5	Because Syria, Ephraim, and the son of Remaliah, have taken evil counsel against thee, saying,
17789	686	6	Let us go up against Judah, and vex it, and let us make a breach therein for us, and set a king in the midst of it, even the son of Tabeal:
17790	686	7	Thus saith the Lord GOD, It shall not stand, neither shall it come to pass.
17791	686	8	For the head of Syria is Damascus, and the head of Damascus is Rezin; and within threescore and five years shall Ephraim be broken, that it be not a people.
17792	686	9	And the head of Ephraim is Samaria, and the head of Samaria is Remaliah's son. If ye will not believe, surely ye shall not be established.
17793	686	10	Moreover the LORD spake again unto Ahaz, saying,
17794	686	11	Ask thee a sign of the LORD thy God; ask it either in the depth, or in the height above.
17795	686	12	But Ahaz said, I will not ask, neither will I tempt the LORD.
17796	686	13	And he said, Hear ye now, O house of David; Is it a small thing for you to weary men, but will ye weary my God also?
17797	686	14	Therefore the Lord himself shall give you a sign; Behold, a virgin shall conceive, and bear a son, and shall call his name Immanuel.
17798	686	15	Butter and honey shall he eat, that he may know to refuse the evil, and choose the good.
17799	686	16	For before the child shall know to refuse the evil, and choose the good, the land that thou abhorrest shall be forsaken of both her kings.
17800	686	17	The LORD shall bring upon thee, and upon thy people, and upon thy father's house, days that have not come, from the day that Ephraim departed from Judah; even the king of Assyria.
17801	686	18	And it shall come to pass in that day, that the LORD shall hiss for the fly that is in the uttermost part of the rivers of Egypt, and for the bee that is in the land of Assyria.
17802	686	19	And they shall come, and shall rest all of them in the desolate valleys, and in the holes of the rocks, and upon all thorns, and upon all bushes.
17803	686	20	In the same day shall the Lord shave with a razor that is hired, namely, by them beyond the river, by the king of Assyria, the head, and the hair of the feet: and it shall also consume the beard.
17804	686	21	And it shall come to pass in that day, that a man shall nourish a young cow, and two sheep;
17805	686	22	And it shall come to pass, for the abundance of milk that they shall give he shall eat butter: for butter and honey shall every one eat that is left in the land.
17806	686	23	And it shall come to pass in that day, that every place shall be, where there were a thousand vines at a thousand silverlings, it shall even be for briers and thorns.
17807	686	24	With arrows and with bows shall men come thither; because all the land shall become briers and thorns.
17808	686	25	And on all hills that shall be digged with the mattock, there shall not come thither the fear of briers and thorns: but it shall be for the sending forth of oxen, and for the treading of lesser cattle.
17809	687	1	MOREOVER the LORD said unto me, Take thee a great roll, and write in it with a man's pen concerning Maher-shalal-hash-baz.
17810	687	2	And I took unto me faithful witnesses to record, Uriah the priest, and Zechariah the son of Jeberechiah.
17811	687	3	And I went unto the prophetess; and she conceived, and bare a son. Then said the LORD to me, Call his name Maher-shalal-hash-baz.
17812	687	4	For before the child shall have knowledge to cry, My father, and my mother, the riches of Damascus and the spoil of Samaria shall be taken away before the king of Assyria.
17813	687	5	The LORD spake also unto me again, saying,
17814	687	6	Forasmuch as this people refuseth the waters of Shiloah that go softly, and rejoice in Rezin and Remaliah's son;
17815	687	7	Now therefore, behold, the Lord bringeth up upon them the waters of the river, strong and many, even the king of Assyria, and all his glory: and he shall come up over all his channels, and go over all his banks:
17816	687	8	And he shall pass through Judah; he shall overflow and go over, he shall reach even to the neck; and the stretching out of his wings shall fill the breadth of thy land, O Immanuel.
17817	687	9	Associate yourselves, O ye people, and ye shall be broken in pieces; and give ear, all ye of far countries: gird yourselves, and ye shall be broken in pieces; gird yourselves, and ye shall be broken in pieces.
17818	687	10	Take counsel together, and it shall come to nought; speak the word, and it shall not stand: for God is with us.
17819	687	11	For the LORD spake thus to me with a strong hand, and instructed me that I should not walk in the way of this people, saying,
17820	687	12	Say ye not, A confederacy, to all them to whom this people shall say, A confederacy; neither fear ye their fear, nor be afraid.
17821	687	13	Sanctify the LORD of hosts himself; and let him be your fear, and let him be your dread.
17822	687	14	And he shall be for a sanctuary; but for a stone of stumbling and for a rock of offence to both the houses of Israel, for a gin and for a snare to the inhabitants of Jerusalem.
17823	687	15	And many among them shall stumble, and fall, and be broken, and be snared, and be taken.
17824	687	16	Bind up the testimony, seal the law among my disciples.
17825	687	17	And I will wait upon the LORD, that hideth his face from the house of Jacob, and I will look for him.
17826	687	18	Behold, I and the children whom the LORD hath given me are for signs and for wonders in Israel from the LORD of hosts, which dwelleth in mount Zion.
17827	687	19	And when they shall say unto you, Seek unto them that have familiar spirits, and unto wizards that peep, and that mutter: should not a people seek unto their God? for the living to the dead?
17828	687	20	To the law and to the testimony: if they speak not according to this word, it is because there is no light in them.
17829	687	21	And they shall pass through it, hardly bestead and hungry: and it shall come to pass, that when they shall be hungry, they shall fret themselves, and curse their king and their God, and look upward.
17830	687	22	And they shall look unto the earth; and behold trouble and darkness, dimness of anguish; and they shall be driven to darkness.
17831	688	1	NEVERTHELESS the dimness shall not be such as was in her vexation, when at the first he lightly afflicted the land of Zebulun and the land of Naphtali, and afterward did more grievously afflict her by the way of the sea, beyond Jordan, in Galilee of the nations.
17832	688	2	The people that walked in darkness have seen a great light: they that dwell in the land of the shadow of death, upon them hath the light shined.
17833	688	3	Thou hast multiplied the nation, and not increased the joy: they joy before thee according to the joy in harvest, and as men rejoice when they divide the spoil.
17834	688	4	For thou hast broken the yoke of his burden, and the staff of his shoulder, the rod of his oppressor, as in the day of Midian.
17835	688	5	For every battle of the warrior is with confused noise, and garments rolled in blood; but this shall be with burning and fuel of fire.
17836	688	6	For unto us a child is born, unto us a son is given: and the government shall be upon his shoulder: and his name shall be called Wonderful, Counsellor, The mighty God, The everlasting Father, The Prince of Peace.
17837	688	7	Of the increase of his government and peace there shall be no end, upon the throne of David, and upon his kingdom, to order it, and to establish it with judgment and with justice from henceforth even for ever. The zeal of the LORD of hosts will perform this.
17838	688	8	The Lord sent a word into Jacob, and it hath lighted upon Israel.
17839	688	9	And all the people shall know, even Ephraim and the inhabitant of Samaria, that say in the pride and stoutness of heart,
17840	688	10	The bricks are fallen down, but we will build with hewn stones: the sycomores are cut down, but we will change them into cedars.
17841	688	11	Therefore the LORD shall set up the adversaries of Rezin against him, and join his enemies together;
17842	688	12	The Syrians before, and the Philistines behind; and they shall devour Israel with open mouth. For all this his anger is not turned away, but his hand is stretched out still.
17843	688	13	For the people turneth not unto him that smiteth them, neither do they seek the LORD of hosts.
17844	688	14	Therefore the LORD will cut off from Israel head and tail, branch and rush, in one day.
17845	688	15	The ancient and honourable, he is the head; and the prophet that teacheth lies, he is the tail.
17846	688	16	For the leaders of this people cause them to err; and they that are led of them are destroyed.
17847	688	17	Therefore the Lord shall have no joy in their young men, neither shall have mercy on their fatherless and widows: for every one is an hypocrite and an evildoer, and every mouth speaketh folly. For all this his anger is not turned away, but his hand is stretched out still.
17848	688	18	For wickedness burneth as the fire: it shall devour the briers and thorns, and shall kindle in the thickets of the forest, and they shall mount up like the lifting up of smoke.
17849	688	19	Through the wrath of the LORD of hosts is the land darkened, and the people shall be as the fuel of the fire: no man shall spare his brother.
17850	688	20	And he shall snatch on the right hand, and be hungry; and he shall eat on the left hand, and they shall not be satisfied: they shall eat every man the flesh of his own arm:
17851	688	21	Manasseh, Ephraim; and Ephraim, Manasseh: and they together shall be against Judah. For all this his anger is not turned away, but his hand is stretched out still.
17852	689	1	WOE unto them that decree unrighteous decrees, and that write grievousness which they have prescribed;
17853	689	2	To turn aside the needy from judgment, and to take away the right from the poor of my people, that widows may be their prey, and that they may rob the fatherless!
17854	689	3	And what will ye do in the day of visitation, and in the desolation which shall come from far? to whom will ye flee for help? and where will ye leave your glory?
17855	689	4	Without me they shall bow down under the prisoners, and they shall fall under the slain. For all this his anger is not turned away, but his hand is stretched out still.
17856	689	5	O Assyrian, the rod of mine anger, and the staff in their hand is mine indignation.
17857	689	6	I will send him against an hypocritical nation, and against the people of my wrath will I give him a charge, to take the spoil, and to take the prey, and to tread them down like the mire of the streets.
17858	689	7	Howbeit he meaneth not so, neither doth his heart think so; but it is in his heart to destroy and cut off nations not a few.
17859	689	8	For he saith, Are not my princes altogether kings?
17860	689	9	Is not Calno as Carchemish? is not Hamath as Arpad? is not Samaria as Damascus?
17861	689	10	As my hand hath found the kingdoms of the idols, and whose graven images did excel them of Jerusalem and of Samaria;
17862	689	11	Shall I not, as I have done unto Samaria and her idols, so do to Jerusalem and her idols?
17863	689	12	Wherefore it shall come to pass, that when the Lord hath performed his whole work upon mount Zion and on Jerusalem, I will punish the fruit of the stout heart of the king of Assyria, and the glory of his high looks.
17864	689	13	For he saith, By the strength of my hand I have done it, and by my wisdom; for I am prudent: and I have removed the bounds of the people, and have robbed their treasures, and I have put down the inhabitants like a valiant man:
17865	689	14	And my hand hath found as a nest the riches of the people: and as one gathereth eggs that are left, have I gathered all the earth; and there was none that moved the wing, or opened the mouth, or peeped.
17866	689	15	Shall the axe boast itself against him that heweth therewith? or shall the saw magnify itself against him that shaketh it? as if the rod should shake itself against them that lift it up, or as if the staff should lift up itself, as if it were no wood.
17867	689	16	Therefore shall the Lord, the Lord of hosts, send among his fat ones leanness; and under his glory he shall kindle a burning like the burning of a fire.
17868	689	17	And the light of Israel shall be for a fire, and his Holy One for a flame: and it shall burn and devour his thorns and his briers in one day;
17869	689	18	And shall consume the glory of his forest, and of his fruitful field, both soul and body: and they shall be as when a standardbearer fainteth.
17870	689	19	And the rest of the trees of his forest shall be few, that a child may write them.
17871	689	20	And it shall come to pass in that day, that the remnant of Israel, and such as are escaped of the house of Jacob, shall no more again stay upon him that smote them; but shall stay upon the LORD, the Holy One of Israel, in truth.
17872	689	21	The remnant shall return, even the remnant of Jacob, unto the mighty God.
17873	689	22	For though thy people Israel be as the sand of the sea, yet a remnant of them shall return: the consumption decreed shall overflow with righteousness.
17874	689	23	For the Lord GOD of hosts shall make a consumption, even determined, in the midst of all the land.
17875	689	24	Therefore thus saith the Lord GOD of hosts, O my people that dwellest in Zion, be not afraid of the Assyrian: he shall smite thee with a rod, and shall lift up his staff against thee, after the manner of Egypt.
17876	689	25	For yet a very little while, and the indignation shall cease, and mine anger in their destruction.
17877	689	26	And the LORD of hosts shall stir up a scourge for him according to the slaughter of Midian at the rock of Oreb: and as his rod was upon the sea, so shall he lift it up after the manner of Egypt.
17878	689	27	And it shall come to pass in that day, that his burden shall be taken away from off thy shoulder, and his yoke from off thy neck, and the yoke shall be destroyed because of the anointing.
17879	689	28	He is come to Aiath, he is passed to Migron; at Michmash he hath laid up his carriages:
17880	689	29	They are gone over the passage: they have taken up their lodging at Geba; Ramah is afraid; Gibeah of Saul is fled.
17881	689	30	Lift up thy voice, O daughter of Gallim: cause it to be heard unto Laish, O poor Anathoth.
17882	689	31	Madmenah is removed; the inhabitants of Gebim gather themselves to flee.
17883	689	32	As yet shall he remain at Nob that day: he shall shake his hand against the mount of the daughter of Zion, the hill of Jerusalem.
17884	689	33	Behold, the Lord, the LORD of hosts, shall lop the bough with terror: and the high ones of stature shall be hewn down, and the haughty shall be humbled.
17885	689	34	And he shall cut down the thickets of the forest with iron, and Lebanon shall fall by a mighty one.
17886	690	1	AND there shall come forth a rod out of the stem of Jesse, and a Branch shall grow out of his roots:
17887	690	2	And the spirit of the LORD shall rest upon him, the spirit of wisdom and understanding, the spirit of counsel and might, the spirit of knowledge and of the fear of the LORD;
17888	690	3	And shall make him of quick understanding in the fear of the LORD: and he shall not judge after the sight of his eyes, neither reprove after the hearing of his ears:
17889	690	4	But with righteousness shall he judge the poor, and reprove with equity for the meek of the earth: and he shall smite the earth with the rod of his mouth, and with the breath of his lips shall he slay the wicked.
17890	690	5	And righteousness shall be the girdle of his loins, and faithfulness the girdle of his reins.
17891	690	6	The wolf also shall dwell with the lamb, and the leopard shall lie down with the kid; and the calf and the young lion and the fatling together; and a little child shall lead them.
17892	690	7	And the cow and the bear shall feed; their young ones shall lie down together: and the lion shall eat straw like the ox.
17893	690	8	And the sucking child shall play on the hole of the asp, and the weaned child shall put his hand on the cockatrice' den.
17894	690	9	They shall not hurt nor destroy in all my holy mountain: for the earth shall be full of the knowledge of the LORD, as the waters cover the sea.
17895	690	10	And in that day there shall be a root of Jesse, which shall stand for an ensign of the people; to it shall the Gentiles seek: and his rest shall be glorious.
17896	690	11	And it shall come to pass in that day, that the Lord shall set his hand again the second time to recover the remnant of his people, which shall be left, from Assyria, and from Egypt, and from Pathros, and from Cush, and from Elam, and from Shinar, and from Hamath, and from the islands of the sea.
17897	690	12	And he shall set up an ensign for the nations, and shall assemble the outcasts of Israel, and gather together the dispersed of Judah from the four corners of the earth.
17898	690	13	The envy also of Ephraim shall depart, and the adversaries of Judah shall be cut off: Ephraim shall not envy Judah, and Judah shall not vex Ephraim.
17899	690	14	But they shall fly upon the shoulders of the Philistines toward the west; they shall spoil them of the east together: they shall lay their hand upon Edom and Moab; and the children of Ammon shall obey them.
17900	690	15	And the LORD shall utterly destroy the tongue of the Egyptian sea; and with his mighty wind shall he shake his hand over the river, and shall smite it in the seven streams, and make men go over dryshod.
17901	690	16	And there shall be an highway for the remnant of his people, which shall be left, from Assyria; like as it was to Israel in the day that he came up out of the land of Egypt.
17902	691	1	AND in that day thou shalt say, O LORD, I will praise thee: though thou wast angry with me, thine anger is turned away, and thou comfortedst me.
17903	691	2	Behold, God is my salvation; I will trust, and not be afraid: for the LORD JEHOVAH is my strength and my song; he also is become my salvation.
17904	691	3	Therefore with joy shall ye draw water out of the wells of salvation.
17905	691	4	And in that day shall ye say, Praise the LORD, call upon his name, declare his doings among the people, make mention that his name is exalted.
17906	691	5	Sing unto the LORD; for he hath done excellent things: this is known in all the earth.
17907	691	6	Cry out and shout, thou inhabitant of Zion: for great is the Holy One of Israel in the midst of thee.
17908	692	1	THE burden of Babylon, which Isaiah the son of Amoz did see.
17909	692	2	Lift ye up a banner upon the high mountain, exalt the voice unto them, shake the hand, that they may go into the gates of the nobles.
17910	692	3	I have commanded my sanctified ones, I have also called my mighty ones for mine anger, even them that rejoice in my highness.
17911	692	4	The noise of a multitude in the mountains, like as of a great people; a tumultuous noise of the kingdoms of nations gathered together: the LORD of hosts mustereth the host of the battle.
17912	692	5	They come from a far country, from the end of heaven, even the LORD, and the weapons of his indignation, to destroy the whole land.
17913	692	6	Howl ye; for the day of the LORD is at hand; it shall come as a destruction from the Almighty.
17914	692	7	Therefore shall all hands be faint, and every man's heart shall melt:
17915	692	8	And they shall be afraid: pangs and sorrows shall take hold of them; they shall be in pain as a woman that travaileth: they shall be amazed one at another; their faces shall be as flames.
17916	692	9	Behold, the day of the LORD cometh, cruel both with wrath and fierce anger, to lay the land desolate: and he shall destroy the sinners thereof out of it.
17917	692	10	For the stars of heaven and the constellations thereof shall not give their light: the sun shall be darkened in his going forth, and the moon shall not cause her light to shine.
17918	692	11	And I will punish the world for their evil, and the wicked for their iniquity; and I will cause the arrogancy of the proud to cease, and will lay low the haughtiness of the terrible.
17919	692	12	I will make a man more precious than fine gold; even a man than the golden wedge of Ophir.
17920	692	13	Therefore I will shake the heavens, and the earth shall remove out of her place, in the wrath of the LORD of hosts, and in the day of his fierce anger.
17921	692	14	And it shall be as the chased roe, and as a sheep that no man taketh up: they shall every man turn to his own people, and flee every one into his own land.
17922	692	15	Every one that is found shall be thrust through; and every one that is joined unto them shall fall by the sword.
17923	692	16	Their children also shall be dashed to pieces before their eyes; their houses shall be spoiled, and their wives ravished.
17924	692	17	Behold, I will stir up the Medes against them, which shall not regard silver; and as for gold, they shall not delight in it.
17925	692	18	Their bows also shall dash the young men to pieces; and they shall have no pity on the fruit of the womb; their eye shall not spare children.
17926	692	19	And Babylon, the glory of kingdoms, the beauty of the Chaldees' excellency, shall be as when God overthrew Sodom and Gomorrah.
17927	692	20	It shall never be inhabited, neither shall it be dwelt in from generation to generation: neither shall the Arabian pitch tent there; neither shall the shepherds make their fold there.
17928	692	21	But wild beasts of the desert shall lie there; and their houses shall be full of doleful creatures; and owls shall dwell there, and satyrs shall dance there.
17929	692	22	And the wild beasts of the islands shall cry in their desolate houses, and dragons in their pleasant palaces: and her time is near to come, and her days shall not be prolonged.
17930	693	1	FOR the LORD will have mercy on Jacob, and will yet choose Israel, and set them in their own land: and the strangers shall be joined with them, and they shall cleave to the house of Jacob.
17931	693	2	And the people shall take them, and bring them to their place: and the house of Israel shall possess them in the land of the LORD for servants and handmaids: and they shall take them captives, whose captives they were; and they shall rule over their oppressors.
17932	693	3	And it shall come to pass in the day that the LORD shall give thee rest from thy sorrow, and from thy fear, and from the hard bondage wherein thou wast made to serve,
17933	693	4	That thou shalt take up this proverb against the king of Babylon, and say, How hath the oppressor ceased! the golden city ceased!
17934	693	5	The LORD hath broken the staff of the wicked, and the sceptre of the rulers.
17935	693	6	He who smote the people in wrath with a continual stroke, he that ruled the nations in anger, is persecuted, and none hindereth.
17936	693	7	The whole earth is at rest, and is quiet: they break forth into singing.
17937	693	8	Yea, the fir trees rejoice at thee, and the cedars of Lebanon, saying, Since thou art laid down, no feller is come up against us.
17938	693	9	Hell from beneath is moved for thee to meet thee at thy coming: it stirreth up the dead for thee, even all the chief ones of the earth; it hath raised up from their thrones all the kings of the nations.
17939	693	10	All they shall speak and say unto thee, Art thou also become weak as we? art thou become like unto us?
17940	693	11	Thy pomp is brought down to the grave, and the noise of thy viols: the worm is spread under thee, and the worms cover thee.
17941	693	12	How art thou fallen from heaven, O Lucifer, son of the morning! how art thou cut down to the ground, which didst weaken the nations!
17942	693	13	For thou hast said in thine heart, I will ascend into heaven, I will exalt my throne above the stars of God: I will sit also upon the mount of the congregation, in the sides of the north:
17943	693	14	I will ascend above the heights of the clouds; I will be like the most High.
17944	693	15	Yet thou shalt be brought down to hell, to the sides of the pit.
17945	693	16	They that see thee shall narrowly look upon thee, and consider thee, saying, Is this the man that made the earth to tremble, that did shake kingdoms;
17946	693	17	That made the world as a wilderness, and destroyed the cities thereof; that opened not the house of his prisoners?
17947	693	18	All the kings of the nations, even all of them, lie in glory, every one in his own house.
17948	693	19	But thou art cast out of thy grave like an abominable branch, and as the raiment of those that are slain, thrust through with a sword, that go down to the stones of the pit; as a carcase trodden under feet.
17949	693	20	Thou shalt not be joined with them in burial, because thou hast destroyed thy land, and slain thy people: the seed of evildoers shall never be renowned.
17950	693	21	Prepare slaughter for his children for the iniquity of their fathers; that they do not rise, nor possess the land, nor fill the face of the world with cities.
17951	693	22	For I will rise up against them, saith the LORD of hosts, and cut off from Babylon the name, and remnant, and son, and nephew, saith the LORD.
17952	693	23	I will also make it a possession for the bittern, and pools of water: and I will sweep it with the besom of destruction, saith the LORD of hosts.
17953	693	24	The LORD of hosts hath sworn, saying, Surely as I have thought, so shall it come to pass; and as I have purposed, so shall it stand:
17954	693	25	That I will break the Assyrian in my land, and upon my mountains tread him under foot: then shall his yoke depart from off them, and his burden depart from off their shoulders.
17955	693	26	This is the purpose that is purposed upon the whole earth: and this is the hand that is stretched out upon all the nations.
17956	693	27	For the LORD of hosts hath purposed, and who shall disannul it? and his hand is stretched out, and who shall turn it back?
17957	693	28	In the year that king Ahaz died was this burden.
17958	693	29	Rejoice not thou, whole Palestina, because the rod of him that smote thee is broken: for out of the serpent's root shall come forth a cockatrice, and his fruit shall be a fiery flying serpent.
17959	693	30	And the firstborn of the poor shall feed, and the needy shall lie down in safety: and I will kill thy root with famine, and he shall slay thy remnant.
17960	693	31	Howl, O gate; cry, O city; thou, whole Palestina, art dissolved: for there shall come from the north a smoke, and none shall be alone in his appointed times.
17961	693	32	What shall one then answer the messengers of the nation? That the LORD hath founded Zion, and the poor of his people shall trust in it.
17962	694	1	THE burden of Moab. Because in the night Ar of Moab is laid waste, and brought to silence; because in the night Kir of Moab is laid waste, and brought to silence;
17963	694	2	He is gone up to Bajith, and to Dibon, the high places, to weep: Moab shall howl over Nebo, and over Medeba: on all their heads shall be baldness, and every beard cut off.
17964	694	3	In their streets they shall gird themselves with sackcloth: on the tops of their houses, and in their streets, every one shall howl, weeping abundantly.
17965	694	4	And Heshbon shall cry, and Elealeh: their voice shall be heard even unto Jahaz: therefore the armed soldiers of Moab shall cry out; his life shall be grievous unto him.
17966	694	5	My heart shall cry out for Moab; his fugitives shall flee unto Zoar, an heifer of three years old: for by the mounting up of Luhith with weeping shall they go it up; for in the way of Horonaim they shall raise up a cry of destruction.
17967	694	6	For the waters of Nimrim shall be desolate: for the hay is withered away, the grass faileth, there is no green thing.
17968	694	7	Therefore the abundance they have gotten, and that which they have laid up, shall they carry away to the brook of the willows.
17969	694	8	For the cry is gone round about the borders of Moab; the howling thereof unto Eglaim, and the howling thereof unto Beer-elim.
17970	694	9	For the waters of Dimon shall be full of blood: for I will bring more upon Dimon, lions upon him that escapeth of Moab, and upon the remnant of the land.
17971	695	1	SEND ye the lamb to the ruler of the land from Sela to the wilderness, unto the mount of the daughter of Zion.
17972	695	2	For it shall be, that, as a wandering bird cast out of the nest, so the daughters of Moab shall be at the fords of Arnon.
17973	695	3	Take counsel, execute judgment; make thy shadow as the night in the midst of the noonday; hide the outcasts; bewray not him that wandereth.
17974	695	4	Let mine outcasts dwell with thee, Moab; be thou a covert to them from the face of the spoiler: for the extortioner is at an end, the spoiler ceaseth, the oppressors are consumed out of the land.
17975	695	5	And in mercy shall the throne be established: and he shall sit upon it in truth in the tabernacle of David, judging, and seeking judgment, and hasting righteousness.
17976	695	6	We have heard of the pride of Moab; he is very proud: even of his haughtiness, and his pride, and his wrath: but his lies shall not be so.
17977	695	7	Therefore shall Moab howl for Moab, every one shall howl: for the foundations of Kir-hareseth shall ye mourn; surely they are stricken.
17978	695	8	For the fields of Heshbon languish, and the vine of Sibmah: the lords of the heathen have broken down the principal plants thereof, they are come even unto Jazer, they wandered through the wilderness: her branches are stretched out, they are gone over the sea.
17979	695	9	Therefore I will bewail with the weeping of Jazer the vine of Sibmah: I will water thee with my tears, O Heshbon, and Elealeh: for the shouting for thy summer fruits and for thy harvest is fallen.
17980	695	10	And gladness is taken away, and joy out of the plentiful field; and in the vineyards there shall be no singing, neither shall there be shouting: the treaders shall tread out no wine in their presses; I have made their vintage shouting to cease.
17981	695	11	Wherefore my bowels shall sound like an harp for Moab, and mine inward parts for Kir-haresh.
17982	695	12	And it shall come to pass, when it is seen that Moab is weary on the high place, that he shall come to his sanctuary to pray; but he shall not prevail.
17983	695	13	This is the word that the LORD hath spoken concerning Moab since that time.
17984	695	14	But now the LORD hath spoken, saying, Within three years, as the years of an hireling, and the glory of Moab shall be contemned, with all that great multitude; and the remnant shall be very small and feeble.
17985	696	1	THE burden of Damascus. Behold, Damascus is taken away from being a city, and it shall be a ruinous heap.
17986	696	2	The cities of Aroer are forsaken: they shall be for flocks, which shall lie down, and none shall make them afraid.
17987	696	3	The fortress also shall cease from Ephraim, and the kingdom from Damascus, and the remnant of Syria: they shall be as the glory of the children of Israel, saith the LORD of hosts.
17988	696	4	And in that day it shall come to pass, that the glory of Jacob shall be made thin, and the fatness of his flesh shall wax lean.
17989	696	5	And it shall be as when the harvestman gathereth the corn, and reapeth the ears with his arm; and it shall be as he that gathereth ears in the valley of Rephaim.
17990	696	6	Yet gleaning grapes shall be left in it, as the shaking of an olive tree, two or three berries in the top of the uppermost bough, four or five in the outmost fruitful branches thereof, saith the LORD God of Israel.
17991	696	7	At that day shall a man look to his Maker, and his eyes shall have respect to the Holy One of Israel.
17992	696	8	And he shall not look to the altars, the work of his hands, neither shall respect that which his fingers have made, either the groves, or the images.
17993	696	9	In that day shall his strong cities be as a forsaken bough, and an uppermost branch, which they left because of the children of Israel: and there shall be desolation.
17994	696	10	Because thou hast forgotten the God of thy salvation, and hast not been mindful of the rock of thy strength, therefore shalt thou plant pleasant plants, and shalt set it with strange slips:
17995	696	11	In the day shalt thou make thy plant to grow, and in the morning shalt thou make thy seed to flourish: but the harvest shall be a heap in the day of grief and of desperate sorrow.
17996	696	12	Woe to the multitude of many people, which make a noise like the noise of the seas; and to the rushing of nations, that make a rushing like the rushing of mighty waters!
17997	696	13	The nations shall rush like the rushing of many waters: but God shall rebuke them, and they shall flee far off, and shall be chased as the chaff of the mountains before the wind, and like a rolling thing before the whirlwind.
17998	696	14	And behold at eveningtide trouble; and before the morning he is not. This is the portion of them that spoil us, and the lot of them that rob us.
17999	697	1	WOE to the land shadowing with wings, which is beyond the rivers of Ethiopia:
18000	697	2	That sendeth ambassadors by the sea, even in vessels of bulrushes upon the waters, saying, Go, ye swift messengers, to a nation scattered and peeled, to a people terrible from their beginning hitherto; a nation meted out and trodden down, whose land the rivers have spoiled!
18001	697	3	All ye inhabitants of the world, and dwellers on the earth, see ye, when he lifteth up an ensign on the mountains; and when he bloweth a trumpet, hear ye.
18002	697	4	For so the LORD said unto me, I will take my rest, and I will consider in my dwelling place like a clear heat upon herbs, and like a cloud of dew in the heat of harvest.
18003	697	5	For afore the harvest, when the bud is perfect, and the sour grape is ripening in the flower, he shall both cut off the sprigs with pruning hooks, and take away and cut down the branches.
18004	697	6	They shall be left together unto the fowls of the mountains, and to the beasts of the earth: and the fowls shall summer upon them, and all the beasts of the earth shall winter upon them.
18005	697	7	In that time shall the present be brought unto the LORD of hosts of a people scattered and peeled, and from a people terrible from their beginning hitherto; a nation meted out and trodden under foot, whose land the rivers have spoiled, to the place of the name of the LORD of hosts, the mount Zion.
18006	698	1	THE burden of Egypt. Behold, the LORD rideth upon a swift cloud, and shall come into Egypt: and the idols of Egypt shall be moved at his presence, and the heart of Egypt shall melt in the midst of it.
18007	698	2	And I will set the Egyptians against the Egyptians: and they shall fight every one against his brother, and every one against his neighbour; city against city, and kingdom against kingdom.
18008	698	3	And the spirit of Egypt shall fail in the midst thereof; and I will destroy the counsel thereof: and they shall seek to the idols, and to the charmers, and to them that have familiar spirits, and to the wizards.
18009	698	4	And the Egyptians will I give over into the hand of a cruel lord; and a fierce king shall rule over them, saith the Lord, the LORD of hosts.
18010	698	5	And the waters shall fail from the sea, and the river shall be wasted and dried up.
18011	698	6	And they shall turn the rivers far away; and the brooks of defence shall be emptied and dried up: the reeds and flags shall wither.
18012	698	7	The paper reeds by the brooks, by the mouth of the brooks, and every thing sown by the brooks, shall wither, be driven away, and be no more.
18013	698	8	The fishers also shall mourn, and all they that cast angle into the brooks shall lament, and they that spread nets upon the waters shall languish.
18014	698	9	Moreover they that work in fine flax, and they that weave networks, shall be confounded.
18015	698	10	And they shall be broken in the purposes thereof, all that make sluices and ponds for fish.
18016	698	11	Surely the princes of Zoan are fools, the counsel of the wise counsellors of Pharaoh is become brutish: how say ye unto Pharaoh, I am the son of the wise, the son of ancient kings?
18017	698	12	Where are they? where are thy wise men? and let them tell thee now, and let them know what the LORD of hosts hath purposed upon Egypt.
18018	698	13	The princes of Zoan are become fools, the princes of Noph are deceived; they have also seduced Egypt, even they that are the stay of the tribes thereof.
18019	698	14	The LORD hath mingled a perverse spirit in the midst thereof: and they have caused Egypt to err in every work thereof, as a drunken man staggereth in his vomit.
18020	698	15	Neither shall there be any work for Egypt, which the head or tail, branch or rush, may do.
18021	698	16	In that day shall Egypt be like unto women: and it shall be afraid and fear because of the shaking of the hand of the LORD of hosts, which he shaketh over it.
18022	698	17	And the land of Judah shall be a terror unto Egypt, every one that maketh mention thereof shall be afraid in himself, because of the counsel of the LORD of hosts, which he hath determined against it.
18023	698	18	In that day shall five cities in the land of Egypt speak the language of Canaan, and swear to the LORD of hosts; one shall be called, The city of destruction.
18024	698	19	In that day shall there be an altar to the LORD in the midst of the land of Egypt, and a pillar at the border thereof to the LORD.
18025	698	20	And it shall be for a sign and for a witness unto the LORD of hosts in the land of Egypt: for they shall cry unto the LORD because of the oppressors, and he shall send them a saviour, and a great one, and he shall deliver them.
18026	698	21	And the LORD shall be known to Egypt, and the Egyptians shall know the LORD in that day, and shall do sacrifice and oblation; yea, they shall vow a vow unto the LORD, and perform it.
18027	698	22	And the LORD shall smite Egypt: he shall smite and heal it: and they shall return even to the LORD, and he shall be intreated of them, and shall heal them.
18028	698	23	In that day shall there be a highway out of Egypt to Assyria, and the Assyrian shall come into Egypt, and the Egyptian into Assyria, and the Egyptians shall serve with the Assyrians.
18029	698	24	In that day shall Israel be the third with Egypt and with Assyria, even a blessing in the midst of the land:
18030	698	25	Whom the LORD of hosts shall bless, saying, Blessed be Egypt my people, and Assyria the work of my hands, and Israel mine inheritance.
18031	699	1	IN the year that Tartan came unto Ashdod, (when Sargon the king of Assyria sent him,) and fought against Ashdod, and took it;
18032	699	2	At the same time spake the LORD by Isaiah the son of Amoz, saying, Go and loose the sackcloth from off thy loins, and put off thy shoe from thy foot. And he did so, walking naked and barefoot.
18033	699	3	And the LORD said, Like as my servant Isaiah hath walked naked and barefoot three years for a sign and wonder upon Egypt and upon Ethiopia;
18034	699	4	So shall the king of Assyria lead away the Egyptians prisoners, and the Ethiopians captives, young and old, naked and barefoot, even with their buttocks uncovered, to the shame of Egypt.
18035	699	5	And they shall be afraid and ashamed of Ethiopia their expectation, and of Egypt their glory.
18036	699	6	And the inhabitant of this isle shall say in that day, Behold, such is our expectation, whither we flee for help to be delivered from the king of Assyria: and how shall we escape?
18037	700	1	THE burden of the desert of the sea. As whirlwinds in the south pass through; so it cometh from the desert, from a terrible land.
18038	700	2	A grievous vision is declared unto me; the treacherous dealer dealeth treacherously, and the spoiler spoileth. Go up, O Elam: besiege, O Media; all the sighing thereof have I made to cease.
18039	700	3	Therefore are my loins filled with pain: pangs have taken hold upon me, as the pangs of a woman that travaileth: I was bowed down at the hearing of it; I was dismayed at the seeing of it.
18040	700	4	My heart panted, fearfulness affrighted me: the night of my pleasure hath he turned into fear unto me.
18041	700	5	Prepare the table, watch in the watchtower, eat, drink: arise, ye princes, and anoint the shield.
18042	700	6	For thus hath the Lord said unto me, Go, set a watchman, let him declare what he seeth.
18043	700	7	And he saw a chariot with a couple of horsemen, a chariot of asses, and a chariot of camels; and he hearkened diligently with much heed:
18044	700	8	And he cried, A lion: My lord, I stand continually upon the watchtower in the daytime, and I am set in my ward whole nights:
18045	700	9	And, behold, here cometh a chariot of men, with a couple of horsemen. And he answered and said, Babylon is fallen, is fallen; and all the graven images of her gods he hath broken unto the ground.
18046	700	10	O my threshing, and the corn of my floor: that which I have heard of the LORD of hosts, the God of Israel, have I declared unto you.
18047	700	11	The burden of Dumah. He calleth to me out of Seir, Watchman, what of the night? Watchman, what of the night?
18048	700	12	The watchman said, The morning cometh, and also the night: if ye will enquire, enquire ye: return, come.
18049	700	13	The burden upon Arabia. In the forest in Arabia shall ye lodge, O ye travelling companies of Dedanim.
18050	700	14	The inhabitants of the land of Tema brought water to him that was thirsty, they prevented with their bread him that fled.
18051	700	15	For they fled from the swords, from the drawn sword, and from the bent bow, and from the grievousness of war.
18052	700	16	For thus hath the Lord said unto me, Within a year, according to the years of an hireling, and all the glory of Kedar shall fail:
18053	700	17	And the residue of the number of archers, the mighty men of the children of Kedar, shall be diminished: for the LORD God of Israel hath spoken it.
18054	701	1	THE burden of the valley of vision. What aileth thee now, that thou art wholly gone up to the housetops?
18055	701	2	Thou that art full of stirs, a tumultuous city, a joyous city: thy slain men are not slain with the sword, nor dead in battle.
18056	701	3	All thy rulers are fled together, they are bound by the archers: all that are found in thee are bound together, which have fled from far.
18057	701	4	Therefore said I, Look away from me; I will weep bitterly, labour not to comfort me, because of the spoiling of the daughter of my people.
18058	701	5	For it is a day of trouble, and of treading down, and of perplexity by the Lord GOD of hosts in the valley of vision, breaking down the walls, and of crying to the mountains.
18059	701	6	And Elam bare the quiver with chariots of men and horsemen, and Kir uncovered the shield.
18060	701	7	And it shall come to pass, that thy choicest valleys shall be full of chariots, and the horsemen shall set themselves in array at the gate.
18061	701	8	And he discovered the covering of Judah, and thou didst look in that day to the armour of the house of the forest.
18062	701	9	Ye have seen also the breaches of the city of David, that they are many: and ye gathered together the waters of the lower pool.
18063	701	10	And ye have numbered the houses of Jerusalem, and the houses have ye broken down to fortify the wall.
18064	701	11	Ye made also a ditch between the two walls for the water of the old pool: but ye have not looked unto the maker thereof, neither had respect unto him that fashioned it long ago.
18065	701	12	And in that day did the Lord GOD of hosts call to weeping, and to mourning, and to baldness, and to girding with sackcloth:
18066	701	13	And behold joy and gladness, slaying oxen, and killing sheep, eating flesh, and drinking wine: let us eat and drink; for to morrow we shall die.
18067	701	14	And it was revealed in mine ears by the LORD of hosts, Surely this iniquity shall not be purged from you till ye die, saith the Lord GOD of hosts.
18068	701	15	Thus saith the Lord GOD of hosts, Go, get thee unto this treasurer, even unto Shebna, which is over the house, and say,
18069	701	16	What hast thou here? and whom hast thou here, that thou hast hewed thee out a sepulchre here, as he that heweth him out a sepulchre on high, and that graveth an habitation for himself in a rock?
18070	701	17	Behold, the LORD will carry thee away with a mighty captivity, and will surely cover thee.
18071	701	18	He will surely violently turn and toss thee like a ball into a large country: there shalt thou die, and there the chariots of thy glory shall be the shame of thy lord's house.
18072	701	19	And I will drive thee from thy station, and from thy state shall he pull thee down.
18073	701	20	And it shall come to pass in that day, that I will call my servant Eliakim the son of Hilkiah:
18074	701	21	And I will clothe him with thy robe, and strengthen him with thy girdle, and I will commit thy government into his hand: and he shall be a father to the inhabitants of Jerusalem, and to the house of Judah.
18075	701	22	And the key of the house of David will I lay upon his shoulder; so he shall open, and none shall shut; and he shall shut, and none shall open.
18076	701	23	And I will fasten him as a nail in a sure place; and he shall be for a glorious throne to his father's house.
18077	701	24	And they shall hang upon him all the glory of his father's house, the offspring and the issue, all vessels of small quantity, from the vessels of cups, even to all the vessels of flagons.
18078	701	25	In that day, saith the LORD of hosts, shall the nail that is fastened in the sure place be removed, and be cut down, and fall; and the burden that was upon it shall be cut off: for the LORD hath spoken it.
18079	702	1	THE burden of Tyre. Howl, ye ships of Tarshish; for it is laid waste, so that there is no house, no entering in: from the land of Chittim it is revealed to them.
18080	702	2	Be still, ye inhabitants of the isle; thou whom the merchants of Zidon, that pass over the sea, have replenished.
18081	702	3	And by great waters the seed of Sihor, the harvest of the river, is her revenue; and she is a mart of nations.
18082	702	4	Be thou ashamed, O Zidon: for the sea hath spoken, even the strength of the sea, saying, I travail not, nor bring forth children, neither do I nourish up young men, nor bring up virgins.
18083	702	5	As at the report concerning Egypt, so shall they be sorely pained at the report of Tyre.
18084	702	6	Pass ye over to Tarshish; howl, ye inhabitants of the isle.
18085	702	7	Is this your joyous city, whose antiquity is of ancient days? her own feet shall carry her afar off to sojourn.
18086	702	8	Who hath taken this counsel against Tyre, the crowning city, whose merchants are princes, whose traffickers are the honourable of the earth?
18087	702	9	The LORD of hosts hath purposed it, to stain the pride of all glory, and to bring into contempt all the honourable of the earth.
18088	702	10	Pass through thy land as a river, O daughter of Tarshish: there is no more strength.
18089	702	11	He stretched out his hand over the sea, he shook the kingdoms: the LORD hath given a commandment against the merchant city, to destroy the strong holds thereof.
18090	702	12	And he said, Thou shalt no more rejoice, O thou oppressed virgin, daughter of Zidon: arise, pass over to Chittim; there also shalt thou have no rest.
18091	702	13	Behold the land of the Chaldeans; this people was not, till the Assyrian founded it for them that dwell in the wilderness: they set up the towers thereof, they raised up the palaces thereof; and he brought it to ruin.
18092	702	14	Howl, ye ships of Tarshish: for your strength is laid waste.
18093	702	15	And it shall come to pass in that day, that Tyre shall be forgotten seventy years, according to the days of one king: after the end of seventy years shall Tyre sing as an harlot.
18094	702	16	Take an harp, go about the city, thou harlot that hast been forgotten; make sweet melody, sing many songs, that thou mayest be remembered.
18095	702	17	And it shall come to pass after the end of seventy years, that the LORD will visit Tyre, and she shall turn to her hire, and shall commit fornication with all the kingdoms of the world upon the face of the earth.
18096	702	18	And her merchandise and her hire shall be holiness to the LORD: it shall not be treasured nor laid up; for her merchandise shall be for them that dwell before the LORD, to eat sufficiently, and for durable clothing.
18097	703	1	BEHOLD, the LORD maketh the earth empty, and maketh it waste, and turneth it upside down, and scattereth abroad the inhabitants thereof.
18098	703	2	And it shall be, as with the people, so with the priest; as with the servant, so with his master; as with the maid, so with her mistress; as with the buyer, so with the seller; as with the lender, so with the borrower; as with the taker of usury, so with the giver of usury to him.
18099	703	3	The land shall be utterly emptied, and utterly spoiled: for the LORD hath spoken this word.
18100	703	4	The earth mourneth and fadeth away, the world languisheth and fadeth away, the haughty people of the earth do languish.
18101	703	5	The earth also is defiled under the inhabitants thereof; because they have transgressed the laws, changed the ordinance, broken the everlasting covenant.
18102	703	6	Therefore hath the curse devoured the earth, and they that dwell therein are desolate: therefore the inhabitants of the earth are burned, and few men left.
18103	703	7	The new wine mourneth, the vine languisheth, all the merryhearted do sigh.
18104	703	8	The mirth of tabrets ceaseth, the noise of them that rejoice endeth, the joy of the harp ceaseth.
18105	703	9	They shall not drink wine with a song; strong drink shall be bitter to them that drink it.
18106	703	10	The city of confusion is broken down: every house is shut up, that no man may come in.
18107	703	11	There is a crying for wine in the streets; all joy is darkened, the mirth of the land is gone.
18108	703	12	In the city is left desolation, and the gate is smitten with destruction.
18109	703	13	When thus it shall be in the midst of the land among the people, there shall be as the shaking of an olive tree, and as the gleaning grapes when the vintage is done.
18110	703	14	They shall lift up their voice, they shall sing for the majesty of the LORD, they shall cry aloud from the sea.
18111	703	15	Wherefore glorify ye the LORD in the fires, even the name of the LORD God of Israel in the isles of the sea.
18112	703	16	From the uttermost part of the earth have we heard songs, even glory to the righteous. But I said, My leanness, my leanness, woe unto me! the treacherous dealers have dealt treacherously; yea, the treacherous dealers have dealt very treacherously.
18113	703	17	Fear, and the pit, and the snare, are upon thee, O inhabitant of the earth.
18114	703	18	And it shall come to pass, that he who fleeth from the noise of the fear shall fall into the pit; and he that cometh up out of the midst of the pit shall be taken in the snare: for the windows from on high are open, and the foundations of the earth do shake.
18115	703	19	The earth is utterly broken down, the earth is clean dissolved, the earth is moved exceedingly.
18116	703	20	The earth shall reel to and fro like a drunkard, and shall be removed like a cottage; and the transgression thereof shall be heavy upon it; and it shall fall, and not rise again.
18117	703	21	And it shall come to pass in that day, that the LORD shall punish the host of the high ones that are on high, and the kings of the earth upon the earth.
18118	703	22	And they shall be gathered together, as prisoners are gathered in the pit, and shall be shut up in the prison, and after many days shall they be visited.
18119	703	23	Then the moon shall be confounded, and the sun ashamed, when the LORD of hosts shall reign in mount Zion, and in Jerusalem, and before his ancients gloriously.
18120	704	1	O LORD, thou art my God; I will exalt thee, I will praise thy name; for thou hast done wonderful things; thy counsels of old are faithfulness and truth.
18121	704	2	For thou hast made of a city an heap; of a defenced city a ruin: a palace of strangers to be no city; it shall never be built.
18122	704	3	Therefore shall the strong people glorify thee, the city of the terrible nations shall fear thee.
18123	704	4	For thou hast been a strength to the poor, a strength to the needy in his distress, a refuge from the storm, a shadow from the heat, when the blast of the terrible ones is as a storm against the wall.
18124	704	5	Thou shalt bring down the noise of strangers, as the heat in a dry place; even the heat with the shadow of a cloud: the branch of the terrible ones shall be brought low.
18125	704	6	And in this mountain shall the LORD of hosts make unto all people a feast of fat things, a feast of wines on the lees, of fat things full of marrow, of wines on the lees well refined.
18126	704	7	And he will destroy in this mountain the face of the covering cast over all people, and the vail that is spread over all nations.
18127	704	8	He will swallow up death in victory; and the Lord GOD will wipe away tears from off all faces; and the rebuke of his people shall he take away from off all the earth: for the LORD hath spoken it.
18128	704	9	And it shall be said in that day, Lo, this is our God; we have waited for him, and he will save us: this is the LORD; we have waited for him, we will be glad and rejoice in his salvation.
18129	704	10	For in this mountain shall the hand of the LORD rest, and Moab shall be trodden down under him, even as straw is trodden down for the dunghill.
18130	704	11	And he shall spread forth his hands in the midst of them, as he that swimmeth spreadeth forth his hands to swim: and he shall bring down their pride together with the spoils of their hands.
18131	704	12	And the fortress of the high fort of thy walls shall he bring down, lay low, and bring to the ground, even to the dust.
18132	705	1	IN that day shall this song be sung in the land of Judah; We have a strong city; salvation will God appoint for walls and bulwarks.
18133	705	2	Open ye the gates, that the righteous nation which keepeth the truth may enter in.
18134	705	3	Thou wilt keep him in perfect peace, whose mind is stayed on thee: because he trusteth in thee.
18135	705	4	Trust ye in the LORD for ever: for in the LORD JEHOVAH is everlasting strength:
18136	705	5	For he bringeth down them that dwell on high; the lofty city, he layeth it low; he layeth it low, even to the ground; he bringeth it even to the dust.
18137	705	6	The foot shall tread it down, even the feet of the poor, and the steps of the needy.
18138	705	7	The way of the just is uprightness: thou, most upright, dost weigh the path of the just.
18139	705	8	Yea, in the way of thy judgments, O LORD, have we waited for thee; the desire of our soul is to thy name, and to the remembrance of thee.
18140	705	9	With my soul have I desired thee in the night; yea, with my spirit within me will I seek thee early: for when thy judgments are in the earth, the inhabitants of the world will learn righteousness.
18141	705	10	Let favour be shewed to the wicked, yet will he not learn righteousness: in the land of uprightness will he deal unjustly, and will not behold the majesty of the LORD.
18142	705	11	LORD, when thy hand is lifted up, they will not see: but they shall see, and be ashamed for their envy at the people; yea, the fire of thine enemies shall devour them.
18143	705	12	LORD, thou wilt ordain peace for us: for thou also hast wrought all our works in us.
18144	705	13	O LORD our God, other lords beside thee have had dominion over us: but by thee only will we make mention of thy name.
18145	705	14	They are dead, they shall not live; they are deceased, they shall not rise: therefore hast thou visited and destroyed them, and made all their memory to perish.
18146	705	15	Thou hast increased the nation, O LORD, thou hast increased the nation: thou art glorified: thou hadst removed it far unto all the ends of the earth.
18147	705	16	LORD, in trouble have they visited thee, they poured out a prayer when thy chastening was upon them.
18148	705	17	Like as a woman with child, that draweth near the time of her delivery, is in pain, and crieth out in her pangs; so have we been in thy sight, O LORD.
18149	705	18	We have been with child, we have been in pain, we have as it were brought forth wind; we have not wrought any deliverance in the earth; neither have the inhabitants of the world fallen.
18150	705	19	Thy dead men shall live, together with my dead body shall they arise. Awake and sing, ye that dwell in dust: for thy dew is as the dew of herbs, and the earth shall cast out the dead.
18151	705	20	Come, my people, enter thou into thy chambers, and shut thy doors about thee: hide thyself as it were for a little moment, until the indignation be overpast.
18152	705	21	For, behold, the LORD cometh out of his place to punish the inhabitants of the earth for their iniquity: the earth also shall disclose her blood, and shall no more cover her slain.
18153	706	1	IN that day the LORD with his sore and great and strong sword shall punish leviathan the piercing serpent, even leviathan that crooked serpent; and he shall slay the dragon that is in the sea.
18154	706	2	In that day sing ye unto her, A vineyard of red wine.
18155	706	3	I the LORD do keep it; I will water it every moment: lest any hurt it, I will keep it night and day.
18156	706	4	Fury is not in me: who would set the briers and thorns against me in battle? I would go through them, I would burn them together.
18157	706	5	Or let him take hold of my strength, that he may make peace with me; and he shall make peace with me.
18158	706	6	He shall cause them that come of Jacob to take root: Israel shall blossom and bud, and fill the face of the world with fruit.
18159	706	7	Hath he smitten him, as he smote those that smote him? or is he slain according to the slaughter of them that are slain by him?
18160	706	8	In measure, when it shooteth forth, thou wilt debate with it: he stayeth his rough wind in the day of the east wind.
18161	706	9	By this therefore shall the iniquity of Jacob be purged; and this is all the fruit to take away his sin; when he maketh all the stones of the altar as chalkstones that are beaten in sunder, the groves and images shall not stand up.
18162	706	10	Yet the defenced city shall be desolate, and the habitation forsaken, and left like a wilderness: there shall the calf feed, and there shall he lie down, and consume the branches thereof.
18163	706	11	When the boughs thereof are withered, they shall be broken off: the women come, and set them on fire: for it is a people of no understanding: therefore he that made them will not have mercy on them, and he that formed them will shew them no favour.
18164	706	12	And it shall come to pass in that day, that the LORD shall beat off from the channel of the river unto the stream of Egypt, and ye shall be gathered one by one, O ye children of Israel.
18165	706	13	And it shall come to pass in that day, that the great trumpet shall be blown, and they shall come which were ready to perish in the land of Assyria, and the outcasts in the land of Egypt, and shall worship the LORD in the holy mount at Jerusalem.
18166	707	1	WOE to the crown of pride, to the drunkards of Ephraim, whose glorious beauty is a fading flower, which are on the head of the fat valleys of them that are overcome with wine!
18167	707	2	Behold, the Lord hath a mighty and strong one, which as a tempest of hail and a destroying storm, as a flood of mighty waters overflowing, shall cast down to the earth with the hand.
18168	707	3	The crown of pride, the drunkards of Ephraim, shall be trodden under feet:
18169	707	4	And the glorious beauty, which is on the head of the fat valley, shall be a fading flower, and as the hasty fruit before the summer; which when he that looketh upon it seeth, while it is yet in his hand he eateth it up.
18170	707	5	In that day shall the LORD of hosts be for a crown of glory, and for a diadem of beauty, unto the residue of his people,
18171	707	6	And for a spirit of judgment to him that sitteth in judgment, and for strength to them that turn the battle to the gate.
18172	707	7	But they also have erred through wine, and through strong drink are out of the way; the priest and the prophet have erred through strong drink, they are swallowed up of wine, they are out of the way through strong drink; they err in vision, they stumble in judgment.
18173	707	8	For all tables are full of vomit and filthiness, so that there is no place clean.
18174	707	9	Whom shall he teach knowledge? and whom shall he make to understand doctrine? them that are weaned from the milk, and drawn from the breasts.
18175	707	10	For precept must be upon precept, precept upon precept; line upon line, line upon line; here a little, and there a little:
18176	707	11	For with stammering lips and another tongue will he speak to this people.
18177	707	12	To whom he said, This is the rest wherewith ye may cause the weary to rest; and this is the refreshing: yet they would not hear.
18178	707	13	But the word of the LORD was unto them precept upon precept, precept upon precept; line upon line, line upon line; here a little, and there a little; that they might go, and fall backward, and be broken, and snared, and taken.
18179	707	14	Wherefore hear the word of the LORD, ye scornful men, that rule this people which is in Jerusalem.
18180	707	15	Because ye have said, We have made a covenant with death, and with hell are we at agreement; when the overflowing scourge shall pass through, it shall not come unto us: for we have made lies our refuge, and under falsehood have we hid ourselves:
18181	707	16	Therefore thus saith the Lord GOD, Behold, I lay in Zion for a foundation a stone, a tried stone, a precious corner stone, a sure foundation: he that believeth shall not make haste.
18182	707	17	Judgment also will I lay to the line, and righteousness to the plummet: and the hail shall sweep away the refuge of lies, and the waters shall overflow the hiding place.
18183	707	18	And your covenant with death shall be disannulled, and your agreement with hell shall not stand; when the overflowing scourge shall pass through, then ye shall be trodden down by it.
18184	707	19	From the time that it goeth forth it shall take you: for morning by morning shall it pass over, by day and by night: and it shall be a vexation only to understand the report.
18185	707	20	For the bed is shorter than that a man can stretch himself on it: and the covering narrower than that he can wrap himself in it.
18186	707	21	For the LORD shall rise up as in mount Perazim, he shall be wroth as in the valley of Gibeon, that he may do his work, his strange work; and bring to pass his act, his strange act.
18187	707	22	Now therefore be ye not mockers, lest your bands be made strong: for I have heard from the Lord GOD of hosts a consumption, even determined upon the whole earth.
18188	707	23	Give ye ear, and hear my voice; hearken, and hear my speech.
18189	707	24	Doth the plowman plow all day to sow? doth he open and break the clods of his ground?
18190	707	25	When he hath made plain the face thereof, doth he not cast abroad the fitches, and scatter the cummin, and cast in the principal wheat and the appointed barley and the rie in their place?
18191	707	26	For his God doth instruct him to discretion, and doth teach him.
18192	707	27	For the fitches are not threshed with a threshing instrument, neither is a cart wheel turned about upon the cummin; but the fitches are beaten out with a staff, and the cummin with a rod.
18193	707	28	Bread corn is bruised; because he will not ever be threshing it, nor break it with the wheel of his cart, nor bruise it with his horsemen.
18194	707	29	This also cometh forth from the LORD of hosts, which is wonderful in counsel, and excellent in working.
18195	708	1	WOE to Ariel, to Ariel, the city where David dwelt! add ye year to year; let them kill sacrifices.
18196	708	2	Yet I will distress Ariel, and there shall be heaviness and sorrow: and it shall be unto me as Ariel.
18197	708	3	And I will camp against thee round about, and will lay siege against thee with a mount, and I will raise forts against thee.
18198	708	4	And thou shalt be brought down, and shalt speak out of the ground, and thy speech shall be low out of the dust, and thy voice shall be, as of one that hath a familiar spirit, out of the ground, and thy speech shall whisper out of the dust.
18199	708	5	Moreover the multitude of thy strangers shall be like small dust, and the multitude of the terrible ones shall be as chaff that passeth away: yea, it shall be at an instant suddenly.
18200	708	6	Thou shalt be visited of the LORD of hosts with thunder, and with earthquake, and great noise, with storm and tempest, and the flame of devouring fire.
18201	708	7	And the multitude of all the nations that fight against Ariel, even all that fight against her and her munition, and that distress her, shall be as a dream of a night vision.
18202	708	8	It shall even be as when an hungry man dreameth, and, behold, he eateth; but he awaketh, and his soul is empty: or as when a thirsty man dreameth, and, behold, he drinketh; but he awaketh, and, behold, he is faint, and his soul hath appetite: so shall the multitude of all the nations be, that fight against mount Zion.
18203	708	9	Stay yourselves, and wonder; cry ye out, and cry: they are drunken, but not with wine; they stagger, but not with strong drink.
18204	708	10	For the LORD hath poured out upon you the spirit of deep sleep, and hath closed your eyes: the prophets and your rulers, the seers hath he covered.
18205	708	11	And the vision of all is become unto you as the words of a book that is sealed, which men deliver to one that is learned, saying, Read this, I pray thee: and he saith, I cannot; for it is sealed:
18206	708	12	And the book is delivered to him that is not learned, saying, Read this, I pray thee: and he saith, I am not learned.
18207	708	13	Wherefore the Lord said, Forasmuch as this people draw near me with their mouth, and with their lips do honour me, but have removed their heart far from me, and their fear toward me is taught by the precept of men:
18208	708	14	Therefore, behold, I will proceed to do a marvellous work among this people, even a marvellous work and a wonder: for the wisdom of their wise men shall perish, and the understanding of their prudent men shall be hid.
18209	708	15	Woe unto them that seek deep to hide their counsel from the LORD, and their works are in the dark, and they say, Who seeth us? and who knoweth us?
18210	708	16	Surely your turning of things upside down shall be esteemed as the potter's clay: for shall the work say of him that made it, He made me not? or shall the thing framed say of him that framed it, He had no understanding?
18211	708	17	Is it not yet a very little while, and Lebanon shall be turned into a fruitful field, and the fruitful field shall be esteemed as a forest?
18212	708	18	And in that day shall the deaf hear the words of the book, and the eyes of the blind shall see out of obscurity, and out of darkness.
18213	708	19	The meek also shall increase their joy in the LORD, and the poor among men shall rejoice in the Holy One of Israel.
18214	708	20	For the terrible one is brought to nought, and the scorner is consumed, and all that watch for iniquity are cut off:
18215	708	21	That make a man an offender for a word, and lay a snare for him that reproveth in the gate, and turn aside the just for a thing of nought.
18216	708	22	Therefore thus saith the LORD, who redeemed Abraham, concerning the house of Jacob, Jacob shall not now be ashamed, neither shall his face now wax pale.
18217	708	23	But when he seeth his children, the work of mine hands, in the midst of him, they shall sanctify my name, and sanctify the Holy One of Jacob, and shall fear the God of Israel.
18218	708	24	They also that erred in spirit shall come to understanding, and they that murmured shall learn doctrine.
18219	709	1	WOE to the rebellious children, saith the LORD, that take counsel, but not of me; and that cover with a covering, but not of my spirit, that they may add sin to sin:
18220	709	2	That walk to go down into Egypt, and have not asked at my mouth; to strengthen themselves in the strength of Pharaoh, and to trust in the shadow of Egypt!
18221	709	3	Therefore shall the strength of Pharaoh be your shame, and the trust in the shadow of Egypt your confusion.
18222	709	4	For his princes were at Zoan, and his ambassadors came to Hanes.
18223	709	5	They were all ashamed of a people that could not profit them, nor be an help nor profit, but a shame, and also a reproach.
18224	709	6	The burden of the beasts of the south: into the land of trouble and anguish, from whence come the young and old lion, the viper and fiery flying serpent, they will carry their riches upon the shoulders of young asses, and their treasures upon the bunches of camels, to a people that shall not profit them.
18225	709	7	For the Egyptians shall help in vain, and to no purpose: therefore have I cried concerning this, Their strength is to sit still.
18226	709	8	Now go, write it before them in a table, and note it in a book, that it may be for the time to come for ever and ever:
18227	709	9	That this is a rebellious people, lying children, children that will not hear the law of the LORD:
18228	709	10	Which say to the seers, See not; and to the prophets, Prophesy not unto us right things, speak unto us smooth things, prophesy deceits:
18229	709	11	Get you out of the way, turn aside out of the path, cause the Holy One of Israel to cease from before us.
18230	709	12	Wherefore thus saith the Holy One of Israel, Because ye despise this word, and trust in oppression and perverseness, and stay thereon:
18231	709	13	Therefore this iniquity shall be to you as a breach ready to fall, swelling out in a high wall, whose breaking cometh suddenly at an instant.
18232	709	14	And he shall break it as the breaking of the potters' vessel that is broken in pieces; he shall not spare: so that there shall not be found in the bursting of it a sherd to take fire from the hearth, or to take water withal out of the pit.
18233	709	15	For thus saith the Lord GOD, the Holy One of Israel; In returning and rest shall ye be saved; in quietness and in confidence shall be your strength: and ye would not.
18234	709	16	But ye said, No; for we will flee upon horses; therefore shall ye flee: and, We will ride upon the swift; therefore shall they that pursue you be swift.
18235	709	17	One thousand shall flee at the rebuke of one; at the rebuke of five shall ye flee: till ye be left as a beacon upon the top of a mountain, and as an ensign on an hill.
18236	709	18	And therefore will the LORD wait, that he may be gracious unto you, and therefore will he be exalted, that he may have mercy upon you: for the LORD is a God of judgment: blessed are all they that wait for him.
18237	709	19	For the people shall dwell in Zion at Jerusalem: thou shalt weep no more: he will be very gracious unto thee at the voice of thy cry; when he shall hear it, he will answer thee.
18238	709	20	And though the Lord give you the bread of adversity, and the water of affliction, yet shall not thy teachers be removed into a corner any more, but thine eyes shall see thy teachers:
18239	709	21	And thine ears shall hear a word behind thee, saying, This is the way, walk ye in it, when ye turn to the right hand, and when ye turn to the left.
18240	709	22	Ye shall defile also the covering of thy graven images of silver, and the ornament of thy molten images of gold: thou shalt cast them away as a menstruous cloth; thou shalt say unto it, Get thee hence.
18241	709	23	Then shall he give the rain of thy seed, that thou shalt sow the ground withal; and bread of the increase of the earth, and it shall be fat and plenteous: in that day shall thy cattle feed in large pastures.
18242	709	24	The oxen likewise and the young asses that ear the ground shall eat clean provender, which hath been winnowed with the shovel and with the fan.
18243	709	25	And there shall be upon every high mountain, and upon every high hill, rivers and streams of waters in the day of the great slaughter, when the towers fall.
18244	709	26	Moreover the light of the moon shall be as the light of the sun, and the light of the sun shall be sevenfold, as the light of seven days, in the day that the LORD bindeth up the breach of his people, and healeth the stroke of their wound.
18245	709	27	Behold, the name of the LORD cometh from far, burning with his anger, and the burden thereof is heavy: his lips are full of indignation, and his tongue as a devouring fire:
18246	709	28	And his breath, as an overflowing stream, shall reach to the midst of the neck, to sift the nations with the sieve of vanity: and there shall be a bridle in the jaws of the people, causing them to err.
18247	709	29	Ye shall have a song, as in the night when a holy solemnity is kept; and gladness of heart, as when one goeth with a pipe to come into the mountain of the LORD, to the mighty One of Israel.
18248	709	30	And the LORD shall cause his glorious voice to be heard, and shall shew the lighting down of his arm, with the indignation of his anger, and with the flame of a devouring fire, with scattering, and tempest, and hailstones.
18249	709	31	For through the voice of the LORD shall the Assyrian be beaten down, which smote with a rod.
18250	709	32	And in every place where the grounded staff shall pass, which the LORD shall lay upon him, it shall be with tabrets and harps: and in battles of shaking will he fight with it.
18251	709	33	For Tophet is ordained of old; yea, for the king it is prepared; he hath made it deep and large: the pile thereof is fire and much wood; the breath of the LORD, like a stream of brimstone, doth kindle it.
18252	710	1	WOE to them that go down to Egypt for help; and stay on horses, and trust in chariots, because they are many; and in horsemen, because they are very strong; but they look not unto the Holy One of Israel, neither seek the LORD!
18253	710	2	Yet he also is wise, and will bring evil, and will not call back his words: but will arise against the house of the evildoers, and against the help of them that work iniquity.
18254	710	3	Now the Egyptians are men, and not God; and their horses flesh, and not spirit. When the LORD shall stretch out his hand, both he that helpeth shall fall, and he that is holpen shall fall down, and they all shall fail together.
18255	710	4	For thus hath the LORD spoken unto me, Like as the lion and the young lion roaring on his prey, when a multitude of shepherds is called forth against him, he will not be afraid of their voice, nor abase himself for the noise of them: so shall the LORD of hosts come down to fight for mount Zion, and for the hill thereof.
18256	710	5	As birds flying, so will the LORD of hosts defend Jerusalem; defending also he will deliver it; and passing over he will preserve it.
18257	710	6	Turn ye unto him from whom the children of Israel have deeply revolted.
18258	710	7	For in that day every man shall cast away his idols of silver, and his idols of gold, which your own hands have made unto you for a sin.
18259	710	8	Then shall the Assyrian fall with the sword, not of a mighty man; and the sword, not of a mean man, shall devour him: but he shall flee from the sword, and his young men shall be discomfited.
18260	710	9	And he shall pass over to his strong hold for fear, and his princes shall be afraid of the ensign, saith the LORD, whose fire is in Zion, and his furnace in Jerusalem.
18261	711	1	BEHOLD, a king shall reign in righteousness, and princes shall rule in judgment.
18262	711	2	And a man shall be as an hiding place from the wind, and a covert from the tempest; as rivers of water in a dry place, as the shadow of a great rock in a weary land.
18263	711	3	And the eyes of them that see shall not be dim, and the ears of them that hear shall hearken.
18264	711	4	The heart also of the rash shall understand knowledge, and the tongue of the stammerers shall be ready to speak plainly.
18265	711	5	The vile person shall be no more called liberal, nor the churl said to be bountiful.
18266	711	6	For the vile person will speak villany, and his heart will work iniquity, to practise hypocrisy, and to utter error against the LORD, to make empty the soul of the hungry, and he will cause the drink of the thirsty to fail.
18267	711	7	The instruments also of the churl are evil: he deviseth wicked devices to destroy the poor with lying words, even when the needy speaketh right.
18268	711	8	But the liberal deviseth liberal things; and by liberal things shall he stand.
18269	711	9	Rise up, ye women that are at ease; hear my voice, ye careless daughters; give ear unto my speech.
18270	711	10	Many days and years shall ye be troubled, ye careless women: for the vintage shall fail, the gathering shall not come.
18271	711	11	Tremble, ye women that are at ease; be troubled, ye careless ones: strip you, and make you bare, and gird sackcloth upon your loins.
18272	711	12	They shall lament for the teats, for the pleasant fields, for the fruitful vine.
18273	711	13	Upon the land of my people shall come up thorns and briers; yea, upon all the houses of joy in the joyous city:
18274	711	14	Because the palaces shall be forsaken; the multitude of the city shall be left; the forts and towers shall be for dens for ever, a joy of wild asses, a pasture of flocks;
18275	711	15	Until the spirit be poured upon us from on high, and the wilderness be a fruitful field, and the fruitful field be counted for a forest.
18276	711	16	Then judgment shall dwell in the wilderness, and righteousness remain in the fruitful field.
18277	711	17	And the work of righteousness shall be peace; and the effect of righteousness quietness and assurance for ever.
18278	711	18	And my people shall dwell in a peaceable habitation, and in sure dwellings, and in quiet resting places;
18279	711	19	When it shall hail, coming down on the forest; and the city shall be low in a low place.
18280	711	20	Blessed are ye that sow beside all waters, that send forth thither the feet of the ox and the ass.
18281	712	1	WOE to thee that spoilest, and thou wast not spoiled; and dealest treacherously, and they dealt not treacherously with thee! when thou shalt cease to spoil, thou shalt be spoiled; and when thou shalt make an end to deal treacherously, they shall deal treacherously with thee.
18282	712	2	O LORD, be gracious unto us; we have waited for thee: be thou their arm every morning, our salvation also in the time of trouble.
18283	712	3	At the noise of the tumult the people fled; at the lifting up of thyself the nations were scattered.
18284	712	4	And your spoil shall be gathered like the gathering of the caterpiller: as the running to and fro of locusts shall he run upon them.
18285	712	5	The LORD is exalted; for he dwelleth on high: he hath filled Zion with judgment and righteousness.
18286	712	6	And wisdom and knowledge shall be the stability of thy times, and strength of salvation: the fear of the LORD is his treasure.
18287	712	7	Behold, their valiant ones shall cry without: the ambassadors of peace shall weep bitterly.
18288	712	8	The highways lie waste, the wayfaring man ceaseth: he hath broken the covenant, he hath despised the cities, he regardeth no man.
18289	712	9	The earth mourneth and languisheth: Lebanon is ashamed and hewn down: Sharon is like a wilderness: and Bashan and Carmel shake off their fruits.
18290	712	10	Now will I rise, saith the LORD; now will I be exalted; now will I lift up myself.
18291	712	11	Ye shall conceive chaff, ye shall bring forth stubble: your breath, as fire, shall devour you.
18292	712	12	And the people shall be as the burnings of lime: as thorns cut up shall they be burned in the fire.
18293	712	13	Hear, ye that are far off, what I have done; and, ye that are near, acknowledge my might.
18294	712	14	The sinners in Zion are afraid; fearfulness hath surprised the hypocrites. Who among us shall dwell with the devouring fire? who among us shall dwell with everlasting burnings?
18295	712	15	He that walketh righteously, and speaketh uprightly; he that despiseth the gain of oppressions, that shaketh his hands from holding of bribes, that stoppeth his ears from hearing of blood, and shutteth his eyes from seeing evil;
18296	712	16	He shall dwell on high: his place of defence shall be the munitions of rocks: bread shall be given him; his waters shall be sure.
18297	712	17	Thine eyes shall see the king in his beauty: they shall behold the land that is very far off.
18298	712	18	Thine heart shall meditate terror. Where is the scribe? where is the receiver? where is he that counted the towers?
18299	712	19	Thou shalt not see a fierce people, a people of a deeper speech than thou canst perceive; of a stammering tongue, that thou canst not understand.
18300	712	20	Look upon Zion, the city of our solemnities: thine eyes shall see Jerusalem a quiet habitation, a tabernacle that shall not be taken down; not one of the stakes thereof shall ever be removed, neither shall any of the cords thereof be broken.
18301	712	21	But there the glorious LORD will be unto us a place of broad rivers and streams; wherein shall go no galley with oars, neither shall gallant ship pass thereby.
18302	712	22	For the LORD is our judge, the LORD is our lawgiver, the LORD is our king; he will save us.
18303	712	23	Thy tacklings are loosed; they could not well strengthen their mast, they could not spread the sail: then is the prey of a great spoil divided; the lame take the prey.
18304	712	24	And the inhabitant shall not say, I am sick: the people that dwell therein shall be forgiven their iniquity.
18305	713	1	COME near, ye nations, to hear; and hearken, ye people: let the earth hear, and all that is therein; the world, and all things that come forth of it.
18306	713	2	For the indignation of the LORD is upon all nations, and his fury upon all their armies: he hath utterly destroyed them, he hath delivered them to the slaughter.
18307	713	3	Their slain also shall be cast out, and their stink shall come up out of their carcases, and the mountains shall be melted with their blood.
18308	713	4	And all the host of heaven shall be dissolved, and the heavens shall be rolled together as a scroll: and all their host shall fall down, as the leaf falleth off from the vine, and as a falling fig from the fig tree.
18309	713	5	For my sword shall be bathed in heaven: behold, it shall come down upon Idumea, and upon the people of my curse, to judgment.
18310	713	6	The sword of the LORD is filled with blood, it is made fat with fatness, and with the blood of lambs and goats, with the fat of the kidneys of rams: for the LORD hath a sacrifice in Bozrah, and a great slaughter in the land of Idumea.
18311	713	7	And the unicorns shall come down with them, and the bullocks with the bulls; and their land shall be soaked with blood, and their dust made fat with fatness.
18312	713	8	For it is the day of the LORD's vengeance, and the year of recompences for the controversy of Zion.
18313	713	9	And the streams thereof shall be turned into pitch, and the dust thereof into brimstone, and the land thereof shall become burning pitch.
18314	713	10	It shall not be quenched night nor day; the smoke thereof shall go up for ever: from generation to generation it shall lie waste; none shall pass through it for ever and ever.
18315	713	11	But the cormorant and the bittern shall possess it; the owl also and the raven shall dwell in it: and he shall stretch out upon it the line of confusion, and the stones of emptiness.
18316	713	12	They shall call the nobles thereof to the kingdom, but none shall be there, and all her princes shall be nothing.
18317	713	13	And thorns shall come up in her palaces, nettles and brambles in the fortresses thereof: and it shall be an habitation of dragons, and a court for owls.
18318	713	14	The wild beasts of the desert shall also meet with the wild beasts of the island, and the satyr shall cry to his fellow; the screech owl also shall rest there, and find for herself a place of rest.
18319	713	15	There shall the great owl make her nest, and lay, and hatch, and gather under her shadow: there shall the vultures also be gathered, every one with her mate.
18320	713	16	Seek ye out of the book of the LORD, and read: no one of these shall fail, none shall want her mate: for my mouth it hath commanded, and his spirit it hath gathered them.
18321	713	17	And he hath cast the lot for them, and his hand hath divided it unto them by line: they shall possess it for ever, from generation to generation shall they dwell therein.
18322	714	1	THE wilderness and the solitary place shall be glad for them; and the desert shall rejoice, and blossom as the rose.
18323	714	2	It shall blossom abundantly, and rejoice even with joy and singing: the glory of Lebanon shall be given unto it, the excellency of Carmel and Sharon, they shall see the glory of the LORD, and the excellency of our God.
18324	714	3	Strengthen ye the weak hands, and confirm the feeble knees.
18325	714	4	Say to them that are of a fearful heart, Be strong, fear not: behold, your God will come with vengeance, even God with a recompence; he will come and save you.
18326	714	5	Then the eyes of the blind shall be opened, and the ears of the deaf shall be unstopped.
18327	714	6	Then shall the lame man leap as an hart, and the tongue of the dumb sing: for in the wilderness shall waters break out, and streams in the desert.
18328	714	7	And the parched ground shall become a pool, and the thirsty land springs of water: in the habitation of dragons, where each lay, shall be grass with reeds and rushes.
18329	714	8	And an highway shall be there, and a way, and it shall be called The way of holiness; the unclean shall not pass over it; but it shall be for those: the wayfaring men, though fools, shall not err therein.
18330	714	9	No lion shall be there, nor any ravenous beast shall go up thereon, it shall not be found there; but the redeemed shall walk there:
18331	714	10	And the ransomed of the LORD shall return, and come to Zion with songs and everlasting joy upon their heads: they shall obtain joy and gladness, and sorrow and sighing shall flee away.
18332	715	1	NOW it came to pass in the fourteenth year of king Hezekiah, that Sennacherib king of Assyria came up against all the defenced cities of Judah, and took them.
18333	715	2	And the king of Assyria sent Rabshakeh from Lachish to Jerusalem unto king Hezekiah with a great army. And he stood by the conduit of the upper pool in the highway of the fuller's field.
18334	715	3	Then came forth unto him Eliakim, Hilkiah's son, which was over the house, and Shebna the scribe, and Joah, Asaph's son, the recorder.
18335	715	4	And Rabshakeh said unto them, Say ye now to Hezekiah, Thus saith the great king, the king of Assyria, What confidence is this wherein thou trustest?
18336	715	5	I say, sayest thou, (but they are but vain words) I have counsel and strength for war: now on whom dost thou trust, that thou rebellest against me?
18337	715	6	Lo, thou trustest in the staff of this broken reed, on Egypt; whereon if a man lean, it will go into his hand, and pierce it: so is Pharaoh king of Egypt to all that trust in him.
18338	715	7	But if thou say to me, We trust in the LORD our God: is it not he, whose high places and whose altars Hezekiah hath taken away, and said to Judah and to Jerusalem, Ye shall worship before this altar?
18339	715	8	Now therefore give pledges, I pray thee, to my master the king of Assyria, and I will give thee two thousand horses, if thou be able on thy part to set riders upon them.
18340	715	9	How then wilt thou turn away the face of one captain of the least of my master's servants, and put thy trust on Egypt for chariots and for horsemen?
18341	715	10	And am I now come up without the LORD against this land to destroy it? the LORD said unto me, Go up against this land, and destroy it.
18342	715	11	Then said Eliakim and Shebna and Joah unto Rabshakeh, Speak, I pray thee, unto thy servants in the Syrian language; for we understand it: and speak not to us in the Jews' language, in the ears of the people that are on the wall.
18343	715	12	But Rabshakeh said, Hath my master sent me to thy master and to thee to speak these words? hath he not sent me to the men that sit upon the wall, that they may eat their own dung, and drink their own piss with you?
18344	715	13	Then Rabshakeh stood, and cried with a loud voice in the Jews' language, and said, Hear ye the words of the great king, the king of Assyria.
18345	715	14	Thus saith the king, Let not Hezekiah deceive you: for he shall not be able to deliver you.
18346	715	15	Neither let Hezekiah make you trust in the LORD, saying, The LORD will surely deliver us: this city shall not be delivered into the hand of the king of Assyria.
18347	715	16	Hearken not to Hezekiah: for thus saith the king of Assyria, Make an agreement with me by a present, and come out to me: and eat ye every one of his vine, and every one of his fig tree, and drink ye every one the waters of his own cistern;
18348	715	17	Until I come and take you away to a land like your own land, a land of corn and wine, a land of bread and vineyards.
18349	715	18	Beware lest Hezekiah persuade you, saying, The LORD will deliver us. Hath any of the gods of the nations delivered his land out of the hand of the king of Assyria?
18350	715	19	Where are the gods of Hamath and Arphad? where are the gods of Sepharvaim? and have they delivered Samaria out of my hand?
18351	715	20	Who are they among all the gods of these lands, that have delivered their land out of my hand, that the LORD should deliver Jerusalem out of my hand?
18352	715	21	But they held their peace, and answered him not a word: for the king's commandment was, saying, Answer him not.
18353	715	22	Then came Eliakim, the son of Hilkiah, that was over the household, and Shebna the scribe, and Joah, the son of Asaph, the recorder, to Hezekiah with their clothes rent, and told him the words of Rabshakeh.
18354	716	1	AND it came to pass, when king Hezekiah heard it, that he rent his clothes, and covered himself with sackcloth, and went into the house of the LORD.
18355	716	2	And he sent Eliakim, who was over the household, and Shebna the scribe, and the elders of the priests covered with sackcloth, unto Isaiah the prophet the son of Amoz.
18356	716	3	And they said unto him, Thus saith Hezekiah, This day is a day of trouble, and of rebuke, and of blasphemy: for the children are come to the birth, and there is not strength to bring forth.
18357	716	4	It may be the LORD thy God will hear the words of Rabshakeh, whom the king of Assyria his master hath sent to reproach the living God, and will reprove the words which the LORD thy God hath heard: wherefore lift up thy prayer for the remnant that is left.
18358	716	5	So the servants of king Hezekiah came to Isaiah.
18359	716	6	And Isaiah said unto them, Thus shall ye say unto your master, Thus saith the LORD, Be not afraid of the words that thou hast heard, wherewith the servants of the king of Assyria have blasphemed me.
18360	716	7	Behold, I will send a blast upon him, and he shall hear a rumour, and return to his own land; and I will cause him to fall by the sword in his own land.
18361	716	8	So Rabshakeh returned, and found the king of Assyria warring against Libnah: for he had heard that he was departed from Lachish.
18362	716	9	And he heard say concerning Tirhakah king of Ethiopia, He is come forth to make war with thee. And when he heard it, he sent messengers to Hezekiah, saying,
18363	716	10	Thus shall ye speak to Hezekiah king of Judah, saying, Let not thy God, in whom thou trustest, deceive thee, saying, Jerusalem shall not be given into the hand of the king of Assyria.
18364	716	11	Behold, thou hast heard what the kings of Assyria have done to all lands by destroying them utterly; and shalt thou be delivered?
18365	716	12	Have the gods of the nations delivered them which my fathers have destroyed, as Gozan, and Haran, and Rezeph, and the children of Eden which were in Telassar?
18366	716	13	Where is the king of Hamath, and the king of Arphad, and the king of the city of Sepharvaim, Hena, and Ivah?
18367	716	14	And Hezekiah received the letter from the hand of the messengers, and read it: and Hezekiah went up unto the house of the LORD, and spread it before the LORD.
18368	716	15	And Hezekiah prayed unto the LORD, saying,
18369	716	16	O LORD of hosts, God of Israel, that dwellest between the cherubims, thou art the God, even thou alone, of all the kingdoms of the earth: thou hast made heaven and earth.
18370	716	17	Incline thine ear, O LORD, and hear; open thine eyes, O LORD, and see: and hear all the words of Sennacherib, which hath sent to reproach the living God.
18371	716	18	Of a truth, LORD, the kings of Assyria have laid waste all the nations, and their countries,
18372	716	19	And have cast their gods into the fire: for they were no gods, but the work of men's hands, wood and stone: therefore they have destroyed them.
18373	716	20	Now therefore, O LORD our God, save us from his hand, that all the kingdoms of the earth may know that thou art the LORD, even thou only.
18374	716	21	Then Isaiah the son of Amoz sent unto Hezekiah, saying, Thus saith the LORD God of Israel, Whereas thou hast prayed to me against Sennacherib king of Assyria:
18375	716	22	This is the word which the LORD hath spoken concerning him; The virgin, the daughter of Zion, hath despised thee, and laughed thee to scorn; the daughter of Jerusalem hath shaken her head at thee.
18376	716	23	Whom hast thou reproached and blasphemed? and against whom hast thou exalted thy voice, and lifted up thine eyes on high? even against the Holy One of Israel.
18377	716	24	By thy servants hast thou reproached the Lord, and hast said, By the multitude of my chariots am I come up to the height of the mountains, to the sides of Lebanon; and I will cut down the tall cedars thereof, and the choice fir trees thereof: and I will enter into the height of his border, and the forest of his Carmel.
18378	716	25	I have digged, and drunk water; and with the sole of my feet have I dried up all the rivers of the besieged places.
18379	716	26	Hast thou not heard long ago, how I have done it; and of ancient times, that I have formed it? now have I brought it to pass, that thou shouldest be to lay waste defenced cities into ruinous heaps.
18380	716	27	Therefore their inhabitants were of small power, they were dismayed and confounded: they were as the grass of the field, and as the green herb, as the grass on the housetops, and as corn blasted before it be grown up.
18381	716	28	But I know thy abode, and thy going out, and thy coming in, and thy rage against me.
18382	716	29	Because thy rage against me, and thy tumult, is come up into mine ears, therefore will I put my hook in thy nose, and my bridle in thy lips, and I will turn thee back by the way by which thou camest.
18383	716	30	And this shall be a sign unto thee, Ye shall eat this year such as groweth of itself; and the second year that which springeth of the same: and in the third year sow ye, and reap, and plant vineyards, and eat the fruit thereof.
18384	716	31	And the remnant that is escaped of the house of Judah shall again take root downward, and bear fruit upward:
18385	716	32	For out of Jerusalem shall go forth a remnant, and they that escape out of mount Zion: the zeal of the LORD of hosts shall do this.
18386	716	33	Therefore thus saith the LORD concerning the king of Assyria, He shall not come into this city, nor shoot an arrow there, nor come before it with shields, nor cast a bank against it.
18387	716	34	By the way that he came, by the same shall he return, and shall not come into this city, saith the LORD.
18388	716	35	For I will defend this city to save it for mine own sake, and for my servant David's sake.
18389	716	36	Then the angel of the LORD went forth, and smote in the camp of the Assyrians a hundred and fourscore and five thousand: and when they arose early in the morning, behold, they were all dead corpses.
18390	716	37	So Sennacherib king of Assyria departed, and went and returned, and dwelt at Nineveh.
18391	716	38	And it came to pass, as he was worshipping in the house of Nisroch his god, that Adrammelech and Sharezer his sons smote him with the sword; and they escaped into the land of Armenia: and Esar-haddon his son reigned in his stead.
18392	717	1	IN those days was Hezekiah sick unto death. And Isaiah the prophet the son of Amoz came unto him, and said unto him, Thus saith the LORD, Set thine house in order: for thou shalt die, and not live.
18393	717	2	Then Hezekiah turned his face toward the wall, and prayed unto the LORD,
18394	717	3	And said, Remember now, O LORD, I beseech thee, how I have walked before thee in truth and with a perfect heart, and have done that which is good in thy sight. And Hezekiah wept sore.
18395	717	4	Then came the word of the LORD to Isaiah, saying,
18396	717	5	Go, and say to Hezekiah, Thus saith the LORD, the God of David thy father, I have heard thy prayer, I have seen thy tears: behold, I will add unto thy days fifteen years.
18397	717	6	And I will deliver thee and this city out of the hand of the king of Assyria: and I will defend this city.
18398	717	7	And this shall be a sign unto thee from the LORD, that the LORD will do this thing that he hath spoken;
18399	717	8	Behold, I will bring again the shadow of the degrees, which is gone down in the sun dial of Ahaz, ten degrees backward. So the sun returned ten degrees, by which degrees it was gone down.
18400	717	9	The writing of Hezekiah king of Judah, when he had been sick, and was recovered of his sickness:
18401	717	10	I said in the cutting off of my days, I shall go to the gates of the grave: I am deprived of the residue of my years.
18402	717	11	I said, I shall not see the LORD, even the LORD, in the land of the living: I shall behold man no more with the inhabitants of the world.
18403	717	12	Mine age is departed, and is removed from me as a shepherd's tent: I have cut off like a weaver my life: he will cut me off with pining sickness: from day even to night wilt thou make an end of me.
18404	717	13	I reckoned till morning, that, as a lion, so will he break all my bones: from day even to night wilt thou make an end of me.
18405	717	14	Like a crane or a swallow, so did I chatter: I did mourn as a dove: mine eyes fail with looking upward: O LORD, I am oppressed; undertake for me.
18406	717	15	What shall I say? he hath both spoken unto me, and himself hath done it: I shall go softly all my years in the bitterness of my soul.
18407	717	16	O Lord, by these things men live, and in all these things is the life of my spirit: so wilt thou recover me, and make me to live.
18408	717	17	Behold, for peace I had great bitterness: but thou hast in love to my soul delivered it from the pit of corruption: for thou hast cast all my sins behind thy back.
18409	717	18	For the grave cannot praise thee, death can not celebrate thee: they that go down into the pit cannot hope for thy truth.
18410	717	19	The living, the living, he shall praise thee, as I do this day: the father to the children shall make known thy truth.
18411	717	20	The LORD was ready to save me: therefore we will sing my songs to the stringed instruments all the days of our life in the house of the LORD.
18412	717	21	For Isaiah had said, Let them take a lump of figs, and lay it for a plaister upon the boil, and he shall recover.
18413	717	22	Hezekiah also had said, What is the sign that I shall go up to the house of the LORD?
18414	718	1	AT that time Merodach-baladan, the son of Baladan, king of Babylon, sent letters and a present to Hezekiah: for he had heard that he had been sick, and was recovered.
18415	718	2	And Hezekiah was glad of them, and shewed them the house of his precious things, the silver, and the gold, and the spices, and the precious ointment, and all the house of his armour, and all that was found in his treasures: there was nothing in his house, nor in all his dominion, that Hezekiah shewed them not.
18416	718	3	Then came Isaiah the prophet unto king Hezekiah, and said unto him, What said these men? and from whence came they unto thee? And Hezekiah said, They are come from a far country unto me, even from Babylon.
18417	718	4	Then said he, What have they seen in thine house? And Hezekiah answered, All that is in mine house have they seen: there is nothing among my treasures that I have not shewed them.
18418	718	5	Then said Isaiah to Hezekiah, Hear the word of the LORD of hosts:
18419	718	6	Behold, the days come, that all that is in thine house, and that which thy fathers have laid up in store until this day, shall be carried to Babylon: nothing shall be left, saith the LORD.
18420	718	7	And of thy sons that shall issue from thee, which thou shalt beget, shall they take away; and they shall be eunuchs in the palace of the king of Babylon.
18421	718	8	Then said Hezekiah to Isaiah, Good is the word of the LORD which thou hast spoken. He said moreover, For there shall be peace and truth in my days.
18422	719	1	COMFORT ye, comfort ye my people, saith your God.
18423	719	2	Speak ye comfortably to Jerusalem, and cry unto her, that her warfare is accomplished, that her iniquity is pardoned: for she hath received of the LORD's hand double for all her sins.
18424	719	3	The voice of him that crieth in the wilderness, Prepare ye the way of the LORD, make straight in the desert a highway for our God.
18425	719	4	Every valley shall be exalted, and every mountain and hill shall be made low: and the crooked shall be made straight, and the rough places plain:
18426	719	5	And the glory of the LORD shall be revealed, and all flesh shall see it together: for the mouth of the LORD hath spoken it.
18427	719	6	The voice said, Cry. And he said, What shall I cry? All flesh is grass, and all the goodliness thereof is as the flower of the field:
18428	719	7	The grass withereth, the flower fadeth: because the spirit of the LORD bloweth upon it: surely the people is grass.
18429	719	8	The grass withereth, the flower fadeth: but the word of our God shall stand for ever.
18430	719	9	O Zion, that bringest good tidings, get thee up into the high mountain; O Jerusalem, that bringest good tidings, lift up thy voice with strength; lift it up, be not afraid; say unto the cities of Judah, Behold your God!
18431	719	10	Behold, the Lord GOD will come with strong hand, and his arm shall rule for him: behold, his reward is with him, and his work before him.
18432	719	11	He shall feed his flock like a shepherd: he shall gather the lambs with his arm, and carry them in his bosom, and shall gently lead those that are with young.
18433	719	12	Who hath measured the waters in the hollow of his hand, and meted out heaven with the span, and comprehended the dust of the earth in a measure, and weighed the mountains in scales, and the hills in a balance?
18434	719	13	Who hath directed the Spirit of the LORD, or being his counsellor hath taught him?
18435	719	14	With whom took he counsel, and who instructed him, and taught him in the path of judgment, and taught him knowledge, and shewed to him the way of understanding?
18436	719	15	Behold, the nations are as a drop of a bucket, and are counted as the small dust of the balance: behold, he taketh up the isles as a very little thing.
18437	719	16	And Lebanon is not sufficient to burn, nor the beasts thereof sufficient for a burnt offering.
18438	719	17	All nations before him are as nothing; and they are counted to him less than nothing, and vanity.
18439	719	18	To whom then will ye liken God? or what likeness will ye compare unto him?
18440	719	19	The workman melteth a graven image, and the goldsmith spreadeth it over with gold, and casteth silver chains.
18441	719	20	He that is so impoverished that he hath no oblation chooseth a tree that will not rot; he seeketh unto him a cunning workman to prepare a graven image, that shall not be moved.
18442	719	21	Have ye not known? have ye not heard? hath it not been told you from the beginning? have ye not understood from the foundations of the earth?
18443	719	22	It is he that sitteth upon the circle of the earth, and the inhabitants thereof are as grasshoppers; that stretcheth out the heavens as a curtain, and spreadeth them out as a tent to dwell in:
18444	719	23	That bringeth the princes to nothing; he maketh the judges of the earth as vanity.
18445	719	24	Yea, they shall not be planted; yea, they shall not be sown: yea, their stock shall not take root in the earth: and he shall also blow upon them, and they shall wither, and the whirlwind shall take them away as stubble.
18446	719	25	To whom then will ye liken me, or shall I be equal? saith the Holy One.
18447	719	26	Lift up your eyes on high, and behold who hath created these things, that bringeth out their host by number: he calleth them all by names by the greatness of his might, for that he is strong in power; not one faileth.
18448	719	27	Why sayest thou, O Jacob, and speakest, O Israel, My way is hid from the LORD, and my judgment is passed over from my God?
18449	719	28	Hast thou not known? hast thou not heard, that the everlasting God, the LORD, the Creator of the ends of the earth, fainteth not, neither is weary? there is no searching of his understanding.
18450	719	29	He giveth power to the faint; and to them that have no might he increaseth strength.
18451	719	30	Even the youths shall faint and be weary, and the young men shall utterly fall:
18452	719	31	But they that wait upon the LORD shall renew their strength; they shall mount up with wings as eagles; they shall run, and not be weary; and they shall walk, and not faint.
18453	720	1	KEEP silence before me, O islands; and let the people renew their strength: let them come near; then let them speak: let us come near together to judgment.
18454	720	2	Who raised up the righteous man from the east, called him to his foot, gave the nations before him, and made him rule over kings? he gave them as the dust to his sword, and as driven stubble to his bow.
18455	720	3	He pursued them, and passed safely; even by the way that he had not gone with his feet.
18456	720	4	Who hath wrought and done it, calling the generations from the beginning? I the LORD, the first, and with the last; I am he.
18457	720	5	The isles saw it, and feared; the ends of the earth were afraid, drew near, and came.
18458	720	6	They helped every one his neighbour; and every one said to his brother, Be of good courage.
18459	720	7	So the carpenter encouraged the goldsmith, and he that smootheth with the hammer him that smote the anvil, saying, It is ready for the sodering: and he fastened it with nails, that it should not be moved.
18460	720	8	But thou, Israel, art my servant, Jacob whom I have chosen, the seed of Abraham my friend.
18461	720	9	Thou whom I have taken from the ends of the earth, and called thee from the chief men thereof, and said unto thee, Thou art my servant; I have chosen thee, and not cast thee away.
18462	720	10	Fear thou not; for I am with thee: be not dismayed; for I am thy God: I will strengthen thee; yea, I will help thee; yea, I will uphold thee with the right hand of my righteousness.
18463	720	11	Behold, all they that were incensed against thee shall be ashamed and confounded: they shall be as nothing; and they that strive with thee shall perish.
18464	720	12	Thou shalt seek them, and shalt not find them, even them that contended with thee: they that war against thee shall be as nothing, and as a thing of nought.
18465	720	13	For I the LORD thy God will hold thy right hand, saying unto thee, Fear not; I will help thee.
18466	720	14	Fear not, thou worm Jacob, and ye men of Israel; I will help thee, saith the LORD, and thy redeemer, the Holy One of Israel.
18467	720	15	Behold, I will make thee a new sharp threshing instrument having teeth: thou shalt thresh the mountains, and beat them small, and shalt make the hills as chaff.
18468	720	16	Thou shalt fan them, and the wind shall carry them away, and the whirlwind shall scatter them: and thou shalt rejoice in the LORD, and shalt glory in the Holy One of Israel.
18469	720	17	When the poor and needy seek water, and there is none, and their tongue faileth for thirst, I the LORD will hear them, I the God of Israel will not forsake them.
18470	720	18	I will open rivers in high places, and fountains in the midst of the valleys: I will make the wilderness a pool of water, and the dry land springs of water.
18471	720	19	I will plant in the wilderness the cedar, the shittah tree, and the myrtle, and the oil tree; I will set in the desert the fir tree, and the pine, and the box tree together:
18472	720	20	That they may see, and know, and consider, and understand together, that the hand of the LORD hath done this, and the Holy One of Israel hath created it.
18473	720	21	Produce your cause, saith the LORD; bring forth your strong reasons, saith the King of Jacob.
18474	720	22	Let them bring them forth, and shew us what shall happen: let them shew the former things, what they be, that we may consider them, and know the latter end of them; or declare us things for to come.
18475	720	23	Shew the things that are to come hereafter, that we may know that ye are gods: yea, do good, or do evil, that we may be dismayed, and behold it together.
18476	720	24	Behold, ye are of nothing, and your work of nought: an abomination is he that chooseth you.
18477	720	25	I have raised up one from the north, and he shall come: from the rising of the sun shall he call upon my name: and he shall come upon princes as upon morter, and as the potter treadeth clay.
18478	720	26	Who hath declared from the beginning, that we may know? and beforetime, that we may say, He is righteous? yea, there is none that sheweth, yea, there is none that declareth, yea, there is none that heareth your words.
18479	720	27	The first shall say to Zion, Behold, behold them: and I will give to Jerusalem one that bringeth good tidings.
18480	720	28	For I beheld, and there was no man; even among them, and there was no counsellor, that, when I asked of them, could answer a word.
18481	720	29	Behold, they are all vanity; their works are nothing: their molten images are wind and confusion.
18482	721	1	BEHOLD my servant, whom I uphold; mine elect, in whom my soul delighteth; I have put my spirit upon him: he shall bring forth judgment to the Gentiles.
18483	721	2	He shall not cry, nor lift up, nor cause his voice to be heard in the street.
18484	721	3	A bruised reed shall he not break, and the smoking flax shall he not quench: he shall bring forth judgment unto truth.
18485	721	4	He shall not fail nor be discouraged, till he have set judgment in the earth: and the isles shall wait for his law.
18486	721	5	Thus saith God the LORD, he that created the heavens, and stretched them out; he that spread forth the earth, and that which cometh out of it; he that giveth breath unto the people upon it, and spirit to them that walk therein:
18487	721	6	I the LORD have called thee in righteousness, and will hold thine hand, and will keep thee, and give thee for a covenant of the people, for a light of the Gentiles;
18488	721	7	To open the blind eyes, to bring out the prisoners from the prison, and them that sit in darkness out of the prison house.
18489	721	8	I am the LORD: that is my name: and my glory will I not give to another, neither my praise to graven images.
18490	721	9	Behold, the former things are come to pass, and new things do I declare: before they spring forth I tell you of them.
18491	721	10	Sing unto the LORD a new song, and his praise from the end of the earth, ye that go down to the sea, and all that is therein; the isles, and the inhabitants thereof.
18492	721	11	Let the wilderness and the cities thereof lift up their voice, the villages that Kedar doth inhabit: let the inhabitants of the rock sing, let them shout from the top of the mountains.
18493	721	12	Let them give glory unto the LORD, and declare his praise in the islands.
18494	721	13	The LORD shall go forth as a mighty man, he shall stir up jealousy like a man of war: he shall cry, yea, roar; he shall prevail against his enemies.
18495	721	14	I have long time holden my peace; I have been still, and refrained myself: now will I cry like a travailing woman; I will destroy and devour at once.
18496	721	15	I will make waste mountains and hills, and dry up all their herbs; and I will make the rivers islands, and I will dry up the pools.
18497	721	16	And I will bring the blind by a way that they knew not; I will lead them in paths that they have not known: I will make darkness light before them, and crooked things straight. These things will I do unto them, and not forsake them.
18498	721	17	They shall be turned back, they shall be greatly ashamed, that trust in graven images, that say to the molten images, Ye are our gods.
18499	721	18	Hear, ye deaf; and look, ye blind, that ye may see.
18500	721	19	Who is blind, but my servant? or deaf, as my messenger that I sent? who is blind as he that is perfect, and blind as the LORD's servant?
18501	721	20	Seeing many things, but thou observest not; opening the ears, but he heareth not.
18502	721	21	The LORD is well pleased for his righteousness' sake; he will magnify the law, and make it honourable.
18503	721	22	But this is a people robbed and spoiled; they are all of them snared in holes, and they are hid in prison houses: they are for a prey, and none delivereth; for a spoil, and none saith, Restore.
18504	721	23	Who among you will give ear to this? who will hearken and hear for the time to come?
18505	721	24	Who gave Jacob for a spoil, and Israel to the robbers? did not the LORD, he against whom we have sinned? for they would not walk in his ways, neither were they obedient unto his law.
18506	721	25	Therefore he hath poured upon him the fury of his anger, and the strength of battle: and it hath set him on fire round about, yet he knew not; and it burned him, yet he laid it not to heart.
18507	722	1	BUT now thus saith the LORD that created thee, O Jacob, and he that formed thee, O Israel, Fear not: for I have redeemed thee, I have called thee by thy name; thou art mine.
18508	722	2	When thou passest through the waters, I will be with thee; and through the rivers, they shall not overflow thee: when thou walkest through the fire, thou shalt not be burned; neither shall the flame kindle upon thee.
18509	722	3	For I am the LORD thy God, the Holy One of Israel, thy Saviour: I gave Egypt for thy ransom, Ethiopia and Seba for thee.
18510	722	4	Since thou wast precious in my sight, thou hast been honourable, and I have loved thee: therefore will I give men for thee, and people for thy life.
18511	722	5	Fear not: for I am with thee: I will bring thy seed from the east, and gather thee from the west;
18512	722	6	I will say to the north, Give up; and to the south, Keep not back: bring my sons from far, and my daughters from the ends of the earth;
18513	722	7	Even every one that is called by my name: for I have created him for my glory, I have formed him; yea, I have made him.
18514	722	8	Bring forth the blind people that have eyes, and the deaf that have ears.
18515	722	9	Let all the nations be gathered together, and let the people be assembled: who among them can declare this, and shew us former things? let them bring forth their witnesses, that they may be justified: or let them hear, and say, It is truth.
18516	722	10	Ye are my witnesses, saith the LORD, and my servant whom I have chosen: that ye may know and believe me, and understand that I am he: before me there was no God formed, neither shall there be after me.
18517	722	11	I, even I, am the LORD; and beside me there is no saviour.
18518	722	12	I have declared, and have saved, and I have shewed, when there was no strange god among you: therefore ye are my witnesses, saith the LORD, that I am God.
18519	722	13	Yea, before the day was I am he; and there is none that can deliver out of my hand: I will work, and who shall let it?
18520	722	14	Thus saith the LORD, your redeemer, the Holy One of Israel; For your sake I have sent to Babylon, and have brought down all their nobles, and the Chaldeans, whose cry is in the ships.
18521	722	15	I am the LORD, your Holy One, the creator of Israel, your King.
18522	722	16	Thus saith the LORD, which maketh a way in the sea, and a path in the mighty waters;
18523	722	17	Which bringeth forth the chariot and horse, the army and the power; they shall lie down together, they shall not rise: they are extinct, they are quenched as tow.
18524	722	18	Remember ye not the former things, neither consider the things of old.
18525	722	19	Behold, I will do a new thing; now it shall spring forth; shall ye not know it? I will even make a way in the wilderness, and rivers in the desert.
18526	722	20	The beast of the field shall honour me, the dragons and the owls: because I give waters in the wilderness, and rivers in the desert, to give drink to my people, my chosen.
18527	722	21	This people have I formed for myself; they shall shew forth my praise.
18528	722	22	But thou hast not called upon me, O Jacob; but thou hast been weary of me, O Israel.
18529	722	23	Thou hast not brought me the small cattle of thy burnt offerings; neither hast thou honoured me with thy sacrifices. I have not caused thee to serve with an offering, nor wearied thee with incense.
18530	722	24	Thou hast bought me no sweet cane with money, neither hast thou filled me with the fat of thy sacrifices: but thou hast made me to serve with thy sins, thou hast wearied me with thine iniquities.
18531	722	25	I, even I, am he that blotteth out thy transgressions for mine own sake, and will not remember thy sins.
18532	722	26	Put me in remembrance: let us plead together: declare thou, that thou mayest be justified.
18533	722	27	Thy first father hath sinned, and thy teachers have transgressed against me.
18534	722	28	Therefore I have profaned the princes of the sanctuary, and have given Jacob to the curse, and Israel to reproaches.
18535	723	1	YET now hear, O Jacob my servant; and Israel, whom I have chosen:
18536	723	2	Thus saith the LORD that made thee, and formed thee from the womb, which will help thee; Fear not, O Jacob, my servant; and thou, Jesurun, whom I have chosen.
18537	723	3	For I will pour water upon him that is thirsty, and floods upon the dry ground: I will pour my spirit upon thy seed, and my blessing upon thine offspring:
18538	723	4	And they shall spring up as among the grass, as willows by the water courses.
18539	723	5	One shall say, I am the LORD's; and another shall call himself by the name of Jacob; and another shall subscribe with his hand unto the LORD, and surname himself by the name of Israel.
18540	723	6	Thus saith the LORD the King of Israel, and his redeemer the LORD of hosts; I am the first, and I am the last; and beside me there is no God.
18541	723	7	And who, as I, shall call, and shall declare it, and set it in order for me, since I appointed the ancient people? and the things that are coming, and shall come, let them shew unto them.
18542	723	8	Fear ye not, neither be afraid: have not I told thee from that time, and have declared it? ye are even my witnesses. Is there a God beside me? yea, there is no God; I know not any.
18543	723	9	They that make a graven image are all of them vanity; and their delectable things shall not profit; and they are their own witnesses; they see not, nor know; that they may be ashamed.
18544	723	10	Who hath formed a god, or molten a graven image that is profitable for nothing?
18545	723	11	Behold, all his fellows shall be ashamed: and the workmen, they are of men: let them all be gathered together, let them stand up; yet they shall fear, and they shall be ashamed together.
18546	723	12	The smith with the tongs both worketh in the coals, and fashioneth it with hammers, and worketh it with the strength of his arms: yea, he is hungry, and his strength faileth: he drinketh no water, and is faint.
18547	723	13	The carpenter stretcheth out his rule; he marketh it out with a line; he fitteth it with planes, and he marketh it out with the compass, and maketh it after the figure of a man, according to the beauty of a man; that it may remain in the house.
18548	723	14	He heweth him down cedars, and taketh the cypress and the oak, which he strengtheneth for himself among the trees of the forest: he planteth an ash, and the rain doth nourish it.
18549	723	15	Then shall it be for a man to burn: for he will take thereof, and warm himself; yea, he kindleth it, and baketh bread; yea, he maketh a god, and worshippeth it; he maketh it a graven image, and falleth down thereto.
18550	723	16	He burneth part thereof in the fire; with part thereof he eateth flesh; he roasteth roast, and is satisfied: yea, he warmeth himself, and saith, Aha, I am warm, I have seen the fire:
18551	723	17	And the residue thereof he maketh a god, even his graven image: he falleth down unto it, and worshippeth it, and prayeth unto it, and saith, Deliver me; for thou art my god.
18552	723	18	They have not known nor understood: for he hath shut their eyes, that they cannot see; and their hearts, that they cannot understand.
18553	723	19	And none considereth in his heart, neither is there knowledge nor understanding to say, I have burned part of it in the fire; yea, also I have baked bread upon the coals thereof; I have roasted flesh, and eaten it: and shall I make the residue thereof an abomination? shall I fall down to the stock of a tree?
18554	723	20	He feedeth on ashes: a deceived heart hath turned him aside, that he cannot deliver his soul, nor say, Is there not a lie in my right hand?
18555	723	21	Remember these, O Jacob and Israel; for thou art my servant: I have formed thee; thou art my servant: O Israel, thou shalt not be forgotten of me.
18556	723	22	I have blotted out, as a thick cloud, thy transgressions, and, as a cloud, thy sins: return unto me; for I have redeemed thee.
18557	723	23	Sing, O ye heavens; for the LORD hath done it: shout, ye lower parts of the earth: break forth into singing, ye mountains, O forest, and every tree therein: for the LORD hath redeemed Jacob, and glorified himself in Israel.
18558	723	24	Thus saith the LORD, thy redeemer, and he that formed thee from the womb, I am the LORD that maketh all things; that stretcheth forth the heavens alone; that spreadeth abroad the earth by myself;
18559	723	25	That frustrateth the tokens of the liars, and maketh diviners mad; that turneth wise men backward, and maketh their knowledge foolish;
18560	723	26	That confirmeth the word of his servant, and performeth the counsel of his messengers; that saith to Jerusalem, Thou shalt be inhabited; and to the cities of Judah, Ye shall be built, and I will raise up the decayed places thereof:
18561	723	27	That saith to the deep, Be dry, and I will dry up thy rivers:
18562	723	28	That saith of Cyrus, He is my shepherd, and shall perform all my pleasure: even saying to Jerusalem, Thou shalt be built; and to the temple, Thy foundation shall be laid.
18563	724	1	THUS saith the LORD to his anointed, to Cyrus, whose right hand I have holden, to subdue nations before him; and I will loose the loins of kings, to open before him the two leaved gates; and the gates shall not be shut;
18564	724	2	I will go before thee, and make the crooked places straight: I will break in pieces the gates of brass, and cut in sunder the bars of iron:
18565	724	3	And I will give thee the treasures of darkness, and hidden riches of secret places, that thou mayest know that I, the LORD, which call thee by thy name, am the God of Israel.
18566	724	4	For Jacob my servant's sake, and Israel mine elect, I have even called thee by thy name: I have surnamed thee, though thou hast not known me.
18567	724	5	I am the LORD, and there is none else, there is no God beside me: I girded thee, though thou hast not known me:
18568	724	6	That they may know from the rising of the sun, and from the west, that there is none beside me. I am the LORD, and there is none else.
18569	724	7	I form the light, and create darkness: I make peace, and create evil: I the LORD do all these things.
18570	724	8	Drop down, ye heavens, from above, and let the skies pour down righteousness: let the earth open, and let them bring forth salvation, and let righteousness spring up together; I the LORD have created it.
18571	724	9	Woe unto him that striveth with his Maker! Let the potsherd strive with the potsherds of the earth. Shall the clay say to him that fashioneth it, What makest thou? or thy work, He hath no hands?
18572	724	10	Woe unto him that saith unto his father, What begettest thou? or to the woman, What hast thou brought forth?
18573	724	11	Thus saith the LORD, the Holy One of Israel, and his Maker, Ask me of things to come concerning my sons, and concerning the work of my hands command ye me.
18574	724	12	I have made the earth, and created man upon it: I, even my hands, have stretched out the heavens, and all their host have I commanded.
18575	724	13	I have raised him up in righteousness, and I will direct all his ways: he shall build my city, and he shall let go my captives, not for price nor reward, saith the LORD of hosts.
18576	724	14	Thus saith the LORD, The labour of Egypt, and merchandise of Ethiopia and of the Sabeans, men of stature, shall come over unto thee, and they shall be thine: they shall come after thee; in chains they shall come over, and they shall fall down unto thee, they shall make supplication unto thee, saying, Surely God is in thee; and there is none else, there is no God.
18577	724	15	Verily thou art a God that hidest thyself, O God of Israel, the Saviour.
18578	724	16	They shall be ashamed, and also confounded, all of them: they shall go to confusion together that are makers of idols.
18579	724	17	But Israel shall be saved in the LORD with an everlasting salvation: ye shall not be ashamed nor confounded world without end.
18580	724	18	For thus saith the LORD that created the heavens; God himself that formed the earth and made it; he hath established it, he created it not in vain, he formed it to be inhabited: I am the LORD; and there is none else.
18581	724	19	I have not spoken in secret, in a dark place of the earth: I said not unto the seed of Jacob, Seek ye me in vain: I the LORD speak righteousness, I declare things that are right.
18582	724	20	Assemble yourselves and come; draw near together, ye that are escaped of the nations: they have no knowledge that set up the wood of their graven image, and pray unto a god that cannot save.
18583	724	21	Tell ye, and bring them near; yea, let them take counsel together: who hath declared this from ancient time? who hath told it from that time? have not I the LORD? and there is no God else beside me; a just God and a Saviour; there is none beside me.
18584	724	22	Look unto me, and be ye saved, all the ends of the earth: for I am God, and there is none else.
18585	724	23	I have sworn by myself, the word is gone out of my mouth in righteousness, and shall not return, That unto me every knee shall bow, every tongue shall swear.
18586	724	24	Surely, shall one say, in the LORD have I righteousness and strength: even to him shall men come; and all that are incensed against him shall be ashamed.
18587	724	25	In the LORD shall all the seed of Israel be justified, and shall glory.
18588	725	1	BEL boweth down, Nebo stoopeth, their idols were upon the beasts, and upon the cattle: your carriages were heavy loaden; they are a burden to the weary beast.
18589	725	2	They stoop, they bow down together, they could not deliver the burden, but themselves are gone into captivity.
18590	725	3	Hearken unto me, O house of Jacob, and all the remnant of the house of Israel, which are borne by me from the belly, which are carried from the womb:
18591	725	4	And even to your old age I am he; and even to hoar hairs will I carry you: I have made, and I will bear; even I will carry, and will deliver you.
18592	725	5	To whom will ye liken me, and make me equal, and compare me, that we may be like?
18593	725	6	They lavish gold out of the bag, and weigh silver in the balance, and hire a goldsmith; and he maketh it a god: they fall down, yea, they worship.
18594	725	7	They bear him upon the shoulder, they carry him, and set him in his place, and he standeth; from his place shall he not remove: yea, one shall cry unto him, yet can he not answer, nor save him out of his trouble.
18595	725	8	Remember this, and shew yourselves men: bring it again to mind, O ye transgressors.
18596	725	9	Remember the former things of old: for I am God, and there is none else; I am God, and there is none like me,
18597	725	10	Declaring the end from the beginning, and from ancient times the things that are not yet done, saying, My counsel shall stand, and I will do all my pleasure:
18598	725	11	Calling a ravenous bird from the east, the man that executeth my counsel from a far country: yea, I have spoken it, I will also bring it to pass; I have purposed it, I will also do it.
18599	725	12	Hearken unto me, ye stouthearted, that are far from righteousness:
18600	725	13	I bring near my righteousness; it shall not be far off, and my salvation shall not tarry: and I will place salvation in Zion for Israel my glory.
18601	726	1	COME down, and sit in the dust, O virgin daughter of Babylon, sit on the ground: there is no throne, O daughter of the Chaldeans: for thou shalt no more be called tender and delicate.
18602	726	2	Take the millstones, and grind meal: uncover thy locks, make bare the leg, uncover the thigh, pass over the rivers.
18603	726	3	Thy nakedness shall be uncovered, yea, thy shame shall be seen: I will take vengeance, and I will not meet thee as a man.
18604	726	4	As for our redeemer, the LORD of hosts is his name, the Holy One of Israel.
18605	726	5	Sit thou silent, and get thee into darkness, O daughter of the Chaldeans: for thou shalt no more be called, The lady of kingdoms.
18606	726	6	I was wroth with my people, I have polluted mine inheritance, and given them into thine hand: thou didst shew them no mercy; upon the ancient hast thou very heavily laid thy yoke.
18607	726	7	And thou saidst, I shall be a lady for ever: so that thou didst not lay these things to thy heart, neither didst remember the latter end of it.
18608	726	8	Therefore hear now this, thou that art given to pleasures, that dwellest carelessly, that sayest in thine heart, I am, and none else beside me; I shall not sit as a widow, neither shall I know the loss of children:
18609	726	9	But these two things shall come to thee in a moment in one day, the loss of children, and widowhood: they shall come upon thee in their perfection for the multitude of thy sorceries, and for the great abundance of thine enchantments.
18610	726	10	For thou hast trusted in thy wickedness: thou hast said, None seeth me. Thy wisdom and thy knowledge, it hath perverted thee; and thou hast said in thine heart, I am, and none else beside me.
18611	726	11	Therefore shall evil come upon thee; thou shalt not know from whence it riseth: and mischief shall fall upon thee; thou shalt not be able to put it off: and desolation shall come upon thee suddenly, which thou shalt not know.
18612	726	12	Stand now with thine enchantments, and with the multitude of thy sorceries, wherein thou hast laboured from thy youth; if so be thou shalt be able to profit, if so be thou mayest prevail.
18613	726	13	Thou art wearied in the multitude of thy counsels. Let now the astrologers, the stargazers, the monthly prognosticators, stand up, and save thee from these things that shall come upon thee.
18614	726	14	Behold, they shall be as stubble; the fire shall burn them; they shall not deliver themselves from the power of the flame: there shall not be a coal to warm at, nor fire to sit before it.
18615	726	15	Thus shall they be unto thee with whom thou hast laboured, even thy merchants, from thy youth: they shall wander every one to his quarter; none shall save thee.
18616	727	1	HEAR ye this, O house of Jacob, which are called by the name of Israel, and are come forth out of the waters of Judah, which swear by the name of the LORD, and make mention of the God of Israel, but not in truth, nor in righteousness.
18617	727	2	For they call themselves of the holy city, and stay themselves upon the God of Israel; The LORD of hosts is his name.
18618	727	3	I have declared the former things from the beginning; and they went forth out of my mouth, and I shewed them; I did them suddenly, and they came to pass.
18619	727	4	Because I knew that thou art obstinate, and thy neck is an iron sinew, and thy brow brass;
18620	727	5	I have even from the beginning declared it to thee; before it came to pass I shewed it thee: lest thou shouldest say, Mine idol hath done them, and my graven image, and my molten image, hath commanded them.
18621	727	6	Thou hast heard, see all this; and will not ye declare it? I have shewed thee new things from this time, even hidden things, and thou didst not know them.
18622	727	7	They are created now, and not from the beginning; even before the day when thou heardest them not; lest thou shouldest say, Behold, I knew them.
18623	727	8	Yea, thou heardest not; yea, thou knewest not; yea, from that time that thine ear was not opened: for I knew that thou wouldest deal very treacherously, and wast called a transgressor from the womb.
18624	727	9	For my name's sake will I defer mine anger, and for my praise will I refrain for thee, that I cut thee not off.
18625	727	10	Behold, I have refined thee, but not with silver; I have chosen thee in the furnace of affliction.
18626	727	11	For mine own sake, even for mine own sake, will I do it: for how should my name be polluted? and I will not give my glory unto another.
18627	727	12	Hearken unto me, O Jacob and Israel, my called; I am he; I am the first, I also am the last.
18628	727	13	Mine hand also hath laid the foundation of the earth, and my right hand hath spanned the heavens: when I call unto them, they stand up together.
18629	727	14	All ye, assemble yourselves, and hear; which among them hath declared these things? The LORD hath loved him: he will do his pleasure on Babylon, and his arm shall be on the Chaldeans.
18630	727	15	I, even I, have spoken; yea, I have called him: I have brought him, and he shall make his way prosperous.
18631	727	16	Come ye near unto me, hear ye this; I have not spoken in secret from the beginning; from the time that it was, there am I: and now the Lord GOD, and his Spirit, hath sent me.
18632	727	17	Thus saith the LORD, thy Redeemer, the Holy One of Israel; I am the LORD thy God which teacheth thee to profit, which leadeth thee by the way that thou shouldest go.
18633	727	18	O that thou hadst hearkened to my commandments! then had thy peace been as a river, and thy righteousness as the waves of the sea:
18634	727	19	Thy seed also had been as the sand, and the offspring of thy bowels like the gravel thereof; his name should not have been cut off nor destroyed from before me.
18635	727	20	Go ye forth of Babylon, flee ye from the Chaldeans, with a voice of singing declare ye, tell this, utter it even to the end of the earth; say ye, The LORD hath redeemed his servant Jacob.
18636	727	21	And they thirsted not when he led them through the deserts: he caused the waters to flow out of the rock for them: he clave the rock also, and the waters gushed out.
18637	727	22	There is no peace, saith the LORD, unto the wicked.
18638	728	1	LISTEN, O isles, unto me; and hearken, ye people, from far; The LORD hath called me from the womb; from the bowels of my mother hath he made mention of my name.
18639	728	2	And he hath made my mouth like a sharp sword; in the shadow of his hand hath he hid me, and made me a polished shaft; in his quiver hath he hid me;
18640	728	3	And said unto me, Thou art my servant, O Israel, in whom I will be glorified.
18641	728	4	Then I said, I have laboured in vain, I have spent my strength for nought, and in vain: yet surely my judgment is with the LORD, and my work with my God.
18642	728	5	And now, saith the LORD that formed me from the womb to be his servant, to bring Jacob again to him, Though Israel be not gathered, yet shall I be glorious in the eyes of the LORD, and my God shall be my strength.
18643	728	6	And he said, It is a light thing that thou shouldest be my servant to raise up the tribes of Jacob, and to restore the preserved of Israel: I will also give thee for a light to the Gentiles, that thou mayest be my salvation unto the end of the earth.
18644	728	7	Thus saith the LORD, the Redeemer of Israel, and his Holy One, to him whom man despiseth, to him whom the nation abhorreth, to a servant of rulers, Kings shall see and arise, princes also shall worship, because of the LORD that is faithful, and the Holy One of Israel, and he shall choose thee.
18645	728	8	Thus saith the LORD, In an acceptable time have I heard thee, and in a day of salvation have I helped thee: and I will preserve thee, and give thee for a covenant of the people, to establish the earth, to cause to inherit the desolate heritages;
18646	728	9	That thou mayest say to the prisoners, Go forth; to them that are in darkness, Shew yourselves. They shall feed in the ways, and their pastures shall be in all high places.
18647	728	10	They shall not hunger nor thirst; neither shall the heat nor sun smite them: for he that hath mercy on them shall lead them, even by the springs of water shall he guide them.
18648	728	11	And I will make all my mountains a way, and my highways shall be exalted.
18649	728	12	Behold, these shall come from far: and, lo, these from the north and from the west; and these from the land of Sinim.
18650	728	13	Sing, O heavens; and be joyful, O earth; and break forth into singing, O mountains: for the LORD hath comforted his people, and will have mercy upon his afflicted.
18651	728	14	But Zion said, The LORD hath forsaken me, and my Lord hath forgotten me.
18652	728	15	Can a woman forget her sucking child, that she should not have compassion on the son of her womb? yea, they may forget, yet will I not forget thee.
18653	728	16	Behold, I have graven thee upon the palms of my hands; thy walls are continually before me.
18654	728	17	Thy children shall make haste; thy destroyers and they that made thee waste shall go forth of thee.
18655	728	18	Lift up thine eyes round about, and behold: all these gather themselves together, and come to thee. As I live, saith the LORD, thou shalt surely clothe thee with them all, as with an ornament, and bind them on thee, as a bride doeth.
18656	728	19	For thy waste and thy desolate places, and the land of thy destruction, shall even now be too narrow by reason of the inhabitants, and they that swallowed thee up shall be far away.
18657	728	20	The children which thou shalt have, after thou hast lost the other, shall say again in thine ears, The place is too strait for me: give place to me that I may dwell.
18658	728	21	Then shalt thou say in thine heart, Who hath begotten me these, seeing I have lost my children, and am desolate, a captive, and removing to and fro? and who hath brought up these? Behold, I was left alone; these, where had they been?
18659	728	22	Thus saith the Lord GOD, Behold, I will lift up mine hand to the Gentiles, and set up my standard to the people: and they shall bring thy sons in their arms, and thy daughters shall be carried upon their shoulders.
18660	728	23	And kings shall be thy nursing fathers, and their queens thy nursing mothers: they shall bow down to thee with their face toward the earth, and lick up the dust of thy feet; and thou shalt know that I am the LORD: for they shall not be ashamed that wait for me.
18661	728	24	Shall the prey be taken from the mighty, or the lawful captive delivered?
18662	728	25	But thus saith the LORD, Even the captives of the mighty shall be taken away, and the prey of the terrible shall be delivered: for I will contend with him that contendeth with thee, and I will save thy children.
18663	728	26	And I will feed them that oppress thee with their own flesh; and they shall be drunken with their own blood, as with sweet wine: and all flesh shall know that I the LORD am thy Saviour and thy Redeemer, the mighty One of Jacob.
18664	729	1	THUS saith the LORD, Where is the bill of your mother's divorcement, whom I have put away? or which of my creditors is it to whom I have sold you? Behold, for your iniquities have ye sold yourselves, and for your transgressions is your mother put away.
18665	729	2	Wherefore, when I came, was there no man? when I called, was there none to answer? Is my hand shortened at all, that it cannot redeem? or have I no power to deliver? behold, at my rebuke I dry up the sea, I make the rivers a wilderness: their fish stinketh, because there is no water, and dieth for thirst.
18666	729	3	I clothe the heavens with blackness, and I make sackcloth their covering.
18667	729	4	The Lord GOD hath given me the tongue of the learned, that I should know how to speak a word in season to him that is weary: he wakeneth morning by morning, he wakeneth mine ear to hear as the learned.
18668	729	5	The Lord GOD hath opened mine ear, and I was not rebellious, neither turned away back.
18669	729	6	I gave my back to the smiters, and my cheeks to them that plucked off the hair: I hid not my face from shame and spitting.
18670	729	7	For the Lord GOD will help me; therefore shall I not be confounded: therefore have I set my face like a flint, and I know that I shall not be ashamed.
18671	729	8	He is near that justifieth me; who will contend with me? let us stand together: who is mine adversary? let him come near to me.
18672	729	9	Behold, the Lord GOD will help me; who is he that shall condemn me? lo, they all shall wax old as a garment; the moth shall eat them up.
18673	729	10	Who is among you that feareth the LORD, that obeyeth the voice of his servant, that walketh in darkness, and hath no light? let him trust in the name of the LORD, and stay upon his God.
18674	729	11	Behold, all ye that kindle a fire, that compass yourselves about with sparks: walk in the light of your fire, and in the sparks that ye have kindled. This shall ye have of mine hand; ye shall lie down in sorrow.
18675	730	1	HEARKEN to me, ye that follow after righteousness, ye that seek the LORD: look unto the rock whence ye are hewn, and to the hole of the pit whence ye are digged.
18676	730	2	Look unto Abraham your father, and unto Sarah that bare you: for I called him alone, and blessed him, and increased him.
18677	730	3	For the LORD shall comfort Zion: he will comfort all her waste places; and he will make her wilderness like Eden, and her desert like the garden of the LORD; joy and gladness shall be found therein, thanksgiving, and the voice of melody.
18678	730	4	Hearken unto me, my people; and give ear unto me, O my nation: for a law shall proceed from me, and I will make my judgment to rest for a light of the people.
18679	730	5	My righteousness is near; my salvation is gone forth, and mine arms shall judge the people; the isles shall wait upon me, and on mine arm shall they trust.
18680	730	6	Lift up your eyes to the heavens, and look upon the earth beneath: for the heavens shall vanish away like smoke, and the earth shall wax old like a garment, and they that dwell therein shall die in like manner: but my salvation shall be for ever, and my righteousness shall not be abolished.
18681	730	7	Hearken unto me, ye that know righteousness, the people in whose heart is my law; fear ye not the reproach of men, neither be ye afraid of their revilings.
18682	730	8	For the moth shall eat them up like a garment, and the worm shall eat them like wool: but my righteousness shall be for ever, and my salvation from generation to generation.
18683	730	9	Awake, awake, put on strength, O arm of the LORD; awake, as in the ancient days, in the generations of old. Art thou not it that hath cut Rahab, and wounded the dragon?
18684	730	10	Art thou not it which hath dried the sea, the waters of the great deep; that hath made the depths of the sea a way for the ransomed to pass over?
18685	730	11	Therefore the redeemed of the LORD shall return, and come with singing unto Zion; and everlasting joy shall be upon their head: they shall obtain gladness and joy; and sorrow and mourning shall flee away.
18686	730	12	I, even I, am he that comforteth you: who art thou, that thou shouldest be afraid of a man that shall die, and of the son of man which shall be made as grass;
18687	730	13	And forgettest the LORD thy maker, that hath stretched forth the heavens, and laid the foundations of the earth; and hast feared continually every day because of the fury of the oppressor, as if he were ready to destroy? and where is the fury of the oppressor?
18688	730	14	The captive exile hasteneth that he may be loosed, and that he should not die in the pit, nor that his bread should fail.
18689	730	15	But I am the LORD thy God, that divided the sea, whose waves roared: The LORD of hosts is his name.
18690	730	16	And I have put my words in thy mouth, and I have covered thee in the shadow of mine hand, that I may plant the heavens, and lay the foundations of the earth, and say unto Zion, Thou art my people.
18691	730	17	Awake, awake, stand up, O Jerusalem, which hast drunk at the hand of the LORD the cup of his fury; thou hast drunken the dregs of the cup of trembling, and wrung them out.
18692	730	18	There is none to guide her among all the sons whom she hath brought forth; neither is there any that taketh her by the hand of all the sons that she hath brought up.
18693	730	19	These two things are come unto thee; who shall be sorry for thee? desolation, and destruction, and the famine, and the sword: by whom shall I comfort thee?
18694	730	20	Thy sons have fainted, they lie at the head of all the streets, as a wild bull in a net: they are full of the fury of the LORD, the rebuke of thy God.
18695	730	21	Therefore hear now this, thou afflicted, and drunken, but not with wine:
18696	730	22	Thus saith thy Lord the LORD, and thy God that pleadeth the cause of his people, Behold, I have taken out of thine hand the cup of trembling, even the dregs of the cup of my fury; thou shalt no more drink it again:
18697	730	23	But I will put it into the hand of them that afflict thee; which have said to thy soul, Bow down, that we may go over: and thou hast laid thy body as the ground, and as the street, to them that went over.
18698	731	1	AWAKE, awake; put on thy strength, O Zion; put on thy beautiful garments, O Jerusalem, the holy city: for henceforth there shall no more come into thee the uncircumcised and the unclean.
18699	731	2	Shake thyself from the dust; arise, and sit down, O Jerusalem: loose thyself from the bands of thy neck, O captive daughter of Zion.
18700	731	3	For thus saith the LORD, Ye have sold yourselves for nought; and ye shall be redeemed without money.
18701	731	4	For thus saith the Lord GOD, My people went down aforetime into Egypt to sojourn there; and the Assyrian oppressed them without cause.
18702	731	5	Now therefore, what have I here, saith the LORD, that my people is taken away for nought? they that rule over them make them to howl, saith the LORD; and my name continually every day is blasphemed.
18703	731	6	Therefore my people shall know my name: therefore they shall know in that day that I am he that doth speak: behold, it is I.
18704	731	7	How beautiful upon the mountains are the feet of him that bringeth good tidings, that publisheth peace; that bringeth good tidings of good, that publisheth salvation; that saith unto Zion, Thy God reigneth!
18705	731	8	Thy watchmen shall lift up the voice; with the voice together shall they sing: for they shall see eye to eye, when the LORD shall bring again Zion.
18706	731	9	Break forth into joy, sing together, ye waste places of Jerusalem: for the LORD hath comforted his people, he hath redeemed Jerusalem.
18707	731	10	The LORD hath made bare his holy arm in the eyes of all the nations; and all the ends of the earth shall see the salvation of our God.
18708	731	11	Depart ye, depart ye, go ye out from thence, touch no unclean thing; go ye out of the midst of her; be ye clean, that bear the vessels of the LORD.
18709	731	12	For ye shall not go out with haste, nor go by flight: for the LORD will go before you; and the God of Israel will be your rereward.
18710	731	13	Behold, my servant shall deal prudently, he shall be exalted and extolled, and be very high.
18711	731	14	As many were astonied at thee; his visage was so marred more than any man, and his form more than the sons of men:
18712	731	15	So shall he sprinkle many nations; the kings shall shut their mouths at him: for that which had not been told them shall they see; and that which they had not heard shall they consider.
18713	732	1	WHO hath believed our report? and to whom is the arm of the LORD revealed?
18714	732	2	For he shall grow up before him as a tender plant, and as a root out of a dry ground: he hath no form nor comeliness; and when we shall see him, there is no beauty that we should desire him.
18715	732	3	He is despised and rejected of men; a man of sorrows, and acquainted with grief: and we hid as it were our faces from him; he was despised, and we esteemed him not.
18716	732	4	Surely he hath borne our griefs, and carried our sorrows: yet we did esteem him stricken, smitten of God, and afflicted.
18717	732	5	But he was wounded for our transgressions, he was bruised for our iniquities: the chastisement of our peace was upon him; and with his stripes we are healed.
18718	732	6	All we like sheep have gone astray; we have turned every one to his own way; and the LORD hath laid on him the iniquity of us all.
18719	732	7	He was oppressed, and he was afflicted, yet he opened not his mouth: he is brought as a lamb to the slaughter, and as a sheep before her shearers is dumb, so he openeth not his mouth.
18720	732	8	He was taken from prison and from judgment: and who shall declare his generation? for he was cut off out of the land of the living: for the transgression of my people was he stricken.
18721	732	9	And he made his grave with the wicked, and with the rich in his death; because he had done no violence, neither was any deceit in his mouth.
18722	732	10	Yet it pleased the LORD to bruise him; he hath put him to grief: when thou shalt make his soul an offering for sin, he shall see his seed, he shall prolong his days, and the pleasure of the LORD shall prosper in his hand.
18723	732	11	He shall see of the travail of his soul, and shall be satisfied: by his knowledge shall my righteous servant justify many; for he shall bear their iniquities.
18724	732	12	Therefore will I divide him a portion with the great, and he shall divide the spoil with the strong; because he hath poured out his soul unto death: and he was numbered with the transgressors; and he bare the sin of many, and made intercession for the transgressors.
18725	733	1	SING, O barren, thou that didst not bear; break forth into singing, and cry aloud, thou that didst not travail with child: for more are the children of the desolate than the children of the married wife, saith the LORD.
18726	733	2	Enlarge the place of thy tent, and let them stretch forth the curtains of thine habitations: spare not, lengthen thy cords, and strengthen thy stakes;
18727	733	3	For thou shalt break forth on the right hand and on the left; and thy seed shall inherit the Gentiles, and make the desolate cities to be inhabited.
18728	733	4	Fear not; for thou shalt not be ashamed: neither be thou confounded; for thou shalt not be put to shame: for thou shalt forget the shame of thy youth, and shalt not remember the reproach of thy widowhood any more.
18729	733	5	For thy Maker is thine husband; the LORD of hosts is his name; and thy Redeemer the Holy One of Israel; The God of the whole earth shall he be called.
18730	733	6	For the LORD hath called thee as a woman forsaken and grieved in spirit, and a wife of youth, when thou wast refused, saith thy God.
18731	733	7	For a small moment have I forsaken thee; but with great mercies will I gather thee.
18732	733	8	In a little wrath I hid my face from thee for a moment; but with everlasting kindness will I have mercy on thee, saith the LORD thy Redeemer.
18733	733	9	For this is as the waters of Noah unto me: for as I have sworn that the waters of Noah should no more go over the earth; so have I sworn that I would not be wroth with thee, nor rebuke thee.
18734	733	10	For the mountains shall depart, and the hills be removed; but my kindness shall not depart from thee, neither shall the covenant of my peace be removed, saith the LORD that hath mercy on thee.
18735	733	11	O thou afflicted, tossed with tempest, and not comforted, behold, I will lay thy stones with fair colours, and lay thy foundations with sapphires.
18736	733	12	And I will make thy windows of agates, and thy gates of carbuncles, and all thy borders of pleasant stones.
18737	733	13	And all thy children shall be taught of the LORD; and great shall be the peace of thy children.
18738	733	14	In righteousness shalt thou be established: thou shalt be far from oppression; for thou shalt not fear: and from terror; for it shall not come near thee.
18739	733	15	Behold, they shall surely gather together, but not by me: whosoever shall gather together against thee shall fall for thy sake.
18740	733	16	Behold, I have created the smith that bloweth the coals in the fire, and that bringeth forth an instrument for his work; and I have created the waster to destroy.
18741	733	17	No weapon that is formed against thee shall prosper; and every tongue that shall rise against thee in judgment thou shalt condemn. This is the heritage of the servants of the LORD, and their righteousness is of me, saith the LORD.
18742	734	1	HO, every one that thirsteth, come ye to the waters, and he that hath no money; come ye, buy, and eat; yea, come, buy wine and milk without money and without price.
18743	734	2	Wherefore do ye spend money for that which is not bread? and your labour for that which satisfieth not? hearken diligently unto me, and eat ye that which is good, and let your soul delight itself in fatness.
18744	734	3	Incline your ear, and come unto me: hear, and your soul shall live; and I will make an everlasting covenant with you, even the sure mercies of David.
18745	734	4	Behold, I have given him for a witness to the people, a leader and commander to the people.
18746	734	5	Behold, thou shalt call a nation that thou knowest not, and nations that knew not thee shall run unto thee because of the LORD thy God, and for the Holy One of Israel; for he hath glorified thee.
18747	734	6	Seek ye the LORD while he may be found, call ye upon him while he is near:
18748	734	7	Let the wicked forsake his way, and the unrighteous man his thoughts: and let him return unto the LORD, and he will have mercy upon him; and to our God, for he will abundantly pardon.
18749	734	8	For my thoughts are not your thoughts, neither are your ways my ways, saith the LORD.
18750	734	9	For as the heavens are higher than the earth, so are my ways higher than your ways, and my thoughts than your thoughts.
18751	734	10	For as the rain cometh down, and the snow from heaven, and returneth not thither, but watereth the earth, and maketh it bring forth and bud, that it may give seed to the sower, and bread to the eater:
18752	734	11	So shall my word be that goeth forth out of my mouth: it shall not return unto me void, but it shall accomplish that which I please, and it shall prosper in the thing whereto I sent it.
18753	734	12	For ye shall go out with joy, and be led forth with peace: the mountains and the hills shall break forth before you into singing, and all the trees of the field shall clap their hands.
18754	734	13	Instead of the thorn shall come up the fir tree, and instead of the brier shall come up the myrtle tree: and it shall be to the LORD for a name, for an everlasting sign that shall not be cut off.
18755	735	1	THUS saith the LORD, Keep ye judgment, and do justice: for my salvation is near to come, and my righteousness to be revealed.
18756	735	2	Blessed is the man that doeth this, and the son of man that layeth hold on it; that keepeth the sabbath from polluting it, and keepeth his hand from doing any evil.
18757	735	3	Neither let the son of the stranger, that hath joined himself to the LORD, speak, saying, The LORD hath utterly separated me from his people: neither let the eunuch say, Behold, I am a dry tree.
18758	735	4	For thus saith the LORD unto the eunuchs that keep my sabbaths, and choose the things that please me, and take hold of my covenant;
18759	735	5	Even unto them will I give in mine house and within my walls a place and a name better than of sons and of daughters: I will give them an everlasting name, that shall not be cut off.
18760	735	6	Also the sons of the stranger, that join themselves to the LORD, to serve him, and to love the name of the LORD, to be his servants, every one that keepeth the sabbath from polluting it, and taketh hold of my covenant;
18761	735	7	Even them will I bring to my holy mountain, and make them joyful in my house of prayer: their burnt offerings and their sacrifices shall be accepted upon mine altar; for mine house shall be called an house of prayer for all people.
18762	735	8	The Lord GOD which gathereth the outcasts of Israel saith, Yet will I gather others to him, beside those that are gathered unto him.
18763	735	9	All ye beasts of the field, come to devour, yea, all ye beasts in the forest.
18764	735	10	His watchmen are blind: they are all ignorant, they are all dumb dogs, they cannot bark; sleeping, lying down, loving to slumber.
18765	735	11	Yea, they are greedy dogs which can never have enough, and they are shepherds that cannot understand: they all look to their own way, every one for his gain, from his quarter.
18766	735	12	Come ye, say they, I will fetch wine, and we will fill ourselves with strong drink; and to morrow shall be as this day, and much more abundant.
18767	736	1	THE righteous perisheth, and no man layeth it to heart: and merciful men are taken away, none considering that the righteous is taken away from the evil to come.
18768	736	2	He shall enter into peace: they shall rest in their beds, each one walking in his uprightness.
18769	736	3	But draw near hither, ye sons of the sorceress, the seed of the adulterer and the whore.
18770	736	4	Against whom do ye sport yourselves? against whom make ye a wide mouth, and draw out the tongue? are ye not children of transgression, a seed of falsehood,
18771	736	5	Enflaming yourselves with idols under every green tree, slaying the children in the valleys under the clifts of the rocks?
18772	736	6	Among the smooth stones of the stream is thy portion; they, they are thy lot: even to them hast thou poured a drink offering, thou hast offered a meat offering. Should I receive comfort in these?
18773	736	7	Upon a lofty and high mountain hast thou set thy bed: even thither wentest thou up to offer sacrifice.
18774	736	8	Behind the doors also and the posts hast thou set up thy remembrance: for thou hast discovered thyself to another than me, and art gone up; thou hast enlarged thy bed, and made thee a covenant with them; thou lovedst their bed where thou sawest it.
18775	736	9	And thou wentest to the king with ointment, and didst increase thy perfumes, and didst send thy messengers far off, and didst debase thyself even unto hell.
18776	736	10	Thou art wearied in the greatness of thy way; yet saidst thou not, There is no hope: thou hast found the life of thine hand; therefore thou wast not grieved.
18777	736	11	And of whom hast thou been afraid or feared, that thou hast lied, and hast not remembered me, nor laid it to thy heart? have not I held my peace even of old, and thou fearest me not?
18778	736	12	I will declare thy righteousness, and thy works; for they shall not profit thee.
18779	736	13	When thou criest, let thy companies deliver thee; but the wind shall carry them all away; vanity shall take them: but he that putteth his trust in me shall possess the land, and shall inherit my holy mountain;
18780	736	14	And shall say, Cast ye up, cast ye up, prepare the way, take up the stumblingblock out of the way of my people.
18781	736	15	For thus saith the high and lofty One that inhabiteth eternity, whose name is Holy; I dwell in the high and holy place, with him also that is of a contrite and humble spirit, to revive the spirit of the humble, and to revive the heart of the contrite ones.
18782	736	16	For I will not contend for ever, neither will I be always wroth: for the spirit should fail before me, and the souls which I have made.
18783	736	17	For the iniquity of his covetousness was I wroth, and smote him: I hid me, and was wroth, and he went on frowardly in the way of his heart.
18784	736	18	I have seen his ways, and will heal him: I will lead him also, and restore comforts unto him and to his mourners.
18785	736	19	I create the fruit of the lips; Peace, peace to him that is far off, and to him that is near, saith the LORD; and I will heal him.
18786	736	20	But the wicked are like the troubled sea, when it cannot rest, whose waters cast up mire and dirt.
18787	736	21	There is no peace, saith my God, to the wicked.
18788	737	1	CRY aloud, spare not, lift up thy voice like a trumpet, and shew my people their transgression, and the house of Jacob their sins.
18789	737	2	Yet they seek me daily, and delight to know my ways, as a nation that did righteousness, and forsook not the ordinance of their God: they ask of me the ordinances of justice; they take delight in approaching to God.
18790	737	3	Wherefore have we fasted, say they, and thou seest not? wherefore have we afflicted our soul, and thou takest no knowledge? Behold, in the day of your fast ye find pleasure, and exact all your labours.
18791	737	4	Behold, ye fast for strife and debate, and to smite with the fist of wickedness: ye shall not fast as ye do this day, to make your voice to be heard on high.
18792	737	5	Is it such a fast that I have chosen? a day for a man to afflict his soul? is it to bow down his head as a bulrush, and to spread sackcloth and ashes under him? wilt thou call this a fast, and an acceptable day to the LORD?
18793	737	6	Is not this the fast that I have chosen? to loose the bands of wickedness, to undo the heavy burdens, and to let the oppressed go free, and that ye break every yoke?
18794	737	7	Is it not to deal thy bread to the hungry, and that thou bring the poor that are cast out to thy house? when thou seest the naked, that thou cover him; and that thou hide not thyself from thine own flesh?
18795	737	8	Then shall thy light break forth as the morning, and thine health shall spring forth speedily: and thy righteousness shall go before thee; the glory of the LORD shall be thy rereward.
18796	737	9	Then shalt thou call, and the LORD shall answer; thou shalt cry, and he shall say, Here I am. If thou take away from the midst of thee the yoke, the putting forth of the finger, and speaking vanity;
18797	737	10	And if thou draw out thy soul to the hungry, and satisfy the afflicted soul; then shall thy light rise in obscurity, and thy darkness be as the noonday:
18798	737	11	And the LORD shall guide thee continually, and satisfy thy soul in drought, and make fat thy bones: and thou shalt be like a watered garden, and like a spring of water, whose waters fail not.
18799	737	12	And they that shall be of thee shall build the old waste places: thou shalt raise up the foundations of many generations; and thou shalt be called, The repairer of the breach, The restorer of paths to dwell in.
18800	737	13	If thou turn away thy foot from the sabbath, from doing thy pleasure on my holy day; and call the sabbath a delight, the holy of the LORD, honourable; and shalt honour him, not doing thine own ways, nor finding thine own pleasure, nor speaking thine own words:
18801	737	14	Then shalt thou delight thyself in the LORD; and I will cause thee to ride upon the high places of the earth, and feed thee with the heritage of Jacob thy father: for the mouth of the LORD hath spoken it.
18802	738	1	BEHOLD, the LORD's hand is not shortened, that it cannot save; neither his ear heavy, that it cannot hear:
18803	738	2	But your iniquities have separated between you and your God, and your sins have hid his face from you, that he will not hear.
18804	738	3	For your hands are defiled with blood, and your fingers with iniquity; your lips have spoken lies, your tongue hath muttered perverseness.
18805	738	4	None calleth for justice, nor any pleadeth for truth: they trust in vanity, and speak lies; they conceive mischief, and bring forth iniquity.
18806	738	5	They hatch cockatrice' eggs, and weave the spider's web: he that eateth of their eggs dieth, and that which is crushed breaketh out into a viper.
18807	738	6	Their webs shall not become garments, neither shall they cover themselves with their works: their works are works of iniquity, and the act of violence is in their hands.
18808	738	7	Their feet run to evil, and they make haste to shed innocent blood: their thoughts are thoughts of iniquity; wasting and destruction are in their paths.
18809	738	8	The way of peace they know not; and there is no judgment in their goings: they have made them crooked paths: whosoever goeth therein shall not know peace.
18810	738	9	Therefore is judgment far from us, neither doth justice overtake us: we wait for light, but behold obscurity; for brightness, but we walk in darkness.
18811	738	10	We grope for the wall like the blind, and we grope as if we had no eyes: we stumble at noonday as in the night; we are in desolate places as dead men.
18812	738	11	We roar all like bears, and mourn sore like doves: we look for judgment, but there is none; for salvation, but it is far off from us.
18813	738	12	For our transgressions are multiplied before thee, and our sins testify against us: for our transgressions are with us; and as for our iniquities, we know them;
18814	738	13	In transgressing and lying against the LORD, and departing away from our God, speaking oppression and revolt, conceiving and uttering from the heart words of falsehood.
18815	738	14	And judgment is turned away backward, and justice standeth afar off: for truth is fallen in the street, and equity cannot enter.
18816	738	15	Yea, truth faileth; and he that departeth from evil maketh himself a prey: and the LORD saw it, and it displeased him that there was no judgment.
18817	738	16	And he saw that there was no man, and wondered that there was no intercessor: therefore his arm brought salvation unto him; and his righteousness, it sustained him.
18818	738	17	For he put on righteousness as a breastplate, and an helmet of salvation upon his head; and he put on the garments of vengeance for clothing, and was clad with zeal as a cloke.
18819	738	18	According to their deeds, accordingly he will repay, fury to his adversaries, recompence to his enemies; to the islands he will repay recompence.
18820	738	19	So shall they fear the name of the LORD from the west, and his glory from the rising of the sun. When the enemy shall come in like a flood, the Spirit of the LORD shall lift up a standard against him.
18821	738	20	And the Redeemer shall come to Zion, and unto them that turn from transgression in Jacob, saith the LORD.
18822	738	21	As for me, this is my covenant with them, saith the LORD; My spirit that is upon thee, and my words which I have put in thy mouth, shall not depart out of thy mouth, nor out of the mouth of thy seed, nor out of the mouth of thy seed's seed, saith the LORD, from henceforth and for ever.
18823	739	1	ARISE, shine; for thy light is come, and the glory of the LORD is risen upon thee.
18824	739	2	For, behold, the darkness shall cover the earth, and gross darkness the people: but the LORD shall arise upon thee, and his glory shall be seen upon thee.
18825	739	3	And the Gentiles shall come to thy light, and kings to the brightness of thy rising.
18826	739	4	Lift up thine eyes round about, and see: all they gather themselves together, they come to thee: thy sons shall come from far, and thy daughters shall be nursed at thy side.
18827	739	5	Then thou shalt see, and flow together, and thine heart shall fear, and be enlarged; because the abundance of the sea shall be converted unto thee, the forces of the Gentiles shall come unto thee.
18828	739	6	The multitude of camels shall cover thee, the dromedaries of Midian and Ephah; all they from Sheba shall come: they shall bring gold and incense; and they shall shew forth the praises of the LORD.
18829	739	7	All the flocks of Kedar shall be gathered together unto thee, the rams of Nebaioth shall minister unto thee: they shall come up with acceptance on mine altar, and I will glorify the house of my glory.
18830	739	8	Who are these that fly as a cloud, and as the doves to their windows?
18831	739	9	Surely the isles shall wait for me, and the ships of Tarshish first, to bring thy sons from far, their silver and their gold with them, unto the name of the LORD thy God, and to the Holy One of Israel, because he hath glorified thee.
18832	739	10	And the sons of strangers shall build up thy walls, and their kings shall minister unto thee: for in my wrath I smote thee, but in my favour have I had mercy on thee.
18833	739	11	Therefore thy gates shall be open continually; they shall not be shut day nor night; that men may bring unto thee the forces of the Gentiles, and that their kings may be brought.
18834	739	12	For the nation and kingdom that will not serve thee shall perish; yea, those nations shall be utterly wasted.
18835	739	13	The glory of Lebanon shall come unto thee, the fir tree, the pine tree, and the box together, to beautify the place of my sanctuary; and I will make the place of my feet glorious.
18836	739	14	The sons also of them that afflicted thee shall come bending unto thee; and all they that despised thee shall bow themselves down at the soles of thy feet; and they shall call thee, The city of the LORD, The Zion of the Holy One of Israel.
18837	739	15	Whereas thou hast been forsaken and hated, so that no man went through thee, I will make thee an eternal excellency, a joy of many generations.
18838	739	16	Thou shalt also suck the milk of the Gentiles, and shalt suck the breast of kings: and thou shalt know that I the LORD am thy Saviour and thy Redeemer, the mighty One of Jacob.
18839	739	17	For brass I will bring gold, and for iron I will bring silver, and for wood brass, and for stones iron: I will also make thy officers peace, and thine exactors righteousness.
18840	739	18	Violence shall no more be heard in thy land, wasting nor destruction within thy borders; but thou shalt call thy walls Salvation, and thy gates Praise.
18841	739	19	The sun shall be no more thy light by day; neither for brightness shall the moon give light unto thee: but the LORD shall be unto thee an everlasting light, and thy God thy glory.
18842	739	20	Thy sun shall no more go down; neither shall thy moon withdraw itself: for the LORD shall be thine everlasting light, and the days of thy mourning shall be ended.
18843	739	21	Thy people also shall be all righteous: they shall inherit the land for ever, the branch of my planting, the work of my hands, that I may be glorified.
18844	739	22	A little one shall become a thousand, and a small one a strong nation: I the LORD will hasten it in his time.
18845	740	1	THE Spirit of the Lord GOD is upon me; because the LORD hath anointed me to preach good tidings unto the meek; he hath sent me to bind up the brokenhearted, to proclaim liberty to the captives, and the opening of the prison to them that are bound;
18846	740	2	To proclaim the acceptable year of the LORD, and the day of vengeance of our God; to comfort all that mourn;
18847	740	3	To appoint unto them that mourn in Zion, to give unto them beauty for ashes, the oil of joy for mourning, the garment of praise for the spirit of heaviness; that they might be called trees of righteousness, the planting of the LORD, that he might be glorified.
18848	740	4	And they shall build the old wastes, they shall raise up the former desolations, and they shall repair the waste cities, the desolations of many generations.
18849	740	5	And strangers shall stand and feed your flocks, and the sons of the alien shall be your plowmen and your vinedressers.
18850	740	6	But ye shall be named the Priests of the LORD: men shall call you the Ministers of our God: ye shall eat the riches of the Gentiles, and in their glory shall ye boast yourselves.
18851	740	7	For your shame ye shall have double; and for confusion they shall rejoice in their portion: therefore in their land they shall possess the double: everlasting joy shall be unto them.
18852	740	8	For I the LORD love judgment, I hate robbery for burnt offering; and I will direct their work in truth, and I will make an everlasting covenant with them.
18853	740	9	And their seed shall be known among the Gentiles, and their offspring among the people: all that see them shall acknowledge them, that they are the seed which the LORD hath blessed.
18854	740	10	I will greatly rejoice in the LORD, my soul shall be joyful in my God; for he hath clothed me with the garments of salvation, he hath covered me with the robe of righteousness, as a bridegroom decketh himself with ornaments, and as a bride adorneth herself with her jewels.
18855	740	11	For as the earth bringeth forth her bud, and as the garden causeth the things that are sown in it to spring forth; so the Lord GOD will cause righteousness and praise to spring forth before all the nations.
18856	741	1	FOR Zion's sake will I not hold my peace, and for Jerusalem's sake I will not rest, until the righteousness thereof go forth as brightness, and the salvation thereof as a lamp that burneth.
18857	741	2	And the Gentiles shall see thy righteousness, and all kings thy glory: and thou shalt be called by a new name, which the mouth of the LORD shall name.
18858	741	3	Thou shalt also be a crown of glory in the hand of the LORD, and a royal diadem in the hand of thy God.
18859	741	4	Thou shalt no more be termed Forsaken; neither shall thy land any more be termed Desolate: but thou shalt be called Hephzi-bah, and thy land Beulah: for the LORD delighteth in thee, and thy land shall be married.
18860	741	5	For as a young man marrieth a virgin, so shall thy sons marry thee: and as the bridegroom rejoiceth over the bride, so shall thy God rejoice over thee.
18861	741	6	I have set watchmen upon thy walls, O Jerusalem, which shall never hold their peace day nor night: ye that make mention of the LORD, keep not silence,
18862	741	7	And give him no rest, till he establish, and till he make Jerusalem a praise in the earth.
18863	741	8	The LORD hath sworn by his right hand, and by the arm of his strength, Surely I will no more give thy corn to be meat for thine enemies; and the sons of the stranger shall not drink thy wine, for the which thou hast laboured:
18864	741	9	But they that have gathered it shall eat it, and praise the LORD; and they that have brought it together shall drink it in the courts of my holiness.
18865	741	10	Go through, go through the gates; prepare ye the way of the people; cast up, cast up the highway; gather out the stones; lift up a standard for the people.
18866	741	11	Behold, the LORD hath proclaimed unto the end of the world, Say ye to the daughter of Zion, Behold, thy salvation cometh; behold, his reward is with him, and his work before him.
18867	741	12	And they shall call them, The holy people, The redeemed of the LORD: and thou shalt be called, Sought out, A city not forsaken.
18868	742	1	WHO is this that cometh from Edom, with dyed garments from Bozrah? this that is glorious in his apparel, travelling in the greatness of his strength? I that speak in righteousness, mighty to save.
18869	742	2	Wherefore art thou red in thine apparel, and thy garments like him that treadeth in the winefat?
18870	742	3	I have trodden the winepress alone; and of the people there was none with me: for I will tread them in mine anger, and trample them in my fury; and their blood shall be sprinkled upon my garments, and I will stain all my raiment.
18871	742	4	For the day of vengeance is in mine heart, and the year of my redeemed is come.
18872	742	5	And I looked, and there was none to help; and I wondered that there was none to uphold: therefore mine own arm brought salvation unto me; and my fury, it upheld me.
18873	742	6	And I will tread down the people in mine anger, and make them drunk in my fury, and I will bring down their strength to the earth.
18874	742	7	I will mention the lovingkindnesses of the LORD, and the praises of the LORD, according to all that the LORD hath bestowed on us, and the great goodness toward the house of Israel, which he hath bestowed on them according to his mercies, and according to the multitude of his lovingkindnesses.
18875	742	8	For he said, Surely they are my people, children that will not lie: so he was their Saviour.
18876	742	9	In all their affliction he was afflicted, and the angel of his presence saved them: in his love and in his pity he redeemed them; and he bare them, and carried them all the days of old.
18877	742	10	But they rebelled, and vexed his holy Spirit: therefore he was turned to be their enemy, and he fought against them.
18878	742	11	Then he remembered the days of old, Moses, and his people, saying, Where is he that brought them up out of the sea with the shepherd of his flock? where is he that put his holy Spirit within him?
18879	742	12	That led them by the right hand of Moses with his glorious arm, dividing the water before them, to make himself an everlasting name?
18880	742	13	That led them through the deep, as an horse in the wilderness, that they should not stumble?
18881	742	14	As a beast goeth down into the valley, the Spirit of the LORD caused him to rest: so didst thou lead thy people, to make thyself a glorious name.
18882	742	15	Look down from heaven, and behold from the habitation of thy holiness and of thy glory: where is thy zeal and thy strength, the sounding of thy bowels and of thy mercies toward me? are they restrained?
18883	742	16	Doubtless thou art our father, though Abraham be ignorant of us, and Israel acknowledge us not: thou, O LORD, art our father, our redeemer; thy name is from everlasting.
18884	742	17	O LORD, why hast thou made us to err from thy ways, and hardened our heart from thy fear? Return for thy servants' sake, the tribes of thine inheritance.
18885	742	18	The people of thy holiness have possessed it but a little while: our adversaries have trodden down thy sanctuary.
18886	742	19	We are thine: thou never barest rule over them; they were not called by thy name.
18887	743	1	OH that thou wouldest rend the heavens, that thou wouldest come down, that the mountains might flow down at thy presence,
18888	743	2	As when the melting fire burneth, the fire causeth the waters to boil, to make thy name known to thine adversaries, that the nations may tremble at thy presence!
18889	743	3	When thou didst terrible things which we looked not for, thou camest down, the mountains flowed down at thy presence.
18890	743	4	For since the beginning of the world men have not heard, nor perceived by the ear, neither hath the eye seen, O God, beside thee, what he hath prepared for him that waiteth for him.
18891	743	5	Thou meetest him that rejoiceth and worketh righteousness, those that remember thee in thy ways: behold, thou art wroth; for we have sinned: in those is continuance, and we shall be saved.
18892	743	6	But we are all as an unclean thing, and all our righteousnesses are as filthy rags; and we all do fade as a leaf; and our iniquities, like the wind, have taken us away.
18893	743	7	And there is none that calleth upon thy name, that stirreth up himself to take hold of thee: for thou hast hid thy face from us, and hast consumed us, because of our iniquities.
18894	743	8	But now, O LORD, thou art our father; we are the clay, and thou our potter; and we all are the work of thy hand.
18895	743	9	Be not wroth very sore, O LORD, neither remember iniquity for ever: behold, see, we beseech thee, we are all thy people.
18896	743	10	Thy holy cities are a wilderness, Zion is a wilderness, Jerusalem a desolation.
18897	743	11	Our holy and our beautiful house, where our fathers praised thee, is burned up with fire: and all our pleasant things are laid waste.
18898	743	12	Wilt thou refrain thyself for these things, O LORD? wilt thou hold thy peace, and afflict us very sore?
18899	744	1	I AM sought of them that asked not for me; I am found of them that sought me not: I said, Behold me, behold me, unto a nation that was not called by my name.
18900	744	2	I have spread out my hands all the day unto a rebellious people, which walketh in a way that was not good, after their own thoughts;
18901	744	3	A people that provoketh me to anger continually to my face; that sacrificeth in gardens, and burneth incense upon altars of brick;
18902	744	4	Which remain among the graves, and lodge in the monuments, which eat swine's flesh, and broth of abominable things is in their vessels;
18903	744	5	Which say, Stand by thyself, come not near to me; for I am holier than thou. These are a smoke in my nose, a fire that burneth all the day.
18904	744	6	Behold, it is written before me: I will not keep silence, but will recompense, even recompense into their bosom,
18905	744	7	Your iniquities, and the iniquities of your fathers together, saith the LORD, which have burned incense upon the mountains, and blasphemed me upon the hills: therefore will I measure their former work into their bosom.
18906	744	8	Thus saith the LORD, As the new wine is found in the cluster, and one saith, Destroy it not; for a blessing is in it: so will I do for my servants' sakes, that I may not destroy them all.
18907	744	9	And I will bring forth a seed out of Jacob, and out of Judah an inheritor of my mountains: and mine elect shall inherit it, and my servants shall dwell there.
18908	744	10	And Sharon shall be a fold of flocks, and the valley of Achor a place for the herds to lie down in, for my people that have sought me.
18909	744	11	But ye are they that forsake the LORD, that forget my holy mountain, that prepare a table for that troop, and that furnish the drink offering unto that number.
18910	744	12	Therefore will I number you to the sword, and ye shall all bow down to the slaughter: because when I called, ye did not answer; when I spake, ye did not hear; but did evil before mine eyes, and did choose that wherein I delighted not.
18911	744	13	Therefore thus saith the Lord GOD, Behold, my servants shall eat, but ye shall be hungry: behold, my servants shall drink, but ye shall be thirsty: behold, my servants shall rejoice, but ye shall be ashamed:
18912	744	14	Behold, my servants shall sing for joy of heart, but ye shall cry for sorrow of heart, and shall howl for vexation of spirit.
18913	744	15	And ye shall leave your name for a curse unto my chosen: for the Lord GOD shall slay thee, and call his servants by another name:
18914	744	16	That he who blesseth himself in the earth shall bless himself in the God of truth; and he that sweareth in the earth shall swear by the God of truth; because the former troubles are forgotten, and because they are hid from mine eyes.
18915	744	17	For, behold, I create new heavens and a new earth: and the former shall not be remembered, nor come into mind.
18916	744	18	But be ye glad and rejoice for ever in that which I create: for, behold, I create Jerusalem a rejoicing, and her people a joy.
18917	744	19	And I will rejoice in Jerusalem, and joy in my people: and the voice of weeping shall be no more heard in her, nor the voice of crying.
18918	744	20	There shall be no more thence an infant of days, nor an old man that hath not filled his days: for the child shall die an hundred years old; but the sinner being an hundred years old shall be accursed.
18919	744	21	And they shall build houses, and inhabit them; and they shall plant vineyards, and eat the fruit of them.
18920	744	22	They shall not build, and another inhabit; they shall not plant, and another eat: for as the days of a tree are the days of my people, and mine elect shall long enjoy the work of their hands.
18921	744	23	They shall not labour in vain, nor bring forth for trouble; for they are the seed of the blessed of the LORD, and their offspring with them.
18922	744	24	And it shall come to pass, that before they call, I will answer; and while they are yet speaking, I will hear.
18923	744	25	The wolf and the lamb shall feed together, and the lion shall eat straw like the bullock: and dust shall be the serpent's meat. They shall not hurt nor destroy in all my holy mountain, saith the LORD.
18924	745	1	THUS saith the LORD, The heaven is my throne, and the earth is my footstool: where is the house that ye build unto me? and where is the place of my rest?
18925	745	2	For all those things hath mine hand made, and all those things have been, saith the LORD: but to this man will I look, even to him that is poor and of a contrite spirit, and trembleth at my word.
18926	745	3	He that killeth an ox is as if he slew a man; he that sacrificeth a lamb, as if he cut off a dog's neck; he that offereth an oblation, as if he offered swine's blood; he that burneth incense, as if he blessed an idol. Yea, they have chosen their own ways, and their soul delighteth in their abominations.
18927	745	4	I also will choose their delusions, and will bring their fears upon them; because when I called, none did answer; when I spake, they did not hear: but they did evil before mine eyes, and chose that in which I delighted not.
18928	745	5	Hear the word of the LORD, ye that tremble at his word; your brethren that hated you, that cast you out for my name's sake, said, Let the LORD be glorified: but he shall appear to your joy, and they shall be ashamed.
18929	745	6	A voice of noise from the city, a voice from the temple, a voice of the LORD that rendereth recompence to his enemies.
18930	745	7	Before she travailed, she brought forth; before her pain came, she was delivered of a man child.
18931	745	8	Who hath heard such a thing? who hath seen such things? Shall the earth be made to bring forth in one day? or shall a nation be born at once? for as soon as Zion travailed, she brought forth her children.
18932	745	9	Shall I bring to the birth, and not cause to bring forth? saith the LORD: shall I cause to bring forth, and shut the womb? saith thy God.
18933	745	10	Rejoice ye with Jerusalem, and be glad with her, all ye that love her: rejoice for joy with her, all ye that mourn for her:
18934	745	11	That ye may suck, and be satisfied with the breasts of her consolations; that ye may milk out, and be delighted with the abundance of her glory.
18935	745	12	For thus saith the LORD, Behold, I will extend peace to her like a river, and the glory of the Gentiles like a flowing stream: then shall ye suck, ye shall be borne upon her sides, and be dandled upon her knees.
18936	745	13	As one whom his mother comforteth, so will I comfort you; and ye shall be comforted in Jerusalem.
18937	745	14	And when ye see this, your heart shall rejoice, and your bones shall flourish like an herb: and the hand of the LORD shall be known toward his servants, and his indignation toward his enemies.
18938	745	15	For, behold, the LORD will come with fire, and with his chariots like a whirlwind, to render his anger with fury, and his rebuke with flames of fire.
18939	745	16	For by fire and by his sword will the LORD plead with all flesh: and the slain of the LORD shall be many.
18940	745	17	They that sanctify themselves, and purify themselves in the gardens behind one tree in the midst, eating swine's flesh, and the abomination, and the mouse, shall be consumed together, saith the LORD.
18941	745	18	For I know their works and their thoughts: it shall come, that I will gather all nations and tongues; and they shall come, and see my glory.
18942	745	19	And I will set a sign among them, and I will send those that escape of them unto the nations, to Tarshish, Pul, and Lud, that draw the bow, to Tubal, and Javan, to the isles afar off, that have not heard my fame, neither have seen my glory; and they shall declare my glory among the Gentiles.
18943	745	20	And they shall bring all your brethren for an offering unto the LORD out of all nations upon horses, and in chariots, and in litters, and upon mules, and upon swift beasts, to my holy mountain Jerusalem, saith the LORD, as the children of Israel bring an offering in a clean vessel into the house of the LORD.
18944	745	21	And I will also take of them for priests and for Levites, saith the LORD.
18945	745	22	For as the new heavens and the new earth, which I will make, shall remain before me, saith the LORD, so shall your seed and your name remain.
18946	745	23	And it shall come to pass, that from one new moon to another, and from one sabbath to another, shall all flesh come to worship before me, saith the LORD.
18947	745	24	And they shall go forth, and look upon the carcases of the men that have transgressed against me: for their worm shall not die, neither shall their fire be quenched; and they shall be an abhorring unto all flesh.
18948	746	1	THE words of Jeremiah the son of Hilkiah, of the priests that were in Anathoth in the land of Benjamin:
18949	746	2	To whom the word of the LORD came in the days of Josiah the son of Amon king of Judah, in the thirteenth year of his reign.
18950	746	3	It came also in the days of Jehoiakim the son of Josiah king of Judah, unto the end of the eleventh year of Zedekiah the son of Josiah king of Judah, unto the carrying away of Jerusalem captive in the fifth month.
18951	746	4	Then the word of the LORD came unto me, saying,
18952	746	5	Before I formed thee in the belly I knew thee; and before thou camest forth out of the womb I sanctified thee, and I ordained thee a prophet unto the nations.
18953	746	6	Then said I, Ah, Lord GOD! behold, I cannot speak: for I am a child.
18954	746	7	But the LORD said unto me, Say not, I am a child: for thou shalt go to all that I shall send thee, and whatsoever I command thee thou shalt speak.
18955	746	8	Be not afraid of their faces: for I am with thee to deliver thee, saith the LORD.
18956	746	9	Then the LORD put forth his hand, and touched my mouth. And the LORD said unto me, Behold, I have put my words in thy mouth.
18957	746	10	See, I have this day set thee over the nations and over the kingdoms, to root out, and to pull down, and to destroy, and to throw down, to build, and to plant.
18958	746	11	Moreover the word of the LORD came unto me, saying, Jeremiah, what seest thou? And I said, I see a rod of an almond tree.
18959	746	12	Then said the LORD unto me, Thou hast well seen: for I will hasten my word to perform it.
18960	746	13	And the word of the LORD came unto me the second time, saying, What seest thou? And I said, I see a seething pot; and the face thereof is toward the north.
18961	746	14	Then the LORD said unto me, Out of the north an evil shall break forth upon all the inhabitants of the land.
18962	746	15	For, lo, I will call all the families of the kingdoms of the north, saith the LORD; and they shall come, and they shall set every one his throne at the entering of the gates of Jerusalem, and against all the walls thereof round about, and against all the cities of Judah.
18963	746	16	And I will utter my judgments against them touching all their wickedness, who have forsaken me, and have burned incense unto other gods, and worshipped the works of their own hands.
18964	746	17	Thou therefore gird up thy loins, and arise, and speak unto them all that I command thee: be not dismayed at their faces, lest I confound thee before them.
18965	746	18	For, behold, I have made thee this day a defenced city, and an iron pillar, and brasen walls against the whole land, against the kings of Judah, against the princes thereof, against the priests thereof, and against the people of the land.
18966	746	19	And they shall fight against thee; but they shall not prevail against thee; for I am with thee, saith the LORD, to deliver thee.
18967	747	1	MOREOVER the word of the LORD came to me, saying,
18968	747	2	Go and cry in the ears of Jerusalem, saying, Thus saith the LORD; I remember thee, the kindness of thy youth, the love of thine espousals, when thou wentest after me in the wilderness, in a land that was not sown.
18969	747	3	Israel was holiness unto the LORD, and the firstfruits of his increase: all that devour him shall offend; evil shall come upon them, saith the LORD.
18970	747	4	Hear ye the word of the LORD, O house of Jacob, and all the families of the house of Israel:
18971	747	5	Thus saith the LORD, What iniquity have your fathers found in me, that they are gone far from me, and have walked after vanity, and are become vain?
18972	747	6	Neither said they, Where is the LORD that brought us up out of the land of Egypt, that led us through the wilderness, through a land of deserts and of pits, through a land of drought, and of the shadow of death, through a land that no man passed through, and where no man dwelt?
18973	747	7	And I brought you into a plentiful country, to eat the fruit thereof and the goodness thereof; but when ye entered, ye defiled my land, and made mine heritage an abomination.
18974	747	8	The priests said not, Where is the LORD? and they that handle the law knew me not: the pastors also transgressed against me, and the prophets prophesied by Baal, and walked after things that do not profit.
18975	747	9	Wherefore I will yet plead with you, saith the LORD, and with your children's children will I plead.
18976	747	10	For pass over the isles of Chittim, and see; and send unto Kedar, and consider diligently, and see if there be such a thing.
18977	747	11	Hath a nation changed their gods, which are yet no gods? but my people have changed their glory for that which doth not profit.
18978	747	12	Be astonished, O ye heavens, at this, and be horribly afraid, be ye very desolate, saith the LORD.
18979	747	13	For my people have committed two evils; they have forsaken me the fountain of living waters, and hewed them out cisterns, broken cisterns, that can hold no water.
18980	747	14	Is Israel a servant? is he a homeborn slave? why is he spoiled?
18981	747	15	The young lions roared upon him, and yelled, and they made his land waste: his cities are burned without inhabitant.
18982	747	16	Also the children of Noph and Tahapanes have broken the crown of thy head.
18983	747	17	Hast thou not procured this unto thyself, in that thou hast forsaken the LORD thy God, when he led thee by the way?
18984	747	18	And now what hast thou to do in the way of Egypt, to drink the waters of Sihor? or what hast thou to do in the way of Assyria, to drink the waters of the river?
18985	747	19	Thine own wickedness shall correct thee, and thy backslidings shall reprove thee: know therefore and see that it is an evil thing and bitter, that thou hast forsaken the LORD thy God, and that my fear is not in thee, saith the Lord GOD of hosts.
18986	747	20	For of old time I have broken thy yoke, and burst thy bands; and thou saidst, I will not transgress; when upon every high hill and under every green tree thou wanderest, playing the harlot.
18987	747	21	Yet I had planted thee a noble vine, wholly a right seed: how then art thou turned into the degenerate plant of a strange vine unto me?
18988	747	22	For though thou wash thee with nitre, and take thee much soap, yet thine iniquity is marked before me, saith the Lord GOD.
18989	747	23	How canst thou say, I am not polluted, I have not gone after Baalim? see thy way in the valley, know what thou hast done: thou art a swift dromedary traversing her ways;
18990	747	24	A wild ass used to the wilderness, that snuffeth up the wind at her pleasure; in her occasion who can turn her away? all they that seek her will not weary themselves; in her month they shall find her.
18991	747	25	Withhold thy foot from being unshod, and thy throat from thirst: but thou saidst, There is no hope: no; for I have loved strangers, and after them will I go.
18992	747	26	As the thief is ashamed when he is found, so is the house of Israel ashamed; they, their kings, their princes, and their priests, and their prophets,
18993	747	27	Saying to a stock, Thou art my father; and to a stone, Thou hast brought me forth: for they have turned their back unto me, and not their face: but in the time of their trouble they will say, Arise, and save us.
18994	747	28	But where are thy gods that thou hast made thee? let them arise, if they can save thee in the time of thy trouble: for according to the number of thy cities are thy gods, O Judah.
18995	747	29	Wherefore will ye plead with me? ye all have transgressed against me, saith the LORD.
18996	747	30	In vain have I smitten your children; they received no correction: your own sword hath devoured your prophets, like a destroying lion.
18997	747	31	O generation, see ye the word of the LORD. Have I been a wilderness unto Israel? a land of darkness? wherefore say my people, We are lords; we will come no more unto thee?
18998	747	32	Can a maid forget her ornaments, or a bride her attire? yet my people have forgotten me days without number.
18999	747	33	Why trimmest thou thy way to seek love? therefore hast thou also taught the wicked ones thy ways.
19000	747	34	Also in thy skirts is found the blood of the souls of the poor innocents: I have not found it by secret search, but upon all these.
19001	747	35	Yet thou sayest, Because I am innocent, surely his anger shall turn from me. Behold, I will plead with thee, because thou sayest, I have not sinned.
19002	747	36	Why gaddest thou about so much to change thy way? thou also shalt be ashamed of Egypt, as thou wast ashamed of Assyria.
19003	747	37	Yea, thou shalt go forth from him, and thine hands upon thine head: for the LORD hath rejected thy confidences, and thou shalt not prosper in them.
19004	748	1	THEY say, If a man put away his wife, and she go from him, and become another man's, shall he return unto her again? shall not that land be greatly polluted? but thou hast played the harlot with many lovers; yet return again to me, saith the LORD.
19005	748	2	Lift up thine eyes unto the high places, and see where thou hast not been lien with. In the ways hast thou sat for them, as the Arabian in the wilderness; and thou hast polluted the land with thy whoredoms and with thy wickedness.
19006	748	3	Therefore the showers have been withholden, and there hath been no latter rain; and thou hadst a whore's forehead, thou refusedst to be ashamed.
19007	748	4	Wilt thou not from this time cry unto me, My father, thou art the guide of my youth?
19008	748	5	Will he reserve his anger for ever? will he keep it to the end? Behold, thou hast spoken and done evil things as thou couldest.
19009	748	6	The LORD said also unto me in the days of Josiah the king, Hast thou seen that which backsliding Israel hath done? she is gone up upon every high mountain and under every green tree, and there hath played the harlot.
19010	748	7	And I said after she had done all these things, Turn thou unto me. But she returned not. And her treacherous sister Judah saw it.
19011	748	8	And I saw, when for all the causes whereby backsliding Israel committed adultery I had put her away, and given her a bill of divorce; yet her treacherous sister Judah feared not, but went and played the harlot also.
19012	748	9	And it came to pass through the lightness of her whoredom, that she defiled the land, and committed adultery with stones and with stocks.
19013	748	10	And yet for all this her treacherous sister Judah hath not turned unto me with her whole heart, but feignedly, saith the LORD.
19014	748	11	And the LORD said unto me, The backsliding Israel hath justified herself more than treacherous Judah.
19015	748	12	Go and proclaim these words toward the north, and say, Return, thou backsliding Israel, saith the LORD; and I will not cause mine anger to fall upon you: for I am merciful, saith the LORD, and I will not keep anger for ever.
19016	748	13	Only acknowledge thine iniquity, that thou hast transgressed against the LORD thy God, and hast scattered thy ways to the strangers under every green tree, and ye have not obeyed my voice, saith the LORD.
19017	748	14	Turn, O backsliding children, saith the LORD; for I am married unto you: and I will take you one of a city, and two of a family, and I will bring you to Zion:
19018	748	15	And I will give you pastors according to mine heart, which shall feed you with knowledge and understanding.
19019	748	16	And it shall come to pass, when ye be multiplied and increased in the land, in those days, saith the LORD, they shall say no more, The ark of the covenant of the LORD: neither shall it come to mind: neither shall they remember it; neither shall they visit it; neither shall that be done any more.
19020	748	17	At that time they shall call Jerusalem the throne of the LORD; and all the nations shall be gathered unto it, to the name of the LORD, to Jerusalem: neither shall they walk any more after the imagination of their evil heart.
19021	748	18	In those days the house of Judah shall walk with the house of Israel, and they shall come together out of the land of the north to the land that I have given for an inheritance unto your fathers.
19022	748	19	But I said, How shall I put thee among the children, and give thee a pleasant land, a goodly heritage of the hosts of nations? and I said, Thou shalt call me, My father; and shalt not turn away from me.
19023	748	20	Surely as a wife treacherously departeth from her husband, so have ye dealt treacherously with me, O house of Israel, saith the LORD.
19024	748	21	A voice was heard upon the high places, weeping and supplications of the children of Israel: for they have perverted their way, and they have forgotten the LORD their God.
19025	748	22	Return, ye backsliding children, and I will heal your backslidings. Behold, we come unto thee; for thou art the LORD our God.
19026	748	23	Truly in vain is salvation hoped for from the hills, and from the multitude of mountains: truly in the LORD our God is the salvation of Israel.
19027	748	24	For shame hath devoured the labour of our fathers from our youth; their flocks and their herds, their sons and their daughters.
19028	748	25	We lie down in our shame, and our confusion covereth us: for we have sinned against the LORD our God, we and our fathers, from our youth even unto this day, and have not obeyed the voice of the LORD our God.
19029	749	1	IF thou wilt return, O Israel, saith the LORD, return unto me: and if thou wilt put away thine abominations out of my sight, then shalt thou not remove.
19030	749	2	And thou shalt swear, The LORD liveth, in truth, in judgment, and in righteousness; and the nations shall bless themselves in him, and in him shall they glory.
19031	749	3	For thus saith the LORD to the men of Judah and Jerusalem, Break up your fallow ground, and sow not among thorns.
19032	749	4	Circumcise yourselves to the LORD, and take away the foreskins of your heart, ye men of Judah and inhabitants of Jerusalem: lest my fury come forth like fire, and burn that none can quench it, because of the evil of your doings.
19033	749	5	Declare ye in Judah, and publish in Jerusalem; and say, Blow ye the trumpet in the land: cry, gather together, and say, Assemble yourselves, and let us go into the defenced cities.
19034	749	6	Set up the standard toward Zion: retire, stay not: for I will bring evil from the north, and a great destruction.
19035	749	7	The lion is come up from his thicket, and the destroyer of the Gentiles is on his way; he is gone forth from his place to make thy land desolate; and thy cities shall be laid waste, without an inhabitant.
19036	749	8	For this gird you with sackcloth, lament and howl: for the fierce anger of the LORD is not turned back from us.
19037	749	9	And it shall come to pass at that day, saith the LORD, that the heart of the king shall perish, and the heart of the princes; and the priests shall be astonished, and the prophets shall wonder.
19038	749	10	Then said I, Ah, Lord GOD! surely thou hast greatly deceived this people and Jerusalem, saying, Ye shall have peace; whereas the sword reacheth unto the soul.
19039	749	11	At that time shall it be said to this people and to Jerusalem, A dry wind of the high places in the wilderness toward the daughter of my people, not to fan, nor to cleanse,
19040	749	12	Even a full wind from those places shall come unto me: now also will I give sentence against them.
19041	749	13	Behold, he shall come up as clouds, and his chariots shall be as a whirlwind: his horses are swifter than eagles. Woe unto us! for we are spoiled.
19042	749	14	O Jerusalem, wash thine heart from wickedness, that thou mayest be saved. How long shall thy vain thoughts lodge within thee?
19043	749	15	For a voice declareth from Dan, and publisheth affliction from mount Ephraim.
19044	749	16	Make ye mention to the nations; behold, publish against Jerusalem, that watchers come from a far country, and give out their voice against the cities of Judah.
19045	749	17	As keepers of a field, are they against her round about; because she hath been rebellious against me, saith the LORD.
19046	749	18	Thy way and thy doings have procured these things unto thee; this is thy wickedness, because it is bitter, because it reacheth unto thine heart.
19047	749	19	My bowels, my bowels! I am pained at my very heart; my heart maketh a noise in me; I cannot hold my peace, because thou hast heard, O my soul, the sound of the trumpet, the alarm of war.
19048	749	20	Destruction upon destruction is cried; for the whole land is spoiled: suddenly are my tents spoiled, and my curtains in a moment.
19049	749	21	How long shall I see the standard, and hear the sound of the trumpet?
19050	749	22	For my people is foolish, they have not known me; they are sottish children, and they have none understanding: they are wise to do evil, but to do good they have no knowledge.
19051	749	23	I beheld the earth, and, lo, it was without form, and void; and the heavens, and they had no light.
19052	749	24	I beheld the mountains, and, lo, they trembled, and all the hills moved lightly.
19053	749	25	I beheld, and, lo, there was no man, and all the birds of the heavens were fled.
19054	749	26	I beheld, and, lo, the fruitful place was a wilderness, and all the cities thereof were broken down at the presence of the LORD, and by his fierce anger.
19055	749	27	For thus hath the LORD said, The whole land shall be desolate; yet will I not make a full end.
19056	749	28	For this shall the earth mourn, and the heavens above be black: because I have spoken it, I have purposed it, and will not repent, neither will I turn back from it.
19057	749	29	The whole city shall flee for the noise of the horsemen and bowmen; they shall go into thickets, and climb up upon the rocks: every city shall be forsaken, and not a man dwell therein.
19058	749	30	And when thou art spoiled, what wilt thou do? Though thou clothest thyself with crimson, though thou deckest thee with ornaments of gold, though thou rentest thy face with painting, in vain shalt thou make thyself fair; thy lovers will despise thee, they will seek thy life.
19059	749	31	For I have heard a voice as of a woman in travail, and the anguish as of her that bringeth forth her first child, the voice of the daughter of Zion, that bewaileth herself, that spreadeth her hands, saying, Woe is me now! for my soul is wearied because of murderers.
19060	750	1	RUN ye to and fro through the streets of Jerusalem, and see now, and know, and seek in the broad places thereof, if ye can find a man, if there be any that executeth judgment, that seeketh the truth; and I will pardon it.
19061	750	2	And though they say, The LORD liveth; surely they swear falsely.
19062	750	3	O LORD, are not thine eyes upon the truth? thou hast stricken them, but they have not grieved; thou hast consumed them, but they have refused to receive correction: they have made their faces harder than a rock; they have refused to return.
19063	750	4	Therefore I said, Surely these are poor; they are foolish: for they know not the way of the LORD, nor the judgment of their God.
19064	750	5	I will get me unto the great men, and will speak unto them; for they have known the way of the LORD, and the judgment of their God: but these have altogether broken the yoke, and burst the bonds.
19065	750	6	Wherefore a lion out of the forest shall slay them, and a wolf of the evenings shall spoil them, a leopard shall watch over their cities: every one that goeth out thence shall be torn in pieces: because their transgressions are many, and their backslidings are increased.
19066	750	7	How shall I pardon thee for this? thy children have forsaken me, and sworn by them that are no gods: when I had fed them to the full, they then committed adultery, and assembled themselves by troops in the harlots' houses.
19067	750	8	They were as fed horses in the morning: every one neighed after his neighbour's wife.
19068	750	9	Shall I not visit for these things? saith the LORD: and shall not my soul be avenged on such a nation as this?
19069	750	10	Go ye up upon her walls, and destroy; but make not a full end: take away her battlements; for they are not the LORD's.
19070	750	11	For the house of Israel and the house of Judah have dealt very treacherously against me, saith the LORD.
19071	750	12	They have belied the LORD, and said, It is not he; neither shall evil come upon us; neither shall we see sword nor famine:
19072	750	13	And the prophets shall become wind, and the word is not in them: thus shall it be done unto them.
19073	750	14	Wherefore thus saith the LORD God of hosts, Because ye speak this word, behold, I will make my words in thy mouth fire, and this people wood, and it shall devour them.
19074	750	15	Lo, I will bring a nation upon you from far, O house of Israel, saith the LORD: it is a mighty nation, it is an ancient nation, a nation whose language thou knowest not, neither understandest what they say.
19075	750	16	Their quiver is as an open sepulchre, they are all mighty men.
19076	750	17	And they shall eat up thine harvest, and thy bread, which thy sons and thy daughters should eat: they shall eat up thy flocks and thine herds: they shall eat up thy vines and thy fig trees: they shall impoverish thy fenced cities, wherein thou trustedst, with the sword.
19077	750	18	Nevertheless in those days, saith the LORD, I will not make a full end with you.
19078	750	19	And it shall come to pass, when ye shall say, Wherefore doeth the LORD our God all these things unto us? then shalt thou answer them, Like as ye have forsaken me, and served strange gods in your land, so shall ye serve strangers in a land that is not yours.
19079	750	20	Declare this in the house of Jacob, and publish it in Judah, saying,
19080	750	21	Hear now this, O foolish people, and without understanding; which have eyes, and see not; which have ears, and hear not:
19081	750	22	Fear ye not me? saith the LORD: will ye not tremble at my presence, which have placed the sand for the bound of the sea by a perpetual decree, that it cannot pass it: and though the waves thereof toss themselves, yet can they not prevail; though they roar, yet can they not pass over it?
19082	750	23	But this people hath a revolting and a rebellious heart; they are revolted and gone.
19083	750	24	Neither say they in their heart, Let us now fear the LORD our God, that giveth rain, both the former and the latter, in his season: he reserveth unto us the appointed weeks of the harvest.
19084	750	25	Your iniquities have turned away these things, and your sins have withholden good things from you.
19085	750	26	For among my people are found wicked men: they lay wait, as he that setteth snares; they set a trap, they catch men.
19086	750	27	As a cage is full of birds, so are their houses full of deceit: therefore they are become great, and waxen rich.
19087	750	28	They are waxen fat, they shine: yea, they overpass the deeds of the wicked: they judge not the cause, the cause of the fatherless, yet they prosper; and the right of the needy do they not judge.
19088	750	29	Shall I not visit for these things? saith the LORD: shall not my soul be avenged on such a nation as this?
19089	750	30	A wonderful and horrible thing is committed in the land;
19090	750	31	The prophets prophesy falsely, and the priests bear rule by their means; and my people love to have it so: and what will ye do in the end thereof?
19091	751	1	O YE children of Benjamin, gather yourselves to flee out of the midst of Jerusalem, and blow the trumpet in Tekoa, and set up a sign of fire in Beth-haccerem: for evil appeareth out of the north, and great destruction.
19092	751	2	I have likened the daughter of Zion to a comely and delicate woman.
19093	751	3	The shepherds with their flocks shall come unto her; they shall pitch their tents against her round about; they shall feed every one in his place.
19094	751	4	Prepare ye war against her; arise, and let us go up at noon. Woe unto us! for the day goeth away, for the shadows of the evening are stretched out.
19095	751	5	Arise, and let us go by night, and let us destroy her palaces.
19096	751	6	For thus hath the LORD of hosts said, Hew ye down trees, and cast a mount against Jerusalem: this is the city to be visited; she is wholly oppression in the midst of her.
19097	751	7	As a fountain casteth out her waters, so she casteth out her wickedness: violence and spoil is heard in her; before me continually is grief and wounds.
19098	751	8	Be thou instructed, O Jerusalem, lest my soul depart from thee; lest I make thee desolate, a land not inhabited.
19099	751	9	Thus saith the LORD of hosts, They shall throughly glean the remnant of Israel as a vine: turn back thine hand as a grapegatherer into the baskets.
19100	751	10	To whom shall I speak, and give warning, that they may hear? behold, their ear is uncircumcised, and they cannot hearken: behold, the word of the LORD is unto them a reproach; they have no delight in it.
19101	751	11	Therefore I am full of the fury of the LORD; I am weary with holding in: I will pour it out upon the children abroad, and upon the assembly of young men together: for even the husband with the wife shall be taken, the aged with him that is full of days.
19102	751	12	And their houses shall be turned unto others, with their fields and wives together: for I will stretch out my hand upon the inhabitants of the land, saith the LORD.
19103	751	13	For from the least of them even unto the greatest of them every one is given to covetousness; and from the prophet even unto the priest every one dealeth falsely.
19104	751	14	They have healed also the hurt of the daughter of my people slightly, saying, Peace, peace; when there is no peace.
19105	751	15	Were they ashamed when they had committed abomination? nay, they were not at all ashamed, neither could they blush: therefore they shall fall among them that fall: at the time that I visit them they shall be cast down, saith the LORD.
19106	751	16	Thus saith the LORD, Stand ye in the ways, and see, and ask for the old paths, where is the good way, and walk therein, and ye shall find rest for your souls. But they said, We will not walk therein.
19107	751	17	Also I set watchmen over you, saying, Hearken to the sound of the trumpet. But they said, We will not hearken.
19108	751	18	Therefore hear, ye nations, and know, O congregation, what is among them.
19109	751	19	Hear, O earth: behold, I will bring evil upon this people, even the fruit of their thoughts, because they have not hearkened unto my words, nor to my law, but rejected it.
19110	751	20	To what purpose cometh there to me incense from Sheba, and the sweet cane from a far country? your burnt offerings are not acceptable, nor your sacrifices sweet unto me.
19111	751	21	Therefore thus saith the LORD, Behold, I will lay stumblingblocks before this people, and the fathers and the sons together shall fall upon them; the neighbour and his friend shall perish.
19112	751	22	Thus saith the LORD, Behold, a people cometh from the north country, and a great nation shall be raised from the sides of the earth.
19113	751	23	They shall lay hold on bow and spear; they are cruel, and have no mercy; their voice roareth like the sea; and they ride upon horses, set in array as men for war against thee, O daughter of Zion.
19114	751	24	We have heard the fame thereof: our hands wax feeble: anguish hath taken hold of us, and pain, as of a woman in travail.
19115	751	25	Go not forth into the field, nor walk by the way; for the sword of the enemy and fear is on every side.
19116	751	26	O daughter of my people, gird thee with sackcloth, and wallow thyself in ashes: make thee mourning, as for an only son, most bitter lamentation: for the spoiler shall suddenly come upon us.
19117	751	27	I have set thee for a tower and a fortress among my people, that thou mayest know and try their way.
19118	751	28	They are all grievous revolters, walking with slanders: they are brass and iron; they are all corrupters.
19119	751	29	The bellows are burned, the lead is consumed of the fire; the founder melteth in vain: for the wicked are not plucked away.
19120	751	30	Reprobate silver shall men call them, because the LORD hath rejected them.
19121	752	1	THE word that came to Jeremiah from the LORD, saying,
19122	752	2	Stand in the gate of the LORD's house, and proclaim there this word, and say, Hear the word of the LORD, all ye of Judah, that enter in at these gates to worship the LORD.
19123	752	3	Thus saith the LORD of hosts, the God of Israel, Amend your ways and your doings, and I will cause you to dwell in this place.
19124	752	4	Trust ye not in lying words, saying, The temple of the LORD, The temple of the LORD, The temple of the LORD, are these.
19125	752	5	For if ye throughly amend your ways and your doings; if ye throughly execute judgment between a man and his neighbour;
19126	752	6	If ye oppress not the stranger, the fatherless, and the widow, and shed not innocent blood in this place, neither walk after other gods to your hurt:
19127	752	7	Then will I cause you to dwell in this place, in the land that I gave to your fathers, for ever and ever.
19128	752	8	Behold, ye trust in lying words, that cannot profit.
19129	752	9	Will ye steal, murder, and commit adultery, and swear falsely, and burn incense unto Baal, and walk after other gods whom ye know not;
19130	752	10	And come and stand before me in this house, which is called by my name, and say, We are delivered to do all these abominations?
19131	752	11	Is this house, which is called by my name, become a den of robbers in your eyes? Behold, even I have seen it, saith the LORD.
19132	752	12	But go ye now unto my place which was in Shiloh, where I set my name at the first, and see what I did to it for the wickedness of my people Israel.
19133	752	13	And now, because ye have done all these works, saith the LORD, and I spake unto you, rising up early and speaking, but ye heard not; and I called you, but ye answered not;
19134	752	14	Therefore will I do unto this house, which is called by my name, wherein ye trust, and unto the place which I gave to you and to your fathers, as I have done to Shiloh.
19135	752	15	And I will cast you out of my sight, as I have cast out all your brethren, even the whole seed of Ephraim.
19136	752	16	Therefore pray not thou for this people, neither lift up cry nor prayer for them, neither make intercession to me: for I will not hear thee.
19137	752	17	Seest thou not what they do in the cities of Judah and in the streets of Jerusalem?
19138	752	18	The children gather wood, and the fathers kindle the fire, and the women knead their dough, to make cakes to the queen of heaven, and to pour out drink offerings unto other gods, that they may provoke me to anger.
19139	752	19	Do they provoke me to anger? saith the LORD: do they not provoke themselves to the confusion of their own faces?
19140	752	20	Therefore thus saith the Lord GOD; Behold, mine anger and my fury shall be poured out upon this place, upon man, and upon beast, and upon the trees of the field, and upon the fruit of the ground; and it shall burn, and shall not be quenched.
19141	752	21	Thus saith the LORD of hosts, the God of Israel; Put your burnt offerings unto your sacrifices, and eat flesh.
19142	752	22	For I spake not unto your fathers, nor commanded them in the day that I brought them out of the land of Egypt, concerning burnt offerings or sacrifices:
19143	752	23	But this thing commanded I them, saying, Obey my voice, and I will be your God, and ye shall be my people: and walk ye in all the ways that I have commanded you, that it may be well unto you.
19144	752	24	But they hearkened not, nor inclined their ear, but walked in the counsels and in the imagination of their evil heart, and went backward, and not forward.
19145	752	25	Since the day that your fathers came forth out of the land of Egypt unto this day I have even sent unto you all my servants the prophets, daily rising up early and sending them:
19146	752	26	Yet they hearkened not unto me, nor inclined their ear, but hardened their neck: they did worse than their fathers.
19147	752	27	Therefore thou shalt speak all these words unto them; but they will not hearken to thee: thou shalt also call unto them; but they will not answer thee.
19148	752	28	But thou shalt say unto them, This is a nation that obeyeth not the voice of the LORD their God, nor receiveth correction: truth is perished, and is cut off from their mouth.
19149	752	29	Cut off thine hair, O Jerusalem, and cast it away, and take up a lamentation on high places; for the LORD hath rejected and forsaken the generation of his wrath.
19150	752	30	For the children of Judah have done evil in my sight, saith the LORD: they have set their abominations in the house which is called by my name, to pollute it.
19151	752	31	And they have built the high places of Tophet, which is in the valley of the son of Hinnom, to burn their sons and their daughters in the fire; which I commanded them not, neither came it into my heart.
19152	752	32	Therefore, behold, the days come, saith the LORD, that it shall no more be called Tophet, nor the valley of the son of Hinnom, but the valley of slaughter: for they shall bury in Tophet, till there be no place.
19153	752	33	And the carcases of this people shall be meat for the fowls of the heaven, and for the beasts of the earth; and none shall fray them away.
19154	752	34	Then will I cause to cease from the cities of Judah, and from the streets of Jerusalem, the voice of mirth, and the voice of gladness, the voice of the bridegroom, and the voice of the bride: for the land shall be desolate.
19155	753	1	AT that time, saith the LORD, they shall bring out the bones of the kings of Judah, and the bones of his princes, and the bones of the priests, and the bones of the prophets, and the bones of the inhabitants of Jerusalem, out of their graves:
19156	753	2	And they shall spread them before the sun, and the moon, and all the host of heaven, whom they have loved, and whom they have served, and after whom they have walked, and whom they have sought, and whom they have worshipped: they shall not be gathered, nor be buried; they shall be for dung upon the face of the earth.
19157	753	3	And death shall be chosen rather than life by all the residue of them that remain of this evil family, which remain in all the places whither I have driven them, saith the LORD of hosts.
19158	753	4	Moreover thou shalt say unto them, Thus saith the LORD; Shall they fall, and not arise? shall he turn away, and not return?
19159	753	5	Why then is this people of Jerusalem slidden back by a perpetual backsliding? they hold fast deceit, they refuse to return.
19160	753	6	I hearkened and heard, but they spake not aright: no man repented him of his wickedness, saying, What have I done? every one turned to his course, as the horse rusheth into the battle.
19161	753	7	Yea, the stork in the heaven knoweth her appointed times; and the turtle and the crane and the swallow observe the time of their coming; but my people know not the judgment of the LORD.
19162	753	8	How do ye say, We are wise, and the law of the LORD is with us? Lo, certainly in vain made he it; the pen of the scribes is in vain.
19163	753	9	The wise men are ashamed, they are dismayed and taken: lo, they have rejected the word of the LORD; and what wisdom is in them?
19164	753	10	Therefore will I give their wives unto others, and their fields to them that shall inherit them: for every one from the least even unto the greatest is given to covetousness, from the prophet even unto the priest every one dealeth falsely.
19165	753	11	For they have healed the hurt of the daughter of my people slightly, saying, Peace, peace; when there is no peace.
19166	753	12	Were they ashamed when they had committed abomination? nay, they were not at all ashamed, neither could they blush: therefore shall they fall among them that fall: in the time of their visitation they shall be cast down, saith the LORD.
19167	753	13	I will surely consume them, saith the LORD: there shall be no grapes on the vine, nor figs on the fig tree, and the leaf shall fade; and the things that I have given them shall pass away from them.
19168	753	14	Why do we sit still? assemble yourselves, and let us enter into the defenced cities, and let us be silent there: for the LORD our God hath put us to silence, and given us water of gall to drink, because we have sinned against the LORD.
19169	753	15	We looked for peace, but no good came; and for a time of health, and behold trouble!
19170	753	16	The snorting of his horses was heard from Dan: the whole land trembled at the sound of the neighing of his strong ones; for they are come, and have devoured the land, and all that is in it; the city, and those that dwell therein.
19171	753	17	For, behold, I will send serpents, cockatrices, among you, which will not be charmed, and they shall bite you, saith the LORD.
19172	753	18	When I would comfort myself against sorrow, my heart is faint in me.
19173	753	19	Behold the voice of the cry of the daughter of my people because of them that dwell in a far country: Is not the LORD in Zion? is not her king in her? Why have they provoked me to anger with their graven images, and with strange vanities?
19174	753	20	The harvest is past, the summer is ended, and we are not saved.
19175	753	21	For the hurt of the daughter of my people am I hurt; I am black; astonishment hath taken hold on me.
19176	753	22	Is there no balm in Gilead; is there no physician there? why then is not the health of the daughter of my people recovered?
19177	754	1	OH that my head were waters, and mine eyes a fountain of tears, that I might weep day and night for the slain of the daughter of my people!
19178	754	2	Oh that I had in the wilderness a lodging place of wayfaring men; that I might leave my people, and go from them! for they be all adulterers, an assembly of treacherous men.
19179	754	3	And they bend their tongues like their bow for lies: but they are not valiant for the truth upon the earth; for they proceed from evil to evil, and they know not me, saith the LORD.
19180	754	4	Take ye heed every one of his neighbour, and trust ye not in any brother: for every brother will utterly supplant, and every neighbour will walk with slanders.
19181	754	5	And they will deceive every one his neighbour, and will not speak the truth: they have taught their tongue to speak lies, and weary themselves to commit iniquity.
19182	754	6	Thine habitation is in the midst of deceit; through deceit they refuse to know me, saith the LORD.
19183	754	7	Therefore thus saith the LORD of hosts, Behold, I will melt them, and try them; for how shall I do for the daughter of my people?
19184	754	8	Their tongue is as an arrow shot out; it speaketh deceit: one speaketh peaceably to his neighbour with his mouth, but in heart he layeth his wait.
19185	754	9	Shall I not visit them for these things? saith the LORD: shall not my soul be avenged on such a nation as this?
19186	754	10	For the mountains will I take up a weeping and wailing, and for the habitations of the wilderness a lamentation, because they are burned up, so that none can pass through them; neither can men hear the voice of the cattle; both the fowl of the heavens and the beast are fled; they are gone.
19187	754	11	And I will make Jerusalem heaps, and a den of dragons; and I will make the cities of Judah desolate, without an inhabitant.
19188	754	12	Who is the wise man, that may understand this? and who is he to whom the mouth of the LORD hath spoken, that he may declare it, for what the land perisheth and is burned up like a wilderness, that none passeth through?
19189	754	13	And the LORD saith, Because they have forsaken my law which I set before them, and have not obeyed my voice, neither walked therein;
19190	754	14	But have walked after the imagination of their own heart, and after Baalim, which their fathers taught them:
19191	754	15	Therefore thus saith the LORD of hosts, the God of Israel; Behold, I will feed them, even this people, with wormwood, and give them water of gall to drink.
19192	754	16	I will scatter them also among the heathen, whom neither they nor their fathers have known: and I will send a sword after them, till I have consumed them.
19193	754	17	Thus saith the LORD of hosts, Consider ye, and call for the mourning women, that they may come; and send for cunning women, that they may come:
19194	754	18	And let them make haste, and take up a wailing for us, that our eyes may run down with tears, and our eyelids gush out with waters.
19195	754	19	For a voice of wailing is heard out of Zion, How are we spoiled! we are greatly confounded, because we have forsaken the land, because our dwellings have cast us out.
19196	754	20	Yet hear the word of the LORD, O ye women, and let your ear receive the word of his mouth, and teach your daughters wailing, and every one her neighbour lamentation.
19197	754	21	For death is come up into our windows, and is entered into our palaces, to cut off the children from without, and the young men from the streets.
19198	754	22	Speak, Thus saith the LORD, Even the carcases of men shall fall as dung upon the open field, and as the handful after the harvestman, and none shall gather them.
19199	754	23	Thus saith the LORD, Let not the wise man glory in his wisdom, neither let the mighty man glory in his might, let not the rich man glory in his riches:
19200	754	24	But let him that glorieth glory in this, that he understandeth and knoweth me, that I am the LORD which exercise lovingkindness, judgment, and righteousness, in the earth: for in these things I delight, saith the LORD.
19201	754	25	Behold, the days come, saith the LORD, that I will punish all them which are circumcised with the uncircumcised;
19202	754	26	Egypt, and Judah, and Edom, and the children of Ammon, and Moab, and all that are in the utmost corners, that dwell in the wilderness: for all these nations are uncircumcised, and all the house of Israel are uncircumcised in the heart.
19203	755	1	HEAR ye the word which the LORD speaketh unto you, O house of Israel:
19204	755	2	Thus saith the LORD, Learn not the way of the heathen, and be not dismayed at the signs of heaven; for the heathen are dismayed at them.
19205	755	3	For the customs of the people are vain: for one cutteth a tree out of the forest, the work of the hands of the workman, with the axe.
19206	755	4	They deck it with silver and with gold; they fasten it with nails and with hammers, that it move not.
19207	755	5	They are upright as the palm tree, but speak not: they must needs be borne, because they cannot go. Be not afraid of them; for they cannot do evil, neither also is it in them to do good.
19208	755	6	Forasmuch as there is none like unto thee, O LORD; thou art great, and thy name is great in might.
19209	755	7	Who would not fear thee, O King of nations? for to thee doth it appertain: forasmuch as among all the wise men of the nations, and in all their kingdoms, there is none like unto thee.
19210	755	8	But they are altogether brutish and foolish: the stock is a doctrine of vanities.
19211	755	9	Silver spread into plates is brought from Tarshish, and gold from Uphaz, the work of the workman, and of the hands of the founder: blue and purple is their clothing: they are all the work of cunning men.
19212	755	10	But the LORD is the true God, he is the living God, and an everlasting king: at his wrath the earth shall tremble, and the nations shall not be able to abide his indignation.
19213	755	11	Thus shall ye say unto them, The gods that have not made the heavens and the earth, even they shall perish from the earth, and from under these heavens.
19214	755	12	He hath made the earth by his power, he hath established the world by his wisdom, and hath stretched out the heavens by his discretion.
19215	755	13	When he uttereth his voice, there is a multitude of waters in the heavens, and he causeth the vapours to ascend from the ends of the earth; he maketh lightnings with rain, and bringeth forth the wind out of his treasures.
19216	755	14	Every man is brutish in his knowledge: every founder is confounded by the graven image: for his molten image is falsehood, and there is no breath in them.
19217	755	15	They are vanity, and the work of errors: in the time of their visitation they shall perish.
19218	755	16	The portion of Jacob is not like them: for he is the former of all things; and Israel is the rod of his inheritance: The LORD of hosts is his name.
19219	755	17	Gather up thy wares out of the land, O inhabitant of the fortress.
19220	755	18	For thus saith the LORD, Behold, I will sling out the inhabitants of the land at this once, and will distress them, that they may find it so.
19221	755	19	Woe is me for my hurt! my wound is grievous: but I said, Truly this is a grief, and I must bear it.
19222	755	20	My tabernacle is spoiled, and all my cords are broken: my children are gone forth of me, and they are not: there is none to stretch forth my tent any more, and to set up my curtains.
19223	755	21	For the pastors are become brutish, and have not sought the LORD: therefore they shall not prosper, and all their flocks shall be scattered.
19224	755	22	Behold, the noise of the bruit is come, and a great commotion out of the north country, to make the cities of Judah desolate, and a den of dragons.
19225	755	23	O LORD, I know that the way of man is not in himself: it is not in man that walketh to direct his steps.
19226	755	24	O LORD, correct me, but with judgment; not in thine anger, lest thou bring me to nothing.
19227	755	25	Pour out thy fury upon the heathen that know thee not, and upon the families that call not on thy name: for they have eaten up Jacob, and devoured him, and consumed him, and have made his habitation desolate.
19228	756	1	THE word that came to Jeremiah from the LORD, saying,
19229	756	2	Hear ye the words of this covenant, and speak unto the men of Judah, and to the inhabitants of Jerusalem;
19230	756	3	And say thou unto them, Thus saith the LORD God of Israel; Cursed be the man that obeyeth not the words of this covenant,
19231	756	4	Which I commanded your fathers in the day that I brought them forth out of the land of Egypt, from the iron furnace, saying, Obey my voice, and do them, according to all which I command you: so shall ye be my people, and I will be your God:
19232	756	5	That I may perform the oath which I have sworn unto your fathers, to give them a land flowing with milk and honey, as it is this day. Then answered I, and said, So be it, O LORD.
19233	756	6	Then the LORD said unto me, Proclaim all these words in the cities of Judah, and in the streets of Jerusalem, saying, Hear ye the words of this covenant, and do them.
19234	756	7	For I earnestly protested unto your fathers in the day that I brought them up out of the land of Egypt, even unto this day, rising early and protesting, saying, Obey my voice.
19235	756	8	Yet they obeyed not, nor inclined their ear, but walked every one in the imagination of their evil heart: therefore I will bring upon them all the words of this covenant, which I commanded them to do; but they did them not.
19236	756	9	And the LORD said unto me, A conspiracy is found among the men of Judah, and among the inhabitants of Jerusalem.
19237	756	10	They are turned back to the iniquities of their forefathers, which refused to hear my words; and they went after other gods to serve them: the house of Israel and the house of Judah have broken my covenant which I made with their fathers.
19238	756	11	Therefore thus saith the LORD, Behold, I will bring evil upon them, which they shall not be able to escape; and though they shall cry unto me, I will not hearken unto them.
19239	756	12	Then shall the cities of Judah and inhabitants of Jerusalem go, and cry unto the gods unto whom they offer incense: but they shall not save them at all in the time of their trouble.
19240	756	13	For according to the number of thy cities were thy gods, O Judah; and according to the number of the streets of Jerusalem have ye set up altars to that shameful thing, even altars to burn incense unto Baal.
19241	756	14	Therefore pray not thou for this people, neither lift up a cry or prayer for them: for I will not hear them in the time that they cry unto me for their trouble.
19242	756	15	What hath my beloved to do in mine house, seeing she hath wrought lewdness with many, and the holy flesh is passed from thee? when thou doest evil, then thou rejoicest.
19243	756	16	The LORD called thy name, A green olive tree, fair, and of goodly fruit: with the noise of a great tumult he hath kindled fire upon it, and the branches of it are broken.
19244	756	17	For the LORD of hosts, that planted thee, hath pronounced evil against thee, for the evil of the house of Israel and of the house of Judah, which they have done against themselves to provoke me to anger in offering incense unto Baal.
19245	756	18	And the LORD hath given me knowledge of it, and I know it: then thou shewedst me their doings.
19246	756	19	But I was like a lamb or an ox that is brought to the slaughter; and I knew not that they had devised devices against me, saying, Let us destroy the tree with the fruit thereof, and let us cut him off from the land of the living, that his name may be no more remembered.
19247	756	20	But, O LORD of hosts, that judgest righteously, that triest the reins and the heart, let me see thy vengeance on them: for unto thee have I revealed my cause.
19248	756	21	Therefore thus saith the LORD of the men of Anathoth, that seek thy life, saying, Prophesy not in the name of the LORD, that thou die not by our hand:
19249	756	22	Therefore thus saith the LORD of hosts, Behold, I will punish them: the young men shall die by the sword; their sons and their daughters shall die by famine:
19250	756	23	And there shall be no remnant of them: for I will bring evil upon the men of Anathoth, even the year of their visitation.
19251	757	1	RIGHTEOUS art thou, O LORD, when I plead with thee: yet let me talk with thee of thy judgments: Wherefore doth the way of the wicked prosper? wherefore are all they happy that deal very treacherously?
19252	757	2	Thou hast planted them, yea, they have taken root: they grow, yea, they bring forth fruit: thou art near in their mouth, and far from their reins.
19253	757	3	But thou, O LORD, knowest me: thou hast seen me, and tried mine heart toward thee: pull them out like sheep for the slaughter, and prepare them for the day of slaughter.
19254	757	4	How long shall the land mourn, and the herbs of every field wither, for the wickedness of them that dwell therein? the beasts are consumed, and the birds; because they said, He shall not see our last end.
19255	757	5	If thou hast run with the footmen, and they have wearied thee, then how canst thou contend with horses? and if in the land of peace, wherein thou trustedst, they wearied thee, then how wilt thou do in the swelling of Jordan?
19256	757	6	For even thy brethren, and the house of thy father, even they have dealt treacherously with thee; yea, they have called a multitude after thee: believe them not, though they speak fair words unto thee.
19257	757	7	I have forsaken mine house, I have left mine heritage; I have given the dearly beloved of my soul into the hand of her enemies.
19258	757	8	Mine heritage is unto me as a lion in the forest; it crieth out against me: therefore have I hated it.
19259	757	9	Mine heritage is unto me as a speckled bird, the birds round about are against her; come ye, assemble all the beasts of the field, come to devour.
19260	757	10	Many pastors have destroyed my vineyard, they have trodden my portion under foot, they have made my pleasant portion a desolate wilderness.
19261	757	11	They have made it desolate, and being desolate it mourneth unto me; the whole land is made desolate, because no man layeth it to heart.
19262	757	12	The spoilers are come upon all high places through the wilderness: for the sword of the LORD shall devour from the one end of the land even to the other end of the land: no flesh shall have peace.
19263	757	13	They have sown wheat, but shall reap thorns: they have put themselves to pain, but shall not profit: and they shall be ashamed of your revenues because of the fierce anger of the LORD.
19264	757	14	Thus saith the LORD against all mine evil neighbours, that touch the inheritance which I have caused my people Israel to inherit; Behold, I will pluck them out of their land, and pluck out the house of Judah from among them.
19265	757	15	And it shall come to pass, after that I have plucked them out I will return, and have compassion on them, and will bring them again, every man to his heritage, and every man to his land.
19266	757	16	And it shall come to pass, if they will diligently learn the ways of my people, to swear by my name, The LORD liveth; as they taught my people to swear by Baal; then shall they be built in the midst of my people.
19267	757	17	But if they will not obey, I will utterly pluck up and destroy that nation, saith the LORD.
19268	758	1	THUS saith the LORD unto me, Go and get thee a linen girdle, and put it upon thy loins, and put it not in water.
19269	758	2	So I got a girdle according to the word of the LORD, and put it on my loins.
19270	758	3	And the word of the LORD came unto me the second time, saying,
19271	758	4	Take the girdle that thou hast got, which is upon thy loins, and arise, go to Euphrates, and hide it there in a hole of the rock.
19272	758	5	So I went, and hid it by Euphrates, as the LORD commanded me.
19273	758	6	And it came to pass after many days, that the LORD said unto me, Arise, go to Euphrates, and take the girdle from thence, which I commanded thee to hide there.
19274	758	7	Then I went to Euphrates, and digged, and took the girdle from the place where I had hid it: and, behold, the girdle was marred, it was profitable for nothing.
19275	758	8	Then the word of the LORD came unto me, saying,
19276	758	9	Thus saith the LORD, After this manner will I mar the pride of Judah, and the great pride of Jerusalem.
19277	758	10	This evil people, which refuse to hear my words, which walk in the imagination of their heart, and walk after other gods, to serve them, and to worship them, shall even be as this girdle, which is good for nothing.
19278	758	11	For as the girdle cleaveth to the loins of a man, so have I caused to cleave unto me the whole house of Israel and the whole house of Judah, saith the LORD; that they might be unto me for a people, and for a name, and for a praise, and for a glory: but they would not hear.
19279	758	12	Therefore thou shalt speak unto them this word; Thus saith the LORD God of Israel, Every bottle shall be filled with wine: and they shall say unto thee, Do we not certainly know that every bottle shall be filled with wine?
19280	758	13	Then shalt thou say unto them, Thus saith the LORD, Behold, I will fill all the inhabitants of this land, even the kings that sit upon David's throne, and the priests, and the prophets, and all the inhabitants of Jerusalem, with drunkenness.
19281	758	14	And I will dash them one against another, even the fathers and the sons together, saith the LORD: I will not pity, nor spare, nor have mercy, but destroy them.
19282	758	15	Hear ye, and give ear; be not proud: for the LORD hath spoken.
19283	758	16	Give glory to the LORD your God, before he cause darkness, and before your feet stumble upon the dark mountains, and, while ye look for light, he turn it into the shadow of death, and make it gross darkness.
19284	758	17	But if ye will not hear it, my soul shall weep in secret places for your pride; and mine eye shall weep sore, and run down with tears, because the LORD's flock is carried away captive.
19285	758	18	Say unto the king and to the queen, Humble yourselves, sit down: for your principalities shall come down, even the crown of your glory.
19286	758	19	The cities of the south shall be shut up, and none shall open them: Judah shall be carried away captive all of it, it shall be wholly carried away captive.
19287	758	20	Lift up your eyes, and behold them that come from the north: where is the flock that was given thee, thy beautiful flock?
19288	758	21	What wilt thou say when he shall punish thee? for thou hast taught them to be captains, and as chief over thee: shall not sorrows take thee, as a woman in travail?
19289	758	22	And if thou say in thine heart, Wherefore come these things upon me? For the greatness of thine iniquity are thy skirts discovered, and thy heels made bare.
19290	758	23	Can the Ethiopian change his skin, or the leopard his spots? then may ye also do good, that are accustomed to do evil.
19291	758	24	Therefore will I scatter them as the stubble that passeth away by the wind of the wilderness.
19292	758	25	This is thy lot, the portion of thy measures from me, saith the LORD; because thou hast forgotten me, and trusted in falsehood.
19293	758	26	Therefore will I discover thy skirts upon thy face, that thy shame may appear.
19294	758	27	I have seen thine adulteries, and thy neighings, the lewdness of thy whoredom, and thine abominations on the hills in the fields. Woe unto thee, O Jerusalem! wilt thou not be made clean? when shall it once be?
19295	759	1	THE word of the LORD that came to Jeremiah concerning the dearth.
19296	759	2	Judah mourneth, and the gates thereof languish; they are black unto the ground; and the cry of Jerusalem is gone up.
19297	759	3	And their nobles have sent their little ones to the waters: they came to the pits, and found no water; they returned with their vessels empty; they were ashamed and confounded, and covered their heads.
19298	759	4	Because the ground is chapt, for there was no rain in the earth, the plowmen were ashamed, they covered their heads.
19299	759	5	Yea, the hind also calved in the field, and forsook it, because there was no grass.
19300	759	6	And the wild asses did stand in the high places, they snuffed up the wind like dragons; their eyes did fail, because there was no grass.
19301	759	7	O LORD, though our iniquities testify against us, do thou it for thy name's sake: for our backslidings are many; we have sinned against thee.
19302	759	8	O the hope of Israel, the saviour thereof in time of trouble, why shouldest thou be as a stranger in the land, and as a wayfaring man that turneth aside to tarry for a night?
19303	759	9	Why shouldest thou be as a man astonied, as a mighty man that cannot save? yet thou, O LORD, art in the midst of us, and we are called by thy name; leave us not.
19304	759	10	Thus saith the LORD unto this people, Thus have they loved to wander, they have not refrained their feet, therefore the LORD doth not accept them; he will now remember their iniquity, and visit their sins.
19305	759	11	Then said the LORD unto me, Pray not for this people for their good.
19306	759	12	When they fast, I will not hear their cry; and when they offer burnt offering and an oblation, I will not accept them: but I will consume them by the sword, and by the famine, and by the pestilence.
19307	759	13	Then said I, Ah, Lord GOD! behold, the prophets say unto them, Ye shall not see the sword, neither shall ye have famine; but I will give you assured peace in this place.
19308	759	14	Then the LORD said unto me, The prophets prophesy lies in my name: I sent them not, neither have I commanded them, neither spake unto them: they prophesy unto you a false vision and divination, and a thing of nought, and the deceit of their heart.
19309	759	15	Therefore thus saith the LORD concerning the prophets that prophesy in my name, and I sent them not, yet they say, Sword and famine shall not be in this land; By sword and famine shall those prophets be consumed.
19310	759	16	And the people to whom they prophesy shall be cast out in the streets of Jerusalem because of the famine and the sword; and they shall have none to bury them, them, their wives, nor their sons, nor their daughters: for I will pour their wickedness upon them.
19311	759	17	Therefore thou shalt say this word unto them; Let mine eyes run down with tears night and day, and let them not cease: for the virgin daughter of my people is broken with a great breach, with a very grievous blow.
19312	759	18	If I go forth into the field, then behold the slain with the sword! and if I enter into the city, then behold them that are sick with famine! yea, both the prophet and the priest go about into a land that they know not.
19313	759	19	Hast thou utterly rejected Judah? hath thy soul lothed Zion? why hast thou smitten us, and there is no healing for us? we looked for peace, and there is no good; and for the time of healing, and behold trouble!
19314	759	20	We acknowledge, O LORD, our wickedness, and the iniquity of our fathers: for we have sinned against thee.
19315	759	21	Do not abhor us, for thy name's sake, do not disgrace the throne of thy glory: remember, break not thy covenant with us.
19316	759	22	Are there any among the vanities of the Gentiles that can cause rain? or can the heavens give showers? art not thou he, O LORD our God? therefore we will wait upon thee: for thou hast made all these things.
19317	760	1	THEN said the LORD unto me, Though Moses and Samuel stood before me, yet my mind could not be toward this people: cast them out of my sight, and let them go forth.
19318	760	2	And it shall come to pass, if they say unto thee, Whither shall we go forth? then thou shalt tell them, Thus saith the LORD; Such as are for death, to death; and such as are for the sword, to the sword; and such as are for the famine, to the famine; and such as are for the captivity, to the captivity.
19319	760	3	And I will appoint over them four kinds, saith the LORD: the sword to slay, and the dogs to tear, and the fowls of the heaven, and the beasts of the earth, to devour and destroy.
19320	760	4	And I will cause them to be removed into all kingdoms of the earth, because of Manasseh the son of Hezekiah king of Judah, for that which he did in Jerusalem.
19321	760	5	For who shall have pity upon thee, O Jerusalem? or who shall bemoan thee? or who shall go aside to ask how thou doest?
19322	760	6	Thou hast forsaken me, saith the LORD, thou art gone backward: therefore will I stretch out my hand against thee, and destroy thee; I am weary with repenting.
19323	760	7	And I will fan them with a fan in the gates of the land; I will bereave them of children, I will destroy my people, since they return not from their ways.
19324	760	8	Their widows are increased to me above the sand of the seas: I have brought upon them against the mother of the young men a spoiler at noonday: I have caused him to fall upon it suddenly, and terrors upon the city.
19325	760	9	She that hath borne seven languisheth: she hath given up the ghost; her sun is gone down while it was yet day: she hath been ashamed and confounded: and the residue of them will I deliver to the sword before their enemies, saith the LORD.
19326	760	10	Woe is me, my mother, that thou hast borne me a man of strife and a man of contention to the whole earth! I have neither lent on usury, nor men have lent to me on usury; yet every one of them doth curse me.
19327	760	11	The LORD said, Verily it shall be well with thy remnant; verily I will cause the enemy to entreat thee well in the time of evil and in the time of affliction.
19328	760	12	Shall iron break the northern iron and the steel?
19329	760	13	Thy substance and thy treasures will I give to the spoil without price, and that for all thy sins, even in all thy borders.
19330	760	14	And I will make thee to pass with thine enemies into a land which thou knowest not: for a fire is kindled in mine anger, which shall burn upon you.
19331	760	15	O LORD, thou knowest: remember me, and visit me, and revenge me of my persecutors; take me not away in thy longsuffering: know that for thy sake I have suffered rebuke.
19332	760	16	Thy words were found, and I did eat them; and thy word was unto me the joy and rejoicing of mine heart: for I am called by thy name, O LORD God of hosts.
19333	760	17	I sat not in the assembly of the mockers, nor rejoiced; I sat alone because of thy hand: for thou hast filled me with indignation.
19334	760	18	Why is my pain perpetual, and my wound incurable, which refuseth to be healed? wilt thou be altogether unto me as a liar, and as waters that fail?
19335	760	19	Therefore thus saith the LORD, If thou return, then will I bring thee again, and thou shalt stand before me: and if thou take forth the precious from the vile, thou shalt be as my mouth: let them return unto thee; but return not thou unto them.
19336	760	20	And I will make thee unto this people a fenced brasen wall: and they shall fight against thee, but they shall not prevail against thee: for I am with thee to save thee and to deliver thee, saith the LORD.
19337	760	21	And I will deliver thee out of the hand of the wicked, and I will redeem thee out of the hand of the terrible.
19338	761	1	THE word of the LORD came also unto me, saying,
19339	761	2	Thou shalt not take thee a wife, neither shalt thou have sons or daughters in this place.
19340	761	3	For thus saith the LORD concerning the sons and concerning the daughters that are born in this place, and concerning their mothers that bare them, and concerning their fathers that begat them in this land;
19341	761	4	They shall die of grievous deaths; they shall not be lamented; neither shall they be buried; but they shall be as dung upon the face of the earth: and they shall be consumed by the sword, and by famine; and their carcases shall be meat for the fowls of heaven, and for the beasts of the earth.
19342	761	5	For thus saith the LORD, Enter not into the house of mourning, neither go to lament nor bemoan them: for I have taken away my peace from this people, saith the LORD, even lovingkindness and mercies.
19343	761	6	Both the great and the small shall die in this land: they shall not be buried, neither shall men lament for them, nor cut themselves, nor make themselves bald for them:
19344	761	7	Neither shall men tear themselves for them in mourning, to comfort them for the dead; neither shall men give them the cup of consolation to drink for their father or for their mother.
19345	761	8	Thou shalt not also go into the house of feasting, to sit with them to eat and to drink.
19346	761	9	For thus saith the LORD of hosts, the God of Israel; Behold, I will cause to cease out of this place in your eyes, and in your days, the voice of mirth, and the voice of gladness, the voice of the bridegroom, and the voice of the bride.
19347	761	10	And it shall come to pass, when thou shalt shew this people all these words, and they shall say unto thee, Wherefore hath the LORD pronounced all this great evil against us? or what is our iniquity? or what is our sin that we have committed against the LORD our God?
19348	761	11	Then shalt thou say unto them, Because your fathers have forsaken me, saith the LORD, and have walked after other gods, and have served them, and have worshipped them, and have forsaken me, and have not kept my law;
19349	761	12	And ye have done worse than your fathers; for, behold, ye walk every one after the imagination of his evil heart, that they may not hearken unto me:
19350	761	13	Therefore will I cast you out of this land into a land that ye know not, neither ye nor your fathers; and there shall ye serve other gods day and night; where I will not shew you favour.
19351	761	14	Therefore, behold, the days come, saith the LORD, that it shall no more be said, The LORD liveth, that brought up the children of Israel out of the land of Egypt;
19352	761	15	But, The LORD liveth, that brought up the children of Israel from the land of the north, and from all the lands whither he had driven them: and I will bring them again into their land that I gave unto their fathers.
19353	761	16	Behold, I will send for many fishers, saith the LORD, and they shall fish them; and after will I send for many hunters, and they shall hunt them from every mountain, and from every hill, and out of the holes of the rocks.
19354	761	17	For mine eyes are upon all their ways: they are not hid from my face, neither is their iniquity hid from mine eyes.
19355	761	18	And first I will recompense their iniquity and their sin double; because they have defiled my land, they have filled mine inheritance with the carcases of their detestable and abominable things.
19356	761	19	O LORD, my strength, and my fortress, and my refuge in the day of affliction, the Gentiles shall come unto thee from the ends of the earth, and shall say, Surely our fathers have inherited lies, vanity, and things wherein there is no profit.
19357	761	20	Shall a man make gods unto himself, and they are no gods?
19358	761	21	Therefore, behold, I will this once cause them to know, I will cause them to know mine hand and my might; and they shall know that my name is The LORD.
19359	762	1	THE sin of Judah is written with a pen of iron, and with the point of a diamond: it is graven upon the table of their heart, and upon the horns of your altars;
19360	762	2	Whilst their children remember their altars and their groves by the green trees upon the high hills.
19361	762	3	O my mountain in the field, I will give thy substance and all thy treasures to the spoil, and thy high places for sin, throughout all thy borders.
19362	762	4	And thou, even thyself, shalt discontinue from thine heritage that I gave thee; and I will cause thee to serve thine enemies in the land which thou knowest not: for ye have kindled a fire in mine anger, which shall burn for ever.
19363	762	5	Thus saith the LORD; Cursed be the man that trusteth in man, and maketh flesh his arm, and whose heart departeth from the LORD.
19364	762	6	For he shall be like the heath in the desert, and shall not see when good cometh; but shall inhabit the parched places in the wilderness, in a salt land and not inhabited.
19365	762	7	Blessed is the man that trusteth in the LORD, and whose hope the LORD is.
19366	762	8	For he shall be as a tree planted by the waters, and that spreadeth out her roots by the river, and shall not see when heat cometh, but her leaf shall be green; and shall not be careful in the year of drought, neither shall cease from yielding fruit.
19367	762	9	The heart is deceitful above all things, and desperately wicked: who can know it?
19368	762	10	I the LORD search the heart, I try the reins, even to give every man according to his ways, and according to the fruit of his doings.
19369	762	11	As the partridge sitteth on eggs, and hatcheth them not; so he that getteth riches, and not by right, shall leave them in the midst of his days, and at his end shall be a fool.
19370	762	12	A glorious high throne from the beginning is the place of our sanctuary.
19371	762	13	O LORD, the hope of Israel, all that forsake thee shall be ashamed, and they that depart from me shall be written in the earth, because they have forsaken the LORD, the fountain of living waters.
19372	762	14	Heal me, O LORD, and I shall be healed; save me, and I shall be saved: for thou art my praise.
19373	762	15	Behold, they say unto me, Where is the word of the LORD? let it come now.
19374	762	16	As for me, I have not hastened from being a pastor to follow thee: neither have I desired the woeful day; thou knowest: that which came out of my lips was right before thee.
19375	762	17	Be not a terror unto me: thou art my hope in the day of evil.
19376	762	18	Let them be confounded that persecute me, but let not me be confounded: let them be dismayed, but let not me be dismayed: bring upon them the day of evil, and destroy them with double destruction.
19377	762	19	Thus said the LORD unto me; Go and stand in the gate of the children of the people, whereby the kings of Judah come in, and by the which they go out, and in all the gates of Jerusalem;
19378	762	20	And say unto them, Hear ye the word of the LORD, ye kings of Judah, and all Judah, and all the inhabitants of Jerusalem, that enter in by these gates:
19379	762	21	Thus saith the LORD; Take heed to yourselves, and bear no burden on the sabbath day, nor bring it in by the gates of Jerusalem;
19380	762	22	Neither carry forth a burden out of your houses on the sabbath day, neither do ye any work, but hallow ye the sabbath day, as I commanded your fathers.
19381	762	23	But they obeyed not, neither inclined their ear, but made their neck stiff, that they might not hear, nor receive instruction.
19382	762	24	And it shall come to pass, if ye diligently hearken unto me, saith the LORD, to bring in no burden through the gates of this city on the sabbath day, but hallow the sabbath day, to do no work therein;
19383	762	25	Then shall there enter into the gates of this city kings and princes sitting upon the throne of David, riding in chariots and on horses, they, and their princes, the men of Judah, and the inhabitants of Jerusalem: and this city shall remain for ever.
19384	762	26	And they shall come from the cities of Judah, and from the places about Jerusalem, and from the land of Benjamin, and from the plain, and from the mountains, and from the south, bringing burnt offerings, and sacrifices, and meat offerings, and incense, and bringing sacrifices of praise, unto the house of the LORD.
19385	762	27	But if ye will not hearken unto me to hallow the sabbath day, and not to bear a burden, even entering in at the gates of Jerusalem on the sabbath day; then will I kindle a fire in the gates thereof, and it shall devour the palaces of Jerusalem, and it shall not be quenched.
19386	763	1	THE word which came to Jeremiah from the LORD, saying,
19387	763	2	Arise, and go down to the potter's house, and there I will cause thee to hear my words.
19388	763	3	Then I went down to the potter's house, and, behold, he wrought a work on the wheels.
19389	763	4	And the vessel that he made of clay was marred in the hand of the potter: so he made it again another vessel, as seemed good to the potter to make it.
19390	763	5	Then the word of the LORD came to me, saying,
19391	763	6	O house of Israel, cannot I do with you as this potter? saith the LORD. Behold, as the clay is in the potter's hand, so are ye in mine hand, O house of Israel.
19392	763	7	At what instant I shall speak concerning a nation, and concerning a kingdom, to pluck up, and to pull down, and to destroy it;
19393	763	8	If that nation, against whom I have pronounced, turn from their evil, I will repent of the evil that I thought to do unto them.
19394	763	9	And at what instant I shall speak concerning a nation, and concerning a kingdom, to build and to plant it;
19395	763	10	If it do evil in my sight, that it obey not my voice, then I will repent of the good, wherewith I said I would benefit them.
19396	763	11	Now therefore go to, speak to the men of Judah, and to the inhabitants of Jerusalem, saying, Thus saith the LORD; Behold, I frame evil against you, and devise a device against you: return ye now every one from his evil way, and make your ways and your doings good.
19397	763	12	And they said, There is no hope: but we will walk after our own devices, and we will every one do the imagination of his evil heart.
19398	763	13	Therefore thus saith the LORD; Ask ye now among the heathen, who hath heard such things: the virgin of Israel hath done a very horrible thing.
19399	763	14	Will a man leave the snow of Lebanon which cometh from the rock of the field? or shall the cold flowing waters that come from another place be forsaken?
19400	763	15	Because my people hath forgotten me, they have burned incense to vanity, and they have caused them to stumble in their ways from the ancient paths, to walk in paths, in a way not cast up;
19401	763	16	To make their land desolate, and a perpetual hissing; every one that passeth thereby shall be astonished, and wag his head.
19402	763	17	I will scatter them as with an east wind before the enemy: I will shew them the back, and not the face, in the day of their calamity.
19403	763	18	Then said they, Come, and let us devise devices against Jeremiah; for the law shall not perish from the priest, nor counsel from the wise, nor the word from the prophet. Come, and let us smite him with the tongue, and let us not give heed to any of his words.
19404	763	19	Give heed to me, O LORD, and hearken to the voice of them that contend with me.
19405	763	20	Shall evil be recompensed for good? for they have digged a pit for my soul. Remember that I stood before thee to speak good for them, and to turn away thy wrath from them.
19406	763	21	Therefore deliver up their children to the famine, and pour out their blood by the force of the sword; and let their wives be bereaved of their children, and be widows; and let their men be put to death; let their young men be slain by the sword in battle.
19407	763	22	Let a cry be heard from their houses, when thou shalt bring a troop suddenly upon them: for they have digged a pit to take me, and hid snares for my feet.
19408	763	23	Yet, LORD, thou knowest all their counsel against me to slay me: forgive not their iniquity, neither blot out their sin from thy sight, but let them be overthrown before thee; deal thus with them in the time of thine anger.
19409	764	1	THUS saith the LORD, Go and get a potter's earthen bottle, and take of the ancients of the people, and of the ancients of the priests;
19410	764	2	And go forth unto the valley of the son of Hinnom, which is by the entry of the east gate, and proclaim there the words that I shall tell thee,
19411	764	3	And say, Hear ye the word of the LORD, O kings of Judah, and inhabitants of Jerusalem; Thus saith the LORD of hosts, the God of Israel; Behold, I will bring evil upon this place, the which whosoever heareth, his ears shall tingle.
19412	764	4	Because they have forsaken me, and have estranged this place, and have burned incense in it unto other gods, whom neither they nor their fathers have known, nor the kings of Judah, and have filled this place with the blood of innocents;
19413	764	5	They have built also the high places of Baal, to burn their sons with fire for burnt offerings unto Baal, which I commanded not, nor spake it, neither came it into my mind:
19414	764	6	Therefore, behold, the days come, saith the LORD, that this place shall no more be called Tophet, nor The valley of the son of Hinnom, but The valley of slaughter.
19415	764	7	And I will make void the counsel of Judah and Jerusalem in this place; and I will cause them to fall by the sword before their enemies, and by the hands of them that seek their lives: and their carcases will I give to be meat for the fowls of the heaven, and for the beasts of the earth.
19416	764	8	And I will make this city desolate, and an hissing; every one that passeth thereby shall be astonished and hiss because of all the plagues thereof.
19417	764	9	And I will cause them to eat the flesh of their sons and the flesh of their daughters, and they shall eat every one the flesh of his friend in the siege and straitness, wherewith their enemies, and they that seek their lives, shall straiten them.
19418	764	10	Then shalt thou break the bottle in the sight of the men that go with thee,
19419	764	11	And shalt say unto them, Thus saith the LORD of hosts; Even so will I break this people and this city, as one breaketh a potter's vessel, that cannot be made whole again: and they shall bury them in Tophet, till there be no place to bury.
19420	764	12	Thus will I do unto this place, saith the LORD, and to the inhabitants thereof, and even make this city as Tophet:
19421	764	13	And the houses of Jerusalem, and the houses of the kings of Judah, shall be defiled as the place of Tophet, because of all the houses upon whose roofs they have burned incense unto all the host of heaven, and have poured out drink offerings unto other gods.
19422	764	14	Then came Jeremiah from Tophet, whither the LORD had sent him to prophesy; and he stood in the court of the LORD's house; and said to all the people,
19423	764	15	Thus saith the LORD of hosts, the God of Israel; Behold, I will bring upon this city and upon all her towns all the evil that I have pronounced against it, because they have hardened their necks, that they might not hear my words.
19424	765	1	NOW Pashur the son of Immer the priest, who was also chief governor in the house of the LORD, heard that Jeremiah prophesied these things.
19425	765	2	Then Pashur smote Jeremiah the prophet, and put him in the stocks that were in the high gate of Benjamin, which was by the house of the LORD.
19426	765	3	And it came to pass on the morrow, that Pashur brought forth Jeremiah out of the stocks. Then said Jeremiah unto him, The LORD hath not called thy name Pashur, but Magor-missabib.
19427	765	4	For thus saith the LORD, Behold, I will make thee a terror to thyself, and to all thy friends: and they shall fall by the sword of their enemies, and thine eyes shall behold it: and I will give all Judah into the hand of the king of Babylon, and he shall carry them captive into Babylon, and shall slay them with the sword.
19428	765	5	Moreover I will deliver all the strength of this city, and all the labours thereof, and all the precious things thereof, and all the treasures of the kings of Judah will I give into the hand of their enemies, which shall spoil them, and take them, and carry them to Babylon.
19429	765	6	And thou, Pashur, and all that dwell in thine house shall go into captivity: and thou shalt come to Babylon, and there thou shalt die, and shalt be buried there, thou, and all thy friends, to whom thou hast prophesied lies.
19430	765	7	O LORD, thou hast deceived me, and I was deceived: thou art stronger than I, and hast prevailed: I am in derision daily, every one mocketh me.
19431	765	8	For since I spake, I cried out, I cried violence and spoil; because the word of the LORD was made a reproach unto me, and a derision, daily.
19432	765	9	Then I said, I will not make mention of him, nor speak any more in his name. But his word was in mine heart as a burning fire shut up in my bones, and I was weary with forbearing, and I could not stay.
19433	765	10	For I heard the defaming of many, fear on every side. Report, say they, and we will report it. All my familiars watched for my halting, saying, Peradventure he will be enticed, and we shall prevail against him, and we shall take our revenge on him.
19434	765	11	But the LORD is with me as a mighty terrible one: therefore my persecutors shall stumble, and they shall not prevail: they shall be greatly ashamed; for they shall not prosper: their everlasting confusion shall never be forgotten.
19435	765	12	But, O LORD of hosts, that triest the righteous, and seest the reins and the heart, let me see thy vengeance on them: for unto thee have I opened my cause.
19436	765	13	Sing unto the LORD, praise ye the LORD: for he hath delivered the soul of the poor from the hand of evildoers.
19437	765	14	Cursed be the day wherein I was born: let not the day wherein my mother bare me be blessed.
19438	765	15	Cursed be the man who brought tidings to my father, saying, A man child is born unto thee; making him very glad.
19439	765	16	And let that man be as the cities which the LORD overthrew, and repented not: and let him hear the cry in the morning, and the shouting at noontide;
19440	765	17	Because he slew me not from the womb; or that my mother might have been my grave, and her womb to be always great with me.
19441	765	18	Wherefore came I forth out of the womb to see labour and sorrow, that my days should be consumed with shame?
19442	766	1	THE word which came unto Jeremiah from the LORD, when king Zedekiah sent unto him Pashur the son of Melchiah, and Zephaniah the son of Maaseiah the priest, saying,
19443	766	2	Enquire, I pray thee, of the LORD for us; for Nebuchadrezzar king of Babylon maketh war against us; if so be that the LORD will deal with us according to all his wondrous works, that he may go up from us.
19444	766	3	Then said Jeremiah unto them, Thus shall ye say to Zedekiah:
19445	766	4	Thus saith the LORD God of Israel; Behold, I will turn back the weapons of war that are in your hands, wherewith ye fight against the king of Babylon, and against the Chaldeans, which besiege you without the walls, and I will assemble them into the midst of this city.
19446	766	5	And I myself will fight against you with an outstretched hand and with a strong arm, even in anger, and in fury, and in great wrath.
19447	766	6	And I will smite the inhabitants of this city, both man and beast: they shall die of a great pestilence.
19448	766	7	And afterward, saith the LORD, I will deliver Zedekiah king of Judah, and his servants, and the people, and such as are left in this city from the pestilence, from the sword, and from the famine, into the hand of Nebuchadrezzar king of Babylon, and into the hand of their enemies, and into the hand of those that seek their life: and he shall smite them with the edge of the sword; he shall not spare them, neither have pity, nor have mercy.
19449	766	8	And unto this people thou shalt say, Thus saith the LORD; Behold, I set before you the way of life, and the way of death.
19450	766	9	He that abideth in this city shall die by the sword, and by the famine, and by the pestilence: but he that goeth out, and falleth to the Chaldeans that besiege you, he shall live, and his life shall be unto him for a prey.
19451	766	10	For I have set my face against this city for evil, and not for good, saith the LORD: it shall be given into the hand of the king of Babylon, and he shall burn it with fire.
19452	766	11	And touching the house of the king of Judah, say, Hear ye the word of the LORD;
19453	766	12	O house of David, thus saith the LORD; Execute judgment in the morning, and deliver him that is spoiled out of the hand of the oppressor, lest my fury go out like fire, and burn that none can quench it, because of the evil of your doings.
19454	766	13	Behold, I am against thee, O inhabitant of the valley, and rock of the plain, saith the LORD; which say, Who shall come down against us? or who shall enter into our habitations?
19455	766	14	But I will punish you according to the fruit of your doings, saith the LORD: and I will kindle a fire in the forest thereof, and it shall devour all things round about it.
19456	767	1	THUS saith the LORD; Go down to the house of the king of Judah, and speak there this word,
19457	767	2	And say, Hear the word of the LORD, O king of Judah, that sittest upon the throne of David, thou, and thy servants, and thy people that enter in by these gates:
19458	767	3	Thus saith the LORD; Execute ye judgment and righteousness, and deliver the spoiled out of the hand of the oppressor: and do no wrong, do no violence to the stranger, the fatherless, nor the widow, neither shed innocent blood in this place.
19459	767	4	For if ye do this thing indeed, then shall there enter in by the gates of this house kings sitting upon the throne of David, riding in chariots and on horses, he, and his servants, and his people.
19460	767	5	But if ye will not hear these words, I swear by myself, saith the LORD, that this house shall become a desolation.
19461	767	6	For thus saith the LORD unto the king's house of Judah; Thou art Gilead unto me, and the head of Lebanon: yet surely I will make thee a wilderness, and cities which are not inhabited.
19462	767	7	And I will prepare destroyers against thee, every one with his weapons: and they shall cut down thy choice cedars, and cast them into the fire.
19463	767	8	And many nations shall pass by this city, and they shall say every man to his neighbour, Wherefore hath the LORD done thus unto this great city?
19464	767	9	Then they shall answer, Because they have forsaken the covenant of the LORD their God, and worshipped other gods, and served them.
19465	767	10	Weep ye not for the dead, neither bemoan him: but weep sore for him that goeth away: for he shall return no more, nor see his native country.
19466	767	11	For thus saith the LORD touching Shallum the son of Josiah king of Judah, which reigned instead of Josiah his father, which went forth out of this place; He shall not return thither any more:
19467	767	12	But he shall die in the place whither they have led him captive, and shall see this land no more.
19468	767	13	Woe unto him that buildeth his house by unrighteousness, and his chambers by wrong; that useth his neighbour's service without wages, and giveth him not for his work;
19469	767	14	That saith, I will build me a wide house and large chambers, and cutteth him out windows; and it is cieled with cedar, and painted with vermilion.
19470	767	15	Shalt thou reign, because thou closest thyself in cedar? did not thy father eat and drink, and do judgment and justice, and then it was well with him?
19471	767	16	He judged the cause of the poor and needy; then it was well with him: was not this to know me? saith the LORD.
19472	767	17	But thine eyes and thine heart are not but for thy covetousness, and for to shed innocent blood, and for oppression, and for violence, to do it.
19473	767	18	Therefore thus saith the LORD concerning Jehoiakim the son of Josiah king of Judah; They shall not lament for him, saying, Ah my brother! or, Ah sister! they shall not lament for him, saying, Ah lord! or, Ah his glory!
19474	767	19	He shall be buried with the burial of an ass, drawn and cast forth beyond the gates of Jerusalem.
19475	767	20	Go up to Lebanon, and cry; and lift up thy voice in Bashan, and cry from the passages: for all thy lovers are destroyed.
19476	767	21	I spake unto thee in thy prosperity; but thou saidst, I will not hear. This hath been thy manner from thy youth, that thou obeyedst not my voice.
19477	767	22	The wind shall eat up all thy pastors, and thy lovers shall go into captivity: surely then shalt thou be ashamed and confounded for all thy wickedness.
19478	767	23	O inhabitant of Lebanon, that makest thy nest in the cedars, how gracious shalt thou be when pangs come upon thee, the pain as of a woman in travail!
19479	767	24	As I live, saith the LORD, though Coniah the son of Jehoiakim king of Judah were the signet upon my right hand, yet would I pluck thee thence;
19480	767	25	And I will give thee into the hand of them that seek thy life, and into the hand of them whose face thou fearest, even into the hand of Nebuchadrezzar king of Babylon, and into the hand of the Chaldeans.
19481	767	26	And I will cast thee out, and thy mother that bare thee, into another country, where ye were not born; and there shall ye die.
19482	767	27	But to the land whereunto they desire to return, thither shall they not return.
19483	767	28	Is this man Coniah a despised broken idol? is he a vessel wherein is no pleasure? wherefore are they cast out, he and his seed, and are cast into a land which they know not?
19484	767	29	O earth, earth, earth, hear the word of the LORD.
19485	767	30	Thus saith the LORD, Write ye this man childless, a man that shall not prosper in his days: for no man of his seed shall prosper, sitting upon the throne of David, and ruling any more in Judah.
19486	768	1	WOE be unto the pastors that destroy and scatter the sheep of my pasture! saith the LORD.
19487	768	2	Therefore thus saith the LORD God of Israel against the pastors that feed my people; Ye have scattered my flock, and driven them away, and have not visited them: behold, I will visit upon you the evil of your doings, saith the LORD.
19488	768	3	And I will gather the remnant of my flock out of all countries whither I have driven them, and will bring them again to their folds; and they shall be fruitful and increase.
19489	768	4	And I will set up shepherds over them which shall feed them: and they shall fear no more, nor be dismayed, neither shall they be lacking, saith the LORD.
19490	768	5	Behold, the days come, saith the LORD, that I will raise unto David a righteous Branch, and a King shall reign and prosper, and shall execute judgment and justice in the earth.
19491	768	6	In his days Judah shall be saved, and Israel shall dwell safely: and this is his name whereby he shall be called, THE LORD OUR RIGHTEOUSNESS.
19492	768	7	Therefore, behold, the days come, saith the LORD, that they shall no more say, The LORD liveth, which brought up the children of Israel out of the land of Egypt;
19493	768	8	But, The LORD liveth, which brought up and which led the seed of the house of Israel out of the north country, and from all countries whither I had driven them; and they shall dwell in their own land.
19494	768	9	Mine heart within me is broken because of the prophets; all my bones shake; I am like a drunken man, and like a man whom wine hath overcome, because of the LORD, and because of the words of his holiness.
19495	768	10	For the land is full of adulterers; for because of swearing the land mourneth; the pleasant places of the wilderness are dried up, and their course is evil, and their force is not right.
19496	768	11	For both prophet and priest are profane; yea, in my house have I found their wickedness, saith the LORD.
19497	768	12	Wherefore their way shall be unto them as slippery ways in the darkness: they shall be driven on, and fall therein: for I will bring evil upon them, even the year of their visitation, saith the LORD.
19498	768	13	And I have seen folly in the prophets of Samaria; they prophesied in Baal, and caused my people Israel to err.
19499	768	14	I have seen also in the prophets of Jerusalem an horrible thing: they commit adultery, and walk in lies: they strengthen also the hands of evildoers, that none doth return from his wickedness: they are all of them unto me as Sodom, and the inhabitants thereof as Gomorrah.
19500	768	15	Therefore thus saith the LORD of hosts concerning the prophets; Behold, I will feed them with wormwood, and make them drink the water of gall: for from the prophets of Jerusalem is profaneness gone forth into all the land.
19501	768	16	Thus saith the LORD of hosts, Hearken not unto the words of the prophets that prophesy unto you: they make you vain: they speak a vision of their own heart, and not out of the mouth of the LORD.
19502	768	17	They say still unto them that despise me, The LORD hath said, Ye shall have peace; and they say unto every one that walketh after the imagination of his own heart, No evil shall come upon you.
19503	768	18	For who hath stood in the counsel of the LORD, and hath perceived and heard his word? who hath marked his word, and heard it?
19504	768	19	Behold, a whirlwind of the LORD is gone forth in fury, even a grievous whirlwind: it shall fall grievously upon the head of the wicked.
19505	768	20	The anger of the LORD shall not return, until he have executed, and till he have performed the thoughts of his heart: in the latter days ye shall consider it perfectly.
19506	768	21	I have not sent these prophets, yet they ran: I have not spoken to them, yet they prophesied.
19507	768	22	But if they had stood in my counsel, and had caused my people to hear my words, then they should have turned them from their evil way, and from the evil of their doings.
19508	768	23	Am I a God at hand, saith the LORD, and not a God afar off?
19509	768	24	Can any hide himself in secret places that I shall not see him? saith the LORD. Do not I fill heaven and earth? saith the LORD.
19510	768	25	I have heard what the prophets said, that prophesy lies in my name, saying, I have dreamed, I have dreamed.
19511	768	26	How long shall this be in the heart of the prophets that prophesy lies? yea, they are prophets of the deceit of their own heart;
19512	768	27	Which think to cause my people to forget my name by their dreams which they tell every man to his neighbour, as their fathers have forgotten my name for Baal.
19513	768	28	The prophet that hath a dream, let him tell a dream; and he that hath my word, let him speak my word faithfully. What is the chaff to the wheat? saith the LORD.
19514	768	29	Is not my word like as a fire? saith the LORD; and like a hammer that breaketh the rock in pieces?
19515	768	30	Therefore, behold, I am against the prophets, saith the LORD, that steal my words every one from his neighbour.
19516	768	31	Behold, I am against the prophets, saith the LORD, that use their tongues, and say, He saith.
19517	768	32	Behold, I am against them that prophesy false dreams, saith the LORD, and do tell them, and cause my people to err by their lies, and by their lightness; yet I sent them not, nor commanded them: therefore they shall not profit this people at all, saith the LORD.
19518	768	33	And when this people, or the prophet, or a priest, shall ask thee, saying, What is the burden of the LORD? thou shalt then say unto them, What burden? I will even forsake you, saith the LORD.
19519	768	34	And as for the prophet, and the priest, and the people, that shall say, The burden of the LORD, I will even punish that man and his house.
19520	768	35	Thus shall ye say every one to his neighbour, and every one to his brother, What hath the LORD answered? and, What hath the LORD spoken?
19521	768	36	And the burden of the LORD shall ye mention no more: for every man's word shall be his burden; for ye have perverted the words of the living God, of the LORD of hosts our God.
19522	768	37	Thus shalt thou say to the prophet, What hath the LORD answered thee? and, What hath the LORD spoken?
19523	768	38	But since ye say, The burden of the LORD; therefore thus saith the LORD; Because ye say this word, The burden of the LORD, and I have sent unto you, saying, Ye shall not say, The burden of the LORD;
19524	768	39	Therefore, behold, I, even I, will utterly forget you, and I will forsake you, and the city that I gave you and your fathers, and cast you out of my presence:
19525	768	40	And I will bring an everlasting reproach upon you, and a perpetual shame, which shall not be forgotten.
19526	769	1	THE LORD shewed me, and, behold, two baskets of figs were set before the temple of the LORD, after that Nebuchadrezzar king of Babylon had carried away captive Jeconiah the son of Jehoiakim king of Judah, and the princes of Judah, with the carpenters and smiths, from Jerusalem, and had brought them to Babylon.
19527	769	2	One basket had very good figs, even like the figs that are first ripe: and the other basket had very naughty figs, which could not be eaten, they were so bad.
19528	769	3	Then said the LORD unto me, What seest thou, Jeremiah? And I said, Figs; the good figs, very good; and the evil, very evil, that cannot be eaten, they are so evil.
19529	769	4	Again the word of the LORD came unto me, saying,
19530	769	5	Thus saith the LORD, the God of Israel; Like these good figs, so will I acknowledge them that are carried away captive of Judah, whom I have sent out of this place into the land of the Chaldeans for their good.
19531	769	6	For I will set mine eyes upon them for good, and I will bring them again to this land: and I will build them, and not pull them down; and I will plant them, and not pluck them up.
19532	769	7	And I will give them an heart to know me, that I am the LORD: and they shall be my people, and I will be their God: for they shall return unto me with their whole heart.
19533	769	8	And as the evil figs, which cannot be eaten, they are so evil; surely thus saith the LORD, So will I give Zedekiah the king of Judah, and his princes, and the residue of Jerusalem, that remain in this land, and them that dwell in the land of Egypt:
19534	769	9	And I will deliver them to be removed into all the kingdoms of the earth for their hurt, to be a reproach and a proverb, a taunt and a curse, in all places whither I shall drive them.
19535	769	10	And I will send the sword, the famine, and the pestilence, among them, till they be consumed from off the land that I gave unto them and to their fathers.
19536	770	1	THE word that came to Jeremiah concerning all the people of Judah in the fourth year of Jehoiakim the son of Josiah king of Judah, that was the first year of Nebuchadrezzar king of Babylon;
19537	770	2	The which Jeremiah the prophet spake unto all the people of Judah, and to all the inhabitants of Jerusalem, saying,
19538	770	3	From the thirteenth year of Josiah the son of Amon king of Judah, even unto this day, that is the three and twentieth year, the word of the LORD hath come unto me, and I have spoken unto you, rising early and speaking; but ye have not hearkened.
19539	770	4	And the LORD hath sent unto you all his servants the prophets, rising early and sending them; but ye have not hearkened, nor inclined your ear to hear.
19540	770	5	They said, Turn ye again now every one from his evil way, and from the evil of your doings, and dwell in the land that the LORD hath given unto you and to your fathers for ever and ever:
19541	770	6	And go not after other gods to serve them, and to worship them, and provoke me not to anger with the works of your hands; and I will do you no hurt.
19542	770	7	Yet ye have not hearkened unto me, saith the LORD; that ye might provoke me to anger with the works of your hands to your own hurt.
19543	770	8	Therefore thus saith the LORD of hosts; Because ye have not heard my words,
19544	770	9	Behold, I will send and take all the families of the north, saith the LORD, and Nebuchadrezzar the king of Babylon, my servant, and will bring them against this land, and against the inhabitants thereof, and against all these nations round about, and will utterly destroy them, and make them an astonishment, and an hissing, and perpetual desolations.
19545	770	10	Moreover I will take from them the voice of mirth, and the voice of gladness, the voice of the bridegroom, and the voice of the bride, the sound of the millstones, and the light of the candle.
19546	770	11	And this whole land shall be a desolation, and an astonishment; and these nations shall serve the king of Babylon seventy years.
19547	770	12	And it shall come to pass, when seventy years are accomplished, that I will punish the king of Babylon, and that nation, saith the LORD, for their iniquity, and the land of the Chaldeans, and will make it perpetual desolations.
19548	770	13	And I will bring upon that land all my words which I have pronounced against it, even all that is written in this book, which Jeremiah hath prophesied against all the nations.
19549	770	14	For many nations and great kings shall serve themselves of them also: and I will recompense them according to their deeds, and according to the works of their own hands.
19550	770	15	For thus saith the LORD God of Israel unto me; Take the wine cup of this fury at my hand, and cause all the nations, to whom I send thee, to drink it.
19551	770	16	And they shall drink, and be moved, and be mad, because of the sword that I will send among them.
19552	770	17	Then took I the cup at the LORD's hand, and made all the nations to drink, unto whom the LORD had sent me:
19553	770	18	To wit, Jerusalem, and the cities of Judah, and the kings thereof, and the princes thereof, to make them a desolation, an astonishment, an hissing, and a curse; as it is this day;
19554	770	19	Pharaoh king of Egypt, and his servants, and his princes, and all his people;
19555	770	20	And all the mingled people, and all the kings of the land of Uz, and all the kings of the land of the Philistines, and Ashkelon, and Azzah, and Ekron, and the remnant of Ashdod,
19556	770	21	Edom, and Moab, and the children of Ammon,
19557	770	22	And all the kings of Tyrus, and all the kings of Zidon, and the kings of the isles which are beyond the sea,
19558	770	23	Dedan, and Tema, and Buz, and all that are in the utmost corners,
19559	770	24	And all the kings of Arabia, and all the kings of the mingled people that dwell in the desert,
19560	770	25	And all the kings of Zimri, and all the kings of Elam, and all the kings of the Medes,
19561	770	26	And all the kings of the north, far and near, one with another, and all the kingdoms of the world, which are upon the face of the earth: and the king of Sheshach shall drink after them.
19562	770	27	Therefore thou shalt say unto them, Thus saith the LORD of hosts, the God of Israel; Drink ye, and be drunken, and spue, and fall, and rise no more, because of the sword which I will send among you.
19563	770	28	And it shall be, if they refuse to take the cup at thine hand to drink, then shalt thou say unto them, Thus saith the LORD of hosts; Ye shall certainly drink.
19564	770	29	For, lo, I begin to bring evil on the city which is called by my name, and should ye be utterly unpunished? Ye shall not be unpunished: for I will call for a sword upon all the inhabitants of the earth, saith the LORD of hosts.
19565	770	30	Therefore prophesy thou against them all these words, and say unto them, The LORD shall roar from on high, and utter his voice from his holy habitation; he shall mightily roar upon his habitation; he shall give a shout, as they that tread the grapes, against all the inhabitants of the earth.
19566	770	31	A noise shall come even to the ends of the earth; for the LORD hath a controversy with the nations, he will plead with all flesh; he will give them that are wicked to the sword, saith the LORD.
19567	770	32	Thus saith the LORD of hosts, Behold, evil shall go forth from nation to nation, and a great whirlwind shall be raised up from the coasts of the earth.
19568	770	33	And the slain of the LORD shall be at that day from one end of the earth even unto the other end of the earth: they shall not be lamented, neither gathered, nor buried; they shall be dung upon the ground.
19569	770	34	Howl, ye shepherds, and cry; and wallow yourselves in the ashes, ye principal of the flock: for the days of your slaughter and of your dispersions are accomplished; and ye shall fall like a pleasant vessel.
19570	770	35	And the shepherds shall have no way to flee, nor the principal of the flock to escape.
19571	770	36	A voice of the cry of the shepherds, and an howling of the principal of the flock, shall be heard: for the LORD hath spoiled their pasture.
19572	770	37	And the peaceable habitations are cut down because of the fierce anger of the LORD.
19573	770	38	He hath forsaken his covert, as the lion: for their land is desolate because of the fierceness of the oppressor, and because of his fierce anger.
19574	771	1	IN the beginning of the reign of Jehoiakim the son of Josiah king of Judah came this word from the LORD, saying,
19575	771	2	Thus saith the LORD; Stand in the court of the LORD's house, and speak unto all the cities of Judah, which come to worship in the LORD's house, all the words that I command thee to speak unto them; diminish not a word:
19576	771	3	If so be they will hearken, and turn every man from his evil way, that I may repent me of the evil, which I purpose to do unto them because of the evil of their doings.
19577	771	4	And thou shalt say unto them, Thus saith the LORD; If ye will not hearken to me, to walk in my law, which I have set before you,
19578	771	5	To hearken to the words of my servants the prophets, whom I sent unto you, both rising up early, and sending them, but ye have not hearkened;
19579	771	6	Then will I make this house like Shiloh, and will make this city a curse to all the nations of the earth.
19580	771	7	So the priests and the prophets and all the people heard Jeremiah speaking these words in the house of the LORD.
19581	771	8	Now it came to pass, when Jeremiah had made an end of speaking all that the LORD had commanded him to speak unto all the people, that the priests and the prophets and all the people took him, saying, Thou shalt surely die.
19582	771	9	Why hast thou prophesied in the name of the LORD, saying, This house shall be like Shiloh, and this city shall be desolate without an inhabitant? And all the people were gathered against Jeremiah in the house of the LORD.
19583	771	10	When the princes of Judah heard these things, then they came up from the king's house unto the house of the LORD, and sat down in the entry of the new gate of the LORD's house.
19584	771	11	Then spake the priests and the prophets unto the princes and to all the people, saying, This man is worthy to die; for he hath prophesied against this city, as ye have heard with your ears.
19585	771	12	Then spake Jeremiah unto all the princes and to all the people, saying, The LORD sent me to prophesy against this house and against this city all the words that ye have heard.
19586	771	13	Therefore now amend your ways and your doings, and obey the voice of the LORD your God; and the LORD will repent him of the evil that he hath pronounced against you.
19587	771	14	As for me, behold, I am in your hand: do with me as seemeth good and meet unto you.
19588	771	15	But know ye for certain, that if ye put me to death, ye shall surely bring innocent blood upon yourselves, and upon this city, and upon the inhabitants thereof: for of a truth the LORD hath sent me unto you to speak all these words in your ears.
19589	771	16	Then said the princes and all the people unto the priests and to the prophets; This man is not worthy to die: for he hath spoken to us in the name of the LORD our God.
19590	771	17	Then rose up certain of the elders of the land, and spake to all the assembly of the people, saying,
19591	771	18	Micah the Morasthite prophesied in the days of Hezekiah king of Judah, and spake to all the people of Judah, saying, Thus saith the LORD of hosts; Zion shall be plowed like a field, and Jerusalem shall become heaps, and the mountain of the house as the high places of a forest.
19592	771	19	Did Hezekiah king of Judah and all Judah put him at all to death? did he not fear the LORD, and besought the LORD, and the LORD repented him of the evil which he had pronounced against them? Thus might we procure great evil against our souls.
19593	771	20	And there was also a man that prophesied in the name of the LORD, Urijah the son of Shemaiah of Kirjath-jearim, who prophesied against this city and against this land according to all the words of Jeremiah:
19594	771	21	And when Jehoiakim the king, with all his mighty men, and all the princes, heard his words, the king sought to put him to death: but when Urijah heard it, he was afraid, and fled, and went into Egypt;
19595	771	22	And Jehoiakim the king sent men into Egypt, namely, Elnathan the son of Achbor, and certain men with him into Egypt.
19596	771	23	And they fetched forth Urijah out of Egypt, and brought him unto Jehoiakim the king; who slew him with the sword, and cast his dead body into the graves of the common people.
19597	771	24	Nevertheless the hand of Ahikam the son of Shaphan was with Jeremiah, that they should not give him into the hand of the people to put him to death.
19598	772	1	IN the beginning of the reign of Jehoiakim the son of Josiah king of Judah came this word unto Jeremiah from the LORD, saying,
19599	772	2	Thus saith the LORD to me; Make thee bonds and yokes, and put them upon thy neck,
19600	772	3	And send them to the king of Edom, and to the king of Moab, and to the king of the Ammonites, and to the king of Tyrus, and to the king of Zidon, by the hand of the messengers which come to Jerusalem unto Zedekiah king of Judah;
19601	772	4	And command them to say unto their masters, Thus saith the LORD of hosts, the God of Israel; Thus shall ye say unto your masters;
19602	772	5	I have made the earth, the man and the beast that are upon the ground, by my great power and by my outstretched arm, and have given it unto whom it seemed meet unto me.
19603	772	6	And now have I given all these lands into the hand of Nebuchadnezzar the king of Babylon, my servant; and the beasts of the field have I given him also to serve him.
19604	772	7	And all nations shall serve him, and his son, and his son's son, until the very time of his land come: and then many nations and great kings shall serve themselves of him.
19605	772	8	And it shall come to pass, that the nation and kingdom which will not serve the same Nebuchadnezzar the king of Babylon, and that will not put their neck under the yoke of the king of Babylon, that nation will I punish, saith the LORD, with the sword, and with the famine, and with the pestilence, until I have consumed them by his hand.
19606	772	9	Therefore hearken not ye to your prophets, nor to your diviners, nor to your dreamers, nor to your enchanters, nor to your sorcerers, which speak unto you, saying, Ye shall not serve the king of Babylon:
19607	772	10	For they prophesy a lie unto you, to remove you far from your land; and that I should drive you out, and ye should perish.
19608	772	11	But the nations that bring their neck under the yoke of the king of Babylon, and serve him, those will I let remain still in their own land, saith the LORD; and they shall till it, and dwell therein.
19609	772	12	I spake also to Zedekiah king of Judah according to all these words, saying, Bring your necks under the yoke of the king of Babylon, and serve him and his people, and live.
19610	772	13	Why will ye die, thou and thy people, by the sword, by the famine, and by the pestilence, as the LORD hath spoken against the nation that will not serve the king of Babylon?
19611	772	14	Therefore hearken not unto the words of the prophets that speak unto you, saying, Ye shall not serve the king of Babylon: for they prophesy a lie unto you.
19612	772	15	For I have not sent them, saith the LORD, yet they prophesy a lie in my name; that I might drive you out, and that ye might perish, ye, and the prophets that prophesy unto you.
19613	772	16	Also I spake to the priests and to all this people, saying, Thus saith the LORD; Hearken not to the words of your prophets that prophesy unto you, saying, Behold, the vessels of the LORD's house shall now shortly be brought again from Babylon: for they prophesy a lie unto you.
19614	772	17	Hearken not unto them; serve the king of Babylon, and live: wherefore should this city be laid waste?
19615	772	18	But if they be prophets, and if the word of the LORD be with them, let them now make intercession to the LORD of hosts, that the vessels which are left in the house of the LORD, and in the house of the king of Judah, and at Jerusalem, go not to Babylon.
19616	772	19	For thus saith the LORD of hosts concerning the pillars, and concerning the sea, and concerning the bases, and concerning the residue of the vessels that remain in this city,
19617	772	20	Which Nebuchadnezzar king of Babylon took not, when he carried away captive Jeconiah the son of Jehoiakim king of Judah from Jerusalem to Babylon, and all the nobles of Judah and Jerusalem;
19618	772	21	Yea, thus saith the LORD of hosts, the God of Israel, concerning the vessels that remain in the house of the LORD, and in the house of the king of Judah and of Jerusalem;
19619	772	22	They shall be carried to Babylon, and there shall they be until the day that I visit them, saith the LORD; then will I bring them up, and restore them to this place.
19620	773	1	AND it came to pass the same year, in the beginning of the reign of Zedekiah king of Judah, in the fourth year, and in the fifth month, that Hananiah the son of Azur the prophet, which was of Gibeon, spake unto me in the house of the LORD, in the presence of the priests and of all the people, saying,
19621	773	2	Thus speaketh the LORD of hosts, the God of Israel, saying, I have broken the yoke of the king of Babylon.
19622	773	3	Within two full years will I bring again into this place all the vessels of the LORD's house, that Nebuchadnezzar king of Babylon took away from this place, and carried them to Babylon:
19623	773	4	And I will bring again to this place Jeconiah the son of Jehoiakim king of Judah, with all the captives of Judah, that went into Babylon, saith the LORD: for I will break the yoke of the king of Babylon.
19624	773	5	Then the prophet Jeremiah said unto the prophet Hananiah in the presence of the priests, and in the presence of all the people that stood in the house of the LORD,
19625	773	6	Even the prophet Jeremiah said, Amen: the LORD do so: the LORD perform thy words which thou hast prophesied, to bring again the vessels of the LORD's house, and all that is carried away captive, from Babylon into this place.
19626	773	7	Nevertheless hear thou now this word that I speak in thine ears, and in the ears of all the people;
19627	773	8	The prophets that have been before me and before thee of old prophesied both against many countries, and against great kingdoms, of war, and of evil, and of pestilence.
19628	773	9	The prophet which prophesieth of peace, when the word of the prophet shall come to pass, then shall the prophet be known, that the LORD hath truly sent him.
19629	773	10	Then Hananiah the prophet took the yoke from off the prophet Jeremiah's neck, and brake it.
19630	773	11	And Hananiah spake in the presence of all the people, saying, Thus saith the LORD; Even so will I break the yoke of Nebuchadnezzar king of Babylon from the neck of all nations within the space of two full years. And the prophet Jeremiah went his way.
19631	773	12	Then the word of the LORD came unto Jeremiah the prophet, after that Hananiah the prophet had broken the yoke from off the neck of the prophet Jeremiah, saying,
19632	773	13	Go and tell Hananiah, saying, Thus saith the LORD; Thou hast broken the yokes of wood; but thou shalt make for them yokes of iron.
19633	773	14	For thus saith the LORD of hosts, the God of Israel; I have put a yoke of iron upon the neck of all these nations, that they may serve Nebuchadnezzar king of Babylon; and they shall serve him: and I have given him the beasts of the field also.
19634	773	15	Then said the prophet Jeremiah unto Hananiah the prophet, Hear now, Hananiah; The LORD hath not sent thee; but thou makest this people to trust in a lie.
19635	773	16	Therefore thus saith the LORD; Behold, I will cast thee from off the face of the earth: this year thou shalt die, because thou hast taught rebellion against the LORD.
19636	773	17	So Hananiah the prophet died the same year in the seventh month.
19637	774	1	NOW these are the words of the letter that Jeremiah the prophet sent from Jerusalem unto the residue of the elders which were carried away captives, and to the priests, and to the prophets, and to all the people whom Nebuchadnezzar had carried away captive from Jerusalem to Babylon;
19638	774	2	(After that Jeconiah the king, and the queen, and the eunuchs, the princes of Judah and Jerusalem, and the carpenters, and the smiths, were departed from Jerusalem;)
19639	774	3	By the hand of Elasah the son of Shaphan, and Gemariah the son of Hilkiah, (whom Zedekiah king of Judah sent unto Babylon to Nebuchadnezzar king of Babylon) saying,
19640	774	4	Thus saith the LORD of hosts, the God of Israel, unto all that are carried away captives, whom I have caused to be carried away from Jerusalem unto Babylon;
19641	774	5	Build ye houses, and dwell in them; and plant gardens, and eat the fruit of them;
19642	774	6	Take ye wives, and beget sons and daughters; and take wives for your sons, and give your daughters to husbands, that they may bear sons and daughters; that ye may be increased there, and not diminished.
19643	774	7	And seek the peace of the city whither I have caused you to be carried away captives, and pray unto the LORD for it: for in the peace thereof shall ye have peace.
19644	774	8	For thus saith the LORD of hosts, the God of Israel; Let not your prophets and your diviners, that be in the midst of you, deceive you, neither hearken to your dreams which ye cause to be dreamed.
19645	774	9	For they prophesy falsely unto you in my name: I have not sent them, saith the LORD.
19646	774	10	For thus saith the LORD, That after seventy years be accomplished at Babylon I will visit you, and perform my good word toward you, in causing you to return to this place.
19647	774	11	For I know the thoughts that I think toward you, saith the LORD, thoughts of peace, and not of evil, to give you an expected end.
19648	774	12	Then shall ye call upon me, and ye shall go and pray unto me, and I will hearken unto you.
19649	774	13	And ye shall seek me, and find me, when ye shall search for me with all your heart.
19650	774	14	And I will be found of you, saith the LORD: and I will turn away your captivity, and I will gather you from all the nations, and from all the places whither I have driven you, saith the LORD; and I will bring you again into the place whence I caused you to be carried away captive.
19651	774	15	Because ye have said, The LORD hath raised us up prophets in Babylon;
19652	774	16	Know that thus saith the LORD of the king that sitteth upon the throne of David, and of all the people that dwelleth in this city, and of your brethren that are not gone forth with you into captivity;
19653	774	17	Thus saith the LORD of hosts; Behold, I will send upon them the sword, the famine, and the pestilence, and will make them like vile figs, that cannot be eaten, they are so evil.
19654	774	18	And I will persecute them with the sword, with the famine, and with the pestilence, and will deliver them to be removed to all the kingdoms of the earth, to be a curse, and an astonishment, and an hissing, and a reproach, among all the nations whither I have driven them:
19655	774	19	Because they have not hearkened to my words, saith the LORD, which I sent unto them by my servants the prophets, rising up early and sending them; but ye would not hear, saith the LORD.
19656	774	20	Hear ye therefore the word of the LORD, all ye of the captivity, whom I have sent from Jerusalem to Babylon:
19657	774	21	Thus saith the LORD of hosts, the God of Israel, of Ahab the son of Kolaiah, and of Zedekiah the son of Maaseiah, which prophesy a lie unto you in my name; Behold, I will deliver them into the hand of Nebuchadrezzar king of Babylon; and he shall slay them before your eyes;
19658	774	22	And of them shall be taken up a curse by all the captivity of Judah which are in Babylon, saying, The LORD make thee like Zedekiah and like Ahab, whom the king of Babylon roasted in the fire;
19659	774	23	Because they have committed villany in Israel, and have committed adultery with their neighbours' wives, and have spoken lying words in my name, which I have not commanded them; even I know, and am a witness, saith the LORD.
19660	774	24	Thus shalt thou also speak to Shemaiah the Nehelamite, saying,
19661	774	25	Thus speaketh the LORD of hosts, the God of Israel, saying, Because thou hast sent letters in thy name unto all the people that are at Jerusalem, and to Zephaniah the son of Maaseiah the priest, and to all the priests, saying,
19662	774	26	The LORD hath made thee priest in the stead of Jehoiada the priest, that ye should be officers in the house of the LORD, for every man that is mad, and maketh himself a prophet, that thou shouldest put him in prison, and in the stocks.
19663	774	27	Now therefore why hast thou not reproved Jeremiah of Anathoth, which maketh himself a prophet to you?
19664	774	28	For therefore he sent unto us in Babylon, saying, This captivity is long: build ye houses, and dwell in them; and plant gardens, and eat the fruit of them.
19665	774	29	And Zephaniah the priest read this letter in the ears of Jeremiah the prophet.
19666	774	30	Then came the word of the LORD unto Jeremiah, saying,
19667	774	31	Send to all them of the captivity, saying, Thus saith the LORD concerning Shemaiah the Nehelamite; Because that Shemaiah hath prophesied unto you, and I sent him not, and he caused you to trust in a lie:
19668	774	32	Therefore thus saith the LORD; Behold, I will punish Shemaiah the Nehelamite, and his seed: he shall not have a man to dwell among this people; neither shall he behold the good that I will do for my people, saith the LORD; because he hath taught rebellion against the LORD.
19669	775	1	THE word that came to Jeremiah from the LORD, saying,
19670	775	2	Thus speaketh the LORD God of Israel, saying, Write thee all the words that I have spoken unto thee in a book.
19671	775	3	For, lo, the days come, saith the LORD, that I will bring again the captivity of my people Israel and Judah, saith the LORD: and I will cause them to return to the land that I gave to their fathers, and they shall possess it.
19672	775	4	And these are the words that the LORD spake concerning Israel and concerning Judah.
19673	775	5	For thus saith the LORD; We have heard a voice of trembling, of fear, and not of peace.
19674	775	6	Ask ye now, and see whether a man doth travail with child? wherefore do I see every man with his hands on his loins, as a woman in travail, and all faces are turned into paleness?
19675	775	7	Alas! for that day is great, so that none is like it: it is even the time of Jacob's trouble; but he shall be saved out of it.
19676	775	8	For it shall come to pass in that day, saith the LORD of hosts, that I will break his yoke from off thy neck, and will burst thy bonds, and strangers shall no more serve themselves of him:
19677	775	9	But they shall serve the LORD their God, and David their king, whom I will raise up unto them.
19678	775	10	Therefore fear thou not, O my servant Jacob, saith the LORD; neither be dismayed, O Israel: for, lo, I will save thee from afar, and thy seed from the land of their captivity; and Jacob shall return, and shall be in rest, and be quiet, and none shall make him afraid.
19679	775	11	For I am with thee, saith the LORD, to save thee: though I make a full end of all nations whither I have scattered thee, yet will I not make a full end of thee: but I will correct thee in measure, and will not leave thee altogether unpunished.
19680	775	12	For thus saith the LORD, Thy bruise is incurable, and thy wound is grievous.
19681	775	13	There is none to plead thy cause, that thou mayest be bound up: thou hast no healing medicines.
19682	775	14	All thy lovers have forgotten thee; they seek thee not; for I have wounded thee with the wound of an enemy, with the chastisement of a cruel one, for the multitude of thine iniquity; because thy sins were increased.
19683	775	15	Why criest thou for thine affliction? thy sorrow is incurable for the multitude of thine iniquity: because thy sins were increased, I have done these things unto thee.
19684	775	16	Therefore all they that devour thee shall be devoured; and all thine adversaries, every one of them, shall go into captivity; and they that spoil thee shall be a spoil, and all that prey upon thee will I give for a prey.
19685	775	17	For I will restore health unto thee, and I will heal thee of thy wounds, saith the LORD; because they called thee an Outcast, saying, This is Zion, whom no man seeketh after.
19686	775	18	Thus saith the LORD; Behold, I will bring again the captivity of Jacob's tents, and have mercy on his dwellingplaces; and the city shall be builded upon her own heap, and the palace shall remain after the manner thereof.
19687	775	19	And out of them shall proceed thanksgiving and the voice of them that make merry: and I will multiply them, and they shall not be few; I will also glorify them, and they shall not be small.
19688	775	20	Their children also shall be as aforetime, and their congregation shall be established before me, and I will punish all that oppress them.
19689	775	21	And their nobles shall be of themselves, and their governor shall proceed from the midst of them; and I will cause him to draw near, and he shall approach unto me: for who is this that engaged his heart to approach unto me? saith the LORD.
19690	775	22	And ye shall be my people, and I will be your God.
19691	775	23	Behold, the whirlwind of the LORD goeth forth with fury, a continuing whirlwind: it shall fall with pain upon the head of the wicked.
19692	775	24	The fierce anger of the LORD shall not return, until he have done it, and until he have performed the intents of his heart: in the latter days ye shall consider it.
19693	776	1	AT the same time, saith the LORD, will I be the God of all the families of Israel, and they shall be my people.
19694	776	2	Thus saith the LORD, The people which were left of the sword found grace in the wilderness; even Israel, when I went to cause him to rest.
19695	776	3	The LORD hath appeared of old unto me, saying, Yea, I have loved thee with an everlasting love: therefore with lovingkindness have I drawn thee.
19696	776	4	Again I will build thee, and thou shalt be built, O virgin of Israel: thou shalt again be adorned with thy tabrets, and shalt go forth in the dances of them that make merry.
19697	776	5	Thou shalt yet plant vines upon the mountains of Samaria: the planters shall plant, and shall eat them as common things.
19698	776	6	For there shall be a day, that the watchmen upon the mount Ephraim shall cry, Arise ye, and let us go up to Zion unto the LORD our God.
19699	776	7	For thus saith the LORD; Sing with gladness for Jacob, and shout among the chief of the nations: publish ye, praise ye, and say, O LORD, save thy people, the remnant of Israel.
19700	776	8	Behold, I will bring them from the north country, and gather them from the coasts of the earth, and with them the blind and the lame, the woman with child and her that travaileth with child together: a great company shall return thither.
19701	776	9	They shall come with weeping, and with supplications will I lead them: I will cause them to walk by the rivers of waters in a straight way, wherein they shall not stumble: for I am a father to Israel, and Ephraim is my firstborn.
19702	776	10	Hear the word of the LORD, O ye nations, and declare it in the isles afar off, and say, He that scattered Israel will gather him, and keep him, as a shepherd doth his flock.
19703	776	11	For the LORD hath redeemed Jacob, and ransomed him from the hand of him that was stronger than he.
19704	776	12	Therefore they shall come and sing in the height of Zion, and shall flow together to the goodness of the LORD, for wheat, and for wine, and for oil, and for the young of the flock and of the herd: and their soul shall be as a watered garden; and they shall not sorrow any more at all.
19705	776	13	Then shall the virgin rejoice in the dance, both young men and old together: for I will turn their mourning into joy, and will comfort them, and make them rejoice from their sorrow.
19706	776	14	And I will satiate the soul of the priests with fatness, and my people shall be satisfied with my goodness, saith the LORD.
19707	776	15	Thus saith the LORD; A voice was heard in Ramah, lamentation, and bitter weeping; Rahel weeping for her children refused to be comforted for her children, because they were not.
19708	776	16	Thus saith the LORD; Refrain thy voice from weeping, and thine eyes from tears: for thy work shall be rewarded, saith the LORD; and they shall come again from the land of the enemy.
19709	776	17	And there is hope in thine end, saith the LORD, that thy children shall come again to their own border.
19710	776	18	I have surely heard Ephraim bemoaning himself thus; Thou hast chastised me, and I was chastised, as a bullock unaccustomed to the yoke: turn thou me, and I shall be turned; for thou art the LORD my God.
19711	776	19	Surely after that I was turned, I repented; and after that I was instructed, I smote upon my thigh: I was ashamed, yea, even confounded, because I did bear the reproach of my youth.
19712	776	20	Is Ephraim my dear son? is he a pleasant child? for since I spake against him, I do earnestly remember him still: therefore my bowels are troubled for him; I will surely have mercy upon him, saith the LORD.
19713	776	21	Set thee up waymarks, make thee high heaps: set thine heart toward the highway, even the way which thou wentest: turn again, O virgin of Israel, turn again to these thy cities.
19714	776	22	How long wilt thou go about, O thou backsliding daughter? for the LORD hath created a new thing in the earth, A woman shall compass a man.
19715	776	23	Thus saith the LORD of hosts, the God of Israel; As yet they shall use this speech in the land of Judah and in the cities thereof, when I shall bring again their captivity; The LORD bless thee, O habitation of justice, and mountain of holiness.
19716	776	24	And there shall dwell in Judah itself, and in all the cities thereof together, husbandmen, and they that go forth with flocks.
19717	776	25	For I have satiated the weary soul, and I have replenished every sorrowful soul.
19718	776	26	Upon this I awaked, and beheld; and my sleep was sweet unto me.
19719	776	27	Behold, the days come, saith the LORD, that I will sow the house of Israel and the house of Judah with the seed of man, and with the seed of beast.
19720	776	28	And it shall come to pass, that like as I have watched over them, to pluck up, and to break down, and to throw down, and to destroy, and to afflict; so will I watch over them, to build, and to plant, saith the LORD.
19721	776	29	In those days they shall say no more, The fathers have eaten a sour grape, and the children's teeth are set on edge.
19722	776	30	But every one shall die for his own iniquity: every man that eateth the sour grape, his teeth shall be set on edge.
19723	776	31	Behold, the days come, saith the LORD, that I will make a new covenant with the house of Israel, and with the house of Judah:
19724	776	32	Not according to the covenant that I made with their fathers in the day that I took them by the hand to bring them out of the land of Egypt; which my covenant they brake, although I was an husband unto them, saith the LORD:
19725	776	33	But this shall be the covenant that I will make with the house of Israel; After those days, saith the LORD, I will put my law in their inward parts, and write it in their hearts; and will be their God, and they shall be my people.
19726	776	34	And they shall teach no more every man his neighbour, and every man his brother, saying, Know the LORD: for they shall all know me, from the least of them unto the greatest of them, saith the LORD; for I will forgive their iniquity, and I will remember their sin no more.
19727	776	35	Thus saith the LORD, which giveth the sun for a light by day, and the ordinances of the moon and of the stars for a light by night, which divideth the sea when the waves thereof roar; The LORD of hosts is his name:
19728	776	36	If those ordinances depart from before me, saith the LORD, then the seed of Israel also shall cease from being a nation before me for ever.
19729	776	37	Thus saith the LORD; If heaven above can be measured, and the foundations of the earth searched out beneath, I will also cast off all the seed of Israel for all that they have done, saith the LORD.
19730	776	38	Behold, the days come, saith the LORD, that the city shall be built to the LORD from the tower of Hananeel unto the gate of the corner.
19731	776	39	And the measuring line shall yet go forth over against it upon the hill Gareb, and shall compass about to Goath.
19732	776	40	And the whole valley of the dead bodies, and of the ashes, and all the fields unto the brook of Kidron, unto the corner of the horse gate toward the east, shall be holy unto the LORD; it shall not be plucked up, nor thrown down any more for ever.
19733	777	1	THE word that came to Jeremiah from the LORD in the tenth year of Zedekiah king of Judah, which was the eighteenth year of Nebuchadrezzar.
19734	777	2	For then the king of Babylon's army besieged Jerusalem: and Jeremiah the prophet was shut up in the court of the prison, which was in the king of Judah's house.
19735	777	3	For Zedekiah king of Judah had shut him up, saying, Wherefore dost thou prophesy, and say, Thus saith the LORD, Behold, I will give this city into the hand of the king of Babylon, and he shall take it;
19736	777	4	And Zedekiah king of Judah shall not escape out of the hand of the Chaldeans, but shall surely be delivered into the hand of the king of Babylon, and shall speak with him mouth to mouth, and his eyes shall behold his eyes;
19737	777	5	And he shall lead Zedekiah to Babylon, and there shall he be until I visit him, saith the LORD: though ye fight with the Chaldeans, ye shall not prosper?
19738	777	6	And Jeremiah said, The word of the LORD came unto me, saying,
19739	777	7	Behold, Hanameel the son of Shallum thine uncle shall come unto thee, saying, Buy thee my field that is in Anathoth: for the right of redemption is thine to buy it.
19740	777	8	So Hanameel mine uncle's son came to me in the court of the prison according to the word of the LORD, and said unto me, Buy my field, I pray thee, that is in Anathoth, which is in the country of Benjamin: for the right of inheritance is thine, and the redemption is thine; buy it for thyself. Then I knew that this was the word of the LORD.
19741	777	9	And I bought the field of Hanameel my uncle's son, that was in Anathoth, and weighed him the money, even seventeen shekels of silver.
19742	777	10	And I subscribed the evidence, and sealed it, and took witnesses, and weighed him the money in the balances.
19743	777	11	So I took the evidence of the purchase, both that which was sealed according to the law and custom, and that which was open:
19744	777	12	And I gave the evidence of the purchase unto Baruch the son of Neriah, the son of Maaseiah, in the sight of Hanameel mine uncle's son, and in the presence of the witnesses that subscribed the book of the purchase, before all the Jews that sat in the court of the prison.
19745	777	13	And I charged Baruch before them, saying,
19746	777	14	Thus saith the LORD of hosts, the God of Israel; Take these evidences, this evidence of the purchase, both which is sealed, and this evidence which is open; and put them in an earthen vessel, that they may continue many days.
19747	777	15	For thus saith the LORD of hosts, the God of Israel; Houses and fields and vineyards shall be possessed again in this land.
19748	777	16	Now when I had delivered the evidence of the purchase unto Baruch the son of Neriah, I prayed unto the LORD, saying,
19749	777	17	Ah Lord GOD! behold, thou hast made the heaven and the earth by thy great power and stretched out arm, and there is nothing too hard for thee:
19750	777	18	Thou shewest lovingkindness unto thousands, and recompensest the iniquity of the fathers into the bosom of their children after them: the Great, the Mighty God, the LORD of hosts, is his name,
19751	777	19	Great in counsel, and mighty in work: for thine eyes are open upon all the ways of the sons of men: to give every one according to his ways, and according to the fruit of his doings:
19752	777	20	Which hast set signs and wonders in the land of Egypt, even unto this day, and in Israel, and among other men; and hast made thee a name, as at this day;
19753	777	21	And hast brought forth thy people Israel out of the land of Egypt with signs, and with wonders, and with a strong hand, and with a stretched out arm, and with great terror;
19754	777	22	And hast given them this land, which thou didst swear to their fathers to give them, a land flowing with milk and honey;
19755	777	23	And they came in, and possessed it; but they obeyed not thy voice, neither walked in thy law; they have done nothing of all that thou commandedst them to do: therefore thou hast caused all this evil to come upon them:
19756	777	24	Behold the mounts, they are come unto the city to take it; and the city is given into the hand of the Chaldeans, that fight against it, because of the sword, and of the famine, and of the pestilence: and what thou hast spoken is come to pass; and, behold, thou seest it.
19757	777	25	And thou hast said unto me, O Lord GOD, Buy thee the field for money, and take witnesses; for the city is given into the hand of the Chaldeans.
19758	777	26	Then came the word of the LORD unto Jeremiah, saying,
19759	777	27	Behold, I am the LORD, the God of all flesh: is there any thing too hard for me?
19760	777	28	Therefore thus saith the LORD; Behold, I will give this city into the hand of the Chaldeans, and into the hand of Nebuchadrezzar king of Babylon, and he shall take it:
19761	777	29	And the Chaldeans, that fight against this city, shall come and set fire on this city, and burn it with the houses, upon whose roofs they have offered incense unto Baal, and poured out drink offerings unto other gods, to provoke me to anger.
19762	777	30	For the children of Israel and the children of Judah have only done evil before me from their youth: for the children of Israel have only provoked me to anger with the work of their hands, saith the LORD.
19763	777	31	For this city hath been to me as a provocation of mine anger and of my fury from the day that they built it even unto this day; that I should remove it from before my face,
19764	777	32	Because of all the evil of the children of Israel and of the children of Judah, which they have done to provoke me to anger, they, their kings, their princes, their priests, and their prophets, and the men of Judah, and the inhabitants of Jerusalem.
19765	777	33	And they have turned unto me the back, and not the face: though I taught them, rising up early and teaching them, yet they have not hearkened to receive instruction.
19766	777	34	But they set their abominations in the house, which is called by my name, to defile it.
19767	777	35	And they built the high places of Baal, which are in the valley of the son of Hinnom, to cause their sons and their daughters to pass through the fire unto Molech; which I commanded them not, neither came it into my mind, that they should do this abomination, to cause Judah to sin.
19768	777	36	And now therefore thus saith the LORD, the God of Israel, concerning this city, whereof ye say, It shall be delivered into the hand of the king of Babylon by the sword, and by the famine, and by the pestilence;
19769	777	37	Behold, I will gather them out of all countries, whither I have driven them in mine anger, and in my fury, and in great wrath; and I will bring them again unto this place, and I will cause them to dwell safely:
19770	777	38	And they shall be my people, and I will be their God:
19771	777	39	And I will give them one heart, and one way, that they may fear me for ever, for the good of them, and of their children after them:
19772	777	40	And I will make an everlasting covenant with them, that I will not turn away from them, to do them good; but I will put my fear in their hearts, that they shall not depart from me.
19773	777	41	Yea, I will rejoice over them to do them good, and I will plant them in this land assuredly with my whole heart and with my whole soul.
19774	777	42	For thus saith the LORD; Like as I have brought all this great evil upon this people, so will I bring upon them all the good that I have promised them.
19775	777	43	And fields shall be bought in this land, whereof ye say, It is desolate without man or beast; it is given into the hand of the Chaldeans.
19776	777	44	Men shall buy fields for money, and subscribe evidences, and seal them, and take witnesses in the land of Benjamin, and in the places about Jerusalem, and in the cities of Judah, and in the cities of the mountains, and in the cities of the valley, and in the cities of the south: for I will cause their captivity to return, saith the LORD.
19777	778	1	MOREOVER the word of the LORD came unto Jeremiah the second time, while he was yet shut up in the court of the prison, saying,
19778	778	2	Thus saith the LORD the maker thereof, the LORD that formed it, to establish it; the LORD is his name;
19779	778	3	Call unto me, and I will answer thee, and shew thee great and mighty things, which thou knowest not.
19780	778	4	For thus saith the LORD, the God of Israel, concerning the houses of this city, and concerning the houses of the kings of Judah, which are thrown down by the mounts, and by the sword;
19781	778	5	They come to fight with the Chaldeans, but it is to fill them with the dead bodies of men, whom I have slain in mine anger and in my fury, and for all whose wickedness I have hid my face from this city.
19782	778	6	Behold, I will bring it health and cure, and I will cure them, and will reveal unto them the abundance of peace and truth.
19783	778	7	And I will cause the captivity of Judah and the captivity of Israel to return, and will build them, as at the first.
19784	778	8	And I will cleanse them from all their iniquity, whereby they have sinned against me; and I will pardon all their iniquities, whereby they have sinned, and whereby they have transgressed against me.
19785	778	9	And it shall be to me a name of joy, a praise and an honour before all the nations of the earth, which shall hear all the good that I do unto them: and they shall fear and tremble for all the goodness and for all the prosperity that I procure unto it.
19786	778	10	Thus saith the LORD; Again there shall be heard in this place, which ye say shall be desolate without man and without beast, even in the cities of Judah, and in the streets of Jerusalem, that are desolate, without man, and without inhabitant, and without beast,
19787	778	11	The voice of joy, and the voice of gladness, the voice of the bridegroom, and the voice of the bride, the voice of them that shall say, Praise the LORD of hosts: for the LORD is good; for his mercy endureth for ever: and of them that shall bring the sacrifice of praise into the house of the LORD. For I will cause to return the captivity of the land, as at the first, saith the LORD.
19788	778	12	Thus saith the LORD of hosts; Again in this place, which is desolate without man and without beast, and in all the cities thereof, shall be an habitation of shepherds causing their flocks to lie down.
19789	778	13	In the cities of the mountains, in the cities of the vale, and in the cities of the south, and in the land of Benjamin, and in the places about Jerusalem, and in the cities of Judah, shall the flocks pass again under the hands of him that telleth them, saith the LORD.
19790	778	14	Behold, the days come, saith the LORD, that I will perform that good thing which I have promised unto the house of Israel and to the house of Judah.
19791	778	15	In those days, and at that time, will I cause the Branch of righteousness to grow up unto David; and he shall execute judgment and righteousness in the land.
19792	778	16	In those days shall Judah be saved, and Jerusalem shall dwell safely: and this is the name wherewith she shall be called, The LORD our righteousness.
19793	778	17	For thus saith the LORD; David shall never want a man to sit upon the throne of the house of Israel;
19794	778	18	Neither shall the priests the Levites want a man before me to offer burnt offerings, and to kindle meat offerings, and to do sacrifice continually.
19795	778	19	And the word of the LORD came unto Jeremiah, saying,
19796	778	20	Thus saith the LORD; If ye can break my covenant of the day, and my covenant of the night, and that there should not be day and night in their season;
19797	778	21	Then may also my covenant be broken with David my servant, that he should not have a son to reign upon his throne; and with the Levites the priests, my ministers.
19798	778	22	As the host of heaven cannot be numbered, neither the sand of the sea measured: so will I multiply the seed of David my servant, and the Levites that minister unto me.
19799	778	23	Moreover the word of the LORD came to Jeremiah, saying,
19800	778	24	Considerest thou not what this people have spoken, saying, The two families which the LORD hath chosen, he hath even cast them off? thus they have despised my people, that they should be no more a nation before them.
19801	778	25	Thus saith the LORD; If my covenant be not with day and night, and if I have not appointed the ordinances of heaven and earth;
19802	778	26	Then will I cast away the seed of Jacob, and David my servant, so that I will not take any of his seed to be rulers over the seed of Abraham, Isaac, and Jacob: for I will cause their captivity to return, and have mercy on them.
19803	779	1	THE word which came unto Jeremiah from the LORD, when Nebuchadnezzar king of Babylon, and all his army, and all the kingdoms of the earth of his dominion, and all the people, fought against Jerusalem, and against all the cities thereof, saying,
19804	779	2	Thus saith the LORD, the God of Israel; Go and speak to Zedekiah king of Judah, and tell him, Thus saith the LORD; Behold, I will give this city into the hand of the king of Babylon, and he shall burn it with fire:
19805	779	3	And thou shalt not escape out of his hand, but shalt surely be taken, and delivered into his hand; and thine eyes shall behold the eyes of the king of Babylon, and he shall speak with thee mouth to mouth, and thou shalt go to Babylon.
19806	779	4	Yet hear the word of the LORD, O Zedekiah king of Judah; Thus saith the LORD of thee, Thou shalt not die by the sword:
19807	779	5	But thou shalt die in peace: and with the burnings of thy fathers, the former kings which were before thee, so shall they burn odours for thee; and they will lament thee, saying, Ah lord! for I have pronounced the word, saith the LORD.
19808	779	6	Then Jeremiah the prophet spake all these words unto Zedekiah king of Judah in Jerusalem,
19809	779	7	When the king of Babylon's army fought against Jerusalem, and against all the cities of Judah that were left, against Lachish, and against Azekah: for these defenced cities remained of the cities of Judah.
19810	779	8	This is the word that came unto Jeremiah from the LORD, after that the king Zedekiah had made a covenant with all the people which were at Jerusalem, to proclaim liberty unto them;
19811	779	9	That every man should let his manservant, and every man his maidservant, being an Hebrew or an Hebrewess, go free; that none should serve himself of them, to wit, of a Jew his brother.
19812	779	10	Now when all the princes, and all the people, which had entered into the covenant, heard that every one should let his manservant, and every one his maidservant, go free, that none should serve themselves of them any more, then they obeyed, and let them go.
19813	779	11	But afterward they turned, and caused the servants and the handmaids, whom they had let go free, to return, and brought them into subjection for servants and for handmaids.
19814	779	12	Therefore the word of the LORD came to Jeremiah from the LORD, saying,
19815	779	13	Thus saith the LORD, the God of Israel; I made a covenant with your fathers in the day that I brought them forth out of the land of Egypt, out of the house of bondmen, saying,
19816	779	14	At the end of seven years let ye go every man his brother an Hebrew, which hath been sold unto thee; and when he hath served thee six years, thou shalt let him go free from thee: but your fathers hearkened not unto me, neither inclined their ear.
19817	779	15	And ye were now turned, and had done right in my sight, in proclaiming liberty every man to his neighbour; and ye had made a covenant before me in the house which is called by my name:
19818	779	16	But ye turned and polluted my name, and caused every man his servant, and every man his handmaid, whom ye had set at liberty at their pleasure, to return, and brought them into subjection, to be unto you for servants and for handmaids.
19819	779	17	Therefore thus saith the LORD; Ye have not hearkened unto me, in proclaiming liberty, every one to his brother, and every man to his neighbour: behold, I proclaim a liberty for you, saith the LORD, to the sword, to the pestilence, and to the famine; and I will make you to be removed into all the kingdoms of the earth.
19820	779	18	And I will give the men that have transgressed my covenant, which have not performed the words of the covenant which they had made before me, when they cut the calf in twain, and passed between the parts thereof,
19821	779	19	The princes of Judah, and the princes of Jerusalem, the eunuchs, and the priests, and all the people of the land, which passed between the parts of the calf;
19822	779	20	I will even give them into the hand of their enemies, and into the hand of them that seek their life: and their dead bodies shall be for meat unto the fowls of the heaven, and to the beasts of the earth.
19823	779	21	And Zedekiah king of Judah and his princes will I give into the hand of their enemies, and into the hand of them that seek their life, and into the hand of the king of Babylon's army, which are gone up from you.
19824	779	22	Behold, I will command, saith the LORD, and cause them to return to this city; and they shall fight against it, and take it, and burn it with fire: and I will make the cities of Judah a desolation without an inhabitant.
19825	780	1	THE word which came unto Jeremiah from the LORD in the days of Jehoiakim the son of Josiah king of Judah, saying,
19826	780	2	Go unto the house of the Rechabites, and speak unto them, and bring them into the house of the LORD, into one of the chambers, and give them wine to drink.
19827	780	3	Then I took Jaazaniah the son of Jeremiah, the son of Habaziniah, and his brethren, and all his sons, and the whole house of the Rechabites;
19828	780	4	And I brought them into the house of the LORD, into the chamber of the sons of Hanan, the son of Igdaliah, a man of God, which was by the chamber of the princes, which was above the chamber of Maaseiah the son of Shallum, the keeper of the door:
19829	780	5	And I set before the sons of the house of the Rechabites pots full of wine, and cups, and I said unto them, Drink ye wine.
19830	780	6	But they said, We will drink no wine: for Jonadab the son of Rechab our father commanded us, saying, Ye shall drink no wine, neither ye, nor your sons for ever:
19831	780	7	Neither shall ye build house, nor sow seed, nor plant vineyard, nor have any: but all your days ye shall dwell in tents; that ye may live many days in the land where ye be strangers.
19832	780	8	Thus have we obeyed the voice of Jonadab the son of Rechab our father in all that he hath charged us, to drink no wine all our days, we, our wives, our sons, nor our daughters;
19833	780	9	Nor to build houses for us to dwell in: neither have we vineyard, nor field, nor seed:
19834	780	10	But we have dwelt in tents, and have obeyed, and done according to all that Jonadab our father commanded us.
19835	780	11	But it came to pass, when Nebuchadrezzar king of Babylon came up into the land, that we said, Come, and let us go to Jerusalem for fear of the army of the Chaldeans, and for fear of the army of the Syrians: so we dwell at Jerusalem.
19836	780	12	Then came the word of the LORD unto Jeremiah, saying,
19837	780	13	Thus saith the LORD of hosts, the God of Israel; Go and tell the men of Judah and the inhabitants of Jerusalem, Will ye not receive instruction to hearken to my words? saith the LORD.
19838	780	14	The words of Jonadab the son of Rechab, that he commanded his sons not to drink wine, are performed; for unto this day they drink none, but obey their father's commandment: notwithstanding I have spoken unto you, rising early and speaking; but ye hearkened not unto me.
19839	780	15	I have sent also unto you all my servants the prophets, rising up early and sending them, saying, Return ye now every man from his evil way, and amend your doings, and go not after other gods to serve them, and ye shall dwell in the land which I have given to you and to your fathers: but ye have not inclined your ear, nor hearkened unto me.
19840	780	16	Because the sons of Jonadab the son of Rechab have performed the commandment of their father, which he commanded them; but this people hath not hearkened unto me:
19841	780	17	Therefore thus saith the LORD God of hosts, the God of Israel; Behold, I will bring upon Judah and upon all the inhabitants of Jerusalem all the evil that I have pronounced against them: because I have spoken unto them, but they have not heard; and I have called unto them, but they have not answered.
19842	780	18	And Jeremiah said unto the house of the Rechabites, Thus saith the LORD of hosts, the God of Israel; Because ye have obeyed the commandment of Jonadab your father, and kept all his precepts, and done according unto all that he hath commanded you:
19843	780	19	Therefore thus saith the LORD of hosts, the God of Israel; Jonadab the son of Rechab shall not want a man to stand before me for ever.
19844	781	1	AND it came to pass in the fourth year of Jehoiakim the son of Josiah king of Judah, that this word came unto Jeremiah from the LORD, saying,
19845	781	2	Take thee a roll of a book, and write therein all the words that I have spoken unto thee against Israel, and against Judah, and against all the nations, from the day I spake unto thee, from the days of Josiah, even unto this day.
19846	781	3	It may be that the house of Judah will hear all the evil which I purpose to do unto them; that they may return every man from his evil way; that I may forgive their iniquity and their sin.
19847	781	4	Then Jeremiah called Baruch the son of Neriah: and Baruch wrote from the mouth of Jeremiah all the words of the LORD, which he had spoken unto him, upon a roll of a book.
19848	781	5	And Jeremiah commanded Baruch, saying, I am shut up; I cannot go into the house of the LORD:
19849	781	6	Therefore go thou, and read in the roll, which thou hast written from my mouth, the words of the LORD in the ears of the people in the LORD's house upon the fasting day: and also thou shalt read them in the ears of all Judah that come out of their cities.
19850	781	7	It may be they will present their supplication before the LORD, and will return every one from his evil way: for great is the anger and the fury that the LORD hath pronounced against this people.
19851	781	8	And Baruch the son of Neriah did according to all that Jeremiah the prophet commanded him, reading in the book the words of the LORD in the LORD's house.
19852	781	9	And it came to pass in the fifth year of Jehoiakim the son of Josiah king of Judah, in the ninth month, that they proclaimed a fast before the LORD to all the people in Jerusalem, and to all the people that came from the cities of Judah unto Jerusalem.
19853	781	10	Then read Baruch in the book the words of Jeremiah in the house of the LORD, in the chamber of Gemariah the son of Shaphan the scribe, in the higher court, at the entry of the new gate of the LORD's house, in the ears of all the people.
19854	781	11	When Michaiah the son of Gemariah, the son of Shaphan, had heard out of the book all the words of the LORD,
19855	781	12	Then he went down into the king's house, into the scribe's chamber: and, lo, all the princes sat there, even Elishama the scribe, and Delaiah the son of Shemaiah, and Elnathan the son of Achbor, and Gemariah the son of Shaphan, and Zedekiah the son of Hananiah, and all the princes.
19856	781	13	Then Michaiah declared unto them all the words that he had heard, when Baruch read the book in the ears of the people.
19857	781	14	Therefore all the princes sent Jehudi the son of Nethaniah, the son of Shelemiah, the son of Cushi, unto Baruch, saying, Take in thine hand the roll wherein thou hast read in the ears of the people, and come. So Baruch the son of Neriah took the roll in his hand, and came unto them.
19858	781	15	And they said unto him, Sit down now, and read it in our ears. So Baruch read it in their ears.
19859	781	16	Now it came to pass, when they had heard all the words, they were afraid both one and other, and said unto Baruch, We will surely tell the king of all these words.
19860	781	17	And they asked Baruch, saying, Tell us now, How didst thou write all these words at his mouth?
19861	781	18	Then Baruch answered them, He pronounced all these words unto me with his mouth, and I wrote them with ink in the book.
19862	781	19	Then said the princes unto Baruch, Go, hide thee, thou and Jeremiah; and let no man know where ye be.
19863	781	20	And they went in to the king into the court, but they laid up the roll in the chamber of Elishama the scribe, and told all the words in the ears of the king.
19864	781	21	So the king sent Jehudi to fetch the roll: and he took it out of Elishama the scribe's chamber. And Jehudi read it in the ears of the king, and in the ears of all the princes which stood beside the king.
19865	781	22	Now the king sat in the winterhouse in the ninth month: and there was a fire on the hearth burning before him.
19866	781	23	And it came to pass, that when Jehudi had read three or four leaves, he cut it with the penknife, and cast it into the fire that was on the hearth, until all the roll was consumed in the fire that was on the hearth.
19867	781	24	Yet they were not afraid, nor rent their garments, neither the king, nor any of his servants that heard all these words.
19868	781	25	Nevertheless Elnathan and Delaiah and Gemariah had made intercession to the king that he would not burn the roll: but he would not hear them.
19869	781	26	But the king commanded Jerahmeel the son of Hammelech, and Seraiah the son of Azriel, and Shelemiah the son of Abdeel, to take Baruch the scribe and Jeremiah the prophet: but the LORD hid them.
19870	781	27	Then the word of the LORD came to Jeremiah, after that the king had burned the roll, and the words which Baruch wrote at the mouth of Jeremiah, saying,
19871	781	28	Take thee again another roll, and write in it all the former words that were in the first roll, which Jehoiakim the king of Judah hath burned.
19872	781	29	And thou shalt say to Jehoiakim king of Judah, Thus saith the LORD; Thou hast burned this roll, saying, Why hast thou written therein, saying, The king of Babylon shall certainly come and destroy this land, and shall cause to cease from thence man and beast?
19873	781	30	Therefore thus saith the LORD of Jehoiakim king of Judah; He shall have none to sit upon the throne of David: and his dead body shall be cast out in the day to the heat, and in the night to the frost.
19874	781	31	And I will punish him and his seed and his servants for their iniquity; and I will bring upon them, and upon the inhabitants of Jerusalem, and upon the men of Judah, all the evil that I have pronounced against them; but they hearkened not.
19875	781	32	Then took Jeremiah another roll, and gave it to Baruch the scribe, the son of Neriah; who wrote therein from the mouth of Jeremiah all the words of the book which Jehoiakim king of Judah had burned in the fire: and there were added besides unto them many like words.
19876	782	1	AND king Zedekiah the son of Josiah reigned instead of Coniah the son of Jehoiakim, whom Nebuchadrezzar king of Babylon made king in the land of Judah.
19877	782	2	But neither he, nor his servants, nor the people of the land, did hearken unto the words of the LORD, which he spake by the prophet Jeremiah.
19878	782	3	And Zedekiah the king sent Jehucal the son of Shelemiah and Zephaniah the son of Maaseiah the priest to the prophet Jeremiah, saying, Pray now unto the LORD our God for us.
19879	782	4	Now Jeremiah came in and went out among the people: for they had not put him into prison.
19880	782	5	Then Pharaoh's army was come forth out of Egypt: and when the Chaldeans that besieged Jerusalem heard tidings of them, they departed from Jerusalem.
19881	782	6	Then came the word of the LORD unto the prophet Jeremiah, saying,
19882	782	7	Thus saith the LORD, the God of Israel; Thus shall ye say to the king of Judah, that sent you unto me to inquire of me; Behold, Pharaoh's army, which is come forth to help you, shall return to Egypt into their own land.
19883	782	8	And the Chaldeans shall come again, and fight against this city, and take it, and burn it with fire.
19884	782	9	Thus saith the LORD; Deceive not yourselves, saying, The Chaldeans shall surely depart from us: for they shall not depart.
19885	782	10	For though ye had smitten the whole army of the Chaldeans that fight against you, and there remained but wounded men among them, yet should they rise up every man in his tent, and burn this city with fire.
19886	782	11	And it came to pass, that when the army of the Chaldeans was broken up from Jerusalem for fear of Pharaoh's army,
19887	782	12	Then Jeremiah went forth out of Jerusalem to go into the land of Benjamin, to separate himself thence in the midst of the people.
19888	782	13	And when he was in the gate of Benjamin, a captain of the ward was there, whose name was Irijah, the son of Shelemiah, the son of Hananiah; and he took Jeremiah the prophet, saying, Thou fallest away to the Chaldeans.
19889	782	14	Then said Jeremiah, It is false; I fall not away to the Chaldeans. But he hearkened not to him: so Irijah took Jeremiah, and brought him to the princes.
19890	782	15	Wherefore the princes were wroth with Jeremiah, and smote him, and put him in prison in the house of Jonathan the scribe: for they had made that the prison.
19891	782	16	When Jeremiah was entered into the dungeon, and into the cabins, and Jeremiah had remained there many days;
19892	782	17	Then Zedekiah the king sent, and took him out: and the king asked him secretly in his house, and said, Is there any word from the LORD? And Jeremiah said, There is: for, said he, thou shalt be delivered into the hand of the king of Babylon.
19893	782	18	Moreover Jeremiah said unto king Zedekiah, What have I offended against thee, or against thy servants, or against this people, that ye have put me in prison?
19894	782	19	Where are now your prophets which prophesied unto you, saying, The king of Babylon shall not come against you, nor against this land?
19895	782	20	Therefore hear now, I pray thee, O my lord the king: let my supplication, I pray thee, be accepted before thee; that thou cause me not to return to the house of Jonathan the scribe, lest I die there.
19896	782	21	Then Zedekiah the king commanded that they should commit Jeremiah into the court of the prison, and that they should give him daily a piece of bread out of the bakers' street, until all the bread in the city were spent. Thus Jeremiah remained in the court of the prison.
19897	783	1	THEN Shephatiah the son of Mattan, and Gedaliah the son of Pashur, and Jucal the son of Shelemiah, and Pashur the son of Malchiah, heard the words that Jeremiah had spoken unto all the people, saying,
19898	783	2	Thus saith the LORD, He that remaineth in this city shall die by the sword, by the famine, and by the pestilence: but he that goeth forth to the Chaldeans shall live; for he shall have his life for a prey, and shall live.
19899	783	3	Thus saith the LORD, This city shall surely be given into the hand of the king of Babylon's army, which shall take it.
19900	783	4	Therefore the princes said unto the king, We beseech thee, let this man be put to death: for thus he weakeneth the hands of the men of war that remain in this city, and the hands of all the people, in speaking such words unto them: for this man seeketh not the welfare of this people, but the hurt.
19901	783	5	Then Zedekiah the king said, Behold, he is in your hand: for the king is not he that can do any thing against you.
19902	783	6	Then took they Jeremiah, and cast him into the dungeon of Malchiah the son of Hammelech, that was in the court of the prison: and they let down Jeremiah with cords. And in the dungeon there was no water, but mire: so Jeremiah sunk in the mire.
19903	783	7	Now when Ebed-melech the Ethiopian, one of the eunuchs which was in the king's house, heard that they had put Jeremiah in the dungeon; the king then sitting in the gate of Benjamin;
19904	783	8	Ebed-melech went forth out of the king's house, and spake to the king, saying,
19905	783	9	My lord the king, these men have done evil in all that they have done to Jeremiah the prophet, whom they have cast into the dungeon; and he is like to die for hunger in the place where he is: for there is no more bread in the city.
19906	783	10	Then the king commanded Ebed-melech the Ethiopian, saying, Take from hence thirty men with thee, and take up Jeremiah the prophet out of the dungeon, before he die.
19907	783	11	So Ebed-melech took the men with him, and went into the house of the king under the treasury, and took thence old cast clouts and old rotten rags, and let them down by cords into the dungeon to Jeremiah.
19908	783	12	And Ebed-melech the Ethiopian said unto Jeremiah, Put now these old cast clouts and rotten rags under thine armholes under the cords. And Jeremiah did so.
19909	783	13	So they drew up Jeremiah with cords, and took him up out of the dungeon: and Jeremiah remained in the court of the prison.
19910	783	14	Then Zedekiah the king sent, and took Jeremiah the prophet unto him into the third entry that is in the house of the LORD: and the king said unto Jeremiah, I will ask thee a thing; hide nothing from me.
19911	783	15	Then Jeremiah said unto Zedekiah, If I declare it unto thee, wilt thou not surely put me to death? and if I give thee counsel, wilt thou not hearken unto me?
19912	783	16	So Zedekiah the king sware secretly unto Jeremiah, saying, As the LORD liveth, that made us this soul, I will not put thee to death, neither will I give thee into the hand of these men that seek thy life.
19913	783	17	Then said Jeremiah unto Zedekiah, Thus saith the LORD, the God of hosts, the God of Israel; If thou wilt assuredly go forth unto the king of Babylon's princes, then thy soul shall live, and this city shall not be burned with fire; and thou shalt live, and thine house:
19914	783	18	But if thou wilt not go forth to the king of Babylon's princes, then shall this city be given into the hand of the Chaldeans, and they shall burn it with fire, and thou shalt not escape out of their hand.
19915	783	19	And Zedekiah the king said unto Jeremiah, I am afraid of the Jews that are fallen to the Chaldeans, lest they deliver me into their hand, and they mock me.
19916	783	20	But Jeremiah said, They shall not deliver thee. Obey, I beseech thee, the voice of the LORD, which I speak unto thee: so it shall be well unto thee, and thy soul shall live.
19917	783	21	But if thou refuse to go forth, this is the word that the LORD hath shewed me:
19918	783	22	And, behold, all the women that are left in the king of Judah's house shall be brought forth to the king of Babylon's princes, and those women shall say, Thy friends have set thee on, and have prevailed against thee: thy feet are sunk in the mire, and they are turned away back.
19919	783	23	So they shall bring out all thy wives and thy children to the Chaldeans: and thou shalt not escape out of their hand, but shalt be taken by the hand of the king of Babylon: and thou shalt cause this city to be burned with fire.
19920	783	24	Then said Zedekiah unto Jeremiah, Let no man know of these words, and thou shalt not die.
19921	783	25	But if the princes hear that I have talked with thee, and they come unto thee, and say unto thee, Declare unto us now what thou hast said unto the king, hide it not from us, and we will not put thee to death; also what the king said unto thee:
19922	783	26	Then thou shalt say unto them, I presented my supplication before the king, that he would not cause me to return to Jonathan's house, to die there.
19923	783	27	Then came all the princes unto Jeremiah, and asked him: and he told them according to all these words that the king had commanded. So they left off speaking with him; for the matter was not perceived.
19924	783	28	So Jeremiah abode in the court of the prison until the day that Jerusalem was taken: and he was there when Jerusalem was taken.
19925	784	1	IN the ninth year of Zedekiah king of Judah, in the tenth month, came Nebuchadrezzar king of Babylon and all his army against Jerusalem, and they besieged it.
19926	784	2	And in the eleventh year of Zedekiah, in the fourth month, the ninth day of the month, the city was broken up.
19927	784	3	And all the princes of the king of Babylon came in, and sat in the middle gate, even Nergal-sharezer, Samgar-nebo, Sarsechim, Rab-saris, Nergal-sharezer, Rab-mag, with all the residue of the princes of the king of Babylon.
19928	784	4	And it came to pass, that when Zedekiah the king of Judah saw them, and all the men of war, then they fled, and went forth out of the city by night, by the way of the king's garden, by the gate betwixt the two walls: and he went out the way of the plain.
19929	784	5	But the Chaldeans' army pursued after them, and overtook Zedekiah in the plains of Jericho: and when they had taken him, they brought him up to Nebuchadnezzar king of Babylon to Riblah in the land of Hamath, where he gave judgment upon him.
19930	784	6	Then the king of Babylon slew the sons of Zedekiah in Riblah before his eyes: also the king of Babylon slew all the nobles of Judah.
19931	784	7	Moreover he put out Zedekiah's eyes, and bound him with chains, to carry him to Babylon.
19932	784	8	And the Chaldeans burned the king's house, and the houses of the people, with fire, and brake down the walls of Jerusalem.
19933	784	9	Then Nebuzar-adan the captain of the guard carried away captive into Babylon the remnant of the people that remained in the city, and those that fell away, that fell to him, with the rest of the people that remained.
19934	784	10	But Nebuzar-adan the captain of the guard left of the poor of the people, which had nothing, in the land of Judah, and gave them vineyards and fields at the same time.
19935	784	11	Now Nebuchadrezzar king of Babylon gave charge concerning Jeremiah to Nebuzar-adan the captain of the guard, saying,
19936	784	12	Take him, and look well to him, and do him no harm; but do unto him even as he shall say unto thee.
19937	784	13	So Nebuzar-adan the captain of the guard sent, and Nebushasban, Rab-saris, and Nergal-sharezer, Rab-mag, and all the king of Babylon's princes;
19938	784	14	Even they sent, and took Jeremiah out of the court of the prison, and committed him unto Gedaliah the son of Ahikam the son of Shaphan, that he should carry him home: so he dwelt among the people.
19939	784	15	Now the word of the LORD came unto Jeremiah, while he was shut up in the court of the prison, saying,
19940	784	16	Go and speak to Ebed-melech the Ethiopian, saying, Thus saith the LORD of hosts, the God of Israel; Behold, I will bring my words upon this city for evil, and not for good; and they shall be accomplished in that day before thee.
19941	784	17	But I will deliver thee in that day, saith the LORD: and thou shalt not be given into the hand of the men of whom thou art afraid.
19942	784	18	For I will surely deliver thee, and thou shalt not fall by the sword, but thy life shall be for a prey unto thee: because thou hast put thy trust in me, saith the LORD.
19943	785	1	THE word that came to Jeremiah from the LORD, after that Nebuzar-adan the captain of the guard had let him go from Ramah, when he had taken him being bound in chains among all that were carried away captive of Jerusalem and Judah, which were carried away captive unto Babylon.
19944	785	2	And the captain of the guard took Jeremiah, and said unto him, The LORD thy God hath pronounced this evil upon this place.
19945	785	3	Now the LORD hath brought it, and done according as he hath said: because ye have sinned against the LORD, and have not obeyed his voice, therefore this thing is come upon you.
19946	785	4	And now, behold, I loose thee this day from the chains which were upon thine hand. If it seem good unto thee to come with me into Babylon, come; and I will look well unto thee: but if it seem ill unto thee to come with me into Babylon, forbear: behold, all the land is before thee: whither it seemeth good and convenient for thee to go, thither go.
19947	785	5	Now while he was not yet gone back, he said, Go back also to Gedaliah the son of Ahikam the son of Shaphan, whom the king of Babylon hath made governor over the cities of Judah, and dwell with him among the people: or go wheresoever it seemeth convenient unto thee to go. So the captain of the guard gave him victuals and a reward, and let him go.
19948	785	6	Then went Jeremiah unto Gedaliah the son of Ahikam to Mizpah; and dwelt with him among the people that were left in the land.
19949	785	7	Now when all the captains of the forces which were in the fields, even they and their men, heard that the king of Babylon had made Gedaliah the son of Ahikam governor in the land, and had committed unto him men, and women, and children, and of the poor of the land, of them that were not carried away captive to Babylon;
19950	785	8	Then they came to Gedaliah to Mizpah, even Ishmael the son of Nethaniah, and Johanan and Jonathan the sons of Kareah, and Seraiah the son of Tanhumeth, and the sons of Ephai the Netophathite, and Jezaniah the son of a Maachathite, they and their men.
19951	785	9	And Gedaliah the son of Ahikam the son of Shaphan sware unto them and to their men, saying, Fear not to serve the Chaldeans: dwell in the land, and serve the king of Babylon, and it shall be well with you.
19952	785	10	As for me, behold, I will dwell at Mizpah to serve the Chaldeans, which will come unto us: but ye, gather ye wine, and summer fruits, and oil, and put them in your vessels, and dwell in your cities that ye have taken.
19953	785	11	Likewise when all the Jews that were in Moab, and among the Ammonites, and in Edom, and that were in all the countries, heard that the king of Babylon had left a remnant of Judah, and that he had set over them Gedaliah the son of Ahikam the son of Shaphan;
19954	785	12	Even all the Jews returned out of all places whither they were driven, and came to the land of Judah, to Gedaliah, unto Mizpah, and gathered wine and summer fruits very much.
19955	785	13	Moreover Johanan the son of Kareah, and all the captains of the forces that were in the fields, came to Gedaliah to Mizpah,
19956	785	14	And said unto him, Dost thou certainly know that Baalis the king of the Ammonites hath sent Ishmael the son of Nethaniah to slay thee? But Gedaliah the son of Ahikam believed them not.
19957	785	15	Then Johanan the son of Kareah spake to Gedaliah in Mizpah secretly, saying, Let me go, I pray thee, and I will slay Ishmael the son of Nethaniah, and no man shall know it: wherefore should he slay thee, that all the Jews which are gathered unto thee should be scattered, and the remnant in Judah perish?
19958	785	16	But Gedaliah the son of Ahikam said unto Johanan the son of Kareah, Thou shalt not do this thing: for thou speakest falsely of Ishmael.
19959	786	1	NOW it came to pass in the seventh month, that Ishmael the son of Nethaniah the son of Elishama, of the seed royal, and the princes of the king, even ten men with him, came unto Gedaliah the son of Ahikam to Mizpah; and there they did eat bread together in Mizpah.
19960	786	2	Then arose Ishmael the son of Nethaniah, and the ten men that were with him, and smote Gedaliah the son of Ahikam the son of Shaphan with the sword, and slew him, whom the king of Babylon had made governor over the land.
19961	786	3	Ishmael also slew all the Jews that were with him, even with Gedaliah, at Mizpah, and the Chaldeans that were found there, and the men of war.
19962	786	4	And it came to pass the second day after he had slain Gedaliah, and no man knew it,
19963	786	5	That there came certain from Shechem, from Shiloh, and from Samaria, even fourscore men, having their beards shaven, and their clothes rent, and having cut themselves, with offerings and incense in their hand, to bring them to the house of the LORD.
19964	786	6	And Ishmael the son of Nethaniah went forth from Mizpah to meet them, weeping all along as he went: and it came to pass, as he met them, he said unto them, Come to Gedaliah the son of Ahikam.
19965	786	7	And it was so, when they came into the midst of the city, that Ishmael the son of Nethaniah slew them, and cast them into the midst of the pit, he, and the men that were with him.
19966	786	8	But ten men were found among them that said unto Ishmael, Slay us not: for we have treasures in the field, of wheat, and of barley, and of oil, and of honey. So he forbare, and slew them not among their brethren.
19967	786	9	Now the pit wherein Ishmael had cast all the dead bodies of the men, whom he had slain because of Gedaliah, was it which Asa the king had made for fear of Baasha king of Israel: and Ishmael the son of Nethaniah filled it with them that were slain.
19968	786	10	Then Ishmael carried away captive all the residue of the people that were in Mizpah, even the king's daughters, and all the people that remained in Mizpah, whom Nebuzar-adan the captain of the guard had committed to Gedaliah the son of Ahikam: and Ishmael the son of Nethaniah carried them away captive, and departed to go over to the Ammonites.
19969	786	11	But when Johanan the son of Kareah, and all the captains of the forces that were with him, heard of all the evil that Ishmael the son of Nethaniah had done,
19970	786	12	Then they took all the men, and went to fight with Ishmael the son of Nethaniah, and found him by the great waters that are in Gibeon.
19971	786	13	Now it came to pass, that when all the people which were with Ishmael saw Johanan the son of Kareah, and all the captains of the forces that were with him, then they were glad.
19972	786	14	So all the people that Ishmael had carried away captive from Mizpah cast about and returned, and went unto Johanan the son of Kareah.
19973	786	15	But Ishmael the son of Nethaniah escaped from Johanan with eight men, and went to the Ammonites.
19974	786	16	Then took Johanan the son of Kareah, and all the captains of the forces that were with him, all the remnant of the people whom he had recovered from Ishmael the son of Nethaniah, from Mizpah, after that he had slain Gedaliah the son of Ahikam, even mighty men of war, and the women, and the children, and the eunuchs, whom he had brought again from Gibeon:
19975	786	17	And they departed, and dwelt in the habitation of Chimham, which is by Beth-lehem, to go to enter into Egypt,
19976	786	18	Because of the Chaldeans: for they were afraid of them, because Ishmael the son of Nethaniah had slain Gedaliah the son of Ahikam, whom the king of Babylon made governor in the land.
19977	787	1	THEN all the captains of the forces, and Johanan the son of Kareah, and Jezaniah the son of Hoshaiah, and all the people from the least even unto the greatest, came near,
19978	787	2	And said unto Jeremiah the prophet, Let, we beseech thee, our supplication be accepted before thee, and pray for us unto the LORD thy God, even for all this remnant; (for we are left but a few of many, as thine eyes do behold us:)
19979	787	3	That the LORD thy God may shew us the way wherein we may walk, and the thing that we may do.
19980	787	4	Then Jeremiah the prophet said unto them, I have heard you; behold, I will pray unto the LORD your God according to your words; and it shall come to pass, that whatsoever thing the LORD shall answer you, I will declare it unto you; I will keep nothing back from you.
19981	787	5	Then they said to Jeremiah, The LORD be a true and faithful witness between us, if we do not even according to all things for the which the LORD thy God shall send thee to us.
19982	787	6	Whether it be good, or whether it be evil, we will obey the voice of the LORD our God, to whom we send thee; that it may be well with us, when we obey the voice of the LORD our God.
19983	787	7	And it came to pass after ten days, that the word of the LORD came unto Jeremiah.
19984	787	8	Then called he Johanan the son of Kareah, and all the captains of the forces which were with him, and all the people from the least even to the greatest,
19985	787	9	And said unto them, Thus saith the LORD, the God of Israel, unto whom ye sent me to present your supplication before him;
19986	787	10	If ye will still abide in this land, then will I build you, and not pull you down, and I will plant you, and not pluck you up: for I repent me of the evil that I have done unto you.
19987	787	11	Be not afraid of the king of Babylon, of whom ye are afraid; be not afraid of him, saith the LORD: for I am with you to save you, and to deliver you from his hand.
19988	787	12	And I will shew mercies unto you, that he may have mercy upon you, and cause you to return to your own land.
19989	787	13	But if ye say, We will not dwell in this land, neither obey the voice of the LORD your God,
19990	787	14	Saying, No; but we will go into the land of Egypt, where we shall see no war, nor hear the sound of the trumpet, nor have hunger of bread; and there will we dwell:
19991	787	15	And now therefore hear the word of the LORD, ye remnant of Judah; Thus saith the LORD of hosts, the God of Israel; If ye wholly set your faces to enter into Egypt, and go to sojourn there;
19992	787	16	Then it shall come to pass, that the sword, which ye feared, shall overtake you there in the land of Egypt, and the famine, whereof ye were afraid, shall follow close after you there in Egypt; and there ye shall die.
19993	787	17	So shall it be with all the men that set their faces to go into Egypt to sojourn there; they shall die by the sword, by the famine, and by the pestilence: and none of them shall remain or escape from the evil that I will bring upon them.
19994	787	18	For thus saith the LORD of hosts, the God of Israel; As mine anger and my fury hath been poured forth upon the inhabitants of Jerusalem; so shall my fury be poured forth upon you, when ye shall enter into Egypt: and ye shall be an execration, and an astonishment, and a curse, and a reproach; and ye shall see this place no more.
19995	787	19	The LORD hath said concerning you, O ye remnant of Judah; Go ye not into Egypt: know certainly that I have admonished you this day.
19996	787	20	For ye dissembled in your hearts, when ye sent me unto the LORD your God, saying, Pray for us unto the LORD our God; and according unto all that the LORD our God shall say, so declare unto us, and we will do it.
19997	787	21	And now I have this day declared it to you; but ye have not obeyed the voice of the LORD your God, nor any thing for the which he hath sent me unto you.
19998	787	22	Now therefore know certainly that ye shall die by the sword, by the famine, and by the pestilence, in the place whither ye desire to go and to sojourn.
19999	788	1	AND it came to pass, that when Jeremiah had made an end of speaking unto all the people all the words of the LORD their God, for which the LORD their God had sent him to them, even all these words,
20000	788	2	Then spake Azariah the son of Hoshaiah, and Johanan the son of Kareah, and all the proud men, saying unto Jeremiah, Thou speakest falsely: the LORD our God hath not sent thee to say, Go not into Egypt to sojourn there:
20001	788	3	But Baruch the son of Neriah setteth thee on against us, for to deliver us into the hand of the Chaldeans, that they might put us to death, and carry us away captives into Babylon.
20002	788	4	So Johanan the son of Kareah, and all the captains of the forces, and all the people, obeyed not the voice of the LORD, to dwell in the land of Judah.
20003	788	5	But Johanan the son of Kareah, and all the captains of the forces, took all the remnant of Judah, that were returned from all nations, whither they had been driven, to dwell in the land of Judah;
20004	788	6	Even men, and women, and children, and the king's daughters, and every person that Nebuzar-adan the captain of the guard had left with Gedaliah the son of Ahikam the son of Shaphan, and Jeremiah the prophet, and Baruch the son of Neriah.
20005	788	7	So they came into the land of Egypt: for they obeyed not the voice of the LORD: thus came they even to Tahpanhes.
20006	788	8	Then came the word of the LORD unto Jeremiah in Tahpanhes, saying,
20007	788	9	Take great stones in thine hand, and hide them in the clay in the brickkiln, which is at the entry of Pharaoh's house in Tahpanhes, in the sight of the men of Judah;
20008	788	10	And say unto them, Thus saith the LORD of hosts, the God of Israel; Behold, I will send and take Nebuchadrezzar the king of Babylon, my servant, and will set his throne upon these stones that I have hid; and he shall spread his royal pavilion over them.
20009	788	11	And when he cometh, he shall smite the land of Egypt, and deliver such as are for death to death; and such as are for captivity to captivity; and such as are for the sword to the sword.
20010	788	12	And I will kindle a fire in the houses of the gods of Egypt; and he shall burn them, and carry them away captives: and he shall array himself with the land of Egypt, as a shepherd putteth on his garment; and he shall go forth from thence in peace.
20011	788	13	He shall break also the images of Beth-shemesh, that is in the land of Egypt; and the houses of the gods of the Egyptians shall he burn with fire.
20012	789	1	THE word that came to Jeremiah concerning all the Jews which dwell in the land of Egypt, which dwell at Migdol, and at Tahpanhes, and at Noph, and in the country of Pathros, saying,
20013	789	2	Thus saith the LORD of hosts, the God of Israel; Ye have seen all the evil that I have brought upon Jerusalem, and upon all the cities of Judah; and, behold, this day they are a desolation, and no man dwelleth therein,
20014	789	3	Because of their wickedness which they have committed to provoke me to anger, in that they went to burn incense, and to serve other gods, whom they knew not, neither they, ye, nor your fathers.
20015	789	4	Howbeit I sent unto you all my servants the prophets, rising early and sending them, saying, Oh, do not this abominable thing that I hate.
20016	789	5	But they hearkened not, nor inclined their ear to turn from their wickedness, to burn no incense unto other gods.
20017	789	6	Wherefore my fury and mine anger was poured forth, and was kindled in the cities of Judah and in the streets of Jerusalem; and they are wasted and desolate, as at this day.
20018	789	7	Therefore now thus saith the LORD, the God of hosts, the God of Israel; Wherefore commit ye this great evil against your souls, to cut off from you man and woman, child and suckling, out of Judah, to leave you none to remain;
20019	789	8	In that ye provoke me unto wrath with the works of your hands, burning incense unto other gods in the land of Egypt, whither ye be gone to dwell, that ye might cut yourselves off, and that ye might be a curse and a reproach among all the nations of the earth?
20020	789	9	Have ye forgotten the wickedness of your fathers, and the wickedness of the kings of Judah, and the wickedness of their wives, and your own wickedness, and the wickedness of your wives, which they have committed in the land of Judah, and in the streets of Jerusalem?
20021	789	10	They are not humbled even unto this day, neither have they feared, nor walked in my law, nor in my statutes, that I set before you and before your fathers.
20022	789	11	Therefore thus saith the LORD of hosts, the God of Israel; Behold, I will set my face against you for evil, and to cut off all Judah.
20023	789	12	And I will take the remnant of Judah, that have set their faces to go into the land of Egypt to sojourn there, and they shall all be consumed, and fall in the land of Egypt; they shall even be consumed by the sword and by the famine: they shall die, from the least even unto the greatest, by the sword and by the famine: and they shall be an execration, and an astonishment, and a curse, and a reproach.
20024	789	13	For I will punish them that dwell in the land of Egypt, as I have punished Jerusalem, by the sword, by the famine, and by the pestilence:
20025	789	14	So that none of the remnant of Judah, which are gone into the land of Egypt to sojourn there, shall escape or remain, that they should return into the land of Judah, to the which they have a desire to return to dwell there: for none shall return but such as shall escape.
20026	789	15	Then all the men which knew that their wives had burned incense unto other gods, and all the women that stood by, a great multitude, even all the people that dwelt in the land of Egypt, in Pathros, answered Jeremiah, saying,
20027	789	16	As for the word that thou hast spoken unto us in the name of the LORD, we will not hearken unto thee.
20028	789	17	But we will certainly do whatsoever thing goeth forth out of our own mouth, to burn incense unto the queen of heaven, and to pour out drink offerings unto her, as we have done, we, and our fathers, our kings, and our princes, in the cities of Judah, and in the streets of Jerusalem: for then had we plenty of victuals, and were well, and saw no evil.
20029	789	18	But since we left off to burn incense to the queen of heaven, and to pour out drink offerings unto her, we have wanted all things, and have been consumed by the sword and by the famine.
20030	789	19	And when we burned incense to the queen of heaven, and poured out drink offerings unto her, did we make her cakes to worship her, and pour out drink offerings unto her, without our men?
20031	789	20	Then Jeremiah said unto all the people, to the men, and to the women, and to all the people which had given him that answer, saying,
20032	789	21	The incense that ye burned in the cities of Judah, and in the streets of Jerusalem, ye, and your fathers, your kings, and your princes, and the people of the land, did not the LORD remember them, and came it not into his mind?
20033	789	22	So that the LORD could no longer bear, because of the evil of your doings, and because of the abominations which ye have committed; therefore is your land a desolation, and an astonishment, and a curse, without an inhabitant, as at this day.
20034	789	23	Because ye have burned incense, and because ye have sinned against the LORD, and have not obeyed the voice of the LORD, nor walked in his law, nor in his statutes, nor in his testimonies; therefore this evil is happened unto you, as at this day.
20035	789	24	Moreover Jeremiah said unto all the people, and to all the women, Hear the word of the LORD, all Judah that are in the land of Egypt:
20036	789	25	Thus saith the LORD of hosts, the God of Israel, saying; Ye and your wives have both spoken with your mouths, and fulfilled with your hand, saying, We will surely perform our vows that we have vowed, to burn incense to the queen of heaven, and to pour out drink offerings unto her: ye will surely accomplish your vows, and surely perform your vows.
20037	789	26	Therefore hear ye the word of the LORD, all Judah that dwell in the land of Egypt; Behold, I have sworn by my great name, saith the LORD, that my name shall no more be named in the mouth of any man of Judah in all the land of Egypt, saying, The Lord GOD liveth.
20038	789	27	Behold, I will watch over them for evil, and not for good: and all the men of Judah that are in the land of Egypt shall be consumed by the sword and by the famine, until there be an end of them.
20039	789	28	Yet a small number that escape the sword shall return out of the land of Egypt into the land of Judah, and all the remnant of Judah, that are gone into the land of Egypt to sojourn there, shall know whose words shall stand, mine, or theirs.
20040	789	29	And this shall be a sign unto you, saith the LORD, that I will punish you in this place, that ye may know that my words shall surely stand against you for evil:
20041	789	30	Thus saith the LORD; Behold, I will give Pharaoh-hophra king of Egypt into the hand of his enemies, and into the hand of them that seek his life; as I gave Zedekiah king of Judah into the hand of Nebuchadrezzar king of Babylon, his enemy, and that sought his life.
20042	790	1	THE word that Jeremiah the prophet spake unto Baruch the son of Neriah, when he had written these words in a book at the mouth of Jeremiah, in the fourth year of Jehoiakim the son of Josiah king of Judah, saying,
20043	790	2	Thus saith the LORD, the God of Israel, unto thee, O Baruch;
20044	790	3	Thou didst say, Woe is me now! for the LORD hath added grief to my sorrow; I fainted in my sighing, and I find no rest.
20045	790	4	Thus shalt thou say unto him, The LORD saith thus; Behold, that which I have built will I break down, and that which I have planted I will pluck up, even this whole land.
20046	790	5	And seekest thou great things for thyself? seek them not: for, behold, I will bring evil upon all flesh, saith the LORD: but thy life will I give unto thee for a prey in all places whither thou goest.
20047	791	1	THE word of the LORD which came to Jeremiah the prophet against the Gentiles;
20048	791	2	Against Egypt, against the army of Pharaoh-necho king of Egypt, which was by the river Euphrates in Carchemish, which Nebuchadrezzar king of Babylon smote in the fourth year of Jehoiakim the son of Josiah king of Judah.
20049	791	3	Order ye the buckler and shield, and draw near to battle.
20050	791	4	Harness the horses; and get up, ye horsemen, and stand forth with your helmets; furbish the spears, and put on the brigandines.
20051	791	5	Wherefore have I seen them dismayed and turned away back? and their mighty ones are beaten down, and are fled apace, and look not back: for fear was round about, saith the LORD.
20052	791	6	Let not the swift flee away, nor the mighty man escape; they shall stumble, and fall toward the north by the river Euphrates.
20053	791	7	Who is this that cometh up as a flood, whose waters are moved as the rivers?
20054	791	8	Egypt riseth up like a flood, and his waters are moved like the rivers; and he saith, I will go up, and will cover the earth; I will destroy the city and the inhabitants thereof.
20055	791	9	Come up, ye horses; and rage, ye chariots; and let the mighty men come forth; the Ethiopians and the Libyans, that handle the shield; and the Lydians, that handle and bend the bow.
20056	791	10	For this is the day of the Lord GOD of hosts, a day of vengeance, that he may avenge him of his adversaries: and the sword shall devour, and it shall be satiate and made drunk with their blood: for the Lord GOD of hosts hath a sacrifice in the north country by the river Euphrates.
20057	791	11	Go up into Gilead, and take balm, O virgin, the daughter of Egypt: in vain shalt thou use many medicines; for thou shalt not be cured.
20058	791	12	The nations have heard of thy shame, and thy cry hath filled the land: for the mighty man hath stumbled against the mighty, and they are fallen both together.
20059	791	13	The word that the LORD spake to Jeremiah the prophet, how Nebuchadrezzar king of Babylon should come and smite the land of Egypt.
20060	791	14	Declare ye in Egypt, and publish in Migdol, and publish in Noph and in Tahpanhes: say ye, Stand fast, and prepare thee; for the sword shall devour round about thee.
20061	791	15	Why are thy valiant men swept away? they stood not, because the LORD did drive them.
20062	791	16	He made many to fall, yea, one fell upon another: and they said, Arise, and let us go again to our own people, and to the land of our nativity, from the oppressing sword.
20063	791	17	They did cry there, Pharaoh king of Egypt is but a noise; he hath passed the time appointed.
20064	791	18	As I live, saith the King, whose name is the LORD of hosts, Surely as Tabor is among the mountains, and as Carmel by the sea, so shall he come.
20065	791	19	O thou daughter dwelling in Egypt, furnish thyself to go into captivity: for Noph shall be waste and desolate without an inhabitant.
20066	791	20	Egypt is like a very fair heifer, but destruction cometh; it cometh out of the north.
20067	791	21	Also her hired men are in the midst of her like fatted bullocks; for they also are turned back, and are fled away together: they did not stand, because the day of their calamity was come upon them, and the time of their visitation.
20068	791	22	The voice thereof shall go like a serpent; for they shall march with an army, and come against her with axes, as hewers of wood.
20069	791	23	They shall cut down her forest, saith the LORD, though it cannot be searched; because they are more than the grasshoppers, and are innumerable.
20070	791	24	The daughter of Egypt shall be confounded; she shall be delivered into the hand of the people of the north.
20071	791	25	The LORD of hosts, the God of Israel, saith; Behold, I will punish the multitude of No, and Pharaoh, and Egypt, with their gods, and their kings; even Pharaoh, and all them that trust in him:
20072	791	26	And I will deliver them into the hand of those that seek their lives, and into the hand of Nebuchadrezzar king of Babylon, and into the hand of his servants: and afterward it shall be inhabited, as in the days of old, saith the LORD.
20073	791	27	But fear not thou, O my servant Jacob, and be not dismayed, O Israel: for, behold, I will save thee from afar off, and thy seed from the land of their captivity; and Jacob shall return, and be in rest and at ease, and none shall make him afraid.
20074	791	28	Fear thou not, O Jacob my servant, saith the LORD: for I am with thee; for I will make a full end of all the nations whither I have driven thee: but I will not make a full end of thee, but correct thee in measure; yet will I not leave thee wholly unpunished.
20075	792	1	THE word of the LORD that came to Jeremiah the prophet against the Philistines, before that Pharaoh smote Gaza.
20076	792	2	Thus saith the LORD; Behold, waters rise up out of the north, and shall be an overflowing flood, and shall overflow the land, and all that is therein; the city, and them that dwell therein: then the men shall cry, and all the inhabitants of the land shall howl.
20077	792	3	At the noise of the stamping of the hoofs of his strong horses, at the rushing of his chariots, and at the rumbling of his wheels, the fathers shall not look back to their children for feebleness of hands;
20078	792	4	Because of the day that cometh to spoil all the Philistines, and to cut off from Tyrus and Zidon every helper that remaineth: for the LORD will spoil the Philistines, the remnant of the country of Caphtor.
20079	792	5	Baldness is come upon Gaza; Ashkelon is cut off with the remnant of their valley: how long wilt thou cut thyself?
20080	792	6	O thou sword of the LORD, how long will it be ere thou be quiet? put up thyself into thy scabbard, rest, and be still.
20081	792	7	How can it be quiet, seeing the LORD hath given it a charge against Ashkelon, and against the sea shore? there hath he appointed it.
20082	793	1	AGAINST Moab thus saith the LORD of hosts, the God of Israel; Woe unto Nebo! for it is spoiled: Kiriathaim is confounded and taken: Misgab is confounded and dismayed.
20083	793	2	There shall be no more praise of Moab: in Heshbon they have devised evil against it; come, and let us cut it off from being a nation. Also thou shalt be cut down, O Madmen; the sword shall pursue thee.
20084	793	3	A voice of crying shall be from Horonaim, spoiling and great destruction.
20085	793	4	Moab is destroyed; her little ones have caused a cry to be heard.
20086	793	5	For in the going up of Luhith continual weeping shall go up; for in the going down of Horonaim the enemies have heard a cry of destruction.
20087	793	6	Flee, save your lives, and be like the heath in the wilderness.
20088	793	7	For because thou hast trusted in thy works and in thy treasures, thou shalt also be taken: and Chemosh shall go forth into captivity with his priests and his princes together.
20089	793	8	And the spoiler shall come upon every city, and no city shall escape: the valley also shall perish, and the plain shall be destroyed, as the LORD hath spoken.
20090	793	9	Give wings unto Moab, that it may flee and get away: for the cities thereof shall be desolate, without any to dwell therein.
20091	793	10	Cursed be he that doeth the work of the LORD deceitfully, and cursed be he that keepeth back his sword from blood.
20092	793	11	Moab hath been at ease from his youth, and he hath settled on his lees, and hath not been emptied from vessel to vessel, neither hath he gone into captivity: therefore his taste remained in him, and his scent is not changed.
20093	793	12	Therefore, behold, the days come, saith the LORD, that I will send unto him wanderers, that shall cause him to wander, and shall empty his vessels, and break their bottles.
20094	793	13	And Moab shall be ashamed of Chemosh, as the house of Israel was ashamed of Beth-el their confidence.
20095	793	14	How say ye, We are mighty and strong men for the war?
20096	793	15	Moab is spoiled, and gone up out of her cities, and his chosen young men are gone down to the slaughter, saith the King, whose name is the LORD of hosts.
20097	793	16	The calamity of Moab is near to come, and his affliction hasteth fast.
20098	793	17	All ye that are about him, bemoan him; and all ye that know his name, say, How is the strong staff broken, and the beautiful rod!
20099	793	18	Thou daughter that dost inhabit Dibon, come down from thy glory, and sit in thirst; for the spoiler of Moab shall come upon thee, and he shall destroy thy strong holds.
20100	793	19	O inhabitant of Aroer, stand by the way, and espy; ask him that fleeth, and her that escapeth, and say, What is done?
20101	793	20	Moab is confounded; for it is broken down: howl and cry; tell ye it in Arnon, that Moab is spoiled,
20102	793	21	And judgment is come upon the plain country; upon Holon, and upon Jahazah, and upon Mephaath,
20103	793	22	And upon Dibon, and upon Nebo, and upon Beth-diblathaim,
20104	793	23	And upon Kiriathaim, and upon Beth-gamul, and upon Beth-meon,
20105	793	24	And upon Kerioth, and upon Bozrah, and upon all the cities of the land of Moab, far or near.
20106	793	25	The horn of Moab is cut off, and his arm is broken, saith the LORD.
20107	793	26	Make ye him drunken: for he magnified himself against the LORD: Moab also shall wallow in his vomit, and he also shall be in derision.
20108	793	27	For was not Israel a derision unto thee? was he found among thieves? for since thou spakest of him, thou skippedst for joy.
20109	793	28	O ye that dwell in Moab, leave the cities, and dwell in the rock, and be like the dove that maketh her nest in the sides of the hole's mouth.
20110	793	29	We have heard the pride of Moab, (he is exceeding proud) his loftiness, and his arrogancy, and his pride, and the haughtiness of his heart.
20111	793	30	I know his wrath, saith the LORD; but it shall not be so; his lies shall not so effect it.
20112	793	31	Therefore will I howl for Moab, and I will cry out for all Moab; mine heart shall mourn for the men of Kir-heres.
20113	793	32	O vine of Sibmah, I will weep for thee with the weeping of Jazer: thy plants are gone over the sea, they reach even to the sea of Jazer: the spoiler is fallen upon thy summer fruits and upon thy vintage.
20114	793	33	And joy and gladness is taken from the plentiful field, and from the land of Moab; and I have caused wine to fail from the winepresses: none shall tread with shouting; their shouting shall be no shouting.
20115	793	34	From the cry of Heshbon even unto Elealeh, and even unto Jahaz, have they uttered their voice, from Zoar even unto Horonaim, as an heifer of three years old: for the waters also of Nimrim shall be desolate.
20116	793	35	Moreover I will cause to cease in Moab, saith the LORD, him that offereth in the high places, and him that burneth incense to his gods.
20117	793	36	Therefore mine heart shall sound for Moab like pipes, and mine heart shall sound like pipes for the men of Kir-heres: because the riches that he hath gotten are perished.
20118	793	37	For every head shall be bald, and every beard clipped: upon all the hands shall be cuttings, and upon the loins sackcloth.
20119	793	38	There shall be lamentation generally upon all the housetops of Moab, and in the streets thereof: for I have broken Moab like a vessel wherein is no pleasure, saith the LORD.
20120	793	39	They shall howl, saying, How is it broken down! how hath Moab turned the back with shame! so shall Moab be a derision and a dismaying to all them about him.
20121	793	40	For thus saith the LORD; Behold, he shall fly as an eagle, and shall spread his wings over Moab.
20122	793	41	Kerioth is taken, and the strong holds are surprised, and the mighty men's hearts in Moab at that day shall be as the heart of a woman in her pangs.
20123	793	42	And Moab shall be destroyed from being a people, because he hath magnified himself against the LORD.
20124	793	43	Fear, and the pit, and the snare, shall be upon thee, O inhabitant of Moab, saith the LORD.
20125	793	44	He that fleeth from the fear shall fall into the pit; and he that getteth up out of the pit shall be taken in the snare: for I will bring upon it, even upon Moab, the year of their visitation, saith the LORD.
20126	793	45	They that fled stood under the shadow of Heshbon because of the force: but a fire shall come forth out of Heshbon, and a flame from the midst of Sihon, and shall devour the corner of Moab, and the crown of the head of the tumultuous ones.
20127	793	46	Woe be unto thee, O Moab! the people of Chemosh perisheth: for thy sons are taken captives, and thy daughters captives.
20128	793	47	Yet will I bring again the captivity of Moab in the latter days, saith the LORD. Thus far is the judgment of Moab.
20129	794	1	CONCERNING the Ammonites, thus saith the LORD; Hath Israel no sons? hath he no heir? why then doth their king inherit Gad, and his people dwell in his cities?
20130	794	2	Therefore, behold, the days come, saith the LORD, that I will cause an alarm of war to be heard in Rabbah of the Ammonites; and it shall be a desolate heap, and her daughters shall be burned with fire: then shall Israel be heir unto them that were his heirs, saith the LORD.
20131	794	3	Howl, O Heshbon, for Ai is spoiled: cry, ye daughters of Rabbah, gird you with sackcloth; lament, and run to and fro by the hedges; for their king shall go into captivity, and his priests and his princes together.
20132	794	4	Wherefore gloriest thou in the valleys, thy flowing valley, O backsliding daughter? that trusted in her treasures, saying, Who shall come unto me?
20133	794	5	Behold, I will bring a fear upon thee, saith the Lord GOD of hosts, from all those that be about thee; and ye shall be driven out every man right forth; and none shall gather up him that wandereth.
20134	794	6	And afterward I will bring again the captivity of the children of Ammon, saith the LORD.
20135	794	7	Concerning Edom, thus saith the LORD of hosts; Is wisdom no more in Teman? is counsel perished from the prudent? is their wisdom vanished?
20136	794	8	Flee ye, turn back, dwell deep, O inhabitants of Dedan; for I will bring the calamity of Esau upon him, the time that I will visit him.
20137	794	9	If grapegatherers come to thee, would they not leave some gleaning grapes? if thieves by night, they will destroy till they have enough.
20138	794	10	But I have made Esau bare, I have uncovered his secret places, and he shall not be able to hide himself: his seed is spoiled, and his brethren, and his neighbours, and he is not.
20139	794	11	Leave thy fatherless children, I will preserve them alive; and let thy widows trust in me.
20140	794	12	For thus saith the LORD; Behold, they whose judgment was not to drink of the cup have assuredly drunken; and art thou he that shall altogether go unpunished? thou shalt not go unpunished, but thou shalt surely drink of it.
20141	794	13	For I have sworn by myself, saith the LORD, that Bozrah shall become a desolation, a reproach, a waste, and a curse; and all the cities thereof shall be perpetual wastes;
20142	794	14	I have heard a rumour from the LORD, and an ambassador is sent unto the heathen, saying, Gather ye together, and come against her, and rise up to the battle.
20143	794	15	For, lo, I will make thee small among the heathen, and despised among men.
20144	794	16	Thy terribleness hath deceived thee, and the pride of thine heart, O thou that dwellest in the clefts of the rock, that holdest the height of the hill: though thou shouldest make thy nest as high as the eagle, I will bring thee down from thence, saith the LORD.
20145	794	17	Also Edom shall be a desolation: every one that goeth by it shall be astonished, and shall hiss at all the plagues thereof.
20146	794	18	As in the overthrow of Sodom and Gomorrah and the neighbour cities thereof, saith the LORD, no man shall abide there, neither shall a son of man dwell in it.
20147	794	19	Behold, he shall come up like a lion from the swelling of Jordan against the habitation of the strong: but I will suddenly make him run away from her: and who is a chosen man, that I may appoint over her? for who is like me? and who will appoint me the time? and who is that shepherd that will stand before me?
20148	794	20	Therefore hear the counsel of the LORD, that he hath taken against Edom; and his purposes, that he hath purposed against the inhabitants of Teman: Surely the least of the flock shall draw them out: surely he shall make their habitations desolate with them.
20149	794	21	The earth is moved at the noise of their fall, at the cry the noise thereof was heard in the Red sea.
20150	794	22	Behold, he shall come up and fly as the eagle, and spread his wings over Bozrah: and at that day shall the heart of the mighty men of Edom be as the heart of a woman in her pangs.
20151	794	23	Concerning Damascus. Hamath is confounded, and Arpad: for they have heard evil tidings: they are fainthearted; there is sorrow on the sea; it cannot be quiet.
20152	794	24	Damascus is waxed feeble, and turneth herself to flee, and fear hath seized on her: anguish and sorrows have taken her, as a woman in travail.
20153	794	25	How is the city of praise not left, the city of my joy!
20154	794	26	Therefore her young men shall fall in her streets, and all the men of war shall be cut off in that day, saith the LORD of hosts.
20155	794	27	And I will kindle a fire in the wall of Damascus, and it shall consume the palaces of Ben-hadad.
20156	794	28	Concerning Kedar, and concerning the kingdoms of Hazor, which Nebuchadrezzar king of Babylon shall smite, thus saith the LORD; Arise ye, go up to Kedar, and spoil the men of the east.
20157	794	29	Their tents and their flocks shall they take away: they shall take to themselves their curtains, and all their vessels, and their camels; and they shall cry unto them, Fear is on every side.
20158	794	30	Flee, get you far off, dwell deep, O ye inhabitants of Hazor, saith the LORD; for Nebuchadrezzar king of Babylon hath taken counsel against you, and hath conceived a purpose against you.
20159	794	31	Arise, get you up unto the wealthy nation, that dwelleth without care, saith the LORD, which have neither gates nor bars, which dwell alone.
20160	794	32	And their camels shall be a booty, and the multitude of their cattle a spoil: and I will scatter into all winds them that are in the utmost corners; and I will bring their calamity from all sides thereof, saith the LORD.
20161	794	33	And Hazor shall be a dwelling for dragons, and a desolation for ever: there shall no man abide there, nor any son of man dwell in it.
20162	794	34	The word of the LORD that came to Jeremiah the prophet against Elam in the beginning of the reign of Zedekiah king of Judah, saying,
20163	794	35	Thus saith the LORD of hosts; Behold, I will break the bow of Elam, the chief of their might.
20164	794	36	And upon Elam will I bring the four winds from the four quarters of heaven, and will scatter them toward all those winds; and there shall be no nation whither the outcasts of Elam shall not come.
20165	794	37	For I will cause Elam to be dismayed before their enemies, and before them that seek their life: and I will bring evil upon them, even my fierce anger, saith the LORD; and I will send the sword after them, till I have consumed them:
20166	794	38	And I will set my throne in Elam, and will destroy from thence the king and the princes, saith the LORD.
20167	794	39	But it shall come to pass in the latter days, that I will bring again the captivity of Elam, saith the LORD.
20168	795	1	THE word that the LORD spake against Babylon and against the land of the Chaldeans by Jeremiah the prophet.
20169	795	2	Declare ye among the nations, and publish, and set up a standard; publish, and conceal not: say, Babylon is taken, Bel is confounded, Merodach is broken in pieces; her idols are confounded, her images are broken in pieces.
20170	795	3	For out of the north there cometh up a nation against her, which shall make her land desolate, and none shall dwell therein: they shall remove, they shall depart, both man and beast.
20171	795	4	In those days, and in that time, saith the LORD, the children of Israel shall come, they and the children of Judah together, going and weeping: they shall go, and seek the LORD their God.
20172	795	5	They shall ask the way to Zion with their faces thitherward, saying, Come, and let us join ourselves to the LORD in a perpetual covenant that shall not be forgotten.
20173	795	6	My people hath been lost sheep: their shepherds have caused them to go astray, they have turned them away on the mountains: they have gone from mountain to hill, they have forgotten their restingplace.
20174	795	7	All that found them have devoured them: and their adversaries said, We offend not, because they have sinned against the LORD, the habitation of justice, even the LORD, the hope of their fathers.
20175	795	8	Remove out of the midst of Babylon, and go forth out of the land of the Chaldeans, and be as the he goats before the flocks.
20176	795	9	For, lo, I will raise and cause to come up against Babylon an assembly of great nations from the north country: and they shall set themselves in array against her; from thence she shall be taken: their arrows shall be as of a mighty expert man; none shall return in vain.
20177	795	10	And Chaldea shall be a spoil: all that spoil her shall be satisfied, saith the LORD.
20178	795	11	Because ye were glad, because ye rejoiced, O ye destroyers of mine heritage, because ye are grown fat as the heifer at grass, and bellow as bulls;
20179	795	12	Your mother shall be sore confounded; she that bare you shall be ashamed: behold, the hindermost of the nations shall be a wilderness, a dry land, and a desert.
20180	795	13	Because of the wrath of the LORD it shall not be inhabited, but it shall be wholly desolate: every one that goeth by Babylon shall be astonished, and hiss at all her plagues.
20181	795	14	Put yourselves in array against Babylon round about: all ye that bend the bow, shoot at her, spare no arrows: for she hath sinned against the LORD.
20182	795	15	Shout against her round about: she hath given her hand: her foundations are fallen, her walls are thrown down: for it is the vengeance of the LORD: take vengeance upon her; as she hath done, do unto her.
20183	795	16	Cut off the sower from Babylon, and him that handleth the sickle in the time of harvest: for fear of the oppressing sword they shall turn every one to his people, and they shall flee every one to his own land.
20184	795	17	Israel is a scattered sheep; the lions have driven him away: first the king of Assyria hath devoured him; and last this Nebuchadrezzar king of Babylon hath broken his bones.
20185	795	18	Therefore thus saith the LORD of hosts, the God of Israel; Behold, I will punish the king of Babylon and his land, as I have punished the king of Assyria.
20186	795	19	And I will bring Israel again to his habitation, and he shall feed on Carmel and Bashan, and his soul shall be satisfied upon mount Ephraim and Gilead.
20187	795	20	In those days, and in that time, saith the LORD, the iniquity of Israel shall be sought for, and there shall be none; and the sins of Judah, and they shall not be found: for I will pardon them whom I reserve.
20188	795	21	Go up against the land of Merathaim, even against it, and against the inhabitants of Pekod: waste and utterly destroy after them, saith the LORD, and do according to all that I have commanded thee.
20189	795	22	A sound of battle is in the land, and of great destruction.
20190	795	23	How is the hammer of the whole earth cut asunder and broken! how is Babylon become a desolation among the nations!
20191	795	24	I have laid a snare for thee, and thou art also taken, O Babylon, and thou wast not aware: thou art found, and also caught, because thou hast striven against the LORD.
20192	795	25	The LORD hath opened his armoury, and hath brought forth the weapons of his indignation: for this is the work of the Lord GOD of hosts in the land of the Chaldeans.
20193	795	26	Come against her from the utmost border, open her storehouses: cast her up as heaps, and destroy her utterly: let nothing of her be left.
20194	795	27	Slay all her bullocks; let them go down to the slaughter: woe unto them! for their day is come, the time of their visitation.
20195	795	28	The voice of them that flee and escape out of the land of Babylon, to declare in Zion the vengeance of the LORD our God, the vengeance of his temple.
20196	795	29	Call together the archers against Babylon: all ye that bend the bow, camp against it round about; let none thereof escape: recompense her according to her work; according to all that she hath done, do unto her: for she hath been proud against the LORD, against the Holy One of Israel.
20197	795	30	Therefore shall her young men fall in the streets, and all her men of war shall be cut off in that day, saith the LORD.
20198	795	31	Behold, I am against thee, O thou most proud, saith the Lord GOD of hosts: for thy day is come, the time that I will visit thee.
20199	795	32	And the most proud shall stumble and fall, and none shall raise him up: and I will kindle a fire in his cities, and it shall devour all round about him.
20200	795	33	Thus saith the LORD of hosts; The children of Israel and the children of Judah were oppressed together: and all that took them captives held them fast; they refused to let them go.
20201	795	34	Their Redeemer is strong; the LORD of hosts is his name: he shall throughly plead their cause, that he may give rest to the land, and disquiet the inhabitants of Babylon.
20202	795	35	A sword is upon the Chaldeans, saith the LORD, and upon the inhabitants of Babylon, and upon her princes, and upon her wise men.
20203	795	36	A sword is upon the liars; and they shall dote: a sword is upon her mighty men; and they shall be dismayed.
20204	795	37	A sword is upon their horses, and upon their chariots, and upon all the mingled people that are in the midst of her; and they shall become as women: a sword is upon her treasures; and they shall be robbed.
20205	795	38	A drought is upon her waters; and they shall be dried up: for it is the land of graven images, and they are mad upon their idols.
20206	795	39	Therefore the wild beasts of the desert with the wild beasts of the islands shall dwell there, and the owls shall dwell therein: and it shall be no more inhabited for ever; neither shall it be dwelt in from generation to generation.
20207	795	40	As God overthrew Sodom and Gomorrah and the neighbour cities thereof, saith the LORD; so shall no man abide there, neither shall any son of man dwell therein.
20208	795	41	Behold, a people shall come from the north, and a great nation, and many kings shall be raised up from the coasts of the earth.
20209	795	42	They shall hold the bow and the lance: they are cruel, and will not shew mercy: their voice shall roar like the sea, and they shall ride upon horses, every one put in array, like a man to the battle, against thee, O daughter of Babylon.
20210	795	43	The king of Babylon hath heard the report of them, and his hands waxed feeble: anguish took hold of him, and pangs as of a woman in travail.
20211	795	44	Behold, he shall come up like a lion from the swelling of Jordan unto the habitation of the strong: but I will make them suddenly run away from her: and who is a chosen man, that I may appoint over her? for who is like me? and who will appoint me the time? and who is that shepherd that will stand before me?
20212	795	45	Therefore hear ye the counsel of the LORD, that he hath taken against Babylon; and his purposes, that he hath purposed against the land of the Chaldeans: Surely the least of the flock shall draw them out: surely he shall make their habitation desolate with them.
20213	795	46	At the noise of the taking of Babylon the earth is moved, and the cry is heard among the nations.
20214	796	1	THUS saith the LORD; Behold, I will raise up against Babylon, and against them that dwell in the midst of them that rise up against me, a destroying wind;
20215	796	2	And will send unto Babylon fanners, that shall fan her, and shall empty her land: for in the day of trouble they shall be against her round about.
20216	796	3	Against him that bendeth let the archer bend his bow, and against him that lifteth himself up in his brigandine: and spare ye not her young men; destroy ye utterly all her host.
20217	796	4	Thus the slain shall fall in the land of the Chaldeans, and they that are thrust through in her streets.
20218	796	5	For Israel hath not been forsaken, nor Judah of his God, of the LORD of hosts; though their land was filled with sin against the Holy One of Israel.
20219	796	6	Flee out of the midst of Babylon, and deliver every man his soul: be not cut off in her iniquity; for this is the time of the LORD's vengeance; he will render unto her a recompence.
20220	796	7	Babylon hath been a golden cup in the LORD's hand, that made all the earth drunken: the nations have drunken of her wine; therefore the nations are mad.
20221	796	8	Babylon is suddenly fallen and destroyed: howl for her; take balm for her pain, if so be she may be healed.
20222	796	9	We would have healed Babylon, but she is not healed: forsake her, and let us go every one into his own country: for her judgment reacheth unto heaven, and is lifted up even to the skies.
20223	796	10	The LORD hath brought forth our righteousness: come, and let us declare in Zion the work of the LORD our God.
20224	796	11	Make bright the arrows; gather the shields: the LORD hath raised up the spirit of the kings of the Medes: for his device is against Babylon, to destroy it; because it is the vengeance of the LORD, the vengeance of his temple.
20225	796	12	Set up the standard upon the walls of Babylon, make the watch strong, set up the watchmen, prepare the ambushes: for the LORD hath both devised and done that which he spake against the inhabitants of Babylon.
20226	796	13	O thou that dwellest upon many waters, abundant in treasures, thine end is come, and the measure of thy covetousness.
20227	796	14	The LORD of hosts hath sworn by himself, saying, Surely I will fill thee with men, as with caterpillers; and they shall lift up a shout against thee.
20228	796	15	He hath made the earth by his power, he hath established the world by his wisdom, and hath stretched out the heaven by his understanding.
20229	796	16	When he uttereth his voice, there is a multitude of waters in the heavens; and he causeth the vapours to ascend from the ends of the earth: he maketh lightnings with rain, and bringeth forth the wind out of his treasures.
20230	796	17	Every man is brutish by his knowledge; every founder is confounded by the graven image: for his molten image is falsehood, and there is no breath in them.
20231	796	18	They are vanity, the work of errors: in the time of their visitation they shall perish.
20232	796	19	The portion of Jacob is not like them; for he is the former of all things: and Israel is the rod of his inheritance: the LORD of hosts is his name.
20233	796	20	Thou art my battle axe and weapons of war: for with thee will I break in pieces the nations, and with thee will I destroy kingdoms;
20234	796	21	And with thee will I break in pieces the horse and his rider; and with thee will I break in pieces the chariot and his rider;
20235	796	22	With thee also will I break in pieces man and woman; and with thee will I break in pieces old and young; and with thee will I break in pieces the young man and the maid;
20236	796	23	I will also break in pieces with thee the shepherd and his flock; and with thee will I break in pieces the husbandman and his yoke of oxen; and with thee will I break in pieces captains and rulers.
20237	796	24	And I will render unto Babylon and to all the inhabitants of Chaldea all their evil that they have done in Zion in your sight, saith the LORD.
20238	796	25	Behold, I am against thee, O destroying mountain, saith the LORD, which destroyest all the earth: and I will stretch out mine hand upon thee, and roll thee down from the rocks, and will make thee a burnt mountain.
20239	796	26	And they shall not take of thee a stone for a corner, nor a stone for foundations; but thou shalt be desolate for ever, saith the LORD.
20240	796	27	Set ye up a standard in the land, blow the trumpet among the nations, prepare the nations against her, call together against her the kingdoms of Ararat, Minni, and Ashchenaz; appoint a captain against her; cause the horses to come up as the rough caterpillers.
20241	796	28	Prepare against her the nations with the kings of the Medes, the captains thereof, and all the rulers thereof, and all the land of his dominion.
20242	796	29	And the land shall tremble and sorrow: for every purpose of the LORD shall be performed against Babylon, to make the land of Babylon a desolation without an inhabitant.
20243	796	30	The mighty men of Babylon have forborn to fight, they have remained in their holds: their might hath failed; they became as women: they have burned her dwellingplaces; her bars are broken.
20244	796	31	One post shall run to meet another, and one messenger to meet another, to shew the king of Babylon that his city is taken at one end,
20245	796	32	And that the passages are stopped, and the reeds they have burned with fire, and the men of war are affrighted.
20246	796	33	For thus saith the LORD of hosts, the God of Israel; The daughter of Babylon is like a threshingfloor, it is time to thresh her: yet a little while, and the time of her harvest shall come.
20247	796	34	Nebuchadrezzar the king of Babylon hath devoured me, he hath crushed me, he hath made me an empty vessel, he hath swallowed me up like a dragon, he hath filled his belly with my delicates, he hath cast me out.
20248	796	35	The violence done to me and to my flesh be upon Babylon, shall the inhabitant of Zion say; and my blood upon the inhabitants of Chaldea, shall Jerusalem say.
20249	796	36	Therefore thus saith the LORD; Behold, I will plead thy cause, and take vengeance for thee; and I will dry up her sea, and make her springs dry.
20250	796	37	And Babylon shall become heaps, a dwellingplace for dragons, an astonishment, and an hissing, without an inhabitant.
20251	796	38	They shall roar together like lions: they shall yell as lions' whelps.
20252	796	39	In their heat I will make their feasts, and I will make them drunken, that they may rejoice, and sleep a perpetual sleep, and not wake, saith the LORD.
20253	796	40	I will bring them down like lambs to the slaughter, like rams with he goats.
20254	796	41	How is Sheshach taken! and how is the praise of the whole earth surprised! how is Babylon become an astonishment among the nations!
20255	796	42	The sea is come up upon Babylon: she is covered with the multitude of the waves thereof.
20256	796	43	Her cities are a desolation, a dry land, and a wilderness, a land wherein no man dwelleth, neither doth any son of man pass thereby.
20257	796	44	And I will punish Bel in Babylon, and I will bring forth out of his mouth that which he hath swallowed up: and the nations shall not flow together any more unto him: yea, the wall of Babylon shall fall.
20258	796	45	My people, go ye out of the midst of her, and deliver ye every man his soul from the fierce anger of the LORD.
20259	796	46	And lest your heart faint, and ye fear for the rumour that shall be heard in the land; a rumour shall both come one year, and after that in another year shall come a rumour, and violence in the land, ruler against ruler.
20260	796	47	Therefore, behold, the days come, that I will do judgment upon the graven images of Babylon: and her whole land shall be confounded, and all her slain shall fall in the midst of her.
20261	796	48	Then the heaven and the earth, and all that is therein, shall sing for Babylon: for the spoilers shall come unto her from the north, saith the LORD.
20262	796	49	As Babylon hath caused the slain of Israel to fall, so at Babylon shall fall the slain of all the earth.
20263	796	50	Ye that have escaped the sword, go away, stand not still: remember the LORD afar off, and let Jerusalem come into your mind.
20264	796	51	We are confounded, because we have heard reproach: shame hath covered our faces: for strangers are come into the sanctuaries of the LORD's house.
20265	796	52	Wherefore, behold, the days come, saith the LORD, that I will do judgment upon her graven images: and through all her land the wounded shall groan.
20266	796	53	Though Babylon should mount up to heaven, and though she should fortify the height of her strength, yet from me shall spoilers come unto her, saith the LORD.
20267	796	54	A sound of a cry cometh from Babylon, and great destruction from the land of the Chaldeans:
20268	796	55	Because the LORD hath spoiled Babylon, and destroyed out of her the great voice; when her waves do roar like great waters, a noise of their voice is uttered:
20269	796	56	Because the spoiler is come upon her, even upon Babylon, and her mighty men are taken, every one of their bows is broken: for the LORD God of recompences shall surely requite.
20270	796	57	And I will make drunk her princes, and her wise men, her captains, and her rulers, and her mighty men: and they shall sleep a perpetual sleep, and not wake, saith the King, whose name is the LORD of hosts.
20271	796	58	Thus saith the LORD of hosts; The broad walls of Babylon shall be utterly broken, and her high gates shall be burned with fire; and the people shall labour in vain, and the folk in the fire, and they shall be weary.
20272	796	59	The word which Jeremiah the prophet commanded Seraiah the son of Neriah, the son of Maaseiah, when he went with Zedekiah the king of Judah into Babylon in the fourth year of his reign. And this Seraiah was a quiet prince.
20273	796	60	So Jeremiah wrote in a book all the evil that should come upon Babylon, even all these words that are written against Babylon.
20274	796	61	And Jeremiah said to Seraiah, When thou comest to Babylon, and shalt see, and shalt read all these words;
20275	796	62	Then shalt thou say, O LORD, thou hast spoken against this place, to cut it off, that none shall remain in it, neither man nor beast, but that it shall be desolate for ever.
20276	796	63	And it shall be, when thou hast made an end of reading this book, that thou shalt bind a stone to it, and cast it into the midst of Euphrates:
20277	796	64	And thou shalt say, Thus shall Babylon sink, and shall not rise from the evil that I will bring upon her: and they shall be weary. Thus far are the words of Jeremiah.
20278	797	1	ZEDEKIAH was one and twenty years old when he began to reign, and he reigned eleven years in Jerusalem. And his mother's name was Hamutal the daughter of Jeremiah of Libnah.
20279	797	2	And he did that which was evil in the eyes of the LORD, according to all that Jehoiakim had done.
20280	797	3	For through the anger of the LORD it came to pass in Jerusalem and Judah, till he had cast them out from his presence, that Zedekiah rebelled against the king of Babylon.
20281	797	4	And it came to pass in the ninth year of his reign, in the tenth month, in the tenth day of the month, that Nebuchadrezzar king of Babylon came, he and all his army, against Jerusalem, and pitched against it, and built forts against it round about.
20282	797	5	So the city was besieged unto the eleventh year of king Zedekiah.
20283	797	6	And in the fourth month, in the ninth day of the month, the famine was sore in the city, so that there was no bread for the people of the land.
20284	797	7	Then the city was broken up, and all the men of war fled, and went forth out of the city by night by the way of the gate between the two walls, which was by the king's garden; (now the Chaldeans were by the city round about:) and they went by the way of the plain.
20285	797	8	But the army of the Chaldeans pursued after the king, and overtook Zedekiah in the plains of Jericho; and all his army was scattered from him.
20286	797	9	Then they took the king, and carried him up unto the king of Babylon to Riblah in the land of Hamath; where he gave judgment upon him.
20287	797	10	And the king of Babylon slew the sons of Zedekiah before his eyes: he slew also all the princes of Judah in Riblah.
20288	797	11	Then he put out the eyes of Zedekiah; and the king of Babylon bound him in chains, and carried him to Babylon, and put him in prison till the day of his death.
20289	797	12	Now in the fifth month, in the tenth day of the month, which was the nineteenth year of Nebuchadrezzar king of Babylon, came Nebuzar-adan, captain of the guard, which served the king of Babylon, into Jerusalem,
20290	797	13	And burned the house of the LORD, and the king's house; and all the houses of Jerusalem, and all the houses of the great men, burned he with fire:
20291	797	14	And all the army of the Chaldeans, that were with the captain of the guard, brake down all the walls of Jerusalem round about.
20292	797	15	Then Nebuzar-adan the captain of the guard carried away captive certain of the poor of the people, and the residue of the people that remained in the city, and those that fell away, that fell to the king of Babylon, and the rest of the multitude.
20293	797	16	But Nebuzar-adan the captain of the guard left certain of the poor of the land for vinedressers and for husbandmen.
20294	797	17	Also the pillars of brass that were in the house of the LORD, and the bases, and the brasen sea that was in the house of the LORD, the Chaldeans brake, and carried all the brass of them to Babylon.
20295	797	18	The caldrons also, and the shovels, and the snuffers, and the bowls, and the spoons, and all the vessels of brass wherewith they ministered, took they away.
20296	797	19	And the basons, and the firepans, and the bowls, and the caldrons, and the candlesticks, and the spoons, and the cups; that which was of gold in gold, and that which was of silver in silver, took the captain of the guard away.
20297	797	20	The two pillars, one sea, and twelve brasen bulls that were under the bases, which king Solomon had made in the house of the LORD: the brass of all these vessels was without weight.
20298	797	21	And concerning the pillars, the height of one pillar was eighteen cubits; and a fillet of twelve cubits did compass it; and the thickness thereof was four fingers: it was hollow.
20299	797	22	And a chapiter of brass was upon it; and the height of one chapiter was five cubits, with network and pomegranates upon the chapiters round about, all of brass. The second pillar also and the pomegranates were like unto these.
20300	797	23	And there were ninety and six pomegranates on a side; and all the pomegranates upon the network were an hundred round about.
20301	797	24	And the captain of the guard took Seraiah the chief priest, and Zephaniah the second priest, and the three keepers of the door:
20302	797	25	He took also out of the city an eunuch, which had the charge of the men of war; and seven men of them that were near the king's person, which were found in the city; and the principal scribe of the host, who mustered the people of the land; and threescore men of the people of the land, that were found in the midst of the city.
20303	797	26	So Nebuzar-adan the captain of the guard took them, and brought them to the king of Babylon to Riblah.
20304	797	27	And the king of Babylon smote them, and put them to death in Riblah in the land of Hamath. Thus Judah was carried away captive out of his own land.
20305	797	28	This is the people whom Nebuchadrezzar carried away captive: in the seventh year three thousand Jews and three and twenty:
20306	797	29	In the eighteenth year of Nebuchadrezzar he carried away captive from Jerusalem eight hundred thirty and two persons:
20307	797	30	In the three and twentieth year of Nebuchadrezzar Nebuzar-adan the captain of the guard carried away captive of the Jews seven hundred forty and five persons: all the persons were four thousand and six hundred.
20308	797	31	And it came to pass in the seven and thirtieth year of the captivity of Jehoiachin king of Judah, in the twelfth month, in the five and twentieth day of the month, that Evil-merodach king of Babylon in the first year of his reign lifted up the head of Jehoiachin king of Judah, and brought him forth out of prison,
20309	797	32	And spake kindly unto him, and set his throne above the throne of the kings that were with him in Babylon,
20310	797	33	And changed his prison garments: and he did continually eat bread before him all the days of his life.
20311	797	34	And for his diet, there was a continual diet given him of the king of Babylon, every day a portion until the day of his death, all the days of his life.
20312	798	1	HOW doth the city sit solitary, that was full of people! how is she become as a widow! she that was great among the nations, and princess among the provinces, how is she become tributary!
20313	798	2	She weepeth sore in the night, and her tears are on her cheeks: among all her lovers she hath none to comfort her: all her friends have dealt treacherously with her, they are become her enemies.
20314	798	3	Judah is gone into captivity because of affliction, and because of great servitude: she dwelleth among the heathen, she findeth no rest: all her persecutors overtook her between the straits.
20315	798	4	The ways of Zion do mourn, because none come to the solemn feasts: all her gates are desolate: her priests sigh, her virgins are afflicted, and she is in bitterness.
20316	798	5	Her adversaries are the chief, her enemies prosper; for the LORD hath afflicted her for the multitude of her transgressions: her children are gone into captivity before the enemy.
20317	798	6	And from the daughter of Zion all her beauty is departed: her princes are become like harts that find no pasture, and they are gone without strength before the pursuer.
20318	798	7	Jerusalem remembered in the days of her affliction and of her miseries all her pleasant things that she had in the days of old, when her people fell into the hand of the enemy, and none did help her: the adversaries saw her, and did mock at her sabbaths.
20319	798	8	Jerusalem hath grievously sinned; therefore she is removed: all that honoured her despise her, because they have seen her nakedness: yea, she sigheth, and turneth backward.
20320	798	9	Her filthiness is in her skirts; she remembereth not her last end; therefore she came down wonderfully: she had no comforter. O LORD, behold my affliction: for the enemy hath magnified himself.
20321	798	10	The adversary hath spread out his hand upon all her pleasant things: for she hath seen that the heathen entered into her sanctuary, whom thou didst command that they should not enter into thy congregation.
20322	798	11	All her people sigh, they seek bread; they have given their pleasant things for meat to relieve the soul: see, O LORD, and consider; for I am become vile.
20323	798	12	Is it nothing to you, all ye that pass by? behold, and see if there be any sorrow like unto my sorrow, which is done unto me, wherewith the LORD hath afflicted me in the day of his fierce anger.
20324	798	13	From above hath he sent fire into my bones, and it prevaileth against them: he hath spread a net for my feet, he hath turned me back: he hath made me desolate and faint all the day.
20325	798	14	The yoke of my transgressions is bound by his hand: they are wreathed, and come up upon my neck: he hath made my strength to fall, the Lord hath delivered me into their hands, from whom I am not able to rise up.
20326	798	15	The Lord hath trodden under foot all my mighty men in the midst of me: he hath called an assembly against me to crush my young men: the Lord hath trodden the virgin, the daughter of Judah, as in a winepress.
20327	798	16	For these things I weep; mine eye, mine eye runneth down with water, because the comforter that should relieve my soul is far from me: my children are desolate, because the enemy prevailed.
20328	798	17	Zion spreadeth forth her hands, and there is none to comfort her: the LORD hath commanded concerning Jacob, that his adversaries should be round about him: Jerusalem is as a menstruous woman among them.
20329	798	18	The LORD is righteous; for I have rebelled against his commandment: hear, I pray you, all people, and behold my sorrow: my virgins and my young men are gone into captivity.
20330	798	19	I called for my lovers, but they deceived me: my priests and mine elders gave up the ghost in the city, while they sought their meat to relieve their souls.
20331	798	20	Behold, O LORD; for I am in distress: my bowels are troubled; mine heart is turned within me; for I have grievously rebelled: abroad the sword bereaveth, at home there is as death.
20332	798	21	They have heard that I sigh: there is none to comfort me: all mine enemies have heard of my trouble; they are glad that thou hast done it: thou wilt bring the day that thou hast called, and they shall be like unto me.
20333	798	22	Let all their wickedness come before thee; and do unto them, as thou hast done unto me for all my transgressions: for my sighs are many, and my heart is faint.
20334	799	1	HOW hath the Lord covered the daughter of Zion with a cloud in his anger, and cast down from heaven unto the earth the beauty of Israel, and remembered not his footstool in the day of his anger!
20335	799	2	The Lord hath swallowed up all the habitations of Jacob, and hath not pitied: he hath thrown down in his wrath the strong holds of the daughter of Judah; he hath brought them down to the ground: he hath polluted the kingdom and the princes thereof.
20336	799	3	He hath cut off in his fierce anger all the horn of Israel: he hath drawn back his right hand from before the enemy, and he burned against Jacob like a flaming fire, which devoureth round about.
20337	799	4	He hath bent his bow like an enemy: he stood with his right hand as an adversary, and slew all that were pleasant to the eye in the tabernacle of the daughter of Zion: he poured out his fury like fire.
20338	799	5	The Lord was as an enemy: he hath swallowed up Israel, he hath swallowed up all her palaces: he hath destroyed his strong holds, and hath increased in the daughter of Judah mourning and lamentation.
20339	799	6	And he hath violently taken away his tabernacle, as if it were of a garden: he hath destroyed his places of the assembly: the LORD hath caused the solemn feasts and sabbaths to be forgotten in Zion, and hath despised in the indignation of his anger the king and the priest.
20340	799	7	The Lord hath cast off his altar, he hath abhorred his sanctuary, he hath given up into the hand of the enemy the walls of her palaces; they have made a noise in the house of the LORD, as in the day of a solemn feast.
20341	799	8	The LORD hath purposed to destroy the wall of the daughter of Zion: he hath stretched out a line, he hath not withdrawn his hand from destroying: therefore he made the rampart and the wall to lament; they languished together.
20342	799	9	Her gates are sunk into the ground; he hath destroyed and broken her bars: her king and her princes are among the Gentiles: the law is no more; her prophets also find no vision from the LORD.
20343	799	10	The elders of the daughter of Zion sit upon the ground, and keep silence: they have cast up dust upon their heads; they have girded themselves with sackcloth: the virgins of Jerusalem hang down their heads to the ground.
20344	799	11	Mine eyes do fail with tears, my bowels are troubled, my liver is poured upon the earth, for the destruction of the daughter of my people; because the children and the sucklings swoon in the streets of the city.
20345	799	12	They say to their mothers, Where is corn and wine? when they swooned as the wounded in the streets of the city, when their soul was poured out into their mothers' bosom.
20346	799	13	What thing shall I take to witness for thee? what thing shall I liken to thee, O daughter of Jerusalem? what shall I equal to thee, that I may comfort thee, O virgin daughter of Zion? for thy breach is great like the sea: who can heal thee?
20347	799	14	Thy prophets have seen vain and foolish things for thee: and they have not discovered thine iniquity, to turn away thy captivity; but have seen for thee false burdens and causes of banishment.
20348	799	15	All that pass by clap their hands at thee; they hiss and wag their head at the daughter of Jerusalem, saying, Is this the city that men call The perfection of beauty, The joy of the whole earth?
20349	799	16	All thine enemies have opened their mouth against thee: they hiss and gnash the teeth: they say, We have swallowed her up: certainly this is the day that we looked for; we have found, we have seen it.
20350	799	17	The LORD hath done that which he had devised; he hath fulfilled his word that he had commanded in the days of old: he hath thrown down, and hath not pitied: and he hath caused thine enemy to rejoice over thee, he hath set up the horn of thine adversaries.
20351	799	18	Their heart cried unto the Lord, O wall of the daughter of Zion, let tears run down like a river day and night: give thyself no rest; let not the apple of thine eye cease.
20352	799	19	Arise, cry out in the night: in the beginning of the watches pour out thine heart like water before the face of the Lord: lift up thy hands toward him for the life of thy young children, that faint for hunger in the top of every street.
20353	799	20	Behold, O LORD, and consider to whom thou hast done this. Shall the women eat their fruit, and children of a span long? shall the priest and the prophet be slain in the sanctuary of the Lord?
20354	799	21	The young and the old lie on the ground in the streets: my virgins and my young men are fallen by the sword; thou hast slain them in the day of thine anger; thou hast killed, and not pitied.
20355	799	22	Thou hast called as in a solemn day my terrors round about, so that in the day of the LORD's anger none escaped nor remained: those that I have swaddled and brought up hath mine enemy consumed.
20356	800	1	I AM the man that hath seen affliction by the rod of his wrath.
20357	800	2	He hath led me, and brought me into darkness, but not into light.
20358	800	3	Surely against me is he turned; he turneth his hand against me all the day.
20359	800	4	My flesh and my skin hath he made old; he hath broken my bones.
20360	800	5	He hath builded against me, and compassed me with gall and travail.
20361	800	6	He hath set me in dark places, as they that be dead of old.
20362	800	7	He hath hedged me about, that I cannot get out: he hath made my chain heavy.
20363	800	8	Also when I cry and shout, he shutteth out my prayer.
20364	800	9	He hath inclosed my ways with hewn stone, he hath made my paths crooked.
20365	800	10	He was unto me as a bear lying in wait, and as a lion in secret places.
20366	800	11	He hath turned aside my ways, and pulled me in pieces: he hath made me desolate.
20367	800	12	He hath bent his bow, and set me as a mark for the arrow.
20368	800	13	He hath caused the arrows of his quiver to enter into my reins.
20369	800	14	I was a derision to all my people; and their song all the day.
20370	800	15	He hath filled me with bitterness, he hath made me drunken with wormwood.
20371	800	16	He hath also broken my teeth with gravel stones, he hath covered me with ashes.
20372	800	17	And thou hast removed my soul far off from peace: I forgat prosperity.
20373	800	18	And I said, My strength and my hope is perished from the LORD:
20374	800	19	Remembering mine affliction and my misery, the wormwood and the gall.
20375	800	20	My soul hath them still in remembrance, and is humbled in me.
20376	800	21	This I recall to my mind, therefore have I hope.
20377	800	22	It is of the LORD's mercies that we are not consumed, because his compassions fail not.
20378	800	23	They are new every morning: great is thy faithfulness.
20379	800	24	The LORD is my portion, saith my soul; therefore will I hope in him.
20380	800	25	The LORD is good unto them that wait for him, to the soul that seeketh him.
20381	800	26	It is good that a man should both hope and quietly wait for the salvation of the LORD.
20382	800	27	It is good for a man that he bear the yoke in his youth.
20383	800	28	He sitteth alone and keepeth silence, because he hath borne it upon him.
20384	800	29	He putteth his mouth in the dust; if so be there may be hope.
20385	800	30	He giveth his cheek to him that smiteth him: he is filled full with reproach.
20386	800	31	For the Lord will not cast off for ever:
20387	800	32	But though he cause grief, yet will he have compassion according to the multitude of his mercies.
20388	800	33	For he doth not afflict willingly nor grieve the children of men.
20389	800	34	To crush under his feet all the prisoners of the earth,
20390	800	35	To turn aside the right of a man before the face of the most High,
20391	800	36	To subvert a man in his cause, the Lord approveth not.
20392	800	37	Who is he that saith, and it cometh to pass, when the Lord commandeth it not?
20393	800	38	Out of the mouth of the most High proceedeth not evil and good?
20394	800	39	Wherefore doth a living man complain, a man for the punishment of his sins?
20395	800	40	Let us search and try our ways, and turn again to the LORD.
20396	800	41	Let us lift up our heart with our hands unto God in the heavens.
20397	800	42	We have transgressed and have rebelled: thou hast not pardoned.
20398	800	43	Thou hast covered with anger, and persecuted us: thou hast slain, thou hast not pitied.
20399	800	44	Thou hast covered thyself with a cloud, that our prayer should not pass through.
20400	800	45	Thou hast made us as the offscouring and refuse in the midst of the people.
20401	800	46	All our enemies have opened their mouths against us.
20402	800	47	Fear and a snare is come upon us, desolation and destruction.
20403	800	48	Mine eye runneth down with rivers of water for the destruction of the daughter of my people.
20404	800	49	Mine eye trickleth down, and ceaseth not, without any intermission,
20405	800	50	Till the LORD look down, and behold from heaven.
20406	800	51	Mine eye affecteth mine heart because of all the daughters of my city.
20407	800	52	Mine enemies chased me sore, like a bird, without cause.
20408	800	53	They have cut off my life in the dungeon, and cast a stone upon me.
20409	800	54	Waters flowed over mine head; then I said, I am cut off.
20410	800	55	I called upon thy name, O LORD, out of the low dungeon.
20411	800	56	Thou hast heard my voice: hide not thine ear at my breathing, at my cry.
20412	800	57	Thou drewest near in the day that I called upon thee: thou saidst, Fear not.
20413	800	58	O Lord, thou hast pleaded the causes of my soul; thou hast redeemed my life.
20414	800	59	O LORD, thou hast seen my wrong: judge thou my cause.
20415	800	60	Thou hast seen all their vengeance and all their imaginations against me.
20416	800	61	Thou hast heard their reproach, O LORD, and all their imaginations against me;
20417	800	62	The lips of those that rose up against me, and their device against me all the day.
20418	800	63	Behold their sitting down, and their rising up; I am their musick.
20419	800	64	Render unto them a recompence, O LORD, according to the work of their hands.
20420	800	65	Give them sorrow of heart, thy curse unto them.
20421	800	66	Persecute and destroy them in anger from under the heavens of the LORD.
20422	801	1	HOW is the gold become dim! how is the most fine gold changed! the stones of the sanctuary are poured out in the top of every street.
20423	801	2	The precious sons of Zion, comparable to fine gold, how are they esteemed as earthen pitchers, the work of the hands of the potter!
20424	801	3	Even the sea monsters draw out the breast, they give suck to their young ones: the daughter of my people is become cruel, like the ostriches in the wilderness.
20425	801	4	The tongue of the sucking child cleaveth to the roof of his mouth for thirst: the young children ask bread, and no man breaketh it unto them.
20426	801	5	They that did feed delicately are desolate in the streets: they that were brought up in scarlet embrace dunghills.
20427	801	6	For the punishment of the iniquity of the daughter of my people is greater than the punishment of the sin of Sodom, that was overthrown as in a moment, and no hands stayed on her.
20428	801	7	Her Nazarites were purer than snow, they were whiter than milk, they were more ruddy in body than rubies, their polishing was of sapphire:
20429	801	8	Their visage is blacker than a coal; they are not known in the streets: their skin cleaveth to their bones; it is withered, it is become like a stick.
20430	801	9	They that be slain with the sword are better than they that be slain with hunger: for these pine away, stricken through for want of the fruits of the field.
20431	801	10	The hands of the pitiful women have sodden their own children: they were their meat in the destruction of the daughter of my people.
20432	801	11	The LORD hath accomplished his fury; he hath poured out his fierce anger, and hath kindled a fire in Zion, and it hath devoured the foundations thereof.
20433	801	12	The kings of the earth, and all the inhabitants of the world, would not have believed that the adversary and the enemy should have entered into the gates of Jerusalem.
20434	801	13	For the sins of her prophets, and the iniquities of her priests, that have shed the blood of the just in the midst of her,
20435	801	14	They have wandered as blind men in the streets, they have polluted themselves with blood, so that men could not touch their garments.
20436	801	15	They cried unto them, Depart ye; it is unclean; depart, depart, touch not: when they fled away and wandered, they said among the heathen, They shall no more sojourn there.
20437	801	16	The anger of the LORD hath divided them; he will no more regard them: they respected not the persons of the priests, they favoured not the elders.
20438	801	17	As for us, our eyes as yet failed for our vain help: in our watching we have watched for a nation that could not save us.
20439	801	18	They hunt our steps, that we cannot go in our streets: our end is near, our days are fulfilled; for our end is come.
20440	801	19	Our persecutors are swifter than the eagles of the heaven: they pursued us upon the mountains, they laid wait for us in the wilderness.
20441	801	20	The breath of our nostrils, the anointed of the LORD, was taken in their pits, of whom we said, Under his shadow we shall live among the heathen.
20442	801	21	Rejoice and be glad, O daughter of Edom, that dwellest in the land of Uz; the cup also shall pass through unto thee: thou shalt be drunken, and shalt make thyself naked.
20443	801	22	The punishment of thine iniquity is accomplished, O daughter of Zion; he will no more carry thee away into captivity: he will visit thine iniquity, O daughter of Edom; he will discover thy sins.
20444	802	1	REMEMBER, O LORD, what is come upon us: consider, and behold our reproach.
20445	802	2	Our inheritance is turned to strangers, our houses to aliens.
20446	802	3	We are orphans and fatherless, our mothers are as widows.
20447	802	4	We have drunken our water for money; our wood is sold unto us.
20448	802	5	Our necks are under persecution: we labour, and have no rest.
20449	802	6	We have given the hand to the Egyptians, and to the Assyrians, to be satisfied with bread.
20450	802	7	Our fathers have sinned, and are not; and we have borne their iniquities.
20451	802	8	Servants have ruled over us: there is none that doth deliver us out of their hand.
20452	802	9	We gat our bread with the peril of our lives because of the sword of the wilderness.
20453	802	10	Our skin was black like an oven because of the terrible famine.
20454	802	11	They ravished the women in Zion, and the maids in the cities of Judah.
20455	802	12	Princes are hanged up by their hand: the faces of elders were not honoured.
20456	802	13	They took the young men to grind, and the children fell under the wood.
20457	802	14	The elders have ceased from the gate, the young men from their musick.
20458	802	15	The joy of our heart is ceased; our dance is turned into mourning.
20459	802	16	The crown is fallen from our head: woe unto us, that we have sinned!
20460	802	17	For this our heart is faint; for these things our eyes are dim.
20461	802	18	Because of the mountain of Zion, which is desolate, the foxes walk upon it.
20462	802	19	Thou, O LORD, remainest for ever; thy throne from generation to generation.
20463	802	20	Wherefore dost thou forget us for ever, and forsake us so long time?
20464	802	21	Turn thou us unto thee, O LORD, and we shall be turned; renew our days as of old.
20465	802	22	But thou hast utterly rejected us; thou art very wroth against us.
20466	803	1	NOW it came to pass in the thirtieth year, in the fourth month, in the fifth day of the month, as I was among the captives by the river of Chebar, that the heavens were opened, and I saw visions of God.
20467	803	2	In the fifth day of the month, which was the fifth year of king Jehoiachin's captivity,
20468	803	3	The word of the LORD came expressly unto Ezekiel the priest, the son of Buzi, in the land of the Chaldeans by the river Chebar; and the hand of the LORD was there upon him.
20469	803	4	And I looked, and, behold, a whirlwind came out of the north, a great cloud, and a fire infolding itself, and a brightness was about it, and out of the midst thereof as the colour of amber, out of the midst of the fire.
20470	803	5	Also out of the midst thereof came the likeness of four living creatures. And this was their appearance; they had the likeness of a man.
20471	803	6	And every one had four faces, and every one had four wings.
20472	803	7	And their feet were straight feet; and the sole of their feet was like the sole of a calf's foot: and they sparkled like the colour of burnished brass.
20473	803	8	And they had the hands of a man under their wings on their four sides; and they four had their faces and their wings.
20474	803	9	Their wings were joined one to another; they turned not when they went; they went every one straight forward.
20475	803	10	As for the likeness of their faces, they four had the face of a man, and the face of a lion, on the right side: and they four had the face of an ox on the left side; they four also had the face of an eagle.
20476	803	11	Thus were their faces: and their wings were stretched upward; two wings of every one were joined one to another, and two covered their bodies.
20477	803	12	And they went every one straight forward: whither the spirit was to go, they went; and they turned not when they went.
20478	803	13	As for the likeness of the living creatures, their appearance was like burning coals of fire, and like the appearance of lamps: it went up and down among the living creatures; and the fire was bright, and out of the fire went forth lightning.
20479	803	14	And the living creatures ran and returned as the appearance of a flash of lightning.
20480	803	15	Now as I beheld the living creatures, behold one wheel upon the earth by the living creatures, with his four faces.
20481	803	16	The appearance of the wheels and their work was like unto the colour of a beryl: and they four had one likeness: and their appearance and their work was as it were a wheel in the middle of a wheel.
20482	803	17	When they went, they went upon their four sides: and they turned not when they went.
20483	803	18	As for their rings, they were so high that they were dreadful; and their rings were full of eyes round about them four.
20484	803	19	And when the living creatures went, the wheels went by them: and when the living creatures were lifted up from the earth, the wheels were lifted up.
20485	803	20	Whithersoever the spirit was to go, they went, thither was their spirit to go; and the wheels were lifted up over against them: for the spirit of the living creature was in the wheels.
20486	803	21	When those went, these went; and when those stood, these stood; and when those were lifted up from the earth, the wheels were lifted up over against them: for the spirit of the living creature was in the wheels.
20487	803	22	And the likeness of the firmament upon the heads of the living creature was as the colour of the terrible crystal, stretched forth over their heads above.
20488	803	23	And under the firmament were their wings straight, the one toward the other: every one had two, which covered on this side, and every one had two, which covered on that side, their bodies.
20489	803	24	And when they went, I heard the noise of their wings, like the noise of great waters, as the voice of the Almighty, the voice of speech, as the noise of an host: when they stood, they let down their wings.
20490	803	25	And there was a voice from the firmament that was over their heads, when they stood, and had let down their wings.
20491	803	26	And above the firmament that was over their heads was the likeness of a throne, as the appearance of a sapphire stone: and upon the likeness of the throne was the likeness as the appearance of a man above upon it.
20492	803	27	And I saw as the colour of amber, as the appearance of fire round about within it, from the appearance of his loins even upward, and from the appearance of his loins even downward, I saw as it were the appearance of fire, and it had brightness round about.
20493	803	28	As the appearance of the bow that is in the cloud in the day of rain, so was the appearance of the brightness round about. This was the appearance of the likeness of the glory of the LORD. And when I saw it, I fell upon my face, and I heard a voice of one that spake.
20494	804	1	AND he said unto me, Son of man, stand upon thy feet, and I will speak unto thee.
20495	804	2	And the spirit entered into me when he spake unto me, and set me upon my feet, that I heard him that spake unto me.
20496	804	3	And he said unto me, Son of man, I send thee to the children of Israel, to a rebellious nation that hath rebelled against me: they and their fathers have transgressed against me, even unto this very day.
20497	804	4	For they are impudent children and stiffhearted. I do send thee unto them; and thou shalt say unto them, Thus saith the Lord GOD.
20498	804	5	And they, whether they will hear, or whether they will forbear, (for they are a rebellious house,) yet shall know that there hath been a prophet among them.
20499	804	6	And thou, son of man, be not afraid of them, neither be afraid of their words, though briers and thorns be with thee, and thou dost dwell among scorpions: be not afraid of their words, nor be dismayed at their looks, though they be a rebellious house.
20500	804	7	And thou shalt speak my words unto them, whether they will hear, or whether they will forbear: for they are most rebellious.
20501	804	8	But thou, son of man, hear what I say unto thee; Be not thou rebellious like that rebellious house: open thy mouth, and eat that I give thee.
20502	804	9	And when I looked, behold, an hand was sent unto me; and, lo, a roll of a book was therein;
20503	804	10	And he spread it before me; and it was written within and without: and there was written therein lamentations, and mourning, and woe.
20504	805	1	MOREOVER he said unto me, Son of man, eat that thou findest; eat this roll, and go speak unto the house of Israel.
20505	805	2	So I opened my mouth, and he caused me to eat that roll.
20506	805	3	And he said unto me, Son of man, cause thy belly to eat, and fill thy bowels with this roll that I give thee. Then did I eat it; and it was in my mouth as honey for sweetness.
20507	805	4	And he said unto me, Son of man, go, get thee unto the house of Israel, and speak with my words unto them.
20508	805	5	For thou art not sent to a people of a strange speech and of an hard language, but to the house of Israel;
20509	805	6	Not to many people of a strange speech and of an hard language, whose words thou canst not understand. Surely, had I sent thee to them, they would have hearkened unto thee.
20510	805	7	But the house of Israel will not hearken unto thee; for they will not hearken unto me: for all the house of Israel are impudent and hardhearted.
20511	805	8	Behold, I have made thy face strong against their faces, and thy forehead strong against their foreheads.
20512	805	9	As an adamant harder than flint have I made thy forehead: fear them not, neither be dismayed at their looks, though they be a rebellious house.
20513	805	10	Moreover he said unto me, Son of man, all my words that I shall speak unto thee receive in thine heart, and hear with thine ears.
20514	805	11	And go, get thee to them of the captivity, unto the children of thy people, and speak unto them, and tell them, Thus saith the Lord GOD; whether they will hear, or whether they will forbear.
20515	805	12	Then the spirit took me up, and I heard behind me a voice of a great rushing, saying, Blessed be the glory of the LORD from his place.
20516	805	13	I heard also the noise of the wings of the living creatures that touched one another, and the noise of the wheels over against them, and a noise of a great rushing.
20517	805	14	So the spirit lifted me up, and took me away, and I went in bitterness, in the heat of my spirit; but the hand of the LORD was strong upon me.
20518	805	15	Then I came to them of the captivity at Tel-abib, that dwelt by the river of Chebar, and I sat where they sat, and remained there astonished among them seven days.
20519	805	16	And it came to pass at the end of seven days, that the word of the LORD came unto me, saying,
20520	805	17	Son of man, I have made thee a watchman unto the house of Israel: therefore hear the word at my mouth, and give them warning from me.
20521	805	18	When I say unto the wicked, Thou shalt surely die; and thou givest him not warning, nor speakest to warn the wicked from his wicked way, to save his life; the same wicked man shall die in his iniquity; but his blood will I require at thine hand.
20522	805	19	Yet if thou warn the wicked, and he turn not from his wickedness, nor from his wicked way, he shall die in his iniquity; but thou hast delivered thy soul.
20523	805	20	Again, When a righteous man doth turn from his righteousness, and commit iniquity, and I lay a stumblingblock before him, he shall die: because thou hast not given him warning, he shall die in his sin, and his righteousness which he hath done shall not be remembered; but his blood will I require at thine hand.
20524	805	21	Nevertheless if thou warn the righteous man, that the righteous sin not, and he doth not sin, he shall surely live, because he is warned; also thou hast delivered thy soul.
20525	805	22	And the hand of the LORD was there upon me; and he said unto me, Arise, go forth into the plain, and I will there talk with thee.
20526	805	23	Then I arose, and went forth into the plain: and, behold, the glory of the LORD stood there, as the glory which I saw by the river of Chebar: and I fell on my face.
20527	805	24	Then the spirit entered into me, and set me upon my feet, and spake with me, and said unto me, Go, shut thyself within thine house.
20528	805	25	But thou, O son of man, behold, they shall put bands upon thee, and shall bind thee with them, and thou shalt not go out among them:
20529	805	26	And I will make thy tongue cleave to the roof of thy mouth, that thou shalt be dumb, and shalt not be to them a reprover: for they are a rebellious house.
20530	805	27	But when I speak with thee, I will open thy mouth, and thou shalt say unto them, Thus saith the Lord GOD; He that heareth, let him hear; and he that forbeareth, let him forbear: for they are a rebellious house.
20531	806	1	THOU also, son of man, take thee a tile, and lay it before thee, and pourtray upon it the city, even Jerusalem:
20532	806	2	And lay siege against it, and build a fort against it, and cast a mount against it; set the camp also against it, and set battering rams against it round about.
20533	806	3	Moreover take thou unto thee an iron pan, and set it for a wall of iron between thee and the city: and set thy face against it, and it shall be besieged, and thou shalt lay siege against it. This shall be a sign to the house of Israel.
20534	806	4	Lie thou also upon thy left side, and lay the iniquity of the house of Israel upon it: according to the number of the days that thou shalt lie upon it thou shalt bear their iniquity.
20535	806	5	For I have laid upon thee the years of their iniquity, according to the number of the days, three hundred and ninety days: so shalt thou bear the iniquity of the house of Israel.
20536	806	6	And when thou hast accomplished them, lie again on thy right side, and thou shalt bear the iniquity of the house of Judah forty days: I have appointed thee each day for a year.
20537	806	7	Therefore thou shalt set thy face toward the siege of Jerusalem, and thine arm shall be uncovered, and thou shalt prophesy against it.
20538	806	8	And, behold, I will lay bands upon thee, and thou shalt not turn thee from one side to another, till thou hast ended the days of thy siege.
20539	806	9	Take thou also unto thee wheat, and barley, and beans, and lentiles, and millet, and fitches, and put them in one vessel, and make thee bread thereof, according to the number of the days that thou shalt lie upon thy side, three hundred and ninety days shalt thou eat thereof.
20540	806	10	And thy meat which thou shalt eat shall be by weight, twenty shekels a day: from time to time shalt thou eat it.
20541	806	11	Thou shalt drink also water by measure, the sixth part of an hin: from time to time shalt thou drink.
20542	806	12	And thou shalt eat it as barley cakes, and thou shalt bake it with dung that cometh out of man, in their sight.
20543	806	13	And the LORD said, Even thus shall the children of Israel eat their defiled bread among the Gentiles, whither I will drive them.
20544	806	14	Then said I, Ah Lord GOD! behold, my soul hath not been polluted: for from my youth up even till now have I not eaten of that which dieth of itself, or is torn in pieces; neither came there abominable flesh into my mouth.
20545	806	15	Then he said unto me, Lo, I have given thee cow's dung for man's dung, and thou shalt prepare thy bread therewith.
20546	806	16	Moreover he said unto me, Son of man, behold, I will break the staff of bread in Jerusalem: and they shall eat bread by weight, and with care; and they shall drink water by measure, and with astonishment:
20547	806	17	That they may want bread and water, and be astonied one with another, and consume away for their iniquity.
20548	807	1	AND thou, son of man, take thee a sharp knife, take thee a barber's razor, and cause it to pass upon thine head and upon thy beard: then take thee balances to weight, and divide the hair.
20549	807	2	Thou shalt burn with fire a third part in the midst of the city, when the days of the siege are fulfilled: and thou shalt take a third part, and smite about it with a knife: and a third part thou shalt scatter in the wind; and I will draw out a sword after them.
20550	807	3	Thou shalt also take thereof a few in number, and bind them in thy skirts.
20551	807	4	Then take of them again, and cast them into the midst of the fire, and burn them in the fire; for thereof shall a fire come forth into all the house of Israel.
20552	807	5	Thus saith the Lord GOD; This is Jerusalem: I have set it in the midst of the nations and countries that are round about her.
20553	807	6	And she hath changed my judgments into wickedness more than the nations, and my statutes more than the countries that are round about her: for they have refused my judgments and my statutes, they have not walked in them.
20554	807	7	Therefore thus saith the Lord GOD; Because ye multiplied more than the nations that are round about you, and have not walked in my statutes, neither have kept my judgments, neither have done according to the judgments of the nations that are round about you;
20555	807	8	Therefore thus saith the Lord GOD; Behold, I, even I, am against thee, and will execute judgments in the midst of thee in the sight of the nations.
20556	807	9	And I will do in thee that which I have not done, and whereunto I will not do any more the like, because of all thine abominations.
20557	807	10	Therefore the fathers shall eat the sons in the midst of thee, and the sons shall eat their fathers; and I will execute judgments in thee, and the whole remnant of thee will I scatter into all the winds.
20558	807	11	Wherefore, as I live, saith the Lord GOD; Surely, because thou hast defiled my sanctuary with all thy detestable things, and with all thine abominations, therefore will I also diminish thee; neither shall mine eye spare, neither will I have any pity.
20559	807	12	A third part of thee shall die with the pestilence, and with famine shall they be consumed in the midst of thee: and a third part shall fall by the sword round about thee and I will scatter a third part into all the winds, and I will draw out a sword after them.
20560	807	13	Thus shall mine anger be accomplished, and I will cause my fury to rest upon them, and I will be comforted: and they shall know that I the LORD have spoken it in my zeal, when I have accomplished my fury in them.
20561	807	14	Moreover I will make thee waste, and a reproach among the nations that are round about thee, in the sight of all that pass by.
20562	807	15	So it shall be a reproach and a taunt, an instruction and an astonishment unto the nations that are round about thee, when I shall execute judgments in thee in anger and in fury and in furious rebukes. I the LORD have spoken it.
20563	807	16	When I shall send upon them the evil arrows of famine, which shall be for their destruction, and which I will send to destroy you: and I will increase the famine upon you, and will break your staff of bread:
20564	807	17	So will I send upon you famine and evil beasts, and they shall bereave thee; and pestilence and blood shall pass through thee; and I will bring the sword upon thee. I the LORD have spoken it.
20565	808	1	AND the word of the LORD came unto me, saying,
20566	808	2	Son of man, set thy face toward the mountains of Israel, and prophesy against them,
20567	808	3	And say, Ye mountains of Israel, hear the word of the Lord GOD; Thus saith the Lord GOD to the mountains, and to the hills, to the rivers, and to the valleys; Behold, I, even I, will bring a sword upon you, and I will destroy your high places.
20568	808	4	And your altars shall be desolate, and your images shall be broken: and I will cast down your slain men before your idols.
20569	808	5	And I will lay the dead carcases of the children of Israel before their idols; and I will scatter your bones round about your altars.
20570	808	6	In all your dwellingplaces the cities shall be laid waste, and the high places shall be desolate; that your altars may be laid waste and made desolate, and your idols may be broken and cease, and your images may be cut down, and your works may be abolished.
20571	808	7	And the slain shall fall in the midst of you, and ye shall know that I am the LORD.
20572	808	8	Yet will I leave a remnant, that ye may have some that shall escape the sword among the nations, when ye shall be scattered through the countries.
20573	808	9	And they that escape of you shall remember me among the nations whither they shall be carried captives, because I am broken with their whorish heart, which hath departed from me, and with their eyes, which go a whoring after their idols: and they shall lothe themselves for the evils which they have committed in all their abominations.
20574	808	10	And they shall know that I am the LORD, and that I have not said in vain that I would do this evil unto them.
20575	808	11	Thus saith the Lord GOD; Smite with thine hand, and stamp with thy foot, and say, Alas for all the evil abominations of the house of Israel! for they shall fall by the sword, by the famine, and by the pestilence.
20576	808	12	He that is far off shall die of the pestilence; and he that is near shall fall by the sword; and he that remaineth and is besieged shall die by the famine: thus will I accomplish my fury upon them.
20577	808	13	Then shall ye know that I am the LORD, when their slain men shall be among their idols round about their altars, upon every high hill, in all the tops of the mountains, and under every green tree, and under every thick oak, the place where they did offer sweet savour to all their idols.
20578	808	14	So will I stretch out my hand upon them, and make the land desolate, yea, more desolate than the wilderness toward Diblath, in all their habitations: and they shall know that I am the LORD.
20579	809	1	MOREOVER the word of the LORD came unto me, saying,
20580	809	2	Also, thou son of man, thus saith the Lord GOD unto the land of Israel; An end, the end is come upon the four corners of the land.
20581	809	3	Now is the end come upon thee, and I will send mine anger upon thee, and will judge thee according to thy ways, and will recompense upon thee all thine abominations.
20582	809	4	And mine eye shall not spare thee, neither will I have pity: but I will recompense thy ways upon thee, and thine abominations shall be in the midst of thee: and ye shall know that I am the LORD.
20583	809	5	Thus saith the Lord GOD; An evil, an only evil, behold, is come.
20584	809	6	An end is come, the end is come: it watcheth for thee; behold, it is come.
20585	809	7	The morning is come unto thee, O thou that dwellest in the land: the time is come, the day of trouble is near, and not the sounding again of the mountains.
20586	809	8	Now will I shortly pour out my fury upon thee, and accomplish mine anger upon thee: and I will judge thee according to thy ways, and will recompense thee for all thine abominations.
20587	809	9	And mine eye shall not spare, neither will I have pity: I will recompense thee according to thy ways and thine abominations that are in the midst of thee; and ye shall know that I am the LORD that smiteth.
20588	809	10	Behold the day, behold, it is come: the morning is gone forth; the rod hath blossomed, pride hath budded.
20589	809	11	Violence is risen up into a rod of wickedness: none of them shall remain, nor of their multitude, nor of any of theirs: neither shall there be wailing for them.
20590	809	12	The time is come, the day draweth near: let not the buyer rejoice, nor the seller mourn: for wrath is upon all the multitude thereof.
20591	809	13	For the seller shall not return to that which is sold, although they were yet alive: for the vision is touching the whole multitude thereof, which shall not return; neither shall any strengthen himself in the iniquity of his life.
20592	809	14	They have blown the trumpet, even to make all ready; but none goeth to the battle: for my wrath is upon all the multitude thereof.
20593	809	15	The sword is without, and the pestilence and the famine within: he that is in the field shall die with the sword; and he that is in the city, famine and pestilence shall devour him.
20594	809	16	But they that escape of them shall escape, and shall be on the mountains like doves of the valleys, all of them mourning, every one for his iniquity.
20595	809	17	All hands shall be feeble, and all knees shall be weak as water.
20596	809	18	They shall also gird themselves with sackcloth, and horror shall cover them; and shame shall be upon all faces, and baldness upon all their heads.
20597	809	19	They shall cast their silver in the streets, and their gold shall be removed: their silver and their gold shall not be able to deliver them in the day of the wrath of the LORD: they shall not satisfy their souls, neither fill their bowels: because it is the stumblingblock of their iniquity.
20598	809	20	As for the beauty of his ornament, he set it in majesty: but they made the images of their abominations and of their detestable things therein: therefore have I set it far from them.
20599	809	21	And I will give it into the hands of the strangers for a prey, and to the wicked of the earth for a spoil; and they shall pollute it.
20600	809	22	My face will I turn also from them, and they shall pollute my secret place: for the robbers shall enter into it, and defile it.
20601	809	23	Make a chain: for the land is full of bloody crimes, and the city is full of violence.
20602	809	24	Wherefore I will bring the worst of the heathen, and they shall possess their houses: I will also make the pomp of the strong to cease; and their holy places shall be defiled.
20603	809	25	Destruction cometh; and they shall seek peace, and there shall be none.
20604	809	26	Mischief shall come upon mischief, and rumour shall be upon rumour; then shall they seek a vision of the prophet; but the law shall perish from the priest, and counsel from the ancients.
20605	809	27	The king shall mourn, and the prince shall be clothed with desolation, and the hands of the people of the land shall be troubled: I will do unto them after their way, and according to their deserts will I judge them; and they shall know that I am the LORD.
20606	810	1	AND it came to pass in the sixth year, in the sixth month, in the fifth day of the month, as I sat in mine house, and the elders of Judah sat before me, that the hand of the Lord GOD fell there upon me.
20607	810	2	Then I beheld, and lo a likeness as the appearance of fire: from the appearance of his loins even downward, fire; and from his loins even upward, as the appearance of brightness, as the colour of amber.
20608	810	3	And he put forth the form of an hand, and took me by a lock of mine head; and the spirit lifted me up between the earth and the heaven, and brought me in the visions of God to Jerusalem, to the door of the inner gate that looketh toward the north; where was the seat of the image of jealousy, which provoketh to jealousy.
20609	810	4	And, behold, the glory of the God of Israel was there, according to the vision that I saw in the plain.
20610	810	5	Then said he unto me, Son of man, lift up thine eyes now the way toward the north. So I lifted up mine eyes the way toward the north, and behold northward at the gate of the altar this image of jealousy in the entry.
20611	810	6	He said furthermore unto me, Son of man, seest thou what they do? even the great abominations that the house of Israel committeth here, that I should go far off from my sanctuary? but turn thee yet again, and thou shalt see greater abominations.
20612	810	7	And he brought me to the door of the court; and when I looked, behold a hole in the wall.
20613	810	8	Then said he unto me, Son of man, dig now in the wall: and when I had digged in the wall, behold a door.
20614	810	9	And he said unto me, Go in, and behold the wicked abominations that they do here.
20615	810	10	So I went in and saw; and behold every form of creeping things, and abominable beasts, and all the idols of the house of Israel, pourtrayed upon the wall round about.
20616	810	11	And there stood before them seventy men of the ancients of the house of Israel, and in the midst of them stood Jaazaniah the son of Shaphan, with every man his censer in his hand; and a thick cloud of incense went up.
20617	810	12	Then said he unto me, Son of man, hast thou seen what the ancients of the house of Israel do in the dark, every man in the chambers of his imagery? for they say, The LORD seeth us not; the LORD hath forsaken the earth.
20618	810	13	He said also unto me, Turn thee yet again, and thou shalt see greater abominations that they do.
20619	810	14	Then he brought me to the door of the gate of the LORD's house which was toward the north; and, behold, there sat women weeping for Tammuz.
20620	810	15	Then said he unto me, Hast thou seen this, O son of man? turn thee yet again, and thou shalt see greater abominations than these.
20621	810	16	And he brought me into the inner court of the LORD's house, and, behold, at the door of the temple of the LORD, between the porch and the altar, were about five and twenty men, with their backs toward the temple of the LORD, and their faces toward the east; and they worshipped the sun toward the east.
20622	810	17	Then he said unto me, Hast thou seen this, O son of man? Is it a light thing to the house of Judah that they commit the abominations which they commit here? for they have filled the land with violence, and have returned to provoke me to anger: and, lo, they put the branch to their nose.
20623	810	18	Therefore will I also deal in fury: mine eye shall not spare, neither will I have pity: and though they cry in mine ears with a loud voice, yet will I not hear them.
20624	811	1	HE cried also in mine ears with a loud voice, saying, Cause them that have charge over the city to draw near, even every man with his destroying weapon in his hand.
20625	811	2	And, behold, six men came from the way of the higher gate, which lieth toward the north, and every man a slaughter weapon in his hand; and one man among them was clothed with linen, with a writer's inkhorn by his side: and they went in, and stood beside the brasen altar.
20626	811	3	And the glory of the God of Israel was gone up from the cherub, whereupon he was, to the threshold of the house. And he called to the man clothed with linen, which had the writer's inkhorn by his side;
20627	811	4	And the LORD said unto him, Go through the midst of the city, through the midst of Jerusalem, and set a mark upon the foreheads of the men that sigh and that cry for all the abominations that be done in the midst thereof.
20628	811	5	And to the others he said in mine hearing, Go ye after him through the city, and smite: let not your eye spare, neither have ye pity:
20629	811	6	Slay utterly old and young, both maids, and little children, and women: but come not near any man upon whom is the mark; and begin at my sanctuary. Then they began at the ancient men which were before the house.
20630	811	7	And he said unto them, Defile the house, and fill the courts with the slain: go ye forth. And they went forth, and slew in the city.
20631	811	8	And it came to pass, while they were slaying them, and I was left, that I fell upon my face, and cried, and said, Ah Lord GOD! wilt thou destroy all the residue of Israel in thy pouring out of thy fury upon Jerusalem?
20632	811	9	Then said he unto me, The iniquity of the house of Israel and Judah is exceeding great, and the land is full of blood, and the city full of perverseness: for they say, The LORD hath forsaken the earth, and the LORD seeth not.
20633	811	10	And as for me also, mine eye shall not spare, neither will I have pity, but I will recompense their way upon their head.
20634	811	11	And, behold, the man clothed with linen, which had the inkhorn by his side, reported the matter, saying, I have done as thou hast commanded me.
20635	812	1	THEN I looked, and, behold, in the firmament that was above the head of the cherubims there appeared over them as it were a sapphire stone, as the appearance of the likeness of a throne.
20636	812	2	And he spake unto the man clothed with linen, and said, Go in between the wheels, even under the cherub, and fill thine hand with coals of fire from between the cherubims, and scatter them over the city. And he went in in my sight.
20637	812	3	Now the cherubims stood on the right side of the house, when the man went in; and the cloud filled the inner court.
20638	812	4	Then the glory of the LORD went up from the cherub, and stood over the threshold of the house; and the house was filled with the cloud, and the court was full of the brightness of the LORD's glory.
20639	812	5	And the sound of the cherubims' wings was heard even to the outer court, as the voice of the Almighty God when he speaketh.
20640	812	6	And it came to pass, that when he had commanded the man clothed with linen, saying, Take fire from between the wheels, from between the cherubims; then he went in, and stood beside the wheels.
20641	812	7	And one cherub stretched forth his hand from between the cherubims unto the fire that was between the cherubims, and took thereof, and put it into the hands of him that was clothed with linen: who took it, and went out.
20642	812	8	And there appeared in the cherubims the form of a man's hand under their wings.
20643	812	9	And when I looked, behold the four wheels by the cherubims, one wheel by one cherub, and another wheel by another cherub: and the appearance of the wheels was as the colour of a beryl stone.
20644	812	10	And as for their appearances, they four had one likeness, as if a wheel had been in the midst of a wheel.
20645	812	11	When they went, they went upon their four sides; they turned not as they went, but to the place whither the head looked they followed it; they turned not as they went.
20646	812	12	And their whole body, and their backs, and their hands, and their wings, and the wheels, were full of eyes round about, even the wheels that they four had.
20647	812	13	As for the wheels, it was cried unto them in my hearing, O wheel.
20648	812	14	And every one had four faces: the first face was the face of a cherub, and the second face was the face of a man, and the third the face of a lion, and the fourth the face of an eagle.
20649	812	15	And the cherubims were lifted up. This is the living creature that I saw by the river of Chebar.
20650	812	16	And when the cherubims went, the wheels went by them: and when the cherubims lifted up their wings to mount up from the earth, the same wheels also turned not from beside them.
20651	812	17	When they stood, these stood; and when they were lifted up, these lifted up themselves also: for the spirit of the living creature was in them.
20652	812	18	Then the glory of the LORD departed from off the threshold of the house, and stood over the cherubims.
20653	812	19	And the cherubims lifted up their wings, and mounted up from the earth in my sight: when they went out, the wheels also were beside them, and every one stood at the door of the east gate of the LORD's house; and the glory of the God of Israel was over them above.
20654	812	20	This is the living creature that I saw under the God of Israel by the river of Chebar; and I knew that they were the cherubims.
20655	812	21	Every one had four faces apiece, and every one four wings; and the likeness of the hands of a man was under their wings.
20656	812	22	And the likeness of their faces was the same faces which I saw by the river of Chebar, their appearances and themselves: they went every one straight forward.
20657	813	1	MOREOVER the spirit lifted me up, and brought me unto the east gate of the LORD's house, which looketh eastward: and behold at the door of the gate five and twenty men; among whom I saw Jaazaniah the son of Azur, and Pelatiah the son of Benaiah, princes of the people.
20658	813	2	Then said he unto me, Son of man, these are the men that devise mischief, and give wicked counsel in this city:
20659	813	3	Which say, It is not near; let us build houses: this city is the caldron, and we be the flesh.
20660	813	4	Therefore prophesy against them, prophesy, O son of man.
20661	813	5	And the Spirit of the LORD fell upon me, and said unto me, Speak; Thus saith the LORD; Thus have ye said, O house of Israel: for I know the things that come into your mind, every one of them.
20662	813	6	Ye have multiplied your slain in this city, and ye have filled the streets thereof with the slain.
20663	813	7	Therefore thus saith the Lord GOD; Your slain whom ye have laid in the midst of it, they are the flesh, and this city is the caldron: but I will bring you forth out of the midst of it.
20664	813	8	Ye have feared the sword; and I will bring a sword upon you, saith the Lord GOD.
20665	813	9	And I will bring you out of the midst thereof, and deliver you into the hands of strangers, and will execute judgments among you.
20666	813	10	Ye shall fall by the sword; I will judge you in the border of Israel; and ye shall know that I am the LORD.
20667	813	11	This city shall not be your caldron, neither shall ye be the flesh in the midst thereof; but I will judge you in the border of Israel:
20668	813	12	And ye shall know that I am the LORD: for ye have not walked in my statutes, neither executed my judgments, but have done after the manners of the heathen that are round about you.
20669	813	13	And it came to pass, when I prophesied, that Pelatiah the son of Benaiah died. Then fell I down upon my face, and cried with a loud voice, and said, Ah Lord GOD! wilt thou make a full end of the remnant of Israel?
20670	813	14	Again the word of the LORD came unto me, saying,
20671	813	15	Son of man, thy brethren, even thy brethren, the men of thy kindred, and all the house of Israel wholly, are they unto whom the inhabitants of Jerusalem have said, Get you far from the LORD: unto us is this land given in possession.
20672	813	16	Therefore say, Thus saith the Lord GOD: Although I have cast them far off among the heathen, and although I have scattered them among the countries, yet will I be to them as a little sanctuary in the countries where they shall come.
20673	813	17	Therefore say, Thus saith the Lord GOD; I will even gather you from the people, and assemble you out of the countries where ye have been scattered, and I will give you the land of Israel.
20674	813	18	And they shall come thither, and they shall take away all the detestable things thereof and all the abominations thereof from thence.
20675	813	19	And I will give them one heart, and I will put a new spirit within you; and I will take the stony heart out of their flesh, and will give them an heart of flesh:
20676	813	20	That they may walk in my statutes, and keep mine ordinances, and do them: and they shall be my people, and I will be their God.
20677	813	21	But as for them whose heart walketh after the heart of their detestable things and their abominations, I will recompense their way upon their own heads, saith the Lord GOD.
20678	813	22	Then did the cherubims lift up their wings, and the wheels beside them; and the glory of the God of Israel was over them above.
20679	813	23	And the glory of the LORD went up from the midst of the city, and stood upon the mountain which is on the east side of the city.
20680	813	24	Afterwards the spirit took me up, and brought me in a vision by the Spirit of God into Chaldea, to them of the captivity. So the vision that I had seen went up from me.
20681	813	25	Then I spake unto them of the captivity all the things that the LORD had shewed me.
20682	814	1	THE word of the LORD also came unto me, saying,
20683	814	2	Son of man, thou dwellest in the midst of a rebellious house, which have eyes to see, and see not; they have ears to hear, and hear not: for they are a rebellious house.
20684	814	3	Therefore, thou son of man, prepare thee stuff for removing, and remove by day in their sight; and thou shalt remove from thy place to another place in their sight: it may be they will consider, though they be a rebellious house.
20685	814	4	Then shalt thou bring forth thy stuff by day in their sight, as stuff for removing: and thou shalt go forth at even in their sight, as they that go forth into captivity.
20686	814	5	Dig thou through the wall in their sight, and carry out thereby.
20687	814	6	In their sight shalt thou bear it upon thy shoulders, and carry it forth in the twilight: thou shalt cover thy face, that thou see not the ground: for I have set thee for a sign unto the house of Israel.
20688	814	7	And I did so as I was commanded: I brought forth my stuff by day, as stuff for captivity, and in the even I digged through the wall with mine hand; I brought it forth in the twilight, and I bare it upon my shoulder in their sight.
20689	814	8	And in the morning came the word of the LORD unto me, saying,
20690	814	9	Son of man, hath not the house of Israel, the rebellious house, said unto thee, What doest thou?
20691	814	10	Say thou unto them, Thus saith the Lord GOD; This burden concerneth the prince in Jerusalem, and all the house of Israel that are among them.
20692	814	11	Say, I am your sign: like as I have done, so shall it be done unto them: they shall remove and go into captivity.
20693	814	12	And the prince that is among them shall bear upon his shoulder in the twilight, and shall go forth: they shall dig through the wall to carry out thereby: he shall cover his face, that he see not the ground with his eyes.
20694	814	13	My net also will I spread upon him, and he shall be taken in my snare: and I will bring him to Babylon to the land of the Chaldeans; yet shall he not see it, though he shall die there.
20695	814	14	And I will scatter toward every wind all that are about him to help him, and all his bands; and I will draw out the sword after them.
20696	814	15	And they shall know that I am the LORD, when I shall scatter them among the nations, and disperse them in the countries.
20697	814	16	But I will leave a few men of them from the sword, from the famine, and from the pestilence; that they may declare all their abominations among the heathen whither they come; and they shall know that I am the LORD.
20698	814	17	Moreover the word of the LORD came to me, saying,
20699	814	18	Son of man, eat thy bread with quaking, and drink thy water with trembling and with carefulness;
20700	814	19	And say unto the people of the land, Thus saith the Lord GOD of the inhabitants of Jerusalem, and of the land of Israel; They shall eat their bread with carefulness, and drink their water with astonishment, that her land may be desolate from all that is therein, because of the violence of all them that dwell therein.
20701	814	20	And the cities that are inhabited shall be laid waste, and the land shall be desolate; and ye shall know that I am the LORD.
20702	814	21	And the word of the LORD came unto me, saying,
20703	814	22	Son of man, what is that proverb that ye have in the land of Israel, saying, The days are prolonged, and every vision faileth?
20704	814	23	Tell them therefore, Thus saith the Lord GOD; I will make this proverb to cease, and they shall no more use it as a proverb in Israel; but say unto them, The days are at hand, and the effect of every vision.
20705	814	24	For there shall be no more any vain vision nor flattering divination within the house of Israel.
20706	814	25	For I am the LORD: I will speak, and the word that I shall speak shall come to pass; it shall be no more prolonged: for in your days, O rebellious house, will I say the word, and will perform it, saith the Lord GOD.
20707	814	26	Again the word of the LORD came to me, saying,
20708	814	27	Son of man, behold, they of the house of Israel say, The vision that he seeth is for many days to come, and he prophesieth of the times that are far off.
20709	814	28	Therefore say unto them, Thus saith the Lord GOD; There shall none of my words be prolonged any more, but the word which I have spoken shall be done, saith the Lord GOD.
20710	815	1	AND the word of the LORD came unto me, saying,
20711	815	2	Son of man, prophesy against the prophets of Israel that prophesy, and say thou unto them that prophesy out of their own hearts, Hear ye the word of the LORD;
20712	815	3	Thus saith the Lord GOD; Woe unto the foolish prophets, that follow their own spirit, and have seen nothing!
20713	815	4	O Israel, thy prophets are like the foxes in the deserts.
20714	815	5	Ye have not gone up into the gaps, neither made up the hedge for the house of Israel to stand in the battle in the day of the LORD.
20715	815	6	They have seen vanity and lying divination, saying, The LORD saith: and the LORD hath not sent them: and they have made others to hope that they would confirm the word.
20716	815	7	Have ye not seen a vain vision, and have ye not spoken a lying divination, whereas ye say, The LORD saith it; albeit I have not spoken?
20717	815	8	Therefore thus saith the Lord GOD; Because ye have spoken vanity, and seen lies, therefore, behold, I am against you, saith the Lord GOD.
20718	815	9	And mine hand shall be upon the prophets that see vanity, and that divine lies: they shall not be in the assembly of my people, neither shall they be written in the writing of the house of Israel, neither shall they enter into the land of Israel; and ye shall know that I am the Lord GOD.
20719	815	10	Because, even because they have seduced my people, saying, Peace; and there was no peace; and one built up a wall, and, lo, others daubed it with untempered morter:
20720	815	11	Say unto them which daub it with untempered morter, that it shall fall: there shall be an overflowing shower; and ye, O great hailstones, shall fall; and a stormy wind shall rend it.
20721	815	12	Lo, when the wall is fallen, shall it not be said unto you, Where is the daubing wherewith ye have daubed it?
20722	815	13	Therefore thus saith the Lord GOD; I will even rend it with a stormy wind in my fury; and there shall be an overflowing shower in mine anger, and great hailstones in my fury to consume it.
20723	815	14	So will I break down the wall that ye have daubed with untempered morter, and bring it down to the ground, so that the foundation thereof shall be discovered, and it shall fall, and ye shall be consumed in the midst thereof: and ye shall know that I am the LORD.
20724	815	15	Thus will I accomplish my wrath upon the wall, and upon them that have daubed it with untempered morter, and will say unto you, The wall is no more, neither they that daubed it;
20725	815	16	To wit, the prophets of Israel which prophesy concerning Jerusalem, and which see visions of peace for her, and there is no peace, saith the Lord GOD.
20726	815	17	Likewise, thou son of man, set thy face against the daughters of thy people, which prophesy out of their own heart; and prophesy thou against them,
20727	815	18	And say, Thus saith the Lord GOD; Woe to the women that sew pillows to all armholes, and make kerchiefs upon the head of every stature to hunt souls! Will ye hunt the souls of my people, and will ye save the souls alive that come unto you?
20728	815	19	And will ye pollute me among my people for handfuls of barley and for pieces of bread, to slay the souls that should not die, and to save the souls alive that should not live, by your lying to my people that hear your lies?
20729	815	20	Wherefore thus saith the Lord GOD; Behold, I am against your pillows, wherewith ye there hunt the souls to make them fly, and I will tear them from your arms, and will let the souls go, even the souls that ye hunt to make them fly.
20730	815	21	Your kerchiefs also will I tear, and deliver my people out of your hand, and they shall be no more in your hand to be hunted; and ye shall know that I am the LORD.
20731	815	22	Because with lies ye have made the heart of the righteous sad, whom I have not made sad; and strengthened the hands of the wicked, that he should not return from his wicked way, by promising him life:
20732	815	23	Therefore ye shall see no more vanity, nor divine divinations: for I will deliver my people out of your hand: and ye shall know that I am the LORD.
20733	816	1	THEN came certain of the elders of Israel unto me, and sat before me.
20734	816	2	And the word of the LORD came unto me, saying,
20735	816	3	Son of man, these men have set up their idols in their heart, and put the stumblingblock of their iniquity before their face: should I be enquired of at all by them?
20736	816	4	Therefore speak unto them, and say unto them, Thus saith the Lord GOD; Every man of the house of Israel that setteth up his idols in his heart, and putteth the stumblingblock of his iniquity before his face, and cometh to the prophet; I the LORD will answer him that cometh according to the multitude of his idols;
20737	816	5	That I may take the house of Israel in their own heart, because they are all estranged from me through their idols.
20738	816	6	Therefore say unto the house of Israel, Thus saith the Lord GOD; Repent, and turn yourselves from your idols; and turn away your faces from all your abominations.
20739	816	7	For every one of the house of Israel, or of the stranger that sojourneth in Israel, which separateth himself from me, and setteth up his idols in his heart, and putteth the stumblingblock of his iniquity before his face, and cometh to a prophet to enquire of him concerning me; I the LORD will answer him by myself:
20740	816	8	And I will set my face against that man, and will make him a sign and a proverb, and I will cut him off from the midst of my people; and ye shall know that I am LORD.
20741	816	9	And if the prophet be deceived when he hath spoken a thing, I the LORD have deceived that prophet, and I will stretch out my hand upon him, and will destroy him from the midst of my people Israel.
20742	816	10	And they shall bear the punishment of their iniquity: the punishment of the prophet shall be even as the punishment of him that seeketh unto him;
20743	816	11	That the house of Israel may go no more astray from me, neither be polluted any more with all their transgressions; but that they may be my people, and I may be their God, saith the Lord GOD.
20744	816	12	The word of the LORD came again to me, saying,
20745	816	13	Son of man, when the land sinneth against me by trespassing grievously, then will I stretch out mine hand upon it, and will break the staff of the bread thereof, and will send famine upon it, and will cut off man and beast from it:
20746	816	14	Though these three men, Noah, Daniel, and Job, were in it, they should deliver but their own souls by their righteousness, saith the Lord GOD.
20747	816	15	If I cause noisome beasts to pass through the land, and they spoil it, so that it be desolate, that no man may pass through because of the beasts:
20748	816	16	Though these three men were in it, as I live, saith the Lord GOD, they shall deliver neither sons nor daughters; they only shall be delivered, but the land shall be desolate.
20749	816	17	Or if I bring a sword upon that land, and say, Sword, go through the land; so that I cut off man and beast from it:
20750	816	18	Though these three men were in it, as I live, saith the Lord GOD, they shall deliver neither sons nor daughters, but they only shall be delivered themselves.
20751	816	19	Or if I send a pestilence into that land, and pour out my fury upon it in blood, to cut off from it man and beast:
20752	816	20	Though Noah, Daniel, and Job, were in it, as I live, saith the Lord GOD, they shall deliver neither son nor daughter; they shall but deliver their own souls by their righteousness.
20753	816	21	For thus saith the Lord GOD; How much more when I send my four sore judgments upon Jerusalem, the sword, and the famine, and the noisome beast, and the pestilence, to cut off from it man and beast?
20754	816	22	Yet, behold, therein shall be left a remnant that shall be brought forth, both sons and daughters: behold, they shall come forth unto you, and ye shall see their way and their doings: and ye shall be comforted concerning the evil that I have brought upon Jerusalem, even concerning all that I have brought upon it.
20755	816	23	And they shall comfort you, when ye see their ways and their doings: and ye shall know that I have not done without cause all that I have done in it, saith the Lord GOD.
20756	817	1	AND the word of the LORD came unto me, saying,
20757	817	2	Son of man, What is the vine tree more than any tree, or than a branch which is among the trees of the forest?
20758	817	3	Shall wood be taken thereof to do any work? or will men take a pin of it to hang any vessel thereon?
20759	817	4	Behold, it is cast into the fire for fuel; the fire devoureth both the ends of it, and the midst of it is burned. Is it meet for any work?
20760	817	5	Behold, when it was whole, it was meet for no work: how much less shall it be meet yet for any work, when the fire hath devoured it, and it is burned?
20761	817	6	Therefore thus saith the Lord GOD; As the vine tree among the trees of the forest, which I have given to the fire for fuel, so will I give the inhabitants of Jerusalem.
20762	817	7	And I will set my face against them; they shall go out from one fire, and another fire shall devour them; and ye shall know that I am the LORD, when I set my face against them.
20763	817	8	And I will make the land desolate, because they have committed a trespass, saith the Lord GOD.
20764	818	1	AGAIN the word of the LORD came unto me, saying,
20765	818	2	Son of man, cause Jerusalem to know her abominations,
20766	818	3	And say, Thus saith the Lord GOD unto Jerusalem; Thy birth and thy nativity is of the land of Canaan; thy father was an Amorite, and thy mother an Hittite.
20767	818	4	And as for thy nativity, in the day thou wast born thy navel was not cut, neither wast thou washed in water to supple thee; thou wast not salted at all, nor swaddled at all.
20768	818	5	None eye pitied thee, to do any of these unto thee, to have compassion upon thee; but thou wast cast out in the open field, to the lothing of thy person, in the day that thou wast born.
20769	818	6	And when I passed by thee, and saw thee polluted in thine own blood, I said unto thee when thou wast in thy blood, Live; yea, I said unto thee when thou wast in thy blood, Live.
20770	818	7	I have caused thee to multiply as the bud of the field, and thou hast increased and waxen great, and thou art come to excellent ornaments: thy breasts are fashioned, and thine hair is grown, whereas thou wast naked and bare.
20771	818	8	Now when I passed by thee, and looked upon thee, behold, thy time was the time of love; and I spread my skirt over thee, and covered thy nakedness: yea, I sware unto thee, and entered into a covenant with thee, saith the Lord GOD, and thou becamest mine.
20772	818	9	Then washed I thee with water; yea, I throughly washed away thy blood from thee, and I anointed thee with oil.
20773	818	10	I clothed thee also with broidered work, and shod thee with badgers' skin, and I girded thee about with fine linen, and I covered thee with silk.
20774	818	11	I decked thee also with ornaments, and I put bracelets upon thy hands, and a chain on thy neck.
20775	818	12	And I put a jewel on thy forehead, and earrings in thine ears, and a beautiful crown upon thine head.
20776	818	13	Thus wast thou decked with gold and silver; and thy raiment was of fine linen, and silk, and broidered work; thou didst eat fine flour, and honey, and oil: and thou wast exceeding beautiful, and thou didst prosper into a kingdom.
20777	818	14	And thy renown went forth among the heathen for thy beauty: for it was perfect through my comeliness, which I had put upon thee, saith the Lord GOD.
20778	818	15	But thou didst trust in thine own beauty, and playedst the harlot because of thy renown, and pouredst out thy fornications on every one that passed by; his it was.
20779	818	16	And of thy garments thou didst take, and deckedst thy high places with divers colours, and playedst the harlot thereupon: the like things shall not come, neither shall it be so.
20780	818	17	Thou hast also taken thy fair jewels of my gold and of my silver, which I had given thee, and madest to thyself images of men, and didst commit whoredom with them,
20781	818	18	And tookest thy broidered garments, and coveredst them: and thou hast set mine oil and mine incense before them.
20782	818	19	My meat also which I gave thee, fine flour, and oil, and honey, wherewith I fed thee, thou hast even set it before them for a sweet savour: and thus it was, saith the Lord GOD.
20783	818	20	Moreover thou hast taken thy sons and thy daughters, whom thou hast borne unto me, and these hast thou sacrificed unto them to be devoured. Is this of thy whoredoms a small matter,
20784	818	21	That thou hast slain my children, and delivered them to cause them to pass through the fire for them?
20785	818	22	And in all thine abominations and thy whoredoms thou hast not remembered the days of thy youth, when thou wast naked and bare, and wast polluted in thy blood.
20786	818	23	And it came to pass after all thy wickedness, (woe, woe unto thee! saith the Lord GOD;)
20787	818	24	That thou hast also built unto thee an eminent place, and hast made thee an high place in every street.
20788	818	25	Thou hast built thy high place at every head of the way, and hast made thy beauty to be abhorred, and hast opened thy feet to every one that passed by, and multiplied thy whoredoms.
20789	818	26	Thou hast also committed fornication with the Egyptians thy neighbours, great of flesh; and hast increased thy whoredoms, to provoke me to anger.
20790	818	27	Behold, therefore I have stretched out my hand over thee, and have diminished thine ordinary food, and delivered thee unto the will of them that hate thee, the daughters of the Philistines, which are ashamed of thy lewd way.
20791	818	28	Thou hast played the whore also with the Assyrians, because thou wast unsatiable; yea, thou hast played the harlot with them, and yet couldest not be satisfied.
20792	818	29	Thou hast moreover multiplied thy fornication in the land of Canaan unto Chaldea; and yet thou wast not satisfied herewith.
20793	818	30	How weak is thine heart, saith the Lord GOD, seeing thou doest all these things, the work of an imperious whorish woman;
20794	818	31	In that thou buildest thine eminent place in the head of every way, and makest thine high place in every street; and hast not been as an harlot, in that thou scornest hire;
20795	818	32	But as a wife that committeth adultery, which taketh strangers instead of her husband!
20796	818	33	They give gifts to all whores: but thou givest thy gifts to all thy lovers, and hirest them, that they may come unto thee on every side for thy whoredom.
20797	818	34	And the contrary is in thee from other women in thy whoredoms, whereas none followeth thee to commit whoredoms: and in that thou givest a reward, and no reward is given unto thee, therefore thou art contrary.
20798	818	35	Wherefore, O harlot, hear the word of the LORD:
20799	818	36	Thus saith the Lord GOD; Because thy filthiness was poured out, and thy nakedness discovered through thy whoredoms with thy lovers, and with all the idols of thy abominations, and by the blood of thy children, which thou didst give unto them;
20800	818	37	Behold, therefore I will gather all thy lovers, with whom thou hast taken pleasure, and all them that thou hast loved, with all them that thou hast hated; I will even gather them round about against thee, and will discover thy nakedness unto them, that they may see all thy nakedness.
20801	818	38	And I will judge thee, as women that break wedlock and shed blood are judged; and I will give thee blood in fury and jealousy.
20802	818	39	And I will also give thee into their hand, and they shall throw down thine eminent place, and shall break down thy high places: they shall strip thee also of thy clothes, and shall take thy fair jewels, and leave thee naked and bare.
20803	818	40	They shall also bring up a company against thee, and they shall stone thee with stones, and thrust thee through with their swords.
20804	818	41	And they shall burn thine houses with fire, and execute judgments upon thee in the sight of many women: and I will cause thee to cease from playing the harlot, and thou also shalt give no hire any more.
20805	818	42	So will I make my fury toward thee to rest, and my jealousy shall depart from thee, and I will be quiet, and will be no more angry.
20806	818	43	Because thou hast not remembered the days of thy youth, but hast fretted me in all these things; behold, therefore I also will recompense thy way upon thine head, saith the Lord GOD: and thou shalt not commit this lewdness above all thine abominations.
20807	818	44	Behold, every one that useth proverbs shall use this proverb against thee, saying, As is the mother, so is her daughter.
20808	818	45	Thou art thy mother's daughter, that lotheth her husband and her children; and thou art the sister of thy sisters, which lothed their husbands and their children: your mother was an Hittite, and your father an Amorite.
20809	818	46	And thine elder sister is Samaria, she and her daughters that dwell at thy left hand: and thy younger sister, that dwelleth at thy right hand, is Sodom and her daughters.
20810	818	47	Yet hast thou not walked after their ways, nor done after their abominations: but, as if that were a very little thing, thou wast corrupted more than they in all thy ways.
20811	818	48	As I live, saith the Lord GOD, Sodom thy sister hath not done, she nor her daughters, as thou hast done, thou and thy daughters.
20812	818	49	Behold, this was the iniquity of thy sister Sodom, pride, fulness of bread, and abundance of idleness was in her and in her daughters, neither did she strengthen the hand of the poor and needy.
20813	818	50	And they were haughty, and committed abomination before me: therefore I took them away as I saw good.
20814	818	51	Neither hath Samaria committed half of thy sins; but thou hast multiplied thine abominations more than they, and hast justified thy sisters in all thine abominations which thou hast done.
20815	818	52	Thou also, which hast judged thy sisters, bear thine own shame for thy sins that thou hast committed more abominable than they: they are more righteous than thou: yea, be thou confounded also, and bear thy shame, in that thou hast justified thy sisters.
20816	818	53	When I shall bring again their captivity, the captivity of Sodom and her daughters, and the captivity of Samaria and her daughters, then will I bring again the captivity of thy captives in the midst of them:
20817	818	54	That thou mayest bear thine own shame, and mayest be confounded in all that thou hast done, in that thou art a comfort unto them.
20818	818	55	When thy sisters, Sodom and her daughters, shall return to their former estate, and Samaria and her daughters shall return to their former estate, then thou and thy daughters shall return to your former estate.
20819	818	56	For thy sister Sodom was not mentioned by thy mouth in the day of thy pride,
20820	818	57	Before thy wickedness was discovered, as at the time of thy reproach of the daughters of Syria, and all that are round about her, the daughters of the Philistines, which despise thee round about.
20821	818	58	Thou hast borne thy lewdness and thine abominations, saith the LORD.
20822	818	59	For thus saith the Lord GOD; I will even deal with thee as thou hast done, which hast despised the oath in breaking the covenant.
20823	818	60	Nevertheless I will remember my covenant with thee in the days of thy youth, and I will establish unto thee an everlasting covenant.
20824	818	61	Then thou shalt remember thy ways, and be ashamed, when thou shalt receive thy sisters, thine elder and thy younger: and I will give them unto thee for daughters, but not by thy covenant.
20825	818	62	And I will establish my covenant with thee; and thou shalt know that I am the LORD:
20826	818	63	That thou mayest remember, and be confounded, and never open thy mouth any more because of thy shame, when I am pacified toward thee for all that thou hast done, saith the Lord GOD.
20827	819	1	AND the word of the LORD came unto me, saying,
20828	819	2	Son of man, put forth a riddle, and speak a parable unto the house of Israel;
20829	819	3	And say, Thus saith the Lord GOD; A great eagle with great wings, longwinged, full of feathers, which had divers colours, came unto Lebanon, and took the highest branch of the cedar:
20830	819	4	He cropped off the top of his young twigs, and carried it into a land of traffick; he set it in a city of merchants.
20831	819	5	He took also of the seed of the land, and planted it in a fruitful field; he placed it by great waters, and set it as a willow tree.
20832	819	6	And it grew, and became a spreading vine of low stature, whose branches turned toward him, and the roots thereof were under him: so it became a vine, and brought forth branches, and shot forth sprigs.
20833	819	7	There was also another great eagle with great wings and many feathers: and, behold, this vine did bend her roots toward him, and shot forth her branches toward him, that he might water it by the furrows of her plantation.
20834	819	8	It was planted in a good soil by great waters, that it might bring forth branches, and that it might bear fruit, that it might be a goodly vine.
20835	819	9	Say thou, Thus saith the Lord GOD; Shall it prosper? shall he not pull up the roots thereof, and cut off the fruit thereof, that it wither? it shall wither in all the leaves of her spring, even without great power or many people to pluck it up by the roots thereof.
20836	819	10	Yea, behold, being planted, shall it prosper? shall it not utterly wither, when the east wind toucheth it? it shall wither in the furrows where it grew.
20837	819	11	Moreover the word of the LORD came unto me, saying,
20838	819	12	Say now to the rebellious house, Know ye not what these things mean? tell them, Behold, the king of Babylon is come to Jerusalem, and hath taken the king thereof, and the princes thereof, and led them with him to Babylon;
20839	819	13	And hath taken of the king's seed, and made a covenant with him, and hath taken an oath of him: he hath also taken the mighty of the land:
20840	819	14	That the kingdom might be base, that it might not lift itself up, but that by keeping of his covenant it might stand.
20841	819	15	But he rebelled against him in sending his ambassadors into Egypt, that they might give him horses and much people. Shall he prosper? shall he escape that doeth such things? or shall he break the covenant, and be delivered?
20842	819	16	As I live, saith the Lord GOD, surely in the place where the king dwelleth that made him king, whose oath he despised, and whose covenant he brake, even with him in the midst of Babylon he shall die.
20843	819	17	Neither shall Pharaoh with his mighty army and great company make for him in the war, by casting up mounts, and building forts, to cut off many persons:
20844	819	18	Seeing he despised the oath by breaking the covenant, when, lo, he had given his hand, and hath done all these things, he shall not escape.
20845	819	19	Therefore thus saith the Lord GOD; As I live, surely mine oath that he hath despised, and my covenant that he hath broken, even it will I recompense upon his own head.
20846	819	20	And I will spread my net upon him, and he shall be taken in my snare, and I will bring him to Babylon, and will plead with him there for his trespass that he hath trespassed against me.
20847	819	21	And all his fugitives with all his bands shall fall by the sword, and they that remain shall be scattered toward all winds: and ye shall know that I the LORD have spoken it.
20848	819	22	Thus saith the Lord GOD; I will also take of the highest branch of the high cedar, and will set it; I will crop off from the top of his young twigs a tender one, and will plant it upon an high mountain and eminent:
20849	819	23	In the mountain of the height of Israel will I plant it: and it shall bring forth boughs, and bear fruit, and be a goodly cedar: and under it shall dwell all fowl of every wing; in the shadow of the branches thereof shall they dwell.
20850	819	24	And all the trees of the field shall know that I the LORD have brought down the high tree, have exalted the low tree, have dried up the green tree, and have made the dry tree to flourish: I the LORD have spoken and have done it.
20851	820	1	THE word of the LORD came unto me again, saying,
20852	820	2	What mean ye, that ye use this proverb concerning the land of Israel, saying, The fathers have eaten sour grapes, and the children's teeth are set on edge?
20853	820	3	As I live, saith the Lord GOD, ye shall not have occasion any more to use this proverb in Israel.
20854	820	4	Behold, all souls are mine; as the soul of the father, so also the soul of the son is mine: the soul that sinneth, it shall die.
20855	820	5	But if a man be just, and do that which is lawful and right,
20856	820	6	And hath not eaten upon the mountains, neither hath lifted up his eyes to the idols of the house of Israel, neither hath defiled his neighbour's wife, neither hath come near to a menstruous woman,
20857	820	7	And hath not oppressed any, but hath restored to the debtor his pledge, hath spoiled none by violence, hath given his bread to the hungry, and hath covered the naked with a garment;
20858	820	8	He that hath not given forth upon usury, neither hath taken any increase, that hath withdrawn his hand from iniquity, hath executed true judgment between man and man,
20859	820	9	Hath walked in my statutes, and hath kept my judgments, to deal truly; he is just, he shall surely live, saith the Lord GOD.
20860	820	10	If he beget a son that is a robber, a shedder of blood, and that doeth the like to any one of these things,
20861	820	11	And that doeth not any of those duties, but even hath eaten upon the mountains, and defiled his neighbour's wife,
20862	820	12	Hath oppressed the poor and needy, hath spoiled by violence, hath not restored the pledge, and hath lifted up his eyes to the idols, hath committed abomination,
20863	820	13	Hath given forth upon usury, and hath taken increase: shall he then live? he shall not live: he hath done all these abominations; he shall surely die; his blood shall be upon him.
20864	820	14	Now, lo, if he beget a son, that seeth all his father's sins which he hath done, and considereth, and doeth not such like,
20865	820	15	That hath not eaten upon the mountains, neither hath lifted up his eyes to the idols of the house of Israel, hath not defiled his neighbour's wife,
20866	820	16	Neither hath oppressed any, hath not withholden the pledge, neither hath spoiled by violence, but hath given his bread to the hungry, and hath covered the naked with a garment,
20867	820	17	That hath taken off his hand from the poor, that hath not received usury nor increase, hath executed my judgments, hath walked in my statutes; he shall not die for the iniquity of his father, he shall surely live.
20868	820	18	As for his father, because he cruelly oppressed, spoiled his brother by violence, and did that which is not good among his people, lo, even he shall die in his iniquity.
20869	820	19	Yet say ye, Why? doth not the son bear the iniquity of the father? When the son hath done that which is lawful and right, and hath kept all my statutes, and hath done them, he shall surely live.
20870	820	20	The soul that sinneth, it shall die. The son shall not bear the iniquity of the father, neither shall the father bear the iniquity of the son: the righteousness of the righteous shall be upon him, and the wickedness of the wicked shall be upon him.
20871	820	21	But if the wicked will turn from all his sins that he hath committed, and keep all my statutes, and do that which is lawful and right, he shall surely live, he shall not die.
20872	820	22	All his transgressions that he hath committed, they shall not be mentioned unto him: in his righteousness that he hath done he shall live.
20873	820	23	Have I any pleasure at all that the wicked should die? saith the Lord GOD: and not that he should return from his ways, and live?
20874	820	24	But when the righteous turneth away from his righteousness, and committeth iniquity, and doeth according to all the abominations that the wicked man doeth, shall he live? All his righteousness that he hath done shall not be mentioned: in his trespass that he hath trespassed, and in his sin that he hath sinned, in them shall he die.
20875	820	25	Yet ye say, The way of the Lord is not equal. Hear now, O house of Israel; Is not my way equal? are not your ways unequal?
20876	820	26	When a righteous man turneth away from his righteousness, and committeth iniquity, and dieth in them; for his iniquity that he hath done shall he die.
20877	820	27	Again, when the wicked man turneth away from his wickedness that he hath committed, and doeth that which is lawful and right, he shall save his soul alive.
20878	820	28	Because he considereth, and turneth away from all his transgressions that he hath committed, he shall surely live, he shall not die.
20879	820	29	Yet saith the house of Israel, The way of the Lord is not equal. O house of Israel, are not my ways equal? are not your ways unequal?
20880	820	30	Therefore I will judge you, O house of Israel, every one according to his ways, saith the Lord GOD. Repent, and turn yourselves from all your transgressions; so iniquity shall not be your ruin.
20881	820	31	Cast away from you all your transgressions, whereby ye have transgressed; and make you a new heart and a new spirit: for why will ye die, O house of Israel?
20882	820	32	For I have no pleasure in the death of him that dieth, saith the Lord GOD: wherefore turn yourselves, and live ye.
20883	821	1	MOREOVER take thou up a lamentation for the princes of Israel,
20884	821	2	And say, What is thy mother? A lioness: she lay down among lions, she nourished her whelps among young lions.
20885	821	3	And she brought up one of her whelps: it became a young lion, and it learned to catch the prey; it devoured men.
20886	821	4	The nations also heard of him; he was taken in their pit, and they brought him with chains unto the land of Egypt.
20887	821	5	Now when she saw that she had waited, and her hope was lost, then she took another of her whelps, and made him a young lion.
20888	821	6	And he went up and down among the lions, he became a young lion, and learned to catch the prey, and devoured men.
20889	821	7	And he knew their desolate palaces, and he laid waste their cities; and the land was desolate, and the fulness thereof, by the noise of his roaring.
20890	821	8	Then the nations set against him on every side from the provinces, and spread their net over him: he was taken in their pit.
20891	821	9	And they put him in ward in chains, and brought him to the king of Babylon: they brought him into holds, that his voice should no more be heard upon the mountains of Israel.
20892	821	10	Thy mother is like a vine in thy blood, planted by the waters: she was fruitful and full of branches by reason of many waters.
20893	821	11	And she had strong rods for the sceptres of them that bare rule, and her stature was exalted among the thick branches, and she appeared in her height with the multitude of her branches.
20894	821	12	But she was plucked up in fury, she was cast down to the ground, and the east wind dried up her fruit: her strong rods were broken and withered; the fire consumed them.
20895	821	13	And now she is planted in the wilderness, in a dry and thirsty ground.
20896	821	14	And fire is gone out of a rod of her branches, which hath devoured her fruit, so that she hath no strong rod to be a sceptre to rule. This is a lamentation, and shall be for a lamentation.
20897	822	1	AND it came to pass in the seventh year, in the fifth month, the tenth day of the month, that certain of the elders of Israel came to enquire of the LORD, and sat before me.
20898	822	2	Then came the word of the LORD unto me, saying,
20899	822	3	Son of man, speak unto the elders of Israel, and say unto them, Thus saith the Lord GOD; Are ye come to enquire of me? As I live, saith the Lord GOD, I will not be enquired of by you.
20900	822	4	Wilt thou judge them, son of man, wilt thou judge them? cause them to know the abominations of their fathers:
20901	822	5	And say unto them, Thus saith the Lord GOD; In the day when I chose Israel, and lifted up mine hand unto the seed of the house of Jacob, and made myself known unto them in the land of Egypt, when I lifted up mine hand unto them, saying, I am the LORD your God;
20902	822	6	In the day that I lifted up mine hand unto them, to bring them forth of the land of Egypt into a land that I had espied for them, flowing with milk and honey, which is the glory of all lands:
20903	822	7	Then said I unto them, Cast ye away every man the abominations of his eyes, and defile not yourselves with the idols of Egypt: I am the LORD your God.
20904	822	8	But they rebelled against me, and would not hearken unto me: they did not every man cast away the abominations of their eyes, neither did they forsake the idols of Egypt: then I said, I will pour out my fury upon them, to accomplish my anger against them in the midst of the land of Egypt.
20905	822	9	But I wrought for my name's sake, that it should not be polluted before the heathen, among whom they were, in whose sight I made myself known unto them, in bringing them forth out of the land of Egypt.
20906	822	10	Wherefore I caused them to go forth out of the land of Egypt, and brought them into the wilderness.
20907	822	11	And I gave them my statutes, and shewed them my judgments, which if a man do, he shall even live in them.
20908	822	12	Moreover also I gave them my sabbaths, to be a sign between me and them, that they might know that I am the LORD that sanctify them.
20909	822	13	But the house of Israel rebelled against me in the wilderness: they walked not in my statutes, and they despised my judgments, which if a man do, he shall even live in them; and my sabbaths they greatly polluted: then I said, I would pour out my fury upon them in the wilderness, to consume them.
20910	822	14	But I wrought for my name's sake, that it should not be polluted before the heathen, in whose sight I brought them out.
20911	822	15	Yet also I lifted up my hand unto them in the wilderness, that I would not bring them into the land which I had given them, flowing with milk and honey, which is the glory of all lands;
20912	822	16	Because they despised my judgments, and walked not in my statutes, but polluted my sabbaths: for their heart went after their idols.
20913	822	17	Nevertheless mine eye spared them from destroying them, neither did I make an end of them in the wilderness.
20914	822	18	But I said unto their children in the wilderness, Walk ye not in the statutes of your fathers, neither observe their judgments, nor defile yourselves with their idols:
20915	822	19	I am the LORD your God; walk in my statutes, and keep my judgments, and do them;
20916	822	20	And hallow my sabbaths; and they shall be a sign between me and you, that ye may know that I am the LORD your God.
20917	822	21	Notwithstanding the children rebelled against me: they walked not in my statutes, neither kept my judgments to do them, which if a man do, he shall even live in them; they polluted my sabbaths: then I said, I would pour out my fury upon them, to accomplish my anger against them in the wilderness.
20918	822	22	Nevertheless I withdrew mine hand, and wrought for my name's sake, that it should not be polluted in the sight of the heathen, in whose sight I brought them forth.
20919	822	23	I lifted up mine hand unto them also in the wilderness, that I would scatter them among the heathen, and disperse them through the countries;
20920	822	24	Because they had not executed my judgments, but had despised my statutes, and had polluted my sabbaths, and their eyes were after their fathers' idols.
20921	822	25	Wherefore I gave them also statutes that were not good, and judgments whereby they should not live;
20922	822	26	And I polluted them in their own gifts, in that they caused to pass through the fire all that openeth the womb, that I might make them desolate, to the end that they might know that I am the LORD.
20923	822	27	Therefore, son of man, speak unto the house of Israel, and say unto them, Thus saith the Lord GOD; Yet in this your fathers have blasphemed me, in that they have committed a trespass against me.
20924	822	28	For when I had brought them into the land, for the which I lifted up mine hand to give it to them, then they saw every high hill, and all the thick trees, and they offered there their sacrifices, and there they presented the provocation of their offering: there also they made their sweet savour, and poured out there their drink offerings.
20925	822	29	Then I said unto them, What is the high place whereunto ye go? And the name thereof is called Bamah unto this day.
20926	822	30	Wherefore say unto the house of Israel, Thus saith the Lord GOD; Are ye polluted after the manner of your fathers? and commit ye whoredom after their abominations?
20927	822	31	For when ye offer your gifts, when ye make your sons to pass through the fire, ye pollute yourselves with all your idols, even unto this day: and shall I be enquired of by you, O house of Israel? As I live, saith the Lord GOD, I will not be enquired of by you.
20928	822	32	And that which cometh into your mind shall not be at all, that ye say, We will be as the heathen, as the families of the countries, to serve wood and stone.
20929	822	33	As I live, saith the Lord GOD, surely with a mighty hand, and with a stretched out arm, and with fury poured out, will I rule over you:
20930	822	34	And I will bring you out from the people, and will gather you out of the countries wherein ye are scattered, with a mighty hand, and with a stretched out arm, and with fury poured out.
20931	822	35	And I will bring you into the wilderness of the people, and there will I plead with you face to face.
20932	822	36	Like as I pleaded with your fathers in the wilderness of the land of Egypt, so will I plead with you, saith the Lord GOD.
20933	822	37	And I will cause you to pass under the rod, and I will bring you into the bond of the covenant:
20934	822	38	And I will purge out from among you the rebels, and them that transgress against me: I will bring them forth out of the country where they sojourn, and they shall not enter into the land of Israel: and ye shall know that I am the LORD.
20935	822	39	As for you, O house of Israel, thus saith the Lord GOD; Go ye, serve ye every one his idols, and hereafter also, if ye will not hearken unto me: but pollute ye my holy name no more with your gifts, and with your idols.
20936	822	40	For in mine holy mountain, in the mountain of the height of Israel, saith the Lord GOD, there shall all the house of Israel, all of them in the land, serve me: there will I accept them, and there will I require your offerings, and the firstfruits of your oblations, with all your holy things.
20937	822	41	I will accept you with your sweet savour, when I bring you out from the people, and gather you out of the countries wherein ye have been scattered; and I will be sanctified in you before the heathen.
20938	822	42	And ye shall know that I am the LORD, when I shall bring you into the land of Israel, into the country for the which I lifted up mine hand to give it to your fathers.
20939	822	43	And there shall ye remember your ways, and all your doings, wherein ye have been defiled; and ye shall lothe yourselves in your own sight for all your evils that ye have committed.
20940	822	44	And ye shall know that I am the LORD, when I have wrought with you for my name's sake, not according to your wicked ways, nor according to your corrupt doings, O ye house of Israel, saith the Lord GOD.
20941	822	45	Moreover the word of the LORD came unto me, saying,
20942	822	46	Son of man, set thy face toward the south, and drop thy word toward the south, and prophesy against the forest of the south field;
20943	822	47	And say to the forest of the south, Hear the word of the LORD; Thus saith the Lord GOD; Behold, I will kindle a fire in thee, and it shall devour every green tree in thee, and every dry tree: the flaming flame shall not be quenched, and all faces from the south to the north shall be burned therein.
20944	822	48	And all flesh shall see that I the LORD have kindled it: it shall not be quenched.
20945	822	49	Then said I, Ah Lord GOD! they say of me, Doth he not speak parables?
20946	823	1	AND the word of the LORD came unto me, saying,
20947	823	2	Son of man, set thy face toward Jerusalem, and drop thy word toward the holy places, and prophesy against the land of Israel,
20948	823	3	And say to the land of Israel, Thus saith the LORD; Behold, I am against thee, and will draw forth my sword out of his sheath, and will cut off from thee the righteous and the wicked.
20949	823	4	Seeing then that I will cut off from thee the righteous and the wicked, therefore shall my sword go forth out of his sheath against all flesh from the south to the north:
20950	823	5	That all flesh may know that I the LORD have drawn forth my sword out of his sheath: it shall not return any more.
20951	823	6	Sigh therefore, thou son of man, with the breaking of thy loins; and with bitterness sigh before their eyes.
20952	823	7	And it shall be, when they say unto thee, Wherefore sighest thou? that thou shalt answer, For the tidings; because it cometh: and every heart shall melt, and all hands shall be feeble, and every spirit shall faint, and all knees shall be weak as water: behold, it cometh, and shall be brought to pass, saith the Lord GOD.
20953	823	8	Again the word of the LORD came unto me, saying,
20954	823	9	Son of man, prophesy, and say, Thus saith the LORD; Say, A sword, a sword is sharpened, and also furbished:
20955	823	10	It is sharpened to make a sore slaughter; it is furbished that it may glitter: should we then make mirth? it contemneth the rod of my son, as every tree.
20956	823	11	And he hath given it to be furbished, that it may be handled: this sword is sharpened, and it is furbished, to give it into the hand of the slayer.
20957	823	12	Cry and howl, son of man: for it shall be upon my people, it shall be upon all the princes of Israel: terrors by reason of the sword shall be upon my people: smite therefore upon thy thigh.
20958	823	13	Because it is a trial, and what if the sword contemn even the rod? it shall be no more, saith the Lord GOD.
20959	823	14	Thou therefore, son of man, prophesy, and smite thine hands together, and let the sword be doubled the third time, the sword of the slain: it is the sword of the great men that are slain, which entereth into their privy chambers.
20960	823	15	I have set the point of the sword against all their gates, that their heart may faint, and their ruins be multiplied: ah! it is made bright, it is wrapped up for the slaughter.
20961	823	16	Go thee one way or other, either on the right hand, or on the left, whithersoever thy face is set.
20962	823	17	I will also smite mine hands together, and I will cause my fury to rest: I the LORD have said it.
20963	823	18	The word of the LORD came unto me again, saying,
20964	823	19	Also, thou son of man, appoint thee two ways, that the sword of the king of Babylon may come: both twain shall come forth out of one land: and choose thou a place, choose it at the head of the way to the city.
20965	823	20	Appoint a way, that the sword may come to Rabbath of the Ammonites, and to Judah in Jerusalem the defenced.
20966	823	21	For the king of Babylon stood at the parting of the way, at the head of the two ways, to use divination: he made his arrows bright, he consulted with images, he looked in the liver.
20967	823	22	At his right hand was the divination for Jerusalem, to appoint captains, to open the mouth in the slaughter, to lift up the voice with shouting, to appoint battering rams against the gates, to cast a mount, and to build a fort.
20968	823	23	And it shall be unto them as a false divination in their sight, to them that have sworn oaths: but he will call to remembrance the iniquity, that they may be taken.
20969	823	24	Therefore thus saith the Lord GOD; Because ye have made your iniquity to be remembered, in that your transgressions are discovered, so that in all your doings your sins do appear; because, I say, that ye are come to remembrance, ye shall be taken with the hand.
20970	823	25	And thou, profane wicked prince of Israel, whose day is come, when iniquity shall have an end,
20971	823	26	Thus saith the Lord GOD; Remove the diadem, and take off the crown: this shall not be the same: exalt him that is low, and abase him that is high.
20972	823	27	I will overturn, overturn, overturn, it: and it shall be no more, until he come whose right it is; and I will give it him.
20973	823	28	And thou, son of man, prophesy and say, Thus saith the Lord GOD concerning the Ammonites, and concerning their reproach; even say thou, The sword, the sword is drawn: for the slaughter it is furbished, to consume because of the glittering:
20974	823	29	Whiles they see vanity unto thee, whiles they divine a lie unto thee, to bring thee upon the necks of them that are slain, of the wicked, whose day is come, when their iniquity shall have an end.
20975	823	30	Shall I cause it to return into his sheath? I will judge thee in the place where thou wast created, in the land of thy nativity.
20976	823	31	And I will pour out mine indignation upon thee, I will blow against thee in the fire of my wrath, and deliver thee into the hand of brutish men, and skilful to destroy.
20977	823	32	Thou shalt be for fuel to the fire; thy blood shall be in the midst of the land; thou shalt be no more remembered: for I the LORD have spoken it.
20978	824	1	MOREOVER the word of the LORD came unto me, saying,
20979	824	2	Now, thou son of man, wilt thou judge, wilt thou judge the bloody city? yea, thou shalt shew her all her abominations.
20980	824	3	Then say thou, Thus saith the Lord GOD, The city sheddeth blood in the midst of it, that her time may come, and maketh idols against herself to defile herself.
20981	824	4	Thou art become guilty in thy blood that thou hast shed; and hast defiled thyself in thine idols which thou hast made; and thou hast caused thy days to draw near, and art come even unto thy years: therefore have I made thee a reproach unto the heathen, and a mocking to all countries.
20982	824	5	Those that be near, and those that be far from thee, shall mock thee, which art infamous and much vexed.
20983	824	6	Behold, the princes of Israel, every one were in thee to their power to shed blood.
20984	824	7	In thee have they set light by father and mother: in the midst of thee have they dealt by oppression with the stranger: in thee have they vexed the fatherless and the widow.
20985	824	8	Thou hast despised mine holy things, and hast profaned my sabbaths.
20986	824	9	In thee are men that carry tales to shed blood: and in thee they eat upon the mountains: in the midst of thee they commit lewdness.
20987	824	10	In thee have they discovered their fathers' nakedness: in thee have they humbled her that was set apart for pollution.
20988	824	11	And one hath committed abomination with his neighbour's wife; and another hath lewdly defiled his daughter in law; and another in thee hath humbled his sister, his father's daughter.
20989	824	12	In thee have they taken gifts to shed blood; thou hast taken usury and increase, and thou hast greedily gained of thy neighbours by extortion, and hast forgotten me, saith the Lord GOD.
20990	824	13	Behold, therefore I have smitten mine hand at thy dishonest gain which thou hast made, and at thy blood which hath been in the midst of thee.
20991	824	14	Can thine heart endure, or can thine hands be strong, in the days that I shall deal with thee? I the LORD have spoken it, and will do it.
20992	824	15	And I will scatter thee among the heathen, and disperse thee in the countries, and will consume thy filthiness out of thee.
20993	824	16	And thou shalt take thine inheritance in thyself in the sight of the heathen, and thou shalt know that I am the LORD.
20994	824	17	And the word of the LORD came unto me, saying,
20995	824	18	Son of man, the house of Israel is to me become dross: all they are brass, and tin, and iron, and lead, in the midst of the furnace; they are even the dross of silver.
20996	824	19	Therefore thus saith the Lord GOD; Because ye are all become dross, behold, therefore I will gather you into the midst of Jerusalem.
20997	824	20	As they gather silver, and brass, and iron, and lead, and tin, into the midst of the furnace, to blow the fire upon it, to melt it; so will I gather you in mine anger and in my fury, and I will leave you there, and melt you.
20998	824	21	Yea, I will gather you, and blow upon you in the fire of my wrath, and ye shall be melted in the midst thereof.
20999	824	22	As silver is melted in the midst of the furnace, so shall ye be melted in the midst thereof; and ye shall know that I the LORD have poured out my fury upon you.
21000	824	23	And the word of the LORD came unto me, saying,
21001	824	24	Son of man, say unto her, Thou art the land that is not cleansed, nor rained upon in the day of indignation.
21002	824	25	There is a conspiracy of her prophets in the midst thereof, like a roaring lion ravening the prey; they have devoured souls; they have taken the treasure and precious things; they have made her many widows in the midst thereof.
21003	824	26	Her priests have violated my law, and have profaned mine holy things: they have put no difference between the holy and profane, neither have they shewed difference between the unclean and the clean, and have hid their eyes from my sabbaths, and I am profaned among them.
21004	824	27	Her princes in the midst thereof are like wolves ravening the prey, to shed blood, and to destroy souls, to get dishonest gain.
21005	824	28	And her prophets have daubed them with untempered morter, seeing vanity, and divining lies unto them, saying, Thus saith the Lord GOD, when the LORD hath not spoken.
21006	824	29	The people of the land have used oppression, and exercised robbery, and have vexed the poor and needy: yea, they have oppressed the stranger wrongfully.
21007	824	30	And I sought for a man among them, that should make up the hedge, and stand in the gap before me for the land, that I should not destroy it: but I found none.
21008	824	31	Therefore have I poured out mine indignation upon them; I have consumed them with the fire of my wrath: their own way have I recompensed upon their heads, saith the Lord GOD.
21009	825	1	THE word of the LORD came again unto me, saying,
21010	825	2	Son of man, there were two women, the daughters of one mother:
21011	825	3	And they committed whoredoms in Egypt; they committed whoredoms in their youth: there were their breasts pressed, and there they bruised the teats of their virginity.
21012	825	4	And the names of them were Aholah the elder, and Aholibah her sister: and they were mine, and they bare sons and daughters. Thus were their names; Samaria is Aholah, and Jerusalem Aholibah.
21013	825	5	And Aholah played the harlot when she was mine; and she doted on her lovers, on the Assyrians her neighbours,
21014	825	6	Which were clothed with blue, captains and rulers, all of them desirable young men, horsemen riding upon horses.
21015	825	7	Thus she committed her whoredoms with them, with all them that were the chosen men of Assyria, and with all on whom she doted: with all their idols she defiled herself.
21016	825	8	Neither left she her whoredoms brought from Egypt: for in her youth they lay with her, and they bruised the breasts of her virginity, and poured their whoredom upon her.
21017	825	9	Wherefore I have delivered her into the hand of her lovers, into the hand of the Assyrians, upon whom she doted.
21018	825	10	These discovered her nakedness: they took her sons and her daughters, and slew her with the sword: and she became famous among women; for they had executed judgment upon her.
21019	825	11	And when her sister Aholibah saw this, she was more corrupt in her inordinate love than she, and in her whoredoms more than her sister in her whoredoms.
21020	825	12	She doted upon the Assyrians her neighbours, captains and rulers clothed most gorgeously, horsemen riding upon horses, all of them desirable young men.
21021	825	13	Then I saw that she was defiled, that they took both one way,
21022	825	14	And that she increased her whoredoms: for when she saw men pourtrayed upon the wall, the images of the Chaldeans pourtrayed with vermilion,
21023	825	15	Girded with girdles upon their loins, exceeding in dyed attire upon their heads, all of them princes to look to, after the manner of the Babylonians of Chaldea, the land of their nativity:
21024	825	16	And as soon as she saw them with her eyes, she doted upon them, and sent messengers unto them into Chaldea.
21025	825	17	And the Babylonians came to her into the bed of love, and they defiled her with their whoredom, and she was polluted with them, and her mind was alienated from them.
21026	825	18	So she discovered her whoredoms, and discovered her nakedness: then my mind was alienated from her, like as my mind was alienated from her sister.
21027	825	19	Yet she multiplied her whoredoms, in calling to remembrance the days of her youth, wherein she had played the harlot in the land of Egypt.
21028	825	20	For she doted upon their paramours, whose flesh is as the flesh of asses, and whose issue is like the issue of horses.
21029	825	21	Thus thou calledst to remembrance the lewdness of thy youth, in bruising thy teats by the Egyptians for the paps of thy youth.
21030	825	22	Therefore, O Aholibah, thus saith the Lord GOD; Behold, I will raise up thy lovers against thee, from whom thy mind is alienated, and I will bring them against thee on every side;
21031	825	23	The Babylonians, and all the Chaldeans, Pekod, and Shoa, and Koa, and all the Assyrians with them: all of them desirable young men, captains and rulers, great lords and renowned, all of them riding upon horses.
21032	825	24	And they shall come against thee with chariots, wagons, and wheels, and with an assembly of people, which shall set against thee buckler and shield and helmet round about: and I will set judgment before them, and they shall judge thee according to their judgments.
21033	825	25	And I will set my jealousy against thee, and they shall deal furiously with thee: they shall take away thy nose and thine ears; and thy remnant shall fall by the sword: they shall take thy sons and thy daughters; and thy residue shall be devoured by the fire.
21034	825	26	They shall also strip thee out of thy clothes, and take away thy fair jewels.
21035	825	27	Thus will I make thy lewdness to cease from thee, and thy whoredom brought from the land of Egypt: so that thou shalt not lift up thine eyes unto them, nor remember Egypt any more.
21036	825	28	For thus saith the Lord GOD; Behold, I will deliver thee into the hand of them whom thou hatest, into the hand of them from whom thy mind is alienated:
21037	825	29	And they shall deal with thee hatefully, and shall take away all thy labour, and shall leave thee naked and bare: and the nakedness of thy whoredoms shall be discovered, both thy lewdness and thy whoredoms.
21038	825	30	I will do these things unto thee, because thou hast gone a whoring after the heathen, and because thou art polluted with their idols.
21039	825	31	Thou hast walked in the way of thy sister; therefore will I give her cup into thine hand.
21040	825	32	Thus saith the Lord GOD; Thou shalt drink of thy sister's cup deep and large: thou shalt be laughed to scorn and had in derision; it containeth much.
21041	825	33	Thou shalt be filled with drunkenness and sorrow, with the cup of astonishment and desolation, with the cup of thy sister Samaria.
21042	825	34	Thou shalt even drink it and suck it out, and thou shalt break the sherds thereof, and pluck off thine own breasts: for I have spoken it, saith the Lord GOD.
21043	825	35	Therefore thus saith the Lord GOD; Because thou hast forgotten me, and cast me behind thy back, therefore bear thou also thy lewdness and thy whoredoms.
21044	825	36	The LORD said moreover unto me; Son of man, wilt thou judge Aholah and Aholibah? yea, declare unto them their abominations;
21045	825	37	That they have committed adultery, and blood is in their hands, and with their idols have they committed adultery, and have also caused their sons, whom they bare unto me, to pass for them through the fire, to devour them.
21046	825	38	Moreover this they have done unto me: they have defiled my sanctuary in the same day, and have profaned my sabbaths.
21047	825	39	For when they had slain their children to their idols, then they came the same day into my sanctuary to profane it; and, lo, thus have they done in the midst of mine house.
21048	825	40	And furthermore, that ye have sent for men to come from far, unto whom a messenger was sent; and, lo, they came: for whom thou didst wash thyself, paintedst thy eyes, and deckedst thyself with ornaments,
21049	825	41	And satest upon a stately bed, and a table prepared before it, whereupon thou hast set mine incense and mine oil.
21050	825	42	And a voice of a multitude being at ease was with her: and with the men of the common sort were brought Sabeans from the wilderness, which put bracelets upon their hands, and beautiful crowns upon their heads.
21051	825	43	Then said I unto her that was old in adulteries, Will they now commit whoredoms with her, and she with them?
21052	825	44	Yet they went in unto her, as they go in unto a woman that playeth the harlot: so went they in unto Aholah and unto Aholibah, the lewd women.
21053	825	45	And the righteous men, they shall judge them after the manner of adulteresses, and after the manner of women that shed blood; because they are adulteresses, and blood is in their hands.
21054	825	46	For thus saith the Lord GOD; I will bring up a company upon them, and will give them to be removed and spoiled.
21055	825	47	And the company shall stone them with stones, and dispatch them with their swords; they shall slay their sons and their daughters, and burn up their houses with fire.
21056	825	48	Thus will I cause lewdness to cease out of the land, that all women may be taught not to do after your lewdness.
21057	825	49	And they shall recompense your lewdness upon you, and ye shall bear the sins of your idols: and ye shall know that I am the Lord GOD.
21058	826	1	AGAIN in the ninth year, in the tenth month, in the tenth day of the month, the word of the LORD came unto me, saying,
21059	826	2	Son of man, write thee the name of the day, even of this same day: the king of Babylon set himself against Jerusalem this same day.
21060	826	3	And utter a parable unto the rebellious house, and say unto them, Thus saith the Lord GOD; Set on a pot, set it on, and also pour water into it:
21061	826	4	Gather the pieces thereof into it, even every good piece, the thigh, and the shoulder; fill it with the choice bones.
21062	826	5	Take the choice of the flock, and burn also the bones under it, and make it boil well, and let them seethe the bones of it therein.
21063	826	6	Wherefore thus saith the Lord GOD; Woe to the bloody city, to the pot whose scum is therein, and whose scum is not gone out of it! bring it out piece by piece; let no lot fall upon it.
21064	826	7	For her blood is in the midst of her; she set it upon the top of a rock; she poured it not upon the ground, to cover it with dust;
21065	826	8	That it might cause fury to come up to take vengeance; I have set her blood upon the top of a rock, that it should not be covered.
21066	826	9	Therefore thus saith the Lord GOD; Woe to the bloody city! I will even make the pile for fire great.
21067	826	10	Heap on wood, kindle the fire, consume the flesh, and spice it well, and let the bones be burned.
21068	826	11	Then set it empty upon the coals thereof, that the brass of it may be hot, and may burn, and that the filthiness of it may be molten in it, that the scum of it may be consumed.
21069	826	12	She hath wearied herself with lies, and her great scum went not forth out of her: her scum shall be in the fire.
21070	826	13	In thy filthiness is lewdness: because I have purged thee, and thou wast not purged, thou shalt not be purged from thy filthiness any more, till I have caused my fury to rest upon thee.
21071	826	14	I the LORD have spoken it: it shall come to pass, and I will do it; I will not go back, neither will I spare, neither will I repent; according to thy ways, and according to thy doings, shall they judge thee, saith the Lord GOD.
21072	826	15	Also the word of the LORD came unto me, saying,
21073	826	16	Son of man, behold, I take away from thee the desire of thine eyes with a stroke: yet neither shalt thou mourn nor weep, neither shall thy tears run down.
21074	826	17	Forbear to cry, make no mourning for the dead, bind the tire of thine head upon thee, and put on thy shoes upon thy feet, and cover not thy lips, and eat not the bread of men.
21075	826	18	So I spake unto the people in the morning: and at even my wife died; and I did in the morning as I was commanded.
21076	826	19	And the people said unto me, Wilt thou not tell us what these things are to us, that thou doest so?
21077	826	20	Then I answered them, The word of the LORD came unto me, saying,
21078	826	21	Speak unto the house of Israel, Thus saith the Lord GOD; Behold, I will profane my sanctuary, the excellency of your strength, the desire of your eyes, and that which your soul pitieth; and your sons and your daughters whom ye have left shall fall by the sword.
21079	826	22	And ye shall do as I have done: ye shall not cover your lips, nor eat the bread of men.
21080	826	23	And your tires shall be upon your heads, and your shoes upon your feet: ye shall not mourn nor weep; but ye shall pine away for your iniquities, and mourn one toward another.
21081	826	24	Thus Ezekiel is unto you a sign: according to all that he hath done shall ye do: and when this cometh, ye shall know that I am the Lord GOD.
21082	826	25	Also, thou son of man, shall it not be in the day when I take from them their strength, the joy of their glory, the desire of their eyes, and that whereupon they set their minds, their sons and their daughters,
21083	826	26	That he that escapeth in that day shall come unto thee, to cause thee to hear it with thine ears?
21084	826	27	In that day shall thy mouth be opened to him which is escaped, and thou shalt speak, and be no more dumb: and thou shalt be a sign unto them; and they shall know that I am the LORD.
21085	827	1	THE word of the LORD came again unto me, saying,
21086	827	2	Son of man, set thy face against the Ammonites, and prophesy against them;
21087	827	3	And say unto the Ammonites, Hear the word of the Lord GOD; Thus saith the Lord GOD; Because thou saidst, Aha, against my sanctuary, when it was profaned; and against the land of Israel, when it was desolate; and against the house of Judah, when they went into captivity;
21088	827	4	Behold, therefore I will deliver thee to the men of the east for a possession, and they shall set their palaces in thee, and make their dwellings in thee: they shall eat thy fruit, and they shall drink thy milk.
21089	827	5	And I will make Rabbah a stable for camels, and the Ammonites a couchingplace for flocks: and ye shall know that I am the LORD.
21090	827	6	For thus saith the Lord GOD; Because thou hast clapped thine hands, and stamped with the feet, and rejoiced in heart with all thy despite against the land of Israel;
21091	827	7	Behold, therefore I will stretch out mine hand upon thee, and will deliver thee for a spoil to the heathen; and I will cut thee off from the people, and I will cause thee to perish out of the countries: I will destroy thee; and thou shalt know that I am the LORD.
21092	827	8	Thus saith the Lord GOD; Because that Moab and Seir do say, Behold, the house of Judah is like unto all the heathen;
21093	827	9	Therefore, behold, I will open the side of Moab from the cities, from his cities which are on his frontiers, the glory of the country, Beth-jeshimoth, Baal-meon, and Kiriathaim,
21094	827	10	Unto the men of the east with the Ammonites, and will give them in possession, that the Ammonites may not be remembered among the nations.
21095	827	11	And I will execute judgments upon Moab; and they shall know that I am the LORD.
21096	827	12	Thus saith the Lord GOD; Because that Edom hath dealt against the house of Judah by taking vengeance, and hath greatly offended, and revenged himself upon them;
21097	827	13	Therefore thus saith the Lord GOD; I will also stretch out mine hand upon Edom, and will cut off man and beast from it; and I will make it desolate from Teman; and they of Dedan shall fall by the sword.
21098	827	14	And I will lay my vengeance upon Edom by the hand of my people Israel: and they shall do in Edom according to mine anger and according to my fury; and they shall know my vengeance, saith the Lord GOD.
21099	827	15	Thus saith the Lord GOD; Because the Philistines have dealt by revenge, and have taken vengeance with a despiteful heart, to destroy it for the old hatred;
21100	827	16	Therefore thus saith the Lord GOD; Behold, I will stretch out mine hand upon the Philistines, and I will cut off the Cherethims, and destroy the remnant of the sea coast.
21101	827	17	And I will execute great vengeance upon them with furious rebukes; and they shall know that I am the LORD, when I shall lay my vengeance upon them.
21102	828	1	AND it came to pass in the eleventh year, in the first day of the month, that the word of the LORD came unto me, saying,
21103	828	2	Son of man, because that Tyrus hath said against Jerusalem, Aha, she is broken that was the gates of the people: she is turned unto me: I shall be replenished, now she is laid waste:
21104	828	3	Therefore thus saith the Lord GOD; Behold, I am against thee, O Tyrus, and will cause many nations to come up against thee, as the sea causeth his waves to come up.
21105	828	4	And they shall destroy the walls of Tyrus, and break down her towers: I will also scrape her dust from her, and make her like the top of a rock.
21106	828	5	It shall be a place for the spreading of nets in the midst of the sea: for I have spoken it, saith the Lord GOD: and it shall become a spoil to the nations.
21107	828	6	And her daughters which are in the field shall be slain by the sword; and they shall know that I am the LORD.
21108	828	7	For thus saith the Lord GOD; Behold, I will bring upon Tyrus Nebuchadrezzar king of Babylon, a king of kings, from the north, with horses, and with chariots, and with horsemen, and companies, and much people.
21109	828	8	He shall slay with the sword thy daughters in the field: and he shall make a fort against thee, and cast a mount against thee, and lift up the buckler against thee.
21110	828	9	And he shall set engines of war against thy walls, and with his axes he shall break down thy towers.
21111	828	10	By reason of the abundance of his horses their dust shall cover thee: thy walls shall shake at the noise of the horsemen, and of the wheels, and of the chariots, when he shall enter into thy gates, as men enter into a city wherein is made a breach.
21112	828	11	With the hoofs of his horses shall he tread down all thy streets: he shall slay thy people by the sword, and thy strong garrisons shall go down to the ground.
21113	828	12	And they shall make a spoil of thy riches, and make a prey of thy merchandise: and they shall break down thy walls, and destroy thy pleasant houses: and they shall lay thy stones and thy timber and thy dust in the midst of the water.
21114	828	13	And I will cause the noise of thy songs to cease; and the sound of thy harps shall be no more heard.
21115	828	14	And I will make thee like the top of a rock: thou shalt be a place to spread nets upon; thou shalt be built no more: for I the LORD have spoken it, saith the Lord GOD.
21116	828	15	Thus saith the Lord GOD to Tyrus; Shall not the isles shake at the sound of thy fall, when the wounded cry, when the slaughter is made in the midst of thee?
21117	828	16	Then all the princes of the sea shall come down from their thrones, and lay away their robes, and put off their broidered garments: they shall clothe themselves with trembling; they shall sit upon the ground, and shall tremble at every moment, and be astonished at thee.
21118	828	17	And they shall take up a lamentation for thee, and say to thee, How art thou destroyed, that wast inhabited of seafaring men, the renowned city, which wast strong in the sea, she and her inhabitants, which cause their terror to be on all that haunt it!
21119	828	18	Now shall the isles tremble in the day of thy fall; yea, the isles that are in the sea shall be troubled at thy departure.
21120	828	19	For thus saith the Lord GOD; When I shall make thee a desolate city, like the cities that are not inhabited; when I shall bring up the deep upon thee, and great waters shall cover thee;
21121	828	20	When I shall bring thee down with them that descend into the pit, with the people of old time, and shall set thee in the low parts of the earth, in places desolate of old, with them that go down to the pit, that thou be not inhabited; and I shall set glory in the land of the living;
21122	828	21	I will make thee a terror, and thou shalt be no more: though thou be sought for, yet shalt thou never be found again, saith the Lord GOD.
21123	829	1	THE word of the LORD came again unto me, saying,
21124	829	2	Now, thou son of man, take up a lamentation for Tyrus;
21125	829	3	And say unto Tyrus, O thou that art situate at the entry of the sea, which art a merchant of the people for many isles, Thus saith the Lord GOD; O Tyrus, thou hast said, I am of perfect beauty.
21126	829	4	Thy borders are in the midst of the seas, thy builders have perfected thy beauty.
21127	829	5	They have made all thy ship boards of fir trees of Senir: they have taken cedars from Lebanon to make masts for thee.
21128	829	6	Of the oaks of Bashan have they made thine oars; the company of the Ashurites have made thy benches of ivory, brought out of the isles of Chittim.
21129	829	7	Fine linen with broidered work from Egypt was that which thou spreadest forth to be thy sail; blue and purple from the isles of Elishah was that which covered thee.
21130	829	8	The inhabitants of Zidon and Arvad were thy mariners: thy wise men, O Tyrus, that were in thee, were thy pilots.
21131	829	9	The ancients of Gebal and the wise men thereof were in thee thy calkers: all the ships of the sea with their mariners were in thee to occupy thy merchandise.
21132	829	10	They of Persia and of Lud and of Phut were in thine army, thy men of war: they hanged the shield and helmet in thee; they set forth thy comeliness.
21133	829	11	The men of Arvad with thine army were upon thy walls round about, and the Gammadims were in thy towers: they hanged their shields upon thy walls round about; they have made thy beauty perfect.
21134	829	12	Tarshish was thy merchant by reason of the multitude of all kind of riches; with silver, iron, tin, and lead, they traded in thy fairs.
21135	829	13	Javan, Tubal, and Meshech, they were thy merchants: they traded the persons of men and vessels of brass in thy market.
21136	829	14	They of the house of Togarmah traded in thy fairs with horses and horsemen and mules.
21137	829	15	The men of Dedan were thy merchants; many isles were the merchandise of thine hand: they brought thee for a present horns of ivory and ebony.
21138	829	16	Syria was thy merchant by reason of the multitude of the wares of thy making: they occupied in thy fairs with emeralds, purple, and broidered work, and fine linen, and coral, and agate.
21139	829	17	Judah, and the land of Israel, they were thy merchants: they traded in thy market wheat of Minnith, and Pannag, and honey, and oil, and balm.
21140	829	18	Damascus was thy merchant in the multitude of the wares of thy making, for the multitude of all riches; in the wine of Helbon, and white wool.
21141	829	19	Dan also and Javan going to and fro occupied in thy fairs: bright iron, cassia, and calamus, were in thy market.
21142	829	20	Dedan was thy merchant in precious clothes for chariots.
21143	829	21	Arabia, and all the princes of Kedar, they occupied with thee in lambs, and rams, and goats: in these were they thy merchants.
21144	829	22	The merchants of Sheba and Raamah, they were thy merchants: they occupied in thy fairs with chief of all spices, and with all precious stones, and gold.
21145	829	23	Haran, and Canneh, and Eden, the merchants of Sheba, Asshur, and Chilmad, were thy merchants.
21146	829	24	These were thy merchants in all sorts of things, in blue clothes, and broidered work, and in chests of rich apparel, bound with cords, and made of cedar, among thy merchandise.
21147	829	25	The ships of Tarshish did sing of thee in thy market: and thou wast replenished, and made very glorious in the midst of the seas.
21148	829	26	Thy rowers have brought thee into great waters: the east wind hath broken thee in the midst of the seas.
21149	829	27	Thy riches, and thy fairs, thy merchandise, thy mariners, and thy pilots, thy calkers, and the occupiers of thy merchandise, and all thy men of war, that are in thee, and in all thy company which is in the midst of thee, shall fall into the midst of the seas in the day of thy ruin.
21150	829	28	The suburbs shall shake at the sound of the cry of thy pilots.
21151	829	29	And all that handle the oar, the mariners, and all the pilots of the sea, shall come down from their ships, they shall stand upon the land;
21152	829	30	And shall cause their voice to be heard against thee, and shall cry bitterly, and shall cast up dust upon their heads, they shall wallow themselves in the ashes:
21153	829	31	And they shall make themselves utterly bald for thee, and gird them with sackcloth, and they shall weep for thee with bitterness of heart and bitter wailing.
21154	829	32	And in their wailing they shall take up a lamentation for thee, and lament over thee, saying, What city is like Tyrus, like the destroyed in the midst of the sea?
21155	829	33	When thy wares went forth out of the seas, thou filledst many people; thou didst enrich the kings of the earth with the multitude of thy riches and of thy merchandise.
21156	829	34	In the time when thou shalt be broken by the seas in the depths of the waters thy merchandise and all thy company in the midst of thee shall fall.
21157	829	35	All the inhabitants of the isles shall be astonished at thee, and their kings shall be sore afraid, they shall be troubled in their countenance.
21158	829	36	The merchants among the people shall hiss at thee; thou shalt be a terror, and never shalt be any more.
21159	830	1	THE word of the LORD came again unto me, saying,
21160	830	2	Son of man, say unto the prince of Tyrus, Thus saith the Lord GOD; Because thine heart is lifted up, and thou hast said, I am a God, I sit in the seat of God, in the midst of the seas; yet thou art a man, and not God, though thou set thine heart as the heart of God:
21161	830	3	Behold, thou art wiser than Daniel; there is no secret that they can hide from thee:
21162	830	4	With thy wisdom and with thine understanding thou hast gotten thee riches, and hast gotten gold and silver into thy treasures:
21163	830	5	By thy great wisdom and by thy traffick hast thou increased thy riches, and thine heart is lifted up because of thy riches:
21164	830	6	Therefore thus saith the Lord GOD; Because thou hast set thine heart as the heart of God;
21165	830	7	Behold, therefore I will bring strangers upon thee, the terrible of the nations: and they shall draw their swords against the beauty of thy wisdom, and they shall defile thy brightness.
21166	830	8	They shall bring thee down to the pit, and thou shalt die the deaths of them that are slain in the midst of the seas.
21167	830	9	Wilt thou yet say before him that slayeth thee, I am God? but thou shalt be a man, and no God, in the hand of him that slayeth thee.
21168	830	10	Thou shalt die the deaths of the uncircumcised by the hand of strangers: for I have spoken it, saith the Lord GOD.
21169	830	11	Moreover the word of the LORD came unto me, saying,
21170	830	12	Son of man, take up a lamentation upon the king of Tyrus, and say unto him, Thus saith the Lord GOD; Thou sealest up the sum, full of wisdom, and perfect in beauty.
21171	830	13	Thou hast been in Eden the garden of God; every precious stone was thy covering, the sardius, topaz, and the diamond, the beryl, the onyx, and the jasper, the sapphire, the emerald, and the carbuncle, and gold: the workmanship of thy tabrets and of thy pipes was prepared in thee in the day that thou wast created.
21172	830	14	Thou art the anointed cherub that covereth; and I have set thee so: thou wast upon the holy mountain of God; thou hast walked up and down in the midst of the stones of fire.
21173	830	15	Thou wast perfect in thy ways from the day that thou wast created, till iniquity was found in thee.
21174	830	16	By the multitude of thy merchandise they have filled the midst of thee with violence, and thou hast sinned: therefore I will cast thee as profane out of the mountain of God: and I will destroy thee, O covering cherub, from the midst of the stones of fire.
21175	830	17	Thine heart was lifted up because of thy beauty, thou hast corrupted thy wisdom by reason of thy brightness: I will cast thee to the ground, I will lay thee before kings, that they may behold thee.
21176	830	18	Thou hast defiled thy sanctuaries by the multitude of thine iniquities, by the iniquity of thy traffick; therefore will I bring forth a fire from the midst of thee, it shall devour thee, and I will bring thee to ashes upon the earth in the sight of all them that behold thee.
21177	830	19	All they that know thee among the people shall be astonished at thee: thou shalt be a terror, and never shalt thou be any more.
21178	830	20	Again the word of the LORD came unto me, saying,
21179	830	21	Son of man, set thy face against Zidon, and prophesy against it,
21180	830	22	And say, Thus saith the Lord GOD; Behold, I am against thee, O Zidon; and I will be glorified in the midst of thee: and they shall know that I am the LORD, when I shall have executed judgments in her, and shall be sanctified in her.
21181	830	23	For I will send into her pestilence, and blood into her streets; and the wounded shall be judged in the midst of her by the sword upon her on every side; and they shall know that I am the LORD.
21182	830	24	And there shall be no more a pricking brier unto the house of Israel, nor any grieving thorn of all that are round about them, that despised them; and they shall know that I am the Lord GOD.
21183	830	25	Thus saith the Lord GOD; When I shall have gathered the house of Israel from the people among whom they are scattered, and shall be sanctified in them in the sight of the heathen, then shall they dwell in their land that I have given to my servant Jacob.
21184	830	26	And they shall dwell safely therein, and shall build houses, and plant vineyards; yea, they shall dwell with confidence, when I have executed judgments upon all those that despise them round about them; and they shall know that I am the LORD their God.
21185	831	1	IN the tenth year, in the tenth month, in the twelfth day of the month, the word of the LORD came unto me, saying,
21186	831	2	Son of man, set thy face against Pharaoh king of Egypt, and prophesy against him, and against all Egypt:
21187	831	3	Speak, and say, Thus saith the Lord GOD; Behold, I am against thee, Pharaoh king of Egypt, the great dragon that lieth in the midst of his rivers, which hath said, My river is mine own, and I have made it for myself.
21188	831	4	But I will put hooks in thy jaws, and I will cause the fish of thy rivers to stick unto thy scales, and I will bring thee up out of the midst of thy rivers, and all the fish of thy rivers shall stick unto thy scales.
21189	831	5	And I will leave thee thrown into the wilderness, thee and all the fish of thy rivers: thou shalt fall upon the open fields; thou shalt not be brought together, nor gathered: I have given thee for meat to the beasts of the field and to the fowls of the heaven.
21190	831	6	And all the inhabitants of Egypt shall know that I am the LORD, because they have been a staff of reed to the house of Israel.
21191	831	7	When they took hold of thee by thy hand, thou didst break, and rend all their shoulder: and when they leaned upon thee, thou brakest, and madest all their loins to be at a stand.
21192	831	8	Therefore thus saith the Lord GOD; Behold, I will bring a sword upon thee, and cut off man and beast out of thee.
21193	831	9	And the land of Egypt shall be desolate and waste; and they shall know that I am the LORD: because he hath said, The river is mine, and I have made it.
21194	831	10	Behold, therefore I am against thee, and against thy rivers, and I will make the land of Egypt utterly waste and desolate, from the tower of Syene even unto the border of Ethiopia.
21195	831	11	No foot of man shall pass through it, nor foot of beast shall pass through it, neither shall it be inhabited forty years.
21196	831	12	And I will make the land of Egypt desolate in the midst of the countries that are desolate, and her cities among the cities that are laid waste shall be desolate forty years: and I will scatter the Egyptians among the nations, and will disperse them through the countries.
21197	831	13	Yet thus saith the Lord GOD; At the end of forty years will I gather the Egyptians from the people whither they were scattered:
21198	831	14	And I will bring again the captivity of Egypt, and will cause them to return into the land of Pathros, into the land of their habitation; and they shall be there a base kingdom.
21199	831	15	It shall be the basest of the kingdoms; neither shall it exalt itself any more above the nations: for I will diminish them, that they shall no more rule over the nations.
21200	831	16	And it shall be no more the confidence of the house of Israel, which bringeth their iniquity to remembrance, when they shall look after them: but they shall know that I am the Lord GOD.
21201	831	17	And it came to pass in the seven and twentieth year, in the first month, in the first day of the month, the word of the LORD came unto me, saying,
21202	831	18	Son of man, Nebuchadrezzar king of Babylon caused his army to serve a great service against Tyrus: every head was made bald, and every shoulder was peeled: yet had he no wages, nor his army, for Tyrus, for the service that he had served against it:
21203	831	19	Therefore thus saith the Lord GOD; Behold, I will give the land of Egypt unto Nebuchadrezzar king of Babylon; and he shall take her multitude, and take her spoil, and take her prey; and it shall be the wages for his army.
21204	831	20	I have given him the land of Egypt for his labour wherewith he served against it, because they wrought for me, saith the Lord GOD.
21205	831	21	In that day will I cause the horn of the house of Israel to bud forth, and I will give thee the opening of the mouth in the midst of them; and they shall know that I am the LORD.
21206	832	1	THE word of the LORD came again unto me, saying,
21207	832	2	Son of man, prophesy and say, Thus saith the Lord GOD; Howl ye, Woe worth the day!
21208	832	3	For the day is near, even the day of the LORD is near, a cloudy day; it shall be the time of the heathen.
21209	832	4	And the sword shall come upon Egypt, and great pain shall be in Ethiopia, when the slain shall fall in Egypt, and they shall take away her multitude, and her foundations shall be broken down.
21210	832	5	Ethiopia, and Libya, and Lydia, and all the mingled people, and Chub, and the men of the land that is in league, shall fall with them by the sword.
21211	832	6	Thus saith the LORD; They also that uphold Egypt shall fall; and the pride of her power shall come down: from the tower of Syene shall they fall in it by the sword, saith the Lord GOD.
21212	832	7	And they shall be desolate in the midst of the countries that are desolate, and her cities shall be in the midst of the cities that are wasted.
21213	832	8	And they shall know that I am the LORD, when I have set a fire in Egypt, and when all her helpers shall be destroyed.
21214	832	9	In that day shall messengers go forth from me in ships to make the careless Ethiopians afraid, and great pain shall come upon them, as in the day of Egypt: for, lo, it cometh.
21215	832	10	Thus saith the Lord GOD; I will also make the multitude of Egypt to cease by the hand of Nebuchadrezzar king of Babylon.
21216	832	11	He and his people with him, the terrible of the nations, shall be brought to destroy the land: and they shall draw their swords against Egypt, and fill the land with the slain.
21217	832	12	And I will make the rivers dry, and sell the land into the hand of the wicked: and I will make the land waste, and all that is therein, by the hand of strangers: I the LORD have spoken it.
21218	832	13	Thus saith the Lord GOD; I will also destroy the idols, and I will cause their images to cease out of Noph; and there shall be no more a prince of the land of Egypt: and I will put a fear in the land of Egypt.
21219	832	14	And I will make Pathros desolate, and will set fire in Zoan, and will execute judgments in No.
21220	832	15	And I will pour my fury upon Sin, the strength of Egypt; and I will cut off the multitude of No.
21221	832	16	And I will set fire in Egypt: Sin shall have great pain, and No shall be rent asunder, and Noph shall have distresses daily.
21222	832	17	The young men of Aven and of Pi-beseth shall fall by the sword: and these cities shall go into captivity.
21223	832	18	At Tehaphnehes also the day shall be darkened, when I shall break there the yokes of Egypt: and the pomp of her strength shall cease in her: as for her, a cloud shall cover her, and her daughters shall go into captivity.
21224	832	19	Thus will I execute judgments in Egypt: and they shall know that I am the LORD.
21225	832	20	And it came to pass in the eleventh year, in the first month, in the seventh day of the month, that the word of the LORD came unto me, saying,
21226	832	21	Son of man, I have broken the arm of Pharaoh king of Egypt; and, lo, it shall not be bound up to be healed, to put a roller to bind it, to make it strong to hold the sword.
21227	832	22	Therefore thus saith the Lord GOD; Behold, I am against Pharaoh king of Egypt, and will break his arms, the strong, and that which was broken; and I will cause the sword to fall out of his hand.
21228	832	23	And I will scatter the Egyptians among the nations, and will disperse them through the countries.
21229	832	24	And I will strengthen the arms of the king of Babylon, and put my sword in his hand: but I will break Pharaoh's arms, and he shall groan before him with the groanings of a deadly wounded man.
21230	832	25	But I will strengthen the arms of the king of Babylon, and the arms of Pharaoh shall fall down; and they shall know that I am the LORD, when I shall put my sword into the hand of the king of Babylon, and he shall stretch it out upon the land of Egypt.
21231	832	26	And I will scatter the Egyptians among the nations, and disperse them among the countries; and they shall know that I am the LORD.
21232	833	1	AND it came to pass in the eleventh year, in the third month, in the first day of the month, that the word of the LORD came unto me, saying,
21233	833	2	Son of man, speak unto Pharaoh king of Egypt, and to his multitude; Whom art thou like in thy greatness?
21234	833	3	Behold, the Assyrian was a cedar in Lebanon with fair branches, and with a shadowing shroud, and of an high stature; and his top was among the thick boughs.
21235	833	4	The waters made him great, the deep set him up on high with her rivers running round about his plants, and sent out her little rivers unto all the trees of the field.
21236	833	5	Therefore his height was exalted above all the trees of the field, and his boughs were multiplied, and his branches became long because of the multitude of waters, when he shot forth.
21237	833	6	All the fowls of heaven made their nests in his boughs, and under his branches did all the beasts of the field bring forth their young, and under his shadow dwelt all great nations.
21238	833	7	Thus was he fair in his greatness, in the length of his branches: for his root was by great waters.
21239	833	8	The cedars in the garden of God could not hide him: the fir trees were not like his boughs, and the chesnut trees were not like his branches; nor any tree in the garden of God was like unto him in his beauty.
21240	833	9	I have made him fair by the multitude of his branches: so that all the trees of Eden, that were in the garden of God, envied him.
21241	833	10	Therefore thus saith the Lord GOD; Because thou hast lifted up thyself in height, and he hath shot up his top among the thick boughs, and his heart is lifted up in his height;
21242	833	11	I have therefore delivered him into the hand of the mighty one of the heathen; he shall surely deal with him: I have driven him out for his wickedness.
21243	833	12	And strangers, the terrible of the nations, have cut him off, and have left him: upon the mountains and in all the valleys his branches are fallen, and his boughs are broken by all the rivers of the land; and all the people of the earth are gone down from his shadow, and have left him.
21244	833	13	Upon his ruin shall all the fowls of the heaven remain, and all the beasts of the field shall be upon his branches:
21245	833	14	To the end that none of all the trees by the waters exalt themselves for their height, neither shoot up their top among the thick boughs, neither their trees stand up in their height, all that drink water: for they are all delivered unto death, to the nether parts of the earth, in the midst of the children of men, with them that go down to the pit.
21246	833	15	Thus saith the Lord GOD; In the day when he went down to the grave I caused a mourning: I covered the deep for him, and I restrained the floods thereof, and the great waters were stayed: and I caused Lebanon to mourn for him, and all the trees of the field fainted for him.
21247	833	16	I made the nations to shake at the sound of his fall, when I cast him down to hell with them that descend into the pit: and all the trees of Eden, the choice and best of Lebanon, all that drink water, shall be comforted in the nether parts of the earth.
21248	833	17	They also went down into hell with him unto them that be slain with the sword; and they that were his arm, that dwelt under his shadow in the midst of the heathen.
21249	833	18	To whom art thou thus like in glory and in greatness among the trees of Eden? yet shalt thou be brought down with the trees of Eden unto the nether parts of the earth: thou shalt lie in the midst of the uncircumcised with them that be slain by the sword. This is Pharaoh and all his multitude, saith the Lord GOD.
21250	834	1	AND it came to pass in the twelfth year, in the twelfth month, in the first day of the month, that the word of the LORD came unto me, saying,
21251	834	2	Son of man, take up a lamentation for Pharaoh king of Egypt, and say unto him, Thou art like a young lion of the nations, and thou art as a whale in the seas: and thou camest forth with thy rivers, and troubledst the waters with thy feet, and fouledst their rivers.
21252	834	3	Thus saith the Lord GOD; I will therefore spread out my net over thee with a company of many people; and they shall bring thee up in my net.
21253	834	4	Then will I leave thee upon the land, I will cast thee forth upon the open field, and will cause all the fowls of the heaven to remain upon thee, and I will fill the beasts of the whole earth with thee.
21254	834	5	And I will lay thy flesh upon the mountains, and fill the valleys with thy height.
21255	834	6	I will also water with thy blood the land wherein thou swimmest, even to the mountains; and the rivers shall be full of thee.
21256	834	7	And when I shall put thee out, I will cover the heaven, and make the stars thereof dark; I will cover the sun with a cloud, and the moon shall not give her light.
21257	834	8	All the bright lights of heaven will I make dark over thee, and set darkness upon thy land, saith the Lord GOD.
21258	834	9	I will also vex the hearts of many people, when I shall bring thy destruction among the nations, into the countries which thou hast not known.
21259	834	10	Yea, I will make many people amazed at thee, and their kings shall be horribly afraid for thee, when I shall brandish my sword before them; and they shall tremble at every moment, every man for his own life, in the day of thy fall.
21260	834	11	For thus saith the Lord GOD; The sword of the king of Babylon shall come upon thee.
21261	834	12	By the swords of the mighty will I cause thy multitude to fall, the terrible of the nations, all of them: and they shall spoil the pomp of Egypt, and all the multitude thereof shall be destroyed.
21262	834	13	I will destroy also all the beasts thereof from beside the great waters; neither shall the foot of man trouble them any more, nor the hoofs of beasts trouble them.
21263	834	14	Then will I make their waters deep, and cause their rivers to run like oil, saith the Lord GOD.
21264	834	15	When I shall make the land of Egypt desolate, and the country shall be destitute of that whereof it was full, when I shall smite all them that dwell therein, then shall they know that I am the LORD.
21265	834	16	This is the lamentation wherewith they shall lament her: the daughters of the nations shall lament her: they shall lament for her, even for Egypt, and for all her multitude, saith the Lord GOD.
21266	834	17	It came to pass also in the twelfth year, in the fifteenth day of the month, that the word of the LORD came unto me, saying,
21267	834	18	Son of man, wail for the multitude of Egypt, and cast them down, even her, and the daughters of the famous nations, unto the nether parts of the earth, with them that go down into the pit.
21268	834	19	Whom dost thou pass in beauty? go down, and be thou laid with the uncircumcised.
21269	834	20	They shall fall in the midst of them that are slain by the sword: she is delivered to the sword: draw her and all her multitudes.
21270	834	21	The strong among the mighty shall speak to him out of the midst of hell with them that help him: they are gone down, they lie uncircumcised, slain by the sword.
21271	834	22	Asshur is there and all her company: his graves are about him: all of them slain, fallen by the sword:
21272	834	23	Whose graves are set in the sides of the pit, and her company is round about her grave: all of them slain, fallen by the sword, which caused terror in the land of the living.
21273	834	24	There is Elam and all her multitude round about her grave, all of them slain, fallen by the sword, which are gone down uncircumcised into the nether parts of the earth, which caused their terror in the land of the living; yet have they borne their shame with them that go down to the pit.
21274	834	25	They have set her a bed in the midst of the slain with all her multitude: her graves are round about him: all of them uncircumcised, slain by the sword: though their terror was caused in the land of the living, yet have they borne their shame with them that go down to the pit: he is put in the midst of them that be slain.
21275	834	26	There is Meshech, Tubal, and all her multitude: her graves are round about him: all of them uncircumcised, slain by the sword, though they caused their terror in the land of the living.
21276	834	27	And they shall not lie with the mighty that are fallen of the uncircumcised, which are gone down to hell with their weapons of war: and they have laid their swords under their heads, but their iniquities shall be upon their bones, though they were the terror of the mighty in the land of the living.
21277	834	28	Yea, thou shalt be broken in the midst of the uncircumcised, and shalt lie with them that are slain with the sword.
21278	834	29	There is Edom, her kings, and all her princes, which with their might are laid by them that were slain by the sword: they shall lie with the uncircumcised, and with them that go down to the pit.
21279	834	30	There be the princes of the north, all of them, and all the Zidonians, which are gone down with the slain; with their terror they are ashamed of their might; and they lie uncircumcised with them that be slain by the sword, and bear their shame with them that go down to the pit.
21280	834	31	Pharaoh shall see them, and shall be comforted over all his multitude, even Pharaoh and all his army slain by the sword, saith the Lord GOD.
21281	834	32	For I have caused my terror in the land of the living: and he shall be laid in the midst of the uncircumcised with them that are slain with the sword, even Pharaoh and all his multitude, saith the Lord GOD.
21282	835	1	AGAIN the word of the LORD came unto me, saying,
21283	835	2	Son of man, speak to the children of thy people, and say unto them, When I bring the sword upon a land, if the people of the land take a man of their coasts, and set him for their watchman:
21284	835	3	If when he seeth the sword come upon the land, he blow the trumpet, and warn the people;
21285	835	4	Then whosoever heareth the sound of the trumpet, and taketh not warning; if the sword come, and take him away, his blood shall be upon his own head.
21286	835	5	He heard the sound of the trumpet, and took not warning; his blood shall be upon him. But he that taketh warning shall deliver his soul.
21287	835	6	But if the watchman see the sword come, and blow not the trumpet, and the people be not warned; if the sword come, and take any person from among them, he is taken away in his iniquity; but his blood will I require at the watchman's hand.
21288	835	7	So thou, O son of man, I have set thee a watchman unto the house of Israel; therefore thou shalt hear the word at my mouth, and warn them from me.
21289	835	8	When I say unto the wicked, O wicked man, thou shalt surely die; if thou dost not speak to warn the wicked from his way, that wicked man shall die in his iniquity; but his blood will I require at thine hand.
21290	835	9	Nevertheless, if thou warn the wicked of his way to turn from it; if he do not turn from his way, he shall die in his iniquity; but thou hast delivered thy soul.
21291	835	10	Therefore, O thou son of man, speak unto the house of Israel; Thus ye speak, saying, If our transgressions and our sins be upon us, and we pine away in them, how should we then live?
21292	835	11	Say unto them, As I live, saith the Lord GOD, I have no pleasure in the death of the wicked; but that the wicked turn from his way and live: turn ye, turn ye from your evil ways; for why will ye die, O house of Israel?
21293	835	12	Therefore, thou son of man, say unto the children of thy people, The righteousness of the righteous shall not deliver him in the day of his transgression: as for the wickedness of the wicked, he shall not fall thereby in the day that he turneth from his wickedness; neither shall the righteous be able to live for his righteousness in the day that he sinneth.
21294	835	13	When I shall say to the righteous, that he shall surely live; if he trust to his own righteousness, and commit iniquity, all his righteousnesses shall not be remembered; but for his iniquity that he hath committed, he shall die for it.
21295	835	14	Again, when I say unto the wicked, Thou shalt surely die; if he turn from his sin, and do that which is lawful and right;
21296	835	15	If the wicked restore the pledge, give again that he had robbed, walk in the statutes of life, without committing iniquity; he shall surely live, he shall not die.
21297	835	16	None of his sins that he hath committed shall be mentioned unto him: he hath done that which is lawful and right; he shall surely live.
21298	835	17	Yet the children of thy people say, The way of the Lord is not equal: but as for them, their way is not equal.
21299	835	18	When the righteous turneth from his righteousness, and committeth iniquity, he shall even die thereby.
21300	835	19	But if the wicked turn from his wickedness, and do that which is lawful and right, he shall live thereby.
21301	835	20	Yet ye say, The way of the Lord is not equal. O ye house of Israel, I will judge you every one after his ways.
21302	835	21	And it came to pass in the twelfth year of our captivity, in the tenth month, in the fifth day of the month, that one that had escaped out of Jerusalem came unto me, saying, The city is smitten.
21303	835	22	Now the hand of the LORD was upon me in the evening, afore he that was escaped came; and had opened my mouth, until he came to me in the morning; and my mouth was opened, and I was no more dumb.
21304	835	23	Then the word of the LORD came unto me, saying,
21305	835	24	Son of man, they that inhabit those wastes of the land of Israel speak, saying, Abraham was one, and he inherited the land: but we are many; the land is given us for inheritance.
21306	835	25	Wherefore say unto them, Thus saith the Lord GOD; Ye eat with the blood, and lift up your eyes toward your idols, and shed blood: and shall ye possess the land?
21307	835	26	Ye stand upon your sword, ye work abomination, and ye defile every one his neighbour's wife: and shall ye possess the land?
21308	835	27	Say thou thus unto them, Thus saith the Lord GOD; As I live, surely they that are in the wastes shall fall by the sword, and him that is in the open field will I give to the beasts to be devoured, and they that be in the forts and in the caves shall die of the pestilence.
21309	835	28	For I will lay the land most desolate, and the pomp of her strength shall cease; and the mountains of Israel shall be desolate, that none shall pass through.
21310	835	29	Then shall they know that I am the LORD, when I have laid the land most desolate because of all their abominations which they have committed.
21311	835	30	Also, thou son of man, the children of thy people still are talking against thee by the walls and in the doors of the houses, and speak one to another, every one to his brother, saying, Come, I pray you, and hear what is the word that cometh forth from the LORD.
21312	835	31	And they come unto thee as the people cometh, and they sit before thee as my people, and they hear thy words, but they will not do them: for with their mouth they shew much love, but their heart goeth after their covetousness.
21313	835	32	And, lo, thou art unto them as a very lovely song of one that hath a pleasant voice, and can play well on an instrument: for they hear thy words, but they do them not.
21314	835	33	And when this cometh to pass, (lo, it will come,) then shall they know that a prophet hath been among them.
21315	836	1	AND the word of the LORD came unto me, saying,
21316	836	2	Son of man, prophesy against the shepherds of Israel, prophesy, and say unto them, Thus saith the Lord GOD unto the shepherds; Woe be to the shepherds of Israel that do feed themselves! should not the shepherds feed the flocks?
21317	836	3	Ye eat the fat, and ye clothe you with the wool, ye kill them that are fed: but ye feed not the flock.
21318	836	4	The diseased have ye not strengthened, neither have ye healed that which was sick, neither have ye bound up that which was broken, neither have ye brought again that which was driven away, neither have ye sought that which was lost; but with force and with cruelty have ye ruled them.
21319	836	5	And they were scattered, because there is no shepherd: and they became meat to all the beasts of the field, when they were scattered.
21320	836	6	My sheep wandered through all the mountains, and upon every high hill: yea, my flock was scattered upon all the face of the earth, and none did search or seek after them.
21321	836	7	Therefore, ye shepherds, hear the word of the LORD;
21322	836	8	As I live, saith the Lord GOD, surely because my flock became a prey, and my flock became meat to every beast of the field, because there was no shepherd, neither did my shepherds search for my flock, but the shepherds fed themselves, and fed not my flock;
21323	836	9	Therefore, O ye shepherds, hear the word of the LORD;
21324	836	10	Thus saith the Lord GOD; Behold, I am against the shepherds; and I will require my flock at their hand, and cause them to cease from feeding the flock; neither shall the shepherds feed themselves any more; for I will deliver my flock from their mouth, that they may not be meat for them.
21325	836	11	For thus saith the Lord GOD; Behold, I, even I, will both search my sheep, and seek them out.
21326	836	12	As a shepherd seeketh out his flock in the day that he is among his sheep that are scattered; so will I seek out my sheep, and will deliver them out of all places where they have been scattered in the cloudy and dark day.
21327	836	13	And I will bring them out from the people, and gather them from the countries, and will bring them to their own land, and feed them upon the mountains of Israel by the rivers, and in all the inhabited places of the country.
21328	836	14	I will feed them in a good pasture, and upon the high mountains of Israel shall their fold be: there shall they lie in a good fold, and in a fat pasture shall they feed upon the mountains of Israel.
21329	836	15	I will feed my flock, and I will cause them to lie down, saith the Lord GOD.
21330	836	16	I will seek that which was lost, and bring again that which was driven away, and will bind up that which was broken, and will strengthen that which was sick: but I will destroy the fat and the strong; I will feed them with judgment.
21331	836	17	And as for you, O my flock, thus saith the Lord GOD; Behold, I judge between cattle and cattle, between the rams and the he goats.
21332	836	18	Seemeth it a small thing unto you to have eaten up the good pasture, but ye must tread down with your feet the residue of your pastures? and to have drunk of the deep waters, but ye must foul the residue with your feet?
21333	836	19	And as for my flock, they eat that which ye have trodden with your feet; and they drink that which ye have fouled with your feet.
21334	836	20	Therefore thus saith the Lord GOD unto them; Behold, I, even I, will judge between the fat cattle and between the lean cattle.
21335	836	21	Because ye have thrust with side and with shoulder, and pushed all the diseased with your horns, till ye have scattered them abroad;
21336	836	22	Therefore will I save my flock, and they shall no more be a prey; and I will judge between cattle and cattle.
21337	836	23	And I will set up one shepherd over them, and he shall feed them, even my servant David; he shall feed them, and he shall be their shepherd.
21338	836	24	And I the LORD will be their God, and my servant David a prince among them; I the LORD have spoken it.
21339	836	25	And I will make with them a covenant of peace, and will cause the evil beasts to cease out of the land: and they shall dwell safely in the wilderness, and sleep in the woods.
21340	836	26	And I will make them and the places round about my hill a blessing; and I will cause the shower to come down in his season; there shall be showers of blessing.
21341	836	27	And the tree of the field shall yield her fruit, and the earth shall yield her increase, and they shall be safe in their land, and shall know that I am the LORD, when I have broken the bands of their yoke, and delivered them out of the hand of those that served themselves of them.
21342	836	28	And they shall no more be a prey to the heathen, neither shall the beast of the land devour them; but they shall dwell safely, and none shall make them afraid.
21343	836	29	And I will raise up for them a plant of renown, and they shall be no more consumed with hunger in the land, neither bear the shame of the heathen any more.
21344	836	30	Thus shall they know that I the LORD their God am with them, and that they, even the house of Israel, are my people, saith the Lord GOD.
21345	836	31	And ye my flock, the flock of my pasture, are men, and I am your God, saith the Lord GOD.
21346	837	1	MOREOVER the word of the LORD came unto me, saying,
21347	837	2	Son of man, set thy face against mount Seir, and prophesy against it,
21348	837	3	And say unto it, Thus saith the Lord GOD; Behold, O mount Seir, I am against thee, and I will stretch out mine hand against thee, and I will make thee most desolate.
21349	837	4	I will lay thy cities waste, and thou shalt be desolate, and thou shalt know that I am the LORD.
21350	837	5	Because thou hast had a perpetual hatred, and hast shed the blood of the children of Israel by the force of the sword in the time of their calamity, in the time that their iniquity had an end:
21351	837	6	Therefore, as I live, saith the Lord GOD, I will prepare thee unto blood, and blood shall pursue thee: sith thou hast not hated blood, even blood shall pursue thee.
21352	837	7	Thus will I make mount Seir most desolate, and cut off from it him that passeth out and him that returneth.
21353	837	8	And I will fill his mountains with his slain men: in thy hills, and in thy valleys, and in all thy rivers, shall they fall that are slain with the sword.
21354	837	9	I will make thee perpetual desolations, and thy cities shall not return: and ye shall know that I am the LORD.
21355	837	10	Because thou hast said, These two nations and these two countries shall be mine, and we will possess it; whereas the LORD was there:
21356	837	11	Therefore, as I live, saith the Lord GOD, I will even do according to thine anger, and according to thine envy which thou hast used out of thy hatred against them; and I will make myself known among them, when I have judged thee.
21357	837	12	And thou shalt know that I am the LORD, and that I have heard all thy blasphemies which thou hast spoken against the mountains of Israel, saying, They are laid desolate, they are given us to consume.
21358	837	13	Thus with your mouth ye have boasted against me, and have multiplied your words against me: I have heard them.
21359	837	14	Thus saith the Lord GOD; When the whole earth rejoiceth, I will make thee desolate.
21360	837	15	As thou didst rejoice at the inheritance of the house of Israel, because it was desolate, so will I do unto thee: thou shalt be desolate, O mount Seir, and all Idumea, even all of it: and they shall know that I am the LORD.
21361	838	1	ALSO, thou son of man, prophesy unto the mountains of Israel, and say, Ye mountains of Israel, hear the word of the LORD:
21362	838	2	Thus saith the Lord GOD; Because the enemy hath said against you, Aha, even the ancient high places are ours in possession:
21363	838	3	Therefore prophesy and say, Thus saith the Lord GOD; Because they have made you desolate, and swallowed you up on every side, that ye might be a possession unto the residue of the heathen, and ye are taken up in the lips of talkers, and are an infamy of the people:
21364	838	4	Therefore, ye mountains of Israel, hear the word of the Lord GOD; Thus saith the Lord GOD to the mountains, and to the hills, to the rivers, and to the valleys, to the desolate wastes, and to the cities that are forsaken, which became a prey and derision to the residue of the heathen that are round about;
21365	838	5	Therefore thus saith the Lord GOD; Surely in the fire of my jealousy have I spoken against the residue of the heathen, and against all Idumea, which have appointed my land into their possession with the joy of all their heart, with despiteful minds, to cast it out for a prey.
21366	838	6	Prophesy therefore concerning the land of Israel, and say unto the mountains, and to the hills, to the rivers, and to the valleys, Thus saith the Lord GOD; Behold, I have spoken in my jealousy and in my fury, because ye have borne the shame of the heathen:
21367	838	7	Therefore thus saith the Lord GOD; I have lifted up mine hand, Surely the heathen that are about you, they shall bear their shame.
21368	838	8	But ye, O mountains of Israel, ye shall shoot forth your branches, and yield your fruit to my people of Israel; for they are at hand to come.
21369	838	9	For, behold, I am for you, and I will turn unto you, and ye shall be tilled and sown:
21370	838	10	And I will multiply men upon you, all the house of Israel, even all of it: and the cities shall be inhabited, and the wastes shall be builded:
21371	838	11	And I will multiply upon you man and beast; and they shall increase and bring fruit: and I will settle you after your old estates, and will do better unto you than at your beginnings: and ye shall know that I am the LORD.
21372	838	12	Yea, I will cause men to walk upon you, even my people Israel; and they shall possess thee, and thou shalt be their inheritance, and thou shalt no more henceforth bereave them of men.
21373	838	13	Thus saith the Lord GOD; Because they say unto you, Thou land devourest up men, and hast bereaved thy nations;
21374	838	14	Therefore thou shalt devour men no more, neither bereave thy nations any more, saith the Lord GOD.
21375	838	15	Neither will I cause men to hear in thee the shame of the heathen any more, neither shalt thou bear the reproach of the people any more, neither shalt thou cause thy nations to fall any more, saith the Lord GOD.
21376	838	16	Moreover the word of the LORD came unto me, saying,
21377	838	17	Son of man, when the house of Israel dwelt in their own land, they defiled it by their own way and by their doings: their way was before me as the uncleanness of a removed woman.
21378	838	18	Wherefore I poured my fury upon them for the blood that they had shed upon the land, and for their idols wherewith they had polluted it:
21379	838	19	And I scattered them among the heathen, and they were dispersed through the countries: according to their way and according to their doings I judged them.
21380	838	20	And when they entered unto the heathen, whither they went, they profaned my holy name, when they said to them, These are the people of the LORD, and are gone forth out of his land.
21381	838	21	But I had pity for mine holy name, which the house of Israel had profaned among the heathen, whither they went.
21382	838	22	Therefore say unto the house of Israel, Thus saith the Lord GOD; I do not this for your sakes, O house of Israel, but for mine holy name's sake, which ye have profaned among the heathen, whither ye went.
21383	838	23	And I will sanctify my great name, which was profaned among the heathen, which ye have profaned in the midst of them; and the heathen shall know that I am the LORD, saith the Lord GOD, when I shall be sanctified in you before their eyes.
21384	838	24	For I will take you from among the heathen, and gather you out of all countries, and will bring you into your own land.
21385	838	25	Then will I sprinkle clean water upon you, and ye shall be clean: from all your filthiness, and from all your idols, will I cleanse you.
21386	838	26	A new heart also will I give you, and a new spirit will I put within you: and I will take away the stony heart out of your flesh, and I will give you an heart of flesh.
21387	838	27	And I will put my spirit within you, and cause you to walk in my statutes, and ye shall keep my judgments, and do them.
21388	838	28	And ye shall dwell in the land that I gave to your fathers; and ye shall be my people, and I will be your God.
21389	838	29	I will also save you from all your uncleannesses: and I will call for the corn, and will increase it, and lay no famine upon you.
21390	838	30	And I will multiply the fruit of the tree, and the increase of the field, that ye shall receive no more reproach of famine among the heathen.
21391	838	31	Then shall ye remember your own evil ways, and your doings that were not good, and shall lothe yourselves in your own sight for your iniquities and for your abominations.
21392	838	32	Not for your sakes do I this, saith the Lord GOD, be it known unto you: be ashamed and confounded for your own ways, O house of Israel.
21393	838	33	Thus saith the Lord GOD; In the day that I shall have cleansed you from all your iniquities I will also cause you to dwell in the cities, and the wastes shall be builded.
21394	838	34	And the desolate land shall be tilled, whereas it lay desolate in the sight of all that passed by.
21395	838	35	And they shall say, This land that was desolate is become like the garden of Eden; and the waste and desolate and ruined cities are become fenced, and are inhabited.
21396	838	36	Then the heathen that are left round about you shall know that I the LORD build the ruined places, and plant that that was desolate: I the LORD have spoken it, and I will do it.
21397	838	37	Thus saith the Lord GOD; I will yet for this be enquired of by the house of Israel, to do it for them; I will increase them with men like a flock.
21398	838	38	As the holy flock, as the flock of Jerusalem in her solemn feasts; so shall the waste cities be filled with flocks of men: and they shall know that I am the LORD.
21399	839	1	THE hand of the LORD was upon me, and carried me out in the spirit of the LORD, and set me down in the midst of the valley which was full of bones,
21400	839	2	And caused me to pass by them round about: and, behold, there were very many in the open valley; and, lo, they were very dry.
21401	839	3	And he said unto me, Son of man, can these bones live? And I answered, O Lord GOD, thou knowest.
21402	839	4	Again he said unto me, Prophesy upon these bones, and say unto them, O ye dry bones, hear the word of the LORD.
21403	839	5	Thus saith the Lord GOD unto these bones; Behold, I will cause breath to enter into you, and ye shall live:
21404	839	6	And I will lay sinews upon you, and will bring up flesh upon you, and cover you with skin, and put breath in you, and ye shall live; and ye shall know that I am the LORD.
21405	839	7	So I prophesied as I was commanded: and as I prophesied, there was a noise, and behold a shaking, and the bones came together, bone to his bone.
21406	839	8	And when I beheld, lo, the sinews and the flesh came up upon them, and the skin covered them above: but there was no breath in them.
21407	839	9	Then said he unto me, Prophesy unto the wind, prophesy, son of man, and say to the wind, Thus saith the Lord GOD; Come from the four winds, O breath, and breathe upon these slain, that they may live.
21408	839	10	So I prophesied as he commanded me, and the breath came into them, and they lived, and stood up upon their feet, an exceeding great army.
21409	839	11	Then he said unto me, Son of man, these bones are the whole house of Israel: behold, they say, Our bones are dried, and our hope is lost: we are cut off for our parts.
21410	839	12	Therefore prophesy and say unto them, Thus saith the Lord GOD; Behold, O my people, I will open your graves, and cause you to come up out of your graves, and bring you into the land of Israel.
21411	839	13	And ye shall know that I am the LORD, when I have opened your graves, O my people, and brought you up out of your graves,
21412	839	14	And shall put my spirit in you, and ye shall live, and I shall place you in your own land: then shall ye know that I the LORD have spoken it, and performed it, saith the LORD.
21413	839	15	The word of the LORD came again unto me, saying,
21414	839	16	Moreover, thou son of man, take thee one stick, and write upon it, For Judah, and for the children of Israel his companions: then take another stick, and write upon it, For Joseph, the stick of Ephraim, and for all the house of Israel his companions:
21415	839	17	And join them one to another into one stick; and they shall become one in thine hand.
21416	839	18	And when the children of thy people shall speak unto thee, saying, Wilt thou not shew us what thou meanest by these?
21417	839	19	Say unto them, Thus saith the Lord GOD; Behold, I will take the stick of Joseph, which is in the hand of Ephraim, and the tribes of Israel his fellows, and will put them with him, even with the stick of Judah, and make them one stick, and they shall be one in mine hand.
21418	839	20	And the sticks whereon thou writest shall be in thine hand before their eyes.
21419	839	21	And say unto them, Thus saith the Lord GOD; Behold, I will take the children of Israel from among the heathen, whither they be gone, and will gather them on every side, and bring them into their own land:
21420	839	22	And I will make them one nation in the land upon the mountains of Israel; and one king shall be king to them all: and they shall be no more two nations, neither shall they be divided into two kingdoms any more at all:
21421	839	23	Neither shall they defile themselves any more with their idols, nor with their detestable things, nor with any of their transgressions: but I will save them out of all their dwellingplaces, wherein they have sinned, and will cleanse them: so shall they be my people, and I will be their God.
21422	839	24	And David my servant shall be king over them; and they all shall have one shepherd: they shall also walk in my judgments, and observe my statutes, and do them.
21423	839	25	And they shall dwell in the land that I have given unto Jacob my servant, wherein your fathers have dwelt; and they shall dwell therein, even they, and their children, and their children's children for ever: and my servant David shall be their prince for ever.
21424	839	26	Moreover I will make a covenant of peace with them; it shall be an everlasting covenant with them: and I will place them, and multiply them, and will set my sanctuary in the midst of them for evermore.
21425	839	27	My tabernacle also shall be with them: yea, I will be their God, and they shall be my people.
21426	839	28	And the heathen shall know that I the LORD do sanctify Israel, when my sanctuary shall be in the midst of them for evermore.
21427	840	1	AND the word of the LORD came unto me, saying,
21428	840	2	Son of man, set thy face against Gog, the land of Magog, the chief prince of Meshech and Tubal, and prophesy against him,
21429	840	3	And say, Thus saith the Lord GOD; Behold, I am against thee, O Gog, the chief prince of Meshech and Tubal:
21430	840	4	And I will turn thee back, and put hooks into thy jaws, and I will bring thee forth, and all thine army, horses and horsemen, all of them clothed with all sorts of armour, even a great company with bucklers and shields, all of them handling swords:
21431	840	5	Persia, Ethiopia, and Libya with them; all of them with shield and helmet:
21432	840	6	Gomer, and all his bands; the house of Togarmah of the north quarters, and all his bands: and many people with thee.
21433	840	7	Be thou prepared, and prepare for thyself, thou, and all thy company that are assembled unto thee, and be thou a guard unto them.
21434	840	8	After many days thou shalt be visited: in the latter years thou shalt come into the land that is brought back from the sword, and is gathered out of many people, against the mountains of Israel, which have been always waste: but it is brought forth out of the nations, and they shall dwell safely all of them.
21435	840	9	Thou shalt ascend and come like a storm, thou shalt be like a cloud to cover the land, thou, and all thy bands, and many people with thee.
21436	840	10	Thus saith the Lord GOD; It shall also come to pass, that at the same time shall things come into thy mind, and thou shalt think an evil thought:
21437	840	11	And thou shalt say, I will go up to the land of unwalled villages; I will go to them that are at rest, that dwell safely, all of them dwelling without walls, and having neither bars nor gates,
21438	840	12	To take a spoil, and to take a prey; to turn thine hand upon the desolate places that are now inhabited, and upon the people that are gathered out of the nations, which have gotten cattle and goods, that dwell in the midst of the land.
21439	840	13	Sheba, and Dedan, and the merchants of Tarshish, with all the young lions thereof, shall say unto thee, Art thou come to take a spoil? hast thou gathered thy company to take a prey? to carry away silver and gold, to take away cattle and goods, to take a great spoil?
21440	840	14	Therefore, son of man, prophesy and say unto Gog, Thus saith the Lord GOD; In that day when my people of Israel dwelleth safely, shalt thou not know it?
21441	840	15	And thou shalt come from thy place out of the north parts, thou, and many people with thee, all of them riding upon horses, a great company, and a mighty army:
21442	840	16	And thou shalt come up against my people of Israel, as a cloud to cover the land; it shall be in the latter days, and I will bring thee against my land, that the heathen may know me, when I shall be sanctified in thee, O Gog, before their eyes.
21443	840	17	Thus saith the Lord GOD; Art thou he of whom I have spoken in old time by my servants the prophets of Israel, which prophesied in those days many years that I would bring thee against them?
21444	840	18	And it shall come to pass at the same time when Gog shall come against the land of Israel, saith the Lord GOD, that my fury shall come up in my face.
21445	840	19	For in my jealousy and in the fire of my wrath have I spoken, Surely in that day there shall be a great shaking in the land of Israel;
21446	840	20	So that the fishes of the sea, and the fowls of the heaven, and the beasts of the field, and all creeping things that creep upon the earth, and all the men that are upon the face of the earth, shall shake at my presence, and the mountains shall be thrown down, and the steep places shall fall, and every wall shall fall to the ground.
21447	840	21	And I will call for a sword against him throughout all my mountains, saith the Lord GOD: every man's sword shall be against his brother.
21448	840	22	And I will plead against him with pestilence and with blood; and I will rain upon him, and upon his bands, and upon the many people that are with him, an overflowing rain, and great hailstones, fire, and brimstone.
21449	840	23	Thus will I magnify myself, and sanctify myself; and I will be known in the eyes of many nations, and they shall know that I am the LORD.
21450	841	1	THEREFORE, thou son of man, prophesy against Gog, and say, Thus saith the Lord GOD; Behold, I am against thee, O Gog, the chief prince of Meshech and Tubal:
21451	841	2	And I will turn thee back, and leave but the sixth part of thee, and will cause thee to come up from the north parts, and will bring thee upon the mountains of Israel:
21452	841	3	And I will smite thy bow out of thy left hand, and will cause thine arrows to fall out of thy right hand.
21453	841	4	Thou shalt fall upon the mountains of Israel, thou, and all thy bands, and the people that is with thee: I will give thee unto the ravenous birds of every sort, and to the beasts of the field to be devoured.
21454	841	5	Thou shalt fall upon the open field: for I have spoken it, saith the Lord GOD.
21455	841	6	And I will send a fire on Magog, and among them that dwell carelessly in the isles: and they shall know that I am the LORD.
21456	841	7	So will I make my holy name known in the midst of my people Israel; and I will not let them pollute my holy name any more: and the heathen shall know that I am the LORD, the Holy One in Israel.
21457	841	8	Behold, it is come, and it is done, saith the Lord GOD; this is the day whereof I have spoken.
21458	841	9	And they that dwell in the cities of Israel shall go forth, and shall set on fire and burn the weapons, both the shields and the bucklers, the bows and the arrows, and the handstaves, and the spears, and they shall burn them with fire seven years:
21459	841	10	So that they shall take no wood out of the field, neither cut down any out of the forests; for they shall burn the weapons with fire: and they shall spoil those that spoiled them, and rob those that robbed them, saith the Lord GOD.
21460	841	11	And it shall come to pass in that day, that I will give unto Gog a place there of graves in Israel, the valley of the passengers on the east of the sea: and it shall stop the noses of the passengers: and there shall they bury Gog and all his multitude: and they shall call it The valley of Hamon-gog.
21461	841	12	And seven months shall the house of Israel be burying of them, that they may cleanse the land.
21462	841	13	Yea, all the people of the land shall bury them; and it shall be to them a renown the day that I shall be glorified, saith the Lord GOD.
21463	841	14	And they shall sever out men of continual employment, passing through the land to bury with the passengers those that remain upon the face of the earth, to cleanse it: after the end of seven months shall they search.
21464	841	15	And the passengers that pass through the land, when any seeth a man's bone, then shall he set up a sign by it, till the buriers have buried it in the valley of Hamon-gog.
21465	841	16	And also the name of the city shall be Hamonah. Thus shall they cleanse the land.
21466	841	17	And, thou son of man, thus saith the Lord GOD; Speak unto every feathered fowl, and to every beast of the field, Assemble yourselves, and come; gather yourselves on every side to my sacrifice that I do sacrifice for you, even a great sacrifice upon the mountains of Israel, that ye may eat flesh, and drink blood.
21467	841	18	Ye shall eat the flesh of the mighty, and drink the blood of the princes of the earth, of rams, of lambs, and of goats, of bullocks, all of them fatlings of Bashan.
21468	841	19	And ye shall eat fat till ye be full, and drink blood till ye be drunken, of my sacrifice which I have sacrificed for you.
21469	841	20	Thus ye shall be filled at my table with horses and chariots, with mighty men, and with all men of war, saith the Lord GOD.
21470	841	21	And I will set my glory among the heathen, and all the heathen shall see my judgment that I have executed, and my hand that I have laid upon them.
21471	841	22	So the house of Israel shall know that I am the LORD their God from that day and forward.
21472	841	23	And the heathen shall know that the house of Israel went into captivity for their iniquity: because they trespassed against me, therefore hid I my face from them, and gave them into the hand of their enemies: so fell they all by the sword.
21473	841	24	According to their uncleanness and according to their transgressions have I done unto them, and hid my face from them.
21474	841	25	Therefore thus saith the Lord GOD; Now will I bring again the captivity of Jacob, and have mercy upon the whole house of Israel, and will be jealous for my holy name;
21475	841	26	After that they have borne their shame, and all their trespasses whereby they have trespassed against me, when they dwelt safely in their land, and none made them afraid.
21476	841	27	When I have brought them again from the people, and gathered them out of their enemies' lands, and am sanctified in them in the sight of many nations;
21477	841	28	Then shall they know that I am the LORD their God, which cause them to be led into captivity among the heathen: but I have gathered them unto their own land, and have left none of them any more there.
21478	841	29	Neither will I hide my face any more from them: for I have poured out my spirit upon the house of Israel, saith the Lord GOD.
21479	842	1	IN the five and twentieth year of our captivity, in the beginning of the year, in the tenth day of the month, in the fourteenth year after that the city was smitten, in the selfsame day the hand of the LORD was upon me, and brought me thither.
21480	842	2	In the visions of God brought he me into the land of Israel, and set me upon a very high mountain, by which was as the frame of a city on the south.
21481	842	3	And he brought me thither, and, behold, there was a man, whose appearance was like the appearance of brass, with a line of flax in his hand, and a measuring reed; and he stood in the gate.
21482	842	4	And the man said unto me, Son of man, behold with thine eyes, and hear with thine ears, and set thine heart upon all that I shall shew thee; for to the intent that I might shew them unto thee art thou brought hither: declare all that thou seest to the house of Israel.
21483	842	5	And behold a wall on the outside of the house round about, and in the man's hand a measuring reed of six cubits long by the cubit and an hand breadth: so he measured the breadth of the building, one reed; and the height, one reed.
21484	842	6	Then came he unto the gate which looketh toward the east, and went up the stairs thereof, and measured the threshold of the gate, which was one reed broad; and the other threshold of the gate, which was one reed broad.
21485	842	7	And every little chamber was one reed long, and one reed broad; and between the little chambers were five cubits; and the threshold of the gate by the porch of the gate within was one reed.
21486	842	8	He measured also the porch of the gate within, one reed.
21487	842	9	Then measured he the porch of the gate, eight cubits; and the posts thereof, two cubits; and the porch of the gate was inward.
21488	842	10	And the little chambers of the gate eastward were three on this side, and three on that side; they three were of one measure: and the posts had one measure on this side and on that side.
21489	842	11	And he measured the breadth of the entry of the gate, ten cubits; and the length of the gate, thirteen cubits.
21490	842	12	The space also before the little chambers was one cubit on this side, and the space was one cubit on that side: and the little chambers were six cubits on this side, and six cubits on that side.
21491	842	13	He measured then the gate from the roof of one little chamber to the roof of another: the breadth was five and twenty cubits, door against door.
21492	842	14	He made also posts of threescore cubits, even unto the post of the court round about the gate.
21493	842	15	And from the face of the gate of the entrance unto the face of the porch of the inner gate were fifty cubits.
21494	842	16	And there were narrow windows to the little chambers, and to their posts within the gate round about, and likewise to the arches: and windows were round about inward: and upon each post were palm trees.
21495	842	17	Then brought he me into the outward court, and, lo, there were chambers, and a pavement made for the court round about: thirty chambers were upon the pavement.
21496	842	18	And the pavement by the side of the gates over against the length of the gates was the lower pavement.
21497	842	19	Then he measured the breadth from the forefront of the lower gate unto the forefront of the inner court without, an hundred cubits eastward and northward.
21498	842	20	And the gate of the outward court that looked toward the north, he measured the length thereof, and the breadth thereof.
21499	842	21	And the little chambers thereof were three on this side and three on that side; and the posts thereof and the arches thereof were after the measure of the first gate: the length thereof was fifty cubits, and the breadth five and twenty cubits.
21500	842	22	And their windows, and their arches, and their palm trees, were after the measure of the gate that looketh toward the east; and they went up unto it by seven steps; and the arches thereof were before them.
21501	842	23	And the gate of the inner court was over against the gate toward the north, and toward the east; and he measured from gate to gate an hundred cubits.
21502	842	24	After that he brought me toward the south, and behold a gate toward the south: and he measured the posts thereof and the arches thereof according to these measures.
21503	842	25	And there were windows in it and in the arches thereof round about, like those windows: the length was fifty cubits, and the breadth five and twenty cubits.
21504	842	26	And there were seven steps to go up to it, and the arches thereof were before them: and it had palm trees, one on this side, and another on that side, upon the posts thereof.
21505	842	27	And there was a gate in the inner court toward the south: and he measured from gate to gate toward the south an hundred cubits.
21506	842	28	And he brought me to the inner court by the south gate: and he measured the south gate according to these measures;
21507	842	29	And the little chambers thereof, and the posts thereof, and the arches thereof, according to these measures: and there were windows in it and in the arches thereof round about: it was fifty cubits long, and five and twenty cubits broad.
21508	842	30	And the arches round about were five and twenty cubits long, and five cubits broad.
21509	842	31	And the arches thereof were toward the utter court; and palm trees were upon the posts thereof: and the going up to it had eight steps.
21510	842	32	And he brought me into the inner court toward the east: and he measured the gate according to these measures.
21511	842	33	And the little chambers thereof, and the posts thereof, and the arches thereof, were according to these measures: and there were windows therein and in the arches thereof round about: it was fifty cubits long, and five and twenty cubits broad.
21512	842	34	And the arches thereof were toward the outward court; and palm trees were upon the posts thereof, on this side, and on that side: and the going up to it had eight steps.
21513	842	35	And he brought me to the north gate, and measured it according to these measures;
21514	842	36	The little chambers thereof, the posts thereof, and the arches thereof, and the windows to it round about: the length was fifty cubits, and the breadth five and twenty cubits.
21515	842	37	And the posts thereof were toward the utter court; and palm trees were upon the posts thereof, on this side, and on that side: and the going up to it had eight steps.
21516	842	38	And the chambers and the entries thereof were by the posts of the gates, where they washed the burnt offering.
21517	842	39	And in the porch of the gate were two tables on this side, and two tables on that side, to slay thereon the burnt offering and the sin offering and the trespass offering.
21518	842	40	And at the side without, as one goeth up to the entry of the north gate, were two tables; and on the other side, which was at the porch of the gate, were two tables.
21519	842	41	Four tables were on this side, and four tables on that side, by the side of the gate; eight tables, whereupon they slew their sacrifices.
21520	842	42	And the four tables were of hewn stone for the burnt offering, of a cubit and an half long, and a cubit and an half broad, and one cubit high: whereupon also they laid the instruments wherewith they slew the burnt offering and the sacrifice.
21521	842	43	And within were hooks, an hand broad, fastened round about: and upon the tables was the flesh of the offering.
21522	842	44	And without the inner gate were the chambers of the singers in the inner court, which was at the side of the north gate; and their prospect was toward the south: one at the side of the east gate having the prospect toward the north.
21523	842	45	And he said unto me, This chamber, whose prospect is toward the south, is for the priests, the keepers of the charge of the house.
21524	842	46	And the chamber whose prospect is toward the north is for the priests, the keepers of the charge of the altar: these are the sons of Zadok among the sons of Levi, which come near to the LORD to minister unto him.
21525	842	47	So he measured the court, an hundred cubits long, and an hundred cubits broad, foursquare; and the altar that was before the house.
21526	842	48	And he brought me to the porch of the house, and measured each post of the porch, five cubits on this side, and five cubits on that side: and the breadth of the gate was three cubits on this side, and three cubits on that side.
21527	842	49	The length of the porch was twenty cubits, and the breadth eleven cubits; and he brought me by the steps whereby they went up to it: and there were pillars by the posts, one on this side, and another on that side.
21528	843	1	AFTERWARD he brought me to the temple, and measured the posts, six cubits broad on the one side, and six cubits broad on the other side, which was the breadth of the tabernacle.
21529	843	2	And the breadth of the door was ten cubits; and the sides of the door were five cubits on the one side, and five cubits on the other side: and he measured the length thereof, forty cubits: and the breadth, twenty cubits.
21530	843	3	Then went he inward, and measured the post of the door, two cubits; and the door, six cubits; and the breadth of the door, seven cubits.
21531	843	4	So he measured the length thereof, twenty cubits; and the breadth, twenty cubits, before the temple: and he said unto me, This is the most holy place.
21532	843	5	After he measured the wall of the house, six cubits; and the breadth of every side chamber, four cubits, round about the house on every side.
21533	843	6	And the side chambers were three, one over another, and thirty in order; and they entered into the wall which was of the house for the side chambers round about, that they might have hold, but they had not hold in the wall of the house.
21534	843	7	And there was an enlarging, and a winding about still upward to the side chambers: for the winding about of the house went still upward round about the house: therefore the breadth of the house was still upward, and so increased from the lowest chamber to the highest by the midst.
21535	843	8	I saw also the height of the house round about: the foundations of the side chambers were a full reed of six great cubits.
21536	843	9	The thickness of the wall, which was for the side chamber without, was five cubits: and that which was left was the place of the side chambers that were within.
21537	843	10	And between the chambers was the wideness of twenty cubits round about the house on every side.
21538	843	11	And the doors of the side chambers were toward the place that was left, one door toward the north, and another door toward the south: and the breadth of the place that was left was five cubits round about.
21539	843	12	Now the building that was before the separate place at the end toward the west was seventy cubits broad; and the wall of the building was five cubits thick round about, and the length thereof ninety cubits.
21540	843	13	So he measured the house, an hundred cubits long; and the separate place, and the building, with the walls thereof, an hundred cubits long;
21541	843	14	Also the breadth of the face of the house, and of the separate place toward the east, an hundred cubits.
21542	843	15	And he measured the length of the building over against the separate place which was behind it, and the galleries thereof on the one side and on the other side, an hundred cubits, with the inner temple, and the porches of the court;
21543	843	16	The door posts, and the narrow windows, and the galleries round about on their three stories, over against the door, cieled with wood round about, and from the ground up to the windows, and the windows were covered;
21544	843	17	To that above the door, even unto the inner house, and without, and by all the wall round about within and without, by measure.
21545	843	18	And it was made with cherubims and palm trees, so that a palm tree was between a cherub and a cherub; and every cherub had two faces;
21546	843	19	So that the face of a man was toward the palm tree on the one side, and the face of a young lion toward the palm tree on the other side: it was made through all the house round about.
21547	843	20	From the ground unto above the door were cherubims and palm trees made, and on the wall of the temple.
21548	843	21	The posts of the temple were squared, and the face of the sanctuary; the appearance of the one as the appearance of the other.
21549	843	22	The altar of wood was three cubits high, and the length thereof two cubits; and the corners thereof, and the length thereof, and the walls thereof, were of wood: and he said unto me, This is the table that is before the LORD.
21550	843	23	And the temple and the sanctuary had two doors.
21551	843	24	And the doors had two leaves apiece, two turning leaves; two leaves for the one door, and two leaves for the other door.
21552	843	25	And there were made on them, on the doors of the temple, cherubims and palm trees, like as were made upon the walls; and there were thick planks upon the face of the porch without.
21553	843	26	And there were narrow windows and palm trees on the one side and on the other side, on the sides of the porch, and upon the side chambers of the house, and thick planks.
21554	844	1	THEN he brought me forth into the utter court, the way toward the north: and he brought me into the chamber that was over against the separate place, and which was before the building toward the north.
21555	844	2	Before the length of an hundred cubits was the north door, and the breadth was fifty cubits.
21556	844	3	Over against the twenty cubits which were for the inner court, and over against the pavement which was for the utter court, was gallery against gallery in three stories.
21557	844	4	And before the chambers was a walk of ten cubits breadth inward, a way of one cubit; and their doors toward the north.
21558	844	5	Now the upper chambers were shorter: for the galleries were higher than these, than the lower, and than the middlemost of the building.
21559	844	6	For they were in three stories, but had not pillars as the pillars of the courts: therefore the building was straitened more than the lowest and the middlemost from the ground.
21560	844	7	And the wall that was without over against the chambers, toward the utter court on the forepart of the chambers, the length thereof was fifty cubits.
21561	844	8	For the length of the chambers that were in the utter court was fifty cubits: and, lo, before the temple were an hundred cubits.
21562	844	9	And from under these chambers was the entry on the east side, as one goeth into them from the utter court.
21563	844	10	The chambers were in the thickness of the wall of the court toward the east, over against the separate place, and over against the building.
21564	844	11	And the way before them was like the appearance of the chambers which were toward the north, as long as they, and as broad as they: and all their goings out were both according to their fashions, and according to their doors.
21565	844	12	And according to the doors of the chambers that were toward the south was a door in the head of the way, even the way directly before the wall toward the east, as one entereth into them.
21566	844	13	Then said he unto me, The north chambers and the south chambers, which are before the separate place, they be holy chambers, where the priests that approach unto the LORD shall eat the most holy things: there shall they lay the most holy things, and the meat offering, and the sin offering, and the trespass offering; for the place is holy.
21567	844	14	When the priests enter therein, then shall they not go out of the holy place into the utter court, but there they shall lay their garments wherein they minister; for they are holy; and shall put on other garments, and shall approach to those things which are for the people.
21568	844	15	Now when he had made an end of measuring the inner house, he brought me forth toward the gate whose prospect is toward the east, and measured it round about.
21569	844	16	He measured the east side with the measuring reed, five hundred reeds, with the measuring reed round about.
21570	844	17	He measured the north side, five hundred reeds, with the measuring reed round about.
21571	844	18	He measured the south side, five hundred reeds, with the measuring reed.
21572	844	19	He turned about to the west side, and measured five hundred reeds with the measuring reed.
21573	844	20	He measured it by the four sides: it had a wall round about, five hundred reeds long, and five hundred broad, to make a separation between the sanctuary and the profane place.
21574	845	1	AFTERWARD he brought me to the gate, even the gate that looketh toward the east:
21575	845	2	And, behold, the glory of the God of Israel came from the way of the east: and his voice was like a noise of many waters: and the earth shined with his glory.
21576	845	3	And it was according to the appearance of the vision which I saw, even according to the vision that I saw when I came to destroy the city: and the visions were like the vision that I saw by the river Chebar; and I fell upon my face.
21577	845	4	And the glory of the LORD came into the house by the way of the gate whose prospect is toward the east.
21578	845	5	So the spirit took me up, and brought me into the inner court; and, behold, the glory of the LORD filled the house.
21579	845	6	And I heard him speaking unto me out of the house; and the man stood by me.
21580	845	7	And he said unto me, Son of man, the place of my throne, and the place of the soles of my feet, where I will dwell in the midst of the children of Israel for ever, and my holy name, shall the house of Israel no more defile, neither they, nor their kings, by their whoredom, nor by the carcases of their kings in their high places.
21581	845	8	In their setting of their threshold by my thresholds, and their post by my posts, and the wall between me and them, they have even defiled my holy name by their abominations that they have committed: wherefore I have consumed them in mine anger.
21582	845	9	Now let them put away their whoredom, and the carcases of their kings, far from me, and I will dwell in the midst of them for ever.
21583	845	10	Thou son of man, shew the house to the house of Israel, that they may be ashamed of their iniquities: and let them measure the pattern.
21584	845	11	And if they be ashamed of all that they have done, shew them the form of the house, and the fashion thereof, and the goings out thereof, and the comings in thereof, and all the forms thereof, and all the ordinances thereof, and all the forms thereof, and all the laws thereof: and write it in their sight, that they may keep the whole form thereof, and all the ordinances thereof, and do them.
21585	845	12	This is the law of the house; Upon the top of the mountain the whole limit thereof round about shall be most holy. Behold, this is the law of the house.
21586	845	13	And these are the measures of the altar after the cubits: The cubit is a cubit and an hand breadth; even the bottom shall be a cubit, and the breadth a cubit, and the border thereof by the edge thereof round about shall be a span: and this shall be the higher place of the altar.
21587	845	14	And from the bottom upon the ground even to the lower settle shall be two cubits, and the breadth one cubit; and from the lesser settle even to the greater settle shall be four cubits, and the breadth one cubit.
21588	845	15	So the altar shall be four cubits; and from the altar and upward shall be four horns.
21589	845	16	And the altar shall be twelve cubits long, twelve broad, square in the four squares thereof.
21590	845	17	And the settle shall be fourteen cubits long and fourteen broad in the four squares thereof; and the border about it shall be half a cubit; and the bottom thereof shall be a cubit about; and his stairs shall look toward the east.
21591	845	18	And he said unto me, Son of man, thus saith the Lord GOD; These are the ordinances of the altar in the day when they shall make it, to offer burnt offerings thereon, and to sprinkle blood thereon.
21592	845	19	And thou shalt give to the priests the Levites that be of the seed of Zadok, which approach unto me, to minister unto me, saith the Lord GOD, a young bullock for a sin offering.
21593	845	20	And thou shalt take of the blood thereof, and put it on the four horns of it, and on the four corners of the settle, and upon the border round about: thus shalt thou cleanse and purge it.
21594	845	21	Thou shalt take the bullock also of the sin offering, and he shall burn it in the appointed place of the house, without the sanctuary.
21595	845	22	And on the second day thou shalt offer a kid of the goats without blemish for a sin offering; and they shall cleanse the altar, as they did cleanse it with the bullock.
21596	845	23	When thou hast made an end of cleansing it, thou shalt offer a young bullock without blemish, and a ram out of the flock without blemish.
21597	845	24	And thou shalt offer them before the LORD, and the priests shall cast salt upon them, and they shall offer them up for a burnt offering unto the LORD.
21598	845	25	Seven days shalt thou prepare every day a goat for a sin offering: they shall also prepare a young bullock, and a ram out of the flock, without blemish.
21599	845	26	Seven days shall they purge the altar and purify it; and they shall consecrate themselves.
21600	845	27	And when these days are expired, it shall be, that upon the eighth day, and so forward, the priests shall make your burnt offerings upon the altar, and your peace offerings; and I will accept you, saith the Lord GOD.
21601	846	1	THEN he brought me back the way of the gate of the outward sanctuary which looketh toward the east; and it was shut.
21602	846	2	Then said the LORD unto me; This gate shall be shut, it shall not be opened, and no man shall enter in by it; because the LORD, the God of Israel, hath entered in by it, therefore it shall be shut.
21603	846	3	It is for the prince; the prince, he shall sit in it to eat bread before the LORD; he shall enter by the way of the porch of that gate, and shall go out by the way of the same.
21604	846	4	Then brought he me the way of the north gate before the house: and I looked, and, behold, the glory of the LORD filled the house of the LORD: and I fell upon my face.
21605	846	5	And the LORD said unto me, Son of man, mark well, and behold with thine eyes, and hear with thine ears all that I say unto thee concerning all the ordinances of the house of the LORD, and all the laws thereof; and mark well the entering in of the house, with every going forth of the sanctuary.
21606	846	6	And thou shalt say to the rebellious, even to the house of Israel, Thus saith the Lord GOD; O ye house of Israel, let it suffice you of all your abominations,
21607	846	7	In that ye have brought into my sanctuary strangers, uncircumcised in heart, and uncircumcised in flesh, to be in my sanctuary, to pollute it, even my house, when ye offer my bread, the fat and the blood, and they have broken my covenant because of all your abominations.
21608	846	8	And ye have not kept the charge of mine holy things: but ye have set keepers of my charge in my sanctuary for yourselves.
21609	846	9	Thus saith the Lord GOD; No stranger, uncircumcised in heart, nor uncircumcised in flesh, shall enter into my sanctuary, of any stranger that is among the children of Israel.
21610	846	10	And the Levites that are gone away far from me, when Israel went astray, which went astray away from me after their idols; they shall even bear their iniquity.
21611	846	11	Yet they shall be ministers in my sanctuary, having charge at the gates of the house, and ministering to the house: they shall slay the burnt offering and the sacrifice for the people, and they shall stand before them to minister unto them.
21612	846	12	Because they ministered unto them before their idols, and caused the house of Israel to fall into iniquity; therefore have I lifted up mine hand against them, saith the Lord GOD and they shall bear their iniquity.
21613	846	13	And they shall not come near unto me, to do the office of a priest unto me, nor to come near to any of my holy things, in the most holy place: but they shall bear their shame, and their abominations which they have committed.
21614	846	14	But I will make them keepers of the charge of the house, for all the service thereof, and for all that shall be done therein.
21615	846	15	But the priests the Levites, the sons of Zadok, that kept the charge of my sanctuary when the children of Israel went astray from me, they shall come near to me to minister unto me, and they shall stand before me to offer unto me the fat and the blood, saith the Lord GOD:
21616	846	16	They shall enter into my sanctuary, and they shall come near to my table, to minister unto me, and they shall keep my charge.
21617	846	17	And it shall come to pass, that when they enter in at the gates of the inner court, they shall be clothed with linen garments; and no wool shall come upon them, whiles they minister in the gates of the inner court, and within.
21618	846	18	They shall have linen bonnets upon their heads, and shall have linen breeches upon their loins; they shall not gird themselves with any thing that causeth sweat.
21619	846	19	And when they go forth into the utter court, even into the utter court to the people, they shall put off their garments wherein they ministered, and lay them in the holy chambers, and they shall put on other garments; and they shall not sanctify the people with their garments.
21620	846	20	Neither shall they shave their heads, nor suffer their locks to grow long; they shall only poll their heads.
21621	846	21	Neither shall any priest drink wine, when they enter into the inner court.
21622	846	22	Neither shall they take for their wives a widow, nor her that is put away: but they shall take maidens of the seed of the house of Israel, or a widow that had a priest before.
21623	846	23	And they shall teach my people the difference between the holy and profane, and cause them to discern between the unclean and the clean.
21624	846	24	And in controversy they shall stand in judgment; and they shall judge it according to my judgments: and they shall keep my laws and my statutes in all mine assemblies; and they shall hallow my sabbaths.
21625	846	25	And they shall come at no dead person to defile themselves: but for father, or for mother, or for son, or for daughter, for brother, or for sister that hath had no husband, they may defile themselves.
21626	846	26	And after he is cleansed, they shall reckon unto him seven days.
21627	846	27	And in the day that he goeth into the sanctuary, unto the inner court, to minister in the sanctuary, he shall offer his sin offering, saith the Lord GOD.
21628	846	28	And it shall be unto them for an inheritance: I am their inheritance: and ye shall give them no possession in Israel: I am their possession.
21629	846	29	They shall eat the meat offering, and the sin offering, and the trespass offering; and every dedicated thing in Israel shall be theirs.
21630	846	30	And the first of all the firstfruits of all things, and every oblation of all, of every sort of your oblations, shall be the priest's: ye shall also give unto the priest the first of your dough, that he may cause the blessing to rest in thine house.
21631	846	31	The priests shall not eat of any thing that is dead of itself, or torn, whether it be fowl or beast.
21632	847	1	MOREOVER, when ye shall divide by lot the land for inheritance, ye shall offer an oblation unto the LORD, an holy portion of the land: the length shall be the length of five and twenty thousand reeds, and the breadth shall be ten thousand. This shall be holy in all the borders thereof round about.
21633	847	2	Of this there shall be for the sanctuary five hundred in length, with five hundred in breadth, square round about; and fifty cubits round about for the suburbs thereof.
21634	847	3	And of this measure shalt thou measure the length of five and twenty thousand, and the breadth of ten thousand: and in it shall be the sanctuary and the most holy place.
21635	847	4	The holy portion of the land shall be for the priests the ministers of the sanctuary, which shall come near to minister unto the LORD: and it shall be a place for their houses, and an holy place for the sanctuary.
21636	847	5	And the five and twenty thousand of length, and the ten thousand of breadth, shall also the Levites, the ministers of the house, have for themselves, for a possession for twenty chambers.
21637	847	6	And ye shall appoint the possession of the city five thousand broad, and five and twenty thousand long, over against the oblation of the holy portion: it shall be for the whole house of Israel.
21638	847	7	And a portion shall be for the prince on the one side and on the other side of the oblation of the holy portion, and of the possession of the city, before the oblation of the holy portion, and before the possession of the city, from the west side westward, and from the east side eastward: and the length shall be over against one of the portions, from the west border unto the east border.
21639	847	8	In the land shall be his possession in Israel: and my princes shall no more oppress my people; and the rest of the land shall they give to the house of Israel according to their tribes.
21640	847	9	Thus saith the Lord GOD; Let it suffice you, O princes of Israel: remove violence and spoil, and execute judgment and justice, take away your exactions from my people, saith the Lord GOD.
21641	847	10	Ye shall have just balances, and a just ephah, and a just bath.
21642	847	11	The ephah and the bath shall be of one measure, that the bath may contain the tenth part of an homer, and the ephah the tenth part of an homer: the measure thereof shall be after the homer.
21643	847	12	And the shekel shall be twenty gerahs: twenty shekels, five and twenty shekels, fifteen shekels, shall be your maneh.
21644	847	13	This is the oblation that ye shall offer; the sixth part of an ephah of an homer of wheat, and ye shall give the sixth part of an ephah of an homer of barley:
21645	847	14	Concerning the ordinance of oil, the bath of oil, ye shall offer the tenth part of a bath out of the cor, which is an homer of ten baths; for ten baths are an homer:
21646	847	15	And one lamb out of the flock, out of two hundred, out of the fat pastures of Israel; for a meat offering, and for a burnt offering, and for peace offerings, to make reconciliation for them, saith the Lord GOD.
21647	847	16	All the people of the land shall give this oblation for the prince in Israel.
21648	847	17	And it shall be the prince's part to give burnt offerings, and meat offerings, and drink offerings, in the feasts, and in the new moons, and in the sabbaths, in all solemnities of the house of Israel: he shall prepare the sin offering, and the meat offering, and the burnt offering, and the peace offerings, to make reconciliation for the house of Israel.
21649	847	18	Thus saith the Lord GOD; In the first month, in the first day of the month, thou shalt take a young bullock without blemish, and cleanse the sanctuary:
21650	847	19	And the priest shall take of the blood of the sin offering, and put it upon the posts of the house, and upon the four corners of the settle of the altar, and upon the posts of the gate of the inner court.
21651	847	20	And so thou shalt do the seventh day of the month for every one that erreth, and for him that is simple: so shall ye reconcile the house.
21652	847	21	In the first month, in the fourteenth day of the month, ye shall have the passover, a feast of seven days; unleavened bread shall be eaten.
21653	847	22	And upon that day shall the prince prepare for himself and for all the people of the land a bullock for a sin offering.
21654	847	23	And seven days of the feast he shall prepare a burnt offering to the LORD, seven bullocks and seven rams without blemish daily the seven days; and a kid of the goats daily for a sin offering.
21655	847	24	And he shall prepare a meat offering of an ephah for a bullock, and an ephah for a ram, and an hin of oil for an ephah.
21656	847	25	In the seventh month, in the fifteenth day of the month, shall he do the like in the feast of the seven days, according to the sin offering, according to the burnt offering, and according to the meat offering, and according to the oil.
21657	848	1	THUS saith the Lord GOD; The gate of the inner court that looketh toward the east shall be shut the six working days; but on the sabbath it shall be opened, and in the day of the new moon it shall be opened.
21658	848	2	And the prince shall enter by the way of the porch of that gate without, and shall stand by the post of the gate, and the priests shall prepare his burnt offering and his peace offerings, and he shall worship at the threshold of the gate: then he shall go forth; but the gate shall not be shut until the evening.
21659	848	3	Likewise the people of the land shall worship at the door of this gate before the LORD in the sabbaths and in the new moons.
21660	848	4	And the burnt offering that the prince shall offer unto the LORD in the sabbath day shall be six lambs without blemish, and a ram without blemish.
21661	848	5	And the meat offering shall be an ephah for a ram, and the meat offering for the lambs as he shall be able to give, and an hin of oil to an ephah.
21662	848	6	And in the day of the new moon it shall be a young bullock without blemish, and six lambs, and a ram: they shall be without blemish.
21663	848	7	And he shall prepare a meat offering, an ephah for a bullock, and an ephah for a ram, and for the lambs according as his hand shall attain unto, and an hin of oil to an ephah.
21664	848	8	And when the prince shall enter, he shall go in by the way of the porch of that gate, and he shall go forth by the way thereof.
21665	848	9	But when the people of the land shall come before the LORD in the solemn feasts, he that entereth in by the way of the north gate to worship shall go out by the way of the south gate; and he that entereth by the way of the south gate shall go forth by the way of the north gate: he shall not return by the way of the gate whereby he came in, but shall go forth over against it.
21666	848	10	And the prince in the midst of them, when they go in, shall go in; and when they go forth, shall go forth.
21667	848	11	And in the feast and in the solemnities the meat offering shall be an ephah to a bullock, and ephah to a ram, and to the lambs as he is able to give, and an hin of oil to an ephah.
21668	848	12	Now when the prince shall prepare a voluntary burnt offering or peace offerings voluntarily unto the LORD, one shall then open him the gate that looketh toward the east, and he shall prepare his burnt offering and his peace offerings, as he did on the sabbath day: then he shall go forth; and after his going forth one shall shut the gate.
21669	848	13	Thou shalt daily prepare a burnt offering unto the LORD of a lamb of the first year without blemish: thou shalt prepare it every morning.
21670	848	14	And thou shalt prepare a meat offering for it every morning, the sixth part of an ephah, and the third part of an hin of oil, to temper with the fine flour; a meat offering continually by a perpetual ordinance unto the LORD.
21671	848	15	Thus shall they prepare the lamb, and the meat offering, and the oil, every morning for a continual burnt offering.
21672	848	16	Thus saith the Lord GOD; If the prince give a gift unto any of his sons, the inheritance thereof shall be his sons'; it shall be their possession by inheritance.
21673	848	17	But if he give a gift of his inheritance to one of his servants, then it shall be his to the year of liberty; after it shall return to the prince: but his inheritance shall be his sons' for them.
21674	848	18	Moreover the prince shall not take of the people's inheritance by oppression, to thrust them out of their possession; but he shall give his sons inheritance out of his own possession: that my people be not scattered every man from his possession.
21675	848	19	After he brought me through the entry, which was at the side of the gate, into the holy chambers of the priests, which looked toward the north: and, behold, there was a place on the two sides westward.
21676	848	20	Then said he unto me, This is the place where the priests shall boil the trespass offering and the sin offering, where they shall bake the meat offering; that they bear them not out into the utter court, to sanctify the people.
21677	848	21	Then he brought me forth into the utter court, and caused me to pass by the four corners of the court; and, behold, in every corner of the court there was a court.
21678	848	22	In the four corners of the court there were courts joined of forty cubits long and thirty broad: these four corners were of one measure.
21679	848	23	And there was a row of building round about in them, round about them four, and it was made with boiling places under the rows round about.
21680	848	24	Then said he unto me, These are the places of them that boil, where the ministers of the house shall boil the sacrifice of the people.
21681	849	1	AFTERWARD he brought me again unto the door of the house; and, behold, waters issued out from under the threshold of the house eastward: for the forefront of the house stood toward the east, and the waters came down from under from the right side of the house, at the south side of the altar.
21682	849	2	Then brought he me out of the way of the gate northward, and led me about the way without unto the utter gate by the way that looketh eastward; and, behold, there ran out waters on the right side.
21683	849	3	And when the man that had the line in his hand went forth eastward, he measured a thousand cubits, and he brought me through the waters; the waters were to the ankles.
21684	849	4	Again he measured a thousand, and brought me through the waters; the waters were to the knees. Again he measured a thousand, and brought me through; the waters were to the loins.
21685	849	5	Afterward he measured a thousand; and it was a river that I could not pass over: for the waters were risen, waters to swim in, a river that could not be passed over.
21686	849	6	And he said unto me, Son of man, hast thou seen this? Then he brought me, and caused me to return to the brink of the river.
21687	849	7	Now when I had returned, behold, at the bank of the river were very many trees on the one side and on the other.
21688	849	8	Then said he unto me, These waters issue out toward the east country, and go down into the desert, and go into the sea: which being brought forth into the sea, the waters shall be healed.
21689	849	9	And it shall come to pass, that every thing that liveth, which moveth, whithersoever the rivers shall come, shall live: and there shall be a very great multitude of fish, because these waters shall come thither: for they shall be healed; and every thing shall live whither the river cometh.
21690	849	10	And it shall come to pass, that the fishers shall stand upon it from En-gedi even unto En-eglaim; they shall be a place to spread forth nets; their fish shall be according to their kinds, as the fish of the great sea, exceeding many.
21691	849	11	But the miry places thereof and the marishes thereof shall not be healed; they shall be given to salt.
21692	849	12	And by the river upon the bank thereof, on this side and on that side, shall grow all trees for meat, whose leaf shall not fade, neither shall the fruit thereof be consumed: it shall bring forth new fruit according to his months, because their waters they issued out of the sanctuary: and the fruit thereof shall be for meat, and the leaf thereof for medicine.
21693	849	13	Thus saith the Lord GOD; This shall be the border, whereby ye shall inherit the land according to the twelve tribes of Israel: Joseph shall have two portions.
21694	849	14	And ye shall inherit it, one as well as another: concerning the which I lifted up mine hand to give it unto your fathers: and this land shall fall unto you for inheritance.
21695	849	15	And this shall be the border of the land toward the north side, from the great sea, the way of Hethlon, as men go to Zedad;
21696	849	16	Hamath, Berothah, Sibraim, which is between the border of Damascus and the border of Hamath; Hazar-hatticon, which is by the coast of Hauran.
21697	849	17	And the border from the sea shall be Hazar-enan, the border of Damascus, and the north northward, and the border of Hamath. And this is the north side.
21698	849	18	And the east side ye shall measure from Hauran, and from Damascus, and from Gilead, and from the land of Israel by Jordan, from the border unto the east sea. And this is the east side.
21699	849	19	And the south side southward, from Tamar even to the waters of strife in Kadesh, the river to the great sea. And this is the south side southward.
21700	849	20	The west side also shall be the great sea from the border, till a man come over against Hamath. This is the west side.
21701	849	21	So shall ye divide this land unto you according to the tribes of Israel.
21702	849	22	And it shall come to pass, that ye shall divide it by lot for an inheritance unto you, and to the strangers that sojourn among you, which shall beget children among you: and they shall be unto you as born in the country among the children of Israel; they shall have inheritance with you among the tribes of Israel.
21703	849	23	And it shall come to pass, that in what tribe the stranger sojourneth, there shall ye give him his inheritance, saith the Lord GOD.
21704	850	1	NOW these are the names of the tribes. From the north end to the coast of the way of Hethlon, as one goeth to Hamath, Hazar-enan, the border of Damascus northward, to the coast of Hamath; for these are his sides east and west; a portion for Dan.
21705	850	2	And by the border of Dan, from the east side unto the west side, a portion for Asher.
21706	850	3	And by the border of Asher, from the east side even unto the west side, a portion for Naphtali.
21707	850	4	And by the border of Naphtali, from the east side unto the west side, a portion for Manasseh.
21708	850	5	And by the border of Manasseh, from the east side unto the west side, a portion for Ephraim.
21709	850	6	And by the border of Ephraim, from the east side even unto the west side, a portion for Reuben.
21710	850	7	And by the border of Reuben, from the east side unto the west side, a portion for Judah.
21711	850	8	And by the border of Judah, from the east side unto the west side, shall be the offering which ye shall offer of five and twenty thousand reeds in breadth, and in length as one of the other parts, from the east side unto the west side: and the sanctuary shall be in the midst of it.
21712	850	9	The oblation that ye shall offer unto the LORD shall be of five and twenty thousand in length, and of ten thousand in breadth.
21713	850	10	And for them, even for the priests, shall be this holy oblation; toward the north five and twenty thousand in length, and toward the west ten thousand in breadth, and toward the east ten thousand in breadth, and toward the south five and twenty thousand in length: and the sanctuary of the LORD shall be in the midst thereof.
21714	850	11	It shall be for the priests that are sanctified of the sons of Zadok; which have kept my charge, which went not astray when the children of Israel went astray, as the Levites went astray.
21715	850	12	And this oblation of the land that is offered shall be unto them a thing most holy by the border of the Levites.
21716	850	13	And over against the border of the priests the Levites shall have five and twenty thousand in length, and ten thousand in breadth: all the length shall be five and twenty thousand, and the breadth ten thousand.
21717	850	14	And they shall not sell of it, neither exchange, nor alienate the firstfruits of the land: for it is holy unto the LORD.
21718	850	15	And the five thousand, that are left in the breadth over against the five and twenty thousand, shall be a profane place for the city, for dwelling, and for suburbs: and the city shall be in the midst thereof.
21719	850	16	And these shall be the measures thereof; the north side four thousand and five hundred, and the south side four thousand and five hundred, and on the east side four thousand and five hundred, and the west side four thousand and five hundred.
21720	850	17	And the suburbs of the city shall be toward the north two hundred and fifty, and toward the south two hundred and fifty, and toward the east two hundred and fifty, and toward the west two hundred and fifty.
21721	850	18	And the residue in length over against the oblation of the holy portion shall be ten thousand eastward, and ten thousand westward: and it shall be over against the oblation of the holy portion; and the increase thereof shall be for food unto them that serve the city.
21722	850	19	And they that serve the city shall serve it out of all the tribes of Israel.
21723	850	20	All the oblation shall be five and twenty thousand by five and twenty thousand: ye shall offer the holy oblation foursquare, with the possession of the city.
21724	850	21	And the residue shall be for the prince, on the one side and on the other of the holy oblation, and of the possession of the city, over against the five and twenty thousand of the oblation toward the east border, and westward over against the five and twenty thousand toward the west border, over against the portions for the prince: and it shall be the holy oblation; and the sanctuary of the house shall be in the midst thereof.
21725	850	22	Moreover from the possession of the Levites, and from the possession of the city, being in the midst of that which is the prince's, between the border of Judah and the border of Benjamin, shall be for the prince.
21726	850	23	As for the rest of the tribes, from the east side unto the west side, Benjamin shall have a portion.
21727	850	24	And by the border of Benjamin, from the east side unto the west side, Simeon shall have a portion.
21728	850	25	And by the border of Simeon, from the east side unto the west side, Issachar a portion.
21729	850	26	And by the border of Issachar, from the east side unto the west side, Zebulun a portion.
21730	850	27	And by the border of Zebulun, from the east side unto the west side, Gad a portion.
21731	850	28	And by the border of Gad, at the south side southward, the border shall be even from Tamar unto the waters of strife in Kadesh, and to the river toward the great sea.
21732	850	29	This is the land which ye shall divide by lot unto the tribes of Israel for inheritance, and these are their portions, saith the Lord GOD.
21733	850	30	And these are the goings out of the city on the north side, four thousand and five hundred measures.
21734	850	31	And the gates of the city shall be after the names of the tribes of Israel: three gates northward; one gate of Reuben, one gate of Judah, one gate of Levi.
21735	850	32	And at the east side four thousand and five hundred: and three gates; and one gate of Joseph, one gate of Benjamin, one gate of Dan.
21736	850	33	And at the south side four thousand and five hundred measures: and three gates; one gate of Simeon, one gate of Issachar, one gate of Zebulun.
21737	850	34	At the west side four thousand and five hundred, with their three gates; one gate of Gad, one gate of Asher, one gate of Naphtali.
21738	850	35	It was round about eighteen thousand measures: and the name of the city from that day shall be, The LORD is there.
21739	851	1	IN the third year of the reign of Jehoiakim king of Judah came Nebuchadnezzar king of Babylon unto Jerusalem, and besieged it.
21740	851	2	And the Lord gave Jehoiakim king of Judah into his hand, with part of the vessels of the house of God: which he carried into the land of Shinar to the house of his god; and he brought the vessels into the treasure house of his god.
21741	851	3	And the king spake unto Ashpenaz the master of his eunuchs, that he should bring certain of the children of Israel, and of the king's seed, and of the princes;
21742	851	4	Children in whom was no blemish, but well favoured, and skilful in all wisdom, and cunning in knowledge, and understanding science, and such as had ability in them to stand in the king's palace, and whom they might teach the learning and the tongue of the Chaldeans.
21743	851	5	And the king appointed them a daily provision of the king's meat, and of the wine which he drank: so nourishing them three years, that at the end thereof they might stand before the king.
21744	851	6	Now among these were of the children of Judah, Daniel, Hananiah, Mishael, and Azariah:
21745	851	7	Unto whom the prince of the eunuchs gave names: for he gave unto Daniel the name of Belteshazzar; and to Hananiah, of Shadrach; and to Mishael, of Meshach; and to Azariah, of Abed-nego.
21746	851	8	But Daniel purposed in his heart that he would not defile himself with the portion of the king's meat, nor with the wine which he drank: therefore he requested of the prince of the eunuchs that he might not defile himself.
21747	851	9	Now God had brought Daniel into favour and tender love with the prince of the eunuchs.
21748	851	10	And the prince of the eunuchs said unto Daniel, I fear my lord the king, who hath appointed your meat and your drink: for why should he see your faces worse liking than the children which are of your sort? then shall ye make me endanger my head to the king.
21749	851	11	Then said Daniel to Melzar, whom the prince of the eunuchs had set over Daniel, Hananiah, Mishael, and Azariah,
21750	851	12	Prove thy servants, I beseech thee, ten days; and let them give us pulse to eat, and water to drink.
21751	851	13	Then let our countenances be looked upon before thee, and the countenance of the children that eat of the portion of the king's meat: and as thou seest, deal with thy servants.
21752	851	14	So he consented to them in this matter, and proved them ten days.
21753	851	15	And at the end of ten days their countenances appeared fairer and fatter in flesh than all the children which did eat the portion of the king's meat.
21754	851	16	Thus Melzar took away the portion of their meat, and the wine that they should drink; and gave them pulse.
21755	851	17	As for these four children, God gave them knowledge and skill in all learning and wisdom: and Daniel had understanding in all visions and dreams.
21756	851	18	Now at the end of the days that the king had said he should bring them in, then the prince of the eunuchs brought them in before Nebuchadnezzar.
21757	851	19	And the king communed with them; and among them all was found none like Daniel, Hananiah, Mishael, and Azariah: therefore stood they before the king.
21758	851	20	And in all matters of wisdom and understanding, that the king enquired of them, he found them ten times better than all the magicians and astrologers that were in all his realm.
21759	851	21	And Daniel continued even unto the first year of king Cyrus.
21760	852	1	AND in the second year of the reign of Nebuchadnezzar Nebuchadnezzar dreamed dreams, wherewith his spirit was troubled, and his sleep brake from him.
21761	852	2	Then the king commanded to call the magicians, and the astrologers, and the sorcerers, and the Chaldeans, for to shew the king his dreams. So they came and stood before the king.
21762	852	3	And the king said unto them, I have dreamed a dream, and my spirit was troubled to know the dream.
21763	852	4	Then spake the Chaldeans to the king in Syriack, O king, live for ever: tell thy servants the dream, and we will shew the interpretation,
21764	852	5	The king answered and said to the Chaldeans, The thing is gone from me: if ye will not make known unto me the dream, with the interpretation thereof, ye shall be cut in pieces, and your houses shall be made a dunghill.
21765	852	6	But if ye shew the dream, and the interpretation thereof, ye shall receive of me gifts and rewards and great honour: therefore shew me the dream, and the interpretation thereof.
21766	852	7	They answered again and said, Let the king tell his servants the dream, and we will shew the interpretation of it.
21767	852	8	The king answered and said, I know of certainty that ye would gain the time, because ye see the thing is gone from me.
21768	852	9	But if ye will not make known unto me the dream, there is but one decree for you: for ye have prepared lying and corrupt words to speak before me, till the time be changed: therefore tell me the dream, and I shall know that ye can shew me the interpretation thereof.
21769	852	10	The Chaldeans answered before the king, and said, There is not a man upon the earth that can shew the king's matter: therefore there is no king, lord, nor ruler, that asked such things at any magician, or astrologer, or Chaldean.
21770	852	11	And it is a rare thing that the king requireth, and there is none other that can shew it before the king, except the gods, whose dwelling is not with flesh.
21771	852	12	For this cause the king was angry and very furious, and commanded to destroy all the wise men of Babylon.
21772	852	13	And the decree went forth that the wise men should be slain; and they sought Daniel and his fellows to be slain.
21773	852	14	Then Daniel answered with counsel and wisdom to Arioch the captain of the king's guard, which was gone forth to slay the wise men of Babylon:
21774	852	15	He answered and said to Arioch the king's captain, Why is the decree so hasty from the king? Then Arioch made the thing known to Daniel.
21775	852	16	Then Daniel went in, and desired of the king that he would give him time, and that he would shew the king the interpretation.
21776	852	17	Then Daniel went to his house, and made the thing known to Hananiah, Mishael, and Azariah, his companions:
21777	852	18	That they would desire mercies of the God of heaven concerning this secret; that Daniel and his fellows should not perish with the rest of the wise men of Babylon.
21778	852	19	Then was the secret revealed unto Daniel in a night vision. Then Daniel blessed the God of heaven.
21779	852	20	Daniel answered and said, Blessed be the name of God for ever and ever: for wisdom and might are his:
21780	852	21	And he changeth the times and the seasons: he removeth kings, and setteth up kings: he giveth wisdom unto the wise, and knowledge to them that know understanding:
21781	852	22	He revealeth the deep and secret things: he knoweth what is in the darkness, and the light dwelleth with him.
21782	852	23	I thank thee, and praise thee, O thou God of my fathers, who hast given me wisdom and might, and hast made known unto me now what we desired of thee: for thou hast now made known unto us the king's matter.
21783	852	24	Therefore Daniel went in unto Arioch, whom the king had ordained to destroy the wise men of Babylon: he went and said thus unto him; Destroy not the wise men of Babylon: bring me in before the king, and I will shew unto the king the interpretation.
21784	852	25	Then Arioch brought in Daniel before the king in haste, and said thus unto him, I have found a man of the captives of Judah, that will make known unto the king the interpretation.
21785	852	26	The king answered and said to Daniel, whose name was Belteshazzar, Art thou able to make known unto me the dream which I have seen, and the interpretation thereof?
21786	852	27	Daniel answered in the presence of the king, and said, The secret which the king hath demanded cannot the wise men, the astrologers, the magicians, the soothsayers, shew unto the king;
21787	852	28	But there is a God in heaven that revealeth secrets, and maketh known to the king Nebuchadnezzar what shall be in the latter days. Thy dream, and the visions of thy head upon thy bed, are these;
21788	852	29	As for thee, O king, thy thoughts came into thy mind upon thy bed, what should come to pass hereafter: and he that revealeth secrets maketh known to thee what shall come to pass.
21789	852	30	But as for me, this secret is not revealed to me for any wisdom that I have more than any living, but for their sakes that shall make known the interpretation to the king, and that thou mightest know the thoughts of thy heart.
21790	852	31	Thou, O king, sawest, and behold a great image. This great image, whose brightness was excellent, stood before thee; and the form thereof was terrible.
21791	852	32	This image's head was of fine gold, his breast and his arms of silver, his belly and his thighs of brass,
21792	852	33	His legs of iron, his feet part of iron and part of clay.
21793	852	34	Thou sawest till that a stone was cut out without hands, which smote the image upon his feet that were of iron and clay, and brake them to pieces.
21794	852	35	Then was the iron, the clay, the brass, the silver, and the gold, broken to pieces together, and became like the chaff of the summer threshingfloors; and the wind carried them away, that no place was found for them: and the stone that smote the image became a great mountain, and filled the whole earth.
21795	852	36	This is the dream; and we will tell the interpretation thereof before the king.
21796	852	37	Thou, O king, art a king of kings: for the God of heaven hath given thee a kingdom, power, and strength, and glory.
21797	852	38	And wheresoever the children of men dwell, the beasts of the field and the fowls of the heaven hath he given into thine hand, and hath made thee ruler over them all. Thou art this head of gold.
21798	852	39	And after thee shall arise another kingdom inferior to thee, and another third kingdom of brass, which shall bear rule over all the earth.
21799	852	40	And the fourth kingdom shall be strong as iron: forasmuch as iron breaketh in pieces and subdueth all things: and as iron that breaketh all these, shall it break in pieces and bruise.
21800	852	41	And whereas thou sawest the feet and toes, part of potters' clay, and part of iron, the kingdom shall be divided; but there shall be in it of the strength of the iron, forasmuch as thou sawest the iron mixed with miry clay.
21801	852	42	And as the toes of the feet were part of iron, and part of clay, so the kingdom shall be partly strong, and partly broken.
21802	852	43	And whereas thou sawest iron mixed with miry clay, they shall mingle themselves with the seed of men: but they shall not cleave one to another, even as iron is not mixed with clay.
21803	852	44	And in the days of these kings shall the God of heaven set up a kingdom, which shall never be destroyed: and the kingdom shall not be left to other people, but it shall break in pieces and consume all these kingdoms, and it shall stand for ever.
21804	852	45	Forasmuch as thou sawest that the stone was cut out of the mountain without hands, and that it brake in pieces the iron, the brass, the clay, the silver, and the gold; the great God hath made known to the king what shall come to pass hereafter: and the dream is certain, and the interpretation thereof sure.
21805	852	46	Then the king Nebuchadnezzar fell upon his face, and worshipped Daniel, and commanded that they should offer an oblation and sweet odours unto him.
21806	852	47	The king answered unto Daniel, and said, Of a truth it is, that your God is a God of gods, and a Lord of kings, and a revealer of secrets, seeing thou couldest reveal this secret.
21807	852	48	Then the king made Daniel a great man, and gave him many great gifts, and made him ruler over the whole province of Babylon, and chief of the governors over all the wise men of Babylon.
21808	852	49	Then Daniel requested of the king, and he set Shadrach, Meshach, and Abed-nego, over the affairs of the province of Babylon: but Daniel sat in the gate of the king.
21809	853	1	NEBUCHADNEZZAR the king made an image of gold, whose height was threescore cubits, and the breadth thereof six cubits: he set it up in the plain of Dura, in the province of Babylon.
21810	853	2	Then Nebuchadnezzar the king sent to gather together the princes, the governors, and the captains, the judges, the treasurers, the counsellors, the sheriffs, and all the rulers of the provinces, to come to the dedication of the image which Nebuchadnezzar the king had set up.
21811	853	3	Then the princes, the governors, and captains, the judges, the treasurers, the counsellors, the sheriffs, and all the rulers of the provinces, were gathered together unto the dedication of the image that Nebuchadnezzar the king had set up; and they stood before the image that Nebuchadnezzar had set up.
21812	853	4	Then an herald cried aloud, To you it is commanded, O people, nations, and languages,
21813	853	5	That at what time ye hear the sound of the cornet, flute, harp, sackbut, psaltery, dulcimer, and all kinds of musick, ye fall down and worship the golden image that Nebuchadnezzar the king hath set up:
21814	853	6	And whoso falleth not down and worshippeth shall the same hour be cast into the midst of a burning fiery furnace.
21815	853	7	Therefore at that time, when all the people heard the sound of the cornet, flute, harp, sackbut, psaltery, and all kinds of musick, all the people, the nations, and the languages, fell down and worshipped the golden image that Nebuchadnezzar the king had set up.
21816	853	8	Wherefore at that time certain Chaldeans came near, and accused the Jews.
21817	853	9	They spake and said to the king Nebuchadnezzar, O king, live for ever.
21818	853	10	Thou, O king, hast made a decree, that every man that shall hear the sound of the cornet, flute, harp, sackbut, psaltery, and dulcimer, and all kinds of musick, shall fall down and worship the golden image:
21819	853	11	And whoso falleth not down and worshippeth, that he should be cast into the midst of a burning fiery furnace.
21820	853	12	There are certain Jews whom thou hast set over the affairs of the province of Babylon, Shadrach, Meshach, and Abed-nego; these men, O king, have not regarded thee: they serve not thy gods, nor worship the golden image which thou hast set up.
21821	853	13	Then Nebuchadnezzar in his rage and fury commanded to bring Shadrach, Meshach, and Abed-nego. Then they brought these men before the king.
21822	853	14	Nebuchadnezzar spake and said unto them, Is it true, O Shadrach, Meshach, and Abed-nego, do not ye serve my gods, nor worship the golden image which I have set up?
21823	853	15	Now if ye be ready that at what time ye hear the sound of the cornet, flute, harp, sackbut, psaltery, and dulcimer, and all kinds of musick, ye fall down and worship the image which I have made; well: but if ye worship not, ye shall be cast the same hour into the midst of a burning fiery furnace; and who is that God that shall deliver you out of my hands?
21824	853	16	Shadrach, Meshach, and Abed-nego, answered and said to the king, O Nebuchadnezzar, we are not careful to answer thee in this matter.
21825	853	17	If it be so, our God whom we serve is able to deliver us from the burning fiery furnace, and he will deliver us out of thine hand, O king.
21826	853	18	But if not, be it known unto thee, O king, that we will not serve thy gods, nor worship the golden image which thou hast set up.
21827	853	19	Then was Nebuchadnezzar full of fury, and the form of his visage was changed against Shadrach, Meshach, and Abed-nego: therefore he spake, and commanded that they should heat the furnace one seven times more than it was wont to be heated.
21828	853	20	And he commanded the most mighty men that were in his army to bind Shadrach, Meshach, and Abed-nego, and to cast them into the burning fiery furnace.
21829	853	21	Then these men were bound in their coats, their hosen, and their hats, and their other garments, and were cast into the midst of the burning fiery furnace.
21830	853	22	Therefore because the king's commandment was urgent, and the furnace exceeding hot, the flame of the fire slew those men that took up Shadrach, Meshach, and Abed-nego.
21831	853	23	And these three men, Shadrach, Meshach, and Abed-nego, fell down bound into the midst of the burning fiery furnace.
21832	853	24	Then Nebuchadnezzar the king was astonied, and rose up in haste, and spake, and said unto his counsellors, Did not we cast three men bound into the midst of the fire? They answered and said unto the king, True, O king.
21833	853	25	He answered and said, Lo, I see four men loose, walking in the midst of the fire, and they have no hurt; and the form of the fourth is like the Son of God.
21834	853	26	Then Nebuchadnezzar came near to the mouth of the burning fiery furnace, and spake, and said, Shadrach, Meshach, and Abed-nego, ye servants of the most high God, come forth, and come hither. Then Shadrach, Meshach, and Abed-nego, came forth of the midst of the fire.
21835	853	27	And the princes, governors, and captains, and the king's counsellors, being gathered together, saw these men, upon whose bodies the fire had no power, nor was an hair of their head singed, neither were their coats changed, nor the smell of fire had passed on them.
21836	853	28	Then Nebuchadnezzar spake, and said, Blessed be the God of Shadrach, Meshach, and Abed-nego, who hath sent his angel, and delivered his servants that trusted in him, and have changed the king's word, and yielded their bodies, that they might not serve nor worship any god, except their own God.
21837	853	29	Therefore I make a decree, That every people, nation, and language, which speak any thing amiss against the God of Shadrach, Meshach, and Abed-nego, shall be cut in pieces, and their houses shall be made a dunghill: because there is no other God that can deliver after this sort.
21838	853	30	Then the king promoted Shadrach, Meshach, and Abed-nego, in the province of Babylon.
21839	854	1	NEBUCHADNEZZAR the king, unto all people, nations, and languages, that dwell in all the earth; Peace be multiplied unto you.
21840	854	2	I thought it good to shew the signs and wonders that the high God hath wrought toward me.
21841	854	3	How great are his signs! and how mighty are his wonders! his kingdom is an everlasting kingdom, and his dominion is from generation to generation.
21842	854	4	I Nebuchadnezzar was at rest in mine house, and flourishing in my palace:
21843	854	5	I saw a dream which made me afraid, and the thoughts upon my bed and the visions of my head troubled me.
21844	854	6	Therefore made I a decree to bring in all the wise men of Babylon before me, that they might make known unto me the interpretation of the dream.
21845	854	7	Then came in the magicians, the astrologers, the Chaldeans, and the soothsayers: and I told the dream before them; but they did not make known unto me the interpretation thereof.
21846	854	8	But at the last Daniel came in before me, whose name was Belteshazzar, according to the name of my god, and in whom is the spirit of the holy gods: and before him I told the dream, saying,
21847	854	9	O Belteshazzar, master of the magicians, because I know that the spirit of the holy gods is in thee, and no secret troubleth thee, tell me the visions of my dream that I have seen, and the interpretation thereof.
21848	854	10	Thus were the visions of mine head in my bed; I saw, and behold a tree in the midst of the earth, and the height thereof was great.
21849	854	11	The tree grew, and was strong, and the height thereof reached unto heaven, and the sight thereof to the end of all the earth:
21850	854	12	The leaves thereof were fair, and the fruit thereof much, and in it was meat for all: the beasts of the field had shadow under it, and the fowls of the heaven dwelt in the boughs thereof, and all flesh was fed of it.
21851	854	13	I saw in the visions of my head upon my bed, and, behold, a watcher and an holy one came down from heaven;
21852	854	14	He cried aloud, and said thus, Hew down the tree, and cut off his branches, shake off his leaves, and scatter his fruit: let the beasts get away from under it, and the fowls from his branches:
21853	854	15	Nevertheless leave the stump of his roots in the earth, even with a band of iron and brass, in the tender grass of the field; and let it be wet with the dew of heaven, and let his portion be with the beasts in the grass of the earth:
21854	854	16	Let his heart be changed from man's, and let a beast's heart be given unto him; and let seven times pass over him.
21855	854	17	This matter is by the decree of the watchers, and the demand by the word of the holy ones: to the intent that the living may know that the most High ruleth in the kingdom of men, and giveth it to whomsoever he will, and setteth up over it the basest of men.
21856	854	18	This dream I king Nebuchadnezzar have seen. Now thou, O Belteshazzar, declare the interpretation thereof, forasmuch as all the wise men of my kingdom are not able to make known unto me the interpretation: but thou art able; for the spirit of the holy gods is in thee.
21857	854	19	Then Daniel, whose name was Belteshazzar, was astonied for one hour, and his thoughts troubled him. The king spake, and said, Belteshazzar, let not the dream, or the interpretation thereof, trouble thee. Belteshazzar answered and said, My lord, the dream be to them that hate thee, and the interpretation thereof to thine enemies.
21858	854	20	The tree that thou sawest, which grew, and was strong, whose height reached unto the heaven, and the sight thereof to all the earth;
21859	854	21	Whose leaves were fair, and the fruit thereof much, and in it was meat for all; under which the beasts of the field dwelt, and upon whose branches the fowls of the heaven had their habitation:
21860	854	22	It is thou, O king, that art grown and become strong: for thy greatness is grown, and reacheth unto heaven, and thy dominion to the end of the earth.
21861	854	23	And whereas the king saw a watcher and an holy one coming down from heaven, and saying, Hew the tree down, and destroy it; yet leave the stump of the roots thereof in the earth, even with a band of iron and brass, in the tender grass of the field; and let it be wet with the dew of heaven, and let his portion be with the beasts of the field, till seven times pass over him;
21862	854	24	This is the interpretation, O king, and this is the decree of the most High, which is come upon my lord the king:
21863	854	25	That they shall drive thee from men, and thy dwelling shall be with the beasts of the field, and they shall make thee to eat grass as oxen, and they shall wet thee with the dew of heaven, and seven times shall pass over thee, till thou know that the most High ruleth in the kingdom of men, and giveth it to whomsoever he will.
21864	854	26	And whereas they commanded to leave the stump of the tree roots; thy kingdom shall be sure unto thee, after that thou shalt have known that the heavens do rule.
21865	854	27	Wherefore, O king, let my counsel be acceptable unto thee, and break off thy sins by righteousness, and thine iniquities by shewing mercy to the poor; if it may be a lengthening of thy tranquillity.
21866	854	28	All this came upon the king Nebuchadnezzar.
21867	854	29	At the end of twelve months he walked in the palace of the kingdom of Babylon.
21868	854	30	The king spake, and said, Is not this great Babylon, that I have built for the house of the kingdom by the might of my power, and for the honour of my majesty?
21869	854	31	While the word was in the king's mouth, there fell a voice from heaven, saying, O king Nebuchadnezzar, to thee it is spoken; The kingdom is departed from thee.
21870	854	32	And they shall drive thee from men, and thy dwelling shall be with the beasts of the field: they shall make thee to eat grass as oxen, and seven times shall pass over thee, until thou know that the most High ruleth in the kingdom of men, and giveth it to whomsoever he will.
21871	854	33	The same hour was the thing fulfilled upon Nebuchadnezzar: and he was driven from men, and did eat grass as oxen, and his body was wet with the dew of heaven, till his hairs were grown like eagles' feathers, and his nails like birds' claws.
21872	854	34	And at the end of the days I Nebuchadnezzar lifted up mine eyes unto heaven, and mine understanding returned unto me, and I blessed the most High, and I praised and honoured him that liveth for ever, whose dominion is an everlasting dominion, and his kingdom is from generation to generation:
21873	854	35	And all the inhabitants of the earth are reputed as nothing: and he doeth according to his will in the army of heaven, and among the inhabitants of the earth: and none can stay his hand, or say unto him, What doest thou?
21874	854	36	At the same time my reason returned unto me; and for the glory of my kingdom, mine honour and brightness returned unto me; and my counsellors and my lords sought unto me; and I was established in my kingdom, and excellent majesty was added unto me.
21875	854	37	Now I Nebuchadnezzar praise and extol and honour the King of heaven, all whose works are truth, and his ways judgment: and those that walk in pride he is able to abase.
21876	855	1	BELSHAZZAR the king made a great feast to a thousand of his lords, and drank wine before the thousand.
21877	855	2	Belshazzar, whiles he tasted the wine, commanded to bring the golden and silver vessels which his father Nebuchadnezzar had taken out of the temple which was in Jerusalem; that the king, and his princes, his wives, and his concubines, might drink therein.
21878	855	3	Then they brought the golden vessels that were taken out of the temple of the house of God which was at Jerusalem; and the king, and his princes, his wives, and his concubines, drank in them.
21879	855	4	They drank wine, and praised the gods of gold, and of silver, of brass, of iron, of wood, and of stone.
21880	855	5	In the same hour came forth fingers of a man's hand, and wrote over against the candlestick upon the plaister of the wall of the king's palace: and the king saw the part of the hand that wrote.
21881	855	6	Then the king's countenance was changed, and his thoughts troubled him, so that the joints of his loins were loosed, and his knees smote one against another.
21882	855	7	The king cried aloud to bring in the astrologers, the Chaldeans, and the soothsayers. And the king spake, and said to the wise men of Babylon, Whosoever shall read this writing, and shew me the interpretation thereof, shall be clothed with scarlet, and have a chain of gold about his neck, and shall be the third ruler in the kingdom.
21883	855	8	Then came in all the king's wise men: but they could not read the writing, nor make known to the king the interpretation thereof.
21884	855	9	Then was king Belshazzar greatly troubled, and his countenance was changed in him, and his lords were astonied.
21885	855	10	Now the queen, by reason of the words of the king and his lords, came into the banquet house: and the queen spake and said, O king, live for ever: let not thy thoughts trouble thee, nor let thy countenance be changed:
21886	855	11	There is a man in thy kingdom, in whom is the spirit of the holy gods; and in the days of thy father light and understanding and wisdom, like the wisdom of the gods, was found in him; whom the king Nebuchadnezzar thy father, the king, I say, thy father, made master of the magicians, astrologers, Chaldeans, and soothsayers;
21887	855	12	Forasmuch as an excellent spirit, and knowledge, and understanding, interpreting of dreams, and shewing of hard sentences, and dissolving of doubts, were found in the same Daniel, whom the king named Belteshazzar: now let Daniel be called, and he will shew the interpretation.
21888	855	13	Then was Daniel brought in before the king. And the king spake and said unto Daniel, Art thou that Daniel, which art of the children of the captivity of Judah, whom the king my father brought out of Jewry?
21889	855	14	I have even heard of thee, that the spirit of the gods is in thee, and that light and understanding and excellent wisdom is found in thee.
21890	855	15	And now the wise men, the astrologers, have been brought in before me, that they should read this writing, and make known unto me the interpretation thereof: but they could not shew the interpretation of the thing:
21891	855	16	And I have heard of thee, that thou canst make interpretations, and dissolve doubts: now if thou canst read the writing, and make known to me the interpretation thereof, thou shalt be clothed with scarlet, and have a chain of gold about thy neck, and shalt be the third ruler in the kingdom.
21892	855	17	Then Daniel answered and said before the king, Let thy gifts be to thyself, and give thy rewards to another; yet I will read the writing unto the king, and make known to him the interpretation.
21893	855	18	O thou king, the most high God gave Nebuchadnezzar thy father a kingdom, and majesty, and glory, and honour:
21894	855	19	And for the majesty that he gave him, all people, nations, and languages, trembled and feared before him: whom he would he slew; and whom he would he kept alive; and whom he would he set up; and whom he would he put down.
21895	855	20	But when his heart was lifted up, and his mind hardened in pride, he was deposed from his kingly throne, and they took his glory from him:
21896	855	21	And he was driven from the sons of men; and his heart was made like the beasts, and his dwelling was with the wild asses: they fed him with grass like oxen, and his body was wet with the dew of heaven; till he knew that the most high God ruled in the kingdom of men, and that he appointeth over it whomsoever he will.
21897	855	22	And thou his son, O Belshazzar, hast not humbled thine heart, though thou knewest all this;
21898	855	23	But hast lifted up thyself against the Lord of heaven; and they have brought the vessels of his house before thee, and thou, and thy lords, thy wives, and thy concubines, have drunk wine in them; and thou hast praised the gods of silver, and gold, of brass, iron, wood, and stone, which see not, nor hear, nor know: and the God in whose hand thy breath is, and whose are all thy ways, hast thou not glorified:
21899	855	24	Then was the part of the hand sent from him; and this writing was written.
21900	855	25	And this is the writing that was written, MENE, MENE, TEKEL, UPHARSIN.
21901	855	26	This is the interpretation of the thing: MENE; God hath numbered thy kingdom, and finished it.
21902	855	27	TEKEL; Thou art weighed in the balances, and art found wanting.
21903	855	28	PERES; Thy kingdom is divided, and given to the Medes and Persians.
21904	855	29	Then commanded Belshazzar, and they clothed Daniel with scarlet, and put a chain of gold about his neck, and made a proclamation concerning him, that he should be the third ruler in the kingdom.
21905	855	30	In that night was Belshazzar the king of the Chaldeans slain.
21906	855	31	And Darius the Median took the kingdom, being about threescore and two years old.
21907	856	1	IT pleased Darius to set over the kingdom an hundred and twenty princes, which should be over the whole kingdom;
21908	856	2	And over these three presidents; of whom Daniel was first: that the princes might give accounts unto them, and the king should have no damage.
21909	856	3	Then this Daniel was preferred above the presidents and princes, because an excellent spirit was in him; and the king thought to set him over the whole realm.
21910	856	4	Then the presidents and princes sought to find occasion against Daniel concerning the kingdom; but they could find none occasion nor fault; forasmuch as he was faithful, neither was there any error or fault found in him.
21911	856	5	Then said these men, We shall not find any occasion against this Daniel, except we find it against him concerning the law of his God.
21912	856	6	Then these presidents and princes assembled together to the king, and said thus unto him, King Darius, live for ever.
21913	856	7	All the presidents of the kingdom, the governors, and the princes, the counsellors, and the captains, have consulted together to establish a royal statute, and to make a firm decree, that whosoever shall ask a petition of any God or man for thirty days, save of thee, O king, he shall be cast into the den of lions.
21914	856	8	Now, O king, establish the decree, and sign the writing, that it be not changed, according to the law of the Medes and Persians, which altereth not.
21915	856	9	Wherefore king Darius signed the writing and the decree.
21916	856	10	Now when Daniel knew that the writing was signed, he went into his house; and his windows being open in his chamber toward Jerusalem, he kneeled upon his knees three times a day, and prayed, and gave thanks before his God, as he did aforetime.
21917	856	11	Then these men assembled, and found Daniel praying and making supplication before his God.
21918	856	12	Then they came near, and spake before the king concerning the king's decree; Hast thou not signed a decree, that every man that shall ask a petition of any God or man within thirty days, save of thee, O king, shall be cast into the den of lions? The king answered and said, The thing is true, according to the law of the Medes and Persians, which altereth not.
21919	856	13	Then answered they and said before the king, That Daniel, which is of the children of the captivity of Judah, regardeth not thee, O king, nor the decree that thou hast signed, but maketh his petition three times a day.
21920	856	14	Then the king, when he heard these words, was sore displeased with himself, and set his heart on Daniel to deliver him: and he laboured till the going down of the sun to deliver him.
21921	856	15	Then these men assembled unto the king, and said unto the king, Know, O king, that the law of the Medes and Persians is, That no decree nor statute which the king establisheth may be changed.
21922	856	16	Then the king commanded, and they brought Daniel, and cast him into the den of lions. Now the king spake and said unto Daniel, Thy God whom thou servest continually, he will deliver thee.
21923	856	17	And a stone was brought, and laid upon the mouth of the den; and the king sealed it with his own signet, and with the signet of his lords; that the purpose might not be changed concerning Daniel.
21924	856	18	Then the king went to his palace, and passed the night fasting: neither were instruments of musick brought before him: and his sleep went from him.
21925	856	19	Then the king arose very early in the morning, and went in haste unto the den of lions.
21926	856	20	And when he came to the den, he cried with a lamentable voice unto Daniel: and the king spake and said to Daniel, O Daniel, servant of the living God, is thy God, whom thou servest continually, able to deliver thee from the lions?
21927	856	21	Then said Daniel unto the king, O king, live for ever.
21928	856	22	My God hath sent his angel, and hath shut the lions' mouths, that they have not hurt me: forasmuch as before him innocency was found in me; and also before thee, O king, have I done no hurt.
21929	856	23	Then was the king exceeding glad for him, and commanded that they should take Daniel up out of the den. So Daniel was taken up out of the den, and no manner of hurt was found upon him, because he believed in his God.
21930	856	24	And the king commanded, and they brought those men which had accused Daniel, and they cast them into the den of lions, them, their children, and their wives; and the lions had the mastery of them, and brake all their bones in pieces or ever they came at the bottom of the den.
21931	856	25	Then king Darius wrote unto all people, nations, and languages, that dwell in all the earth; Peace be multiplied unto you.
21932	856	26	I make a decree, That in every dominion of my kingdom men tremble and fear before the God of Daniel: for he is the living God, and stedfast for ever, and his kingdom that which shall not be destroyed, and his dominion shall be even unto the end.
21933	856	27	He delivereth and rescueth, and he worketh signs and wonders in heaven and in earth, who hath delivered Daniel from the power of the lions.
21934	856	28	So this Daniel prospered in the reign of Darius, and in the reign of Cyrus the Persian.
21935	857	1	IN the first year of Belshazzar king of Babylon Daniel had a dream and visions of his head upon his bed: then he wrote the dream, and told the sum of the matters.
21936	857	2	Daniel spake and said, I saw in my vision by night, and, behold, the four winds of the heaven strove upon the great sea.
21937	857	3	And four great beasts came up from the sea, diverse one from another.
21938	857	4	The first was like a lion, and had eagle's wings: I beheld till the wings thereof were plucked, and it was lifted up from the earth, and made stand upon the feet as a man, and a man's heart was given to it.
21939	857	5	And behold another beast, a second, like to a bear, and it raised up itself on one side, and it had three ribs in the mouth of it between the teeth of it: and they said thus unto it, Arise, devour much flesh.
21940	857	6	After this I beheld, and lo another, like a leopard, which had upon the back of it four wings of a fowl; the beast had also four heads; and dominion was given to it.
21941	857	7	After this I saw in the night visions, and behold a fourth beast, dreadful and terrible, and strong exceedingly; and it had great iron teeth: it devoured and brake in pieces, and stamped the residue with the feet of it: and it was diverse from all the beasts that were before it; and it had ten horns.
21942	857	8	I considered the horns, and, behold, there came up among them another little horn, before whom there were three of the first horns plucked up by the roots: and, behold, in this horn were eyes like the eyes of man, and a mouth speaking great things.
21943	857	9	I beheld till the thrones were cast down, and the Ancient of days did sit, whose garment was white as snow, and the hair of his head like the pure wool: his throne was like the fiery flame, and his wheels as burning fire.
21944	857	10	A fiery stream issued and came forth from before him: thousand thousands ministered unto him, and ten thousand times ten thousand stood before him: the judgment was set, and the books were opened.
21945	857	11	I beheld then because of the voice of the great words which the horn spake: I beheld even till the beast was slain, and his body destroyed, and given to the burning flame.
21946	857	12	As concerning the rest of the beasts, they had their dominion taken away: yet their lives were prolonged for a season and time.
21947	857	13	I saw in the night visions, and, behold, one like the Son of man came with the clouds of heaven, and came to the Ancient of days, and they brought him near before him.
21948	857	14	And there was given him dominion, and glory, and a kingdom, that all people, nations, and languages, should serve him: his dominion is an everlasting dominion, which shall not pass away, and his kingdom that which shall not be destroyed.
21949	857	15	I Daniel was grieved in my spirit in the midst of my body, and the visions of my head troubled me.
21950	857	16	I came near unto one of them that stood by, and asked him the truth of all this. So he told me, and made me know the interpretation of the things.
21951	857	17	These great beasts, which are four, are four kings, which shall arise out of the earth.
21952	857	18	But the saints of the most High shall take the kingdom, and possess the kingdom for ever, even for ever and ever.
21953	857	19	Then I would know the truth of the fourth beast, which was diverse from all the others, exceeding dreadful, whose teeth were of iron, and his nails of brass; which devoured, brake in pieces, and stamped the residue with his feet;
21954	857	20	And of the ten horns that were in his head, and of the other which came up, and before whom three fell; even of that horn that had eyes, and a mouth that spake very great things, whose look was more stout than his fellows.
21955	857	21	I beheld, and the same horn made war with the saints, and prevailed against them;
21956	857	22	Until the Ancient of days came, and judgment was given to the saints of the most High; and the time came that the saints possessed the kingdom.
21957	857	23	Thus he said, The fourth beast shall be the fourth kingdom upon earth, which shall be diverse from all kingdoms, and shall devour the whole earth, and shall tread it down, and break it in pieces.
21958	857	24	And the ten horns out of this kingdom are ten kings that shall arise: and another shall rise after them; and he shall be diverse from the first, and he shall subdue three kings.
21959	857	25	And he shall speak great words against the most High, and shall wear out the saints of the most High, and think to change times and laws: and they shall be given into his hand until a time and times and the dividing of time.
21960	857	26	But the judgment shall sit, and they shall take away his dominion, to consume and to destroy it unto the end.
21961	857	27	And the kingdom and dominion, and the greatness of the kingdom under the whole heaven, shall be given to the people of the saints of the most High, whose kingdom is an everlasting kingdom, and all dominions shall serve and obey him.
21962	857	28	Hitherto is the end of the matter. As for me Daniel, my cogitations much troubled me, and my countenance changed in me: but I kept the matter in my heart.
21963	858	1	IN the third year of the reign of king Belshazzar a vision appeared unto me, even unto me Daniel, after that which appeared unto me at the first.
21964	858	2	And I saw in a vision; and it came to pass, when I saw, that I was at Shushan in the palace, which is in the province of Elam; and I saw in a vision, and I was by the river of Ulai.
21965	858	3	Then I lifted up mine eyes, and saw, and, behold, there stood before the river a ram which had two horns: and the two horns were high; but one was higher than the other, and the higher came up last.
21966	858	4	I saw the ram pushing westward, and northward, and southward; so that no beasts might stand before him, neither was there any that could deliver out of his hand; but he did according to his will, and became great.
21967	858	5	And as I was considering, behold, an he goat came from the west on the face of the whole earth, and touched not the ground: and the goat had a notable horn between his eyes.
21968	858	6	And he came to the ram that had two horns, which I had seen standing before the river, and ran unto him in the fury of his power.
21969	858	7	And I saw him come close unto the ram, and he was moved with choler against him, and smote the ram, and brake his two horns: and there was no power in the ram to stand before him, but he cast him down to the ground, and stamped upon him: and there was none that could deliver the ram out of his hand.
21970	858	8	Therefore the he goat waxed very great: and when he was strong, the great horn was broken; and for it came up four notable ones toward the four winds of heaven.
21971	858	9	And out of one of them came forth a little horn, which waxed exceeding great, toward the south, and toward the east, and toward the pleasant land.
21972	858	10	And it waxed great, even to the host of heaven; and it cast down some of the host and of the stars to the ground, and stamped upon them.
21973	858	11	Yea, he magnified himself even to the prince of the host, and by him the daily sacrifice was taken away, and the place of his sanctuary was cast down.
21974	858	12	And an host was given him against the daily sacrifice by reason of transgression, and it cast down the truth to the ground; and it practised, and prospered.
21975	858	13	Then I heard one saint speaking, and another saint said unto that certain saint which spake, How long shall be the vision concerning the daily sacrifice, and the transgression of desolation, to give both the sanctuary and the host to be trodden under foot?
21976	858	14	And he said unto me, Unto two thousand and three hundred days; then shall the sanctuary be cleansed.
21977	858	15	And it came to pass, when I, even I Daniel, had seen the vision, and sought for the meaning, then, behold, there stood before me as the appearance of a man.
21978	858	16	And I heard a man's voice between the banks of Ulai, which called, and said, Gabriel, make this man to understand the vision.
21979	858	17	So he came near where I stood: and when he came, I was afraid, and fell upon my face: but he said unto me, Understand, O son of man: for at the time of the end shall be the vision.
21980	858	18	Now as he was speaking with me, I was in a deep sleep on my face toward the ground: but he touched me, and set me upright.
21981	858	19	And he said, Behold, I will make thee know what shall be in the last end of the indignation: for at the time appointed the end shall be.
21982	858	20	The ram which thou sawest having two horns are the kings of Media and Persia.
21983	858	21	And the rough goat is the king of Grecia: and the great horn that is between his eyes is the first king.
21984	858	22	Now that being broken, whereas four stood up for it, four kingdoms shall stand up out of the nation, but not in his power.
21985	858	23	And in the latter time of their kingdom, when the transgressors are come to the full, a king of fierce countenance, and understanding dark sentences, shall stand up.
21986	858	24	And his power shall be mighty, but not by his own power; and he shall destroy wonderfully, and shall prosper, and practise, and shall destroy the mighty and the holy people.
21987	858	25	And through his policy also he shall cause craft to prosper in his hand; and he shall magnify himself in his heart, and by peace shall destroy many: he shall also stand up against the Prince of princes; but he shall be broken without hand.
21988	858	26	And the vision of the evening and the morning which was told is true: wherefore shut thou up the vision; for it shall be for many days.
21989	858	27	And I Daniel fainted, and was sick certain days; afterward I rose up, and did the king's business; and I was astonished at the vision, but none understood it.
21990	859	1	IN the first year of Darius the son of Ahasuerus, of the seed of the Medes, which was made king over the realm of the Chaldeans;
21991	859	2	In the first year of his reign I Daniel understood by books the number of the years, whereof the word of the LORD came to Jeremiah the prophet, that he would accomplish seventy years in the desolations of Jerusalem.
21992	859	3	And I set my face unto the Lord God, to seek by prayer and supplications, with fasting, and sackcloth, and ashes:
21993	859	4	And I prayed unto the LORD my God, and made my confession, and said, O Lord, the great and dreadful God, keeping the covenant and mercy to them that love him, and to them that keep his commandments;
21994	859	5	We have sinned, and have committed iniquity, and have done wickedly, and have rebelled, even by departing from thy precepts and from thy judgments:
21995	859	6	Neither have we hearkened unto thy servants the prophets, which spake in thy name to our kings, our princes, and our fathers, and to all the people of the land.
21996	859	7	O Lord, righteousness belongeth unto thee, but unto us confusion of faces, as at this day; to the men of Judah, and to the inhabitants of Jerusalem, and unto all Israel, that are near, and that are far off, through all the countries whither thou hast driven them, because of their trespass that they have trespassed against thee.
21997	859	8	O Lord, to us belongeth confusion of face, to our kings, to our princes, and to our fathers, because we have sinned against thee.
21998	859	9	To the Lord our God belong mercies and forgivenesses, though we have rebelled against him;
21999	859	10	Neither have we obeyed the voice of the LORD our God, to walk in his laws, which he set before us by his servants the prophets.
22000	859	11	Yea, all Israel have transgressed thy law, even by departing, that they might not obey thy voice; therefore the curse is poured upon us, and the oath that is written in the law of Moses the servant of God, because we have sinned against him.
22001	859	12	And he hath confirmed his words, which he spake against us, and against our judges that judged us, by bringing upon us a great evil: for under the whole heaven hath not been done as hath been done upon Jerusalem.
22002	859	13	As it is written in the law of Moses, all this evil is come upon us: yet made we not our prayer before the LORD our God, that we might turn from our iniquities, and understand thy truth.
22003	859	14	Therefore hath the LORD watched upon the evil, and brought it upon us: for the LORD our God is righteous in all his works which he doeth: for we obeyed not his voice.
22004	859	15	And now, O Lord our God, that hast brought thy people forth out of the land of Egypt with a mighty hand, and hast gotten thee renown, as at this day; we have sinned, we have done wickedly.
22005	859	16	O Lord, according to all thy righteousness, I beseech thee, let thine anger and thy fury be turned away from thy city Jerusalem, thy holy mountain: because for our sins, and for the iniquities of our fathers, Jerusalem and thy people are become a reproach to all that are about us.
22006	859	17	Now therefore, O our God, hear the prayer of thy servant, and his supplications, and cause thy face to shine upon thy sanctuary that is desolate, for the Lord's sake.
22007	859	18	O my God, incline thine ear, and hear; open thine eyes, and behold our desolations, and the city which is called by thy name: for we do not present our supplications before thee for our righteousnesses, but for thy great mercies.
22008	859	19	O Lord, hear; O Lord, forgive; O Lord, hearken and do; defer not, for thine own sake, O my God: for thy city and thy people are called by thy name.
22009	859	20	And whiles I was speaking, and praying, and confessing my sin and the sin of my people Israel, and presenting my supplication before the LORD my God for the holy mountain of my God;
22010	859	21	Yea, whiles I was speaking in prayer, even the man Gabriel, whom I had seen in the vision at the beginning, being caused to fly swiftly, touched me about the time of the evening oblation.
22011	859	22	And he informed me, and talked with me, and said, O Daniel, I am now come forth to give thee skill and understanding.
22012	859	23	At the beginning of thy supplications the commandment came forth, and I am come to shew thee; for thou art greatly beloved: therefore understand the matter, and consider the vision.
22013	859	24	Seventy weeks are determined upon thy people and upon thy holy city, to finish the transgression, and to make an end of sins, and to make reconciliation for iniquity, and to bring in everlasting righteousness, and to seal up the vision and prophecy, and to anoint the most Holy.
22014	859	25	Know therefore and understand, that from the going forth of the commandment to restore and to build Jerusalem unto the Messiah the Prince shall be seven weeks, and threescore and two weeks: the street shall be built again, and the wall, even in troublous times.
22015	859	26	And after threescore and two weeks shall Messiah be cut off, but not for himself: and the people of the prince that shall come shall destroy the city and the sanctuary; and the end thereof shall be with a flood, and unto the end of the war desolations are determined.
22016	859	27	And he shall confirm the covenant with many for one week: and in the midst of the week he shall cause the sacrifice and the oblation to cease, and for the overspreading of abominations he shall make it desolate, even until the consummation, and that determined shall be poured upon the desolate.
22017	860	1	IN the third year of Cyrus king of Persia a thing was revealed unto Daniel, whose name was called Belteshazzar; and the thing was true, but the time appointed was long: and he understood the thing, and had understanding of the vision.
22018	860	2	In those days I Daniel was mourning three full weeks.
22019	860	3	I ate no pleasant bread, neither came flesh nor wine in my mouth, neither did I anoint myself at all, till three whole weeks were fulfilled.
22020	860	4	And in the four and twentieth day of the first month, as I was by the side of the great river, which is Hiddekel;
22021	860	5	Then I lifted up mine eyes, and looked, and behold a certain man clothed in linen, whose loins were girded with fine gold of Uphaz:
22022	860	6	His body also was like the beryl, and his face as the appearance of lightning, and his eyes as lamps of fire, and his arms and his feet like in colour to polished brass, and the voice of his words like the voice of a multitude.
22023	860	7	And I Daniel alone saw the vision: for the men that were with me saw not the vision; but a great quaking fell upon them, so that they fled to hide themselves.
22024	860	8	Therefore I was left alone, and saw this great vision, and there remained no strength in me: for my comeliness was turned in me into corruption, and I retained no strength.
22025	860	9	Yet heard I the voice of his words: and when I heard the voice of his words, then was I in a deep sleep on my face, and my face toward the ground.
22026	860	10	And, behold, an hand touched me, which set me upon my knees and upon the palms of my hands.
22027	860	11	And he said unto me, O Daniel, a man greatly beloved, understand the words that I speak unto thee, and stand upright: for unto thee am I now sent. And when he had spoken this word unto me, I stood trembling.
22028	860	12	Then said he unto me, Fear not, Daniel: for from the first day that thou didst set thine heart to understand, and to chasten thyself before thy God, thy words were heard, and I am come for thy words.
22029	860	13	But the prince of the kingdom of Persia withstood me one and twenty days: but, lo, Michael, one of the chief princes, came to help me; and I remained there with the kings of Persia.
22030	860	14	Now I am come to make thee understand what shall befall thy people in the latter days: for yet the vision is for many days.
22031	860	15	And when he had spoken such words unto me, I set my face toward the ground, and I became dumb.
22032	860	16	And, behold, one like the similitude of the sons of men touched my lips: then I opened my mouth, and spake, and said unto him that stood before me, O my lord, by the vision my sorrows are turned upon me, and I have retained no strength.
22033	860	17	For how can the servant of this my lord talk with this my lord? for as for me, straightway there remained no strength in me, neither is there breath left in me.
22034	860	18	Then there came again and touched me one like the appearance of a man, and he strengthened me,
22035	860	19	And said, O man greatly beloved, fear not: peace be unto thee, be strong, yea, be strong. And when he had spoken unto me, I was strengthened, and said, Let my lord speak; for thou hast strengthened me.
22036	860	20	Then said he, Knowest thou wherefore I come unto thee? and now will I return to fight with the prince of Persia: and when I am gone forth, lo, the prince of Grecia shall come.
22037	860	21	But I will shew thee that which is noted in the scripture of truth: and there is none that holdeth with me in these things, but Michael your prince.
22038	861	1	ALSO I in the first year of Darius the Mede, even I, stood to confirm and to strengthen him.
22039	861	2	And now will I shew thee the truth. Behold, there shall stand up yet three kings in Persia; and the fourth shall be far richer than they all: and by his strength through his riches he shall stir up all against the realm of Grecia.
22040	861	3	And a mighty king shall stand up, that shall rule with great dominion, and do according to his will.
22041	861	4	And when he shall stand up, his kingdom shall be broken, and shall be divided toward the four winds of heaven; and not to his posterity, nor according to his dominion which he ruled: for his kingdom shall be plucked up, even for others beside those.
22042	861	5	And the king of the south shall be strong, and one of his princes; and he shall be strong above him, and have dominion; his dominion shall be a great dominion.
22043	861	6	And in the end of years they shall join themselves together; for the king's daughter of the south shall come to the king of the north to make an agreement: but she shall not retain the power of the arm; neither shall he stand, nor his arm: but she shall be given up, and they that brought her, and he that begat her, and he that strengthened her in these times.
22044	861	7	But out of a branch of her roots shall one stand up in his estate, which shall come with an army, and shall enter into the fortress of the king of the north, and shall deal against them, and shall prevail:
22045	861	8	And shall also carry captives into Egypt their gods, with their princes, and with their precious vessels of silver and of gold; and he shall continue more years than the king of the north.
22046	861	9	So the king of the south shall come into his kingdom, and shall return into his own land.
22047	861	10	But his sons shall be stirred up, and shall assemble a multitude of great forces: and one shall certainly come, and overflow, and pass through: then shall he return, and be stirred up, even to his fortress.
22048	861	11	And the king of the south shall be moved with choler, and shall come forth and fight with him, even with the king of the north: and he shall set forth a great multitude; but the multitude shall be given into his hand.
22049	861	12	And when he hath taken away the multitude, his heart shall be lifted up; and he shall cast down many ten thousands: but he shall not be strengthened by it.
22050	861	13	For the king of the north shall return, and shall set forth a multitude greater than the former, and shall certainly come after certain years with a great army and with much riches.
22051	861	14	And in those times there shall many stand up against the king of the south: also the robbers of thy people shall exalt themselves to establish the vision; but they shall fall.
22052	861	15	So the king of the north shall come, and cast up a mount, and take the most fenced cities: and the arms of the south shall not withstand, neither his chosen people, neither shall there be any strength to withstand.
22053	861	16	But he that cometh against him shall do according to his own will, and none shall stand before him: and he shall stand in the glorious land, which by his hand shall be consumed.
22054	861	17	He shall also set his face to enter with the strength of his whole kingdom, and upright ones with him; thus shall he do: and he shall give him the daughter of women, corrupting her: but she shall not stand on his side, neither be for him.
22055	861	18	After this shall he turn his face unto the isles, and shall take many: but a prince for his own behalf shall cause the reproach offered by him to cease; without his own reproach he shall cause it to turn upon him.
22056	861	19	Then he shall turn his face toward the fort of his own land: but he shall stumble and fall, and not be found.
22057	861	20	Then shall stand up in his estate a raiser of taxes in the glory of the kingdom: but within few days he shall be destroyed, neither in anger, nor in battle.
22058	861	21	And in his estate shall stand up a vile person, to whom they shall not give the honour of the kingdom: but he shall come in peaceably, and obtain the kingdom by flatteries.
22059	861	22	And with the arms of a flood shall they be overflown from before him, and shall be broken; yea, also the prince of the covenant.
22060	861	23	And after the league made with him he shall work deceitfully: for he shall come up, and shall become strong with a small people.
22061	861	24	He shall enter peaceably even upon the fattest places of the province; and he shall do that which his fathers have not done, nor his fathers' fathers; he shall scatter among them the prey, and spoil, and riches: yea, and he shall forecast his devices against the strong holds, even for a time.
22062	861	25	And he shall stir up his power and his courage against the king of the south with a great army; and the king of the south shall be stirred up to battle with a very great and mighty army; but he shall not stand: for they shall forecast devices against him.
22063	861	26	Yea, they that feed of the portion of his meat shall destroy him, and his army shall overflow: and many shall fall down slain.
22064	861	27	And both these kings' hearts shall be to do mischief, and they shall speak lies at one table; but it shall not prosper: for yet the end shall be at the time appointed.
22065	861	28	Then shall he return into his land with great riches; and his heart shall be against the holy covenant; and he shall do exploits, and return to his own land.
22066	861	29	At the time appointed he shall return, and come toward the south; but it shall not be as the former, or as the latter.
22067	861	30	For the ships of Chittim shall come against him: therefore he shall be grieved, and return, and have indignation against the holy covenant: so shall he do; he shall even return, and have intelligence with them that forsake the holy covenant.
22068	861	31	And arms shall stand on his part, and they shall pollute the sanctuary of strength, and shall take away the daily sacrifice, and they shall place the abomination that maketh desolate.
22069	861	32	And such as do wickedly against the covenant shall he corrupt by flatteries: but the people that do know their God shall be strong, and do exploits.
22070	861	33	And they that understand among the people shall instruct many: yet they shall fall by the sword, and by flame, by captivity, and by spoil, many days.
22071	861	34	Now when they shall fall, they shall be holpen with a little help: but many shall cleave to them with flatteries.
22072	861	35	And some of them of understanding shall fall, to try them, and to purge, and to make them white, even to the time of the end: because it is yet for a time appointed.
22073	861	36	And the king shall do according to his will; and he shall exalt himself, and magnify himself above every god, and shall speak marvellous things against the God of gods, and shall prosper till the indignation be accomplished: for that that is determined shall be done.
22074	861	37	Neither shall he regard the God of his fathers, nor the desire of women, nor regard any god: for he shall magnify himself above all.
22075	861	38	But in his estate shall he honour the God of forces: and a god whom his fathers knew not shall he honour with gold, and silver, and with precious stones, and pleasant things.
22076	861	39	Thus shall he do in the most strong holds with a strange god, whom he shall acknowledge and increase with glory: and he shall cause them to rule over many, and shall divide the land for gain.
22077	861	40	And at the time of the end shall the king of the south push at him: and the king of the north shall come against him like a whirlwind, with chariots, and with horsemen, and with many ships; and he shall enter into the countries, and shall overflow and pass over.
22078	861	41	He shall enter also into the glorious land, and many countries shall be overthrown: but these shall escape out of his hand, even Edom, and Moab, and the chief of the children of Ammon.
22079	861	42	He shall stretch forth his hand also upon the countries: and the land of Egypt shall not escape.
22080	861	43	But he shall have power over the treasures of gold and of silver, and over all the precious things of Egypt: and the Libyans and the Ethiopians shall be at his steps.
22081	861	44	But tidings out of the east and out of the north shall trouble him: therefore he shall go forth with great fury to destroy, and utterly to make away many.
22082	861	45	And he shall plant the tabernacles of his palace between the seas in the glorious holy mountain; yet he shall come to his end, and none shall help him.
22083	862	1	AND at that time shall Michael stand up, the great prince which standeth for the children of thy people: and there shall be a time of trouble, such as never was since there was a nation even to that same time: and at that time thy people shall be delivered, every one that shall be found written in the book.
22084	862	2	And many of them that sleep in the dust of the earth shall awake, some to everlasting life, and some to shame and everlasting contempt.
22085	862	3	And they that be wise shall shine as the brightness of the firmament; and they that turn many to righteousness as the stars for ever and ever.
22086	862	4	But thou, O Daniel, shut up the words, and seal the book, even to the time of the end: many shall run to and fro, and knowledge shall be increased.
22087	862	5	Then I Daniel looked, and, behold, there stood other two, the one on this side of the bank of the river, and the other on that side of the bank of the river.
22088	862	6	And one said to the man clothed in linen, which was upon the waters of the river, How long shall it be to the end of these wonders?
22089	862	7	And I heard the man clothed in linen, which was upon the waters of the river, when he held up his right hand and his left hand unto heaven, and sware by him that liveth for ever that it shall be for a time, times, and an half; and when he shall have accomplished to scatter the power of the holy people, all these things shall be finished.
22090	862	8	And I heard, but I understood not: then said I, O my Lord, what shall be the end of these things?
22091	862	9	And he said, Go thy way, Daniel: for the words are closed up and sealed till the time of the end.
22092	862	10	Many shall be purified, and made white, and tried; but the wicked shall do wickedly: and none of the wicked shall understand; but the wise shall understand.
22093	862	11	And from the time that the daily sacrifice shall be taken away, and the abomination that maketh desolate set up, there shall be a thousand two hundred and ninety days.
22094	862	12	Blessed is he that waiteth, and cometh to the thousand three hundred and five and thirty days.
22095	862	13	But go thou thy way till the end be: for thou shalt rest, and stand in thy lot at the end of the days.
22096	863	1	THE word of the LORD that came unto Hosea, the son of Beeri, in the days of Uzziah, Jotham, Ahaz, and Hezekiah, kings of Judah, and in the days of Jeroboam the son of Joash, king of Israel.
22097	863	2	The beginning of the word of the LORD by Hosea. And the LORD said to Hosea, Go, take unto thee a wife of whoredoms and children of whoredoms: for the land hath committed great whoredom, departing from the LORD.
22098	863	3	So he went and took Gomer the daughter of Diblaim; which conceived, and bare him a son.
22099	863	4	And the LORD said unto him, Call his name Jezreel; for yet a little while, and I will avenge the blood of Jezreel upon the house of Jehu, and will cause to cease the kingdom of the house of Israel.
22100	863	5	And it shall come to pass at that day, that I will break the bow of Israel in the valley of Jezreel.
22101	863	6	And she conceived again, and bare a daughter. And God said unto him, Call her name Lo-ruhamah: for I will no more have mercy upon the house of Israel; but I will utterly take them away.
22102	863	7	But I will have mercy upon the house of Judah, and will save them by the LORD their God, and will not save them by bow, nor by sword, nor by battle, by horses, nor by horsemen.
22103	863	8	Now when she had weaned Lo-ruhamah, she conceived, and bare a son.
22104	863	9	Then said God, Call his name Lo-ammi: for ye are not my people, and I will not be your God.
22105	863	10	Yet the number of the children of Israel shall be as the sand of the sea, which cannot be measured nor numbered; and it shall come to pass, that in the place where it was said unto them, Ye are not my people, there it shall be said unto them, Ye are the sons of the living God.
22106	863	11	Then shall the children of Judah and the children of Israel be gathered together, and appoint themselves one head, and they shall come up out of the land: for great shall be the day of Jezreel.
22107	864	1	SAY ye unto your brethren, Ammi; and to your sisters, Ruhamah.
22108	864	2	Plead with your mother, plead: for she is not my wife, neither am I her husband: let her therefore put away her whoredoms out of her sight, and her adulteries from between her breasts;
22109	864	3	Lest I strip her naked, and set her as in the day that she was born, and make her as a wilderness, and set her like a dry land, and slay her with thirst.
22110	864	4	And I will not have mercy upon her children; for they be the children of whoredoms.
22111	864	5	For their mother hath played the harlot: she that conceived them hath done shamefully: for she said, I will go after my lovers, that give me my bread and my water, my wool and my flax, mine oil and my drink.
22112	864	6	Therefore, behold, I will hedge up thy way with thorns, and make a wall, that she shall not find her paths.
22113	864	7	And she shall follow after her lovers, but she shall not overtake them; and she shall seek them, but shall not find them: then shall she say, I will go and return to my first husband; for then was it better with me than now.
22114	864	8	For she did not know that I gave her corn, and wine, and oil, and multiplied her silver and gold, which they prepared for Baal.
22115	864	9	Therefore will I return, and take away my corn in the time thereof, and my wine in the season thereof, and will recover my wool and my flax given to cover her nakedness.
22116	864	10	And now will I discover her lewdness in the sight of her lovers, and none shall deliver her out of mine hand.
22117	864	11	I will also cause all her mirth to cease, her feast days, her new moons, and her sabbaths, and all her solemn feasts.
22118	864	12	And I will destroy her vines and her fig trees, whereof she hath said, These are my rewards that my lovers have given me: and I will make them a forest, and the beasts of the field shall eat them.
22119	864	13	And I will visit upon her the days of Baalim, wherein she burned incense to them, and she decked herself with her earrings and her jewels, and she went after her lovers, and forgat me, saith the LORD.
22120	864	14	Therefore, behold, I will allure her, and bring her into the wilderness, and speak comfortably unto her.
22121	864	15	And I will give her her vineyards from thence, and the valley of Achor for a door of hope: and she shall sing there, as in the days of her youth, and as in the day when she came up out of the land of Egypt.
22122	864	16	And it shall be at that day, saith the LORD, that thou shalt call me Ishi; and shalt call me no more Baali.
22123	864	17	For I will take away the names of Baalim out of her mouth, and they shall no more be remembered by their name.
22124	864	18	And in that day will I make a covenant for them with the beasts of the field, and with the fowls of heaven, and with the creeping things of the ground: and I will break the bow and the sword and the battle out of the earth, and will make them to lie down safely.
22125	864	19	And I will betroth thee unto me for ever; yea, I will betroth thee unto me in righteousness, and in judgment, and in lovingkindness, and in mercies.
22126	864	20	I will even betroth thee unto me in faithfulness: and thou shalt know the LORD.
22127	864	21	And it shall come to pass in that day, I will hear, saith the LORD, I will hear the heavens, and they shall hear the earth;
22128	864	22	And the earth shall hear the corn, and the wine, and the oil; and they shall hear Jezreel.
22129	864	23	And I will sow her unto me in the earth; and I will have mercy upon her that had not obtained mercy; and I will say to them which were not my people, Thou art my people; and they shall say, Thou art my God.
22130	865	1	THEN said the LORD unto me, Go yet, love a woman beloved of her friend, yet an adulteress, according to the love of the LORD toward the children of Israel, who look to other gods, and love flagons of wine.
22131	865	2	So I bought her to me for fifteen pieces of silver, and for an homer of barley, and an half homer of barley:
22132	865	3	And I said unto her, Thou shalt abide for me many days; thou shalt not play the harlot, and thou shalt not be for another man: so will I also be for thee.
22133	865	4	For the children of Israel shall abide many days without a king, and without a prince, and without a sacrifice, and without an image, and without an ephod, and without teraphim:
22134	865	5	Afterward shall the children of Israel return, and seek the LORD their God, and David their king; and shall fear the LORD and his goodness in the latter days.
22135	866	1	HEAR the word of the LORD, ye children of Israel: for the LORD hath a controversy with the inhabitants of the land, because there is no truth, nor mercy, nor knowledge of God in the land.
22136	866	2	By swearing, and lying, and killing, and stealing, and committing adultery, they break out, and blood toucheth blood.
22137	866	3	Therefore shall the land mourn, and every one that dwelleth therein shall languish, with the beasts of the field, and with the fowls of heaven; yea, the fishes of the sea also shall be taken away.
22138	866	4	Yet let no man strive, nor reprove another: for thy people are as they that strive with the priest.
22139	866	5	Therefore shalt thou fall in the day, and the prophet also shall fall with thee in the night, and I will destroy thy mother.
22140	866	6	My people are destroyed for lack of knowledge: because thou hast rejected knowledge, I will also reject thee, that thou shalt be no priest to me: seeing thou hast forgotten the law of thy God, I will also forget thy children.
22141	866	7	As they were increased, so they sinned against me: therefore will I change their glory into shame.
22142	866	8	They eat up the sin of my people, and they set their heart on their iniquity.
22143	866	9	And there shall be, like people, like priest: and I will punish them for their ways, and reward them their doings.
22144	866	10	For they shall eat, and not have enough: they shall commit whoredom, and shall not increase: because they have left off to take heed to the LORD.
22145	866	11	Whoredom and wine and new wine take away the heart.
22146	866	12	My people ask counsel at their stocks, and their staff declareth unto them: for the spirit of whoredoms hath caused them to err, and they have gone a whoring from under their God.
22147	866	13	They sacrifice upon the tops of the mountains, and burn incense upon the hills, under oaks and poplars and elms, because the shadow thereof is good: therefore your daughters shall commit whoredom, and your spouses shall commit adultery.
22148	866	14	I will not punish your daughters when they commit whoredom, nor your spouses when they commit adultery: for themselves are separated with whores, and they sacrifice with harlots: therefore the people that doth not understand shall fall.
22149	866	15	Though thou, Israel, play the harlot, yet let not Judah offend; and come not ye unto Gilgal, neither go ye up to Beth-aven, nor swear, The LORD liveth.
22150	866	16	For Israel slideth back as a backsliding heifer: now the LORD will feed them as a lamb in a large place.
22151	866	17	Ephraim is joined to idols: let him alone.
22152	866	18	Their drink is sour: they have committed whoredom continually: her rulers with shame do love, Give ye.
22153	866	19	The wind hath bound her up in her wings, and they shall be ashamed because of their sacrifices.
22154	867	1	HEAR ye this, O priests; and hearken, ye house of Israel; and give ye ear, O house of the king; for judgment is toward you, because ye have been a snare on Mizpah, and a net spread upon Tabor.
22155	867	2	And the revolters are profound to make slaughter, though I have been a rebuker of them all.
22156	867	3	I know Ephraim, and Israel is not hid from me: for now, O Ephraim, thou committest whoredom, and Israel is defiled.
22157	867	4	They will not frame their doings to turn unto their God: for the spirit of whoredoms is in the midst of them, and they have not known the LORD.
22158	867	5	And the pride of Israel doth testify to his face: therefore shall Israel and Ephraim fall in their iniquity; Judah also shall fall with them.
22159	867	6	They shall go with their flocks and with their herds to seek the LORD; but they shall not find him; he hath withdrawn himself from them.
22160	867	7	They have dealt treacherously against the LORD: for they have begotten strange children: now shall a month devour them with their portions.
22161	867	8	Blow ye the cornet in Gibeah, and the trumpet in Ramah: cry aloud at Beth-aven, after thee, O Benjamin.
22162	867	9	Ephraim shall be desolate in the day of rebuke: among the tribes of Israel have I made known that which shall surely be.
22163	867	10	The princes of Judah were like them that remove the bound: therefore I will pour out my wrath upon them like water.
22164	867	11	Ephraim is oppressed and broken in judgment, because he willingly walked after the commandment.
22165	867	12	Therefore will I be unto Ephraim as a moth, and to the house of Judah as rottenness.
22166	867	13	When Ephraim saw his sickness, and Judah saw his wound, then went Ephraim to the Assyrian, and sent to king Jareb: yet could he not heal you, nor cure you of your wound.
22167	867	14	For I will be unto Ephraim as a lion, and as a young lion to the house of Judah: I, even I, will tear and go away; I will take away, and none shall rescue him.
22168	867	15	I will go and return to my place, till they acknowledge their offence, and seek my face: in their affliction they will seek me early.
22169	868	1	COME, and let us return unto the LORD: for he hath torn, and he will heal us; he hath smitten, and he will bind us up.
22170	868	2	After two days will he revive us: in the third day he will raise us up, and we shall live in his sight.
22171	868	3	Then shall we know, if we follow on to know the LORD: his going forth is prepared as the morning; and he shall come unto us as the rain, as the latter and former rain unto the earth.
22172	868	4	O Ephraim, what shall I do unto thee? O Judah, what shall I do unto thee? for your goodness is as a morning cloud, and as the early dew it goeth away.
22173	868	5	Therefore have I hewed them by the prophets; I have slain them by the words of my mouth: and thy judgments are as the light that goeth forth.
22174	868	6	For I desired mercy, and not sacrifice; and the knowledge of God more than burnt offerings.
22175	868	7	But they like men have transgressed the covenant: there have they dealt treacherously against me.
22176	868	8	Gilead is a city of them that work iniquity, and is polluted with blood.
22177	868	9	And as troops of robbers wait for a man, so the company of priests murder in the way by consent: for they commit lewdness.
22178	868	10	I have seen an horrible thing in the house of Israel: there is the whoredom of Ephraim, Israel is defiled.
22179	868	11	Also, O Judah, he hath set an harvest for thee, when I returned the captivity of my people.
22180	869	1	WHEN I would have healed Israel, then the iniquity of Ephraim was discovered, and the wickedness of Samaria: for they commit falsehood; and the thief cometh in, and the troop of robbers spoileth without.
22181	869	2	And they consider not in their hearts that I remember all their wickedness: now their own doings have beset them about; they are before my face.
22182	869	3	They make the king glad with their wickedness, and the princes with their lies.
22183	869	4	They are all adulterers, as an oven heated by the baker, who ceaseth from raising after he hath kneeded the dough, until it be leavened.
22184	869	5	In the day of our king the princes have made him sick with bottles of wine; he stretched out his hand with scorners.
22185	869	6	For they have made ready their heart like an oven, whiles they lie in wait: their baker sleepeth all the night; in the morning it burneth as a flaming fire.
22186	869	7	They are all hot as an oven, and have devoured their judges; all their kings are fallen: there is none among them that calleth unto me.
22187	869	8	Ephraim, he hath mixed himself among the people; Ephraim is a cake not turned.
22188	869	9	Strangers have devoured his strength, and he knoweth it not: yea, gray hairs are here and there upon him, yet he knoweth not.
22189	869	10	And the pride of Israel testifieth to his face: and they do not return to the LORD their God, nor seek him for all this.
22190	869	11	Ephraim also is like a silly dove without heart: they call to Egypt, they go to Assyria.
22191	869	12	When they shall go, I will spread my net upon them; I will bring them down as the fowls of the heaven; I will chastise them, as their congregation hath heard.
22192	869	13	Woe unto them! for they have fled from me: destruction unto them! because they have transgressed against me: though I have redeemed them, yet they have spoken lies against me.
22193	869	14	And they have not cried unto me with their heart, when they howled upon their beds: they assemble themselves for corn and wine, and they rebel against me.
22194	869	15	Though I have bound and strengthened their arms, yet do they imagine mischief against me.
22195	869	16	They return, but not to the most High: they are like a deceitful bow: their princes shall fall by the sword for the rage of their tongue: this shall be their derision in the land of Egypt.
22196	870	1	SET the trumpet to thy mouth. He shall come as an eagle against the house of the LORD, because they have transgressed my covenant, and trespassed against my law.
22197	870	2	Israel shall cry unto me, My God, we know thee.
22198	870	3	Israel hath cast off the thing that is good: the enemy shall pursue him.
22199	870	4	They have set up kings, but not by me: they have made princes, and I knew it not: of their silver and their gold have they made them idols, that they may be cut off.
22200	870	5	Thy calf, O Samaria, hath cast thee off; mine anger is kindled against them: how long will it be ere they attain to innocency?
22201	870	6	For from Israel was it also: the workman made it; therefore it is not God: but the calf of Samaria shall be broken in pieces.
22202	870	7	For they have sown the wind, and they shall reap the whirlwind: it hath no stalk: the bud shall yield no meal: if so be it yield, the strangers shall swallow it up.
22203	870	8	Israel is swallowed up: now shall they be among the Gentiles as a vessel wherein is no pleasure.
22204	870	9	For they are gone up to Assyria, a wild ass alone by himself: Ephraim hath hired lovers.
22205	870	10	Yea, though they have hired among the nations, now will I gather them, and they shall sorrow a little for the burden of the king of princes.
22206	870	11	Because Ephraim hath made many altars to sin, altars shall be unto him to sin.
22207	870	12	I have written to him the great things of my law, but they were counted as a strange thing.
22208	870	13	They sacrifice flesh for the sacrifices of mine offerings, and eat it; but the LORD accepteth them not; now will he remember their iniquity, and visit their sins: they shall return to Egypt.
22209	870	14	For Israel hath forgotten his Maker, and buildeth temples; and Judah hath multiplied fenced cities: but I will send a fire upon his cities, and it shall devour the palaces thereof.
22210	871	1	REJOICE not, O Israel, for joy, as other people: for thou hast gone a whoring from thy God, thou hast loved a reward upon every cornfloor.
22211	871	2	The floor and the winepress shall not feed them, and the new wine shall fail in her.
22212	871	3	They shall not dwell in the LORD's land; but Ephraim shall return to Egypt, and they shall eat unclean things in Assyria.
22213	871	4	They shall not offer wine offerings to the LORD, neither shall they be pleasing unto him: their sacrifices shall be unto them as the bread of mourners; all that eat thereof shall be polluted: for their bread for their soul shall not come into the house of the LORD.
22214	871	5	What will ye do in the solemn day, and in the day of the feast of the LORD?
22215	871	6	For, lo, they are gone because of destruction: Egypt shall gather them up, Memphis shall bury them: the pleasant places for their silver, nettles shall possess them: thorns shall be in their tabernacles.
22216	871	7	The days of visitation are come, the days of recompence are come; Israel shall know it: the prophet is a fool, the spiritual man is mad, for the multitude of thine iniquity, and the great hatred.
22217	871	8	The watchman of Ephraim was with my God: but the prophet is a snare of a fowler in all his ways, and hatred in the house of his God.
22218	871	9	They have deeply corrupted themselves, as in the days of Gibeah: therefore he will remember their iniquity, he will visit their sins.
22219	871	10	I found Israel like grapes in the wilderness; I saw your fathers as the firstripe in the fig tree at her first time: but they went to Baal-peor, and separated themselves unto that shame; and their abominations were according as they loved.
22220	871	11	As for Ephraim, their glory shall fly away like a bird, from the birth, and from the womb, and from the conception.
22221	871	12	Though they bring up their children, yet will I bereave them, that there shall not be a man left: yea, woe also to them when I depart from them!
22222	871	13	Ephraim, as I saw Tyrus, is planted in a pleasant place: but Ephraim shall bring forth his children to the murderer.
22223	871	14	Give them, O LORD: what wilt thou give? give them a miscarrying womb and dry breasts.
22224	871	15	All their wickedness is in Gilgal: for there I hated them: for the wickedness of their doings I will drive them out of mine house, I will love them no more: all their princes are revolters.
22225	871	16	Ephraim is smitten, their root is dried up, they shall bear no fruit: yea, though they bring forth, yet will I slay even the beloved fruit of their womb.
22226	871	17	My God will cast them away, because they did not hearken unto him: and they shall be wanderers among the nations.
22227	872	1	ISRAEL is an empty vine, he bringeth forth fruit unto himself: according to the multitude of his fruit he hath increased the altars; according to the goodness of his land they have made goodly images.
22228	872	2	Their heart is divided; now shall they be found faulty: he shall break down their altars, he shall spoil their images.
22229	872	3	For now they shall say, We have no king, because we feared not the LORD; what then should a king do to us?
22230	872	4	They have spoken words, swearing falsely in making a covenant: thus judgment springeth up as hemlock in the furrows of the field.
22231	872	5	The inhabitants of Samaria shall fear because of the calves of Beth-aven: for the people thereof shall mourn over it, and the priests thereof that rejoiced on it, for the glory thereof, because it is departed from it.
22232	872	6	It shall be also carried unto Assyria for a present to king Jareb: Ephraim shall receive shame, and Israel shall be ashamed of his own counsel.
22233	872	7	As for Samaria, her king is cut off as the foam upon the water.
22234	872	8	The high places also of Aven, the sin of Israel, shall be destroyed: the thorn and the thistle shall come up on their altars; and they shall say to the mountains, Cover us; and to the hills, Fall on us.
22235	872	9	O Israel, thou hast sinned from the days of Gibeah: there they stood: the battle in Gibeah against the children of iniquity did not overtake them.
22236	872	10	It is in my desire that I should chastise them; and the people shall be gathered against them, when they shall bind themselves in their two furrows.
22237	872	11	And Ephraim is as an heifer that is taught, and loveth to tread out the corn; but I passed over upon her fair neck: I will make Ephraim to ride; Judah shall plow, and Jacob shall break his clods.
22238	872	12	Sow to yourselves in righteousness, reap in mercy; break up your fallow ground: for it is time to seek the LORD, till he come and rain righteousness upon you.
22239	872	13	Ye have plowed wickedness, ye have reaped iniquity; ye have eaten the fruit of lies: because thou didst trust in thy way, in the multitude of thy mighty men.
22240	872	14	Therefore shall a tumult arise among thy people, and all thy fortresses shall be spoiled, as Shalman spoiled Beth-arbel in the day of battle: the mother was dashed in pieces upon her children.
22241	872	15	So shall Beth-el do unto you because of your great wickedness: in a morning shall the king of Israel utterly be cut off.
22242	873	1	WHEN Israel was a child, then I loved him, and called my son out of Egypt.
22243	873	2	As they called them, so they went from them: they sacrificed unto Baalim, and burned incense to graven images.
22244	873	3	I taught Ephraim also to go, taking them by their arms; but they knew not that I healed them.
22245	873	4	I drew them with cords of a man, with bands of love: and I was to them as they that take off the yoke on their jaws, and I laid meat unto them.
22246	873	5	He shall not return into the land of Egypt, but the Assyrian shall be his king, because they refused to return.
22247	873	6	And the sword shall abide on his cities, and shall consume his branches, and devour them, because of their own counsels.
22248	873	7	And my people are bent to backsliding from me: though they called them to the most High, none at all would exalt him.
22249	873	8	How shall I give thee up, Ephraim? how shall I deliver thee, Israel? how shall I make thee as Admah? how shall I set thee as Zeboim? mine heart is turned within me, my repentings are kindled together.
22250	873	9	I will not execute the fierceness of mine anger, I will not return to destroy Ephraim: for I am God, and not man; the Holy One in the midst of thee: and I will not enter into the city.
22251	873	10	They shall walk after the LORD: he shall roar like a lion: when he shall roar, then the children shall tremble from the west.
22252	873	11	They shall tremble as a bird out of Egypt, and as a dove out of the land of Assyria: and I will place them in their houses, saith the LORD.
22253	873	12	Ephraim compasseth me about with lies, and the house of Israel with deceit: but Judah yet ruleth with God, and is faithful with the saints.
22254	874	1	EPHRAIM feedeth on wind, and followeth after the east wind: he daily increaseth lies and desolation; and they do make a covenant with the Assyrians, and oil is carried into Egypt.
22255	874	2	The LORD hath also a controversy with Judah, and will punish Jacob according to his ways; according to his doings will he recompense him.
22256	874	3	He took his brother by the heel in the womb, and by his strength he had power with God:
22257	874	4	Yea, he had power over the angel, and prevailed: he wept, and made supplication unto him: he found him in Beth-el, and there he spake with us;
22258	874	5	Even the LORD God of hosts; the LORD is his memorial.
22259	874	6	Therefore turn thou to thy God: keep mercy and judgment, and wait on thy God continually.
22260	874	7	He is a merchant, the balances of deceit are in his hand: he loveth to oppress.
22261	874	8	And Ephraim said, Yet I am become rich, I have found me out substance: in all my labours they shall find none iniquity in me that were sin.
22262	874	9	And I that am the LORD thy God from the land of Egypt will yet make thee to dwell in tabernacles, as in the days of the solemn feast.
22263	874	10	I have also spoken by the prophets, and I have multiplied visions, and used similitudes, by the ministry of the prophets.
22264	874	11	Is there iniquity in Gilead? surely they are vanity: they sacrifice bullocks in Gilgal; yea, their altars are as heaps in the furrows of the fields.
22265	874	12	And Jacob fled into the country of Syria, and Israel served for a wife, and for a wife he kept sheep.
22266	874	13	And by a prophet the LORD brought Israel out of Egypt, and by a prophet was he preserved.
22267	874	14	Ephraim provoked him to anger most bitterly: therefore shall he leave his blood upon him, and his reproach shall his Lord return unto him.
22268	875	1	WHEN Ephraim spake trembling, he exalted himself in Israel; but when he offended in Baal, he died.
22269	875	2	And now they sin more and more, and have made them molten images of their silver, and idols according to their own understanding, all of it the work of the craftsmen: they say of them, Let the men that sacrifice kiss the calves.
22270	875	3	Therefore they shall be as the morning cloud, and as the early dew that passeth away, as the chaff that is driven with the whirlwind out of the floor, and as the smoke out of the chimney.
22271	875	4	Yet I am the LORD thy God from the land of Egypt, and thou shalt know no god but me: for there is no saviour beside me.
22272	875	5	I did know thee in the wilderness, in the land of great drought.
22273	875	6	According to their pasture, so were they filled; they were filled, and their heart was exalted; therefore have they forgotten me.
22274	875	7	Therefore I will be unto them as a lion: as a leopard by the way will I observe them:
22275	875	8	I will meet them as a bear that is bereaved of her whelps, and will rend the caul of their heart, and there will I devour them like a lion: the wild beast shall tear them.
22276	875	9	O Israel, thou hast destroyed thyself; but in me is thine help.
22277	875	10	I will be thy king: where is any other that may save thee in all thy cities? and thy judges of whom thou saidst, Give me a king and princes?
22278	875	11	I gave thee a king in mine anger, and took him away in my wrath.
22279	875	12	The iniquity of Ephraim is bound up; his sin is hid.
22280	875	13	The sorrows of a travailing woman shall come upon him: he is an unwise son; for he should not stay long in the place of the breaking forth of children.
22281	875	14	I will ransom them from the power of the grave; I will redeem them from death: O death, I will be thy plagues; O grave, I will be thy destruction: repentance shall be hid from mine eyes.
22282	875	15	Though he be fruitful among his brethren, an east wind shall come, the wind of the LORD shall come up from the wilderness, and his spring shall become dry, and his fountain shall be dried up: he shall spoil the treasure of all pleasant vessels.
22283	875	16	Samaria shall become desolate; for she hath rebelled against her God: they shall fall by the sword: their infants shall be dashed in pieces, and their women with child shall be ripped up.
22284	876	1	O ISRAEL, return unto the LORD thy God; for thou hast fallen by thine iniquity.
22285	876	2	Take with you words, and turn to the LORD: say unto him, Take away all iniquity, and receive us graciously: so will we render the calves of our lips.
22286	876	3	Asshur shall not save us; we will not ride upon horses: neither will we say any more to the work of our hands, Ye are our gods: for in thee the fatherless findeth mercy.
22287	876	4	I will heal their backsliding, I will love them freely: for mine anger is turned away from him.
22288	876	5	I will be as the dew unto Israel: he shall grow as the lily, and cast forth his roots as Lebanon.
22289	876	6	His branches shall spread, and his beauty shall be as the olive tree, and his smell as Lebanon.
22290	876	7	They that dwell under his shadow shall return; they shall revive as the corn, and grow as the vine: the scent thereof shall be as the wine of Lebanon.
22291	876	8	Ephraim shall say, What have I to do any more with idols? I have heard him, and observed him: I am like a green fir tree. From me is thy fruit found.
22292	876	9	Who is wise, and he shall understand these things? prudent, and he shall know them? for the ways of the LORD are right, and the just shall walk in them: but the transgressors shall fall therein.
22293	877	1	THE word of the LORD that came to Joel the son of Pethuel.
22294	877	2	Hear this, ye old men, and give ear, all ye inhabitants of the land. Hath this been in your days, or even in the days of your fathers?
22295	877	3	Tell ye your children of it, and let your children tell their children, and their children another generation.
22296	877	4	That which the palmerworm hath left hath the locust eaten; and that which the locust hath left hath the cankerworm eaten; and that which the cankerworm hath left hath the caterpiller eaten.
22297	877	5	Awake, ye drunkards, and weep; and howl, all ye drinkers of wine, because of the new wine; for it is cut off from your mouth.
22298	877	6	For a nation is come up upon my land, strong, and without number, whose teeth are the teeth of a lion, and he hath the cheek teeth of a great lion.
22299	877	7	He hath laid my vine waste, and barked my fig tree: he hath made it clean bare, and cast it away; the branches thereof are made white.
22300	877	8	Lament like a virgin girded with sackcloth for the husband of her youth.
22301	877	9	The meat offering and the drink offering is cut off from the house of the LORD; the priests, the LORD's ministers, mourn.
22302	877	10	The field is wasted, the land mourneth; for the corn is wasted: the new wine is dried up, the oil languisheth.
22303	877	11	Be ye ashamed, O ye husbandmen; howl, O ye vinedressers, for the wheat and for the barley; because the harvest of the field is perished.
22304	877	12	The vine is dried up, and the fig tree languisheth; the pomegranate tree, the palm tree also, and the apple tree, even all the trees of the field, are withered: because joy is withered away from the sons of men.
22305	877	13	Gird yourselves, and lament, ye priests: howl, ye ministers of the altar: come, lie all night in sackcloth, ye ministers of my God: for the meat offering and the drink offering is withholden from the house of your God.
22306	877	14	Sanctify ye a fast, call a solemn assembly, gather the elders and all the inhabitants of the land into the house of the LORD your God, and cry unto the LORD,
22307	877	15	Alas for the day! for the day of the LORD is at hand, and as a destruction from the Almighty shall it come.
22308	877	16	Is not the meat cut off before our eyes, yea, joy and gladness from the house of our God?
22309	877	17	The seed is rotten under their clods, the garners are laid desolate, the barns are broken down; for the corn is withered.
22310	877	18	How do the beasts groan! the herds of cattle are perplexed, because they have no pasture; yea, the flocks of sheep are made desolate.
22311	877	19	O LORD, to thee will I cry: for the fire hath devoured the pastures of the wilderness, and the flame hath burned all the trees of the field.
22312	877	20	The beasts of the field cry also unto thee: for the rivers of waters are dried up, and the fire hath devoured the pastures of the wilderness.
22313	878	1	BLOW ye the trumpet in Zion, and sound an alarm in my holy mountain: let all the inhabitants of the land tremble: for the day of the LORD cometh, for it is nigh at hand;
22314	878	2	A day of darkness and of gloominess, a day of clouds and of thick darkness, as the morning spread upon the mountains: a great people and a strong; there hath not been ever the like, neither shall be any more after it, even to the years of many generations.
22315	878	3	A fire devoureth before them; and behind them a flame burneth: the land is as the garden of Eden before them, and behind them a desolate wilderness; yea, and nothing shall escape them.
22316	878	4	The appearance of them is as the appearance of horses; and as horsemen, so shall they run.
22317	878	5	Like the noise of chariots on the tops of mountains shall they leap, like the noise of a flame of fire that devoureth the stubble, as a strong people set in battle array.
22318	878	6	Before their face the people shall be much pained: all faces shall gather blackness.
22319	878	7	They shall run like mighty men; they shall climb the wall like men of war; and they shall march every one on his ways, and they shall not break their ranks:
22320	878	8	Neither shall one thrust another; they shall walk every one in his path: and when they fall upon the sword, they shall not be wounded.
22321	878	9	They shall run to and fro in the city; they shall run upon the wall, they shall climb up upon the houses; they shall enter in at the windows like a thief.
22322	878	10	The earth shall quake before them; the heavens shall tremble: the sun and the moon shall be dark, and the stars shall withdraw their shining:
22323	878	11	And the LORD shall utter his voice before his army: for his camp is very great: for he is strong that executeth his word: for the day of the LORD is great and very terrible; and who can abide it?
22324	878	12	Therefore also now, saith the LORD, turn ye even to me with all your heart, and with fasting, and with weeping, and with mourning:
22325	878	13	And rend your heart, and not your garments, and turn unto the LORD your God: for he is gracious and merciful, slow to anger, and of great kindness, and repenteth him of the evil.
22326	878	14	Who knoweth if he will return and repent, and leave a blessing behind him; even a meat offering and a drink offering unto the LORD your God?
22327	878	15	Blow the trumpet in Zion, sanctify a fast, call a solemn assembly:
22328	878	16	Gather the people, sanctify the congregation, assemble the elders, gather the children, and those that suck the breasts: let the bridegroom go forth of his chamber, and the bride out of her closet.
22329	878	17	Let the priests, the ministers of the LORD, weep between the porch and the altar, and let them say, Spare thy people, O LORD, and give not thine heritage to reproach, that the heathen should rule over them: wherefore should they say among the people, Where is their God?
22330	878	18	Then will the LORD be jealous for his land, and pity his people.
22331	878	19	Yea, the LORD will answer and say unto his people, Behold, I will send you corn, and wine, and oil, and ye shall be satisfied therewith: and I will no more make you a reproach among the heathen:
22332	878	20	But I will remove far off from you the northern army, and will drive him into a land barren and desolate, with his face toward the east sea, and his hinder part toward the utmost sea, and his stink shall come up, and his ill savour shall come up, because he hath done great things.
22333	878	21	Fear not, O land; be glad and rejoice: for the LORD will do great things.
22334	878	22	Be not afraid, ye beasts of the field: for the pastures of the wilderness do spring, for the tree beareth her fruit, the fig tree and the vine do yield their strength.
22335	878	23	Be glad then, ye children of Zion, and rejoice in the LORD your God: for he hath given you the former rain moderately, and he will cause to come down for you the rain, the former rain, and the latter rain in the first month.
22336	878	24	And the floors shall be full of wheat, and the fats shall overflow with wine and oil.
22337	878	25	And I will restore to you the years that the locust hath eaten, the cankerworm, and the caterpiller, and the palmerworm, my great army which I sent among you.
22338	878	26	And ye shall eat in plenty, and be satisfied, and praise the name of the LORD your God, that hath dealt wondrously with you: and my people shall never be ashamed.
22339	878	27	And ye shall know that I am in the midst of Israel, and that I am the LORD your God, and none else: and my people shall never be ashamed.
22340	878	28	And it shall come to pass afterward, that I will pour out my spirit upon all flesh; and your sons and your daughters shall prophesy, your old men shall dream dreams, your young men shall see visions:
22341	878	29	And also upon the servants and upon the handmaids in those days will I pour out my spirit.
22342	878	30	And I will shew wonders in the heavens and in the earth, blood, and fire, and pillars of smoke.
22343	878	31	The sun shall be turned into darkness, and the moon into blood, before the great and the terrible day of the LORD come.
22344	878	32	And it shall come to pass, that whosoever shall call on the name of the LORD shall be delivered: for in mount Zion and in Jerusalem shall be deliverance, as the LORD hath said, and in the remnant whom the LORD shall call.
22345	879	1	FOR, behold, in those days, and in that time, when I shall bring again the captivity of Judah and Jerusalem,
22346	879	2	I will also gather all nations, and will bring them down into the valley of Jehoshaphat, and will plead with them there for my people and for my heritage Israel, whom they have scattered among the nations, and parted my land.
22347	879	3	And they have cast lots for my people; and have given a boy for an harlot, and sold a girl for wine, that they might drink.
22348	879	4	Yea, and what have ye to do with me, O Tyre, and Zidon, and all the coasts of Palestine? will ye render me a recompence? and if ye recompense me, swiftly and speedily will I return your recompence upon your own head;
22349	879	5	Because ye have taken my silver and my gold, and have carried into your temples my goodly pleasant things:
22350	879	6	The children also of Judah and the children of Jerusalem have ye sold unto the Grecians, that ye might remove them far from their border.
22351	879	7	Behold, I will raise them out of the place whither ye have sold them, and will return your recompence upon your own head:
22352	879	8	And I will sell your sons and your daughters into the hand of the children of Judah, and they shall sell them to the Sabeans, to a people far off: for the LORD hath spoken it.
22353	879	9	Proclaim ye this among the Gentiles; Prepare war, wake up the mighty men, let all the men of war draw near; let them come up:
22354	879	10	Beat your plowshares into swords, and your pruninghooks into spears: let the weak say, I am strong.
22355	879	11	Assemble yourselves, and come, all ye heathen, and gather yourselves together round about: thither cause thy mighty ones to come down, O LORD.
22356	879	12	Let the heathen be wakened, and come up to the valley of Jehoshaphat: for there will I sit to judge all the heathen round about.
22357	879	13	Put ye in the sickle, for the harvest is ripe: come, get you down; for the press is full, the fats overflow; for their wickedness is great.
22358	879	14	Multitudes, multitudes in the valley of decision: for the day of the LORD is near in the valley of decision.
22359	879	15	The sun and the moon shall be darkened, and the stars shall withdraw their shining.
22360	879	16	The LORD also shall roar out of Zion, and utter his voice from Jerusalem; and the heavens and the earth shall shake: but the LORD will be the hope of his people, and the strength of the children of Israel.
22361	879	17	So shall ye know that I am the LORD your God dwelling in Zion, my holy mountain: then shall Jerusalem be holy, and there shall no strangers pass through her any more.
22362	879	18	And it shall come to pass in that day, that the mountains shall drop down new wine, and the hills shall flow with milk, and all the rivers of Judah shall flow with waters, and a fountain shall come forth of the house of the LORD, and shall water the valley of Shittim.
22363	879	19	Egypt shall be a desolation, and Edom shall be a desolate wilderness, for the violence against the children of Judah, because they have shed innocent blood in their land.
22364	879	20	But Judah shall dwell for ever, and Jerusalem from generation to generation.
22365	879	21	For I will cleanse their blood that I have not cleansed: for the LORD dwelleth in Zion.
22366	880	1	THE words of Amos, who was among the herdmen of Tekoa, which he saw concerning Israel in the days of Uzziah king of Judah, and in the days of Jeroboam the son of Joash king of Israel, two years before the earthquake.
22367	880	2	And he said, The LORD will roar from Zion, and utter his voice from Jerusalem; and the habitations of the shepherds shall mourn, and the top of Carmel shall wither.
22368	880	3	Thus saith the LORD; For three transgressions of Damascus, and for four, I will not turn away the punishment thereof; because they have threshed Gilead with threshing instruments of iron:
22369	880	4	But I will send a fire into the house of Hazael, which shall devour the palaces of Ben-hadad.
22370	880	5	I will break also the bar of Damascus, and cut off the inhabitant from the plain of Aven, and him that holdeth the sceptre from the house of Eden: and the people of Syria shall go into captivity unto Kir, saith the LORD.
22371	880	6	Thus saith the LORD; For three transgressions of Gaza, and for four, I will not turn away the punishment thereof; because they carried away captive the whole captivity, to deliver them up to Edom:
22372	880	7	But I will send a fire on the wall of Gaza, which shall devour the palaces thereof:
22373	880	8	And I will cut off the inhabitant from Ashdod, and him that holdeth the sceptre from Ashkelon, and I will turn mine hand against Ekron: and the remnant of the Philistines shall perish, saith the Lord GOD.
22374	880	9	Thus saith the LORD; For three transgressions of Tyrus, and for four, I will not turn away the punishment thereof; because they delivered up the whole captivity to Edom, and remembered not the brotherly covenant:
22375	880	10	But I will send a fire on the wall of Tyrus, which shall devour the palaces thereof.
22376	880	11	Thus saith the LORD; For three transgressions of Edom, and for four, I will not turn away the punishment thereof; because he did pursue his brother with the sword, and did cast off all pity, and his anger did tear perpetually, and he kept his wrath for ever:
22377	880	12	But I will send a fire upon Teman, which shall devour the palaces of Bozrah.
22378	880	13	Thus saith the LORD; For three transgressions of the children of Ammon, and for four, I will not turn away the punishment thereof; because they have ripped up the women with child of Gilead, that they might enlarge their border:
22379	880	14	But I will kindle a fire in the wall of Rabbah, and it shall devour the palaces thereof, with shouting in the day of battle, with a tempest in the day of the whirlwind:
22380	880	15	And their king shall go into captivity, he and his princes together, saith the LORD.
22381	881	1	THUS saith the LORD; For three transgressions of Moab, and for four, I will not turn away the punishment thereof; because he burned the bones of the king of Edom into lime:
22382	881	2	But I will send a fire upon Moab, and it shall devour the palaces of Kirioth: and Moab shall die with tumult, with shouting, and with the sound of the trumpet:
22383	881	3	And I will cut off the judge from the midst thereof, and will slay all the princes thereof with him, saith the LORD.
22384	881	4	Thus saith the LORD; For three transgressions of Judah, and for four, I will not turn away the punishment thereof; because they have despised the law of the LORD, and have not kept his commandments, and their lies caused them to err, after the which their fathers have walked:
22385	881	5	But I will send a fire upon Judah, and it shall devour the palaces of Jerusalem.
22386	881	6	Thus saith the LORD; For three transgressions of Israel, and for four, I will not turn away the punishment thereof; because they sold the righteous for silver, and the poor for a pair of shoes;
22387	881	7	That pant after the dust of the earth on the head of the poor, and turn aside the way of the meek: and a man and his father will go in unto the same maid, to profane my holy name:
22388	881	8	And they lay themselves down upon clothes laid to pledge by every altar, and they drink the wine of the condemned in the house of their god.
22389	881	9	Yet destroyed I the Amorite before them, whose height was like the height of the cedars, and he was strong as the oaks; yet I destroyed his fruit from above, and his roots from beneath.
22390	881	10	Also I brought you up from the land of Egypt, and led you forty years through the wilderness, to possess the land of the Amorite.
22391	881	11	And I raised up of your sons for prophets, and of your young men for Nazarites. Is it not even thus, O ye children of Israel? saith the LORD.
22392	881	12	But ye gave the Nazarites wine to drink; and commanded the prophets, saying, Prophesy not.
22393	881	13	Behold, I am pressed under you, as a cart is pressed that is full of sheaves.
22394	881	14	Therefore the flight shall perish from the swift, and the strong shall not strengthen his force, neither shall the mighty deliver himself:
22395	881	15	Neither shall he stand that handleth the bow; and he that is swift of foot shall not deliver himself: neither shall he that rideth the horse deliver himself.
22396	881	16	And he that is courageous among the mighty shall flee away naked in that day, saith the LORD.
22397	882	1	HEAR this word that the LORD hath spoken against you, O children of Israel, against the whole family which I brought up from the land of Egypt, saying,
22398	882	2	You only have I known of all the families of the earth: therefore I will punish you for all your iniquities.
22399	882	3	Can two walk together, except they be agreed?
22400	882	4	Will a lion roar in the forest, when he hath no prey? will a young lion cry out of his den, if he have taken nothing?
22401	882	5	Can a bird fall in a snare upon the earth, where no gin is for him? shall one take up a snare from the earth, and have taken nothing at all?
22402	882	6	Shall a trumpet be blown in the city, and the people not be afraid? shall there be evil in a city, and the LORD hath not done it?
22403	882	7	Surely the Lord GOD will do nothing, but he revealeth his secret unto his servants the prophets.
22404	882	8	The lion hath roared, who will not fear? the Lord GOD hath spoken, who can but prophesy?
22405	882	9	Publish in the palaces at Ashdod, and in the palaces in the land of Egypt, and say, Assemble yourselves upon the mountains of Samaria, and behold the great tumults in the midst thereof, and the oppressed in the midst thereof.
22406	882	10	For they know not to do right, saith the LORD, who store up violence and robbery in their palaces.
22407	882	11	Therefore thus saith the Lord GOD; An adversary there shall be even round about the land; and he shall bring down thy strength from thee, and thy palaces shall be spoiled.
22408	882	12	Thus saith the LORD; As the shepherd taketh out of the mouth of the lion two legs, or a piece of an ear; so shall the children of Israel be taken out that dwell in Samaria in the corner of a bed, and in Damascus in a couch.
22409	882	13	Hear ye, and testify in the house of Jacob, saith the Lord GOD, the God of hosts,
22410	882	14	That in the day that I shall visit the transgressions of Israel upon him I will also visit the altars of Beth-el: and the horns of the altar shall be cut off, and fall to the ground.
22411	882	15	And I will smite the winter house with the summer house; and the houses of ivory shall perish, and the great houses shall have an end, saith the LORD.
22412	883	1	HEAR this word, ye kine of Bashan, that are in the mountain of Samaria, which oppress the poor, which crush the needy, which say to their masters, Bring, and let us drink.
22413	883	2	The Lord GOD hath sworn by his holiness, that, lo, the days shall come upon you, that he will take you away with hooks, and your posterity with fishhooks.
22414	883	3	And ye shall go out at the breaches, every cow at that which is before her; and ye shall cast them into the palace, saith the LORD.
22415	883	4	Come to Beth-el, and transgress; at Gilgal multiply transgression; and bring your sacrifices every morning, and your tithes after three years:
22416	883	5	And offer a sacrifice of thanksgiving with leaven, and proclaim and publish the free offerings: for this liketh you, O ye children of Israel, saith the Lord GOD.
22417	883	6	And I also have given you cleanness of teeth in all your cities, and want of bread in all your places: yet have ye not returned unto me, saith the LORD.
22418	883	7	And also I have withholden the rain from you, when there were yet three months to the harvest: and I caused it to rain upon one city, and caused it not to rain upon another city: one piece was rained upon, and the piece whereupon it rained not withered.
22419	883	8	So two or three cities wandered unto one city, to drink water; but they were not satisfied: yet have ye not returned unto me, saith the LORD.
22420	883	9	I have smitten you with blasting and mildew: when your gardens and your vineyards and your fig trees and your olive trees increased, the palmerworm devoured them: yet have ye not returned unto me, saith the LORD.
22421	883	10	I have sent among you the pestilence after the manner of Egypt: your young men have I slain with the sword, and have taken away your horses; and I have made the stink of your camps to come up unto your nostrils: yet have ye not returned unto me, saith the LORD.
22422	883	11	I have overthrown some of you, as God overthrew Sodom and Gomorrah, and ye were as a firebrand plucked out of the burning: yet have ye not returned unto me, saith the LORD.
22423	883	12	Therefore thus will I do unto thee, O Israel: and because I will do this unto thee, prepare to meet thy God, O Israel.
22424	883	13	For, lo, he that formeth the mountains, and createth the wind, and declareth unto man what is his thought, that maketh the morning darkness, and treadeth upon the high places of the earth, The LORD, The God of hosts, is his name.
22425	884	1	HEAR ye this word which I take up against you, even a lamentation, O house of Israel.
22426	884	2	The virgin of Israel is fallen; she shall no more rise: she is forsaken upon her land; there is none to raise her up.
22427	884	3	For thus saith the Lord GOD; The city that went out by a thousand shall leave an hundred, and that which went forth by an hundred shall leave ten, to the house of Israel.
22428	884	4	For thus saith the LORD unto the house of Israel, Seek ye me, and ye shall live:
22429	884	5	But seek not Beth-el, nor enter into Gilgal, and pass not to Beer-sheba: for Gilgal shall surely go into captivity, and Beth-el shall come to nought.
22430	884	6	Seek the LORD, and ye shall live; lest he break out like fire in the house of Joseph, and devour it, and there be none to quench it in Beth-el.
22431	884	7	Ye who turn judgment to wormwood, and leave off righteousness in the earth,
22432	884	8	Seek him that maketh the seven stars and Orion, and turneth the shadow of death into the morning, and maketh the day dark with night: that calleth for the waters of the sea, and poureth them out upon the face of the earth: The LORD is his name:
22433	884	9	That strengtheneth the spoiled against the strong, so that the spoiled shall come against the fortress.
22434	884	10	They hate him that rebuketh in the gate, and they abhor him that speaketh uprightly.
22435	884	11	Forasmuch therefore as your treading is upon the poor, and ye take from him burdens of wheat: ye have built houses of hewn stone, but ye shall not dwell in them; ye have planted pleasant vineyards, but ye shall not drink wine of them.
22436	884	12	For I know your manifold transgressions and your mighty sins: they afflict the just, they take a bribe, and they turn aside the poor in the gate from their right.
22437	884	13	Therefore the prudent shall keep silence in that time; for it is an evil time.
22438	884	14	Seek good, and not evil, that ye may live: and so the LORD, the God of hosts, shall be with you, as ye have spoken.
22439	884	15	Hate the evil, and love the good, and establish judgment in the gate: it may be that the LORD God of hosts will be gracious unto the remnant of Joseph.
22440	884	16	Therefore the LORD, the God of hosts, the Lord, saith thus; Wailing shall be in all streets; and they shall say in all the highways, Alas! alas! and they shall call the husbandman to mourning, and such as are skilful of lamentation to wailing.
22441	884	17	And in all vineyards shall be wailing: for I will pass through thee, saith the LORD.
22442	884	18	Woe unto you that desire the day of the LORD! to what end is it for you? the day of the LORD is darkness, and not light.
22443	884	19	As if a man did flee from a lion, and a bear met him; or went into the house, and leaned his hand on the wall, and a serpent bit him.
22444	884	20	Shall not the day of the LORD be darkness, and not light? even very dark, and no brightness in it?
22445	884	21	I hate, I despise your feast days, and I will not smell in your solemn assemblies.
22446	884	22	Though ye offer me burnt offerings and your meat offerings, I will not accept them: neither will I regard the peace offerings of your fat beasts.
22447	884	23	Take thou away from me the noise of thy songs; for I will not hear the melody of thy viols.
22448	884	24	But let judgment run down as waters, and righteousness as a mighty stream.
22449	884	25	Have ye offered unto me sacrifices and offerings in the wilderness forty years, O house of Israel?
22450	884	26	But ye have borne the tabernacle of your Moloch and Chiun your images, the star of your god, which ye made to yourselves.
22451	884	27	Therefore will I cause you to go into captivity beyond Damascus, saith the LORD, whose name is The God of hosts.
22452	885	1	WOE to them that are at ease in Zion, and trust in the mountain of Samaria, which are named chief of the nations, to whom the house of Israel came!
22453	885	2	Pass ye unto Calneh, and see; and from thence go ye to Hamath the great: then go down to Gath of the Philistines: be they better than these kingdoms? or their border greater than your border?
22454	885	3	Ye that put far away the evil day, and cause the seat of violence to come near;
22455	885	4	That lie upon beds of ivory, and stretch themselves upon their couches, and eat the lambs out of the flock, and the calves out of the midst of the stall;
22456	885	5	That chant to the sound of the viol, and invent to themselves instruments of musick, like David;
22457	885	6	That drink wine in bowls, and anoint themselves with the chief ointments: but they are not grieved for the affliction of Joseph.
22458	885	7	Therefore now shall they go captive with the first that go captive, and the banquet of them that stretched themselves shall be removed.
22459	885	8	The Lord GOD hath sworn by himself, saith the LORD the God of hosts, I abhor the excellency of Jacob, and hate his palaces: therefore will I deliver up the city with all that is therein.
22460	885	9	And it shall come to pass, if there remain ten men in one house, that they shall die.
22461	885	10	And a man's uncle shall take him up, and he that burneth him, to bring out the bones out of the house, and shall say unto him that is by the sides of the house, Is there yet any with thee? and he shall say, No. Then shall he say, Hold thy tongue: for we may not make mention of the name of the LORD.
22462	885	11	For, behold, the LORD commandeth, and he will smite the great house with breaches, and the little house with clefts.
22463	885	12	Shall horses run upon the rock? will one plow there with oxen? for ye have turned judgment into gall, and the fruit of righteousness into hemlock:
22464	885	13	Ye which rejoice in a thing of nought, which say, Have we not taken to us horns by our own strength?
22465	885	14	But, behold, I will raise up against you a nation, O house of Israel, saith the LORD the God of hosts; and they shall afflict you from the entering in of Hemath unto the river of the wilderness.
22466	886	1	THUS hath the Lord GOD shewed unto me; and, behold, he formed grasshoppers in the beginning of the shooting up of the latter growth; and, lo, it was the latter growth after the king's mowings.
22467	886	2	And it came to pass, that when they had made an end of eating the grass of the land, then I said, O Lord GOD, forgive, I beseech thee: by whom shall Jacob arise? for he is small.
22468	886	3	The LORD repented for this: It shall not be, saith the LORD.
22469	886	4	Thus hath the Lord GOD shewed unto me: and, behold, the Lord GOD called to contend by fire, and it devoured the great deep, and did eat up a part.
22470	886	5	Then said I, O Lord GOD, cease, I beseech thee: by whom shall Jacob arise? for he is small.
22471	886	6	The LORD repented for this: This also shall not be, saith the Lord GOD.
22472	886	7	Thus he shewed me: and, behold, the Lord stood upon a wall made by a plumbline, with a plumbline in his hand.
22473	886	8	And the LORD said unto me, Amos, what seest thou? And I said, A plumbline. Then said the Lord, Behold, I will set a plumbline in the midst of my people Israel: I will not again pass by them any more:
22474	886	9	And the high places of Isaac shall be desolate, and the sanctuaries of Israel shall be laid waste; and I will rise against the house of Jeroboam with the sword.
22475	886	10	Then Amaziah the priest of Beth-el sent to Jeroboam king of Israel, saying, Amos hath conspired against thee in the midst of the house of Israel: the land is not able to bear all his words.
22476	886	11	For thus Amos saith, Jeroboam shall die by the sword, and Israel shall surely be led away captive out of their own land.
22477	886	12	Also Amaziah said unto Amos, O thou seer, go, flee thee away into the land of Judah, and there eat bread, and prophesy there:
22478	886	13	But prophesy not again any more at Beth-el: for it is the king's chapel, and it is the king's court.
22479	886	14	Then answered Amos, and said to Amaziah, I was no prophet, neither was I a prophet's son; but I was an herdman, and a gatherer of sycomore fruit:
22480	886	15	And the LORD took me as I followed the flock, and the LORD said unto me, Go, prophesy unto my people Israel.
22481	886	16	Now therefore hear thou the word of the LORD: Thou sayest, Prophesy not against Israel, and drop not thy word against the house of Isaac.
22482	886	17	Therefore thus saith the LORD; Thy wife shall be an harlot in the city, and thy sons and thy daughters shall fall by the sword, and thy land shall be divided by line; and thou shalt die in a polluted land: and Israel shall surely go into captivity forth of his land.
22483	887	1	THUS hath the Lord GOD shewed unto me: and behold a basket of summer fruit.
22484	887	2	And he said, Amos, what seest thou? And I said, A basket of summer fruit. Then said the LORD unto me, The end is come upon my people of Israel; I will not again pass by them any more.
22485	887	3	And the songs of the temple shall be howlings in that day, saith the Lord GOD: there shall be many dead bodies in every place; they shall cast them forth with silence.
22486	887	4	Hear this, O ye that swallow up the needy, even to make the poor of the land to fail,
22487	887	5	Saying, When will the new moon be gone, that we may sell corn? and the sabbath, that we may set forth wheat, making the ephah small, and the shekel great, and falsifying the balances by deceit?
22488	887	6	That we may buy the poor for silver, and the needy for a pair of shoes; yea, and sell the refuse of the wheat?
22489	887	7	The LORD hath sworn by the excellency of Jacob, Surely I will never forget any of their works.
22490	887	8	Shall not the land tremble for this, and every one mourn that dwelleth therein? and it shall rise up wholly as a flood; and it shall be cast out and drowned, as by the flood of Egypt.
22491	887	9	And it shall come to pass in that day, saith the Lord GOD, that I will cause the sun to go down at noon, and I will darken the earth in the clear day:
22492	887	10	And I will turn your feasts into mourning, and all your songs into lamentation; and I will bring up sackcloth upon all loins, and baldness upon every head; and I will make it as the mourning of an only son, and the end thereof as a bitter day.
22493	887	11	Behold, the days come, saith the Lord GOD, that I will send a famine in the land, not a famine of bread, nor a thirst for water, but of hearing the words of the LORD:
22494	887	12	And they shall wander from sea to sea, and from the north even to the east, they shall run to and fro to seek the word of the LORD, and shall not find it.
22495	887	13	In that day shall the fair virgins and young men faint for thirst.
22496	887	14	They that swear by the sin of Samaria, and say, Thy god, O Dan, liveth; and, The manner of Beer-sheba liveth; even they shall fall, and never rise up again.
22497	888	1	I SAW the Lord standing upon the altar: and he said, Smite the lintel of the door, that the posts may shake: and cut them in the head, all of them; and I will slay the last of them with the sword: he that fleeth of them shall not flee away, and he that escapeth of them shall not be delivered.
22498	888	2	Though they dig into hell, thence shall mine hand take them; though they climb up to heaven, thence will I bring them down:
22499	888	3	And though they hide themselves in the top of Carmel, I will search and take them out thence; and though they be hid from my sight in the bottom of the sea, thence will I command the serpent, and he shall bite them:
22500	888	4	And though they go into captivity before their enemies, thence will I command the sword, and it shall slay them: and I will set mine eyes upon them for evil, and not for good.
22501	888	5	And the Lord GOD of hosts is he that toucheth the land, and it shall melt, and all that dwell therein shall mourn: and it shall rise up wholly like a flood; and shall be drowned, as by the flood of Egypt.
22502	888	6	It is he that buildeth his stories in the heaven, and hath founded his troop in the earth; he that calleth for the waters of the sea, and poureth them out upon the face of the earth: The LORD is his name.
22503	888	7	Are ye not as children of the Ethiopians unto me, O children of Israel? saith the LORD. Have not I brought up Israel out of the land of Egypt? and the Philistines from Caphtor, and the Syrians from Kir?
22504	888	8	Behold, the eyes of the Lord GOD are upon the sinful kingdom, and I will destroy it from off the face of the earth; saving that I will not utterly destroy the house of Jacob, saith the LORD.
22505	888	9	For, lo, I will command, and I will sift the house of Israel among all nations, like as corn is sifted in a sieve, yet shall not the least grain fall upon the earth.
22506	888	10	All the sinners of my people shall die by the sword, which say, The evil shall not overtake nor prevent us.
22507	888	11	In that day will I raise up the tabernacle of David that is fallen, and close up the breaches thereof; and I will raise up his ruins, and I will build it as in the days of old:
22508	888	12	That they may possess the remnant of Edom, and of all the heathen, which are called by my name, saith the LORD that doeth this.
22509	888	13	Behold, the days come, saith the LORD, that the plowman shall overtake the reaper, and the treader of grapes him that soweth seed; and the mountains shall drop sweet wine, and all the hills shall melt.
22510	888	14	And I will bring again the captivity of my people of Israel, and they shall build the waste cities, and inhabit them; and they shall plant vineyards, and drink the wine thereof; they shall also make gardens, and eat the fruit of them.
22511	888	15	And I will plant them upon their land, and they shall no more be pulled up out of their land which I have given them, saith the LORD thy God.
22512	889	1	THE vision of Obadiah. Thus saith the Lord GOD concerning Edom; We have heard a rumour from the LORD, and an ambassador is sent among the heathen, Arise ye, and let us rise up against her in battle.
22513	889	2	Behold, I have made thee small among the heathen: thou art greatly despised.
22514	889	3	The pride of thine heart hath deceived thee, thou that dwellest in the clefts of the rock, whose habitation is high; that saith in his heart, Who shall bring me down to the ground?
22515	889	4	Though thou exalt thyself as the eagle, and though thou set thy nest among the stars, thence will I bring thee down, saith the LORD.
22516	889	5	If thieves came to thee, if robbers by night, (how art thou cut off!) would they not have stolen till they had enough? if the grapegatherers came to thee, would they not leave some grapes?
22517	889	6	How are the things of Esau searched out! how are his hidden things sought up!
22518	889	7	All the men of thy confederacy have brought thee even to the border: the men that were at peace with thee have deceived thee, and prevailed against thee; they that eat thy bread have laid a wound under thee: there is none understanding in him.
22519	889	8	Shall I not in that day, saith the LORD, even destroy the wise men out of Edom, and understanding out of the mount of Esau?
22520	889	9	And thy mighty men, O Teman, shall be dismayed, to the end that every one of the mount of Esau may be cut off by slaughter.
22521	889	10	For thy violence against thy brother Jacob shame shall cover thee, and thou shalt be cut off for ever.
22522	889	11	In the day that thou stoodest on the other side, in the day that the strangers carried away captive his forces, and foreigners entered into his gates, and cast lots upon Jerusalem, even thou wast as one of them.
22523	889	12	But thou shouldest not have looked on the day of thy brother in the day that he became a stranger; neither shouldest thou have rejoiced over the children of Judah in the day of their destruction; neither shouldest thou have spoken proudly in the day of distress.
22524	889	13	Thou shouldest not have entered into the gate of my people in the day of their calamity; yea, thou shouldest not have looked on their affliction in the day of their calamity, nor have laid hands on their substance in the day of their calamity;
22525	889	14	Neither shouldest thou have stood in the crossway, to cut off those of his that did escape; neither shouldest thou have delivered up those of his that did remain in the day of distress.
22526	889	15	For the day of the LORD is near upon all the heathen: as thou hast done, it shall be done unto thee: thy reward shall return upon thine own head.
22527	889	16	For as ye have drunk upon my holy mountain, so shall all the heathen drink continually, yea, they shall drink, and they shall swallow down, and they shall be as though they had not been.
22528	889	17	But upon mount Zion shall be deliverance, and there shall be holiness; and the house of Jacob shall possess their possessions.
22529	889	18	And the house of Jacob shall be a fire, and the house of Joseph a flame, and the house of Esau for stubble, and they shall kindle in them, and devour them; and there shall not be any remaining of the house of Esau; for the LORD hath spoken it.
22530	889	19	And they of the south shall possess the mount of Esau; and they of the plain the Philistines: and they shall possess the fields of Ephraim, and the fields of Samaria: and Benjamin shall possess Gilead.
22531	889	20	And the captivity of this host of the children of Israel shall possess that of the Canaanites, even unto Zarephath; and the captivity of Jerusalem, which is in Sepharad, shall possess the cities of the south.
22532	889	21	And saviours shall come up on mount Zion to judge the mount of Esau; and the kingdom shall be the LORD's.
22533	890	1	NOW the word of the LORD came unto Jonah the son of Amittai, saying,
22534	890	2	Arise, go to Nineveh, that great city, and cry against it; for their wickedness is come up before me.
22535	890	3	But Jonah rose up to flee unto Tarshish from the presence of the LORD, and went down to Joppa; and he found a ship going to Tarshish: so he paid the fare thereof, and went down into it, to go with them unto Tarshish from the presence of the LORD.
22536	890	4	But the LORD sent out a great wind into the sea, and there was a mighty tempest in the sea, so that the ship was like to be broken.
22537	890	5	Then the mariners were afraid, and cried every man unto his god, and cast forth the wares that were in the ship into the sea, to lighten it of them. But Jonah was gone down into the sides of the ship; and he lay, and was fast asleep.
22538	890	6	So the shipmaster came to him, and said unto him, What meanest thou, O sleeper? arise, call upon thy God, if so be that God will think upon us, that we perish not.
22539	890	7	And they said every one to his fellow, Come, and let us cast lots, that we may know for whose cause this evil is upon us. So they cast lots, and the lot fell upon Jonah.
22540	890	8	Then said they unto him, Tell us, we pray thee, for whose cause this evil is upon us; What is thine occupation? and whence comest thou? what is thy country? and of what people art thou?
22541	890	9	And he said unto them, I am an Hebrew; and I fear the LORD, the God of heaven, which hath made the sea and the dry land.
22542	890	10	Then were the men exceedingly afraid, and said unto him, Why hast thou done this? For the men knew that he fled from the presence of the LORD, because he had told them.
22543	890	11	Then said they unto him, What shall we do unto thee, that the sea may be calm unto us? for the sea wrought, and was tempestuous.
22544	890	12	And he said unto them, Take me up, and cast me forth into the sea; so shall the sea be calm unto you: for I know that for my sake this great tempest is upon you.
22545	890	13	Nevertheless the men rowed hard to bring it to the land; but they could not: for the sea wrought, and was tempestuous against them.
22546	890	14	Wherefore they cried unto the LORD, and said, We beseech thee, O LORD, we beseech thee, let us not perish for this man's life, and lay not upon us innocent blood: for thou, O LORD, hast done as it pleased thee.
22547	890	15	So they took up Jonah, and cast him forth into the sea: and the sea ceased from her raging.
22548	890	16	Then the men feared the LORD exceedingly, and offered a sacrifice unto the LORD, and made vows.
22549	890	17	Now the LORD had prepared a great fish to swallow up Jonah. And Jonah was in the belly of the fish three days and three nights.
22550	891	1	THEN Jonah prayed unto the LORD his God out of the fish's belly,
22551	891	2	And said, I cried by reason of mine affliction unto the LORD, and he heard me; out of the belly of hell cried I, and thou heardest my voice.
22552	891	3	For thou hadst cast me into the deep, in the midst of the seas; and the floods compassed me about: all thy billows and thy waves passed over me.
22553	891	4	Then I said, I am cast out of thy sight; yet I will look again toward thy holy temple.
22554	891	5	The waters compassed me about, even to the soul: the depth closed me round about, the weeds were wrapped about my head.
22555	891	6	I went down to the bottoms of the mountains; the earth with her bars was about me for ever: yet hast thou brought up my life from corruption, O LORD my God.
22556	891	7	When my soul fainted within me I remembered the LORD: and my prayer came in unto thee, into thine holy temple.
22557	891	8	They that observe lying vanities forsake their own mercy.
22558	891	9	But I will sacrifice unto thee with the voice of thanksgiving; I will pay that that I have vowed. Salvation is of the LORD.
22559	891	10	And the LORD spake unto the fish, and it vomited out Jonah upon the dry land.
22560	892	1	AND the word of the LORD came unto Jonah the second time, saying,
22561	892	2	Arise, go unto Nineveh, that great city, and preach unto it the preaching that I bid thee.
22562	892	3	So Jonah arose, and went unto Nineveh, according to the word of the LORD. Now Nineveh was an exceeding great city of three days' journey.
22563	892	4	And Jonah began to enter into the city a day's journey, and he cried, and said, Yet forty days, and Nineveh shall be overthrown.
22564	892	5	So the people of Nineveh believed God, and proclaimed a fast, and put on sackcloth, from the greatest of them even to the least of them.
22565	892	6	For word came unto the king of Nineveh, and he arose from his throne, and he laid his robe from him, and covered him with sackcloth, and sat in ashes.
22566	892	7	And he caused it to be proclaimed and published through Nineveh by the decree of the king and his nobles, saying, Let neither man nor beast, herd nor flock, taste any thing: let them not feed, nor drink water:
22567	892	8	But let man and beast be covered with sackcloth, and cry mightily unto God: yea, let them turn every one from his evil way, and from the violence that is in their hands.
22568	892	9	Who can tell if God will turn and repent, and turn away from his fierce anger, that we perish not?
22569	892	10	And God saw their works, that they turned from their evil way; and God repented of the evil, that he had said that he would do unto them; and he did it not.
22570	893	1	BUT it displeased Jonah exceedingly, and he was very angry.
22571	893	2	And he prayed unto the LORD, and said, I pray thee, O LORD, was not this my saying, when I was yet in my country? Therefore I fled before unto Tarshish: for I knew that thou art a gracious God, and merciful, slow to anger, and of great kindness, and repentest thee of the evil.
22572	893	3	Therefore now, O LORD, take, I beseech thee, my life from me; for it is better for me to die than to live.
22573	893	4	Then said the LORD, Doest thou well to be angry?
22574	893	5	So Jonah went out of the city, and sat on the east side of the city, and there made him a booth, and sat under it in the shadow, till he might see what would become of the city.
22575	893	6	And the LORD God prepared a gourd, and made it to come up over Jonah, that it might be a shadow over his head, to deliver him from his grief. So Jonah was exceeding glad of the gourd.
22576	893	7	But God prepared a worm when the morning rose the next day, and it smote the gourd that it withered.
22577	893	8	And it came to pass, when the sun did arise, that God prepared a vehement east wind; and the sun beat upon the head of Jonah, that he fainted, and wished in himself to die, and said, It is better for me to die than to live.
22578	893	9	And God said to Jonah, Doest thou well to be angry for the gourd? And he said, I do well to be angry, even unto death.
22579	893	10	Then said the LORD, Thou hast had pity on the gourd, for the which thou hast not laboured, neither madest it grow; which came up in a night, and perished in a night:
22580	893	11	And should not I spare Nineveh, that great city, wherein are more than sixscore thousand persons that cannot discern between their right hand and their left hand; and also much cattle?
22581	894	1	THE word of the LORD that came to Micah the Morasthite in the days of Jotham, Ahaz, and Hezekiah, kings of Judah, which he saw concerning Samaria and Jerusalem.
22582	894	2	Hear, all ye people; hearken, O earth, and all that therein is: and let the Lord GOD be witness against you, the Lord from his holy temple.
22583	894	3	For, behold, the LORD cometh forth out of his place, and will come down, and tread upon the high places of the earth.
22584	894	4	And the mountains shall be molten under him, and the valleys shall be cleft, as wax before the fire, and as the waters that are poured down a steep place.
22585	894	5	For the transgression of Jacob is all this, and for the sins of the house of Israel. What is the transgression of Jacob? is it not Samaria? and what are the high places of Judah? are they not Jerusalem?
22586	894	6	Therefore I will make Samaria as an heap of the field, and as plantings of a vineyard: and I will pour down the stones thereof into the valley, and I will discover the foundations thereof.
22587	894	7	And all the graven images thereof shall be beaten to pieces, and all the hires thereof shall be burned with the fire, and all the idols thereof will I lay desolate: for she gathered it of the hire of an harlot, and they shall return to the hire of an harlot.
22588	894	8	Therefore I will wail and howl, I will go stripped and naked: I will make a wailing like the dragons, and mourning as the owls.
22589	894	9	For her wound is incurable; for it is come unto Judah; he is come unto the gate of my people, even to Jerusalem.
22590	894	10	Declare ye it not at Gath, weep ye not at all: in the house of Aphrah roll thyself in the dust.
22591	894	11	Pass ye away, thou inhabitant of Saphir, having thy shame naked: the inhabitant of Zaanan came not forth in the mourning of Beth-ezel; he shall receive of you his standing.
22592	894	12	For the inhabitant of Maroth waited carefully for good: but evil came down from the LORD unto the gate of Jerusalem.
22593	894	13	O thou inhabitant of Lachish, bind the chariot to the swift beast: she is the beginning of the sin to the daughter of Zion: for the transgressions of Israel were found in thee.
22594	894	14	Therefore shalt thou give presents to Moresheth-gath: the houses of Achzib shall be a lie to the kings of Israel.
22595	894	15	Yet will I bring an heir unto thee, O inhabitant of Mareshah: he shall come unto Adullam the glory of Israel.
22596	894	16	Make thee bald, and poll thee for thy delicate children; enlarge thy baldness as the eagle; for they are gone into captivity from thee.
22597	895	1	WOE to them that devise iniquity, and work evil upon their beds! when the morning is light, they practise it, because it is in the power of their hand.
22598	895	2	And they covet fields, and take them by violence; and houses, and take them away: so they oppress a man and his house, even a man and his heritage.
22599	895	3	Therefore thus saith the LORD; Behold, against this family do I devise an evil, from which ye shall not remove your necks; neither shall ye go haughtily: for this time is evil.
22600	895	4	In that day shall one take up a parable against you, and lament with a doleful lamentation, and say, We be utterly spoiled: he hath changed the portion of my people: how hath he removed it from me! turning away he hath divided our fields.
22601	895	5	Therefore thou shalt have none that shall cast a cord by lot in the congregation of the LORD.
22602	895	6	Prophesy ye not, say they to them that prophesy: they shall not prophesy to them, that they shall not take shame.
22603	895	7	O thou that art named the house of Jacob, is the spirit of the LORD straitened? are these his doings? do not my words do good to him that walketh uprightly?
22604	895	8	Even of late my people is risen up as an enemy: ye pull off the robe with the garment from them that pass by securely as men averse from war.
22605	895	9	The women of my people have ye cast out from their pleasant houses; from their children have ye taken away my glory for ever.
22606	895	10	Arise ye, and depart; for this is not your rest: because it is polluted, it shall destroy you, even with a sore destruction.
22607	895	11	If a man walking in the spirit and falsehood do lie, saying, I will prophesy unto thee of wine and of strong drink; he shall even be the prophet of this people.
22608	895	12	I will surely assemble, O Jacob, all of thee; I will surely gather the remnant of Israel; I will put them together as the sheep of Bozrah, as the flock in the midst of their fold: they shall make great noise by reason of the multitude of men.
22609	895	13	The breaker is come up before them: they have broken up, and have passed through the gate, and are gone out by it: and their king shall pass before them, and the LORD on the head of them.
22610	896	1	AND I said, Hear, I pray you, O heads of Jacob, and ye princes of the house of Israel; Is it not for you to know judgment?
22611	896	2	Who hate the good, and love the evil; who pluck off their skin from off them, and their flesh from off their bones;
22612	896	3	Who also eat the flesh of my people, and flay their skin from off them; and they break their bones, and chop them in pieces, as for the pot, and as flesh within the caldron.
22613	896	4	Then shall they cry unto the LORD, but he will not hear them: he will even hide his face from them at that time, as they have behaved themselves ill in their doings.
22614	896	5	Thus saith the LORD concerning the prophets that make my people err, that bite with their teeth, and cry, Peace; and he that putteth not into their mouths, they even prepare war against him.
22615	896	6	Therefore night shall be unto you, that ye shall not have a vision; and it shall be dark unto you, that ye shall not divine; and the sun shall go down over the prophets, and the day shall be dark over them.
22616	896	7	Then shall the seers be ashamed, and the diviners confounded: yea, they shall all cover their lips; for there is no answer of God.
22617	896	8	But truly I am full of power by the spirit of the LORD, and of judgment, and of might, to declare unto Jacob his transgression, and to Israel his sin.
22618	896	9	Hear this, I pray you, ye heads of the house of Jacob, and princes of the house of Israel, that abhor judgment, and pervert all equity.
22619	896	10	They build up Zion with blood, and Jerusalem with iniquity.
22620	896	11	The heads thereof judge for reward, and the priests thereof teach for hire, and the prophets thereof divine for money: yet will they lean upon the LORD, and say, Is not the LORD among us? none evil can come upon us.
22621	896	12	Therefore shall Zion for your sake be plowed as a field, and Jerusalem shall become heaps, and the mountain of the house as the high places of the forest.
22622	897	1	BUT in the last days it shall come to pass, that the mountain of the house of the LORD shall be established in the top of the mountains, and it shall be exalted above the hills; and people shall flow unto it.
22623	897	2	And many nations shall come, and say, Come, and let us go up to the mountain of the LORD, and to the house of the God of Jacob; and he will teach us of his ways, and we will walk in his paths: for the law shall go forth of Zion, and the word of the LORD from Jerusalem.
22624	897	3	And he shall judge among many people, and rebuke strong nations afar off; and they shall beat their swords into plowshares, and their spears into pruninghooks: nation shall not lift up a sword against nation, neither shall they learn war any more.
22625	897	4	But they shall sit every man under his vine and under his fig tree; and none shall make them afraid: for the mouth of the LORD of hosts hath spoken it.
22626	897	5	For all people will walk every one in the name of his god, and we will walk in the name of the LORD our God for ever and ever.
22627	897	6	In that day, saith the LORD, will I assemble her that halteth, and I will gather her that is driven out, and her that I have afflicted;
22628	897	7	And I will make her that halted a remnant, and her that was cast far off a strong nation: and the LORD shall reign over them in mount Zion from henceforth, even for ever.
22629	897	8	And thou, O tower of the flock, the strong hold of the daughter of Zion, unto thee shall it come, even the first dominion; the kingdom shall come to the daughter of Jerusalem.
22630	897	9	Now why dost thou cry out aloud? is there no king in thee? is thy counsellor perished? for pangs have taken thee as a woman in travail.
22631	897	10	Be in pain, and labour to bring forth, O daughter of Zion, like a woman in travail: for now shalt thou go forth out of the city, and thou shalt dwell in the field, and thou shalt go even to Babylon; there shalt thou be delivered; there the LORD shall redeem thee from the hand of thine enemies.
22632	897	11	Now also many nations are gathered against thee, that say, Let her be defiled, and let our eye look upon Zion.
22633	897	12	But they know not the thoughts of the LORD, neither understand they his counsel: for he shall gather them as the sheaves into the floor.
22634	897	13	Arise and thresh, O daughter of Zion: for I will make thine horn iron, and I will make thy hoofs brass: and thou shalt beat in pieces many people: and I will consecrate their gain unto the LORD, and their substance unto the Lord of the whole earth.
22635	898	1	NOW gather thyself in troops, O daughter of troops: he hath laid siege against us: they shall smite the judge of Israel with a rod upon the cheek.
22636	898	2	But thou, Beth-lehem Ephratah, though thou be little among the thousands of Judah, yet out of thee shall he come forth unto me that is to be ruler in Israel; whose goings forth have been from of old, from everlasting.
22637	898	3	Therefore will he give them up, until the time that she which travaileth hath brought forth: then the remnant of his brethren shall return unto the children of Israel.
22638	898	4	And he shall stand and feed in the strength of the LORD, in the majesty of the name of the LORD his God; and they shall abide: for now shall he be great unto the ends of the earth.
22639	898	5	And this man shall be the peace, when the Assyrian shall come into our land: and when he shall tread in our palaces, then shall we raise against him seven shepherds, and eight principal men.
22640	898	6	And they shall waste the land of Assyria with the sword, and the land of Nimrod in the entrances thereof: thus shall he deliver us from the Assyrian, when he cometh into our land, and when he treadeth within our borders.
22641	898	7	And the remnant of Jacob shall be in the midst of many people as a dew from the LORD, as the showers upon the grass, that tarrieth not for man, nor waiteth for the sons of men.
22642	898	8	And the remnant of Jacob shall be among the Gentiles in the midst of many people as a lion among the beasts of the forest, as a young lion among the flocks of sheep: who, if he go through, both treadeth down, and teareth in pieces, and none can deliver.
22643	898	9	Thine hand shall be lifted up upon thine adversaries, and all thine enemies shall be cut off.
22644	898	10	And it shall come to pass in that day, saith the LORD, that I will cut off thy horses out of the midst of thee, and I will destroy thy chariots:
22645	898	11	And I will cut off the cities of thy land, and throw down all thy strong holds:
22646	898	12	And I will cut off witchcrafts out of thine hand; and thou shalt have no more soothsayers:
22647	898	13	Thy graven images also will I cut off, and thy standing images out of the midst of thee; and thou shalt no more worship the work of thine hands.
22648	898	14	And I will pluck up thy groves out of the midst of thee: so will I destroy thy cities.
22649	898	15	And I will execute vengeance in anger and fury upon the heathen, such as they have not heard.
22650	899	1	HEAR ye now what the LORD saith; Arise, contend thou before the mountains, and let the hills hear thy voice.
22651	899	2	Hear ye, O mountains, the LORD's controversy, and ye strong foundations of the earth: for the LORD hath a controversy with his people, and he will plead with Israel.
22652	899	3	O my people, what have I done unto thee? and wherein have I wearied thee? testify against me.
22653	899	4	For I brought thee up out of the land of Egypt, and redeemed thee out of the house of servants; and I sent before thee Moses, Aaron, and Miriam.
22654	899	5	O my people, remember now what Balak king of Moab consulted, and what Balaam the son of Beor answered him from Shittim unto Gilgal; that ye may know the righteousness of the LORD.
22655	899	6	Wherewith shall I come before the LORD, and bow myself before the high God? shall I come before him with burnt offerings, with calves of a year old?
22656	899	7	Will the LORD be pleased with thousands of rams, or with ten thousands of rivers of oil? shall I give my firstborn for my transgression, the fruit of my body for the sin of my soul?
22657	899	8	He hath shewed thee, O man, what is good; and what doth the LORD require of thee, but to do justly, and to love mercy, and to walk humbly with thy God?
22658	899	9	The LORD's voice crieth unto the city, and the man of wisdom shall see thy name: hear ye the rod, and who hath appointed it.
22659	899	10	Are there yet the treasures of wickedness in the house of the wicked, and the scant measure that is abominable?
22660	899	11	Shall I count them pure with the wicked balances, and with the bag of deceitful weights?
22661	899	12	For the rich men thereof are full of violence, and the inhabitants thereof have spoken lies, and their tongue is deceitful in their mouth.
22662	899	13	Therefore also will I make thee sick in smiting thee, in making thee desolate because of thy sins.
22663	899	14	Thou shalt eat, but not be satisfied; and thy casting down shall be in the midst of thee; and thou shalt take hold, but shalt not deliver; and that which thou deliverest will I give up to the sword.
22664	899	15	Thou shalt sow, but thou shalt not reap; thou shalt tread the olives, but thou shalt not anoint thee with oil; and sweet wine, but shalt not drink wine.
22665	899	16	For the statutes of Omri are kept, and all the works of the house of Ahab, and ye walk in their counsels; that I should make thee a desolation, and the inhabitants thereof an hissing: therefore ye shall bear the reproach of my people.
22666	900	1	WOE is me! for I am as when they have gathered the summer fruits, as the grapegleanings of the vintage: there is no cluster to eat: my soul desired the firstripe fruit.
22667	900	2	The good man is perished out of the earth: and there is none upright among men: they all lie in wait for blood; they hunt every man his brother with a net.
22668	900	3	That they may do evil with both hands earnestly, the prince asketh, and the judge asketh for a reward; and the great man, he uttereth his mischievous desire: so they wrap it up.
22669	900	4	The best of them is as a brier: the most upright is sharper than a thorn hedge: the day of thy watchmen and thy visitation cometh; now shall be their perplexity.
22670	900	5	Trust ye not in a friend, put ye not confidence in a guide: keep the doors of thy mouth from her that lieth in thy bosom.
22671	900	6	For the son dishonoureth the father, the daughter riseth up against her mother, the daughter in law against her mother in law; a man's enemies are the men of his own house.
22672	900	7	Therefore I will look unto the LORD; I will wait for the God of my salvation: my God will hear me.
22673	900	8	Rejoice not against me, O mine enemy: when I fall, I shall arise; when I sit in darkness, the LORD shall be a light unto me.
22674	900	9	I will bear the indignation of the LORD, because I have sinned against him, until he plead my cause, and execute judgment for me: he will bring me forth to the light, and I shall behold his righteousness.
22675	900	10	Then she that is mine enemy shall see it, and shame shall cover her which said unto me, Where is the LORD thy God? mine eyes shall behold her: now shall she be trodden down as the mire of the streets.
22676	900	11	In the day that thy walls are to be built, in that day shall the decree be far removed.
22677	900	12	In that day also he shall come even to thee from Assyria, and from the fortified cities, and from the fortress even to the river, and from sea to sea, and from mountain to mountain.
22678	900	13	Notwithstanding the land shall be desolate because of them that dwell therein, for the fruit of their doings.
22679	900	14	Feed thy people with thy rod, the flock of thine heritage, which dwell solitarily in the wood, in the midst of Carmel: let them feed in Bashan and Gilead, as in the days of old.
22680	900	15	According to the days of thy coming out of the land of Egypt will I shew unto him marvellous things.
22681	900	16	The nations shall see and be confounded at all their might: they shall lay their hand upon their mouth, their ears shall be deaf.
22682	900	17	They shall lick the dust like a serpent, they shall move out of their holes like worms of the earth: they shall be afraid of the LORD our God, and shall fear because of thee.
22683	900	18	Who is a God like unto thee, that pardoneth iniquity, and passeth by the transgression of the remnant of his heritage? he retaineth not his anger for ever, because he delighteth in mercy.
22684	900	19	He will turn again, he will have compassion upon us; he will subdue our iniquities; and thou wilt cast all their sins into the depths of the sea.
22685	900	20	Thou wilt perform the truth to Jacob, and the mercy to Abraham, which thou hast sworn unto our fathers from the days of old.
22686	901	1	THE burden of Nineveh. The book of the vision of Nahum the Elkoshite.
22687	901	2	God is jealous, and the LORD revengeth; the LORD revengeth, and is furious; the LORD will take vengeance on his adversaries, and he reserveth wrath for his enemies.
22688	901	3	The LORD is slow to anger, and great in power, and will not at all acquit the wicked: the LORD hath his way in the whirlwind and in the storm, and the clouds are the dust of his feet.
22689	901	4	He rebuketh the sea, and maketh it dry, and drieth up all the rivers: Bashan languisheth, and Carmel, and the flower of Lebanon languisheth.
22690	901	5	The mountains quake at him, and the hills melt, and the earth is burned at his presence, yea, the world, and all that dwell therein.
22691	901	6	Who can stand before his indignation? and who can abide in the fierceness of his anger? his fury is poured out like fire, and the rocks are thrown down by him.
22692	901	7	The LORD is good, a strong hold in the day of trouble; and he knoweth them that trust in him.
22693	901	8	But with an overrunning flood he will make an utter end of the place thereof, and darkness shall pursue his enemies.
22694	901	9	What do ye imagine against the LORD? he will make an utter end: affliction shall not rise up the second time.
22695	901	10	For while they be folden together as thorns, and while they are drunken as drunkards, they shall be devoured as stubble fully dry.
22696	901	11	There is one come out of thee, that imagineth evil against the LORD, a wicked counsellor.
22697	901	12	Thus saith the LORD: Though they be quiet, and likewise many, yet thus shall they be cut down, when he shall pass through. Though I have afflicted thee, I will afflict thee no more.
22698	901	13	For now will I break his yoke from off thee, and will burst thy bonds in sunder.
22699	901	14	And the LORD hath given a commandment concerning thee, that no more of thy name be sown: out of the house of thy gods will I cut off the graven image and the molten image: I will make thy grave; for thou art vile.
22700	901	15	Behold upon the mountains the feet of him that bringeth good tidings, that publisheth peace! O Judah, keep thy solemn feasts, perform thy vows: for the wicked shall no more pass through thee; he is utterly cut off.
22701	902	1	HE that dasheth in pieces is come up before thy face: keep the munition, watch the way, make thy loins strong, fortify thy power mightily.
22702	902	2	For the LORD hath turned away the excellency of Jacob, as the excellency of Israel: for the emptiers have emptied them out, and marred their vine branches.
22703	902	3	The shield of his mighty men is made red, the valiant men are in scarlet: the chariots shall be with flaming torches in the day of his preparation, and the fir trees shall be terribly shaken.
22704	902	4	The chariots shall rage in the streets, they shall justle one against another in the broad ways: they shall seem like torches, they shall run like the lightnings.
22705	902	5	He shall recount his worthies: they shall stumble in their walk; they shall make hast to the wall thereof, and the defence shall be prepared.
22706	902	6	The gates of the rivers shall be opened, and the palace shall be dissolved.
22707	902	7	And Huzzab shall be led away captive, she shall be brought up, and her maids shall lead her as with the voice of doves, tabering upon their breasts.
22708	902	8	But Nineveh is of old like a pool of water: yet they shall flee away. Stand, stand, shall they cry; but none shall look back.
22709	902	9	Take ye the spoil of silver, take the spoil of gold: for there is none end of the store and glory out of all the pleasant furniture.
22710	902	10	She is empty, and void, and waste: and the heart melteth, and the knees smite together, and much pain is in all loins, and the faces of them all gather blackness.
22711	902	11	Where is the dwelling of the lions, and the feedingplace of the young lions, where the lion, even the old lion, walked, and the lion's whelp, and none made them afraid?
22712	902	12	The lion did tear in pieces enough for his whelps, and strangled for his lionesses, and filled his holes with prey, and his dens with ravin.
22713	902	13	Behold, I am against thee, saith the LORD of hosts, and I will burn her chariots in the smoke, and the sword shall devour thy young lions: and I will cut off thy prey from the earth, and the voice of thy messengers shall no more be heard.
22714	903	1	WOE to the bloody city! it is all full of lies and robbery; the prey departeth not;
22715	903	2	The noise of a whip, and the noise of the rattling of the wheels, and of the pransing horses, and of the jumping chariots.
22716	903	3	The horseman lifteth up both the bright sword and the glittering spear: and there is a multitude of slain, and a great number of carcases; and there is none end of their corpses; they stumble upon their corpses:
22717	903	4	Because of the multitude of the whoredoms of the wellfavoured harlot, the mistress of witchcrafts, that selleth nations through her whoredoms, and families through her witchcrafts.
22718	903	5	Behold, I am against thee, saith the LORD of hosts; and I will discover thy skirts upon thy face, and I will shew the nations thy nakedness, and the kingdoms thy shame.
22719	903	6	And I will cast abominable filth upon thee, and make thee vile, and will set thee as a gazingstock.
22720	903	7	And it shall come to pass, that all they that look upon thee shall flee from thee, and say, Nineveh is laid waste: who will bemoan her? whence shall I seek comforters for thee?
22721	903	8	Art thou better than populous No, that was situate among the rivers, that had the waters round about it, whose rampart was the sea, and her wall was from the sea?
22722	903	9	Ethiopia and Egypt were her strength, and it was infinite; Put and Lubim were thy helpers.
22723	903	10	Yet was she carried away, she went into captivity: her young children also were dashed in pieces at the top of all the streets: and they cast lots for her honourable men, and all her great men were bound in chains.
22724	903	11	Thou also shalt be drunken: thou shalt be hid, thou also shalt seek strength because of the enemy.
22725	903	12	All thy strong holds shall be like fig trees with the firstripe figs: if they be shaken, they shall even fall into the mouth of the eater.
22726	903	13	Behold, thy people in the midst of thee are women: the gates of thy land shall be set wide open unto thine enemies: the fire shall devour thy bars.
22727	903	14	Draw thee waters for the siege, fortify thy strong holds: go into clay, and tread the morter, make strong the brickkiln.
22728	903	15	There shall the fire devour thee; the sword shall cut thee off, it shall eat thee up like the cankerworm: make thyself many as the cankerworm, make thyself many as the locusts.
22729	903	16	Thou hast multiplied thy merchants above the stars of heaven: the cankerworm spoileth, and flieth away.
22730	903	17	Thy crowned are as the locusts, and thy captains as the great grasshoppers, which camp in the hedges in the cold day, but when the sun ariseth they flee away, and their place is not known where they are.
22731	903	18	Thy shepherds slumber, O king of Assyria: thy nobles shall dwell in the dust: thy people is scattered upon the mountains, and no man gathereth them.
22732	903	19	There is no healing of thy bruise; thy wound is grievous: all that hear the bruit of thee shall clap the hands over thee: for upon whom hath not thy wickedness passed continually?
22733	904	1	THE burden which Habakkuk the prophet did see.
22734	904	2	O LORD, how long shall I cry, and thou wilt not hear! even cry out unto thee of violence, and thou wilt not save!
22735	904	3	Why dost thou shew me iniquity, and cause me to behold grievance? for spoiling and violence are before me: and there are that raise up strife and contention.
22736	904	4	Therefore the law is slacked, and judgment doth never go forth: for the wicked doth compass about the righteous; therefore wrong judgment proceedeth.
22737	904	5	Behold ye among the heathen, and regard, and wonder marvellously: for I will work a work in your days, which ye will not believe, though it be told you.
22738	904	6	For, lo, I raise up the Chaldeans, that bitter and hasty nation, which shall march through the breadth of the land, to possess the dwellingplaces that are not theirs.
22739	904	7	They are terrible and dreadful: their judgment and their dignity shall proceed of themselves.
22740	904	8	Their horses also are swifter than the leopards, and are more fierce than the evening wolves: and their horsemen shall spread themselves, and their horsemen shall come from far; they shall fly as the eagle that hasteth to eat.
22741	904	9	They shall come all for violence: their faces shall sup up as the east wind, and they shall gather the captivity as the sand.
22742	904	10	And they shall scoff at the kings, and the princes shall be a scorn unto them: they shall deride every strong hold; for they shall heap dust, and take it.
22743	904	11	Then shall his mind change, and he shall pass over, and offend, imputing this his power unto his god.
22744	904	12	Art thou not from everlasting, O LORD my God, mine Holy One? we shall not die. O LORD, thou hast ordained them for judgment; and, O mighty God, thou hast established them for correction.
22745	904	13	Thou art of purer eyes than to behold evil, and canst not look on iniquity: wherefore lookest thou upon them that deal treacherously, and holdest thy tongue when the wicked devoureth the man that is more righteous than he?
22746	904	14	And makest men as the fishes of the sea, as the creeping things, that have no ruler over them?
22747	904	15	They take up all of them with the angle, they catch them in their net, and gather them in their drag: therefore they rejoice and are glad.
22748	904	16	Therefore they sacrifice unto their net, and burn incense unto their drag; because by them their portion is fat, and their meat plenteous.
22749	904	17	Shall they therefore empty their net, and not spare continually to slay the nations?
22750	905	1	I WILL stand upon my watch, and set me upon the tower, and will watch to see what he will say unto me, and what I shall answer when I am reproved.
22751	905	2	And the LORD answered me, and said, Write the vision, and make it plain upon tables, that he may run that readeth it.
22752	905	3	For the vision is yet for an appointed time, but at the end it shall speak, and not lie: though it tarry, wait for it; because it will surely come, it will not tarry.
22753	905	4	Behold, his soul which is lifted up is not upright in him: but the just shall live by his faith.
22754	905	5	Yea also, because he transgresseth by wine, he is a proud man, neither keepeth at home, who enlargeth his desire as hell, and is as death, and cannot be satisfied, but gathereth unto him all nations, and heapeth unto him all people:
22755	905	6	Shall not all these take up a parable against him, and a taunting proverb against him, and say, Woe to him that increaseth that which is not his! how long? and to him that ladeth himself with thick clay!
22756	905	7	Shall they not rise up suddenly that shall bite thee, and awake that shall vex thee, and thou shalt be for booties unto them?
22757	905	8	Because thou hast spoiled many nations, all the remnant of the people shall spoil thee; because of men's blood, and for the violence of the land, of the city, and of all that dwell therein.
22758	905	9	Woe to him that coveteth an evil covetousness to his house, that he may set his nest on high, that he may be delivered from the power of evil!
22759	905	10	Thou hast consulted shame to thy house by cutting off many people, and hast sinned against thy soul.
22760	905	11	For the stone shall cry out of the wall, and the beam out of the timber shall answer it.
22761	905	12	Woe to him that buildeth a town with blood, and stablisheth a city by iniquity!
22762	905	13	Behold, is it not of the LORD of hosts that the people shall labour in the very fire, and the people shall weary themselves for very vanity?
22763	905	14	For the earth shall be filled with the knowledge of the glory of the LORD, as the waters cover the sea.
22764	905	15	Woe unto him that giveth his neighbour drink, that puttest thy bottle to him, and makest him drunken also, that thou mayest look on their nakedness!
22765	905	16	Thou art filled with shame for glory: drink thou also, and let thy foreskin be uncovered: the cup of the LORD's right hand shall be turned unto thee, and shameful spewing shall be on thy glory.
22766	905	17	For the violence of Lebanon shall cover thee, and the spoil of beasts, which made them afraid, because of men's blood, and for the violence of the land, of the city, and of all that dwell therein.
22767	905	18	What profiteth the graven image that the maker thereof hath graven it; the molten image, and a teacher of lies, that the maker of his work trusteth therein, to make dumb idols?
22768	905	19	Woe unto him that saith to the wood, Awake; to the dumb stone, Arise, it shall teach! Behold, it is laid over with gold and silver, and there is no breath at all in the midst of it.
22769	905	20	But the LORD is in his holy temple: let all the earth keep silence before him.
22770	906	1	A PRAYER of Habakkuk the prophet upon Shigionoth.
22771	906	2	O LORD, I have heard thy speech, and was afraid: O LORD, revive thy work in the midst of the years, in the midst of the years make known; in wrath remember mercy.
22772	906	3	God came from Teman, and the Holy One from mount Paran. Selah. His glory covered the heavens, and the earth was full of his praise.
22773	906	4	And his brightness was as the light; he had horns coming out of his hand: and there was the hiding of his power.
22774	906	5	Before him went the pestilence, and burning coals went forth at his feet.
22775	906	6	He stood, and measured the earth: he beheld, and drove asunder the nations; and the everlasting mountains were scattered, the perpetual hills did bow: his ways are everlasting.
22776	906	7	I saw the tents of Cushan in affliction: and the curtains of the land of Midian did tremble.
22777	906	8	Was the LORD displeased against the rivers? was thine anger against the rivers? was thy wrath against the sea, that thou didst ride upon thine horses and thy chariots of salvation?
22778	906	9	Thy bow was made quite naked, according to the oaths of the tribes, even thy word. Selah. Thou didst cleave the earth with rivers.
22779	906	10	The mountains saw thee, and they trembled: the overflowing of the water passed by: the deep uttered his voice, and lifted up his hands on high.
22780	906	11	The sun and moon stood still in their habitation: at the light of thine arrows they went, and at the shining of thy glittering spear.
22781	906	12	Thou didst march through the land in indignation, thou didst thresh the heathen in anger.
22782	906	13	Thou wentest forth for the salvation of thy people, even for salvation with thine anointed; thou woundedst the head out of the house of the wicked, by discovering the foundation unto the neck. Selah.
22783	906	14	Thou didst strike through with his staves the head of his villages: they came out as a whirlwind to scatter me: their rejoicing was as to devour the poor secretly.
22784	906	15	Thou didst walk through the sea with thine horses, through the heap of great waters.
22785	906	16	When I heard, my belly trembled; my lips quivered at the voice: rottenness entered into my bones, and I trembled in myself, that I might rest in the day of trouble: when he cometh up unto the people, he will invade them with his troops.
22786	906	17	Although the fig tree shall not blossom, neither shall fruit be in the vines; the labour of the olive shall fail, and the fields shall yield no meat; the flock shall be cut off from the fold, and there shall be no herd in the stalls:
22787	906	18	Yet I will rejoice in the LORD, I will joy in the God of my salvation.
22788	906	19	The LORD God is my strength, and he will make my feet like hinds' feet, and he will make me to walk upon mine high places. To the chief singer on my stringed instruments.
22789	907	1	THE word of the LORD which came unto Zephaniah the son of Cushi, the son of Gedaliah, the son of Amariah, the son of Hizkiah, in the days of Josiah the son of Amon, king of Judah.
22790	907	2	I will utterly consume all things from off the land, saith the LORD.
22791	907	3	I will consume man and beast; I will consume the fowls of the heaven, and the fishes of the sea, and the stumblingblocks with the wicked; and I will cut off man from off the land, saith the LORD.
22792	907	4	I will also stretch out mine hand upon Judah, and upon all the inhabitants of Jerusalem; and I will cut off the remnant of Baal from this place, and the name of the Chemarims with the priests;
22793	907	5	And them that worship the host of heaven upon the housetops; and them that worship and that swear by the LORD, and that swear by Malcham;
22794	907	6	And them that are turned back from the LORD; and those that have not sought the LORD, nor enquired for him.
22795	907	7	Hold thy peace at the presence of the Lord GOD: for the day of the LORD is at hand: for the LORD hath prepared a sacrifice, he hath bid his guests.
22796	907	8	And it shall come to pass in the day of the LORD's sacrifice, that I will punish the princes, and the king's children, and all such as are clothed with strange apparel.
22797	907	9	In the same day also will I punish all those that leap on the threshold, which fill their masters' houses with violence and deceit.
22798	907	10	And it shall come to pass in that day, saith the LORD, that there shall be the noise of a cry from the fish gate, and an howling from the second, and a great crashing from the hills.
22799	907	11	Howl, ye inhabitants of Maktesh, for all the merchant people are cut down; all they that bear silver are cut off.
22800	907	12	And it shall come to pass at that time, that I will search Jerusalem with candles, and punish the men that are settled on their lees: that say in their heart, The LORD will not do good, neither will he do evil.
22801	907	13	Therefore their goods shall become a booty, and their houses a desolation: they shall also build houses, but not inhabit them; and they shall plant vineyards, but not drink the wine thereof.
22802	907	14	The great day of the LORD is near, it is near, and hasteth greatly, even the voice of the day of the LORD: the mighty man shall cry there bitterly.
22803	907	15	That day is a day of wrath, a day of trouble and distress, a day of wasteness and desolation, a day of darkness and gloominess, a day of clouds and thick darkness,
22804	907	16	A day of the trumpet and alarm against the fenced cities, and against the high towers.
22805	907	17	And I will bring distress upon men, that they shall walk like blind men, because they have sinned against the LORD: and their blood shall be poured out as dust, and their flesh as the dung.
22806	907	18	Neither their silver nor their gold shall be able to deliver them in the day of the LORD's wrath; but the whole land shall be devoured by the fire of his jealousy: for he shall make even a speedy riddance of all them that dwell in the land.
22807	908	1	GATHER yourselves together, yea, gather together, O nation not desired;
22808	908	2	Before the decree bring forth, before the day pass as the chaff, before the fierce anger of the LORD come upon you, before the day of the LORD's anger come upon you.
22809	908	3	Seek ye the LORD, all ye meek of the earth, which have wrought his judgment; seek righteousness, seek meekness: it may be ye shall be hid in the day of the LORD's anger.
22810	908	4	For Gaza shall be forsaken, and Ashkelon a desolation: they shall drive out Ashdod at the noon day, and Ekron shall be rooted up.
22811	908	5	Woe unto the inhabitants of the sea coast, the nation of the Cherethites! the word of the LORD is against you; O Canaan, the land of the Philistines, I will even destroy thee, that there shall be no inhabitant.
22812	908	6	And the sea coast shall be dwellings and cottages for shepherds, and folds for flocks.
22813	908	7	And the coast shall be for the remnant of the house of Judah; they shall feed thereupon: in the houses of Ashkelon shall they lie down in the evening: for the LORD their God shall visit them, and turn away their captivity.
22814	908	8	I have heard the reproach of Moab, and the revilings of the children of Ammon, whereby they have reproached my people, and magnified themselves against their border.
22815	908	9	Therefore as I live, saith the LORD of hosts, the God of Israel, Surely Moab shall be as Sodom, and the children of Ammon as Gomorrah, even the breeding of nettles, and saltpits, and a perpetual desolation: the residue of my people shall spoil them, and the remnant of my people shall possess them.
22816	908	10	This shall they have for their pride, because they have reproached and magnified themselves against the people of the LORD of hosts.
22817	908	11	The LORD will be terrible unto them: for he will famish all the gods of the earth; and men shall worship him, every one from his place, even all the isles of the heathen.
22818	908	12	Ye Ethiopians also, ye shall be slain by my sword.
22819	908	13	And he will stretch out his hand against the north, and destroy Assyria; and will make Nineveh a desolation, and dry like a wilderness.
22820	908	14	And flocks shall lie down in the midst of her, all the beasts of the nations: both the cormorant and the bittern shall lodge in the upper lintels of it; their voice shall sing in the windows; desolation shall be in the thresholds: for he shall uncover the cedar work.
22821	908	15	This is the rejoicing city that dwelt carelessly, that said in her heart, I am, and there is none beside me: how is she become a desolation, a place for beasts to lie down in! every one that passeth by her shall hiss, and wag his hand.
22822	909	1	WOE to her that is filthy and polluted, to the oppressing city!
22823	909	2	She obeyed not the voice; she received not correction; she trusted not in the LORD; she drew not near to her God.
22824	909	3	Her princes within her are roaring lions; her judges are evening wolves; they gnaw not the bones till the morrow.
22825	909	4	Her prophets are light and treacherous persons: her priests have polluted the sanctuary, they have done violence to the law.
22826	909	5	The just LORD is in the midst thereof; he will not do iniquity: every morning doth he bring his judgment to light, he faileth not; but the unjust knoweth no shame.
22827	909	6	I have cut off the nations: their towers are desolate; I made their streets waste, that none passeth by: their cities are destroyed, so that there is no man, that there is none inhabitant.
22828	909	7	I said, Surely thou wilt fear me, thou wilt receive instruction; so their dwelling should not be cut off, howsoever I punished them: but they rose early, and corrupted all their doings.
22829	909	8	Therefore wait ye upon me, saith the LORD, until the day that I rise up to the prey: for my determination is to gather the nations, that I may assemble the kingdoms, to pour upon them mine indignation, even all my fierce anger: for all the earth shall be devoured with the fire of my jealousy.
22830	909	9	For then will I turn to the people a pure language, that they may all call upon the name of the LORD, to serve him with one consent.
22831	909	10	From beyond the rivers of Ethiopia my suppliants, even the daughter of my dispersed, shall bring mine offering.
22832	909	11	In that day shalt thou not be ashamed for all thy doings, wherein thou hast transgressed against me: for then I will take away out of the midst of thee them that rejoice in thy pride, and thou shalt no more be haughty because of my holy mountain.
22833	909	12	I will also leave in the midst of thee an afflicted and poor people, and they shall trust in the name of the LORD.
22834	909	13	The remnant of Israel shall not do iniquity, nor speak lies; neither shall a deceitful tongue be found in their mouth: for they shall feed and lie down, and none shall make them afraid.
22835	909	14	Sing, O daughter of Zion; shout, O Israel; be glad and rejoice with all the heart, O daughter of Jerusalem.
22836	909	15	The LORD hath taken away thy judgments, he hath cast out thine enemy: the king of Israel, even the LORD, is in the midst of thee: thou shalt not see evil any more.
22837	909	16	In that day it shall be said to Jerusalem, Fear thou not: and to Zion, Let not thine hands be slack.
22838	909	17	The LORD thy God in the midst of thee is mighty; he will save, he will rejoice over thee with joy; he will rest in his love, he will joy over thee with singing.
22839	909	18	I will gather them that are sorrowful for the solemn assembly, who are of thee, to whom the reproach of it was a burden.
22840	909	19	Behold, at that time I will undo all that afflict thee: and I will save her that halteth, and gather her that was driven out; and I will get them praise and fame in every land where they have been put to shame.
22841	909	20	At that time will I bring you again, even in the time that I gather you: for I will make you a name and a praise among all people of the earth, when I turn back your captivity before your eyes, saith the LORD.
22842	910	1	IN the second year of Darius the king, in the sixth month, in the first day of the month, came the word of the LORD by Haggai the prophet unto Zerubbabel the son of Shealtiel, governor of Judah, and to Joshua the son of Josedech, the high priest, saying,
22843	910	2	Thus speaketh the LORD of hosts, saying, This people say, The time is not come, the time that the LORD's house should be built.
22844	910	3	Then came the word of the LORD by Haggai the prophet, saying,
22845	910	4	Is it time for you, O ye, to dwell in your cieled houses, and this house lie waste?
22846	910	5	Now therefore thus saith the LORD of hosts; Consider your ways.
22847	910	6	Ye have sown much, and bring in little; ye eat, but ye have not enough; ye drink, but ye are not filled with drink; ye clothe you, but there is none warm; and he that earneth wages earneth wages to put it into a bag with holes.
22848	910	7	Thus saith the LORD of hosts; Consider your ways.
22849	910	8	Go up to the mountain, and bring wood, and build the house; and I will take pleasure in it, and I will be glorified, saith the LORD.
22850	910	9	Ye looked for much, and, lo, it came to little; and when ye brought it home, I did blow upon it. Why? saith the LORD of hosts. Because of mine house that is waste, and ye run every man unto his own house.
22851	910	10	Therefore the heaven over you is stayed from dew, and the earth is stayed from her fruit.
22852	910	11	And I called for a drought upon the land, and upon the mountains, and upon the corn, and upon the new wine, and upon the oil, and upon that which the ground bringeth forth, and upon men, and upon cattle, and upon all the labour of the hands.
22853	910	12	Then Zerubbabel the son of Shealtiel, and Joshua the son of Josedech, the high priest, with all the remnant of the people, obeyed the voice of the LORD their God, and the words of Haggai the prophet, as the LORD their God had sent him, and the people did fear before the LORD.
22854	910	13	Then spake Haggai the LORD's messenger in the LORD's message unto the people, saying, I am with you, saith the LORD.
22855	910	14	And the LORD stirred up the spirit of Zerubbabel the son of Shealtiel, governor of Judah, and the spirit of Joshua the son of Josedech, the high priest, and the spirit of all the remnant of the people; and they came and did work in the house of the LORD of hosts, their God,
22856	910	15	In the four and twentieth day of the sixth month, in the second year of Darius the king.
22857	911	1	IN the seventh month, in the one and twentieth day of the month, came the word of the LORD by the prophet Haggai, saying,
22858	911	2	Speak now to Zerubbabel the son of Shealtiel, governor of Judah, and to Joshua the son of Josedech, the high priest, and to the residue of the people, saying,
22859	911	3	Who is left among you that saw this house in her first glory? and how do ye see it now? is it not in your eyes in comparison of it as nothing?
22860	911	4	Yet now be strong, O Zerubbabel, saith the LORD; and be strong, O Joshua, son of Josedech, the high priest; and be strong, all ye people of the land, saith the LORD, and work: for I am with you, saith the LORD of hosts:
22861	911	5	According to the word that I covenanted with you when ye came out of Egypt, so my spirit remaineth among you: fear ye not.
22862	911	6	For thus saith the LORD of hosts; Yet once, it is a little while, and I will shake the heavens, and the earth, and the sea, and the dry land;
22863	911	7	And I will shake all nations, and the desire of all nations shall come: and I will fill this house with glory, saith the LORD of hosts.
22864	911	8	The silver is mine, and the gold is mine, saith the LORD of hosts.
22865	911	9	The glory of this latter house shall be greater than of the former, saith the LORD of hosts: and in this place will I give peace, saith the LORD of hosts.
22866	911	10	In the four and twentieth day of the ninth month, in the second year of Darius, came the word of the LORD by Haggai the prophet, saying,
22867	911	11	Thus saith the LORD of hosts; Ask now the priests concerning the law, saying,
22868	911	12	If one bear holy flesh in the skirt of his garment, and with his skirt do touch bread, or pottage, or wine, or oil, or any meat, shall it be holy? And the priests answered and said, No.
22869	911	13	Then said Haggai, If one that is unclean by a dead body touch any of these, shall it be unclean? And the priests answered and said, It shall be unclean.
22870	911	14	Then answered Haggai, and said, So is this people, and so is this nation before me, saith the LORD; and so is every work of their hands; and that which they offer there is unclean.
22871	911	15	And now, I pray you, consider from this day and upward, from before a stone was laid upon a stone in the temple of the LORD:
22872	911	16	Since those days were, when one came to an heap of twenty measures, there were but ten: when one came to the pressfat for to draw out fifty vessels out of the press, there were but twenty.
22873	911	17	I smote you with blasting and with mildew and with hail in all the labours of your hands; yet ye turned not to me, saith the LORD.
22874	911	18	Consider now from this day and upward, from the four and twentieth day of the ninth month, even from the day that the foundation of the LORD's temple was laid, consider it.
22875	911	19	Is the seed yet in the barn? yea, as yet the vine, and the fig tree, and the pomegranate, and the olive tree, hath not brought forth: from this day will I bless you.
22876	911	20	And again the word of the LORD came unto Haggai in the four and twentieth day of the month, saying,
22877	911	21	Speak to Zerubbabel, governor of Judah, saying, I will shake the heavens and the earth;
22878	911	22	And I will overthrow the throne of kingdoms, and I will destroy the strength of the kingdoms of the heathen; and I will overthrow the chariots, and those that ride in them; and the horses and their riders shall come down, every one by the sword of his brother.
22879	911	23	In that day, saith the LORD of hosts, will I take thee, O Zerubbabel, my servant, the son of Shealtiel, saith the LORD, and will make thee as a signet: for I have chosen thee, saith the LORD of hosts.
22880	912	1	IN the eighth month, in the second year of Darius, came the word of the LORD unto Zechariah, the son of Berechiah, the son of Iddo the prophet, saying,
22881	912	2	The LORD hath been sore displeased with your fathers.
22882	912	3	Therefore say thou unto them, Thus saith the LORD of hosts; Turn ye unto me, saith the LORD of hosts, and I will turn unto you, saith the LORD of hosts.
22883	912	4	Be ye not as your fathers, unto whom the former prophets have cried, saying, Thus saith the LORD of hosts; Turn ye now from your evil ways, and from your evil doings: but they did not hear, nor hearken unto me, saith the LORD.
22884	912	5	Your fathers, where are they? and the prophets, do they live for ever?
22885	912	6	But my words and my statutes, which I commanded my servants the prophets, did they not take hold of your fathers? and they returned and said, Like as the LORD of hosts thought to do unto us, according to our ways, and according to our doings, so hath he dealt with us.
22886	912	7	Upon the four and twentieth day of the eleventh month, which is the month Sebat, in the second year of Darius, came the word of the LORD unto Zechariah, the son of Berechiah, the son of Iddo the prophet, saying,
22887	912	8	I saw by night, and behold a man riding upon a red horse, and he stood among the myrtle trees that were in the bottom; and behind him were there red horses, speckled, and white.
22888	912	9	Then said I, O my lord, what are these? And the angel that talked with me said unto me, I will shew thee what these be.
22889	912	10	And the man that stood among the myrtle trees answered and said, These are they whom the LORD hath sent to walk to and fro through the earth.
22890	912	11	And they answered the angel of the LORD that stood among the myrtle trees, and said, We have walked to and fro through the earth, and, behold, all the earth sitteth still, and is at rest.
22891	912	12	Then the angel of the LORD answered and said, O LORD of hosts, how long wilt thou not have mercy on Jerusalem and on the cities of Judah, against which thou hast had indignation these threescore and ten years?
22892	912	13	And the LORD answered the angel that talked with me with good words and comfortable words.
22893	912	14	So the angel that communed with me said unto me, Cry thou, saying, Thus saith the LORD of hosts; I am jealous for Jerusalem and for Zion with a great jealousy.
22894	912	15	And I am very sore displeased with the heathen that are at ease: for I was but a little displeased, and they helped forward the affliction.
22895	912	16	Therefore thus saith the LORD; I am returned to Jerusalem with mercies: my house shall be built in it, saith the LORD of hosts, and a line shall be stretched forth upon Jerusalem.
22896	912	17	Cry yet, saying, Thus saith the LORD of hosts; My cities through prosperity shall yet be spread abroad; and the LORD shall yet comfort Zion, and shall yet choose Jerusalem.
22897	912	18	Then lifted I up mine eyes, and saw, and behold four horns.
22898	912	19	And I said unto the angel that talked with me, What be these? And he answered me, These are the horns which have scattered Judah, Israel, and Jerusalem.
22899	912	20	And the LORD shewed me four carpenters.
22900	912	21	Then said I, What come these to do? And he spake, saying, These are the horns which have scattered Judah, so that no man did lift up his head: but these are come to fray them, to cast out the horns of the Gentiles, which lifted up their horn over the land of Judah to scatter it.
22901	913	1	I LIFTED up mine eyes again, and looked, and behold a man with a measuring line in his hand.
22902	913	2	Then said I, Whither goest thou? And he said unto me, To measure Jerusalem, to see what is the breadth thereof, and what is the length thereof.
22903	913	3	And, behold, the angel that talked with me went forth, and another angel went out to meet him,
22904	913	4	And said unto him, Run, speak to this young man, saying, Jerusalem shall be inhabited as towns without walls for the multitude of men and cattle therein:
22905	913	5	For I, saith the LORD, will be unto her a wall of fire round about, and will be the glory in the midst of her.
22906	913	6	Ho, ho, come forth, and flee from the land of the north, saith the LORD: for I have spread you abroad as the four winds of the heaven, saith the LORD.
22907	913	7	Deliver thyself, O Zion, that dwellest with the daughter of Babylon.
22908	913	8	For thus saith the LORD of hosts; After the glory hath he sent me unto the nations which spoiled you: for he that toucheth you toucheth the apple of his eye.
22909	913	9	For, behold, I will shake mine hand upon them, and they shall be a spoil to their servants: and ye shall know that the LORD of hosts hath sent me.
22910	913	10	Sing and rejoice, O daughter of Zion: for, lo, I come, and I will dwell in the midst of thee, saith the LORD.
22911	913	11	And many nations shall be joined to the LORD in that day, and shall be my people: and I will dwell in the midst of thee, and thou shalt know that the LORD of hosts hath sent me unto thee.
22912	913	12	And the LORD shall inherit Judah his portion in the holy land, and shall choose Jerusalem again.
22913	913	13	Be silent, O all flesh, before the LORD: for he is raised up out of his holy habitation.
22914	914	1	AND he shewed me Joshua the high priest standing before the angel of the LORD, and Satan standing at his right hand to resist him.
22915	914	2	And the LORD said unto Satan, The LORD rebuke thee, O Satan; even the LORD that hath chosen Jerusalem rebuke thee: is not this a brand plucked out of the fire?
22916	914	3	Now Joshua was clothed with filthy garments, and stood before the angel.
22917	914	4	And he answered and spake unto those that stood before him, saying, Take away the filthy garments from him. And unto him he said, Behold, I have caused thine iniquity to pass from thee, and I will clothe thee with change of raiment.
22918	914	5	And I said, Let them set a fair mitre upon his head. So they set a fair mitre upon his head, and clothed him with garments. And the angel of the LORD stood by.
22919	914	6	And the angel of the LORD protested unto Joshua, saying,
22920	914	7	Thus saith the LORD of hosts; If thou wilt walk in my ways, and if thou wilt keep my charge, then thou shalt also judge my house, and shalt also keep my courts, and I will give thee places to walk among these that stand by.
22921	914	8	Hear now, O Joshua the high priest, thou, and thy fellows that sit before thee: for they are men wondered at: for, behold, I will bring forth my servant the BRANCH.
22922	914	9	For behold the stone that I have laid before Joshua; upon one stone shall be seven eyes: behold, I will engrave the graving thereof, saith the LORD of hosts, and I will remove the iniquity of that land in one day.
22923	914	10	In that day, saith the LORD of hosts, shall ye call every man his neighbour under the vine and under the fig tree.
22924	915	1	AND the angel that talked with me came again, and waked me, as a man that is wakened out of his sleep,
22925	915	2	And said unto me, What seest thou? And I said, I have looked, and behold a candlestick all of gold, with a bowl upon the top of it, and his seven lamps thereon, and seven pipes to the seven lamps, which are upon the top thereof:
22926	915	3	And two olive trees by it, one upon the right side of the bowl, and the other upon the left side thereof.
22927	915	4	So I answered and spake to the angel that talked with me, saying, What are these, my lord?
22928	915	5	Then the angel that talked with me answered and said unto me, Knowest thou not what these be? And I said, No, my lord.
22929	915	6	Then he answered and spake unto me, saying, This is the word of the LORD unto Zerubbabel, saying, Not by might, nor by power, but by my spirit, saith the LORD of hosts.
22930	915	7	Who art thou, O great mountain? before Zerubbabel thou shalt become a plain: and he shall bring forth the headstone thereof with shoutings, crying, Grace, grace unto it.
22931	915	8	Moreover the word of the LORD came unto me, saying,
22932	915	9	The hands of Zerubbabel have laid the foundation of this house; his hands shall also finish it; and thou shalt know that the LORD of hosts hath sent me unto you.
22933	915	10	For who hath despised the day of small things? for they shall rejoice, and shall see the plummet in the hand of Zerubbabel with those seven; they are the eyes of the LORD, which run to and fro through the whole earth.
22934	915	11	Then answered I, and said unto him, What are these two olive trees upon the right side of the candlestick and upon the left side thereof?
22935	915	12	And I answered again, and said unto him, What be these two olive branches which through the two golden pipes empty the golden oil out of themselves?
22936	915	13	And he answered me and said, Knowest thou not what these be? And I said, No, my lord.
22937	915	14	Then said he, These are the two anointed ones, that stand by the Lord of the whole earth.
22938	916	1	THEN I turned, and lifted up mine eyes, and looked, and behold a flying roll.
22939	916	2	And he said unto me, What seest thou? And I answered, I see a flying roll; the length thereof is twenty cubits, and the breadth thereof ten cubits.
22940	916	3	Then said he unto me, This is the curse that goeth forth over the face of the whole earth: for every one that stealeth shall be cut off as on this side according to it; and every one that sweareth shall be cut off as on that side according to it.
22941	916	4	I will bring it forth, saith the LORD of hosts, and it shall enter into the house of the thief, and into the house of him that sweareth falsely by my name: and it shall remain in the midst of his house, and shall consume it with the timber thereof and the stones thereof.
22942	916	5	Then the angel that talked with me went forth, and said unto me, Lift up now thine eyes, and see what is this that goeth forth.
22943	916	6	And I said, What is it? And he said, This is an ephah that goeth forth. He said moreover, This is their resemblance through all the earth.
22944	916	7	And, behold, there was lifted up a talent of lead: and this is a woman that sitteth in the midst of the ephah.
22945	916	8	And he said, This is wickedness. And he cast it into the midst of the ephah; and he cast the weight of lead upon the mouth thereof.
22946	916	9	Then lifted I up mine eyes, and looked, and, behold, there came out two women, and the wind was in their wings; for they had wings like the wings of a stork: and they lifted up the ephah between the earth and the heaven.
22947	916	10	Then said I to the angel that talked with me, Whither do these bear the ephah?
22948	916	11	And he said unto me, To build it an house in the land of Shinar: and it shall be established, and set there upon her own base.
22949	917	1	AND I turned, and lifted up mine eyes, and looked, and, behold, there came four chariots out from between two mountains; and the mountains were mountains of brass.
22950	917	2	In the first chariot were red horses; and in the second chariot black horses;
22951	917	3	And in the third chariot white horses; and in the fourth chariot grisled and bay horses.
22952	917	4	Then I answered and said unto the angel that talked with me, What are these, my lord?
22953	917	5	And the angel answered and said unto me, These are the four spirits of the heavens, which go forth from standing before the Lord of all the earth.
22954	917	6	The black horses which are therein go forth into the north country; and the white go forth after them; and the grisled go forth toward the south country.
22955	917	7	And the bay went forth, and sought to go that they might walk to and fro through the earth: and he said, Get you hence, walk to and fro through the earth. So they walked to and fro through the earth.
22956	917	8	Then cried he upon me, and spake unto me, saying, Behold, these that go toward the north country have quieted my spirit in the north country.
22957	917	9	And the word of the LORD came unto me, saying,
22958	917	10	Take of them of the captivity, even of Heldai, of Tobijah, and of Jedaiah, which are come from Babylon, and come thou the same day, and go into the house of Josiah the son of Zephaniah;
22959	917	11	Then take silver and gold, and make crowns, and set them upon the head of Joshua the son of Josedech, the high priest;
22960	917	12	And speak unto him, saying, Thus speaketh the LORD of hosts, saying, Behold the man whose name is The BRANCH; and he shall grow up out of his place, and he shall build the temple of the LORD:
22961	917	13	Even he shall build the temple of the LORD; and he shall bear the glory, and shall sit and rule upon his throne; and he shall be a priest upon his throne: and the counsel of peace shall be between them both.
22962	917	14	And the crowns shall be to Helem, and to Tobijah, and to Jedaiah, and to Hen the son of Zephaniah, for a memorial in the temple of the LORD.
22963	917	15	And they that are far off shall come and build in the temple of the LORD, and ye shall know that the LORD of hosts hath sent me unto you. And this shall come to pass, if ye will diligently obey the voice of the LORD your God.
22964	918	1	AND it came to pass in the fourth year of king Darius, that the word of the LORD came unto Zechariah in the fourth day of the ninth month, even in Chisleu;
22965	918	2	When they had sent unto the house of God Sherezer and Regem-melech, and their men, to pray before the LORD,
22966	918	3	And to speak unto the priests which were in the house of the LORD of hosts, and to the prophets, saying, Should I weep in the fifth month, separating myself, as I have done these so many years?
22967	918	4	Then came the word of the LORD of hosts unto me, saying,
22968	918	5	Speak unto all the people of the land, and to the priests, saying, When ye fasted and mourned in the fifth and seventh month, even those seventy years, did ye at all fast unto me, even to me?
22969	918	6	And when ye did eat, and when ye did drink, did not ye eat for yourselves, and drink for yourselves?
22970	918	7	Should ye not hear the words which the LORD hath cried by the former prophets, when Jerusalem was inhabited and in prosperity, and the cities thereof round about her, when men inhabited the south and the plain?
22971	918	8	And the word of the LORD came unto Zechariah, saying,
22972	918	9	Thus speaketh the LORD of hosts, saying, Execute true judgment, and shew mercy and compassions every man to his brother:
22973	918	10	And oppress not the widow, nor the fatherless, the stranger, nor the poor; and let none of you imagine evil against his brother in your heart.
22974	918	11	But they refused to hearken, and pulled away the shoulder, and stopped their ears, that they should not hear.
22975	918	12	Yea, they made their hearts as an adamant stone, lest they should hear the law, and the words which the LORD of hosts hath sent in his spirit by the former prophets: therefore came a great wrath from the LORD of hosts.
22976	918	13	Therefore it is come to pass, that as he cried, and they would not hear; so they cried, and I would not hear, saith the LORD of hosts:
22977	918	14	But I scattered them with a whirlwind among all the nations whom they knew not. Thus the land was desolate after them, that no man passed through nor returned: for they laid the pleasant land desolate.
22978	919	1	AGAIN the word of the LORD of hosts came to me, saying,
22979	919	2	Thus saith the LORD of hosts; I was jealous for Zion with great jealousy, and I was jealous for her with great fury.
22980	919	3	Thus saith the LORD; I am returned unto Zion, and will dwell in the midst of Jerusalem: and Jerusalem shall be called a city of truth; and the mountain of the LORD of hosts the holy mountain.
22981	919	4	Thus saith the LORD of hosts; There shall yet old men and old women dwell in the streets of Jerusalem, and every man with his staff in his hand for very age.
22982	919	5	And the streets of the city shall be full of boys and girls playing in the streets thereof.
22983	919	6	Thus saith the LORD of hosts; If it be marvellous in the eyes of the remnant of this people in these days, should it also be marvellous in mine eyes? saith the LORD of hosts.
22984	919	7	Thus saith the LORD of hosts; Behold, I will save my people from the east country, and from the west country;
22985	919	8	And I will bring them, and they shall dwell in the midst of Jerusalem: and they shall be my people, and I will be their God, in truth and in righteousness.
22986	919	9	Thus saith the LORD of hosts; Let your hands be strong, ye that hear in these days these words by the mouth of the prophets, which were in the day that the foundation of the house of the LORD of hosts was laid, that the temple might be built.
22987	919	10	For before these days there was no hire for man, nor any hire for beast; neither was there any peace to him that went out or came in because of the affliction: for I set all men every one against his neighbour.
22988	919	11	But now I will not be unto the residue of this people as in the former days, saith the LORD of hosts.
22989	919	12	For the seed shall be prosperous; the vine shall give her fruit, and the ground shall give her increase, and the heavens shall give their dew; and I will cause the remnant of this people to possess all these things.
22990	919	13	And it shall come to pass, that as ye were a curse among the heathen, O house of Judah, and house of Israel; so will I save you, and ye shall be a blessing: fear not, but let your hands be strong.
22991	919	14	For thus saith the LORD of hosts; As I thought to punish you, when your fathers provoked me to wrath, saith the LORD of hosts, and I repented not:
22992	919	15	So again have I thought in these days to do well unto Jerusalem and to the house of Judah: fear ye not.
22993	919	16	These are the things that ye shall do; Speak ye every man the truth to his neighbour; execute the judgment of truth and peace in your gates:
22994	919	17	And let none of you imagine evil in your hearts against his neighbour; and love no false oath: for all these are things that I hate, saith the LORD.
22995	919	18	And the word of the LORD of hosts came unto me, saying,
22996	919	19	Thus saith the LORD of hosts; The fast of the fourth month, and the fast of the fifth, and the fast of the seventh, and the fast of the tenth, shall be to the house of Judah joy and gladness, and cheerful feasts; therefore love the truth and peace.
22997	919	20	Thus saith the LORD of hosts; It shall yet come to pass, that there shall come people, and the inhabitants of many cities:
22998	919	21	And the inhabitants of one city shall go to another, saying, Let us go speedily to pray before the LORD, and to seek the LORD of hosts: I will go also.
22999	919	22	Yea, many people and strong nations shall come to seek the LORD of hosts in Jerusalem, and to pray before the LORD.
23000	919	23	Thus saith the LORD of hosts; In those days it shall come to pass, that ten men shall take hold out of all languages of the nations, even shall take hold of the skirt of him that is a Jew, saying, We will go with you: for we have heard that God is with you.
23001	920	1	THE burden of the word of the LORD in the land of Hadrach, and Damascus shall be the rest thereof: when the eyes of man, as of all the tribes of Israel, shall be toward the LORD.
23002	920	2	And Hamath also shall border thereby; Tyrus, and Zidon, though it be very wise.
23003	920	3	And Tyrus did build herself a strong hold, and heaped up silver as the dust, and fine gold as the mire of the streets.
23004	920	4	Behold, the Lord will cast her out, and he will smite her power in the sea; and she shall be devoured with fire.
23005	920	5	Ashkelon shall see it, and fear; Gaza also shall see it, and be very sorrowful, and Ekron; for her expectation shall be ashamed; and the king shall perish from Gaza, and Ashkelon shall not be inhabited.
23006	920	6	And a bastard shall dwell in Ashdod, and I will cut off the pride of the Philistines.
23007	920	7	And I will take away his blood out of his mouth, and his abominations from between his teeth: but he that remaineth, even he, shall be for our God, and he shall be as a governor in Judah, and Ekron as a Jebusite.
23008	920	8	And I will encamp about mine house because of the army, because of him that passeth by, and because of him that returneth: and no oppressor shall pass through them any more: for now have I seen with mine eyes.
23009	920	9	Rejoice greatly, O daughter of Zion; shout, O daughter of Jerusalem: behold, thy King cometh unto thee: he is just, and having salvation; lowly, and riding upon an ass, and upon a colt the foal of an ass.
23010	920	10	And I will cut off the chariot from Ephraim, and the horse from Jerusalem, and the battle bow shall be cut off: and he shall speak peace unto the heathen: and his dominion shall be from sea even to sea, and from the river even to the ends of the earth.
23011	920	11	As for thee also, by the blood of thy covenant I have sent forth thy prisoners out of the pit wherein is no water.
23012	920	12	Turn you to the strong hold, ye prisoners of hope: even to day do I declare that I will render double unto thee;
23013	920	13	When I have bent Judah for me, filled the bow with Ephraim, and raised up thy sons, O Zion, against thy sons, O Greece, and made thee as the sword of a mighty man.
23014	920	14	And the LORD shall be seen over them, and his arrow shall go forth as the lightning: and the Lord GOD shall blow the trumpet, and shall go with whirlwinds of the south.
23015	920	15	The LORD of hosts shall defend them; and they shall devour, and subdue with sling stones; and they shall drink, and make a noise as through wine; and they shall be filled like bowls, and as the corners of the altar.
23016	920	16	And the LORD their God shall save them in that day as the flock of his people: for they shall be as the stones of a crown, lifted up as an ensign upon his land.
23017	920	17	For how great is his goodness, and how great is his beauty! corn shall make the young men cheerful, and new wine the maids.
23018	921	1	ASK ye of the LORD rain in the time of the latter rain; so the LORD shall make bright clouds, and give them showers of rain, to every one grass in the field.
23019	921	2	For the idols have spoken vanity, and the diviners have seen a lie, and have told false dreams; they comfort in vain: therefore they went their way as a flock, they were troubled, because there was no shepherd.
23020	921	3	Mine anger was kindled against the shepherds, and I punished the goats: for the LORD of hosts hath visited his flock the house of Judah, and hath made them as his goodly horse in the battle.
23021	921	4	Out of him came forth the corner, out of him the nail, out of him the battle bow, out of him every oppressor together.
23022	921	5	And they shall be as mighty men, which tread down their enemies in the mire of the streets in the battle: and they shall fight, because the LORD is with them, and the riders on horses shall be confounded.
23023	921	6	And I will strengthen the house of Judah, and I will save the house of Joseph, and I will bring them again to place them; for I have mercy upon them: and they shall be as though I had not cast them off: for I am the LORD their God, and will hear them.
23024	921	7	And they of Ephraim shall be like a mighty man, and their heart shall rejoice as through wine: yea, their children shall see it, and be glad; their heart shall rejoice in the LORD.
23025	921	8	I will hiss for them, and gather them; for I have redeemed them: and they shall increase as they have increased.
23026	921	9	And I will sow them among the people: and they shall remember me in far countries; and they shall live with their children, and turn again.
23027	921	10	I will bring them again also out of the land of Egypt, and gather them out of Assyria; and I will bring them into the land of Gilead and Lebanon; and place shall not be found for them.
23028	921	11	And he shall pass through the sea with affliction, and shall smite the waves in the sea, and all the deeps of the river shall dry up: and the pride of Assyria shall be brought down, and the sceptre of Egypt shall depart away.
23029	921	12	And I will strengthen them in the LORD; and they shall walk up and down in his name, saith the LORD.
23030	922	1	OPEN thy doors, O Lebanon, that the fire may devour thy cedars.
23031	922	2	Howl, fir tree; for the cedar is fallen; because the mighty are spoiled: howl, O ye oaks of Bashan; for the forest of the vintage is come down.
23032	922	3	There is a voice of the howling of the shepherds; for their glory is spoiled: a voice of the roaring of young lions; for the pride of Jordan is spoiled.
23033	922	4	Thus saith the LORD my God; Feed the flock of the slaughter;
23034	922	5	Whose possessors slay them, and hold themselves not guilty: and they that sell them say, Blessed be the LORD; for I am rich: and their own shepherds pity them not.
23035	922	6	For I will no more pity the inhabitants of the land, saith the LORD: but, lo, I will deliver the men every one into his neighbour's hand, and into the hand of his king: and they shall smite the land, and out of their hand I will not deliver them.
23036	922	7	And I will feed the flock of slaughter, even you, O poor of the flock. And I took unto me two staves; the one I called Beauty, and the other I called Bands; and I fed the flock.
23037	922	8	Three shepherds also I cut off in one month; and my soul lothed them, and their soul also abhorred me.
23038	922	9	Then said I, I will not feed you: that that dieth, let it die; and that that is to be cut off, let it be cut off; and let the rest eat every one the flesh of another.
23039	922	10	And I took my staff, even Beauty, and cut it assunder, that I might break my covenant which I had made with all the people.
23040	922	11	And it was broken in that day: and so the poor of the flock that waited upon me knew that it was the word of the LORD.
23041	922	12	And I said unto them, If ye think good, give me my price; and if not, forbear. So they weighed for my price thirty pieces of silver.
23042	922	13	And the LORD said unto me, Cast it unto the potter: a goodly price that I was prised at of them. And I took the thirty pieces of silver, and cast them to the potter in the house of the LORD.
23043	922	14	Then I cut asunder mine other staff, even Bands, that I might break the brotherhood between Judah and Israel.
23044	922	15	And the LORD said unto me, Take unto thee yet the instruments of a foolish shepherd.
23045	922	16	For, lo, I will raise up a shepherd in the land, which shall not visit those that be cut off, neither shall seek the young one, nor heal that that is broken, nor feed that that standeth still: but he shall eat the flesh of the fat, and tear their claws in pieces.
23046	922	17	Woe to the idol shepherd that leaveth the flock! the sword shall be upon his arm, and upon his right eye: his arm shall be clean dried up, and his right eye shall be utterly darkened.
23047	923	1	THE burden of the word of the LORD for Israel, saith the LORD, which stretcheth forth the heavens, and layeth the foundation of the earth, and formeth the spirit of man within him.
23048	923	2	Behold, I will make Jerusalem a cup of trembling unto all the people round about, when they shall be in the siege both against Judah and against Jerusalem.
23049	923	3	And in that day will I make Jerusalem a burdensome stone for all people: all that burden themselves with it shall be cut in pieces, though all the people of the earth be gathered together against it.
23050	923	4	In that day, saith the LORD, I will smite every horse with astonishment, and his rider with madness: and I will open mine eyes upon the house of Judah, and will smite every horse of the people with blindness.
23051	923	5	And the governors of Judah shall say in their heart, The inhabitants of Jerusalem shall be my strength in the LORD of hosts their God.
23052	923	6	In that day will I make the governors of Judah like an hearth of fire among the wood, and like a torch of fire in a sheaf; and they shall devour all the people round about, on the right hand and on the left: and Jerusalem shall be inhabited again in her own place, even in Jerusalem.
23053	923	7	The LORD also shall save the tents of Judah first, that the glory of the house of David and the glory of the inhabitants of Jerusalem do not magnify themselves against Judah.
23054	923	8	In that day shall the LORD defend the inhabitants of Jerusalem; and he that is feeble among them at that day shall be as David; and the house of David shall be as God, as the angel of the LORD before them.
23055	923	9	And it shall come to pass in that day, that I will seek to destroy all the nations that come against Jerusalem.
23056	923	10	And I will pour upon the house of David, and upon the inhabitants of Jerusalem, the spirit of grace and of supplications: and they shall look upon me whom they have pierced, and they shall mourn for him, as one mourneth for his only son, and shall be in bitterness for him, as one that is in bitterness for his firstborn.
23057	923	11	In that day shall there be a great mourning in Jerusalem, as the mourning of Hadadrimmon in the valley of Megiddon.
23058	923	12	And the land shall mourn, every family apart; the family of the house of David apart, and their wives apart; the family of the house of Nathan apart, and their wives apart;
23059	923	13	The family of the house of Levi apart, and their wives apart; the family of Shimei apart, and their wives apart;
23060	923	14	All the families that remain, every family apart, and their wives apart.
23061	924	1	IN that day there shall be a fountain opened to the house of David and to the inhabitants of Jerusalem for sin and for uncleanness.
23062	924	2	And it shall come to pass in that day, saith the LORD of hosts, that I will cut off the names of the idols out of the land, and they shall no more be remembered: and also I will cause the prophets and the unclean spirit to pass out of the land.
23063	924	3	And it shall come to pass, that when any shall yet prophesy, then his father and his mother that begat him shall say unto him, Thou shalt not live; for thou speakest lies in the name of the LORD: and his father and his mother that begat him shall thrust him through when he prophesieth.
23064	924	4	And it shall come to pass in that day, that the prophets shall be ashamed every one of his vision, when he hath prophesied; neither shall they wear a rough garment to deceive:
23065	924	5	But he shall say, I am no prophet, I am an husbandman; for man taught me to keep cattle from my youth.
23066	924	6	And one shall say unto him, What are these wounds in thine hands? Then he shall answer, Those with which I was wounded in the house of my friends.
23067	924	7	Awake, O sword, against my shepherd, and against the man that is my fellow, saith the LORD of hosts: smite the shepherd, and the sheep shall be scattered: and I will turn mine hand upon the little ones.
23068	924	8	And it shall come to pass, that in all the land, saith the LORD, two parts therein shall be cut off and die; but the third shall be left therein.
23069	924	9	And I will bring the third part through the fire, and will refine them as silver is refined, and will try them as gold is tried: they shall call on my name, and I will hear them: I will say, It is my people: and they shall say, The LORD is my God.
23070	925	1	BEHOLD, the day of the LORD cometh, and thy spoil shall be divided in the midst of thee.
23071	925	2	For I will gather all nations against Jerusalem to battle; and the city shall be taken, and the houses rifled, and the women ravished; and half of the city shall go forth into captivity, and the residue of the people shall not be cut off from the city.
23072	925	3	Then shall the LORD go forth, and fight against those nations, as when he fought in the day of battle.
23073	925	4	And his feet shall stand in that day upon the mount of Olives, which is before Jerusalem on the east, and the mount of Olives shall cleave in the midst thereof toward the east and toward the west, and there shall be a very great valley; and half of the mountain shall remove toward the north, and half of it toward the south.
23074	925	5	And ye shall flee to the valley of the mountains; for the valley of the mountains shall reach unto Azal: yea, ye shall flee, like as ye fled from before the earthquake in the days of Uzziah king of Judah: and the LORD my God shall come, and all the saints with thee.
23075	925	6	And it shall come to pass in that day, that the light shall not be clear, nor dark:
23076	925	7	But it shall be one day which shall be known to the LORD, not day, nor night: but it shall come to pass, that at evening time it shall be light.
23077	925	8	And it shall be in that day, that living waters shall go out from Jerusalem; half of them toward the former sea, and half of them toward the hinder sea: in summer and in winter shall it be.
23078	925	9	And the LORD shall be king over all the earth: in that day shall there be one LORD, and his name one.
23079	925	10	All the land shall be turned as a plain from Geba to Rimmon south of Jerusalem: and it shall be lifted up, and inhabited in her place, from Benjamin's gate unto the place of the first gate, unto the corner gate, and from the tower of Hananeel unto the king's winepresses.
23080	925	11	And men shall dwell in it, and there shall be no more utter destruction; but Jerusalem shall be safely inhabited.
23081	925	12	And this shall be the plague wherewith the LORD will smite all the people that have fought against Jerusalem; Their flesh shall consume away while they stand upon their feet, and their eyes shall consume away in their holes, and their tongue shall consume away in their mouth.
23082	925	13	And it shall come to pass in that day, that a great tumult from the LORD shall be among them; and they shall lay hold every one on the hand of his neighbour, and his hand shall rise up against the hand of his neighbour.
23083	925	14	And Judah also shall fight at Jerusalem; and the wealth of all the heathen round about shall be gathered together, gold, and silver, and apparel, in great abundance.
23084	925	15	And so shall be the plague of the horse, of the mule, of the camel, and of the ass, and of all the beasts that shall be in these tents, as this plague.
23085	925	16	And it shall come to pass, that every one that is left of all the nations which came against Jerusalem shall even go up from year to year to worship the King, the LORD of hosts, and to keep the feast of tabernacles.
23086	925	17	And it shall be, that whoso will not come up of all the families of the earth unto Jerusalem to worship the King, the LORD of hosts, even upon them shall be no rain.
23087	925	18	And if the family of Egypt go not up, and come not, that have no rain; there shall be the plague, wherewith the LORD will smite the heathen that come not up to keep the feast of tabernacles.
23088	925	19	This shall be the punishment of Egypt, and the punishment of all nations that come not up to keep the feast of tabernacles.
23089	925	20	In that day shall there be upon the bells of the horses, HOLINESS UNTO THE LORD; and the pots in the LORD's house shall be like the bowls before the altar.
23090	925	21	Yea, every pot in Jerusalem and in Judah shall be holiness unto the LORD of hosts: and all they that sacrifice shall come and take of them, and seethe therein: and in that day there shall be no more the Canaanite in the house of the LORD of hosts.
23091	926	1	THE burden of the word of the LORD to Israel by Malachi.
23092	926	2	I have loved you, saith the LORD. Yet ye say, Wherein hast thou loved us? Was not Esau Jacob's brother? saith the LORD: yet I loved Jacob,
23093	926	3	And I hated Esau, and laid his mountains and his heritage waste for the dragons of the wilderness.
23094	926	4	Whereas Edom saith, We are impoverished, but we will return and build the desolate places; thus saith the LORD of hosts, They shall build, but I will throw down; and they shall call them, The border of wickedness, and, The people against whom the LORD hath indignation for ever.
23095	926	5	And your eyes shall see, and ye shall say, The LORD will be magnified from the border of Israel.
23096	926	6	A son honoureth his father, and a servant his master: if then I be a father, where is mine honour? and if I be a master, where is my fear? saith the LORD of hosts unto you, O priests, that despise my name. And ye say, Wherein have we despised thy name?
23097	926	7	Ye offer polluted bread upon mine altar; and ye say, Wherein have we polluted thee? In that ye say, The table of the LORD is contemptible.
23098	926	8	And if ye offer the blind for sacrifice, is it not evil? and if ye offer the lame and sick, is it not evil? offer it now unto thy governor; will he be pleased with thee, or accept thy person? saith the LORD of hosts.
23099	926	9	And now, I pray you, beseech God that he will be gracious unto us: this hath been by your means: will he regard your persons? saith the LORD of hosts.
23100	926	10	Who is there even among you that would shut the doors for nought? neither do ye kindle fire on mine altar for nought. I have no pleasure in you, saith the LORD of hosts, neither will I accept an offering at your hand.
23101	926	11	For from the rising of the sun even unto the going down of the same my name shall be great among the Gentiles; and in every place incense shall be offered unto my name, and a pure offering: for my name shall be great among the heathen, saith the LORD of hosts.
23102	926	12	But ye have profaned it, in that ye say, The table of the LORD is polluted; and the fruit thereof, even his meat, is contemptible.
23103	926	13	Ye said also, Behold, what a weariness is it! and ye have snuffed at it, saith the LORD of hosts; and ye brought that which was torn, and the lame, and the sick; thus ye brought an offering: should I accept this of your hand? saith the LORD.
23104	926	14	But cursed be the deceiver, which hath in his flock a male, and voweth, and sacrificeth unto the Lord a corrupt thing: for I am a great King, saith the LORD of hosts, and my name is dreadful among the heathen.
23105	927	1	AND now, O ye priests, this commandment is for you.
23106	927	2	If ye will not hear, and if ye will not lay it to heart, to give glory unto my name, saith the LORD of hosts, I will even send a curse upon you, and I will curse your blessings: yea, I have cursed them already, because ye do not lay it to heart.
23107	927	3	Behold, I will corrupt your seed, and spread dung upon your faces, even the dung of your solemn feasts; and one shall take you away with it.
23108	927	4	And ye shall know that I have sent this commandment unto you, that my covenant might be with Levi, saith the LORD of hosts.
23109	927	5	My covenant was with him of life and peace; and I gave them to him for the fear wherewith he feared me, and was afraid before my name.
23110	927	6	The law of truth was in his mouth, and iniquity was not found in his lips: he walked with me in peace and equity, and did turn many away from iniquity.
23111	927	7	For the priest's lips should keep knowledge, and they should seek the law at his mouth: for he is the messenger of the LORD of hosts.
23112	927	8	But ye are departed out of the way; ye have caused many to stumble at the law; ye have corrupted the covenant of Levi, saith the LORD of hosts.
23113	927	9	Therefore have I also made you contemptible and base before all the people, according as ye have not kept my ways, but have been partial in the law.
23114	927	10	Have we not all one father? hath not one God created us? why do we deal treacherously every man against his brother, by profaning the covenant of our fathers?
23115	927	11	Judah hath dealt treacherously, and an abomination is committed in Israel and in Jerusalem; for Judah hath profaned the holiness of the LORD which he loved, and hath married the daughter of a strange god.
23116	927	12	The LORD will cut off the man that doeth this, the master and the scholar, out of the tabernacles of Jacob, and him that offereth an offering unto the LORD of hosts.
23117	927	13	And this have ye done again, covering the altar of the LORD with tears, with weeping, and with crying out, insomuch that he regardeth not the offering any more, or receiveth it with good will at your hand.
23118	927	14	Yet ye say, Wherefore? Because the LORD hath been witness between thee and the wife of thy youth, against whom thou hast dealt treacherously: yet is she thy companion, and the wife of thy covenant.
23119	927	15	And did not he make one? Yet had he the residue of the spirit. And wherefore one? That he might seek a godly seed. Therefore take heed to your spirit, and let none deal treacherously against the wife of his youth.
23120	927	16	For the LORD, the God of Israel, saith that he hateth putting away: for one covereth violence with his garment, saith the LORD of hosts: therefore take heed to your spirit, that ye deal not treacherously.
23121	927	17	Ye have wearied the LORD with your words. Yet ye say, Wherein have we wearied him? When ye say, Every one that doeth evil is good in the sight of the LORD, and he delighteth in them; or, Where is the God of judgment?
23122	928	1	BEHOLD, I will send my messenger, and he shall prepare the way before me: and the Lord, whom ye seek, shall suddenly come to his temple, even the messenger of the covenant, whom ye delight in: behold, he shall come, saith the LORD of hosts.
23123	928	2	But who may abide the day of his coming? and who shall stand when he appeareth? for he is like a refiner's fire, and like fullers' soap:
23124	928	3	And he shall sit as a refiner and purifer of silver: and he shall purify the sons of Levi, and purge them as gold and silver, that they may offer unto the LORD an offering in righteousness.
23125	928	4	Then shall the offering of Judah and Jerusalem be pleasant unto the LORD, as in the days of old, and as in former years.
23126	928	5	And I will come near to you to judgment; and I will be a swift witness against the sorcerers, and against the adulterers, and against false swearers, and against those that oppress the hireling in his wages, the widow, and the fatherless, and that turn aside the stranger from his right, and fear not me, saith the LORD of hosts.
23127	928	6	For I am the LORD, I change not; therefore ye sons of Jacob are not consumed.
23128	928	7	Even from the days of your fathers ye are gone away from mine ordinances, and have not kept them. Return unto me, and I will return unto you, saith the LORD of hosts. But ye said, Wherein shall we return?
23129	928	8	Will a man rob God? Yet ye have robbed me. But ye say, Wherein have we robbed thee? In tithes and offerings.
23130	928	9	Ye are cursed with a curse: for ye have robbed me, even this whole nation.
23131	928	10	Bring ye all the tithes into the storehouse, that there may be meat in mine house, and prove me now herewith, saith the LORD of hosts, if I will not open you the windows of heaven, and pour you out a blessing, that there shall not be room enough to receive it.
23132	928	11	And I will rebuke the devourer for your sakes, and he shall not destroy the fruits of your ground; neither shall your vine cast her fruit before the time in the field, saith the LORD of hosts.
23133	928	12	And all nations shall call you blessed: for ye shall be a delightsome land, saith the LORD of hosts.
23134	928	13	Your words have been stout against me, saith the LORD. Yet ye say, What have we spoken so much against thee?
23135	928	14	Ye have said, It is vain to serve God: and what profit is it that we have kept his ordinance, and that we have walked mournfully before the LORD of hosts?
23136	928	15	And now we call the proud happy; yea, they that work wickedness are set up; yea, they that tempt God are even delivered.
23137	928	16	Then they that feared the LORD spake often one to another: and the LORD hearkened, and heard it, and a book of remembrance was written before him for them that feared the LORD, and that thought upon his name.
23138	928	17	And they shall be mine, saith the LORD of hosts, in that day when I make up my jewels; and I will spare them, as a man spareth his own son that serveth him.
23139	928	18	Then shall ye return, and discern between the righteous and the wicked, between him that serveth God and him that serveth him not.
23140	929	1	FOR, behold, the day cometh, that shall burn as an oven; and all the proud, yea, and all that do wickedly, shall be stubble: and the day that cometh shall burn them up, saith the LORD of hosts, that it shall leave them neither root nor branch.
23141	929	2	But unto you that fear my name shall the Sun of righteousness arise with healing in his wings; and ye shall go forth, and grow up as calves of the stall.
23142	929	3	And ye shall tread down the wicked; for they shall be ashes under the soles of your feet in the day that I shall do this, saith the LORD of hosts.
23143	929	4	Remember ye the law of Moses my servant, which I commanded unto him in Horeb for all Israel, with the statutes and judgments.
23144	929	5	Behold, I will send you Elijah the prophet before the coming of the great and dreadful day of the LORD:
23145	929	6	And he shall turn the heart of the fathers to the children, and the heart of the children to their fathers, lest I come and smite the earth with a curse.
23146	930	1	THE book of the generation of Jesus Christ, the son of David, the son of Abraham.
23147	930	2	Abraham begat Isaac; and Isaac begat Jacob; and Jacob begat Judas and his brethren;
23148	930	3	And Judas begat Phares and Zara of Thamar; and Phares begat Esrom; and Esrom begat Aram;
23149	930	4	And Aram begat Aminadab; and Aminadab begat Naasson; and Naasson begat Salmon;
23150	930	5	And Salmon begat Booz of Rachab; and Booz begat Obed of Ruth; and Obed begat Jesse;
23151	930	6	And Jesse begat David the king; and David the king begat Solomon of her that had been the wife of Urias;
23152	930	7	And Solomon begat Roboam; and Roboam begat Abia; and Abia begat Asa;
23153	930	8	And Asa begat Josaphat; and Josaphat begat Joram; and Joram begat Ozias;
23154	930	9	And Ozias begat Joatham; and Joatham begat Achaz; and Achaz begat Ezekias;
23155	930	10	And Ezekias begat Manasses; and Manasses begat Amon; and Amon begat Josias;
23156	930	11	And Josias begat Jechonias and his brethren, about the time they were carried away to Babylon:
23157	930	12	And after they were brought to Babylon, Jechonias begat Salathiel; and Salathiel begat Zorobabel;
23158	930	13	And Zorobabel begat Abiud; and Abiud begat Eliakim; and Eliakim begat Azor;
23159	930	14	And Azor begat Sadoc; and Sadoc begat Achim; and Achim begat Eliud;
23160	930	15	And Eliud begat Eleazar; and Eleazar begat Matthan; and Matthan begat Jacob;
23161	930	16	And Jacob begat Joseph the husband of Mary, of whom was born Jesus, who is called Christ.
23162	930	17	So all the generations from Abraham to David are fourteen generations; and from David until the carrying away into Babylon are fourteen generations; and from the carrying away into Babylon unto Christ are fourteen generations.
23163	930	18	Now the birth of Jesus Christ was on this wise: When as his mother Mary was espoused to Joseph, before they came together, she was found with child of the Holy Ghost.
23164	930	19	Then Joseph her husband, being a just man, and not willing to make her a publick example, was minded to put her away privily.
23165	930	20	But while he thought on these things, behold, the angel of the Lord appeared unto him in a dream, saying, Joseph, thou son of David, fear not to take unto thee Mary thy wife: for that which is conceived in her is of the Holy Ghost.
23166	930	21	And she shall bring forth a son, and thou shalt call his name JESUS: for he shall save his people from their sins.
23167	930	22	Now all this was done, that it might be fulfilled which was spoken of the Lord by the prophet, saying,
23168	930	23	Behold, a virgin shall be with child, and shall bring forth a son, and they shall call his name Emmanuel, which being interpreted is, God with us.
23169	930	24	Then Joseph being raised from sleep did as the angel of the Lord had bidden him, and took unto him his wife:
23170	930	25	And knew her not till she had brought forth her firstborn son: and he called his name JESUS.
23171	931	1	NOW when Jesus was born in Bethlehem of Judaea in the days of Herod the king, behold, there came wise men from the east to Jerusalem,
23172	931	2	Saying, Where is he that is born King of the Jews? for we have seen his star in the east, and are come to worship him.
23173	931	3	When Herod the king had heard these things, he was troubled, and all Jerusalem with him.
23174	931	4	And when he had gathered all the chief priests and scribes of the people together, he demanded of them where Christ should be born.
23175	931	5	And they said unto him, In Bethlehem of Judaea: for thus it is written by the prophet,
23176	931	6	And thou Bethlehem, in the land of Juda, art not the least among the princes of Juda: for out of thee shall come a Governor, that shall rule my people Israel.
23177	931	7	Then Herod, when he had privily called the wise men, enquired of them diligently what time the star appeared.
23178	931	8	And he sent them to Bethlehem, and said, Go and search diligently for the young child; and when ye have found him, bring me word again, that I may come and worship him also.
23179	931	9	When they had heard the king, they departed; and, lo, the star, which they saw in the east, went before them, till it came and stood over where the young child was.
23180	931	10	When they saw the star, they rejoiced with exceeding great joy.
23181	931	11	And when they were come into the house, they saw the young child with Mary his mother, and fell down, and worshipped him: and when they had opened their treasures, they presented unto him gifts; gold, and frankincense, and myrrh.
23182	931	12	And being warned of God in a dream that they should not return to Herod, they departed into their own country another way.
23183	931	13	And when they were departed, behold, the angel of the Lord appeareth to Joseph in a dream, saying, Arise, and take the young child and his mother, and flee into Egypt, and be thou there until I bring thee word: for Herod will seek the young child to destroy him.
23184	931	14	When he arose, he took the young child and his mother by night, and departed into Egypt:
23185	931	15	And was there until the death of Herod: that it might be fulfilled which was spoken of the Lord by the prophet, saying, Out of Egypt have I called my son.
23186	931	16	Then Herod, when he saw that he was mocked of the wise men, was exceeding wroth, and sent forth, and slew all the children that were in Bethlehem, and in all the coasts thereof, from two years old and under, according to the time which he had diligently enquired of the wise men.
23187	931	17	Then was fulfilled that which was spoken by Jeremy the prophet, saying,
23188	931	18	In Rama was there a voice heard, lamentation, and weeping, and great mourning, Rachel weeping for her children, and would not be comforted, because they are not.
23189	931	19	But when Herod was dead, behold, an angel of the Lord appeareth in a dream to Joseph in Egypt,
23190	931	20	Saying, Arise, and take the young child and his mother, and go into the land of Israel: for they are dead which sought the young child's life.
23191	931	21	And he arose, and took the young child and his mother, and came into the land of Israel.
23192	931	22	But when he heard that Archelaus did reign in Judaea in the room of his father Herod, he was afraid to go thither: notwithstanding, being warned of God in a dream, he turned aside into the parts of Galilee:
23193	931	23	And he came and dwelt in a city called Nazareth: that it might be fulfilled which was spoken by the prophets, He shall be called a Nazarene.
23194	932	1	IN those days came John the Baptist, preaching in the wilderness of Judaea,
23195	932	2	And saying, Repent ye: for the kingdom of heaven is at hand.
23196	932	3	For this is he that was spoken of by the prophet Esaias, saying, The voice of one crying in the wilderness, Prepare ye the way of the Lord, make his paths straight.
23197	932	4	And the same John had his raiment of camel's hair, and a leathern girdle about his loins; and his meat was locusts and wild honey.
23198	932	5	Then went out to him Jerusalem, and all Judaea, and all the region round about Jordan,
23199	932	6	And were baptized of him in Jordan, confessing their sins.
23200	932	7	But when he saw many of the Pharisees and Sadducees come to his baptism, he said unto them, O generation of vipers, who hath warned you to flee from the wrath to come?
23201	932	8	Bring forth therefore fruits meet for repentance:
23202	932	9	And think not to say within yourselves, We have Abraham to our father: for I say unto you, that God is able of these stones to raise up children unto Abraham.
23203	932	10	And now also the axe is laid unto the root of the trees: therefore every tree which bringeth not forth good fruit is hewn down, and cast into the fire.
23204	932	11	I indeed baptize you with water unto repentance: but he that cometh after me is mightier than I, whose shoes I am not worthy to bear: he shall baptize you with the Holy Ghost, and with fire:
23205	932	12	Whose fan is in his hand, and he will throughly purge his floor, and gather his wheat into the garner; but he will burn up the chaff with unquenchable fire.
23206	932	13	Then cometh Jesus from Galilee to Jordan unto John, to be baptized of him.
23207	932	14	But John forbad him, saying, I have need to be baptized of thee, and comest thou to me?
23208	932	15	And Jesus answering said unto him, Suffer it to be so now: for thus it becometh us to fulfil all righteousness. Then he suffered him.
23209	932	16	And Jesus, when he was baptized, went up straightway out of the water: and, lo, the heavens were opened unto him, and he saw the Spirit of God descending like a dove, and lighting upon him:
23210	932	17	And lo a voice from heaven, saying, This is my beloved Son, in whom I am well pleased.
23211	933	1	THEN was Jesus led up of the Spirit into the wilderness to be tempted of the devil.
23212	933	2	And when he had fasted forty days and forty nights, he was afterward an hungred.
23213	933	3	And when the tempter came to him, he said, If thou be the Son of God, command that these stones be made bread.
23214	933	4	But he answered and said, It is written, Man shall not live by bread alone, but by every word that proceedeth out of the mouth of God.
23215	933	5	Then the devil taketh him up into the holy city, and setteth him on a pinnacle of the temple,
23216	933	6	And saith unto him, If thou be the Son of God, cast thyself down: for it is written, He shall give his angels charge concerning thee: and in their hands they shall bear thee up, lest at any time thou dash thy foot against a stone.
23217	933	7	Jesus said unto him, It is written again, Thou shalt not tempt the Lord thy God.
23218	933	8	Again, the devil taketh him up into an exceeding high mountain, and sheweth him all the kingdoms of the world, and the glory of them;
23219	933	9	And saith unto him, All these things will I give thee, if thou wilt fall down and worship me.
23220	933	10	Then saith Jesus unto him, Get thee hence, Satan: for it is written, Thou shalt worship the Lord thy God, and him only shalt thou serve.
23221	933	11	Then the devil leaveth him, and, behold, angels came and ministered unto him.
23222	933	12	Now when Jesus had heard that John was cast into prison, he departed into Galilee;
23223	933	13	And leaving Nazareth, he came and dwelt in Capernaum, which is upon the sea coast, in the borders of Zabulon and Nephthalim:
23224	933	14	That it might be fulfilled which was spoken by Esaias the prophet, saying,
23225	933	15	The land of Zabulon, and the land of Nephthalim, by the way of the sea, beyond Jordan, Galilee of the Gentiles;
23226	933	16	The people which sat in darkness saw great light; and to them which sat in the region and shadow of death light is sprung up.
23227	933	17	From that time Jesus began to preach, and to say, Repent: for the kingdom of heaven is at hand.
23228	933	18	And Jesus, walking by the sea of Galilee, saw two brethren, Simon called Peter, and Andrew his brother, casting a net into the sea: for they were fishers.
23229	933	19	And he saith unto them, Follow me, and I will make you fishers of men.
23230	933	20	And they straightway left their nets, and followed him.
23231	933	21	And going on from thence, he saw other two brethren, James the son of Zebedee, and John his brother, in a ship with Zebedee their father, mending their nets; and he called them.
23232	933	22	And they immediately left the ship and their father, and followed him.
23233	933	23	And Jesus went about all Galilee, teaching in their synagogues, and preaching the gospel of the kingdom, and healing all manner of sickness and all manner of disease among the people.
23234	933	24	And his fame went throughout all Syria: and they brought unto him all sick people that were taken with divers diseases and torments, and those which were possessed with devils, and those which were lunatick, and those that had the palsy; and he healed them.
23235	933	25	And there followed him great multitudes of people from Galilee, and from Decapolis, and from Jerusalem, and from Judaea, and from beyond Jordan.
23236	934	1	AND seeing the multitudes, he went up into a mountain: and when he was set, his disciples came unto him:
23237	934	2	And he opened his mouth, and taught them, saying,
23238	934	3	Blessed are the poor in spirit: for theirs is the kingdom of heaven.
23239	934	4	Blessed are they that mourn: for they shall be comforted.
23240	934	5	Blessed are the meek: for they shall inherit the earth.
23241	934	6	Blessed are they which do hunger and thirst after righteousness: for they shall be filled.
23242	934	7	Blessed are the merciful: for they shall obtain mercy.
23243	934	8	Blessed are the pure in heart: for they shall see God.
23244	934	9	Blessed are the peacemakers: for they shall be called the children of God.
23245	934	10	Blessed are they which are persecuted for righteousness' sake: for theirs is the kingdom of heaven.
23246	934	11	Blessed are ye, when men shall revile you, and persecute you, and shall say all manner of evil against you falsely, for my sake.
23247	934	12	Rejoice, and be exceeding glad: for great is your reward in heaven: for so persecuted they the prophets which were before you.
23248	934	13	Ye are the salt of the earth: but if the salt have lost his savour, wherewith shall it be salted? it is thenceforth good for nothing, but to be cast out, and to be trodden under foot of men.
23249	934	14	Ye are the light of the world. A city that is set on an hill cannot be hid.
23250	934	15	Neither do men light a candle, and put it under a bushel, but on a candlestick; and it giveth light unto all that are in the house.
23251	934	16	Let your light so shine before men, that they may see your good works, and glorify your Father which is in heaven.
23252	934	17	Think not that I am come to destroy the law, or the prophets: I am not come to destroy, but to fulfil.
23253	934	18	For verily I say unto you, Till heaven and earth pass, one jot or one tittle shall in no wise pass from the law, till all be fulfilled.
23254	934	19	Whosoever therefore shall break one of these least commandments, and shall teach men so, he shall be called the least in the kingdom of heaven: but whosoever shall do and teach them, the same shall be called great in the kingdom of heaven.
23255	934	20	For I say unto you, That except your righteousness shall exceed the righteousness of the scribes and Pharisees, ye shall in no case enter into the kingdom of heaven.
23256	934	21	Ye have heard that it was said by them of old time, Thou shalt not kill; and whosoever shall kill shall be in danger of the judgment:
23257	934	22	But I say unto you, That whosoever is angry with his brother without a cause shall be in danger of the judgment: and whosoever shall say to his brother, Raca, shall be in danger of the council: but whosoever shall say, Thou fool, shall be in danger of hell fire.
23258	934	23	Therefore if thou bring thy gift to the altar, and there rememberest that thy brother hath ought against thee;
23259	934	24	Leave there thy gift before the altar, and go thy way; first be reconciled to thy brother, and then come and offer thy gift.
23260	934	25	Agree with thine adversary quickly, whiles thou art in the way with him; lest at any time the adversary deliver thee to the judge, and the judge deliver thee to the officer, and thou be cast into prison.
23261	934	26	Verily I say unto thee, Thou shalt by no means come out thence, till thou hast paid the uttermost farthing.
23262	934	27	Ye have heard that it was said by them of old time, Thou shalt not commit adultery:
23263	934	28	But I say unto you, That whosoever looketh on a woman to lust after her hath committed adultery with her already in his heart.
23264	934	29	And if thy right eye offend thee, pluck it out, and cast it from thee: for it is profitable for thee that one of thy members should perish, and not that thy whole body should be cast into hell.
23265	934	30	And if thy right hand offend thee, cut if off, and cast it from thee: for it is profitable for thee that one of thy members should perish, and not that thy whole body should be cast into hell.
23266	934	31	It hath been said, Whosoever shall put away his wife, let him give her a writing of divorcement:
23267	934	32	But I say unto you, That whosoever shall put away his wife, saving for the cause of fornication, causeth her to commit adultery: and whosoever shall marry her that is divorced committeth adultery.
23268	934	33	Again, ye have heard that it hath been said by them of old time, Thou shalt not forswear thyself, but shalt perform unto the Lord thine oaths:
23269	934	34	But I say unto you, Swear not at all; neither by heaven; for it is God's throne:
23270	934	35	Nor by the earth; for it is his footstool: neither by Jerusalem; for it is the city of the great King.
23271	934	36	Neither shalt thou swear by thy head, because thou canst not make one hair white or black.
23272	934	37	But let your communication be, Yea, yea; Nay, nay: for whatsoever is more than these cometh of evil.
23273	934	38	Ye have heard that it hath been said, An eye for an eye, and a tooth for a tooth:
23274	934	39	But I say unto you, That ye resist not evil: but whosoever shall smite thee on thy right cheek, turn to him the other also.
23275	934	40	And if any man will sue thee at the law, and take away thy coat, let him have thy cloke also.
23276	934	41	And whosoever shall compel thee to go a mile, go with him twain.
23277	934	42	Give to him that asketh thee, and from him that would borrow of thee turn not thou away.
23278	934	43	Ye have heard that it hath been said, Thou shalt love thy neighbour, and hate thine enemy.
23279	934	44	But I say unto you, Love your enemies, bless them that curse you, do good to them that hate you, and pray for them which despitefully use you, and persecute you;
23280	934	45	That ye may be the children of your Father which is in heaven: for he maketh his sun to rise on the evil and on the good, and sendeth rain on the just and on the unjust.
23281	934	46	For if ye love them which love you, what reward have ye? do not even the publicans the same?
23282	934	47	And if ye salute your brethren only, what do ye more than others? do not even the publicans so?
23283	934	48	Be ye therefore perfect, even as your Father which is in heaven is perfect.
23284	935	1	TAKE heed that ye do not your alms before men, to be seen of them: otherwise ye have no reward of your Father which is in heaven.
23285	935	2	Therefore when thou doest thine alms, do not sound a trumpet before thee, as the hypocrites do in the synagogues and in the streets, that they may have glory of men. Verily I say unto you, They have their reward.
23286	935	3	But when thou doest alms, let not thy left hand know what thy right hand doeth:
23287	935	4	That thine alms may be in secret: and thy Father which seeth in secret himself shall reward thee openly.
23288	935	5	And when thou prayest, thou shalt not be as the hypocrites are: for they love to pray standing in the synagogues and in the corners of the streets, that they may be seen of men. Verily I say unto you, They have their reward.
23289	935	6	But thou, when thou prayest, enter into thy closet, and when thou hast shut thy door, pray to thy Father which is in secret; and thy Father which seeth in secret shall reward thee openly.
23290	935	7	But when ye pray, use not vain repetitions, as the heathen do: for they think that they shall be heard for their much speaking.
23291	935	8	Be not ye therefore like unto them: for your Father knoweth what things ye have need of, before ye ask him.
23292	935	9	After this manner therefore pray ye: Our Father which art in heaven, Hallowed be thy name.
23293	935	10	Thy kingdom come. Thy will be done in earth, as it is in heaven.
23294	935	11	Give us this day our daily bread.
23295	935	12	And forgive us our debts, as we forgive our debtors.
23296	935	13	And lead us not into temptation, but deliver us from evil: For thine is the kingdom, and the power, and the glory, for ever. Amen.
23297	935	14	For if ye forgive men their trespasses, your heavenly Father will also forgive you:
23298	935	15	But if ye forgive not men their trespasses, neither will your Father forgive your trespasses.
23299	935	16	Moreover when ye fast, be not, as the hypocrites, of a sad countenance: for they disfigure their faces, that they may appear unto men to fast. Verily I say unto you, They have their reward.
23300	935	17	But thou, when thou fastest, anoint thine head, and wash thy face;
23301	935	18	That thou appear not unto men to fast, but unto thy Father which is in secret: and thy Father, which seeth in secret, shall reward thee openly.
23302	935	19	Lay not up for yourselves treasures upon earth, where moth and rust doth corrupt, and where thieves break through and steal:
23303	935	20	But lay up for yourselves treasures in heaven, where neither moth nor rust doth corrupt, and where thieves do not break through nor steal:
23304	935	21	For where your treasure is, there will your heart be also.
23305	935	22	The light of the body is the eye: if therefore thine eye be single, thy whole body shall be full of light.
23306	935	23	But if thine eye be evil, thy whole body shall be full of darkness. If therefore the light that is in thee be darkness, how great is that darkness!
23307	935	24	No man can serve two masters: for either he will hate the one, and love the other; or else he will hold to the one, and despise the other. Ye cannot serve God and mammon.
23308	935	25	Therefore I say unto you, Take no thought for your life, what ye shall eat, or what ye shall drink; nor yet for your body, what ye shall put on. Is not the life more than meat, and the body than raiment?
23309	935	26	Behold the fowls of the air: for they sow not, neither do they reap, nor gather into barns; yet your heavenly Father feedeth them. Are ye not much better than they?
23310	935	27	Which of you by taking thought can add one cubit unto his stature?
23311	935	28	And why take ye thought for raiment? Consider the lilies of the field, how they grow; they toil not, neither do they spin:
23312	935	29	And yet I say unto you, That even Solomon in all his glory was not arrayed like one of these.
23313	935	30	Wherefore, if God so clothe the grass of the field, which to day is, and to morrow is cast into the oven, shall he not much more clothe you, O ye of little faith?
23314	935	31	Therefore take no thought, saying, What shall we eat? or, What shall we drink? or, Wherewithal shall we be clothed?
23315	935	32	(For after all these things do the Gentiles seek:) for your heavenly Father knoweth that ye have need of all these things.
23316	935	33	But seek ye first the kingdom of God, and his righteousness; and all these things shall be added unto you.
23317	935	34	Take therefore no thought for the morrow: for the morrow shall take thought for the things of itself. Sufficient unto the day is the evil thereof.
23318	936	1	JUDGE not, that ye be not judged.
23319	936	2	For with what judgment ye judge, ye shall be judged: and with what measure ye mete, it shall be measured to you again.
23320	936	3	And why beholdest thou the mote that is in thy brother's eye, but considerest not the beam that is in thine own eye?
23321	936	4	Or how wilt thou say to thy brother, Let me pull out the mote out of thine eye; and, behold, a beam is in thine own eye?
23322	936	5	Thou hypocrite, first cast out the beam out of thine own eye; and then shalt thou see clearly to cast out the mote out of thy brother's eye.
23323	936	6	Give not that which is holy unto the dogs, neither cast ye your pearls before swine, lest they trample them under their feet, and turn again and rend you.
23324	936	7	Ask, and it shall be given you; seek, and ye shall find; knock, and it shall be opened unto you:
23325	936	8	For every one that asketh receiveth; and he that seeketh findeth; and to him that knocketh it shall be opened.
23326	936	9	Or what man is there of you, whom if his son ask bread, will he give him a stone?
23327	936	10	Or if he ask a fish, will he give him a serpent?
23328	936	11	If ye then, being evil, know how to give good gifts unto your children, how much more shall your Father which is in heaven give good things to them that ask him?
23329	936	12	Therefore all things whatsoever ye would that men should do to you, do ye even so to them: for this is the law and the prophets.
23330	936	13	Enter ye in at the strait gate: for wide is the gate, and broad is the way, that leadeth to destruction, and many there be which go in thereat:
23331	936	14	Because strait is the gate, and narrow is the way, which leadeth unto life, and few there be that find it.
23332	936	15	Beware of false prophets, which come to you in sheep's clothing, but inwardly they are ravening wolves.
23333	936	16	Ye shall know them by their fruits. Do men gather grapes of thorns, or figs of thistles?
23334	936	17	Even so every good tree bringeth forth good fruit; but a corrupt tree bringeth forth evil fruit.
23335	936	18	A good tree cannot bring forth evil fruit, neither can a corrupt tree bring forth good fruit.
23336	936	19	Every tree that bringeth not forth good fruit is hewn down, and cast into the fire.
23337	936	20	Wherefore by their fruits ye shall know them.
23338	936	21	Not every one that saith unto me, Lord, Lord, shall enter into the kingdom of heaven; but he that doeth the will of my Father which is in heaven.
23339	936	22	Many will say to me in that day, Lord, Lord, have we not prophesied in thy name? and in thy name have cast out devils? and in thy name done many wonderful works?
23340	936	23	And then will I profess unto them, I never knew you: depart from me, ye that work iniquity.
23341	936	24	Therefore whosoever heareth these sayings of mine, and doeth them, I will liken him unto a wise man, which built his house upon a rock:
23342	936	25	And the rain descended, and the floods came, and the winds blew, and beat upon that house; and it fell not: for it was founded upon a rock.
23343	936	26	And every one that heareth these sayings of mine, and doeth them not, shall be likened unto a foolish man, which built his house upon the sand:
23344	936	27	And the rain descended, and the floods came, and the winds blew, and beat upon that house; and it fell: and great was the fall of it.
23345	936	28	And it came to pass, when Jesus had ended these sayings, the people were astonished at his doctrine:
23346	936	29	For he taught them as one having authority, and not as the scribes.
23347	937	1	WHEN he was come down from the mountain, great multitudes followed him.
23348	937	2	And, behold, there came a leper and worshipped him, saying, Lord, if thou wilt, thou canst make me clean.
23349	937	3	And Jesus put forth his hand, and touched him, saying, I will; be thou clean. And immediately his leprosy was cleansed.
23350	937	4	And Jesus saith unto him, See thou tell no man; but go thy way, shew thyself to the priest, and offer the gift that Moses commanded, for a testimony unto them.
23351	937	5	And when Jesus was entered into Capernaum, there came unto him a centurion, beseeching him,
23352	937	6	And saying, Lord, my servant lieth at home sick of the palsy, grievously tormented.
23353	937	7	And Jesus saith unto him, I will come and heal him.
23354	937	8	The centurion answered and said, Lord, I am not worthy that thou shouldest come under my roof: but speak the word only, and my servant shall be healed.
23355	937	9	For I am a man under authority, having soldiers under me: and I say to this man, Go, and he goeth; and to another, Come, and he cometh; and to my servant, Do this, and he doeth it.
23356	937	10	When Jesus heard it, he marvelled, and said to them that followed, Verily I say unto you, I have not found so great faith, no, not in Israel.
23357	937	11	And I say unto you, That many shall come from the east and west, and shall sit down with Abraham, and Isaac, and Jacob, in the kingdom of heaven.
23358	937	12	But the children of the kingdom shall be cast out into outer darkness: there shall be weeping and gnashing of teeth.
23359	937	13	And Jesus said unto the centurion, Go thy way; and as thou hast believed, so be it done unto thee. And his servant was healed in the selfsame hour.
23360	937	14	And when Jesus was come into Peter's house, he saw his wife's mother laid, and sick of a fever.
23361	937	15	And he touched her hand, and the fever left her: and she arose, and ministered unto them.
23362	937	16	When the even was come, they brought unto him many that were possessed with devils: and he cast out the spirits with his word, and healed all that were sick:
23363	937	17	That it might be fulfilled which was spoken by Esaias the prophet, saying, Himself took our infirmities, and bare our sicknesses.
23364	937	18	Now when Jesus saw great multitudes about him, he gave commandment to depart unto the other side.
23365	937	19	And a certain scribe came, and said unto him, Master, I will follow thee whithersoever thou goest.
23366	937	20	And Jesus saith unto him, The foxes have holes, and the birds of the air have nests; but the Son of man hath not where to lay his head.
23367	937	21	And another of his disciples said unto him, Lord, suffer me first to go and bury my father.
23368	937	22	But Jesus said unto him, Follow me; and let the dead bury their dead.
23369	937	23	And when he was entered into a ship, his disciples followed him.
23370	937	24	And, behold, there arose a great tempest in the sea, insomuch that the ship was covered with the waves: but he was asleep.
23371	937	25	And his disciples came to him, and awoke him, saying, Lord, save us: we perish.
23372	937	26	And he saith unto them, Why are ye fearful, O ye of little faith? Then he arose, and rebuked the winds and the sea; and there was a great calm.
23373	937	27	But the men marvelled, saying, What manner of man is this, that even the winds and the sea obey him!
23374	937	28	And when he was come to the other side into the country of the Gergesenes, there met him two possessed with devils, coming out of the tombs, exceeding fierce, so that no man might pass by that way.
23375	937	29	And, behold, they cried out, saying, What have we to do with thee, Jesus, thou Son of God? art thou come hither to torment us before the time?
23376	937	30	And there was a good way off from them an herd of many swine feeding.
23377	937	31	So the devils besought him, saying, If thou cast us out, suffer us to go away into the herd of swine.
23378	937	32	And he said unto them, Go. And when they were come out, they went into the herd of swine: and, behold, the whole herd of swine ran violently down a steep place into the sea, and perished in the waters.
23379	937	33	And they that kept them fled, and went their ways into the city, and told every thing, and what was befallen to the possessed of the devils.
23380	937	34	And, behold, the whole city came out to meet Jesus: and when they saw him, they besought him that he would depart out of their coasts.
23381	938	1	AND he entered into a ship, and passed over, and came into his own city.
23382	938	2	And, behold, they brought to him a man sick of the palsy, lying on a bed: and Jesus seeing their faith said unto the sick of the palsy; Son, be of good cheer; thy sins be forgiven thee.
23383	938	3	And, behold, certain of the scribes said within themselves, This man blasphemeth.
23384	938	4	And Jesus knowing their thoughts said, Wherefore think ye evil in your hearts?
23385	938	5	For whether is easier, to say, Thy sins be forgiven thee; or to say, Arise, and walk?
23386	938	6	But that ye may know that the Son of man hath power on earth to forgive sins, (then saith he to the sick of the palsy,) Arise, take up thy bed, and go unto thine house.
23387	938	7	And he arose, and departed to his house.
23388	938	8	But when the multitudes saw it, they marvelled, and glorified God, which had given such power unto men.
23389	938	9	And as Jesus passed forth from thence, he saw a man, named Matthew, sitting at the receipt of custom: and he saith unto him, Follow me. And he arose, and followed him.
23390	938	10	And it came to pass, as Jesus sat at meat in the house, behold, many publicans and sinners came and sat down with him and his disciples.
23391	938	11	And when the Pharisees saw it, they said unto his disciples, Why eateth your Master with publicans and sinners?
23392	938	12	But when Jesus heard that, he said unto them, They that be whole need not a physician, but they that are sick.
23393	938	13	But go ye and learn what that meaneth, I will have mercy, and not sacrifice: for I am not come to call the righteous, but sinners to repentance.
23394	938	14	Then came to him the disciples of John, saying, Why do we and the Pharisees fast oft, but thy disciples fast not?
23395	938	15	And Jesus said unto them, Can the children of the bridechamber mourn, as long as the bridegroom is with them? but the days will come, when the bridegroom shall be taken from them, and then shall they fast.
23396	938	16	No man putteth a piece of new cloth unto an old garment, for that which is put in to fill it up taketh from the garment, and the rent is made worse.
23397	938	17	Neither do men put new wine into old bottles: else the bottles break, and the wine runneth out, and the bottles perish: but they put new wine into new bottles, and both are preserved.
23398	938	18	While he spake these things unto them, behold, there came a certain ruler, and worshipped him, saying, My daughter is even now dead: but come and lay thy hand upon her, and she shall live.
23399	938	19	And Jesus arose, and followed him, and so did his disciples.
23400	938	20	And, behold, a woman, which was diseased with an issue of blood twelve years, came behind him, and touched the hem of his garment:
23401	938	21	For she said within herself, If I may but touch his garment, I shall be whole.
23402	938	22	But Jesus turned him about, and when he saw her, he said, Daughter, be of good comfort; thy faith hath made thee whole. And the woman was made whole from that hour.
23403	938	23	And when Jesus came into the ruler's house, and saw the minstrels and the people making a noise,
23404	938	24	He said unto them, Give place: for the maid is not dead, but sleepeth. And they laughed him to scorn.
23405	938	25	But when the people were put forth, he went in, and took her by the hand, and the maid arose.
23406	938	26	And the fame hereof went abroad into all that land.
23407	938	27	And when Jesus departed thence, two blind men followed him, crying, and saying, Thou Son of David, have mercy on us.
23408	938	28	And when he was come into the house, the blind men came to him: and Jesus saith unto them, Believe ye that I am able to do this? They said unto him, Yea, Lord.
23409	938	29	Then touched he their eyes, saying, According to your faith be it unto you.
23410	938	30	And their eyes were opened; and Jesus straitly charged them, saying, See that no man know it.
23411	938	31	But they, when they were departed, spread abroad his fame in all that country.
23412	938	32	As they went out, behold, they brought to him a dumb man possessed with a devil.
23413	938	33	And when the devil was cast out, the dumb spake: and the multitudes marvelled, saying, It was never so seen in Israel.
23414	938	34	But the Pharisees said, He casteth out devils through the prince of the devils.
23415	938	35	And Jesus went about all the cities and villages, teaching in their synagogues, and preaching the gospel of the kingdom, and healing every sickness and every disease among the people.
23416	938	36	But when he saw the multitudes, he was moved with compassion on them, because they fainted, and were scattered abroad, as sheep having no shepherd.
23417	938	37	Then saith he unto his disciples, The harvest truly is plenteous, but the labourers are few;
23418	938	38	Pray ye therefore the Lord of the harvest, that he will send forth labourers into his harvest.
23419	939	1	AND when he had called unto him his twelve disciples, he gave them power against unclean spirits, to cast them out, and to heal all manner of sickness and all manner of disease.
23420	939	2	Now the names of the twelve apostles are these; The first, Simon, who is called Peter, and Andrew his brother; James the son of Zebedee, and John his brother;
23421	939	3	Philip, and Bartholomew; Thomas, and Matthew the publican; James the son of Alphaeus, and Lebbaeus, whose surname was Thaddaeus;
23422	939	4	Simon the Canaanite, and Judas Iscariot, who also betrayed him.
23423	939	5	These twelve Jesus sent forth, and commanded them, saying, Go not into the way of the Gentiles, and into any city of the Samaritans enter ye not:
23424	939	6	But go rather to the lost sheep of the house of Israel.
23425	939	7	And as ye go, preach, saying, The kingdom of heaven is at hand.
23426	939	8	Heal the sick, cleanse the lepers, raise the dead, cast out devils: freely ye have received, freely give.
23427	939	9	Provide neither gold, nor silver, nor brass in your purses,
23428	939	10	Nor scrip for your journey, neither two coats, neither shoes, nor yet staves: for the workman is worthy of his meat.
23429	939	11	And into whatsoever city or town ye shall enter, enquire who in it is worthy; and there abide till ye go thence.
23430	939	12	And when ye come into an house, salute it.
23431	939	13	And if the house be worthy, let your peace come upon it: but if it be not worthy, let your peace return to you.
23432	939	14	And whosoever shall not receive you, nor hear your words, when ye depart out of that house or city, shake off the dust of your feet.
23433	939	15	Verily I say unto you, It shall be more tolerable for the land of Sodom and Gomorrha in the day of judgment, than for that city.
23434	939	16	Behold, I send you forth as sheep in the midst of wolves: be ye therefore wise as serpents, and harmless as doves.
23435	939	17	But beware of men: for they will deliver you up to the councils, and they will scourge you in their synagogues;
23436	939	18	And ye shall be brought before governors and kings for my sake, for a testimony against them and the Gentiles.
23437	939	19	But when they deliver you up, take no thought how or what ye shall speak: for it shall be given you in that same hour what ye shall speak.
23438	939	20	For it is not ye that speak, but the Spirit of your Father which speaketh in you.
23439	939	21	And the brother shall deliver up the brother to death, and the father the child: and the children shall rise up against their parents, and cause them to be put to death.
23440	939	22	And ye shall be hated of all men for my name's sake: but he that endureth to the end shall be saved.
23441	939	23	But when they persecute you in this city, flee ye into another: for verily I say unto you, Ye shall not have gone over the cities of Israel, till the Son of man be come.
23442	939	24	The disciple is not above his master, nor the servant above his lord.
23443	939	25	It is enough for the disciple that he be as his master, and the servant as his lord. If they have called the master of the house Beelzebub, how much more shall they call them of his household?
23444	939	26	Fear them not therefore: for there is nothing covered, that shall not be revealed; and hid, that shall not be known.
23445	939	27	What I tell you in darkness, that speak ye in light: and what ye hear in the ear, that preach ye upon the housetops.
23446	939	28	And fear not them which kill the body, but are not able to kill the soul: but rather fear him which is able to destroy both soul and body in hell.
23447	939	29	Are not two sparrows sold for a farthing? and one of them shall not fall on the ground without your Father.
23448	939	30	But the very hairs of your head are all numbered.
23449	939	31	Fear ye not therefore, ye are of more value than many sparrows.
23450	939	32	Whosoever therefore shall confess me before men, him will I confess also before my Father which is in heaven.
23451	939	33	But whosoever shall deny me before men, him will I also deny before my Father which is in heaven.
23452	939	34	Think not that I am come to send peace on earth: I came not to send peace, but a sword.
23453	939	35	For I am come to set a man at variance against his father, and the daughter against her mother, and the daughter in law against her mother in law.
23454	939	36	And a man's foes shall be they of his own household.
23455	939	37	He that loveth father or mother more than me is not worthy of me: and he that loveth son or daughter more than me is not worthy of me.
23456	939	38	And he that taketh not his cross, and followeth after me, is not worthy of me.
23457	939	39	He that findeth his life shall lose it: and he that loseth his life for my sake shall find it.
23458	939	40	He that receiveth you receiveth me, and he that receiveth me receiveth him that sent me.
23459	939	41	He that receiveth a prophet in the name of a prophet shall receive a prophet's reward; and he that receiveth a righteous man in the name of a righteous man shall receive a righteous man's reward.
23460	939	42	And whosoever shall give to drink unto one of these little ones a cup of cold water only in the name of a disciple, verily I say unto you, he shall in no wise lose his reward.
23461	940	1	AND it came to pass, when Jesus had made an end of commanding his twelve disciples, he departed thence to teach and to preach in their cities.
23462	940	2	Now when John had heard in the prison the works of Christ, he sent two of his disciples,
23463	940	3	And said unto him, Art thou he that should come, or do we look for another?
23464	940	4	Jesus answered and said unto them, Go and shew John again those things which ye do hear and see:
23465	940	5	The blind receive their sight, and the lame walk, the lepers are cleansed, and the deaf hear, the dead are raised up, and the poor have the gospel preached to them.
23466	940	6	And blessed is he, whosoever shall not be offended in me.
23467	940	7	And as they departed, Jesus began to say unto the multitudes concerning John, What went ye out into the wilderness to see? A reed shaken with the wind?
23468	940	8	But what went ye out for to see? A man clothed in soft raiment? behold, they that wear soft clothing are in kings' houses.
23469	940	9	But what went ye out for to see? A prophet? yea, I say unto you, and more than a prophet.
23470	940	10	For this is he, of whom it is written, Behold, I send my messenger before thy face, which shall prepare thy way before thee.
23471	940	11	Verily I say unto you, Among them that are born of women there hath not risen a greater than John the Baptist: notwithstanding he that is least in the kingdom of heaven is greater than he.
23472	940	12	And from the days of John the Baptist until now the kingdom of heaven suffereth violence, and the violent take it by force.
23473	940	13	For all the prophets and the law prophesied until John.
23474	940	14	And if ye will receive it, this is Elias, which was for to come.
23475	940	15	He that hath ears to hear, let him hear.
23476	940	16	But whereunto shall I liken this generation? It is like unto children sitting in the markets, and calling unto their fellows,
23477	940	17	And saying, We have piped unto you, and ye have not danced; we have mourned unto you, and ye have not lamented.
23478	940	18	For John came neither eating nor drinking, and they say, He hath a devil.
23479	940	19	The Son of man came eating and drinking, and they say, Behold a man gluttonous, and a winebibber, a friend of publicans and sinners. But wisdom is justified of her children.
23480	940	20	Then began he to upbraid the cities wherein most of his mighty works were done, because they repented not:
23481	940	21	Woe unto thee, Chorazin! woe unto thee, Bethsaida! for if the mighty works, which were done in you, had been done in Tyre and Sidon, they would have repented long ago in sackcloth and ashes.
23482	940	22	But I say unto you, It shall be more tolerable for Tyre and Sidon at the day of judgment, than for you.
23483	940	23	And thou, Capernaum, which art exalted unto heaven, shalt be brought down to hell: for if the mighty works, which have been done in thee, had been done in Sodom, it would have remained until this day.
23484	940	24	But I say unto you, That it shall be more tolerable for the land of Sodom in the day of judgment, than for thee.
23485	940	25	At that time Jesus answered and said, I thank thee, O Father, Lord of heaven and earth, because thou hast hid these things from the wise and prudent, and hast revealed them unto babes.
23486	940	26	Even so, Father: for so it seemed good in thy sight.
23487	940	27	All things are delivered unto me of my Father: and no man knoweth the Son, but the Father; neither knoweth any man the Father, save the Son, and he to whomsoever the Son will reveal him.
23488	940	28	Come unto me, all ye that labour and are heavy laden, and I will give you rest.
23489	940	29	Take my yoke upon you, and learn of me; for I am meek and lowly in heart: and ye shall find rest unto your souls.
23490	940	30	For my yoke is easy, and my burden is light.
23491	941	1	AT that time Jesus went on the sabbath day through the corn; and his disciples were an hungred, and began to pluck the ears of corn, and to eat.
23492	941	2	But when the Pharisees saw it, they said unto him, Behold, thy disciples do that which is not lawful to do upon the sabbath day.
23493	941	3	But he said unto them, Have ye not read what David did, when he was an hungred, and they that were with him;
23494	941	4	How he entered into the house of God, and did eat the shewbread, which was not lawful for him to eat, neither for them which were with him, but only for the priests?
23495	941	5	Or have ye not read in the law, how that on the sabbath days the priests in the temple profane the sabbath, and are blameless?
23496	941	6	But I say unto you, That in this place is one greater than the temple.
23497	941	7	But if ye had known what this meaneth, I will have mercy, and not sacrifice, ye would not have condemned the guiltless.
23498	941	8	For the Son of man is Lord even of the sabbath day.
23499	941	9	And when he was departed thence, he went into their synagogue:
23500	941	10	And, behold, there was a man which had his hand withered. And they asked him, saying, Is it lawful to heal on the sabbath days? that they might accuse him.
23501	941	11	And he said unto them, What man shall there be among you, that shall have one sheep, and if it fall into a pit on the sabbath day, will he not lay hold on it, and lift it out?
23502	941	12	How much then is a man better than a sheep? Wherefore it is lawful to do well on the sabbath days.
23503	941	13	Then saith he to the man, Stretch forth thine hand. And he stretched it forth; and it was restored whole, like as the other.
23504	941	14	Then the Pharisees went out, and held a council against him, how they might destroy him.
23505	941	15	But when Jesus knew it, he withdrew himself from thence: and great multitudes followed him, and he healed them all;
23506	941	16	And charged them that they should not make him known:
23507	941	17	That it might be fulfilled which was spoken by Esaias the prophet, saying.
23508	941	18	Behold my servant, whom I have chosen; my beloved, in whom my soul is well pleased: I will put my spirit upon him, and he shall shew judgment to the Gentiles.
23509	941	19	He shall not strive, nor cry; neither shall any man hear his voice in the streets.
23510	941	20	A bruised reed shall he not break, and smoking flax shall he not quench, till he send forth judgment unto victory.
23511	941	21	And in his name shall the Gentiles trust.
23512	941	22	Then was brought unto him one possessed with a devil, blind, and dumb: and he healed him, insomuch that the blind and dumb both spake and saw.
23513	941	23	And all the people were amazed, and said, Is not this the son of David?
23514	941	24	But when the Pharisees heard it, they said, This fellow doth not cast out devils, but by Beelzebub the prince of the devils.
23515	941	25	And Jesus knew their thoughts, and said unto them, Every kingdom divided against itself is brought to desolation; and every city or house divided against itself shall not stand:
23516	941	26	And if Satan cast out Satan, he is divided against himself; how shall then his kingdom stand?
23517	941	27	And if I by Beelzebub cast out devils, by whom do your children cast them out? therefore they shall be your judges.
23518	941	28	But if I cast out devils by the Spirit of God, then the kingdom of God is come unto you.
23519	941	29	Or else how can one enter into a strong man's house, and spoil his goods, except he first bind the strong man? and then he will spoil his house.
23520	941	30	He that is not with me is against me; and he that gathereth not with me scattereth abroad.
23521	941	31	Wherefore I say unto you, All manner of sin and blasphemy shall be forgiven unto men: but the blasphemy against the Holy Ghost shall not be forgiven unto men.
23522	941	32	And whosoever speaketh a word against the Son of man, it shall be forgiven him: but whosoever speaketh against the Holy Ghost, it shall not be forgiven him, neither in this world, neither in the world to come.
23523	941	33	Either make the tree good, and his fruit good; or else make the tree corrupt, and his fruit corrupt: for the tree is known by his fruit.
23524	941	34	O generation of vipers, how can ye, being evil, speak good things? for out of the abundance of the heart the mouth speaketh.
23525	941	35	A good man out of the good treasure of the heart bringeth forth good things: and an evil man out of the evil treasure bringeth forth evil things.
23526	941	36	But I say unto you, That every idle word that men shall speak, they shall give account thereof in the day of judgment.
23527	941	37	For by thy words thou shalt be justified, and by thy words thou shalt be condemned.
23528	941	38	Then certain of the scribes and of the Pharisees answered, saying, Master, we would see a sign from thee.
23529	941	39	But he answered and said unto them, An evil and adulterous generation seeketh after a sign; and there shall no sign be given to it, but the sign of the prophet Jonas:
23530	941	40	For as Jonas was three days and three nights in the whale's belly; so shall the Son of man be three days and three nights in the heart of the earth.
23531	941	41	The men of Nineveh shall rise in judgment with this generation, and shall condemn it: because they repented at the preaching of Jonas; and, behold, a greater than Jonas is here.
23532	941	42	The queen of the south shall rise up in the judgment with this generation, and shall condemn it: for she came from the uttermost parts of the earth to hear the wisdom of Solomon; and, behold, a greater than Solomon is here.
23533	941	43	When the unclean spirit is gone out of a man, he walketh through dry places, seeking rest, and findeth none.
23534	941	44	Then he saith, I will return into my house from whence I came out; and when he is come, he findeth it empty, swept, and garnished.
23535	941	45	Then goeth he, and taketh with himself seven other spirits more wicked than himself, and they enter in and dwell there: and the last state of that man is worse than the first. Even so shall it be also unto this wicked generation.
23536	941	46	While he yet talked to the people, behold, his mother and his brethren stood without, desiring to speak with him.
23537	941	47	Then one said unto him, Behold, thy mother and thy brethren stand without, desiring to speak with thee.
23538	941	48	But he answered and said unto him that told him, Who is my mother? and who are my brethren?
23539	941	49	And he stretched forth his hand toward his disciples, and said, Behold my mother and my brethren!
23540	941	50	For whosoever shall do the will of my Father which is in heaven, the same is my brother, and sister, and mother.
23541	942	1	THE same day went Jesus out of the house, and sat by the sea side.
23542	942	2	And great multitudes were gathered together unto him, so that he went into a ship, and sat; and the whole multitude stood on the shore.
23543	942	3	And he spake many things unto them in parables, saying, Behold, a sower went forth to sow;
23544	942	4	And when he sowed, some seeds fell by the way side, and the fowls came and devoured them up:
23545	942	5	Some fell upon stony places, where they had not much earth: and forthwith they sprung up, because they had no deepness of earth:
23546	942	6	And when the sun was up, they were scorched; and because they had no root, they withered away.
23547	942	7	And some fell among thorns; and the thorns sprung up, and choked them:
23548	942	8	But other fell into good ground, and brought forth fruit, some an hundredfold, some sixtyfold, some thirtyfold.
23549	942	9	Who hath ears to hear, let him hear.
23550	942	10	And the disciples came, and said unto him, Why speakest thou unto them in parables?
23551	942	11	He answered and said unto them, Because it is given unto you to know the mysteries of the kingdom of heaven, but to them it is not given.
23552	942	12	For whosoever hath, to him shall be given, and he shall have more abundance: but whosoever hath not, from him shall be taken away even that he hath.
23553	942	13	Therefore speak I to them in parables: because they seeing see not; and hearing they hear not, neither do they understand.
23554	942	14	And in them is fulfilled the prophecy of Esaias, which saith, By hearing ye shall hear, and shall not understand; and seeing ye shall see, and shall not perceive:
23555	942	15	For this people's heart is waxed gross, and their ears are dull of hearing, and their eyes they have closed; lest at any time they should see with their eyes, and hear with their ears, and should understand with their heart, and should be converted, and I should heal them.
23556	942	16	But blessed are your eyes, for they see: and your ears, for they hear.
23557	942	17	For verily I say unto you, That many prophets and righteous men have desired to see those things which ye see, and have not seen them; and to hear those things which ye hear, and have not heard them.
23558	942	18	Hear ye therefore the parable of the sower.
23559	942	19	When any one heareth the word of the kingdom, and understandeth it not, then cometh the wicked one, and catcheth away that which was sown in his heart. This is he which received seed by the way side.
23560	942	20	But he that received the seed into stony places, the same is he that heareth the word, and anon with joy receiveth it;
23561	942	21	Yet hath he not root in himself, but dureth for a while: for when tribulation or persecution ariseth because of the word, by and by he is offended.
23562	942	22	He also that received seed among the thorns is he that heareth the word; and the care of this world, and the deceitfulness of riches, choke the word, and he becometh unfruitful.
23563	942	23	But he that received seed into the good ground is he that heareth the word, and understandeth it; which also beareth fruit, and bringeth forth, some an hundredfold, some sixty, some thirty.
23564	942	24	Another parable put he forth unto them, saying, The kingdom of heaven is likened unto a man which sowed good seed in his field:
23565	942	25	But while men slept, his enemy came and sowed tares among the wheat, and went his way.
23566	942	26	But when the blade was sprung up, and brought forth fruit, then appeared the tares also.
23567	942	27	So the servants of the householder came and said unto him, Sir, didst not thou sow good seed in thy field? from whence then hath it tares?
23568	942	28	He said unto them, An enemy hath done this. The servants said unto him, Wilt thou then that we go and gather them up?
23569	942	29	But he said, Nay; lest while ye gather up the tares, ye root up also the wheat with them.
23570	942	30	Let both grow together until the harvest: and in the time of harvest I will say to the reapers, Gather ye together first the tares, and bind them in bundles to burn them: but gather the wheat into my barn.
23571	942	31	Another parable put he forth unto them, saying, The kingdom of heaven is like to a grain of mustard seed, which a man took, and sowed in his field:
23572	942	32	Which indeed is the least of all seeds: but when it is grown, it is the greatest among herbs, and becometh a tree, so that the birds of the air come and lodge in the branches thereof.
23573	942	33	Another parable spake he unto them; The kingdom of heaven is like unto leaven, which a woman took, and hid in three measures of meal, till the whole was leavened.
23574	942	34	All these things spake Jesus unto the multitude in parables; and without a parable spake he not unto them:
23575	942	35	That it might be fulfilled which was spoken by the prophet, saying, I will open my mouth in parables; I will utter things which have been kept secret from the foundation of the world.
23576	942	36	Then Jesus sent the multitude away, and went into the house: and his disciples came unto him, saying, Declare unto us the parable of the tares of the field.
23577	942	37	He answered and said unto them, He that soweth the good seed is the Son of man;
23578	942	38	The field is the world; the good seed are the children of the kingdom; but the tares are the children of the wicked one;
23579	942	39	The enemy that sowed them is the devil; the harvest is the end of the world; and the reapers are the angels.
23580	942	40	As therefore the tares are gathered and burned in the fire; so shall it be in the end of this world.
23581	942	41	The Son of man shall send forth his angels, and they shall gather out of his kingdom all things that offend, and them which do iniquity;
23582	942	42	And shall cast them into a furnace of fire: there shall be wailing and gnashing of teeth.
23583	942	43	Then shall the righteous shine forth as the sun in the kingdom of their Father. Who hath ears to hear, let him hear.
23584	942	44	Again, the kingdom of heaven is like unto treasure hid in a field; the which when a man hath found, he hideth, and for joy thereof goeth and selleth all that he hath, and buyeth that field.
23585	942	45	Again, the kingdom of heaven is like unto a merchant man, seeking goodly pearls:
23586	942	46	Who, when he had found one pearl of great price, went and sold all that he had, and bought it.
23587	942	47	Again, the kingdom of heaven is like unto a net, that was cast into the sea, and gathered of every kind:
23588	942	48	Which, when it was full, they drew to shore, and sat down, and gathered the good into vessels, but cast the bad away.
23589	942	49	So shall it be at the end of the world: the angels shall come forth, and sever the wicked from among the just,
23590	942	50	And shall cast them into the furnace of fire: there shall be wailing and gnashing of teeth.
23591	942	51	Jesus saith unto them, Have ye understood all these things? They say unto him, Yea, Lord.
23592	942	52	Then said he unto them, Therefore every scribe which is instructed unto the kingdom of heaven is like unto a man that is an householder, which bringeth forth out of his treasure things new and old.
23593	942	53	And it came to pass, that when Jesus had finished these parables, he departed thence.
23594	942	54	And when he was come into his own country, he taught them in their synagogue, insomuch that they were astonished, and said, Whence hath this man this wisdom, and these mighty works?
23595	942	55	Is not this the carpenter's son? is not his mother called Mary? and his brethren, James, and Joses, and Simon, and Judas?
23596	942	56	And his sisters, are they not all with us? Whence then hath this man all these things?
23597	942	57	And they were offended in him. But Jesus said unto them, A prophet is not without honour, save in his own country, and in his own house.
23598	942	58	And he did not many mighty works there because of their unbelief.
23599	943	1	AT that time Herod the tetrarch heard of the fame of Jesus,
23600	943	2	And said unto his servants, This is John the Baptist; he is risen from the dead; and therefore mighty works do shew forth themselves in him.
23601	943	3	For Herod had laid hold on John, and bound him, and put him in prison for Herodias' sake, his brother Philip's wife.
23602	943	4	For John said unto him, It is not lawful for thee to have her.
23603	943	5	And when he would have put him to death, he feared the multitude, because they counted him as a prophet.
23604	943	6	But when Herod's birthday was kept, the daughter of Herodias danced before them, and pleased Herod.
23605	943	7	Whereupon he promised with an oath to give her whatsoever she would ask.
23606	943	8	And she, being before instructed of her mother, said, Give me here John Baptist's head in a charger.
23607	943	9	And the king was sorry: nevertheless for the oath's sake, and them which sat with him at meat, he commanded it to be given her.
23608	943	10	And he sent, and beheaded John in the prison.
23609	943	11	And his head was brought in a charger, and given to the damsel: and she brought it to her mother.
23610	943	12	And his disciples came, and took up the body, and buried it, and went and told Jesus.
23611	943	13	When Jesus heard of it, he departed thence by ship into a desert place apart: and when the people had heard thereof, they followed him on foot out of the cities.
23612	943	14	And Jesus went forth, and saw a great multitude, and was moved with compassion toward them, and he healed their sick.
23613	943	15	And when it was evening, his disciples came to him, saying, This is a desert place, and the time is now past; send the multitude away, that they may go into the villages, and buy themselves victuals.
23614	943	16	But Jesus said unto them, They need not depart; give ye them to eat.
23615	943	17	And they say unto him, We have here but five loaves, and two fishes.
23616	943	18	He said, Bring them hither to me.
23617	943	19	And he commanded the multitude to sit down on the grass, and took the five loaves, and the two fishes, and looking up to heaven, he blessed, and brake, and gave the loaves to his disciples, and the disciples to the multitude.
23618	943	20	And they did all eat, and were filled: and they took up of the fragments that remained twelve baskets full.
23619	943	21	And they that had eaten were about five thousand men, beside women and children.
23620	943	22	And straightway Jesus constrained his disciples to get into a ship, and to go before him unto the other side, while he sent the multitudes away.
23621	943	23	And when he had sent the multitudes away, he went up into a mountain apart to pray: and when the evening was come, he was there alone.
23622	943	24	But the ship was now in the midst of the sea, tossed with waves: for the wind was contrary.
23623	943	25	And in the fourth watch of the night Jesus went unto them, walking on the sea.
23624	943	26	And when the disciples saw him walking on the sea, they were troubled, saying, It is a spirit; and they cried out for fear.
23625	943	27	But straightway Jesus spake unto them, saying, Be of good cheer; it is I; be not afraid.
23626	943	28	And Peter answered him and said, Lord, if it be thou, bid me come unto thee on the water.
23627	943	29	And he said, Come. And when Peter was come down out of the ship, he walked on the water, to go to Jesus.
23628	943	30	But when he saw the wind boisterous, he was afraid; and beginning to sink, he cried, saying, Lord, save me.
23629	943	31	And immediately Jesus stretched forth his hand, and caught him, and said unto him, O thou of little faith, wherefore didst thou doubt?
23630	943	32	And when they were come into the ship, the wind ceased.
23631	943	33	Then they that were in the ship came and worshipped him, saying, Of a truth thou art the Son of God.
23632	943	34	And when they were gone over, they came into the land of Gennesaret.
23633	943	35	And when the men of that place had knowledge of him, they sent out into all that country round about, and brought unto him all that were diseased;
23634	943	36	And besought him that they might only touch the hem of his garment: and as many as touched were made perfectly whole.
23635	944	1	THEN came to Jesus scribes and Pharisees, which were of Jerusalem, saying,
23636	944	2	Why do thy disciples transgress the tradition of the elders? for they wash not their hands when they eat bread.
23637	944	3	But he answered and said unto them, Why do ye also transgress the commandment of God by your tradition?
23638	944	4	For God commanded, saying, Honour thy father and mother: and, He that curseth father or mother, let him die the death.
23639	944	5	But ye say, Whosoever shall say to his father or his mother, It is a gift, by whatsoever thou mightest be profited by me;
23640	944	6	And honour not his father or his mother, he shall be free. Thus have ye made the commandment of God of none effect by your tradition.
23641	944	7	Ye hypocrites, well did Esaias prophesy of you, saying,
23642	944	8	This people draweth nigh unto me with their mouth, and honoureth me with their lips; but their heart is far from me.
23643	944	9	But in vain they do worship me, teaching for doctrines the commandments of men.
23644	944	10	And he called the multitude, and said unto them, Hear, and understand:
23645	944	11	Not that which goeth into the mouth defileth a man; but that which cometh out of the mouth, this defileth a man.
23646	944	12	Then came his disciples, and said unto him, Knowest thou that the Pharisees were offended, after they heard this saying?
23647	944	13	But he answered and said, Every plant, which my heavenly Father hath not planted, shall be rooted up.
23648	944	14	Let them alone: they be blind leaders of the blind. And if the blind lead the blind, both shall fall into the ditch.
23649	944	15	Then answered Peter and said unto him, Declare unto us this parable.
23650	944	16	And Jesus said, Are ye also yet without understanding?
23651	944	17	Do not ye yet understand, that whatsoever entereth in at the mouth goeth into the belly, and is cast out into the draught?
23652	944	18	But those things which proceed out of the mouth come forth from the heart; and they defile the man.
23653	944	19	For out of the heart proceed evil thoughts, murders, adulteries, fornications, thefts, false witness, blasphemies:
23654	944	20	These are the things which defile a man: but to eat with unwashen hands defileth not a man.
23655	944	21	Then Jesus went thence, and departed into the coasts of Tyre and Sidon.
23656	944	22	And, behold, a woman of Canaan came out of the same coasts, and cried unto him, saying, Have mercy on me, O Lord, thou Son of David; my daughter is grievously vexed with a devil.
23657	944	23	But he answered her not a word. And his disciples came and besought him, saying, Send her away; for she crieth after us.
23658	944	24	But he answered and said, I am not sent but unto the lost sheep of the house of Israel.
23659	944	25	Then came she and worshipped him, saying, Lord, help me.
23660	944	26	But he answered and said, It is not meet to take the children's bread, and to cast it to dogs.
23661	944	27	And she said, Truth, Lord: yet the dogs eat of the crumbs which fall from their masters' table.
23662	944	28	Then Jesus answered and said unto her, O woman, great is thy faith: be it unto thee even as thou wilt. And her daughter was made whole from that very hour.
23663	944	29	And Jesus departed from thence, and came nigh unto the sea of Galilee; and went up into a mountain, and sat down there.
23664	944	30	And great multitudes came unto him, having with them those that were lame, blind, dumb, maimed, and many others, and cast them down at Jesus' feet; and he healed them:
23665	944	31	Insomuch that the multitude wondered, when they saw the dumb to speak, the maimed to be whole, the lame to walk, and the blind to see: and they glorified the God of Israel.
23666	944	32	Then Jesus called his disciples unto him, and said, I have compassion on the multitude, because they continue with me now three days, and have nothing to eat: and I will not send them away fasting, lest they faint in the way.
23667	944	33	And his disciples say unto him, Whence should we have so much bread in the wilderness, as to fill so great a multitude?
23668	944	34	And Jesus saith unto them, How many loaves have ye? And they said, Seven, and a few little fishes.
23669	944	35	And he commanded the multitude to sit down on the ground.
23670	944	36	And he took the seven loaves and the fishes, and gave thanks, and brake them, and gave to his disciples, and the disciples to the multitude.
23671	944	37	And they did all eat, and were filled: and they took up of the broken meat that was left seven baskets full.
23672	944	38	And they that did eat were four thousand men, beside women and children.
23673	944	39	And he sent away the multitude, and took ship, and came into the coasts of Magdala.
23674	945	1	THE Pharisees also with the Sadducees came, and tempting desired him that he would shew them a sign from heaven.
23675	945	2	He answered and said unto them, When it is evening, ye say, It will be fair weather: for the sky is red.
23676	945	3	And in the morning, It will be foul weather to day: for the sky is red and lowring, O ye hypocrites, ye can discern the face of the sky; but can ye not discern the signs of the times?
23677	945	4	A wicked and adulterous generation seeketh after a sign; and there shall no sign be given unto it, but the sign of the prophet Jonas. And he left them, and departed.
23678	945	5	And when his disciples were come to the other side, they had forgotten to take bread.
23679	945	6	Then Jesus said unto them, Take heed and beware of the leaven of the Pharisees and of the Sadducees.
23680	945	7	And they reasoned among themselves, saying, It is because we have taken no bread.
23681	945	8	Which when Jesus perceived, he said unto them, O ye of little faith, why reason ye among yourselves, because ye have brought no bread?
23682	945	9	Do ye not yet understand, neither remember the five loaves of the five thousand, and how many baskets ye took up?
23683	945	10	Neither the seven loaves of the four thousand, and how many baskets ye took up?
23684	945	11	How is it that ye do not understand that I spake it not to you concerning bread, that ye should beware of the leaven of the Pharisees and of the Sadducees?
23685	945	12	Then understood they how that he bade them not beware of the leaven of bread, but of the doctrine of the Pharisees and of the Sadducees.
23686	945	13	When Jesus came into the coasts of Caesarea Philippi, he asked his disciples, saying, Whom do men say that I the Son of man am?
23687	945	14	And they said, Some say that thou art John the Baptist: some, Elias; and others, Jeremias, or one of the prophets.
23688	945	15	He saith unto them, But whom say ye that I am?
23689	945	16	And Simon Peter answered and said, Thou art the Christ, the Son of the living God.
23690	945	17	And Jesus answered and said unto him, Blessed art thou, Simon Bar-jona: for flesh and blood hath not revealed it unto thee, but my Father which is in heaven.
23691	945	18	And I say also unto thee, That thou art Peter, and upon this rock I will build my church; and the gates of hell shall not prevail against it.
23692	945	19	And I will give unto thee the keys of the kingdom of heaven: and whatsoever thou shalt bind on earth shall be bound in heaven: and whatsoever thou shalt loose on earth shall be loosed in heaven.
23693	945	20	Then charged he his disciples that they should tell no man that he was Jesus the Christ.
23694	945	21	From that time forth began Jesus to shew unto his disciples, how that he must go unto Jerusalem, and suffer many things of the elders and chief priests and scribes, and be killed, and be raised again the third day.
23695	945	22	Then Peter took him, and began to rebuke him, saying, Be it far from thee, Lord: this shall not be unto thee.
23696	945	23	But he turned, and said unto Peter, Get thee behind me, Satan: thou art an offence unto me: for thou savourest not the things that be of God, but those that be of men.
23697	945	24	Then said Jesus unto his disciples, If any man will come after me, let him deny himself, and take up his cross, and follow me.
23698	945	25	For whosoever will save his life shall lose it: and whosoever will lose his life for my sake shall find it.
23699	945	26	For what is a man profited, if he shall gain the whole world, and lose his own soul? or what shall a man give in exchange for his soul?
23700	945	27	For the Son of man shall come in the glory of his Father with his angels; and then he shall reward every man according to his works.
23701	945	28	Verily I say unto you, There be some standing here, which shall not taste of death, till they see the Son of man coming in his kingdom.
23702	946	1	AND after six days Jesus taketh Peter, James, and John his brother, and bringeth them up into an high mountain apart,
23703	946	2	And was transfigured before them: and his face did shine as the sun, and his raiment was white as the light.
23704	946	3	And, behold, there appeared unto them Moses and Elias talking with him.
23705	946	4	Then answered Peter, and said unto Jesus, Lord, it is good for us to be here: if thou wilt, let us make here three tabernacles; one for thee, and one for Moses, and one for Elias.
23706	946	5	While he yet spake, behold, a bright cloud overshadowed them: and behold a voice out of the cloud, which said, This is my beloved Son, in whom I am well pleased; hear ye him.
23707	946	6	And when the disciples heard it, they fell on their face, and were sore afraid.
23708	946	7	And Jesus came and touched them, and said, Arise, and be not afraid.
23709	946	8	And when they had lifted up their eyes, they saw no man, save Jesus only.
23710	946	9	And as they came down from the mountain, Jesus charged them, saying, Tell the vision to no man, until the Son of man be risen again from the dead.
23711	946	10	And his disciples asked him, saying, Why then say the scribes that Elias must first come?
23712	946	11	And Jesus answered and said unto them, Elias truly shall first come, and restore all things.
23713	946	12	But I say unto you, That Elias is come already, and they knew him not, but have done unto him whatsoever they listed. Likewise shall also the Son of man suffer of them.
23714	946	13	Then the disciples understood that he spake unto them of John the Baptist.
23715	946	14	And when they were come to the multitude, there came to him a certain man, kneeling down to him, and saying,
23716	946	15	Lord, have mercy on my son: for he is lunatick, and sore vexed: for ofttimes he falleth into the fire, and oft into the water.
23717	946	16	And I brought him to thy disciples, and they could not cure him.
23718	946	17	Then Jesus answered and said, O faithless and perverse generation, how long shall I be with you? how long shall I suffer you? bring him hither to me.
23719	946	18	And Jesus rebuked the devil; and he departed out of him: and the child was cured from that very hour.
23720	946	19	Then came the disciples to Jesus apart, and said, Why could not we cast him out?
23721	946	20	And Jesus said unto them, Because of your unbelief: for verily I say unto you, If ye have faith as a grain of mustard seed, ye shall say unto this mountain, Remove hence to yonder place; and it shall remove; and nothing shall be impossible unto you.
23722	946	21	Howbeit this kind goeth not out but by prayer and fasting.
23723	946	22	And while they abode in Galilee, Jesus said unto them, The Son of man shall be betrayed into the hands of men:
23724	946	23	And they shall kill him, and the third day he shall be raised again. And they were exceeding sorry.
23725	946	24	And when they were come to Capernaum, they that received tribute money came to Peter, and said, Doth not your master pay tribute?
23726	946	25	He saith, Yes. And when he was come into the house, Jesus prevented him, saying, What thinkest thou, Simon? of whom do the kings of the earth take custom or tribute? of their own children, or of strangers?
23727	946	26	Peter saith unto him, Of strangers. Jesus saith unto him, Then are the children free.
23728	946	27	Notwithstanding, lest we should offend them, go thou to the sea, and cast an hook, and take up the fish that first cometh up; and when thou hast opened his mouth, thou shalt find a piece of money: that take, and give unto them for me and thee.
23729	947	1	AT the same time came the disciples unto Jesus, saying, Who is the greatest in the kingdom of heaven?
23730	947	2	And Jesus called a little child unto him, and set him in the midst of them,
23731	947	3	And said, Verily I say unto you, Except ye be converted, and become as little children, ye shall not enter into the kingdom of heaven.
23732	947	4	Whosoever therefore shall humble himself as this little child, the same is greatest in the kingdom of heaven.
23733	947	5	And whoso shall receive one such little child in my name receiveth me.
23734	947	6	But whoso shall offend one of these little ones which believe in me, it were better for him that a millstone were hanged about his neck, and that he were drowned in the depth of the sea.
23735	947	7	Woe unto the world because of offences! for it must needs be that offences come; but woe to that man by whom the offence cometh!
23736	947	8	Wherefore if thy hand or thy foot offend thee, cut them off, and cast them from thee: it is better for thee to enter into life halt or maimed, rather than having two hands or two feet to be cast into everlasting fire.
23737	947	9	And if thine eye offend thee, pluck it out, and cast it from thee: it is better for thee to enter into life with one eye, rather than having two eyes to be cast into hell fire.
23738	947	10	Take heed that ye despise not one of these little ones; for I say unto you, That in heaven their angels do always behold the face of my Father which is in heaven.
23739	947	11	For the Son of man is come to save that which was lost.
23740	947	12	How think ye? if a man have an hundred sheep, and one of them be gone astray, doth he not leave the ninety and nine, and goeth into the mountains, and seeketh that which is gone astray?
23741	947	13	And if so be that he find it, verily I say unto you, he rejoiceth more of that sheep, than of the ninety and nine which went not astray.
23742	947	14	Even so it is not the will of your Father which is in heaven, that one of these little ones should perish.
23743	947	15	Moreover if thy brother shall trespass against thee, go and tell him his fault between thee and him alone: if he shall hear thee, thou hast gained thy brother.
23744	947	16	But if he will not hear thee, then take with thee one or two more, that in the mouth of two or three witnesses every word may be established.
23745	947	17	And if he shall neglect to hear them, tell it unto the church: but if he neglect to hear the church, let him be unto thee as an heathen man and a publican.
23746	947	18	Verily I say unto you, Whatsoever ye shall bind on earth shall be bound in heaven: and whatsoever ye shall loose on earth shall be loosed in heaven.
23747	947	19	Again I say unto you, That if two of you shall agree on earth as touching any thing that they shall ask, it shall be done for them of my Father which is in heaven.
23748	947	20	For where two or three are gathered together in my name, there am I in the midst of them.
23749	947	21	Then came Peter to him, and said, Lord, how oft shall my brother sin against me, and I forgive him? till seven times?
23750	947	22	Jesus saith unto him, I say not unto thee, Until seven times: but, Until seventy times seven.
23751	947	23	Therefore is the kingdom of heaven likened unto a certain king, which would take account of his servants.
23752	947	24	And when he had begun to reckon, one was brought unto him, which owed him ten thousand talents.
23753	947	25	But forasmuch as he had not to pay, his lord commanded him to be sold, and his wife, and children, and all that he had, and payment to be made.
23754	947	26	The servant therefore fell down, and worshipped him, saying, Lord, have patience with me, and I will pay thee all.
23755	947	27	Then the lord of that servant was moved with compassion, and loosed him, and forgave him the debt.
23756	947	28	But the same servant went out, and found one of his fellowservants, which owed him an hundred pence: and he laid hands on him, and took him by the throat, saying, Pay me that thou owest.
23757	947	29	And his fellowservant fell down at his feet, and besought him, saying, Have patience with me, and I will pay thee all.
23758	947	30	And he would not: but went and cast him into prison, till he should pay the debt.
23759	947	31	So when his fellowservants saw what was done, they were very sorry, and came and told unto their lord all that was done.
23760	947	32	Then his lord, after that he had called him, said unto him, O thou wicked servant, I forgave thee all that debt, because thou desiredst me:
23761	947	33	Shouldest not thou also have had compassion on thy fellowservant, even as I had pity on thee?
23762	947	34	And his lord was wroth, and delivered him to the tormentors, till he should pay all that was due unto him.
23763	947	35	So likewise shall my heavenly Father do also unto you, if ye from your hearts forgive not every one his brother their trespasses.
23764	948	1	AND it came to pass, that when Jesus had finished these sayings, he departed from Galilee, and came into the coasts of Judaea beyond Jordan;
23765	948	2	And great multitudes followed him; and he healed them there.
23766	948	3	The Pharisees also came unto him, tempting him, and saying unto him, Is it lawful for a man to put away his wife for every cause?
23767	948	4	And he answered and said unto them, Have ye not read, that he which made them at the beginning made them male and female,
23768	948	5	And said, For this cause shall a man leave father and mother, and shall cleave to his wife: and they twain shall be one flesh?
23769	948	6	Wherefore they are no more twain, but one flesh. What therefore God hath joined together, let not man put asunder.
23770	948	7	They say unto him, Why did Moses then command to give a writing of divorcement, and to put her away?
23771	948	8	He saith unto them, Moses because of the hardness of your hearts suffered you to put away your wives: but from the beginning it was not so.
23772	948	9	And I say unto you, Whosoever shall put away his wife, except it be for fornication, and shall marry another, committeth adultery: and whoso marrieth her which is put away doth commit adultery.
23773	948	10	His disciples say unto him, If the case of the man be so with his wife, it is not good to marry.
23774	948	11	But he said unto them, All men cannot receive this saying, save they to whom it is given.
23775	948	12	For there are some eunuchs, which were so born from their mother's womb: and there are some eunuchs, which were made eunuchs of men: and there be eunuchs, which have made themselves eunuchs for the kingdom of heaven's sake. He that is able to receive it, let him receive it.
23776	948	13	Then were there brought unto him little children, that he should put his hands on them, and pray: and the disciples rebuked them.
23777	948	14	But Jesus said, Suffer little children, and forbid them not, to come unto me: for of such is the kingdom of heaven.
23778	948	15	And he laid his hands on them, and departed thence.
23779	948	16	And, behold, one came and said unto him, Good Master, what good thing shall I do, that I may have eternal life?
23780	948	17	And he said unto him, Why callest thou me good? there is none good but one, that is, God: but if thou wilt enter into life, keep the commandments.
23781	948	18	He saith unto him, Which? Jesus said, Thou shalt do no murder, Thou shalt not commit adultery, Thou shalt not steal, Thou shalt not bear false witness,
23782	948	19	Honour thy father and thy mother: and, Thou shalt love thy neighbour as thyself.
23783	948	20	The young man saith unto him, All these things have I kept from my youth up: what lack I yet?
23784	948	21	Jesus said unto him, If thou wilt be perfect, go and sell that thou hast, and give to the poor, and thou shalt have treasure in heaven: and come and follow me.
23785	948	22	But when the young man heard that saying, he went away sorrowful: for he had great possessions.
23786	948	23	Then said Jesus unto his disciples, Verily I say unto you, That a rich man shall hardly enter into the kingdom of heaven.
23787	948	24	And again I say unto you, It is easier for a camel to go through the eye of a needle, than for a rich man to enter into the kingdom of God.
23788	948	25	When his disciples heard it, they were exceedingly amazed, saying, Who then can be saved?
23789	948	26	But Jesus beheld them, and said unto them, With men this is impossible; but with God all things are possible.
23790	948	27	Then answered Peter and said unto him, Behold, we have forsaken all, and followed thee; what shall we have therefore?
23791	948	28	And Jesus said unto them, Verily I say unto you, That ye which have followed me, in the regeneration when the Son of man shall sit in the throne of his glory, ye also shall sit upon twelve thrones, judging the twelve tribes of Israel.
23792	948	29	And every one that hath forsaken houses, or brethren, or sisters, or father, or mother, or wife, or children, or lands, for my name's sake, shall receive an hundredfold, and shall inherit everlasting life.
23793	948	30	But many that are first shall be last; and the last shall be first.
23794	949	1	FOR the kingdom of heaven is like unto a man that is an householder, which went out early in the morning to hire labourers into his vineyard.
23795	949	2	And when he had agreed with the labourers for a penny a day, he sent them into his vineyard.
23796	949	3	And he went out about the third hour, and saw others standing idle in the marketplace,
23797	949	4	And said unto them; Go ye also into the vineyard, and whatsoever is right I will give you. And they went their way.
23798	949	5	Again he went out about the sixth and ninth hour, and did likewise.
23799	949	6	And about the eleventh hour he went out, and found others standing idle, and saith unto them, Why stand ye here all the day idle?
23800	949	7	They say unto him, Because no man hath hired us. He saith unto them, Go ye also into the vineyard; and whatsoever is right, that shall ye receive.
23801	949	8	So when even was come, the lord of the vineyard saith unto his steward, Call the labourers, and give them their hire, beginning from the last unto the first.
23802	949	9	And when they came that were hired about the eleventh hour, they received every man a penny.
23803	949	10	But when the first came, they supposed that they should have received more; and they likewise received every man a penny.
23804	949	11	And when they had received it, they murmured against the goodman of the house,
23805	949	12	Saying, These last have wrought but one hour, and thou hast made them equal unto us, which have borne the burden and heat of the day.
23806	949	13	But he answered one of them, and said, Friend, I do thee no wrong: didst not thou agree with me for a penny?
23807	949	14	Take that thine is, and go thy way: I will give unto this last, even as unto thee.
23808	949	15	Is it not lawful for me to do what I will with mine own? Is thine eye evil, because I am good?
23809	949	16	So the last shall be first, and the first last: for many be called, but few chosen.
23810	949	17	And Jesus going up to Jerusalem took the twelve disciples apart in the way, and said unto them,
23811	949	18	Behold, we go up to Jerusalem; and the Son of man shall be betrayed unto the chief priests and unto the scribes, and they shall condemn him to death,
23812	949	19	And shall deliver him to the Gentiles to mock, and to scourge, and to crucify him: and the third day he shall rise again.
23813	949	20	Then came to him the mother of Zebedee's children with her sons, worshipping him, and desiring a certain thing of him.
23814	949	21	And he said unto her, What wilt thou? She saith unto him, Grant that these my two sons may sit, the one on thy right hand, and the other on the left, in thy kingdom.
23815	949	22	But Jesus answered and said, Ye know not what ye ask. Are ye able to drink of the cup that I shall drink of, and to be baptized with the baptism that I am baptized with? They say unto him, We are able.
23816	949	23	And he saith unto them, Ye shall drink indeed of my cup, and be baptized with the baptism that I am baptized with: but to sit on my right hand, and on my left, is not mine to give, but it shall be given to them for whom it is prepared of my Father.
23817	949	24	And when the ten heard it, they were moved with indignation against the two brethren.
23818	949	25	But Jesus called them unto him, and said, Ye know that the princes of the Gentiles exercise dominion over them, and they that are great exercise authority upon them.
23819	949	26	But it shall not be so among you: but whosoever will be great among you, let him be your minister;
23820	949	27	And whosoever will be chief among you, let him be your servant:
23821	949	28	Even as the Son of man came not to be ministered unto, but to minister, and to give his life a ransom for many.
23822	949	29	And as they departed from Jericho, a great multitude followed him.
23823	949	30	And, behold, two blind men sitting by the way side, when they heard that Jesus passed by, cried out, saying, Have mercy on us, O Lord, thou Son of David.
23824	949	31	And the multitude rebuked them, because they should hold their peace: but they cried the more, saying, Have mercy on us, O Lord, thou Son of David.
23825	949	32	And Jesus stood still, and called them, and said, What will ye that I shall do unto you?
23826	949	33	They say unto him, Lord, that our eyes may be opened.
23827	949	34	So Jesus had compassion on them, and touched their eyes: and immediately their eyes received sight, and they followed him.
23828	950	1	AND when they drew nigh unto Jerusalem, and were come to Bethphage, unto the mount of Olives, then sent Jesus two disciples,
23829	950	2	Saying unto them, Go into the village over against you, and straightway ye shall find an ass tied, and a colt with her: loose them, and bring them unto me.
23830	950	3	And if any man say ought unto you, ye shall say, The Lord hath need of them; and straightway he will send them.
23831	950	4	All this was done, that it might be fulfilled which was spoken by the prophet, saying,
23832	950	5	Tell ye the daughter of Sion, Behold, thy King cometh unto thee, meek, and sitting upon an ass, and a colt the foal of an ass.
23833	950	6	And the disciples went, and did as Jesus commanded them,
23834	950	7	And brought the ass, and the colt, and put on them their clothes, and they set him thereon.
23835	950	8	And a very great multitude spread their garments in the way; others cut down branches from the trees, and strawed them in the way.
23836	950	9	And the multitudes that went before, and that followed, cried, saying, Hosanna to the Son of David: Blessed is he that cometh in the name of the Lord; Hosanna in the highest.
23837	950	10	And when he was come into Jerusalem, all the city was moved, saying, Who is this?
23838	950	11	And the multitude said, This is Jesus the prophet of Nazareth of Galilee.
23839	950	12	And Jesus went into the temple of God, and cast out all them that sold and bought in the temple, and overthrew the tables of the moneychangers, and the seats of them that sold doves,
23840	950	13	And said unto them, It is written, My house shall be called the house of prayer; but ye have made it a den of thieves.
23841	950	14	And the blind and the lame came to him in the temple; and he healed them.
23842	950	15	And when the chief priests and scribes saw the wonderful things that he did, and the children crying in the temple, and saying, Hosanna to the Son of David; they were sore displeased,
23843	950	16	And said unto him, Hearest thou what these say? And Jesus saith unto them, Yea; have ye never read, Out of the mouth of babes and sucklings thou hast perfected praise?
23844	950	17	And he left them, and went out of the city into Bethany; and he lodged there.
23845	950	18	Now in the morning as he returned into the city, he hungered.
23846	950	19	And when he saw a fig tree in the way, he came to it, and found nothing thereon, but leaves only, and said unto it, Let no fruit grow on thee henceforward for ever. And presently the fig tree withered away.
23847	950	20	And when the disciples saw it, they marvelled, saying, How soon is the fig tree withered away!
23848	950	21	Jesus answered and said unto them, Verily I say unto you, If ye have faith, and doubt not, ye shall not only do this which is done to the fig tree, but also if ye shall say unto this mountain, Be thou removed, and be thou cast into the sea; it shall be done.
23849	950	22	And all things, whatsoever ye shall ask in prayer, believing, ye shall receive.
23850	950	23	And when he was come into the temple, the chief priests and the elders of the people came unto him as he was teaching, and said, By what authority doest thou these things? and who gave thee this authority?
23851	950	24	And Jesus answered and said unto them, I also will ask you one thing, which if ye tell me, I in like wise will tell you by what authority I do these things.
23852	950	25	The baptism of John, whence was it? from heaven, or of men? And they reasoned with themselves, saying, If we shall say, From heaven; he will say unto us, Why did ye not then believe him?
23853	950	26	But if we shall say, Of men; we fear the people; for all hold John as a prophet.
23854	950	27	And they answered Jesus, and said, We cannot tell. And he said unto them, Neither tell I you by what authority I do these things.
23855	950	28	But what think ye? A certain man had two sons; and he came to the first, and said, Son, go work to day in my vineyard.
23856	950	29	He answered and said, I will not: but afterward he repented, and went.
23857	950	30	And he came to the second, and said likewise. And he answered and said, I go, sir: and went not.
23858	950	31	Whether of them twain did the will of his father? They say unto him, The first. Jesus saith unto them, Verily I say unto you, That the publicans and the harlots go into the kingdom of God before you.
23859	950	32	For John came unto you in the way of righteousness, and ye believed him not: but the publicans and the harlots believed him: and ye, when ye had seen it, repented not afterward, that ye might believe him.
23860	950	33	Hear another parable: There was a certain householder, which planted a vineyard, and hedged it round about, and digged a winepress in it, and built a tower, and let it out to husbandmen, and went into a far country:
23861	950	34	And when the time of the fruit drew near, he sent his servants to the husbandmen, that they might receive the fruits of it.
23862	950	35	And the husbandmen took his servants, and beat one, and killed another, and stoned another.
23863	950	36	Again, he sent other servants more than the first: and they did unto them likewise.
23864	950	37	But last of all he sent unto them his son, saying, They will reverence my son.
23865	950	38	But when the husbandmen saw the son, they said among themselves, This is the heir; come, let us kill him, and let us seize on his inheritance.
23866	950	39	And they caught him, and cast him out of the vineyard, and slew him.
23867	950	40	When the lord therefore of the vineyard cometh, what will he do unto those husbandmen?
23868	950	41	They say unto him, He will miserably destroy those wicked men, and will let out his vineyard unto other husbandmen, which shall render him the fruits in their seasons.
23869	950	42	Jesus saith unto them, Did ye never read in the scriptures, The stone which the builders rejected, the same is become the head of the corner: this is the Lord's doing, and it is marvellous in our eyes?
23870	950	43	Therefore say I unto you, The kingdom of God shall be taken from you, and given to a nation bringing forth the fruits thereof.
23871	950	44	And whosoever shall fall on this stone shall be broken: but on whomsoever it shall fall, it will grind him to powder.
23872	950	45	And when the chief priests and Pharisees had heard his parables, they perceived that he spake of them.
23873	950	46	But when they sought to lay hands on him, they feared the multitude, because they took him for a prophet.
23874	951	1	AND Jesus answered and spake unto them again by parables, and said,
23875	951	2	The kingdom of heaven is like unto a certain king, which made a marriage for his son,
23876	951	3	And sent forth his servants to call them that were bidden to the wedding: and they would not come.
23877	951	4	Again, he sent forth other servants, saying, Tell them which are bidden, Behold, I have prepared my dinner: my oxen and my fatlings are killed, and all things are ready: come unto the marriage.
23878	951	5	But they made light of it, and went their ways, one to his farm, another to his merchandise:
23879	951	6	And the remnant took his servants, and entreated them spitefully, and slew them.
23880	951	7	But when the king heard thereof, he was wroth: and he sent forth his armies, and destroyed those murderers, and burned up their city.
23881	951	8	Then saith he to his servants, The wedding is ready, but they which were bidden were not worthy.
23882	951	9	Go ye therefore into the highways, and as many as ye shall find, bid to the marriage.
23883	951	10	So those servants went out into the highways, and gathered together all as many as they found, both bad and good: and the wedding was furnished with guests.
23884	951	11	And when the king came in to see the guests, he saw there a man which had not on a wedding garment:
23885	951	12	And he saith unto him, Friend, how camest thou in hither not having a wedding garment? And he was speechless.
23886	951	13	Then said the king to the servants, Bind him hand and foot, and take him away, and cast him into outer darkness; there shall be weeping and gnashing of teeth.
23887	951	14	For many are called, but few are chosen.
23888	951	15	Then went the Pharisees, and took counsel how they might entangle him in his talk.
23889	951	16	And they sent out unto him their disciples with the Herodians, saying, Master, we know that thou art true, and teachest the way of God in truth, neither carest thou for any man: for thou regardest not the person of men.
23890	951	17	Tell us therefore, What thinkest thou? Is it lawful to give tribute unto Caesar, or not?
23891	951	18	But Jesus perceived their wickedness, and said, Why tempt ye me, ye hypocrites?
23892	951	19	Shew me the tribute money. And they brought unto him a penny.
23893	951	20	And he saith unto them, Whose is this image and superscription?
23894	951	21	They say unto him, Caesar's. Then saith he unto them, Render therefore unto Caesar the things which are Caesar's; and unto God the things that are God's.
23895	951	22	When they had heard these words, they marvelled, and left him, and went their way.
23896	951	23	The same day came to him the Sadducees, which say that there is no resurrection, and asked him,
23897	951	24	Saying, Master, Moses said, If a man die, having no children, his brother shall marry his wife, and raise up seed unto his brother.
23898	951	25	Now there were with us seven brethren: and the first, when he had married a wife, deceased, and, having no issue, left his wife unto his brother:
23899	951	26	Likewise the second also, and the third, unto the seventh.
23900	951	27	And last of all the woman died also.
23901	951	28	Therefore in the resurrection whose wife shall she be of the seven? for they all had her.
23902	951	29	Jesus answered and said unto them, Ye do err, not knowing the scriptures, nor the power of God.
23903	951	30	For in the resurrection they neither marry, nor are given in marriage, but are as the angels of God in heaven.
23904	951	31	But as touching the resurrection of the dead, have ye not read that which was spoken unto you by God, saying,
23905	951	32	I am the God of Abraham, and the God of Isaac, and the God of Jacob? God is not the God of the dead, but of the living.
23906	951	33	And when the multitude heard this, they were astonished at his doctrine.
23907	951	34	But when the Pharisees had heard that he had put the Sadducees to silence, they were gathered together.
23908	951	35	Then one of them, which was a lawyer, asked him a question, tempting him, and saying,
23909	951	36	Master, which is the great commandment in the law?
23910	951	37	Jesus said unto him, Thou shalt love the Lord thy God with all thy heart, and with all thy soul, and with all thy mind.
23911	951	38	This is the first and great commandment.
23912	951	39	And the second is like unto it, Thou shalt love thy neighbour as thyself.
23913	951	40	On these two commandments hang all the law and the prophets.
23914	951	41	While the Pharisees were gathered together, Jesus asked them,
23915	951	42	Saying, What think ye of Christ? whose son is he? They say unto him, The Son of David.
23916	951	43	He saith unto them, How then doth David in spirit call him Lord, saying,
23917	951	44	The LORD said unto my Lord, Sit thou on my right hand, till I make thine enemies thy footstool?
23918	951	45	If David then call him Lord, how is he his son?
23919	951	46	And no man was able to answer him a word, neither durst any man from that day forth ask him any more questions.
23920	952	1	THEN spake Jesus to the multitude, and to his disciples,
23921	952	2	Saying, The scribes and the Pharisees sit in Moses' seat:
23922	952	3	All therefore whatsoever they bid you observe, that observe and do; but do not ye after their works: for they say, and do not.
23923	952	4	For they bind heavy burdens and grievous to be borne, and lay them on men's shoulders; but they themselves will not move them with one of their fingers.
23924	952	5	But all their works they do for to be seen of men: they make broad their phylacteries, and enlarge the borders of their garments,
23925	952	6	And love the uppermost rooms at feasts, and the chief seats in the synagogues,
23926	952	7	And greetings in the markets, and to be called of men, Rabbi, Rabbi.
23927	952	8	But be not ye called Rabbi: for one is your Master, even Christ; and all ye are brethren.
23928	952	9	And call no man your father upon the earth: for one is your Father, which is in heaven.
23929	952	10	Neither be ye called masters: for one is your Master, even Christ.
23930	952	11	But he that is greatest among you shall be your servant.
23931	952	12	And whosoever shall exalt himself shall be abased; and he that shall humble himself shall be exalted.
23932	952	13	But woe unto you, scribes and Pharisees, hypocrites! for ye shut up the kingdom of heaven against men: for ye neither go in yourselves, neither suffer ye them that are entering to go in.
23933	952	14	Woe unto you, scribes and Pharisees, hypocrites! for ye devour widows' houses, and for a pretence make long prayer: therefore ye shall receive the greater damnation.
23934	952	15	Woe unto you, scribes and Pharisees, hypocrites! for ye compass sea and land to make one proselyte, and when he is made, ye make him twofold more the child of hell than yourselves.
23935	952	16	Woe unto you, ye blind guides, which say, Whosoever shall swear by the temple, it is nothing; but whosoever shall swear by the gold of the temple, he is a debtor!
23936	952	17	Ye fools and blind: for whether is greater, the gold, or the temple that sanctifieth the gold?
23937	952	18	And, Whosoever shall swear by the altar, it is nothing; but whosoever sweareth by the gift that is upon it, he is guilty.
23938	952	19	Ye fools and blind: for whether is greater, the gift, or the altar that sanctifieth the gift?
23939	952	20	Whoso therefore shall swear by the altar, sweareth by it, and by all things thereon.
23940	952	21	And whoso shall swear by the temple, sweareth by it, and by him that dwelleth therein.
23941	952	22	And he that shall swear by heaven, sweareth by the throne of God, and by him that sitteth thereon.
23942	952	23	Woe unto you, scribes and Pharisees, hypocrites! for ye pay tithe of mint and anise and cummin, and have omitted the weightier matters of the law, judgment, mercy, and faith: these ought ye to have done, and not to leave the other undone.
23943	952	24	Ye blind guides, which strain at a gnat, and swallow a camel.
23944	952	25	Woe unto you, scribes and Pharisees, hypocrites! for ye make clean the outside of the cup and of the platter, but within they are full of extortion and excess.
23945	952	26	Thou blind Pharisee, cleanse first that which is within the cup and platter, that the outside of them may be clean also.
23946	952	27	Woe unto you, scribes and Pharisees, hypocrites! for ye are like unto whited sepulchres, which indeed appear beautiful outward, but are within full of dead men's bones, and of all uncleanness.
23947	952	28	Even so ye also outwardly appear righteous unto men, but within ye are full of hypocrisy and iniquity.
23948	952	29	Woe unto you, scribes and Pharisees, hypocrites! because ye build the tombs of the prophets, and garnish the sepulchres of the righteous,
23949	952	30	And say, If we had been in the days of our fathers, we would not have been partakers with them in the blood of the prophets.
23950	952	31	Wherefore ye be witnesses unto yourselves, that ye are the children of them which killed the prophets.
23951	952	32	Fill ye up then the measure of your fathers.
23952	952	33	Ye serpents, ye generation of vipers, how can ye escape the damnation of hell?
23953	952	34	Wherefore, behold, I send unto you prophets, and wise men, and scribes: and some of them ye shall kill and crucify; and some of them shall ye scourge in your synagogues, and persecute them from city to city:
23954	952	35	That upon you may come all the righteous blood shed upon the earth, from the blood of righteous Abel unto the blood of Zacharias son of Barachias, whom ye slew between the temple and the altar.
23955	952	36	Verily I say unto you, All these things shall come upon this generation.
23956	952	37	O Jerusalem, Jerusalem, thou that killest the prophets, and stonest them which are sent unto thee, how often would I have gathered thy children together, even as a hen gathereth her chickens under her wings, and ye would not!
23957	952	38	Behold, your house is left unto you desolate.
23958	952	39	For I say unto you, Ye shall not see me henceforth, till ye shall say, Blessed is he that cometh in the name of the Lord.
23959	953	1	AND Jesus went out, and departed from the temple: and his disciples came to him for to shew him the buildings of the temple.
23960	953	2	And Jesus said unto them, See ye not all these things? verily I say unto you, There shall not be left here one stone upon another, that shall not be thrown down.
23961	953	3	And as he sat upon the mount of Olives, the disciples came unto him privately, saying, Tell us, when shall these things be? and what shall be the sign of thy coming, and of the end of the world?
23962	953	4	And Jesus answered and said unto them, Take heed that no man deceive you.
23963	953	5	For many shall come in my name, saying, I am Christ; and shall deceive many.
23964	953	6	And ye shall hear of wars and rumours of wars: see that ye be not troubled: for all these things must come to pass, but the end is not yet.
23965	953	7	For nation shall rise against nation, and kingdom against kingdom: and there shall be famines, and pestilences, and earthquakes, in divers places.
23966	953	8	All these are the beginning of sorrows.
23967	953	9	Then shall they deliver you up to be afflicted, and shall kill you: and ye shall be hated of all nations for my name's sake.
23968	953	10	And then shall many be offended, and shall betray one another, and shall hate one another.
23969	953	11	And many false prophets shall rise, and shall deceive many.
23970	953	12	And because iniquity shall abound, the love of many shall wax cold.
23971	953	13	But he that shall endure unto the end, the same shall be saved.
23972	953	14	And this gospel of the kingdom shall be preached in all the world for a witness unto all nations; and then shall the end come.
23973	953	15	When ye therefore shall see the abomination of desolation, spoken of by Daniel the prophet, stand in the holy place, (whoso readeth, let him understand:)
23974	953	16	Then let them which be in Judaea flee into the mountains:
23975	953	17	Let him which is on the housetop not come down to take any thing out of his house:
23976	953	18	Neither let him which is in the field return back to take his clothes.
23977	953	19	And woe unto them that are with child, and to them that give suck in those days!
23978	953	20	But pray ye that your flight be not in the winter, neither on the sabbath day:
23979	953	21	For then shall be great tribulation, such as was not since the beginning of the world to this time, no, nor ever shall be.
23980	953	22	And except those days should be shortened, there should no flesh be saved: but for the elect's sake those days shall be shortened.
23981	953	23	Then if any man shall say unto you, Lo, here is Christ, or there; believe it not.
23982	953	24	For there shall arise false Christs, and false prophets, and shall shew great signs and wonders; insomuch that, if it were possible, they shall deceive the very elect.
23983	953	25	Behold, I have told you before.
23984	953	26	Wherefore if they shall say unto you, Behold, he is in the desert; go not forth: behold, he is in the secret chambers; believe it not.
23985	953	27	For as the lightning cometh out of the east, and shineth even unto the west; so shall also the coming of the Son of man be.
23986	953	28	For wheresoever the carcase is, there will the eagles be gathered together.
23987	953	29	Immediately after the tribulation of those days shall the sun be darkened, and the moon shall not give her light, and the stars shall fall from heaven, and the powers of the heavens shall be shaken:
23988	953	30	And then shall appear the sign of the Son of man in heaven: and then shall all the tribes of the earth mourn, and they shall see the Son of man coming in the clouds of heaven with power and great glory.
23989	953	31	And he shall send his angels with a great sound of a trumpet, and they shall gather together his elect from the four winds, from one end of heaven to the other.
23990	953	32	Now learn a parable of the fig tree; When his branch is yet tender, and putteth forth leaves, ye know that summer is nigh:
23991	953	33	So likewise ye, when ye shall see all these things, know that it is near, even at the doors.
23992	953	34	Verily I say unto you, This generation shall not pass, till all these things be fulfilled.
23993	953	35	Heaven and earth shall pass away, but my words shall not pass away.
23994	953	36	But of that day and hour knoweth no man, no, not the angels of heaven, but my Father only.
23995	953	37	But as the days of Noe were, so shall also the coming of the Son of man be.
23996	953	38	For as in the days that were before the flood they were eating and drinking, marrying and giving in marriage, until the day that Noe entered into the ark,
23997	953	39	And knew not until the flood came, and took them all away; so shall also the coming of the Son of man be.
23998	953	40	Then shall two be in the field; the one shall be taken, and the other left.
23999	953	41	Two women shall be grinding at the mill; the one shall be taken, and the other left.
24000	953	42	Watch therefore: for ye know not what hour your Lord doth come.
24001	953	43	But know this, that if the goodman of the house had known in what watch the thief would come, he would have watched, and would not have suffered his house to be broken up.
24002	953	44	Therefore be ye also ready: for in such an hour as ye think not the Son of man cometh.
24003	953	45	Who then is a faithful and wise servant, whom his lord hath made ruler over his household, to give them meat in due season?
24004	953	46	Blessed is that servant, whom his lord when he cometh shall find so doing.
24005	953	47	Verily I say unto you, That he shall make him ruler over all his goods.
24006	953	48	But and if that evil servant shall say in his heart, My lord delayeth his coming;
24007	953	49	And shall begin to smite his fellowservants, and to eat and drink with the drunken;
24008	953	50	The lord of that servant shall come in a day when he looketh not for him, and in an hour that he is not aware of,
24009	953	51	And shall cut him asunder, and appoint him his portion with the hypocrites: there shall be weeping and gnashing of teeth.
24010	954	1	THEN shall the kingdom of heaven be likened unto ten virgins, which took their lamps, and went forth to meet the bridegroom.
24011	954	2	And five of them were wise, and five were foolish.
24012	954	3	They that were foolish took their lamps, and took no oil with them:
24013	954	4	But the wise took oil in their vessels with their lamps.
24014	954	5	While the bridegroom tarried, they all slumbered and slept.
24015	954	6	And at midnight there was a cry made, Behold, the bridegroom cometh; go ye out to meet him.
24016	954	7	Then all those virgins arose, and trimmed their lamps.
24017	954	8	And the foolish said unto the wise, Give us of your oil; for our lamps are gone out.
24018	954	9	But the wise answered, saying, Not so; lest there be not enough for us and you: but go ye rather to them that sell, and buy for yourselves.
24019	954	10	And while they went to buy, the bridegroom came; and they that were ready went in with him to the marriage: and the door was shut.
24020	954	11	Afterward came also the other virgins, saying, Lord, Lord, open to us.
24021	954	12	But he answered and said, Verily I say unto you, I know you not.
24022	954	13	Watch therefore, for ye know neither the day nor the hour wherein the Son of man cometh.
24023	954	14	For the kingdom of heaven is as a man travelling into a far country, who called his own servants, and delivered unto them his goods.
24024	954	15	And unto one he gave five talents, to another two, and to another one; to every man according to his several ability; and straightway took his journey.
24025	954	16	Then he that had received the five talents went and traded with the same, and made them other five talents.
24026	954	17	And likewise he that had received two, he also gained other two.
24027	954	18	But he that had received one went and digged in the earth, and hid his lord's money.
24028	954	19	After a long time the lord of those servants cometh, and reckoneth with them.
24029	954	20	And so he that had received five talents came and brought other five talents, saying, Lord, thou deliveredst unto me five talents: behold, I have gained beside them five talents more.
24030	954	21	His lord said unto him, Well done, thou good and faithful servant: thou hast been faithful over a few things, I will make thee ruler over many things: enter thou into the joy of thy lord.
24031	954	22	He also that had received two talents came and said, Lord, thou deliveredst unto me two talents: behold, I have gained two other talents beside them.
24032	954	23	His lord said unto him, Well done, good and faithful servant; thou hast been faithful over a few things, I will make thee ruler over many things: enter thou into the joy of thy lord.
24033	954	24	Then he which had received the one talent came and said, Lord, I knew thee that thou art an hard man, reaping where thou hast not sown, and gathering where thou hast not strawed:
24034	954	25	And I was afraid, and went and hid thy talent in the earth: lo, there thou hast that is thine.
24035	954	26	His lord answered and said unto him, Thou wicked and slothful servant, thou knewest that I reap where I sowed not, and gather where I have not strawed:
24036	954	27	Thou oughtest therefore to have put my money to the exchangers, and then at my coming I should have received mine own with usury.
24037	954	28	Take therefore the talent from him, and give it unto him which hath ten talents.
24038	954	29	For unto every one that hath shall be given, and he shall have abundance: but from him that hath not shall be taken away even that which he hath.
24039	954	30	And cast ye the unprofitable servant into outer darkness: there shall be weeping and gnashing of teeth.
24040	954	31	When the Son of man shall come in his glory, and all the holy angels with him, then shall he sit upon the throne of his glory:
24041	954	32	And before him shall be gathered all nations: and he shall separate them one from another, as a shepherd divideth his sheep from the goats:
24042	954	33	And he shall set the sheep on his right hand, but the goats on the left.
24043	954	34	Then shall the King say unto them on his right hand, Come, ye blessed of my Father, inherit the kingdom prepared for you from the foundation of the world:
24044	954	35	For I was an hungred, and ye gave me meat: I was thirsty, and ye gave me drink: I was a stranger, and ye took me in:
24045	954	36	Naked, and ye clothed me: I was sick, and ye visited me: I was in prison, and ye came unto me.
24046	954	37	Then shall the righteous answer him, saying, Lord, when saw we thee an hungred, and fed thee? or thirsty, and gave thee drink?
24047	954	38	When saw we thee a stranger, and took thee in? or naked, and clothed thee?
24048	954	39	Or when saw we thee sick, or in prison, and came unto thee?
24049	954	40	And the King shall answer and say unto them, Verily I say unto you, Inasmuch as ye have done it unto one of the least of these my brethren, ye have done it unto me.
24050	954	41	Then shall he say also unto them on the left hand, Depart from me, ye cursed, into everlasting fire, prepared for the devil and his angels:
24051	954	42	For I was an hungred, and ye gave me no meat: I was thirsty, and ye gave me no drink:
24052	954	43	I was a stranger, and ye took me not in: naked, and ye clothed me not: sick, and in prison, and ye visited me not.
24053	954	44	Then shall they also answer him, saying, Lord, when saw we thee an hungred, or athirst, or a stranger, or naked, or sick, or in prison, and did not minister unto thee?
24054	954	45	Then shall he answer them, saying, Verily I say unto you, Inasmuch as ye did it not to one of the least of these, ye did it not to me.
24055	954	46	And these shall go away into everlasting punishment: but the righteous into life eternal.
24056	955	1	AND it came to pass, when Jesus had finished all these sayings, he said unto his disciples,
24057	955	2	Ye know that after two days is the feast of the passover, and the Son of man is betrayed to be crucified.
24058	955	3	Then assembled together the chief priests, and the scribes, and the elders of the people, unto the palace of the high priest, who was called Caiaphas,
24059	955	4	And consulted that they might take Jesus by subtilty, and kill him.
24060	955	5	But they said, Not on the feast day, lest there be an uproar among the people.
24061	955	6	Now when Jesus was in Bethany, in the house of Simon the leper,
24062	955	7	There came unto him a woman having an alabaster box of very precious ointment, and poured it on his head, as he sat at meat.
24063	955	8	But when his disciples saw it, they had indignation, saying, To what purpose is this waste?
24064	955	9	For this ointment might have been sold for much, and given to the poor.
24065	955	10	When Jesus understood it, he said unto them, Why trouble ye the woman? for she hath wrought a good work upon me.
24066	955	11	For ye have the poor always with you; but me ye have not always.
24067	955	12	For in that she hath poured this ointment on my body, she did it for my burial.
24068	955	13	Verily I say unto you, Wheresoever this gospel shall be preached in the whole world, there shall also this, that this woman hath done, be told for a memorial of her.
24069	955	14	Then one of the twelve, called Judas Iscariot, went unto the chief priests,
24070	955	15	And said unto them, What will ye give me, and I will deliver him unto you? And they covenanted with him for thirty pieces of silver.
24071	955	16	And from that time he sought opportunity to betray him.
24072	955	17	Now the first day of the feast of unleavened bread the disciples came to Jesus, saying unto him, Where wilt thou that we prepare for thee to eat the passover?
24073	955	18	And he said, Go into the city to such a man, and say unto him, The Master saith, My time is at hand; I will keep the passover at thy house with my disciples.
24074	955	19	And the disciples did as Jesus had appointed them; and they made ready the passover.
24075	955	20	Now when the even was come, he sat down with the twelve.
24076	955	21	And as they did eat, he said, Verily I say unto you, that one of you shall betray me.
24077	955	22	And they were exceeding sorrowful, and began every one of them to say unto him, Lord, is it I?
24078	955	23	And he answered and said, He that dippeth his hand with me in the dish, the same shall betray me.
24079	955	24	The Son of man goeth as it is written of him: but woe unto that man by whom the Son of man is betrayed! it had been good for that man if he had not been born.
24080	955	25	Then Judas, which betrayed him, answered and said, Master, is it I? He said unto him, Thou hast said.
24081	955	26	And as they were eating, Jesus took bread, and blessed it, and brake it, and gave it to the disciples, and said, Take, eat; this is my body.
24082	955	27	And he took the cup, and gave thanks, and gave it to them, saying, Drink ye all of it;
24083	955	28	For this is my blood of the new testament, which is shed for many for the remission of sins.
24084	955	29	But I say unto you, I will not drink henceforth of this fruit of the vine, until that day when I drink it new with you in my Father's kingdom.
24085	955	30	And when they had sung an hymn, they went out into the mount of Olives.
24086	955	31	Then saith Jesus unto them, All ye shall be offended because of me this night: for it is written, I will smite the shepherd, and the sheep of the flock shall be scattered abroad.
24087	955	32	But after I am risen again, I will go before you into Galilee.
24088	955	33	Peter answered and said unto him, Though all men shall be offended because of thee, yet will I never be offended.
24089	955	34	Jesus said unto him, Verily I say unto thee, That this night, before the cock crow, thou shalt deny me thrice.
24090	955	35	Peter said unto him, Though I should die with thee, yet will I not deny thee. Likewise also said all the disciples.
24091	955	36	Then cometh Jesus with them unto a place called Gethsemane, and saith unto the disciples, Sit ye here, while I go and pray yonder.
24092	955	37	And he took with him Peter and the two sons of Zebedee, and began to be sorrowful and very heavy.
24093	955	38	Then saith he unto them, My soul is exceeding sorrowful, even unto death: tarry ye here, and watch with me.
24094	955	39	And he went a little further, and fell on his face, and prayed, saying, O my Father, if it be possible, let this cup pass from me: nevertheless not as I will, but as thou wilt.
24095	955	40	And he cometh unto the disciples, and findeth them asleep, and saith unto Peter, What, could ye not watch with me one hour?
24096	955	41	Watch and pray, that ye enter not into temptation: the spirit indeed is willing, but the flesh is weak.
24097	955	42	He went away again the second time, and prayed, saying, O my Father, if this cup may not pass away from me, except I drink it, thy will be done.
24098	955	43	And he came and found them asleep again: for their eyes were heavy.
24099	955	44	And he left them, and went away again, and prayed the third time, saying the same words.
24100	955	45	Then cometh he to his disciples, and saith unto them, Sleep on now, and take your rest: behold, the hour is at hand, and the Son of man is betrayed into the hands of sinners.
24101	955	46	Rise, let us be going: behold, he is at hand that doth betray me.
24102	955	47	And while he yet spake, lo, Judas, one of the twelve, came, and with him a great multitude with swords and staves, from the chief priests and elders of the people.
24103	955	48	Now he that betrayed him gave them a sign, saying, Whomsoever I shall kiss, that same is he: hold him fast.
24104	955	49	And forthwith he came to Jesus, and said, Hail, master; and kissed him.
24105	955	50	And Jesus said unto him, Friend, wherefore art thou come? Then came they, and laid hands on Jesus, and took him.
24106	955	51	And, behold, one of them which were with Jesus stretched out his hand, and drew his sword, and struck a servant of the high priest's, and smote off his ear.
24107	955	52	Then said Jesus unto him, Put up again thy sword into his place: for all they that take the sword shall perish with the sword.
24108	955	53	Thinkest thou that I cannot now pray to my Father, and he shall presently give me more than twelve legions of angels?
24109	955	54	But how then shall the scriptures be fulfilled, that thus it must be?
24110	955	55	In that same hour said Jesus to the multitudes, Are ye come out as against a thief with swords and staves for to take me? I sat daily with you teaching in the temple, and ye laid no hold on me.
24111	955	56	But all this was done, that the scriptures of the prophets might be fulfilled. Then all the disciples forsook him, and fled.
24112	955	57	And they that had laid hold on Jesus led him away to Caiaphas the high priest, where the scribes and the elders were assembled.
24113	955	58	But Peter followed him afar off unto the high priest's palace, and went in, and sat with the servants, to see the end.
24114	955	59	Now the chief priests, and elders, and all the council, sought false witness against Jesus, to put him to death;
24115	955	60	But found none: yea, though many false witnesses came, yet found they none. At the last came two false witnesses,
24116	955	61	And said, This fellow said, I am able to destroy the temple of God, and to build it in three days.
24117	955	62	And the high priest arose, and said unto him, Answerest thou nothing? what is it which these witness against thee?
24118	955	63	But Jesus held his peace. And the high priest answered and said unto him, I adjure thee by the living God, that thou tell us whether thou be the Christ, the Son of God.
24119	955	64	Jesus saith unto him, Thou hast said: nevertheless I say unto you, Hereafter shall ye see the Son of man sitting on the right hand of power, and coming in the clouds of heaven.
24120	955	65	Then the high priest rent his clothes, saying, He hath spoken blasphemy; what further need have we of witnesses? behold, now ye have heard his blasphemy.
24121	955	66	What think ye? They answered and said, He is guilty of death.
24122	955	67	Then did they spit in his face, and buffeted him; and others smote him with the palms of their hands,
24123	955	68	Saying, Prophesy unto us, thou Christ, Who is he that smote thee?
24124	955	69	Now Peter sat without in the palace: and a damsel came unto him, saying, Thou also wast with Jesus of Galilee.
24125	955	70	But he denied before them all, saying, I know not what thou sayest.
24126	955	71	And when he was gone out into the porch, another maid saw him, and said unto them that were there, This fellow was also with Jesus of Nazareth.
24127	955	72	And again he denied with an oath, I do not know the man.
24128	955	73	And after a while came unto him they that stood by, and said to Peter, Surely thou also art one of them; for thy speech bewrayeth thee.
24129	955	74	Then began he to curse and to swear, saying, I know not the man. And immediately the cock crew.
24130	955	75	And Peter remembered the word of Jesus, which said unto him, Before the cock crow, thou shalt deny me thrice. And he went out, and wept bitterly.
24131	956	1	WHEN the morning was come, all the chief priests and elders of the people took counsel against Jesus to put him to death:
24132	956	2	And when they had bound him, they led him away, and delivered him to Pontius Pilate the governor.
24133	956	3	Then Judas, which had betrayed him, when he saw that he was condemned, repented himself, and brought again the thirty pieces of silver to the chief priests and elders,
24134	956	4	Saying, I have sinned in that I have betrayed the innocent blood. And they said, What is that to us? see thou to that.
24135	956	5	And he cast down the pieces of silver in the temple, and departed, and went and hanged himself.
24136	956	6	And the chief priests took the silver pieces, and said, It is not lawful for to put them into the treasury, because it is the price of blood.
24137	956	7	And they took counsel, and bought with them the potter's field, to bury strangers in.
24138	956	8	Wherefore that field was called, The field of blood, unto this day.
24139	956	9	Then was fulfilled that which was spoken by Jeremy the prophet, saying, And they took the thirty pieces of silver, the price of him that was valued, whom they of the children of Israel did value;
24140	956	10	And gave them for the potter's field, as the Lord appointed me.
24141	956	11	And Jesus stood before the governor: and the governor asked him, saying, Art thou the King of the Jews? And Jesus said unto him, Thou sayest.
24142	956	12	And when he was accused of the chief priests and elders, he answered nothing.
24143	956	13	Then said Pilate unto him, Hearest thou not how many things they witness against thee?
24144	956	14	And he answered him to never a word; insomuch that the governor marvelled greatly.
24145	956	15	Now at that feast the governor was wont to release unto the people a prisoner, whom they would.
24146	956	16	And they had then a notable prisoner, called Barabbas.
24147	956	17	Therefore when they were gathered together, Pilate said unto them, Whom will ye that I release unto you? Barabbas, or Jesus which is called Christ?
24148	956	18	For he knew that for envy they had delivered him.
24149	956	19	When he was set down on the judgment seat, his wife sent unto him, saying, Have thou nothing to do with that just man: for I have suffered many things this day in a dream because of him.
24150	956	20	But the chief priests and elders persuaded the multitude that they should ask Barabbas, and destroy Jesus.
24151	956	21	The governor answered and said unto them, Whether of the twain will ye that I release unto you? They said, Barabbas.
24152	956	22	Pilate saith unto them, What shall I do then with Jesus which is called Christ? They all say unto him, Let him be crucified.
24153	956	23	And the governor said, Why, what evil hath he done? But they cried out the more, saying, Let him be crucified.
24154	956	24	When Pilate saw that he could prevail nothing, but that rather a tumult was made, he took water, and washed his hands before the multitude, saying, I am innocent of the blood of this just person: see ye to it.
24155	956	25	Then answered all the people, and said, His blood be on us, and on our children.
24156	956	26	Then released he Barabbas unto them: and when he had scourged Jesus, he delivered him to be crucified.
24157	956	27	Then the soldiers of the governor took Jesus into the common hall, and gathered unto him the whole band of soldiers.
24158	956	28	And they stripped him, and put on him a scarlet robe.
24159	956	29	And when they had platted a crown of thorns, they put it upon his head, and a reed in his right hand: and they bowed the knee before him, and mocked him, saying, Hail, King of the Jews!
24160	956	30	And they spit upon him, and took the reed, and smote him on the head.
24161	956	31	And after that they had mocked him, they took the robe off from him, and put his own raiment on him, and led him away to crucify him.
24162	956	32	And as they came out, they found a man of Cyrene, Simon by name: him they compelled to bear his cross.
24163	956	33	And when they were come unto a place called Golgotha, that is to say, a place of a skull,
24164	956	34	They gave him vinegar to drink mingled with gall: and when he had tasted thereof, he would not drink.
24165	956	35	And they crucified him, and parted his garments, casting lots: that it might be fulfilled which was spoken by the prophet, They parted my garments among them, and upon my vesture did they cast lots.
24166	956	36	And sitting down they watched him there;
24167	956	37	And set up over his head his accusation written, THIS IS JESUS THE KING OF THE JEWS.
24168	956	38	Then were there two thieves crucified with him, one on the right hand, and another on the left.
24169	956	39	And they that passed by reviled him, wagging their heads,
24170	956	40	And saying, Thou that destroyest the temple, and buildest it in three days, save thyself. If thou be the Son of God, come down from the cross.
24171	956	41	Likewise also the chief priests mocking him, with the scribes and elders, said,
24172	956	42	He saved others; himself he cannot save. If he be the King of Israel, let him now come down from the cross, and we will believe him.
24173	956	43	He trusted in God; let him deliver him now, if he will have him: for he said, I am the Son of God.
24174	956	44	The thieves also, which were crucified with him, cast the same in his teeth.
24175	956	45	Now from the sixth hour there was darkness over all the land unto the ninth hour.
24176	956	46	And about the ninth hour Jesus cried with a loud voice, saying, Eli, Eli, lama sabachthani? that is to say, My God, my God, why hast thou forsaken me?
24177	956	47	Some of them that stood there, when they heard that, said, This man calleth for Elias.
24178	956	48	And straightway one of them ran, and took a spunge, and filled it with vinegar, and put it on a reed, and gave him to drink.
24179	956	49	The rest said, Let be, let us see whether Elias will come to save him.
24180	956	50	Jesus, when he had cried again with a loud voice, yielded up the ghost.
24181	956	51	And, behold, the veil of the temple was rent in twain from the top to the bottom; and the earth did quake, and the rocks rent;
24182	956	52	And the graves were opened; and many bodies of the saints which slept arose,
24183	956	53	And came out of the graves after his resurrection, and went into the holy city, and appeared unto many.
24184	956	54	Now when the centurion, and they that were with him, watching Jesus, saw the earthquake, and those things that were done, they feared greatly, saying, Truly this was the Son of God.
24185	956	55	And many women were there beholding afar off, which followed Jesus from Galilee, ministering unto him:
24186	956	56	Among which was Mary Magdalene, and Mary the mother of James and Joses, and the mother of Zebedee's children.
24187	956	57	When the even was come, there came a rich man of Arimathaea, named Joseph, who also himself was Jesus' disciple:
24188	956	58	He went to Pilate, and begged the body of Jesus. Then Pilate commanded the body to be delivered.
24189	956	59	And when Joseph had taken the body, he wrapped it in a clean linen cloth,
24190	956	60	And laid it in his own new tomb, which he had hewn out in the rock: and he rolled a great stone to the door of the sepulchre, and departed.
24191	956	61	And there was Mary Magdalene, and the other Mary, sitting over against the sepulchre.
24192	956	62	Now the next day, that followed the day of the preparation, the chief priests and Pharisees came together unto Pilate,
24193	956	63	Saying, Sir, we remember that that deceiver said, while he was yet alive, After three days I will rise again.
24194	956	64	Command therefore that the sepulchre be made sure until the third day, lest his disciples come by night, and steal him away, and say unto the people, He is risen from the dead: so the last error shall be worse than the first.
24195	956	65	Pilate said unto them, Ye have a watch: go your way, make it as sure as ye can.
24196	956	66	So they went, and made the sepulchre sure, sealing the stone, and setting a watch.
24197	957	1	IN the end of the sabbath, as it began to dawn toward the first day of the week, came Mary Magdalene and the other Mary to see the sepulchre.
24198	957	2	And, behold, there was a great earthquake: for the angel of the Lord descended from heaven, and came and rolled back the stone from the door, and sat upon it.
24199	957	3	His countenance was like lightning, and his raiment white as snow:
24200	957	4	And for fear of him the keepers did shake, and became as dead men.
24201	957	5	And the angel answered and said unto the women, Fear not ye: for I know that ye seek Jesus, which was crucified.
24202	957	6	He is not here: for he is risen, as he said. Come, see the place where the Lord lay.
24203	957	7	And go quickly, and tell his disciples that he is risen from the dead; and, behold, he goeth before you into Galilee; there shall ye see him: lo, I have told you.
24204	957	8	And they departed quickly from the sepulchre with fear and great joy; and did run to bring his disciples word.
24205	957	9	And as they went to tell his disciples, behold, Jesus met them, saying, All hail. And they came and held him by the feet, and worshipped him.
24206	957	10	Then said Jesus unto them, Be not afraid: go tell my brethren that they go into Galilee, and there shall they see me.
24207	957	11	Now when they were going, behold, some of the watch came into the city, and shewed unto the chief priests all the things that were done.
24208	957	12	And when they were assembled with the elders, and had taken counsel, they gave large money unto the soldiers,
24209	957	13	Saying, Say ye, His disciples came by night, and stole him away while we slept.
24210	957	14	And if this come to the governor's ears, we will persuade him, and secure you.
24211	957	15	So they took the money, and did as they were taught: and this saying is commonly reported among the Jews until this day.
24212	957	16	Then the eleven disciples went away into Galilee, into a mountain where Jesus had appointed them.
24213	957	17	And when they saw him, they worshipped him: but some doubted.
24214	957	18	And Jesus came and spake unto them, saying, All power is given unto me in heaven and in earth.
24215	957	19	Go ye therefore, and teach all nations, baptizing them in the name of the Father, and of the Son, and of the Holy Ghost:
24216	957	20	Teaching them to observe all things whatsoever I have commanded you: and, lo, I am with you alway, even unto the end of the world. Amen.
24217	958	1	THE beginning of the gospel of Jesus Christ, the Son of God;
24218	958	2	As it is written in the prophets, Behold, I send my messenger before thy face, which shall prepare thy way before thee.
24219	958	3	The voice of one crying in the wilderness, Prepare ye the way of the Lord, make his paths straight.
24220	958	4	John did baptize in the wilderness, and preach the baptism of repentance for the remission of sins.
24221	958	5	And there went out unto him all the land of Judaea, and they of Jerusalem, and were all baptized of him in the river of Jordan, confessing their sins.
24222	958	6	And John was clothed with camel's hair, and with a girdle of a skin about his loins; and he did eat locusts and wild honey;
24223	958	7	And preached, saying, There cometh one mightier than I after me, the latchet of whose shoes I am not worthy to stoop down and unloose.
24224	958	8	I indeed have baptized you with water: but he shall baptize you with the Holy Ghost.
24225	958	9	And it came to pass in those days, that Jesus came from Nazareth of Galilee, and was baptized of John in Jordan.
24226	958	10	And straightway coming up out of the water, he saw the heavens opened, and the Spirit like a dove descending upon him:
24227	958	11	And there came a voice from heaven, saying, Thou art my beloved Son, in whom I am well pleased.
24228	958	12	And immediately the Spirit driveth him into the wilderness.
24229	958	13	And he was there in the wilderness forty days, tempted of Satan; and was with the wild beasts; and the angels ministered unto him.
24230	958	14	Now after that John was put in prison, Jesus came into Galilee, preaching the gospel of the kingdom of God,
24231	958	15	And saying, The time is fulfilled, and the kingdom of God is at hand: repent ye, and believe the gospel.
24232	958	16	Now as he walked by the sea of Galilee, he saw Simon and Andrew his brother casting a net into the sea: for they were fishers.
24233	958	17	And Jesus said unto them, Come ye after me, and I will make you to become fishers of men.
24234	958	18	And straightway they forsook their nets, and followed him.
24235	958	19	And when he had gone a little further thence, he saw James the son of Zebedee, and John his brother, who also were in the ship mending their nets.
24236	958	20	And straightway he called them: and they left their father Zebedee in the ship with the hired servants, and went after him.
24237	958	21	And they went into Capernaum; and straightway on the sabbath day he entered into the synagogue, and taught.
24238	958	22	And they were astonished at his doctrine: for he taught them as one that had authority, and not as the scribes.
24239	958	23	And there was in their synagogue a man with an unclean spirit; and he cried out,
24240	958	24	Saying, Let us alone; what have we to do with thee, thou Jesus of Nazareth? art thou come to destroy us? I know thee who thou art, the Holy One of God.
24241	958	25	And Jesus rebuked him, saying, Hold thy peace, and come out of him.
24242	958	26	And when the unclean spirit had torn him, and cried with a loud voice, he came out of him.
24243	958	27	And they were all amazed, insomuch that they questioned among themselves, saying, What thing is this? what new doctrine is this? for with authority commandeth he even the unclean spirits, and they do obey him.
24244	958	28	And immediately his fame spread abroad throughout all the region round about Galilee.
24245	958	29	And forthwith, when they were come out of the synagogue, they entered into the house of Simon and Andrew, with James and John.
24246	958	30	But Simon's wife's mother lay sick of a fever, and anon they tell him of her.
24247	958	31	And he came and took her by the hand, and lifted her up; and immediately the fever left her, and she ministered unto them.
24248	958	32	And at even, when the sun did set, they brought unto him all that were diseased, and them that were possessed with devils.
24249	958	33	And all the city was gathered together at the door.
24250	958	34	And he healed many that were sick of divers diseases, and cast out many devils; and suffered not the devils to speak, because they knew him.
24251	958	35	And in the morning, rising up a great while before day, he went out, and departed into a solitary place, and there prayed.
24252	958	36	And Simon and they that were with him followed after him.
24253	958	37	And when they had found him, they said unto him, All men seek for thee.
24254	958	38	And he said unto them, Let us go into the next towns, that I may preach there also: for therefore came I forth.
24255	958	39	And he preached in their synagogues throughout all Galilee, and cast out devils.
24256	958	40	And there came a leper to him, beseeching him, and kneeling down to him, and saying unto him, If thou wilt, thou canst make me clean.
24257	958	41	And Jesus, moved with compassion, put forth his hand, and touched him, and saith unto him, I will; be thou clean.
24258	958	42	And as soon as he had spoken, immediately the leprosy departed from him, and he was cleansed.
24259	958	43	And he straitly charged him, and forthwith sent him away;
24260	958	44	And saith unto him, See thou say nothing to any man: but go thy way, shew thyself to the priest, and offer for thy cleansing those things which Moses commanded, for a testimony unto them.
24261	958	45	But he went out, and began to publish it much, and to blaze abroad the matter, insomuch that Jesus could no more openly enter into the city, but was without in desert places: and they came to him from every quarter.
24262	959	1	AND again he entered into Capernaum after some days; and it was noised that he was in the house.
24263	959	2	And straightway many were gathered together, insomuch that there was no room to receive them, no, not so much as about the door: and he preached the word unto them.
24264	959	3	And they come unto him, bringing one sick of the palsy, which was borne of four.
24265	959	4	And when they could not come nigh unto him for the press, they uncovered the roof where he was: and when they had broken it up, they let down the bed wherein the sick of the palsy lay.
24266	959	5	When Jesus saw their faith, he said unto the sick of the palsy, Son, thy sins be forgiven thee.
24267	959	6	But there were certain of the scribes sitting there, and reasoning in their hearts,
24268	959	7	Why doth this man thus speak blasphemies? who can forgive sins but God only?
24269	959	8	And immediately when Jesus perceived in his spirit that they so reasoned within themselves, he said unto them, Why reason ye these things in your hearts?
24270	959	9	Whether is it easier to say to the sick of the palsy, Thy sins be forgiven thee; or to say, Arise, and take up thy bed, and walk?
24271	959	10	But that ye may know that the Son of man hath power on earth to forgive sins, (he saith to the sick of the palsy,)
24272	959	11	I say unto thee, Arise, and take up thy bed, and go thy way into thine house.
24273	959	12	And immediately he arose, took up the bed, and went forth before them all; insomuch that they were all amazed, and glorified God, saying, We never saw it on this fashion.
24274	959	13	And he went forth again by the sea side; and all the multitude resorted unto him, and he taught them.
24275	959	14	And as he passed by, he saw Levi the son of Alphaeus sitting at the receipt of custom, and said unto him, Follow me. And he arose and followed him.
24276	959	15	And it came to pass, that, as Jesus sat at meat in his house, many publicans and sinners sat also together with Jesus and his disciples: for there were many, and they followed him.
24277	959	16	And when the scribes and Pharisees saw him eat with publicans and sinners, they said unto his disciples, How is it that he eateth and drinketh with publicans and sinners?
24278	959	17	When Jesus heard it, he saith unto them, They that are whole have no need of the physician, but they that are sick: I came not to call the righteous, but sinners to repentance.
24279	959	18	And the disciples of John and of the Pharisees used to fast: and they come and say unto him, Why do the disciples of John and of the Pharisees fast, but thy disciples fast not?
24280	959	19	And Jesus said unto them, Can the children of the bridechamber fast, while the bridegroom is with them? as long as they have the bridegroom with them, they cannot fast.
24281	959	20	But the days will come, when the bridegroom shall be taken away from them, and then shall they fast in those days.
24282	959	21	No man also seweth a piece of new cloth on an old garment: else the new piece that filled it up taketh away from the old, and the rent is made worse.
24283	959	22	And no man putteth new wine into old bottles: else the new wine doth burst the bottles, and the wine is spilled, and the bottles will be marred: but new wine must be put into new bottles.
24284	959	23	And it came to pass, that he went through the corn fields on the sabbath day; and his disciples began, as they went, to pluck the ears of corn.
24285	959	24	And the Pharisees said unto him, Behold, why do they on the sabbath day that which is not lawful?
24286	959	25	And he said unto them, Have ye never read what David did, when he had need, and was an hungred, he, and they that were with him?
24287	959	26	How he went into the house of God in the days of Abiathar the high priest, and did eat the shewbread, which is not lawful to eat but for the priests, and gave also to them which were with him?
24288	959	27	And he said unto them, The sabbath was made for man, and not man for the sabbath:
24289	959	28	Therefore the Son of man is Lord also of the sabbath.
24290	960	1	AND he entered again into the synagogue; and there was a man there which had a withered hand.
24291	960	2	And they watched him, whether he would heal him on the sabbath day; that they might accuse him.
24292	960	3	And he saith unto the man which had the withered hand, Stand forth.
24293	960	4	And he saith unto them, Is it lawful to do good on the sabbath days, or to do evil? to save life, or to kill? But they held their peace.
24294	960	5	And when he had looked round about on them with anger, being grieved for the hardness of their hearts, he saith unto the man, Stretch forth thine hand. And he stretched it out: and his hand was restored whole as the other.
24295	960	6	And the Pharisees went forth, and straightway took counsel with the Herodians against him, how they might destroy him.
24296	960	7	But Jesus withdrew himself with his disciples to the sea: and a great multitude from Galilee followed him, and from Judaea,
24297	960	8	And from Jerusalem, and from Idumaea, and from beyond Jordan; and they about Tyre and Sidon, a great multitude, when they had heard what great things he did, came unto him.
24298	960	9	And he spake to his disciples, that a small ship should wait on him because of the multitude, lest they should throng him.
24299	960	10	For he had healed many; insomuch that they pressed upon him for to touch him, as many as had plagues.
24300	960	11	And unclean spirits, when they saw him, fell down before him, and cried, saying, Thou art the Son of God.
24301	960	12	And he straitly charged them that they should not make him known.
24302	960	13	And he goeth up into a mountain, and calleth unto him whom he would: and they came unto him.
24303	960	14	And he ordained twelve, that they should be with him, and that he might send them forth to preach,
24304	960	15	And to have power to heal sicknesses, and to cast out devils:
24305	960	16	And Simon he surnamed Peter;
24306	960	17	And James the son of Zebedee, and John the brother of James; and he surnamed them Boanerges, which is, The sons of thunder:
24307	960	18	And Andrew, and Philip, and Bartholomew, and Matthew, and Thomas, and James the son of Alphaeus, and Thaddaeus, and Simon the Canaanite,
24308	960	19	And Judas Iscariot, which also betrayed him: and they went into an house.
24309	960	20	And the multitude cometh together again, so that they could not so much as eat bread.
24310	960	21	And when his friends heard of it, they went out to lay hold on him: for they said, He is beside himself.
24311	960	22	And the scribes which came down from Jerusalem said, He hath Beelzebub, and by the prince of the devils casteth he out devils.
24312	960	23	And he called them unto him, and said unto them in parables, How can Satan cast out Satan?
24313	960	24	And if a kingdom be divided against itself, that kingdom cannot stand.
24314	960	25	And if a house be divided against itself, that house cannot stand.
24315	960	26	And if Satan rise up against himself, and be divided, he cannot stand, but hath an end.
24316	960	27	No man can enter into a strong man's house, and spoil his goods, except he will first bind the strong man; and then he will spoil his house.
24317	960	28	Verily I say unto you, All sins shall be forgiven unto the sons of men, and blasphemies wherewith soever they shall blaspheme:
24318	960	29	But he that shall blaspheme against the Holy Ghost hath never forgiveness, but is in danger of eternal damnation:
24319	960	30	Because they said, He hath an unclean spirit.
24320	960	31	There came then his brethren and his mother, and, standing without, sent unto him, calling him.
24321	960	32	And the multitude sat about him, and they said unto him, Behold, thy mother and thy brethren without seek for thee.
24322	960	33	And he answered them, saying, Who is my mother, or my brethren?
24323	960	34	And he looked round about on them which sat about him, and said, Behold my mother and my brethren!
24324	960	35	For whosoever shall do the will of God, the same is my brother, and my sister, and mother.
24325	961	1	AND he began again to teach by the sea side: and there was gathered unto him a great multitude, so that he entered into a ship, and sat in the sea; and the whole multitude was by the sea on the land.
24326	961	2	And he taught them many things by parables, and said unto them in his doctrine,
24327	961	3	Hearken; Behold, there went out a sower to sow:
24328	961	4	And it came to pass, as he sowed, some fell by the way side, and the fowls of the air came and devoured it up.
24329	961	5	And some fell on stony ground, where it had not much earth; and immediately it sprang up, because it had no depth of earth:
24330	961	6	But when the sun was up, it was scorched; and because it had no root, it withered away.
24331	961	7	And some fell among thorns, and the thorns grew up, and choked it, and it yielded no fruit.
24332	961	8	And other fell on good ground, and did yield fruit that sprang up and increased; and brought forth, some thirty, and some sixty, and some an hundred.
24333	961	9	And he said unto them, He that hath ears to hear, let him hear.
24334	961	10	And when he was alone, they that were about him with the twelve asked of him the parable.
24335	961	11	And he said unto them, Unto you it is given to know the mystery of the kingdom of God: but unto them that are without, all these things are done in parables:
24336	961	12	That seeing they may see, and not perceive; and hearing they may hear, and not understand; lest at any time they should be converted, and their sins should be forgiven them.
24337	961	13	And he said unto them, Know ye not this parable? and how then will ye know all parables?
24338	961	14	The sower soweth the word.
24339	961	15	And these are they by the way side, where the word is sown; but when they have heard, Satan cometh immediately, and taketh away the word that was sown in their hearts.
24340	961	16	And these are they likewise which are sown on stony ground; who, when they have heard the word, immediately receive it with gladness;
24341	961	17	And have no root in themselves, and so endure but for a time: afterward, when affliction or persecution ariseth for the word's sake, immediately they are offended.
24342	961	18	And these are they which are sown among thorns; such as hear the word,
24343	961	19	And the cares of this world, and the deceitfulness of riches, and the lusts of other things entering in, choke the word, and it becometh unfruitful.
24344	961	20	And these are they which are sown on good ground; such as hear the word, and receive it, and bring forth fruit, some thirtyfold, some sixty, and some an hundred.
24345	961	21	And he said unto them, Is a candle brought to be put under a bushel, or under a bed? and not to be set on a candlestick?
24346	961	22	For there is nothing hid, which shall not be manifested; neither was any thing kept secret, but that it should come abroad.
24347	961	23	If any man have ears to hear, let him hear.
24348	961	24	And he said unto them, Take heed what ye hear: with what measure ye mete, it shall be measured to you: and unto you that hear shall more be given.
24349	961	25	For he that hath, to him shall be given: and he that hath not, from him shall be taken even that which he hath.
24350	961	26	And he said, So is the kingdom of God, as if a man should cast seed into the ground;
24351	961	27	And should sleep, and rise night and day, and the seed should spring and grow up, he knoweth not how.
24352	961	28	For the earth bringeth forth fruit of herself; first the blade, then the ear, after that the full corn in the ear.
24353	961	29	But when the fruit is brought forth, immediately he putteth in the sickle, because the harvest is come.
24354	961	30	And he said, Whereunto shall we liken the kingdom of God? or with what comparison shall we compare it?
24355	961	31	It is like a grain of mustard seed, which, when it is sown in the earth, is less than all the seeds that be in the earth:
24356	961	32	But when it is sown, it groweth up, and becometh greater than all herbs, and shooteth out great branches; so that the fowls of the air may lodge under the shadow of it.
24357	961	33	And with many such parables spake he the word unto them, as they were able to hear it.
24358	961	34	But without a parable spake he not unto them: and when they were alone, he expounded all things to his disciples.
24359	961	35	And the same day, when the even was come, he saith unto them, Let us pass over unto the other side.
24360	961	36	And when they had sent away the multitude, they took him even as he was in the ship. And there were also with him other little ships.
24361	961	37	And there arose a great storm of wind, and the waves beat into the ship, so that it was now full.
24362	961	38	And he was in the hinder part of the ship, asleep on a pillow: and they awake him, and say unto him, Master, carest thou not that we perish?
24363	961	39	And he arose, and rebuked the wind, and said unto the sea, Peace, be still. And the wind ceased, and there was a great calm.
24364	961	40	And he said unto them, Why are ye so fearful? how is it that ye have no faith?
24365	961	41	And they feared exceedingly, and said one to another, What manner of man is this, that even the wind and the sea obey him?
24366	962	1	AND they came over unto the other side of the sea, into the country of the Gadarenes.
24367	962	2	And when he was come out of the ship, immediately there met him out of the tombs a man with an unclean spirit,
24368	962	3	Who had his dwelling among the tombs; and no man could bind him, no, not with chains:
24369	962	4	Because that he had been often bound with fetters and chains, and the chains had been plucked asunder by him, and the fetters broken in pieces: neither could any man tame him.
24370	962	5	And always, night and day, he was in the mountains, and in the tombs, crying, and cutting himself with stones.
24371	962	6	But when he saw Jesus afar off, he ran and worshipped him,
24372	962	7	And cried with a loud voice, and said, What have I to do with thee, Jesus, thou Son of the most high God? I adjure thee by God, that thou torment me not.
24373	962	8	For he said unto him, Come out of the man, thou unclean spirit.
24374	962	9	And he asked him, What is thy name? And he answered, saying, My name is Legion: for we are many.
24375	962	10	And he besought him much that he would not send them away out of the country.
24376	962	11	Now there was there nigh unto the mountains a great herd of swine feeding.
24377	962	12	And all the devils besought him, saying, Send us into the swine, that we may enter into them.
24378	962	13	And forthwith Jesus gave them leave. And the unclean spirits went out, and entered into the swine: and the herd ran violently down a steep place into the sea, (they were about two thousand;) and were choked in the sea.
24379	962	14	And they that fed the swine fled, and told it in the city, and in the country. And they went out to see what it was that was done.
24380	962	15	And they come to Jesus, and see him that was possessed with the devil, and had the legion, sitting, and clothed, and in his right mind: and they were afraid.
24381	962	16	And they that saw it told them how it befell to him that was possessed with the devil, and also concerning the swine.
24382	962	17	And they began to pray him to depart out of their coasts.
24383	962	18	And when he was come into the ship, he that had been possessed with the devil prayed him that he might be with him.
24384	962	19	Howbeit Jesus suffered him not, but saith unto him, Go home to thy friends, and tell them how great things the Lord hath done for thee, and hath had compassion on thee.
24385	962	20	And he departed, and began to publish in Decapolis how great things Jesus had done for him: and all men did marvel.
24386	962	21	And when Jesus was passed over again by ship unto the other side, much people gathered unto him: and he was nigh unto the sea.
24387	962	22	And, behold, there cometh one of the rulers of the synagogue, Jairus by name; and when he saw him, he fell at his feet,
24388	962	23	And besought him greatly, saying, My little daughter lieth at the point of death: I pray thee, come and lay thy hands on her, that she may be healed; and she shall live.
24389	962	24	And Jesus went with him; and much people followed him, and thronged him.
24390	962	25	And a certain woman, which had an issue of blood twelve years,
24391	962	26	And had suffered many things of many physicians, and had spent all that she had, and was nothing bettered, but rather grew worse,
24392	962	27	When she had heard of Jesus, came in the press behind, and touched his garment.
24393	962	28	For she said, If I may touch but his clothes, I shall be whole.
24394	962	29	And straightway the fountain of her blood was dried up; and she felt in her body that she was healed of that plague.
24395	962	30	And Jesus, immediately knowing in himself that virtue had gone out of him, turned him about in the press, and said, Who touched my clothes?
24396	962	31	And his disciples said unto him, Thou seest the multitude thronging thee, and sayest thou, Who touched me?
24397	962	32	And he looked round about to see her that had done this thing.
24398	962	33	But the woman fearing and trembling, knowing what was done in her, came and fell down before him, and told him all the truth.
24399	962	34	And he said unto her, Daughter, thy faith hath made thee whole; go in peace, and be whole of thy plague.
24400	962	35	While he yet spake, there came from the ruler of the synagogue's house certain which said, Thy daughter is dead: why troublest thou the Master any further?
24401	962	36	As soon as Jesus heard the word that was spoken, he saith unto the ruler of the synagogue, Be not afraid, only believe.
24402	962	37	And he suffered no man to follow him, save Peter, and James, and John the brother of James.
24403	962	38	And he cometh to the house of the ruler of the synagogue, and seeth the tumult, and them that wept and wailed greatly.
24404	962	39	And when he was come in, he saith unto them, Why make ye this ado, and weep? the damsel is not dead, but sleepeth.
24405	962	40	And they laughed him to scorn. But when he had put them all out, he taketh the father and the mother of the damsel, and them that were with him, and entereth in where the damsel was lying.
24406	962	41	And he took the damsel by the hand, and said unto her, Talitha cumi; which is, being interpreted, Damsel, I say unto thee, arise.
24407	962	42	And straightway the damsel arose, and walked; for she was of the age of twelve years. And they were astonished with a great astonishment.
24408	962	43	And he charged them straitly that no man should know it; and commanded that something should be given her to eat.
24409	963	1	AND he went out from thence, and came into his own country; and his disciples follow him.
24410	963	2	And when the sabbath day was come, he began to teach in the synagogue: and many hearing him were astonished, saying, From whence hath this man these things? and what wisdom is this which is given unto him, that even such mighty works are wrought by his hands?
24411	963	3	Is not this the carpenter, the son of Mary, the brother of James, and Joses, and of Juda, and Simon? and are not his sisters here with us? And they were offended at him.
24412	963	4	But Jesus said unto them, A prophet is not without honour, but in his own country, and among his own kin, and in his own house.
24413	963	5	And he could there do no mighty work, save that he laid his hands upon a few sick folk, and healed them.
24414	963	6	And he marvelled because of their unbelief. And he went round about the villages, teaching.
24415	963	7	And he called unto him the twelve, and began to send them forth by two and two; and gave them power over unclean spirits;
24416	963	8	And commanded them that they should take nothing for their journey, save a staff only; no scrip, no bread, no money in their purse:
24417	963	9	But be shod with sandals; and not put on two coats.
24418	963	10	And he said unto them, In what place soever ye enter into an house, there abide till ye depart from that place.
24419	963	11	And whosoever shall not receive you, nor hear you, when ye depart thence, shake off the dust under your feet for a testimony against them. Verily I say unto you, It shall be more tolerable for Sodom and Gomorrha in the day of judgment, than for that city.
24420	963	12	And they went out, and preached that men should repent.
24421	963	13	And they cast out many devils, and anointed with oil many that were sick, and healed them.
24422	963	14	And king Herod heard of him; (for his name was spread abroad:) and he said, That John the Baptist was risen from the dead, and therefore mighty works do shew forth themselves in him.
24423	963	15	Others said, That it is Elias. And others said, That it is a prophet, or as one of the prophets.
24424	963	16	But when Herod heard thereof, he said, It is John, whom I beheaded: he is risen from the dead.
24425	963	17	For Herod himself had sent forth and laid hold upon John, and bound him in prison for Herodias' sake, his brother Philip's wife: for he had married her.
24426	963	18	For John had said unto Herod, It is not lawful for thee to have thy brother's wife.
24427	963	19	Therefore Herodias had a quarrel against him, and would have killed him; but she could not:
24428	963	20	For Herod feared John, knowing that he was a just man and an holy, and observed him; and when he heard him, he did many things, and heard him gladly.
24429	963	21	And when a convenient day was come, that Herod on his birthday made a supper to his lords, high captains, and chief estates of Galilee;
24430	963	22	And when the daughter of the said Herodias came in, and danced, and pleased Herod and them that sat with him, the king said unto the damsel, Ask of me whatsoever thou wilt, and I will give it thee.
24431	963	23	And he sware unto her, Whatsoever thou shalt ask of me, I will give it thee, unto the half of my kingdom.
24432	963	24	And she went forth, and said unto her mother, What shall I ask? And she said, The head of John the Baptist.
24433	963	25	And she came in straightway with haste unto the king, and asked, saying, I will that thou give me by and by in a charger the head of John the Baptist.
24434	963	26	And the king was exceeding sorry; yet for his oath's sake, and for their sakes which sat with him, he would not reject her.
24435	963	27	And immediately the king sent an executioner, and commanded his head to be brought: and he went and beheaded him in the prison,
24436	963	28	And brought his head in a charger, and gave it to the damsel: and the damsel gave it to her mother.
24437	963	29	And when his disciples heard of it, they came and took up his corpse, and laid it in a tomb.
24438	963	30	And the apostles gathered themselves together unto Jesus, and told him all things, both what they had done, and what they had taught.
24439	963	31	And he said unto them, Come ye yourselves apart into a desert place, and rest a while: for there were many coming and going, and they had no leisure so much as to eat.
24440	963	32	And they departed into a desert place by ship privately.
24441	963	33	And the people saw them departing, and many knew him, and ran afoot thither out of all cities, and outwent them, and came together unto him.
24442	963	34	And Jesus, when he came out, saw much people, and was moved with compassion toward them, because they were as sheep not having a shepherd: and he began to teach them many things.
24443	963	35	And when the day was now far spent, his disciples came unto him, and said, This is a desert place, and now the time is far passed:
24444	963	36	Send them away, that they may go into the country round about, and into the villages, and buy themselves bread: for they have nothing to eat.
24445	963	37	He answered and said unto them, Give ye them to eat. And they say unto him, Shall we go and buy two hundred pennyworth of bread, and give them to eat?
24446	963	38	He saith unto them, How many loaves have ye? go and see. And when they knew, they say, Five, and two fishes.
24447	963	39	And he commanded them to make all sit down by companies upon the green grass.
24448	963	40	And they sat down in ranks, by hundreds, and by fifties.
24449	963	41	And when he had taken the five loaves and the two fishes, he looked up to heaven, and blessed, and brake the loaves, and gave them to his disciples to set before them; and the two fishes divided he among them all.
24450	963	42	And they did all eat, and were filled.
24451	963	43	And they took up twelve baskets full of the fragments, and of the fishes.
24452	963	44	And they that did eat of the loaves were about five thousand men.
24453	963	45	And straightway he constrained his disciples to get into the ship, and to go to the other side before unto Bethsaida, while he sent away the people.
24454	963	46	And when he had sent them away, he departed into a mountain to pray.
24455	963	47	And when even was come, the ship was in the midst of the sea, and he alone on the land.
24456	963	48	And he saw them toiling in rowing; for the wind was contrary unto them: and about the fourth watch of the night he cometh unto them, walking upon the sea, and would have passed by them.
24457	963	49	But when they saw him walking upon the sea, they supposed it had been a spirit, and cried out:
24458	963	50	For they all saw him, and were troubled. And immediately he talked with them, and saith unto them, Be of good cheer: it is I; be not afraid.
24459	963	51	And he went up unto them into the ship; and the wind ceased: and they were sore amazed in themselves beyond measure, and wondered.
24460	963	52	For they considered not the miracle of the loaves: for their heart was hardened.
24461	963	53	And when they had passed over, they came into the land of Gennesaret, and drew to the shore.
24462	963	54	And when they were come out of the ship, straightway they knew him,
24463	963	55	And ran through that whole region round about, and began to carry about in beds those that were sick, where they heard he was.
24464	963	56	And whithersoever he entered, into villages, or cities, or country, they laid the sick in the streets, and besought him that they might touch if it were but the border of his garment: and as many as touched him were made whole.
24465	964	1	THEN came together unto him the Pharisees, and certain of the scribes, which came from Jerusalem.
24466	964	2	And when they saw some of his disciples eat bread with defiled, that is to say, with unwashen, hands, they found fault.
24467	964	3	For the Pharisees, and all the Jews, except they wash their hands oft, eat not, holding the tradition of the elders.
24468	964	4	And when they come from the market, except they wash, they eat not. And many other things there be, which they have received to hold, as the washing of cups, and pots, brasen vessels, and of tables.
24469	964	5	Then the Pharisees and scribes asked him, Why walk not thy disciples according to the tradition of the elders, but eat bread with unwashen hands?
24470	964	6	He answered and said unto them, Well hath Esaias prophesied of you hypocrites, as it is written, This people honoureth me with their lips, but their heart is far from me.
24471	964	7	Howbeit in vain do they worship me, teaching for doctrines the commandments of men.
24472	964	8	For laying aside the commandment of God, ye hold the tradition of men, as the washing of pots and cups: and many other such like things ye do.
24473	964	9	And he said unto them, Full well ye reject the commandment of God, that ye may keep your own tradition.
24474	964	10	For Moses said, Honour thy father and thy mother; and, Whoso curseth father or mother, let him die the death:
24475	964	11	But ye say, If a man shall say to his father or mother, It is Corban, that is to say, a gift, by whatsoever thou mightest be profited by me; he shall be free.
24476	964	12	And ye suffer him no more to do ought for his father or his mother;
24477	964	13	Making the word of God of none effect through your tradition, which ye have delivered: and many such like things do ye.
24478	964	14	And when he had called all the people unto him, he said unto them, Hearken unto me every one of you, and understand:
24479	964	15	There is nothing from without a man, that entering into him can defile him: but the things which come out of him, those are they that defile the man.
24480	964	16	If any man have ears to hear, let him hear.
24481	964	17	And when he was entered into the house from the people, his disciples asked him concerning the parable.
24482	964	18	And he saith unto them, Are ye so without understanding also? Do ye not perceive, that whatsoever thing from without entereth into the man, it cannot defile him;
24483	964	19	Because it entereth not into his heart, but into the belly, and goeth out into the draught, purging all meats?
24484	964	20	And he said, That which cometh out of the man, that defileth the man.
24485	964	21	For from within, out of the heart of men, proceed evil thoughts, adulteries, fornications, murders,
24486	964	22	Thefts, covetousness, wickedness, deceit, lasciviousness, an evil eye, blasphemy, pride, foolishness:
24487	964	23	All these evil things come from within, and defile the man.
24488	964	24	And from thence he arose, and went into the borders of Tyre and Sidon, and entered into an house, and would have no man know it: but he could not be hid.
24489	964	25	For a certain woman, whose young daughter had an unclean spirit, heard of him, and came and fell at his feet:
24490	964	26	The woman was a Greek, a Syrophenician by nation; and she besought him that he would cast forth the devil out of her daughter.
24491	964	27	But Jesus said unto her, Let the children first be filled: for it is not meet to take the children's bread, and to cast it unto the dogs.
24492	964	28	And she answered and said unto him, Yes, Lord: yet the dogs under the table eat of the children's crumbs.
24493	964	29	And he said unto her, For this saying go thy way; the devil is gone out of thy daughter.
24494	964	30	And when she was come to her house, she found the devil gone out, and her daughter laid upon the bed.
24495	964	31	And again, departing from the coasts of Tyre and Sidon, he came unto the sea of Galilee, through the midst of the coasts of Decapolis.
24496	964	32	And they bring unto him one that was deaf, and had an impediment in his speech; and they beseech him to put his hand upon him.
24497	964	33	And he took him aside from the multitude, and put his fingers into his ears, and he spit, and touched his tongue;
24498	964	34	And looking up to heaven, he sighed, and saith unto him, Ephphatha, that is, Be opened.
24499	964	35	And straightway his ears were opened, and the string of his tongue was loosed, and he spake plain.
24500	964	36	And he charged them that they should tell no man: but the more he charged them, so much the more a great deal they published it;
24501	964	37	And were beyond measure astonished, saying, He hath done all things well: he maketh both the deaf to hear, and the dumb to speak.
24502	965	1	IN those days the multitude being very great, and having nothing to eat, Jesus called his disciples unto him, and saith unto them,
24503	965	2	I have compassion on the multitude, because they have now been with me three days, and have nothing to eat:
24504	965	3	And if I send them away fasting to their own houses, they will faint by the way: for divers of them came from far.
24505	965	4	And his disciples answered him, From whence can a man satisfy these men with bread here in the wilderness?
24506	965	5	And he asked them, How many loaves have ye? And they said, Seven.
24507	965	6	And he commanded the people to sit down on the ground: and he took the seven loaves, and gave thanks, and brake, and gave to his disciples to set before them; and they did set them before the people.
24508	965	7	And they had a few small fishes: and he blessed, and commanded to set them also before them.
24509	965	8	So they did eat, and were filled: and they took up of the broken meat that was left seven baskets.
24510	965	9	And they that had eaten were about four thousand: and he sent them away.
24511	965	10	And straightway he entered into a ship with his disciples, and came into the parts of Dalmanutha.
24512	965	11	And the Pharisees came forth, and began to question with him, seeking of him a sign from heaven, tempting him.
24513	965	12	And he sighed deeply in his spirit, and saith, Why doth this generation seek after a sign? verily I say unto you, There shall no sign be given unto this generation.
24514	965	13	And he left them, and entering into the ship again departed to the other side.
24515	965	14	Now the disciples had forgotten to take bread, neither had they in the ship with them more than one loaf.
24516	965	15	And he charged them, saying, Take heed, beware of the leaven of the Pharisees, and of the leaven of Herod.
24517	965	16	And they reasoned among themselves, saying, It is because we have no bread.
24518	965	17	And when Jesus knew it, he saith unto them, Why reason ye, because ye have no bread? perceive ye not yet, neither understand? have ye your heart yet hardened?
24519	965	18	Having eyes, see ye not? and having ears, hear ye not? and do ye not remember?
24520	965	19	When I brake the five loaves among five thousand, how many baskets full of fragments took ye up? They say unto him, Twelve.
24521	965	20	And when the seven among four thousand, how many baskets full of fragments took ye up? And they said, Seven.
24522	965	21	And he said unto them, How is it that ye do not understand?
24523	965	22	And he cometh to Bethsaida; and they bring a blind man unto him, and besought him to touch him.
24524	965	23	And he took the blind man by the hand, and led him out of the town; and when he had spit on his eyes, and put his hands upon him, he asked him if he saw ought.
24525	965	24	And he looked up, and said, I see men as trees, walking.
24526	965	25	After that he put his hands again upon his eyes, and made him look up: and he was restored, and saw every man clearly.
24527	965	26	And he sent him away to his house, saying, Neither go into the town, nor tell it to any in the town.
24528	965	27	And Jesus went out, and his disciples, into the towns of Caesarea Philippi: and by the way he asked his disciples, saying unto them, Whom do men say that I am?
24529	965	28	And they answered, John the Baptist: but some say, Elias; and others, One of the prophets.
24530	965	29	And he saith unto them, But whom say ye that I am? And Peter answereth and saith unto him, Thou art the Christ.
24531	965	30	And he charged them that they should tell no man of him.
24532	965	31	And he began to teach them, that the Son of man must suffer many things, and be rejected of the elders, and of the chief priests, and scribes, and be killed, and after three days rise again.
24533	965	32	And he spake that saying openly. And Peter took him, and began to rebuke him.
24534	965	33	But when he had turned about and looked on his disciples, he rebuked Peter, saying, Get thee behind me, Satan: for thou savourest not the things that be of God, but the things that be of men.
24535	965	34	And when he had called the people unto him with his disciples also, he said unto them, Whosoever will come after me, let him deny himself, and take up his cross, and follow me.
24536	965	35	For whosoever will save his life shall lose it; but whosoever shall lose his life for my sake and the gospel's, the same shall save it.
24537	965	36	For what shall it profit a man, if he shall gain the whole world, and lose his own soul?
24538	965	37	Or what shall a man give in exchange for his soul?
24539	965	38	Whosoever therefore shall be ashamed of me and of my words in this adulterous and sinful generation; of him also shall the Son of man be ashamed, when he cometh in the glory of his Father with the holy angels.
24540	966	1	AND he said unto them, Verily I say unto you, That there be some of them that stand here, which shall not taste of death, till they have seen the kingdom of God come with power.
24541	966	2	And after six days Jesus taketh with him Peter, and James, and John, and leadeth them up into an high mountain apart by themselves: and he was transfigured before them.
24542	966	3	And his raiment became shining, exceeding white as snow; so as no fuller on earth can white them.
24543	966	4	And there appeared unto them Elias with Moses: and they were talking with Jesus.
24544	966	5	And Peter answered and said to Jesus, Master, it is good for us to be here: and let us make three tabernacles; one for thee, and one for Moses, and one for Elias.
24545	966	6	For he wist not what to say; for they were sore afraid.
24546	966	7	And there was a cloud that overshadowed them: and a voice came out of the cloud, saying, This is my beloved Son: hear him.
24547	966	8	And suddenly, when they had looked round about, they saw no man any more, save Jesus only with themselves.
24548	966	9	And as they came down from the mountain, he charged them that they should tell no man what things they had seen, till the Son of man were risen from the dead.
24549	966	10	And they kept that saying with themselves, questioning one with another what the rising from the dead should mean.
24550	966	11	And they asked him, saying, Why say the scribes that Elias must first come?
24551	966	12	And he answered and told them, Elias verily cometh first, and restoreth all things; and how it is written of the Son of man, that he must suffer many things, and be set at nought.
24552	966	13	But I say unto you, That Elias is indeed come, and they have done unto him whatsoever they listed, as it is written of him.
24553	966	14	And when he came to his disciples, he saw a great multitude about them, and the scribes questioning with them.
24554	966	15	And straightway all the people, when they beheld him, were greatly amazed and, running to him saluted him.
24555	966	16	And he asked the scribes, What question ye with them?
24556	966	17	And one of the multitude answered and said, Master, I have brought unto thee my son, which hath a dumb spirit;
24557	966	18	And wheresoever he taketh him, he teareth him: and he foameth, and gnasheth with his teeth, and pineth away: and I spake to thy disciples that they should cast him out; and they could not.
24558	966	19	He answereth him, and saith, O faithless generation, how long shall I be with you? how long shall I suffer you? bring him unto me.
24559	966	20	And they brought him unto him: and when he saw him, straightway the spirit tare him; and he fell on the ground, and wallowed foaming.
24560	966	21	And he asked his father, How long is it ago since this came unto him? And he said, Of a child.
24561	966	22	And ofttimes it hath cast him into the fire, and into the waters, to destroy him: but if thou canst do any thing, have compassion on us, and help us.
24562	966	23	Jesus said unto him, If thou canst believe, all things are possible to him that believeth.
24563	966	24	And straightway the father of the child cried out, and said with tears, Lord, I believe; help thou mine unbelief.
24564	966	25	When Jesus saw that the people came running together, he rebuked the foul spirit, saying unto him, Thou dumb and deaf spirit, I charge thee, come out of him, and enter no more into him.
24565	966	26	And the spirit cried, and rent him sore, and came out of him: and he was as one dead; insomuch that many said, He is dead.
24566	966	27	But Jesus took him by the hand, and lifted him up; and he arose.
24567	966	28	And when he was come into the house, his disciples asked him privately, Why could not we cast him out?
24568	966	29	And he said unto them, This kind can come forth by nothing, but by prayer and fasting.
24569	966	30	And they departed thence, and passed through Galilee; and he would not that any man should know it.
24570	966	31	For he taught his disciples, and said unto them, The Son of man is delivered into the hands of men, and they shall kill him; and after that he is killed, he shall rise the third day.
24571	966	32	But they understood not that saying, and were afraid to ask him.
24572	966	33	And he came to Capernaum: and being in the house he asked them, What was it that ye disputed among yourselves by the way?
24573	966	34	But they held their peace: for by the way they had disputed among themselves, who should be the greatest.
24574	966	35	And he sat down, and called the twelve, and saith unto them, If any man desire to be first, the same shall be last of all, and servant of all.
24575	966	36	And he took a child, and set him in the midst of them: and when he had taken him in his arms, he said unto them,
24576	966	37	Whosoever shall receive one of such children in my name, receiveth me: and whosoever shall receive me, receiveth not me, but him that sent me.
24577	966	38	And John answered him, saying, Master, we saw one casting out devils in thy name, and he followeth not us: and we forbad him, because he followeth not us.
24578	966	39	But Jesus said, Forbid him not: for there is no man which shall do a miracle in my name, that can lightly speak evil of me.
24579	966	40	For he that is not against us is on our part.
24580	966	41	For whosoever shall give you a cup of water to drink in my name, because ye belong to Christ, verily I say unto you, he shall not lose his reward.
24581	966	42	And whosoever shall offend one of these little ones that believe in me, it is better for him that a millstone were hanged about his neck, and he were cast into the sea.
24582	966	43	And if thy hand offend thee, cut it off: it is better for thee to enter into life maimed, than having two hands to go into hell, into the fire that never shall be quenched:
24583	966	44	Where their worm dieth not, and the fire is not quenched.
24584	966	45	And if thy foot offend thee, cut it off: it is better for thee to enter halt into life, than having two feet to be cast into hell, into the fire that never shall be quenched:
24585	966	46	Where their worm dieth not, and the fire is not quenched.
24586	966	47	And if thine eye offend thee, pluck it out: it is better for thee to enter into the kingdom of God with one eye, than having two eyes to be cast into hell fire:
24587	966	48	Where their worm dieth not, and the fire is not quenched.
24588	966	49	For every one shall be salted with fire, and every sacrifice shall be salted with salt.
24589	966	50	Salt is good: but if the salt have lost his saltness, wherewith will ye season it? Have salt in yourselves, and have peace one with another.
24590	967	1	AND he arose from thence, and cometh into the coasts of Judaea by the farther side of Jordan: and the people resort unto him again; and, as he was wont, he taught them again.
24591	967	2	And the Pharisees came to him, and asked him, Is it lawful for a man to put away his wife? tempting him.
24592	967	3	And he answered and said unto them, What did Moses command you?
24593	967	4	And they said, Moses suffered to write a bill of divorcement, and to put her away.
24594	967	5	And Jesus answered and said unto them, For the hardness of your heart he wrote you this precept.
24595	967	6	But from the beginning of the creation God made them male and female.
24596	967	7	For this cause shall a man leave his father and mother, and cleave to his wife;
24597	967	8	And they twain shall be one flesh: so then they are no more twain, but one flesh.
24598	967	9	What therefore God hath joined together, let not man put asunder.
24599	967	10	And in the house his disciples asked him again of the same matter.
24600	967	11	And he saith unto them, Whosoever shall put away his wife, and marry another, committeth adultery against her.
24601	967	12	And if a woman shall put away her husband, and be married to another, she committeth adultery.
24602	967	13	And they brought young children to him, that he should touch them: and his disciples rebuked those that brought them.
24603	967	14	But when Jesus saw it, he was much displeased, and said unto them, Suffer the little children to come unto me, and forbid them not: for of such is the kingdom of God.
24604	967	15	Verily I say unto you, Whosoever shall not receive the kingdom of God as a little child, he shall not enter therein.
24605	967	16	And he took them up in his arms, put his hands upon them, and blessed them.
24606	967	17	And when he was gone forth into the way, there came one running, and kneeled to him, and asked him, Good Master, what shall I do that I may inherit eternal life?
24607	967	18	And Jesus said unto him, Why callest thou me good? there is none good but one, that is, God.
24608	967	19	Thou knowest the commandments, Do not commit adultery, Do not kill, Do not steal, Do not bear false witness, Defraud not, Honour thy father and mother.
24609	967	20	And he answered and said unto him, Master, all these have I observed from my youth.
24610	967	21	Then Jesus beholding him loved him, and said unto him, One thing thou lackest: go thy way, sell whatsoever thou hast, and give to the poor, and thou shalt have treasure in heaven: and come, take up the cross, and follow me.
24611	967	22	And he was sad at that saying, and went away grieved: for he had great possessions.
24612	967	23	And Jesus looked round about, and saith unto his disciples, How hardly shall they that have riches enter into the kingdom of God!
24613	967	24	And the disciples were astonished at his words. But Jesus answereth again, and saith unto them, Children, how hard is it for them that trust in riches to enter into the kingdom of God!
24614	967	25	It is easier for a camel to go through the eye of a needle, than for a rich man to enter into the kingdom of God.
24615	967	26	And they were astonished out of measure, saying among themselves, Who then can be saved?
24616	967	27	And Jesus looking upon them saith, With men it is impossible, but not with God: for with God all things are possible.
24617	967	28	Then Peter began to say unto him, Lo, we have left all, and have followed thee.
24618	967	29	And Jesus answered and said, Verily I say unto you, There is no man that hath left house, or brethren, or sisters, or father, or mother, or wife, or children, or lands, for my sake, and the gospel's,
24619	967	30	But he shall receive an hundredfold now in this time, houses, and brethren, and sisters, and mothers, and children, and lands, with persecutions; and in the world to come eternal life.
24620	967	31	But many that are first shall be last; and the last first.
24621	967	32	And they were in the way going up to Jerusalem; and Jesus went before them: and they were amazed; and as they followed, they were afraid. And he took again the twelve, and began to tell them what things should happen unto him,
24622	967	33	Saying, Behold, we go up to Jerusalem; and the Son of man shall be delivered unto the chief priests, and unto the scribes; and they shall condemn him to death, and shall deliver him to the Gentiles:
24623	967	34	And they shall mock him, and shall scourge him, and shall spit upon him, and shall kill him: and the third day he shall rise again.
24624	967	35	And James and John, the sons of Zebedee, come unto him, saying, Master, we would that thou shouldest do for us whatsoever we shall desire.
24625	967	36	And he said unto them, What would ye that I should do for you?
24626	967	37	They said unto him, Grant unto us that we may sit, one on thy right hand, and the other on thy left hand, in thy glory.
24627	967	38	But Jesus said unto them, Ye know not what ye ask: can ye drink of the cup that I drink of? and be baptized with the baptism that I am baptized with?
24628	967	39	And they said unto him, We can. And Jesus said unto them, Ye shall indeed drink of the cup that I drink of; and with the baptism that I am baptized withal shall ye be baptized:
24629	967	40	But to sit on my right hand and on my left hand is not mine to give; but it shall be given to them for whom it is prepared.
24630	967	41	And when the ten heard it, they began to be much displeased with James and John.
24631	967	42	But Jesus called them to him, and saith unto them, Ye know that they which are accounted to rule over the Gentiles exercise lordship over them; and their great ones exercise authority upon them.
24632	967	43	But so shall it not be among you: but whosoever will be great among you, shall be your minister:
24633	967	44	And whosoever of you will be the chiefest, shall be servant of all.
24634	967	45	For even the Son of man came not to be ministered unto, but to minister, and to give his life a ransom for many.
24635	967	46	And they came to Jericho: and as he went out of Jericho with his disciples and a great number of people, blind Bartimaeus, the son of Timaeus, sat by the highway side begging.
24636	967	47	And when he heard that it was Jesus of Nazareth, he began to cry out, and say, Jesus, thou Son of David, have mercy on me.
24637	967	48	And many charged him that he should hold his peace: but he cried the more a great deal, Thou Son of David, have mercy on me.
24638	967	49	And Jesus stood still, and commanded him to be called. And they call the blind man, saying unto him, Be of good comfort, rise; he calleth thee.
24639	967	50	And he, casting away his garment, rose, and came to Jesus.
24640	967	51	And Jesus answered and said unto him, What wilt thou that I should do unto thee? The blind man said unto him, Lord, that I might receive my sight.
24641	967	52	And Jesus said unto him, Go thy way; thy faith hath made thee whole. And immediately he received his sight, and followed Jesus in the way.
24642	968	1	AND when they came nigh to Jerusalem, unto Bethphage and Bethany, at the mount of Olives, he sendeth forth two of his disciples,
24643	968	2	And saith unto them, Go your way into the village over against you: and as soon as ye be entered into it, ye shall find a colt tied, whereon never man sat; loose him, and bring him.
24644	968	3	And if any man say unto you, Why do ye this? say ye that the Lord hath need of him; and straightway he will send him hither.
24645	968	4	And they went their way, and found the colt tied by the door without in a place where two ways met; and they loose him.
24646	968	5	And certain of them that stood there said unto them, What do ye, loosing the colt?
24647	968	6	And they said unto them even as Jesus had commanded: and they let them go.
24648	968	7	And they brought the colt to Jesus, and cast their garments on him; and he sat upon him.
24649	968	8	And many spread their garments in the way: and others cut down branches off the trees, and strawed them in the way.
24650	968	9	And they that went before, and they that followed, cried, saying, Hosanna; Blessed is he that cometh in the name of the Lord:
24651	968	10	Blessed be the kingdom of our father David, that cometh in the name of the Lord: Hosanna in the highest.
24652	968	11	And Jesus entered into Jerusalem, and into the temple: and when he had looked round about upon all things, and now the eventide was come, he went out unto Bethany with the twelve.
24653	968	12	And on the morrow, when they were come from Bethany, he was hungry:
24654	968	13	And seeing a fig tree afar off having leaves, he came, if haply he might find any thing thereon: and when he came to it, he found nothing but leaves; for the time of figs was not yet.
24655	968	14	And Jesus answered and said unto it, No man eat fruit of thee hereafter for ever. And his disciples heard it.
24656	968	15	And they come to Jerusalem: and Jesus went into the temple, and began to cast out them that sold and bought in the temple, and overthrew the tables of the moneychangers, and the seats of them that sold doves;
24657	968	16	And would not suffer that any man should carry any vessel through the temple.
24658	968	17	And he taught, saying unto them, Is it not written, My house shall be called of all nations the house of prayer? but ye have made it a den of thieves.
24659	968	18	And the scribes and chief priests heard it, and sought how they might destroy him: for they feared him, because all the people was astonished at his doctrine.
24660	968	19	And when even was come, he went out of the city.
24661	968	20	And in the morning, as they passed by, they saw the fig tree dried up from the roots.
24662	968	21	And Peter calling to remembrance saith unto him, Master, behold, the fig tree which thou cursedst is withered away.
24663	968	22	And Jesus answering saith unto them, Have faith in God.
24664	968	23	For verily I say unto you, That whosoever shall say unto this mountain, Be thou removed, and be thou cast into the sea; and shall not doubt in his heart, but shall believe that those things which he saith shall come to pass; he shall have whatsoever he saith.
24665	968	24	Therefore I say unto you, What things soever ye desire, when ye pray, believe that ye receive them, and ye shall have them.
24666	968	25	And when ye stand praying, forgive, if ye have ought against any: that your Father also which is in heaven may forgive you your trespasses.
24667	968	26	But if ye do not forgive, neither will your Father which is in heaven forgive your trespasses.
24668	968	27	And they come again to Jerusalem: and as he was walking in the temple, there come to him the chief priests, and the scribes, and the elders,
24669	968	28	And say unto him, By what authority doest thou these things? and who gave thee this authority to do these things?
24670	968	29	And Jesus answered and said unto them, I will also ask of you one question, and answer me, and I will tell you by what authority I do these things.
24671	968	30	The baptism of John, was it from heaven, or of men? answer me.
24672	968	31	And they reasoned with themselves, saying, If we shall say, From heaven; he will say, Why then did ye not believe him?
24673	968	32	But if we shall say, Of men; they feared the people: for all men counted John, that he was a prophet indeed.
24674	968	33	And they answered and said unto Jesus, We cannot tell. And Jesus answering saith unto them, Neither do I tell you by what authority I do these things.
24675	969	1	AND he began to speak unto them by parables. A certain man planted a vineyard, and set an hedge about it, and digged a place for the winefat, and built a tower, and let it out to husbandmen, and went into a far country.
24676	969	2	And at the season he sent to the husbandmen a servant, that he might receive from the husbandmen of the fruit of the vineyard.
24677	969	3	And they caught him, and beat him, and sent him away empty.
24678	969	4	And again he sent unto them another servant; and at him they cast stones, and wounded him in the head, and sent him away shamefully handled.
24679	969	5	And again he sent another; and him they killed, and many others; beating some, and killing some.
24680	969	6	Having yet therefore one son, his wellbeloved, he sent him also last unto them, saying, They will reverence my son.
24681	969	7	But those husbandmen said among themselves, This is the heir; come, let us kill him, and the inheritance shall be ours.
24682	969	8	And they took him, and killed him, and cast him out of the vineyard.
24683	969	9	What shall therefore the lord of the vineyard do? he will come and destroy the husbandmen, and will give the vineyard unto others.
24684	969	10	And have ye not read this scripture; The stone which the builders rejected is become the head of the corner:
24685	969	11	This was the Lord's doing, and it is marvellous in our eyes?
24686	969	12	And they sought to lay hold on him, but feared the people: for they knew that he had spoken the parable against them: and they left him, and went their way.
24687	969	13	And they send unto him certain of the Pharisees and of the Herodians, to catch him in his words.
24688	969	14	And when they were come, they say unto him, Master, we know that thou art true, and carest for no man: for thou regardest not the person of men, but teachest the way of God in truth: Is it lawful to give tribute to Caesar, or not?
24689	969	15	Shall we give, or shall we not give? But he, knowing their hypocrisy, said unto them, Why tempt ye me? bring me a penny, that I may see it.
24690	969	16	And they brought it. And he saith unto them, Whose is this image and superscription? And they said unto him, Caesar's.
24691	969	17	And Jesus answering said unto them, Render to Caesar the things that are Caesar's, and to God the things that are God's. And they marvelled at him.
24692	969	18	Then come unto him the Sadducees, which say there is no resurrection; and they asked him, saying,
24693	969	19	Master, Moses wrote unto us, If a man's brother die, and leave his wife behind him, and leave no children, that his brother should take his wife, and raise up seed unto his brother.
24694	969	20	Now there were seven brethren: and the first took a wife, and dying left no seed.
24695	969	21	And the second took her, and died, neither left he any seed: and the third likewise.
24696	969	22	And the seven had her, and left no seed: last of all the woman died also.
24697	969	23	In the resurrection therefore, when they shall rise, whose wife shall she be of them? for the seven had her to wife.
24698	969	24	And Jesus answering said unto them, Do ye not therefore err, because ye know not the scriptures, neither the power of God?
24699	969	25	For when they shall rise from the dead, they neither marry, nor are given in marriage; but are as the angels which are in heaven.
24700	969	26	And as touching the dead, that they rise: have ye not read in the book of Moses, how in the bush God spake unto him, saying, I am the God of Abraham, and the God of Isaac, and the God of Jacob?
24701	969	27	He is not the God of the dead, but the God of the living: ye therefore do greatly err.
24702	969	28	And one of the scribes came, and having heard them reasoning together, and perceiving that he had answered them well, asked him, Which is the first commandment of all?
24703	969	29	And Jesus answered him, The first of all the commandments is, Hear, O Israel; The Lord our God is one Lord:
24704	969	30	And thou shalt love the Lord thy God with all thy heart, and with all thy soul, and with all thy mind, and with all thy strength: this is the first commandment.
24705	969	31	And the second is like, namely this, Thou shalt love thy neighbour as thyself. There is none other commandment greater than these.
24706	969	32	And the scribe said unto him, Well, Master, thou hast said the truth: for there is one God; and there is none other but he:
24707	969	33	And to love him with all the heart, and with all the understanding, and with all the soul, and with all the strength, and to love his neighbour as himself, is more than all whole burnt offerings and sacrifices.
24708	969	34	And when Jesus saw that he answered discreetly, he said unto him, Thou art not far from the kingdom of God. And no man after that durst ask him any question.
24709	969	35	And Jesus answered and said, while he taught in the temple, How say the scribes that Christ is the Son of David?
24710	969	36	For David himself said by the Holy Ghost, The LORD said to my Lord, Sit thou on my right hand, till I make thine enemies thy footstool.
24711	969	37	David therefore himself calleth him Lord; and whence is he then his son? And the common people heard him gladly.
24712	969	38	And he said unto them in his doctrine, Beware of the scribes, which love to go in long clothing, and love salutations in the marketplaces,
24713	969	39	And the chief seats in the synagogues, and the uppermost rooms at feasts:
24714	969	40	Which devour widows' houses, and for a pretence make long prayers: these shall receive greater damnation.
24715	969	41	And Jesus sat over against the treasury, and beheld how the people cast money into the treasury: and many that were rich cast in much.
24716	969	42	And there came a certain poor widow, and she threw in two mites, which make a farthing.
24717	969	43	And he called unto him his disciples, and saith unto them, Verily I say unto you, That this poor widow hath cast more in, than all they which have cast into the treasury:
24718	969	44	For all they did cast in of their abundance; but she of her want did cast in all that she had, even all her living.
24719	970	1	AND as he went out of the temple, one of his disciples saith unto him, Master, see what manner of stones and what buildings are here!
24720	970	2	And Jesus answering said unto him, Seest thou these great buildings? there shall not be left one stone upon another, that shall not be thrown down.
24721	970	3	And as he sat upon the mount of Olives over against the temple, Peter and James and John and Andrew asked him privately,
24722	970	4	Tell us, when shall these things be? and what shall be the sign when all these things shall be fulfilled?
24723	970	5	And Jesus answering them began to say, Take heed lest any man deceive you:
24724	970	6	For many shall come in my name, saying, I am Christ; and shall deceive many.
24725	970	7	And when ye shall hear of wars and rumours of wars, be ye not troubled: for such things must needs be; but the end shall not be yet.
24726	970	8	For nation shall rise against nation, and kingdom against kingdom: and there shall be earthquakes in divers places, and there shall be famines and troubles: these are the beginnings of sorrows.
24727	970	9	But take heed to yourselves: for they shall deliver you up to councils; and in the synagogues ye shall be beaten: and ye shall be brought before rulers and kings for my sake, for a testimony against them.
24728	970	10	And the gospel must first be published among all nations.
24729	970	11	But when they shall lead you, and deliver you up, take no thought beforehand what ye shall speak, neither do ye premeditate: but whatsoever shall be given you in that hour, that speak ye: for it is not ye that speak, but the Holy Ghost.
24730	970	12	Now the brother shall betray the brother to death, and the father the son; and children shall rise up against their parents, and shall cause them to be put to death.
24731	970	13	And ye shall be hated of all men for my name's sake: but he that shall endure unto the end, the same shall be saved.
24732	970	14	But when ye shall see the abomination of desolation, spoken of by Daniel the prophet, standing where it ought not, (let him that readeth understand,) then let them that be in Judaea flee to the mountains:
24733	970	15	And let him that is on the housetop not go down into the house, neither enter therein, to take any thing out of his house:
24734	970	16	And let him that is in the field not turn back again for to take up his garment.
24735	970	17	But woe to them that are with child, and to them that give suck in those days!
24736	970	18	And pray ye that your flight be not in the winter.
24737	970	19	For in those days shall be affliction, such as was not from the beginning of the creation which God created unto this time, neither shall be.
24738	970	20	And except that the Lord had shortened those days, no flesh should be saved: but for the elect's sake, whom he hath chosen, he hath shortened the days.
24739	970	21	And then if any man shall say to you, Lo, here is Christ; or, lo, he is there; believe him not:
24740	970	22	For false Christs and false prophets shall rise, and shall shew signs and wonders, to seduce, if it were possible, even the elect.
24741	970	23	But take ye heed: behold, I have foretold you all things.
24742	970	24	But in those days, after that tribulation, the sun shall be darkened, and the moon shall not give her light,
24743	970	25	And the stars of heaven shall fall, and the powers that are in heaven shall be shaken.
24744	970	26	And then shall they see the Son of man coming in the clouds with great power and glory.
24745	970	27	And then shall he send his angels, and shall gather together his elect from the four winds, from the uttermost part of the earth to the uttermost part of heaven.
24746	970	28	Now learn a parable of the fig tree; When her branch is yet tender, and putteth forth leaves, ye know that summer is near:
24747	970	29	So ye in like manner, when ye shall see these things come to pass, know that it is nigh, even at the doors.
24748	970	30	Verily I say unto you, that this generation shall not pass, till all these things be done.
24749	970	31	Heaven and earth shall pass away: but my words shall not pass away.
24750	970	32	But of that day and that hour knoweth no man, no, not the angels which are in heaven, neither the Son, but the Father.
24751	970	33	Take ye heed, watch and pray: for ye know not when the time is.
24752	970	34	For the Son of man is as a man taking a far journey, who left his house, and gave authority to his servants, and to every man his work, and commanded the porter to watch.
24753	970	35	Watch ye therefore: for ye know not when the master of the house cometh, at even, or at midnight, or at the cockcrowing, or in the morning:
24754	970	36	Lest coming suddenly he find you sleeping.
24755	970	37	And what I say unto you I say unto all, Watch.
24756	971	1	AFTER two days was the feast of the passover, and of unleavened bread: and the chief priests and the scribes sought how they might take him by craft, and put him to death.
24757	971	2	But they said, Not on the feast day, lest there be an uproar of the people.
24758	971	3	And being in Bethany in the house of Simon the leper, as he sat at meat, there came a woman having an alabaster box of ointment of spikenard very precious; and she brake the box, and poured it on his head.
24759	971	4	And there were some that had indignation within themselves, and said, Why was this waste of the ointment made?
24760	971	5	For it might have been sold for more than three hundred pence, and have been given to the poor. And they murmured against her.
24761	971	6	And Jesus said, Let her alone; why trouble ye her? she hath wrought a good work on me.
24762	971	7	For ye have the poor with you always, and whensoever ye will ye may do them good: but me ye have not always.
24763	971	8	She hath done what she could: she is come aforehand to anoint my body to the burying.
24764	971	9	Verily I say unto you, Wheresoever this gospel shall be preached throughout the whole world, this also that she hath done shall be spoken of for a memorial of her.
24765	971	10	And Judas Iscariot, one of the twelve, went unto the chief priests, to betray him unto them.
24766	971	11	And when they heard it, they were glad, and promised to give him money. And he sought how he might conveniently betray him.
24767	971	12	And the first day of unleavened bread, when they killed the passover, his disciples said unto him, Where wilt thou that we go and prepare that thou mayest eat the passover?
24768	971	13	And he sendeth forth two of his disciples, and saith unto them, Go ye into the city, and there shall meet you a man bearing a pitcher of water: follow him.
24769	971	14	And wheresoever he shall go in, say ye to the goodman of the house, The Master saith, Where is the guestchamber, where I shall eat the passover with my disciples?
24770	971	15	And he will shew you a large upper room furnished and prepared: there make ready for us.
24771	971	16	And his disciples went forth, and came into the city, and found as he had said unto them: and they made ready the passover.
24772	971	17	And in the evening he cometh with the twelve.
24773	971	18	And as they sat and did eat, Jesus said, Verily I say unto you, One of you which eateth with me shall betray me.
24774	971	19	And they began to be sorrowful, and to say unto him one by one, Is it I? and another said, Is it I?
24775	971	20	And he answered and said unto them, It is one of the twelve, that dippeth with me in the dish.
24776	971	21	The Son of man indeed goeth, as it is written of him: but woe to that man by whom the Son of man is betrayed! good were it for that man if he had never been born.
24777	971	22	And as they did eat, Jesus took bread, and blessed, and brake it, and gave to them, and said, Take, eat: this is my body.
24778	971	23	And he took the cup, and when he had given thanks, he gave it to them: and they all drank of it.
24779	971	24	And he said unto them, This is my blood of the new testament, which is shed for many.
24780	971	25	Verily I say unto you, I will drink no more of the fruit of the vine, until that day that I drink it new in the kingdom of God.
24781	971	26	And when they had sung an hymn, they went out into the mount of Olives.
24782	971	27	And Jesus saith unto them, All ye shall be offended because of me this night: for it is written, I will smite the shepherd, and the sheep shall be scattered.
24783	971	28	But after that I am risen, I will go before you into Galilee.
24784	971	29	But Peter said unto him, Although all shall be offended, yet will not I.
24785	971	30	And Jesus saith unto him, Verily I say unto thee, That this day, even in this night, before the cock crow twice, thou shalt deny me thrice.
24786	971	31	But he spake the more vehemently, If I should die with thee, I will not deny thee in any wise. Likewise also said they all.
24787	971	32	And they came to a place which was named Gethsemane: and he saith to his disciples, Sit ye here, while I shall pray.
24788	971	33	And he taketh with him Peter and James and John, and began to be sore amazed, and to be very heavy;
24789	971	34	And saith unto them, My soul is exceeding sorrowful unto death: tarry ye here, and watch.
24790	971	35	And he went forward a little, and fell on the ground, and prayed that, if it were possible, the hour might pass from him.
24791	971	36	And he said, Abba, Father, all things are possible unto thee; take away this cup from me: nevertheless not what I will, but what thou wilt.
24792	971	37	And he cometh, and findeth them sleeping, and saith unto Peter, Simon, sleepest thou? couldest not thou watch one hour?
24793	971	38	Watch ye and pray, lest ye enter into temptation. The spirit truly is ready, but the flesh is weak.
24794	971	39	And again he went away, and prayed, and spake the same words.
24795	971	40	And when he returned, he found them asleep again, (for their eyes were heavy,) neither wist they what to answer him.
24796	971	41	And he cometh the third time, and saith unto them, Sleep on now, and take your rest: it is enough, the hour is come; behold, the Son of man is betrayed into the hands of sinners.
24797	971	42	Rise up, let us go; lo, he that betrayeth me is at hand.
24798	971	43	And immediately, while he yet spake, cometh Judas, one of the twelve, and with him a great multitude with swords and staves, from the chief priests and the scribes and the elders.
24799	971	44	And he that betrayed him had given them a token, saying, Whomsoever I shall kiss, that same is he; take him, and lead him away safely.
24800	971	45	And as soon as he was come, he goeth straightway to him, and saith, Master, master; and kissed him.
24801	971	46	And they laid their hands on him, and took him.
24802	971	47	And one of them that stood by drew a sword, and smote a servant of the high priest, and cut off his ear.
24803	971	48	And Jesus answered and said unto them, Are ye come out, as against a thief, with swords and with staves to take me?
24804	971	49	I was daily with you in the temple teaching, and ye took me not: but the scriptures must be fulfilled.
24805	971	50	And they all forsook him, and fled.
24806	971	51	And there followed him a certain young man, having a linen cloth cast about his naked body; and the young men laid hold on him:
24807	971	52	And he left the linen cloth, and fled from them naked.
24808	971	53	And they led Jesus away to the high priest: and with him were assembled all the chief priests and the elders and the scribes.
24809	971	54	And Peter followed him afar off, even into the palace of the high priest: and he sat with the servants, and warmed himself at the fire.
24810	971	55	And the chief priests and all the council sought for witness against Jesus to put him to death; and found none.
24811	971	56	For many bare false witness against him, but their witness agreed not together.
24812	971	57	And there arose certain, and bare false witness against him, saying,
24813	971	58	We heard him say, I will destroy this temple that is made with hands, and within three days I will build another made without hands.
24814	971	59	But neither so did their witness agree together.
24815	971	60	And the high priest stood up in the midst, and asked Jesus, saying, Answerest thou nothing? what is it which these witness against thee?
24816	971	61	But he held his peace, and answered nothing. Again the high priest asked him, and said unto him, Art thou the Christ, the Son of the Blessed?
24817	971	62	And Jesus said, I am: and ye shall see the Son of man sitting on the right hand of power, and coming in the clouds of heaven.
24818	971	63	Then the high priest rent his clothes, and saith, What need we any further witnesses?
24819	971	64	Ye have heard the blasphemy: what think ye? And they all condemned him to be guilty of death.
24820	971	65	And some began to spit on him, and to cover his face, and to buffet him, and to say unto him, Prophesy: and the servants did strike him with the palms of their hands.
24821	971	66	And as Peter was beneath in the palace, there cometh one of the maids of the high priest:
24822	971	67	And when she saw Peter warming himself, she looked upon him, and said, And thou also wast with Jesus of Nazareth.
24823	971	68	But he denied, saying, I know not, neither understand I what thou sayest. And he went out into the porch; and the cock crew.
24824	971	69	And a maid saw him again, and began to say to them that stood by, This is one of them.
24825	971	70	And he denied it again. And a little after, they that stood by said again to Peter, Surely thou art one of them: for thou art a Galilaean, and thy speech agreeth thereto.
24826	971	71	But he began to curse and to swear, saying, I know not this man of whom ye speak.
24827	971	72	And the second time the cock crew. And Peter called to mind the word that Jesus said unto him, Before the cock crow twice, thou shalt deny me thrice. And when he thought thereon, he wept.
24828	972	1	AND straightway in the morning the chief priests held a consultation with the elders and scribes and the whole council, and bound Jesus, and carried him away, and delivered him to Pilate.
24829	972	2	And Pilate asked him, Art thou the King of the Jews? And he answering said unto him, Thou sayest it.
24830	972	3	And the chief priests accused him of many things: but he answered nothing.
24831	972	4	And Pilate asked him again, saying, Answerest thou nothing? behold how many things they witness against thee.
24832	972	5	But Jesus yet answered nothing; so that Pilate marvelled.
24833	972	6	Now at that feast he released unto them one prisoner, whomsoever they desired.
24834	972	7	And there was one named Barabbas, which lay bound with them that had made insurrection with him, who had committed murder in the insurrection.
24835	972	8	And the multitude crying aloud began to desire him to do as he had ever done unto them.
24836	972	9	But Pilate answered them, saying, Will ye that I release unto you the King of the Jews?
24837	972	10	For he knew that the chief priests had delivered him for envy.
24838	972	11	But the chief priests moved the people, that he should rather release Barabbas unto them.
24839	972	12	And Pilate answered and said again unto them, What will ye then that I shall do unto him whom ye call the King of the Jews?
24840	972	13	And they cried out again, Crucify him.
24841	972	14	Then Pilate said unto them, Why, what evil hath he done? And they cried out the more exceedingly, Crucify him.
24842	972	15	And so Pilate, willing to content the people, released Barabbas unto them, and delivered Jesus, when he had scourged him, to be crucified.
24843	972	16	And the soldiers led him away into the hall, called Praetorium; and they call together the whole band.
24844	972	17	And they clothed him with purple, and platted a crown of thorns, and put it about his head,
24845	972	18	And began to salute him, Hail, King of the Jews!
24846	972	19	And they smote him on the head with a reed, and did spit upon him, and bowing their knees worshipped him.
24847	972	20	And when they had mocked him, they took off the purple from him, and put his own clothes on him, and led him out to crucify him.
24848	972	21	And they compel one Simon a Cyrenian, who passed by, coming out of the country, the father of Alexander and Rufus, to bear his cross.
24849	972	22	And they bring him unto the place Golgotha, which is, being interpreted, The place of a skull.
24850	972	23	And they gave him to drink wine mingled with myrrh: but he received it not.
24851	972	24	And when they had crucified him, they parted his garments, casting lots upon them, what every man should take.
24852	972	25	And it was the third hour, and they crucified him.
24853	972	26	And the superscription of his accusation was written over, THE KING OF THE JEWS.
24854	972	27	And with him they crucify two thieves; the one on his right hand, and the other on his left.
24855	972	28	And the scripture was fulfilled, which saith, And he was numbered with the transgressors.
24856	972	29	And they that passed by railed on him, wagging their heads, and saying, Ah, thou that destroyest the temple, and buildest it in three days,
24857	972	30	Save thyself, and come down from the cross.
24858	972	31	Likewise also the chief priests mocking said among themselves with the scribes, He saved others; himself he cannot save.
24859	972	32	Let Christ the King of Israel descend now from the cross, that we may see and believe. And they that were crucified with him reviled him.
24860	972	33	And when the sixth hour was come, there was darkness over the whole land until the ninth hour.
24861	972	34	And at the ninth hour Jesus cried with a loud voice, saying, Eloi, Eloi, lama sabachthani? which is, being interpreted, My God, my God, why hast thou forsaken me?
24862	972	35	And some of them that stood by, when they heard it, said, Behold, he calleth Elias.
24863	972	36	And one ran and filled a spunge full of vinegar, and put it on a reed, and gave him to drink, saying, Let alone; let us see whether Elias will come to take him down.
24864	972	37	And Jesus cried with a loud voice, and gave up the ghost.
24865	972	38	And the veil of the temple was rent in twain from the top to the bottom.
24866	972	39	And when the centurion, which stood over against him, saw that he so cried out, and gave up the ghost, he said, Truly this man was the Son of God.
24867	972	40	There were also women looking on afar off: among whom was Mary Magdalene, and Mary the mother of James the less and of Joses, and Salome;
24868	972	41	(Who also, when he was in Galilee, followed him, and ministered unto him;) and many other women which came up with him unto Jerusalem.
24869	972	42	And now when the even was come, because it was the preparation, that is, the day before the sabbath,
24870	972	43	Joseph of Arimathaea, and honourable counsellor, which also waited for the kingdom of God, came, and went in boldly unto Pilate, and craved the body of Jesus.
24871	972	44	And Pilate marvelled if he were already dead: and calling unto him the centurion, he asked him whether he had been any while dead.
24872	972	45	And when he knew it of the centurion, he gave the body to Joseph.
24873	972	46	And he bought fine linen, and took him down, and wrapped him in the linen, and laid him in a sepulchre which was hewn out of a rock, and rolled a stone unto the door of the sepulchre.
24874	972	47	And Mary Magdalene and Mary the mother of Joses beheld where he was laid.
24875	973	1	AND when the sabbath was past, Mary Magdalene, and Mary the mother of James, and Salome, had bought sweet spices, that they might come and anoint him.
24876	973	2	And very early in the morning the first day of the week, they came unto the sepulchre at the rising of the sun.
24877	973	3	And they said among themselves, Who shall roll us away the stone from the door of the sepulchre?
24878	973	4	And when they looked, they saw that the stone was rolled away: for it was very great.
24879	973	5	And entering into the sepulchre, they saw a young man sitting on the right side, clothed in a long white garment; and they were affrighted.
24880	973	6	And he saith unto them, Be not affrighted: Ye seek Jesus of Nazareth, which was crucified: he is risen; he is not here: behold the place where they laid him.
24881	973	7	But go your way, tell his disciples and Peter that he goeth before you into Galilee: there shall ye see him, as he said unto you.
24882	973	8	And they went out quickly, and fled from the sepulchre; for they trembled and were amazed: neither said they any thing to any man; for they were afraid.
24883	973	9	Now when Jesus was risen early the first day of the week, he appeared first to Mary Magdalene, out of whom he had cast seven devils.
24884	973	10	And she went and told them that had been with him, as they mourned and wept.
24885	973	11	And they, when they had heard that he was alive, and had been seen of her, believed not.
24886	973	12	After that he appeared in another form unto two of them, as they walked, and went into the country.
24887	973	13	And they went and told it unto the residue: neither believed they them.
24888	973	14	Afterward he appeared unto the eleven as they sat at meat, and upbraided them with their unbelief and hardness of heart, because they believed not them which had seen him after he was risen.
24889	973	15	And he said unto them, Go ye into all the world, and preach the gospel to every creature.
24890	973	16	He that believeth and is baptized shall be saved; but he that believeth not shall be damned.
24891	973	17	And these signs shall follow them that believe; In my name shall they cast out devils; they shall speak with new tongues;
24892	973	18	They shall take up serpents; and if they drink any deadly thing, it shall not hurt them: they shall lay hands on the sick, and they shall recover.
24893	973	19	So then after the Lord had spoken unto them, he was received up into heaven, and sat on the right hand of God.
24894	973	20	And they went forth, and preached every where, the Lord working with them, and confirming the word with signs following. Amen.
24895	974	1	FORASMUCH as many have taken in hand to set forth in order a declaration of those things which are most surely believed among us,
24896	974	2	Even as they delivered them unto us, which from the beginning were eyewitnesses, and ministers of the word;
24897	974	3	It seemed good to me also, having had perfect understanding of all things from the very first, to write unto thee in order, most excellent Theophilus,
24898	974	4	That thou mightest know the certainty of those things, wherein thou hast been instructed.
24899	974	5	THERE was in the days of Herod, the king of Judaea, a certain priest named Zacharias, of the course of Abia: and his wife was of the daughters of Aaron, and her name was Elisabeth.
24900	974	6	And they were both righteous before God, walking in all the commandments and ordinances of the Lord blameless.
24901	974	7	And they had no child, because that Elisabeth was barren, and they both were now well stricken in years.
24902	974	8	And it came to pass, that while he executed the priest's office before God in the order of his course,
24903	974	9	According to the custom of the priest's office, his lot was to burn incense when he went into the temple of the Lord.
24904	974	10	And the whole multitude of the people were praying without at the time of incense.
24905	974	11	And there appeared unto him an angel of the Lord standing on the right side of the altar of incense.
24906	974	12	And when Zacharias saw him, he was troubled, and fear fell upon him.
24907	974	13	But the angel said unto him, Fear not, Zacharias: for thy prayer is heard; and thy wife Elisabeth shall bear thee a son, and thou shalt call his name John.
24908	974	14	And thou shalt have joy and gladness; and many shall rejoice at his birth.
24909	974	15	For he shall be great in the sight of the Lord, and shall drink neither wine nor strong drink; and he shall be filled with the Holy Ghost, even from his mother's womb.
24910	974	16	And many of the children of Israel shall he turn to the Lord their God.
24911	974	17	And he shall go before him in the spirit and power of Elias, to turn the hearts of the fathers to the children, and the disobedient to the wisdom of the just; to make ready a people prepared for the Lord.
24912	974	18	And Zacharias said unto the angel, Whereby shall I know this? for I am an old man, and my wife well stricken in years.
24913	974	19	And the angel answering said unto him, I am Gabriel, that stand in the presence of God; and am sent to speak unto thee, and to shew thee these glad tidings.
24914	974	20	And, behold, thou shalt be dumb, and not able to speak, until the day that these things shall be performed, because thou believest not my words, which shall be fulfilled in their season.
24915	974	21	And the people waited for Zacharias, and marvelled that he tarried so long in the temple.
24916	974	22	And when he came out, he could not speak unto them: and they perceived that he had seen a vision in the temple: for he beckoned unto them, and remained speechless.
24917	974	23	And it came to pass, that, as soon as the days of his ministration were accomplished, he departed to his own house.
24918	974	24	And after those days his wife Elisabeth conceived, and hid herself five months, saying,
24919	974	25	Thus hath the Lord dealt with me in the days wherein he looked on me, to take away my reproach among men.
24920	974	26	And in the sixth month the angel Gabriel was sent from God unto a city of Galilee, named Nazareth,
24921	974	27	To a virgin espoused to a man whose name was Joseph, of the house of David; and the virgin's name was Mary.
24922	974	28	And the angel came in unto her, and said, Hail, thou that art highly favoured, the Lord is with thee: blessed art thou among women.
24923	974	29	And when she saw him, she was troubled at his saying, and cast in her mind what manner of salutation this should be.
24924	974	30	And the angel said unto her, Fear not, Mary: for thou hast found favour with God.
24925	974	31	And, behold, thou shalt conceive in thy womb, and bring forth a son, and shalt call his name JESUS.
24926	974	32	He shall be great, and shall be called the Son of the Highest: and the Lord God shall give unto him the throne of his father David:
24927	974	33	And he shall reign over the house of Jacob for ever; and of his kingdom there shall be no end.
24928	974	34	Then said Mary unto the angel, How shall this be, seeing I know not a man?
24929	974	35	And the angel answered and said unto her, The Holy Ghost shall come upon thee, and the power of the Highest shall overshadow thee: therefore also that holy thing which shall be born of thee shall be called the Son of God.
24930	974	36	And, behold, thy cousin Elisabeth, she hath also conceived a son in her old age: and this is the sixth month with her, who was called barren.
24931	974	37	For with God nothing shall be impossible.
24932	974	38	And Mary said, Behold the handmaid of the Lord; be it unto me according to thy word. And the angel departed from her.
24933	974	39	And Mary arose in those days, and went into the hill country with haste, into a city of Juda;
24934	974	40	And entered into the house of Zacharias, and saluted Elisabeth.
24935	974	41	And it came to pass, that, when Elisabeth heard the salutation of Mary, the babe leaped in her womb; and Elisabeth was filled with the Holy Ghost:
24936	974	42	And she spake out with a loud voice, and said, Blessed art thou among women, and blessed is the fruit of thy womb.
24937	974	43	And whence is this to me, that the mother of my Lord should come to me?
24938	974	44	For, lo, as soon as the voice of thy salutation sounded in mine ears, the babe leaped in my womb for joy.
24939	974	45	And blessed is she that believed: for there shall be a performance of those things which were told her from the Lord.
24940	974	46	And Mary said, My soul doth magnify the Lord,
24941	974	47	And my spirit hath rejoiced in God my Saviour.
24942	974	48	For he hath regarded the low estate of his handmaiden: for, behold, from henceforth all generations shall call me blessed.
24943	974	49	For he that is mighty hath done to me great things; and holy is his name.
24944	974	50	And his mercy is on them that fear him from generation to generation.
24945	974	51	He hath shewed strength with his arm; he hath scattered the proud in the imagination of their hearts.
24946	974	52	He hath put down the mighty from their seats, and exalted them of low degree.
24947	974	53	He hath filled the hungry with good things; and the rich he hath sent empty away.
24948	974	54	He hath holpen his servant Israel, in remembrance of his mercy;
24949	974	55	As he spake to our fathers, to Abraham, and to his seed for ever.
24950	974	56	And Mary abode with her about three months, and returned to her own house.
24951	974	57	Now Elisabeth's full time came that she should be delivered; and she brought forth a son.
24952	974	58	And her neighbours and her cousins heard how the Lord had shewed great mercy upon her; and they rejoiced with her.
24953	974	59	And it came to pass, that on the eighth day they came to circumcise the child; and they called him Zacharias, after the name of his father.
24954	974	60	And his mother answered and said, Not so; but he shall be called John.
24955	974	61	And they said unto her, There is none of thy kindred that is called by this name.
24956	974	62	And they made signs to his father, how he would have him called.
24957	974	63	And he asked for a writing table, and wrote, saying, His name is John. And they marvelled all.
24958	974	64	And his mouth was opened immediately, and his tongue loosed, and he spake, and praised God.
24959	974	65	And fear came on all that dwelt round about them: and all these sayings were noised abroad throughout all the hill country of Judaea.
24960	974	66	And all they that heard them laid them up in their hearts, saying, What manner of child shall this be! And the hand of the Lord was with him.
24961	974	67	And his father Zacharias was filled with the Holy Ghost, and prophesied, saying,
24962	974	68	Blessed be the Lord God of Israel; for he hath visited and redeemed his people,
24963	974	69	And hath raised up an horn of salvation for us in the house of his servant David;
24964	974	70	As he spake by the mouth of his holy prophets, which have been since the world began:
24965	974	71	That we should be saved from our enemies, and from the hand of all that hate us;
24966	974	72	To perform the mercy promised to our fathers, and to remember his holy covenant;
24967	974	73	The oath which he sware to our father Abraham,
24968	974	74	That he would grant unto us, that we being delivered out of the hand of our enemies might serve him without fear,
24969	974	75	In holiness and righteousness before him, all the days of our life.
24970	974	76	And thou, child, shalt be called the prophet of the Highest: for thou shalt go before the face of the Lord to prepare his ways;
24971	974	77	To give knowledge of salvation unto his people by the remission of their sins,
24972	974	78	Through the tender mercy of our God; whereby the dayspring from on high hath visited us,
24973	974	79	To give light to them that sit in darkness and in the shadow of death, to guide our feet into the way of peace.
24974	974	80	And the child grew, and waxed strong in spirit, and was in the deserts till the day of his shewing unto Israel.
24975	975	1	AND it came to pass in those days, that there went out a decree from Caesar Augustus, that all the world should be taxed.
24976	975	2	(And this taxing was first made when Cyrenius was governor of Syria.)
24977	975	3	And all went to be taxed, every one into his own city.
24978	975	4	And Joseph also went up from Galilee, out of the city of Nazareth, into Judaea, unto the city of David, which is called Bethlehem; (because he was of the house and lineage of David:)
24979	975	5	To be taxed with Mary his espoused wife, being great with child.
24980	975	6	And so it was, that, while they were there, the days were accomplished that she should be delivered.
24981	975	7	And she brought forth her firstborn son, and wrapped him in swaddling clothes, and laid him in a manger; because there was no room for them in the inn.
24982	975	8	And there were in the same country shepherds abiding in the field, keeping watch over their flock by night.
24983	975	9	And, lo, the angel of the Lord came upon them, and the glory of the Lord shone round about them: and they were sore afraid.
24984	975	10	And the angel said unto them, Fear not: for, behold, I bring you good tidings of great joy, which shall be to all people.
24985	975	11	For unto you is born this day in the city of David a Saviour, which is Christ the Lord.
24986	975	12	And this shall be a sign unto you; Ye shall find the babe wrapped in swaddling clothes, lying in a manger.
24987	975	13	And suddenly there was with the angel a multitude of the heavenly host praising God, and saying,
24988	975	14	Glory to God in the highest, and on earth peace, good will toward men.
24989	975	15	And it came to pass, as the angels were gone away from them into heaven, the shepherds said one to another, Let us now go even unto Bethlehem, and see this thing which is come to pass, which the Lord hath made known unto us.
24990	975	16	And they came with haste, and found Mary, and Joseph, and the babe lying in a manger.
24991	975	17	And when they had seen it, they made known abroad the saying which was told them concerning this child.
24992	975	18	And all they that heard it wondered at those things which were told them by the shepherds.
24993	975	19	But Mary kept all these things, and pondered them in her heart.
24994	975	20	And the shepherds returned, glorifying and praising God for all the things that they had heard and seen, as it was told unto them.
24995	975	21	And when eight days were accomplished for the circumcising of the child, his name was called JESUS, which was so named of the angel before he was conceived in the womb.
24996	975	22	And when the days of her purification according to the law of Moses were accomplished, they brought him to Jerusalem, to present him to the Lord;
24997	975	23	(As it is written in the law of the Lord, Every male that openeth the womb shall be called holy to the Lord;)
24998	975	24	And to offer a sacrifice according to that which is said in the law of the Lord, A pair of turtledoves, or two young pigeons.
24999	975	25	And, behold, there was a man in Jerusalem, whose name was Simeon; and the same man was just and devout, waiting for the consolation of Israel: and the Holy Ghost was upon him.
25000	975	26	And it was revealed unto him by the Holy Ghost, that he should not see death, before he had seen the Lord's Christ.
25001	975	27	And he came by the Spirit into the temple: and when the parents brought in the child Jesus, to do for him after the custom of the law,
25002	975	28	Then took he him up in his arms, and blessed God, and said,
25003	975	29	Lord, now lettest thou thy servant depart in peace, according to thy word:
25004	975	30	For mine eyes have seen thy salvation,
25005	975	31	Which thou hast prepared before the face of all people;
25006	975	32	A light to lighten the Gentiles, and the glory of thy people Israel.
25007	975	33	And Joseph and his mother marvelled at those things which were spoken of him.
25008	975	34	And Simeon blessed them, and said unto Mary his mother, Behold, this child is set for the fall and rising again of many in Israel; and for a sign which shall be spoken against;
25009	975	35	(Yea, a sword shall pierce through thy own soul also,) that the thoughts of many hearts may be revealed.
25010	975	36	And there was one Anna, a prophetess, the daughter of Phanuel, of the tribe of Aser: she was of a great age, and had lived with an husband seven years from her virginity;
25011	975	37	And she was a widow of about fourscore and four years, which departed not from the temple, but served God with fastings and prayers night and day.
25012	975	38	And she coming in that instant gave thanks likewise unto the Lord, and spake of him to all them that looked for redemption in Jerusalem.
25013	975	39	And when they had performed all things according to the law of the Lord, they returned into Galilee, to their own city Nazareth.
25014	975	40	And the child grew, and waxed strong in spirit, filled with wisdom: and the grace of God was upon him.
25015	975	41	Now his parents went to Jerusalem every year at the feast of the passover.
25016	975	42	And when he was twelve years old, they went up to Jerusalem after the custom of the feast.
25017	975	43	And when they had fulfilled the days, as they returned, the child Jesus tarried behind in Jerusalem; and Joseph and his mother knew not of it.
25018	975	44	But they, supposing him to have been in the company, went a day's journey; and they sought him among their kinsfolk and acquaintance.
25019	975	45	And when they found him not, they turned back again to Jerusalem, seeking him.
25020	975	46	And it came to pass, that after three days they found him in the temple, sitting in the midst of the doctors, both hearing them, and asking them questions.
25021	975	47	And all that heard him were astonished at his understanding and answers.
25022	975	48	And when they saw him, they were amazed: and his mother said unto him, Son, why hast thou thus dealt with us? behold, thy father and I have sought thee sorrowing.
25023	975	49	And he said unto them, How is it that ye sought me? wist ye not that I must be about my Father's business?
25024	975	50	And they understood not the saying which he spake unto them.
25025	975	51	And he went down with them, and came to Nazareth, and was subject unto them: but his mother kept all these sayings in her heart.
25026	975	52	And Jesus increased in wisdom and stature, and in favour with God and man.
25027	976	1	NOW in the fifteenth year of the reign of Tiberius Caesar, Pontius Pilate being governor of Judaea, and Herod being tetrarch of Galilee, and his brother Philip tetrarch of Ituraea and of the region of Trachonitis, and Lysanias the tetrarch of Abilene,
25028	976	2	Annas and Caiaphas being the high priests, the word of God came unto John the son of Zacharias in the wilderness.
25029	976	3	And he came into all the country about Jordan, preaching the baptism of repentance for the remission of sins;
25030	976	4	As it is written in the book of the words of Esaias the prophet, saying, The voice of one crying in the wilderness, Prepare ye the way of the Lord, make his paths straight.
25031	976	5	Every valley shall be filled, and every mountain and hill shall be brought low; and the crooked shall be made straight, and the rough ways shall be made smooth;
25032	976	6	And all flesh shall see the salvation of God.
25033	976	7	Then said he to the multitude that came forth to be baptized of him, O generation of vipers, who hath warned you to flee from the wrath to come?
25034	976	8	Bring forth therefore fruits worthy of repentance, and begin not to say within yourselves, We have Abraham to our father: for I say unto you, That God is able of these stones to raise up children unto Abraham.
25035	976	9	And now also the axe is laid unto the root of the trees: every tree therefore which bringeth not forth good fruit is hewn down, and cast into the fire.
25036	976	10	And the people asked him, saying, What shall we do then?
25037	976	11	He answereth and saith unto them, He that hath two coats, let him impart to him that hath none; and he that hath meat, let him do likewise.
25038	976	12	Then came also publicans to be baptized, and said unto him, Master, what shall we do?
25039	976	13	And he said unto them, Exact no more than that which is appointed you.
25040	976	14	And the soldiers likewise demanded of him, saying, And what shall we do? And he said unto them, Do violence to no man, neither accuse any falsely; and be content with your wages.
25041	976	15	And as the people were in expectation, and all men mused in their hearts of John, whether he were the Christ, or not;
25042	976	16	John answered, saying unto them all, I indeed baptize you with water; but one mightier than I cometh, the latchet of whose shoes I am not worthy to unloose: he shall baptize you with the Holy Ghost and with fire:
25043	976	17	Whose fan is in his hand, and he will throughly purge his floor, and will gather the wheat into his garner; but the chaff he will burn with fire unquenchable.
25044	976	18	And many other things in his exhortation preached he unto the people.
25045	976	19	But Herod the tetrarch, being reproved by him for Herodias his brother Philip's wife, and for all the evils which Herod had done,
25046	976	20	Added yet this above all, that he shut up John in prison.
25047	976	21	Now when all the people were baptized, it came to pass, that Jesus also being baptized, and praying, the heaven was opened,
25048	976	22	And the Holy Ghost descended in a bodily shape like a dove upon him, and a voice came from heaven, which said, Thou art my beloved Son; in thee I am well pleased.
25049	976	23	And Jesus himself began to be about thirty years of age, being (as was supposed) the son of Joseph, which was the son of Heli,
25050	976	24	Which was the son of Matthat, which was the son of Levi, which was the son of Melchi, which was the son of Janna, which was the son of Joseph,
25051	976	25	Which was the son of Mattathias, which was the son of Amos, which was the son of Naum, which was the son of Esli, which was the son of Nagge,
25052	976	26	Which was the son of Maath, which was the son of Mattathias, which was the son of Semei, which was the son of Joseph, which was the son of Juda,
25053	976	27	Which was the son of Joanna, which was the son of Rhesa, which was the son of Zorobabel, which was the son of Salathiel, which was the son of Neri,
25054	976	28	Which was the son of Melchi, which was the son of Addi, which was the son of Cosam, which was the son of Elmodam, which was the son of Er,
25055	976	29	Which was the son of Jose, which was the son of Eliezer, which was the son of Jorim, which was the son of Matthat, which was the son of Levi,
25056	976	30	Which was the son of Simeon, which was the son of Juda, which was the son of Joseph, which was the son of Jonan, which was the son of Eliakim,
25057	976	31	Which was the son of Melea, which was the son of Menan, which was the son of Mattatha, which was the son of Nathan, which was the son of David,
25058	976	32	Which was the son of Jesse, which was the son of Obed, which was the son of Booz, which was the son of Salmon, which was the son of Naasson,
25059	976	33	Which was the son of Aminadab, which was the son of Aram, which was the son of Esrom, which was the son of Phares, which was the son of Juda,
25060	976	34	Which was the son of Jacob, which was the son of Isaac, which was the son of Abraham, which was the son of Thara, which was the son of Nachor,
25061	976	35	Which was the son of Saruch, which was the son of Ragau, which was the son of Phalec, which was the son of Heber, which was the son of Sala,
25062	976	36	Which was the son of Cainan, which was the son of Arphaxad, which was the son of Sem, which was the son of Noe, which was the son of Lamech,
25063	976	37	Which was the son of Mathusala, which was the son of Enoch, which was the son of Jared, which was the son of Maleleel, which was the son of Cainan,
25064	976	38	Which was the son of Enos, which was the son of Seth, which was the son of Adam, which was the son of God.
25065	977	1	AND Jesus being full of the Holy Ghost returned from Jordan, and was led by the Spirit into the wilderness,
25066	977	2	Being forty days tempted of the devil. And in those days he did eat nothing: and when they were ended, he afterward hungered.
25067	977	3	And the devil said unto him, If thou be the Son of God, command this stone that it be made bread.
25068	977	4	And Jesus answered him, saying, It is written, That man shall not live by bread alone, but by every word of God.
25069	977	5	And the devil, taking him up into an high mountain, shewed unto him all the kingdoms of the world in a moment of time.
25070	977	6	And the devil said unto him, All this power will I give thee, and the glory of them: for that is delivered unto me; and to whomsoever I will I give it.
25071	977	7	If thou therefore wilt worship me, all shall be thine.
25072	977	8	And Jesus answered and said unto him, Get thee behind me, Satan: for it is written, Thou shalt worship the Lord thy God, and him only shalt thou serve.
25073	977	9	And he brought him to Jerusalem, and set him on a pinnacle of the temple, and said unto him, If thou be the Son of God, cast thyself down from hence:
25074	977	10	For it is written, He shall give his angels charge over thee, to keep thee:
25075	977	11	And in their hands they shall bear thee up, lest at any time thou dash thy foot against a stone.
25076	977	12	And Jesus answering said unto him, It is said, Thou shalt not tempt the Lord thy God.
25077	977	13	And when the devil had ended all the temptation, he departed from him for a season.
25078	977	14	And Jesus returned in the power of the Spirit into Galilee: and there went out a fame of him through all the region round about.
25079	977	15	And he taught in their synagogues, being glorified of all.
25080	977	16	And he came to Nazareth, where he had been brought up: and, as his custom was, he went into the synagogue on the sabbath day, and stood up for to read.
25081	977	17	And there was delivered unto him the book of the prophet Esaias. And when he had opened the book, he found the place where it was written,
25082	977	18	The Spirit of the Lord is upon me, because he hath anointed me to preach the gospel to the poor; he hath sent me to heal the brokenhearted, to preach deliverance to the captives, and recovering of sight to the blind, to set at liberty them that are bruised,
25083	977	19	To preach the acceptable year of the Lord.
25084	977	20	And he closed the book, and he gave it again to the minister, and sat down. And the eyes of all them that were in the synagogue were fastened on him.
25085	977	21	And he began to say unto them, This day is this scripture fulfilled in your ears.
25086	977	22	And all bare him witness, and wondered at the gracious words which proceeded out of his mouth. And they said, Is not this Joseph's son?
25087	977	23	And he said unto them, Ye will surely say unto me this proverb, Physician, heal thyself: whatsoever we have heard done in Capernaum, do also here in thy country.
25088	977	24	And he said, Verily I say unto you, No prophet is accepted in his own country.
25089	977	25	But I tell you of a truth, many widows were in Israel in the days of Elias, when the heaven was shut up three years and six months, when great famine was throughout all the land;
25090	977	26	But unto none of them was Elias sent, save unto Sarepta, a city of Sidon, unto a woman that was a widow.
25091	977	27	And many lepers were in Israel in the time of Eliseus the prophet; and none of them was cleansed, saving Naaman the Syrian.
25092	977	28	And all they in the synagogue, when they heard these things, were filled with wrath,
25093	977	29	And rose up, and thrust him out of the city, and led him unto the brow of the hill whereon their city was built, that they might cast him down headlong.
25094	977	30	But he passing through the midst of them went his way,
25095	977	31	And came down to Capernaum, a city of Galilee, and taught them on the sabbath days.
25096	977	32	And they were astonished at his doctrine: for his word was with power.
25097	977	33	And in the synagogue there was a man, which had a spirit of an unclean devil, and cried out with a loud voice,
25098	977	34	Saying, Let us alone; what have we to do with thee, thou Jesus of Nazareth? art thou come to destroy us? I know thee who thou art; the Holy One of God.
25099	977	35	And Jesus rebuked him, saying, Hold thy peace, and come out of him. And when the devil had thrown him in the midst, he came out of him, and hurt him not.
25100	977	36	And they were all amazed, and spake among themselves, saying, What a word is this! for with authority and power he commandeth the unclean spirits, and they come out.
25101	977	37	And the fame of him went out into every place of the country round about.
25102	977	38	And he arose out of the synagogue, and entered into Simon's house. And Simon's wife's mother was taken with a great fever; and they besought him for her.
25103	977	39	And he stood over her, and rebuked the fever; and it left her: and immediately she arose and ministered unto them.
25104	977	40	Now when the sun was setting, all they that had any sick with divers diseases brought them unto him; and he laid his hands on every one of them, and healed them.
25105	977	41	And devils also came out of many, crying out, and saying, Thou art Christ the Son of God. And he rebuking them suffered them not to speak: for they knew that he was Christ.
25106	977	42	And when it was day, he departed and went into a desert place: and the people sought him, and came unto him, and stayed him, that he should not depart from them.
25107	977	43	And he said unto them, I must preach the kingdom of God to other cities also: for therefore am I sent.
25108	977	44	And he preached in the synagogues of Galilee.
25109	978	1	AND it came to pass, that, as the people pressed upon him to hear the word of God, he stood by the lake of Gennesaret,
25110	978	2	And saw two ships standing by the lake: but the fishermen were gone out of them, and were washing their nets.
25111	978	3	And he entered into one of the ships, which was Simon's, and prayed him that he would thrust out a little from the land. And he sat down, and taught the people out of the ship.
25112	978	4	Now when he had left speaking, he said unto Simon, Launch out into the deep, and let down your nets for a draught.
25113	978	5	And Simon answering said unto him, Master, we have toiled all the night, and have taken nothing: nevertheless at thy word I will let down the net.
25114	978	6	And when they had this done, they inclosed a great multitude of fishes: and their net brake.
25115	978	7	And they beckoned unto their partners, which were in the other ship, that they should come and help them. And they came, and filled both the ships, so that they began to sink.
25116	978	8	When Simon Peter saw it, he fell down at Jesus' knees, saying, Depart from me; for I am a sinful man, O Lord.
25117	978	9	For he was astonished, and all that were with him, at the draught of the fishes which they had taken:
25118	978	10	And so was also James, and John, the sons of Zebedee, which were partners with Simon. And Jesus said unto Simon, Fear not; from henceforth thou shalt catch men.
25119	978	11	And when they had brought their ships to land, they forsook all, and followed him.
25120	978	12	And it came to pass, when he was in a certain city, behold a man full of leprosy: who seeing Jesus fell on his face, and besought him, saying, Lord, if thou wilt, thou canst make me clean.
25121	978	13	And he put forth his hand, and touched him, saying, I will: be thou clean. And immediately the leprosy departed from him.
25122	978	14	And he charged him to tell no man: but go, and shew thyself to the priest, and offer for thy cleansing, according as Moses commanded, for a testimony unto them.
25123	978	15	But so much the more went there a fame abroad of him: and great multitudes came together to hear, and to be healed by him of their infirmities.
25124	978	16	And he withdrew himself into the wilderness, and prayed.
25125	978	17	And it came to pass on a certain day, as he was teaching, that there were Pharisees and doctors of the law sitting by, which were come out of every town of Galilee, and Judaea, and Jerusalem: and the power of the Lord was present to heal them.
25126	978	18	And, behold, men brought in a bed a man which was taken with a palsy: and they sought means to bring him in, and to lay him before him.
25127	978	19	And when they could not find by what way they might bring him in because of the multitude, they went upon the housetop, and let him down through the tiling with his couch into the midst before Jesus.
25128	978	20	And when he saw their faith, he said unto him, Man, thy sins are forgiven thee.
25129	978	21	And the scribes and the Pharisees began to reason, saying, Who is this which speaketh blasphemies? Who can forgive sins, but God alone?
25130	978	22	But when Jesus perceived their thoughts, he answering said unto them, What reason ye in your hearts?
25131	978	23	Whether is easier, to say, Thy sins be forgiven thee; or to say, Rise up and walk?
25132	978	24	But that ye may know that the Son of man hath power upon earth to forgive sins, (he said unto the sick of the palsy,) I say unto thee, Arise, and take up thy couch, and go into thine house.
25133	978	25	And immediately he rose up before them, and took up that whereon he lay, and departed to his own house, glorifying God.
25134	978	26	And they were all amazed, and they glorified God, and were filled with fear, saying, We have seen strange things to day.
25135	978	27	And after these things he went forth, and saw a publican, named Levi, sitting at the receipt of custom: and he said unto him, Follow me.
25136	978	28	And he left all, rose up, and followed him.
25137	978	29	And Levi made him a great feast in his own house: and there was a great company of publicans and of others that sat down with them.
25138	978	30	But their scribes and Pharisees murmured against his disciples, saying, Why do ye eat and drink with publicans and sinners?
25139	978	31	And Jesus answering said unto them, They that are whole need not a physician; but they that are sick.
25140	978	32	I came not to call the righteous, but sinners to repentance.
25141	978	33	And they said unto him, Why do the disciples of John fast often, and make prayers, and likewise the disciples of the Pharisees; but thine eat and drink?
25142	978	34	And he said unto them, Can ye make the children of the bridechamber fast, while the bridegroom is with them?
25143	978	35	But the days will come, when the bridegroom shall be taken away from them, and then shall they fast in those days.
25144	978	36	And he spake also a parable unto them; No man putteth a piece of a new garment upon an old; if otherwise, then both the new maketh a rent, and the piece that was taken out of the new agreeth not with the old.
25145	978	37	And no man putteth new wine into old bottles; else the new wine will burst the bottles, and be spilled, and the bottles shall perish.
25146	978	38	But new wine must be put into new bottles; and both are preserved.
25147	978	39	No man also having drunk old wine straightway desireth new: for he saith, The old is better.
25148	979	1	AND it came to pass on the second sabbath after the first, that he went through the corn fields; and his disciples plucked the ears of corn, and did eat, rubbing them in their hands.
25149	979	2	And certain of the Pharisees said unto them, Why do ye that which is not lawful to do on the sabbath days?
25150	979	3	And Jesus answering them said, Have ye not read so much as this, what David did, when himself was an hungred, and they which were with him;
25151	979	4	How he went into the house of God, and did take and eat the shewbread, and gave also to them that were with him; which it is not lawful to eat but for the priests alone?
25152	979	5	And he said unto them, That the Son of man is Lord also of the sabbath.
25153	979	6	And it came to pass also on another sabbath, that he entered into the synagogue and taught: and there was a man whose right hand was withered.
25154	979	7	And the scribes and Pharisees watched him, whether he would heal on the sabbath day; that they might find an accusation against him.
25155	979	8	But he knew their thoughts, and said to the man which had the withered hand, Rise up, and stand forth in the midst. And he arose and stood forth.
25156	979	9	Then said Jesus unto them, I will ask you one thing; Is it lawful on the sabbath days to do good, or to do evil? to save life, or to destroy it?
25157	979	10	And looking round about upon them all, he said unto the man, Stretch forth thy hand. And he did so: and his hand was restored whole as the other.
25158	979	11	And they were filled with madness; and communed one with another what they might do to Jesus.
25159	979	12	And it came to pass in those days, that he went out into a mountain to pray, and continued all night in prayer to God.
25160	979	13	And when it was day, he called unto him his disciples: and of them he chose twelve, whom also he named apostles;
25161	979	14	Simon, (whom he also named Peter,) and Andrew his brother, James and John, Philip and Bartholomew,
25162	979	15	Matthew and Thomas, James the son of Alphaeus, and Simon called Zelotes,
25163	979	16	And Judas the brother of James, and Judas Iscariot, which also was the traitor.
25164	979	17	And he came down with them, and stood in the plain, and the company of his disciples, and a great multitude of people out of all Judaea and Jerusalem, and from the sea coast of Tyre and Sidon, which came to hear him, and to be healed of their diseases;
25165	979	18	And they that were vexed with unclean spirits: and they were healed.
25166	979	19	And the whole multitude sought to touch him: for there went virtue out of him, and healed them all.
25167	979	20	And he lifted up his eyes on his disciples, and said, Blessed be ye poor: for yours is the kingdom of God.
25168	979	21	Blessed are ye that hunger now: for ye shall be filled. Blessed are ye that weep now: for ye shall laugh.
25169	979	22	Blessed are ye, when men shall hate you, and when they shall separate you from their company, and shall reproach you, and cast out your name as evil, for the Son of man's sake.
25170	979	23	Rejoice ye in that day, and leap for joy: for, behold, your reward is great in heaven: for in the like manner did their fathers unto the prophets.
25171	979	24	But woe unto you that are rich! for ye have received your consolation.
25172	979	25	Woe unto you that are full! for ye shall hunger. Woe unto you that laugh now! for ye shall mourn and weep.
25173	979	26	Woe unto you, when all men shall speak well of you! for so did their fathers to the false prophets.
25174	979	27	But I say unto you which hear, Love your enemies, do good to them which hate you,
25175	979	28	Bless them that curse you, and pray for them which despitefully use you.
25176	979	29	And unto him that smiteth thee on the one cheek offer also the other; and him that taketh away thy cloke forbid not to take thy coat also.
25177	979	30	Give to every man that asketh of thee; and of him that taketh away thy goods ask them not again.
25178	979	31	And as ye would that men should do to you, do ye also to them likewise.
25179	979	32	For if ye love them which love you, what thank have ye? for sinners also love those that love them.
25180	979	33	And if ye do good to them which do good to you, what thank have ye? for sinners also do even the same.
25181	979	34	And if ye lend to them of whom ye hope to receive, what thank have ye? for sinners also lend to sinners, to receive as much again.
25182	979	35	But love ye your enemies, and do good, and lend, hoping for nothing again; and your reward shall be great, and ye shall be the children of the Highest: for he is kind unto the unthankful and to the evil.
25183	979	36	Be ye therefore merciful, as your Father also is merciful.
25184	979	37	Judge not, and ye shall not be judged: condemn not, and ye shall not be condemned: forgive, and ye shall be forgiven:
25185	979	38	Give, and it shall be given unto you; good measure, pressed down, and shaken together, and running over, shall men give into your bosom. For with the same measure that ye mete withal it shall be measured to you again.
25186	979	39	And he spake a parable unto them, Can the blind lead the blind? shall they not both fall into the ditch?
25187	979	40	The disciple is not above his master: but every one that is perfect shall be as his master.
25188	979	41	And why beholdest thou the mote that is in thy brother's eye, but perceivest not the beam that is in thine own eye?
25189	979	42	Either how canst thou say to thy brother, Brother, let me pull out the mote that is in thine eye, when thou thyself beholdest not the beam that is in thine own eye? Thou hypocrite, cast out first the beam out of thine own eye, and then shalt thou see clearly to pull out the mote that is in thy brother's eye.
25190	979	43	For a good tree bringeth not forth corrupt fruit; neither doth a corrupt tree bring forth good fruit.
25191	979	44	For every tree is known by his own fruit. For of thorns men do not gather figs, nor of a bramble bush gather they grapes.
25192	979	45	A good man out of the good treasure of his heart bringeth forth that which is good; and an evil man out of the evil treasure of his heart bringeth forth that which is evil: for of the abundance of the heart his mouth speaketh.
25193	979	46	And why call ye me, Lord, Lord, and do not the things which I say?
25194	979	47	Whosoever cometh to me, and heareth my sayings, and doeth them, I will shew you to whom he is like:
25195	979	48	He is like a man which built an house, and digged deep, and laid the foundation on a rock: and when the flood arose, the stream beat vehemently upon that house, and could not shake it: for it was founded upon a rock.
25196	979	49	But he that heareth, and doeth not, is like a man that without a foundation built an house upon the earth; against which the stream did beat vehemently, and immediately it fell; and the ruin of that house was great.
25197	980	1	NOW when he had ended all his sayings in the audience of the people, he entered into Capernaum.
25198	980	2	And a certain centurion's servant, who was dear unto him, was sick, and ready to die.
25199	980	3	And when he heard of Jesus, he sent unto him the elders of the Jews, beseeching him that he would come and heal his servant.
25200	980	4	And when they came to Jesus, they besought him instantly, saying, That he was worthy for whom he should do this:
25201	980	5	For he loveth our nation, and he hath built us a synagogue.
25202	980	6	Then Jesus went with them. And when he was now not far from the house, the centurion sent friends to him, saying unto him, Lord, trouble not thyself: for I am not worthy that thou shouldest enter under my roof:
25203	980	7	Wherefore neither thought I myself worthy to come unto thee: but say in a word, and my servant shall be healed.
25204	980	8	For I also am a man set under authority, having under me soldiers, and I say unto one, Go, and he goeth; and to another, Come, and he cometh; and to my servant, Do this, and he doeth it.
25205	980	9	When Jesus heard these things, he marvelled at him, and turned him about, and said unto the people that followed him, I say unto you, I have not found so great faith, no, not in Israel.
25206	980	10	And they that were sent, returning to the house, found the servant whole that had been sick.
25207	980	11	And it came to pass the day after, that he went into a city called Nain; and many of his disciples went with him, and much people.
25208	980	12	Now when he came nigh to the gate of the city, behold, there was a dead man carried out, the only son of his mother, and she was a widow: and much people of the city was with her.
25209	980	13	And when the Lord saw her, he had compassion on her, and said unto her, Weep not.
25210	980	14	And he came and touched the bier: and they that bare him stood still. And he said, Young man, I say unto thee, Arise.
25211	980	15	And he that was dead sat up, and began to speak. And he delivered him to his mother.
25212	980	16	And there came a fear on all: and they glorified God, saying, That a great prophet is risen up among us; and, That God hath visited his people.
25213	980	17	And this rumour of him went forth throughout all Judaea, and throughout all the region round about.
25214	980	18	And the disciples of John shewed him of all these things.
25215	980	19	And John calling unto him two of his disciples sent them to Jesus, saying, Art thou he that should come? or look we for another?
25216	980	20	When the men were come unto him, they said, John Baptist hath sent us unto thee, saying, Art thou he that should come? or look we for another?
25217	980	21	And in that same hour he cured many of their infirmities and plagues, and of evil spirits; and unto many that were blind he gave sight.
25218	980	22	Then Jesus answering said unto them, Go your way, and tell John what things ye have seen and heard; how that the blind see, the lame walk, the lepers are cleansed, the deaf hear, the dead are raised, to the poor the gospel is preached.
25219	980	23	And blessed is he, whosoever shall not be offended in me.
25220	980	24	And when the messengers of John were departed, he began to speak unto the people concerning John, What went ye out into the wilderness for to see? A reed shaken with the wind?
25221	980	25	But what went ye out for to see? A man clothed in soft raiment? Behold, they which are gorgeously apparelled, and live delicately, are in kings' courts.
25222	980	26	But what went ye out for to see? A prophet? Yea, I say unto you, and much more than a prophet.
25223	980	27	This is he, of whom it is written, Behold, I send my messenger before thy face, which shall prepare thy way before thee.
25224	980	28	For I say unto you, Among those that are born of women there is not a greater prophet than John the Baptist: but he that is least in the kingdom of God is greater than he.
25225	980	29	And all the people that heard him, and the publicans, justified God, being baptized with the baptism of John.
25226	980	30	But the Pharisees and lawyers rejected the counsel of God against themselves, being not baptized of him.
25227	980	31	And the Lord said, Whereunto then shall I liken the men of this generation? and to what are they like?
25228	980	32	They are like unto children sitting in the marketplace, and calling one to another, and saying, We have piped unto you, and ye have not danced; we have mourned to you, and ye have not wept.
25229	980	33	For John the Baptist came neither eating bread nor drinking wine; and ye say, He hath a devil.
25230	980	34	The Son of man is come eating and drinking; and ye say, Behold a gluttonous man, and a winebibber, a friend of publicans and sinners!
25231	980	35	But wisdom is justified of all her children.
25232	980	36	And one of the Pharisees desired him that he would eat with him. And he went into the Pharisee's house, and sat down to meat.
25233	980	37	And, behold, a woman in the city, which was a sinner, when she knew that Jesus sat at meat in the Pharisee's house, brought an alabaster box of ointment,
25234	980	38	And stood at his feet behind him weeping, and began to wash his feet with tears, and did wipe them with the hairs of her head, and kissed his feet, and anointed them with the ointment.
25235	980	39	Now when the Pharisee which had bidden him saw it, he spake within himself, saying, This man, if he were a prophet, would have known who and what manner of woman this is that toucheth him: for she is a sinner.
25236	980	40	And Jesus answering said unto him, Simon, I have somewhat to say unto thee. And he saith, Master, say on.
25237	980	41	There was a certain creditor which had two debtors: the one owed five hundred pence, and the other fifty.
25238	980	42	And when they had nothing to pay, he frankly forgave them both. Tell me therefore, which of them will love him most?
25239	980	43	Simon answered and said, I suppose that he, to whom he forgave most. And he said unto him, Thou hast rightly judged.
25240	980	44	And he turned to the woman, and said unto Simon, Seest thou this woman? I entered into thine house, thou gavest me no water for my feet: but she hath washed my feet with tears, and wiped them with the hairs of her head.
25241	980	45	Thou gavest me no kiss: but this woman since the time I came in hath not ceased to kiss my feet.
25242	980	46	My head with oil thou didst not anoint: but this woman hath anointed my feet with ointment.
25243	980	47	Wherefore I say unto thee, Her sins, which are many, are forgiven; for she loved much: but to whom little is forgiven, the same loveth little.
25244	980	48	And he said unto her, Thy sins are forgiven.
25245	980	49	And they that sat at meat with him began to say within themselves, Who is this that forgiveth sins also?
25246	980	50	And he said to the woman, Thy faith hath saved thee; go in peace.
25247	981	1	AND it came to pass afterward, that he went throughout every city and village, preaching and shewing the glad tidings of the kingdom of God: and the twelve were with him,
25248	981	2	And certain women, which had been healed of evil spirits and infirmities, Mary called Magdalene, out of whom went seven devils,
25249	981	3	And Joanna the wife of Chuza Herod's steward, and Susanna, and many others, which ministered unto him of their substance.
25250	981	4	And when much people were gathered together, and were come to him out of every city, he spake by a parable:
25251	981	5	A sower went out to sow his seed: and as he sowed, some fell by the way side; and it was trodden down, and the fowls of the air devoured it.
25252	981	6	And some fell upon a rock; and as soon as it was sprung up, it withered away, because it lacked moisture.
25253	981	7	And some fell among thorns; and the thorns sprang up with it, and choked it.
25254	981	8	And other fell on good ground, and sprang up, and bare fruit an hundredfold. And when he had said these things, he cried, He that hath ears to hear, let him hear.
25255	981	9	And his disciples asked him, saying, What might this parable be?
25256	981	10	And he said, Unto you it is given to know the mysteries of the kingdom of God: but to others in parables; that seeing they might not see, and hearing they might not understand.
25257	981	11	Now the parable is this: The seed is the word of God.
25258	981	12	Those by the way side are they that hear; then cometh the devil, and taketh away the word out of their hearts, lest they should believe and be saved.
25259	981	13	They on the rock are they, which, when they hear, receive the word with joy; and these have no root, which for a while believe, and in time of temptation fall away.
25260	981	14	And that which fell among thorns are they, which, when they have heard, go forth, and are choked with cares and riches and pleasures of this life, and bring no fruit to perfection.
25261	981	15	But that on the good ground are they, which in an honest and good heart, having heard the word, keep it, and bring forth fruit with patience.
25262	981	16	No man, when he hath lighted a candle, covereth it with a vessel, or putteth it under a bed; but setteth it on a candlestick, that they which enter in may see the light.
25263	981	17	For nothing is secret, that shall not be made manifest; neither any thing hid, that shall not be known and come abroad.
25264	981	18	Take heed therefore how ye hear: for whosoever hath, to him shall be given; and whosoever hath not, from him shall be taken even that which he seemeth to have.
25265	981	19	Then came to him his mother and his brethren, and could not come at him for the press.
25266	981	20	And it was told him by certain which said, Thy mother and thy brethren stand without, desiring to see thee.
25267	981	21	And he answered and said unto them, My mother and my brethren are these which hear the word of God, and do it.
25268	981	22	Now it came to pass on a certain day, that he went into a ship with his disciples: and he said unto them, Let us go over unto the other side of the lake. And they launched forth.
25269	981	23	But as they sailed he fell asleep: and there came down a storm of wind on the lake; and they were filled with water, and were in jeopardy.
25270	981	24	And they came to him, and awoke him, saying, Master, master, we perish. Then he arose, and rebuked the wind and the raging of the water: and they ceased, and there was a calm.
25271	981	25	And he said unto them, Where is your faith? And they being afraid wondered, saying one to another, What manner of man is this! for he commandeth even the winds and water, and they obey him.
25272	981	26	And they arrived at the country of the Gadarenes, which is over against Galilee.
25273	981	27	And when he went forth to land, there met him out of the city a certain man, which had devils long time, and ware no clothes, neither abode in any house, but in the tombs.
25274	981	28	When he saw Jesus, he cried out, and fell down before him, and with a loud voice said, What have I to do with thee, Jesus, thou Son of God most high? I beseech thee, torment me not.
25275	981	29	(For he had commanded the unclean spirit to come out of the man. For oftentimes it had caught him: and he was kept bound with chains and in fetters; and he brake the bands, and was driven of the devil into the wilderness.)
25276	981	30	And Jesus asked him, saying, What is thy name? And he said, Legion: because many devils were entered into him.
25277	981	31	And they besought him that he would not command them to go out into the deep.
25278	981	32	And there was there an herd of many swine feeding on the mountain: and they besought him that he would suffer them to enter into them. And he suffered them.
25279	981	33	Then went the devils out of the man, and entered into the swine: and the herd ran violently down a steep place into the lake, and were choked.
25280	981	34	When they that fed them saw what was done, they fled, and went and told it in the city and in the country.
25281	981	35	Then they went out to see what was done; and came to Jesus, and found the man, out of whom the devils were departed, sitting at the feet of Jesus, clothed, and in his right mind: and they were afraid.
25282	981	36	They also which saw it told them by what means he that was possessed of the devils was healed.
25283	981	37	Then the whole multitude of the country of the Gadarenes round about besought him to depart from them; for they were taken with great fear: and he went up into the ship, and returned back again.
25284	981	38	Now the man out of whom the devils were departed besought him that he might be with him: but Jesus sent him away, saying,
25285	981	39	Return to thine own house, and shew how great things God hath done unto thee. And he went his way, and published throughout the whole city how great things Jesus had done unto him.
25286	981	40	And it came to pass, that, when Jesus was returned, the people gladly received him: for they were all waiting for him.
25287	981	41	And, behold, there came a man named Jairus, and he was a ruler of the synagogue: and he fell down at Jesus' feet, and besought him that he would come into his house:
25288	981	42	For he had one only daughter, about twelve years of age, and she lay a dying. But as he went the people thronged him.
25289	981	43	And a woman having an issue of blood twelve years, which had spent all her living upon physicians, neither could be healed of any,
25290	981	44	Came behind him, and touched the border of his garment: and immediately her issue of blood stanched.
25291	981	45	And Jesus said, Who touched me? When all denied, Peter and they that were with him said, Master, the multitude throng thee and press thee, and sayest thou, Who touched me?
25292	981	46	And Jesus said, Somebody hath touched me: for I perceive that virtue is gone out of me.
25293	981	47	And when the woman saw that she was not hid, she came trembling, and falling down before him, she declared unto him before all the people for what cause she had touched him and how she was healed immediately.
25294	981	48	And he said unto her, Daughter, be of good comfort: thy faith hath made thee whole; go in peace.
25295	981	49	While he yet spake, there cometh one from the ruler of the synagogue's house, saying to him, Thy daughter is dead; trouble not the Master.
25296	981	50	But when Jesus heard it, he answered him, saying, Fear not: believe only, and she shall be made whole.
25297	981	51	And when he came into the house, he suffered no man to go in, save Peter, and James, and John, and the father and the mother of the maiden.
25298	981	52	And all wept, and bewailed her: but he said, Weep not; she is not dead, but sleepeth.
25299	981	53	And they laughed him to scorn, knowing that she was dead.
25300	981	54	And he put them all out, and took her by the hand, and called, saying, Maid, arise.
25301	981	55	And her spirit came again, and she arose straightway: and he commanded to give her meat.
25302	981	56	And her parents were astonished: but he charged them that they should tell no man what was done.
25303	982	1	THEN he called his twelve disciples together, and gave them power and authority over all devils, and to cure diseases.
25304	982	2	And he sent them to preach the kingdom of God, and to heal the sick.
25305	982	3	And he said unto them, Take nothing for your journey, neither staves, nor scrip, neither bread, neither money; neither have two coats apiece.
25306	982	4	And whatsoever house ye enter into, there abide, and thence depart.
25307	982	5	And whosoever will not receive you, when ye go out of that city, shake off the very dust from your feet for a testimony against them.
25308	982	6	And they departed, and went through the towns, preaching the gospel, and healing every where.
25309	982	7	Now Herod the tetrarch heard of all that was done by him: and he was perplexed, because that it was said of some, that John was risen from the dead;
25310	982	8	And of some, that Elias had appeared; and of others, that one of the old prophets was risen again.
25311	982	9	And Herod said, John have I beheaded: but who is this, of whom I hear such things? And he desired to see him.
25312	982	10	And the apostles, when they were returned, told him all that they had done. And he took them, and went aside privately into a desert place belonging to the city called Bethsaida.
25313	982	11	And the people, when they knew it, followed him: and he received them, and spake unto them of the kingdom of God, and healed them that had need of healing.
25314	982	12	And when the day began to wear away, then came the twelve, and said unto him, Send the multitude away, that they may go into the towns and country round about, and lodge, and get victuals: for we are here in a desert place.
25315	982	13	But he said unto them, Give ye them to eat. And they said, We have no more but five loaves and two fishes; except we should go and buy meat for all this people.
25316	982	14	For they were about five thousand men. And he said to his disciples, Make them sit down by fifties in a company.
25317	982	15	And they did so, and made them all sit down.
25318	982	16	Then he took the five loaves and the two fishes, and looking up to heaven, he blessed them, and brake, and gave to the disciples to set before the multitude.
25319	982	17	And they did eat, and were all filled: and there was taken up of fragments that remained to them twelve baskets.
25320	982	18	And it came to pass, as he was alone praying, his disciples were with him: and he asked them, saying, Whom say the people that I am?
25321	982	19	They answering said, John the Baptist; but some say, Elias; and others say, that one of the old prophets is risen again.
25322	982	20	He said unto them, But whom say ye that I am? Peter answering said, The Christ of God.
25323	982	21	And he straitly charged them, and commanded them to tell no man that thing;
25324	982	22	Saying, The Son of man must suffer many things, and be rejected of the elders and chief priests and scribes, and be slain, and be raised the third day.
25325	982	23	And he said to them all, If any man will come after me, let him deny himself, and take up his cross daily, and follow me.
25326	982	24	For whosoever will save his life shall lose it: but whosoever will lose his life for my sake, the same shall save it.
25327	982	25	For what is a man advantaged, if he gain the whole world, and lose himself, or be cast away?
25328	982	26	For whosoever shall be ashamed of me and of my words, of him shall the Son of man be ashamed, when he shall come in his own glory, and in his Father's, and of the holy angels.
25329	982	27	But I tell you of a truth, there be some standing here, which shall not taste of death, till they see the kingdom of God.
25330	982	28	And it came to pass about an eight days after these sayings, he took Peter and John and James, and went up into a mountain to pray.
25331	982	29	And as he prayed, the fashion of his countenance was altered, and his raiment was white and glistering.
25332	982	30	And, behold, there talked with him two men, which were Moses and Elias:
25333	982	31	Who appeared in glory, and spake of his decease which he should accomplish at Jerusalem.
25334	982	32	But Peter and they that were with him were heavy with sleep: and when they were awake, they saw his glory, and the two men that stood with him.
25335	982	33	And it came to pass, as they departed from him, Peter said unto Jesus, Master, it is good for us to be here: and let us make three tabernacles; one for thee, and one for Moses, and one for Elias: not knowing what he said.
25336	982	34	While he thus spake, there came a cloud, and overshadowed them: and they feared as they entered into the cloud.
25337	982	35	And there came a voice out of the cloud, saying, This is my beloved Son: hear him.
25338	982	36	And when the voice was past, Jesus was found alone. And they kept it close, and told no man in those days any of those things which they had seen.
25339	982	37	And it came to pass, that on the next day, when they were come down from the hill, much people met him.
25340	982	38	And, behold, a man of the company cried out, saying, Master, I beseech thee, look upon my son: for he is mine only child.
25341	982	39	And, lo, a spirit taketh him, and he suddenly crieth out; and it teareth him that he foameth again, and bruising him hardly departeth from him.
25342	982	40	And I besought thy disciples to cast him out; and they could not.
25343	982	41	And Jesus answering said, O faithless and perverse generation, how long shall I be with you, and suffer you? Bring thy son hither.
25344	982	42	And as he was yet a coming, the devil threw him down, and tare him. And Jesus rebuked the unclean spirit, and healed the child, and delivered him again to his father.
25345	982	43	And they were all amazed at the mighty power of God. But while they wondered every one at all things which Jesus did, he said unto his disciples,
25346	982	44	Let these sayings sink down into your ears: for the Son of man shall be delivered into the hands of men.
25347	982	45	But they understood not this saying, and it was hid from them, that they perceived it not: and they feared to ask him of that saying.
25348	982	46	Then there arose a reasoning among them, which of them should be greatest.
25349	982	47	And Jesus, perceiving the thought of their heart, took a child, and set him by him,
25350	982	48	And said unto them, Whosoever shall receive this child in my name receiveth me: and whosoever shall receive me receiveth him that sent me: for he that is least among you all, the same shall be great.
25351	982	49	And John answered and said, Master, we saw one casting out devils in thy name; and we forbad him, because he followeth not with us.
25352	982	50	And Jesus said unto him, Forbid him not: for he that is not against us is for us.
25353	982	51	And it came to pass, when the time was come that he should be received up, he stedfastly set his face to go to Jerusalem,
25354	982	52	And sent messengers before his face: and they went, and entered into a village of the Samaritans, to make ready for him.
25355	982	53	And they did not receive him, because his face was as though he would go to Jerusalem.
25356	982	54	And when his disciples James and John saw this, they said, Lord, wilt thou that we command fire to come down from heaven, and consume them, even as Elias did?
25357	982	55	But he turned, and rebuked them, and said, Ye know not what manner of spirit ye are of.
25358	982	56	For the Son of man is not come to destroy men's lives, but to save them. And they went to another village.
25359	982	57	And it came to pass, that, as they went in the way, a certain man said unto him, Lord, I will follow thee whithersoever thou goest.
25360	982	58	And Jesus said unto him, Foxes have holes, and birds of the air have nests; but the Son of man hath not where to lay his head.
25361	982	59	And he said unto another, Follow me. But he said, Lord, suffer me first to go and bury my father.
25362	982	60	Jesus said unto him, Let the dead bury their dead: but go thou and preach the kingdom of God.
25363	982	61	And another also said, Lord, I will follow thee; but let me first go bid them farewell, which are at home at my house.
25364	982	62	And Jesus said unto him, No man, having put his hand to the plough, and looking back, is fit for the kingdom of God.
25365	983	1	AFTER these things the Lord appointed other seventy also, and sent them two and two before his face into every city and place, whither he himself would come.
25366	983	2	Therefore said he unto them, The harvest truly is great, but the labourers are few: pray ye therefore the Lord of the harvest, that he would send forth labourers into his harvest.
25367	983	3	Go your ways: behold, I send you forth as lambs among wolves.
25368	983	4	Carry neither purse, nor scrip, nor shoes: and salute no man by the way.
25369	983	5	And into whatsoever house ye enter, first say, Peace be to this house.
25370	983	6	And if the son of peace be there, your peace shall rest upon it: if not, it shall turn to you again.
25371	983	7	And in the same house remain, eating and drinking such things as they give: for the labourer is worthy of his hire. Go not from house to house.
25372	983	8	And into whatsoever city ye enter, and they receive you, eat such things as are set before you:
25373	983	9	And heal the sick that are therein, and say unto them, The kingdom of God is come nigh unto you.
25374	983	10	But into whatsoever city ye enter, and they receive you not, go your ways out into the streets of the same, and say,
25375	983	11	Even the very dust of your city, which cleaveth on us, we do wipe off against you: notwithstanding be ye sure of this, that the kingdom of God is come nigh unto you.
25376	983	12	But I say unto you, that it shall be more tolerable in that day for Sodom, than for that city.
25377	983	13	Woe unto thee, Chorazin! woe unto thee, Bethsaida! for if the mighty works had been done in Tyre and Sidon, which have been done in you, they had a great while ago repented, sitting in sackcloth and ashes.
25378	983	14	But it shall be more tolerable for Tyre and Sidon at the judgment, than for you.
25379	983	15	And thou, Capernaum, which art exalted to heaven, shalt be thrust down to hell.
25380	983	16	He that heareth you heareth me; and he that despiseth you despiseth me; and he that despiseth me despiseth him that sent me.
25381	983	17	And the seventy returned again with joy, saying, Lord, even the devils are subject unto us through thy name.
25382	983	18	And he said unto them, I beheld Satan as lightning fall from heaven.
25383	983	19	Behold, I give unto you power to tread on serpents and scorpions, and over all the power of the enemy: and nothing shall by any means hurt you.
25384	983	20	Notwithstanding in this rejoice not, that the spirits are subject unto you; but rather rejoice, because your names are written in heaven.
25385	983	21	In that hour Jesus rejoiced in spirit, and said, I thank thee, O Father, Lord of heaven and earth, that thou hast hid these things from the wise and prudent, and hast revealed them unto babes: even so, Father; for so it seemed good in thy sight.
25386	983	22	All things are delivered to me of my Father: and no man knoweth who the Son is, but the Father; and who the Father is, but the Son, and he to whom the Son will reveal him.
25387	983	23	And he turned him unto his disciples, and said privately, Blessed are the eyes which see the things that ye see:
25388	983	24	For I tell you, that many prophets and kings have desired to see those things which ye see, and have not seen them; and to hear those things which ye hear, and have not heard them.
25389	983	25	And, behold, a certain lawyer stood up, and tempted him, saying, Master, what shall I do to inherit eternal life?
25390	983	26	He said unto him, What is written in the law? how readest thou?
25391	983	27	And he answering said, Thou shalt love the Lord thy God with all thy heart, and with all thy soul, and with all thy strength, and with all thy mind; and thy neighbour as thyself.
25392	983	28	And he said unto him, Thou hast answered right: this do, and thou shalt live.
25393	983	29	But he, willing to justify himself, said unto Jesus, And who is my neighbour?
25394	983	30	And Jesus answering said, A certain man went down from Jerusalem to Jericho, and fell among thieves, which stripped him of his raiment, and wounded him, and departed, leaving him half dead.
25395	983	31	And by chance there came down a certain priest that way: and when he saw him, he passed by on the other side.
25396	983	32	And likewise a Levite, when he was at the place, came and looked on him, and passed by on the other side.
25397	983	33	But a certain Samaritan, as he journeyed, came where he was: and when he saw him, he had compassion on him,
25398	983	34	And went to him, and bound up his wounds, pouring in oil and wine, and set him on his own beast, and brought him to an inn, and took care of him.
25399	983	35	And on the morrow when he departed, he took out two pence, and gave them to the host, and said unto him, Take care of him; and whatsoever thou spendest more, when I come again, I will repay thee.
25400	983	36	Which now of these three, thinkest thou, was neighbour unto him that fell among the thieves?
25401	983	37	And he said, He that shewed mercy on him. Then said Jesus unto him, Go, and do thou likewise.
25402	983	38	Now it came to pass, as they went, that he entered into a certain village: and a certain woman named Martha received him into her house.
25403	983	39	And she had a sister called Mary, which also sat at Jesus' feet, and heard his word.
25404	983	40	But Martha was cumbered about much serving, and came to him, and said, Lord, dost thou not care that my sister hath left me to serve alone? bid her therefore that she help me.
25405	983	41	And Jesus answered and said unto her, Martha, Martha, thou art careful and troubled about many things:
25406	983	42	But one thing is needful: and Mary hath chosen that good part, which shall not be taken away from her.
25407	984	1	AND it came to pass, that, as he was praying in a certain place, when he ceased, one of his disciples said unto him, Lord, teach us to pray, as John also taught his disciples.
25408	984	2	And he said unto them, When ye pray, say, Our Father which art in heaven, Hallowed be thy name. Thy kingdom come. Thy will be done, as in heaven, so in earth.
25409	984	3	Give us day by day our daily bread.
25410	984	4	And forgive us our sins; for we also forgive every one that is indebted to us. And lead us not into temptation; but deliver us from evil.
25411	984	5	And he said unto them, Which of you shall have a friend, and shall go unto him at midnight, and say unto him, Friend, lend me three loaves;
25412	984	6	For a friend of mine in his journey is come to me, and I have nothing to set before him?
25413	984	7	And he from within shall answer and say, Trouble me not: the door is now shut, and my children are with me in bed; I cannot rise and give thee.
25414	984	8	I say unto you, Though he will not rise and give him, because he is his friend, yet because of his importunity he will rise and give him as many as he needeth.
25415	984	9	And I say unto you, Ask, and it shall be given you; seek, and ye shall find; knock, and it shall be opened unto you.
25416	984	10	For every one that asketh receiveth; and he that seeketh findeth; and to him that knocketh it shall be opened.
25417	984	11	If a son shall ask bread of any of you that is a father, will he give him a stone? or if he ask a fish, will he for a fish give him a serpent?
25418	984	12	Or if he shall ask an egg, will he offer him a scorpion?
25419	984	13	If ye then, being evil, know how to give good gifts unto your children: how much more shall your heavenly Father give the Holy Spirit to them that ask him?
25420	984	14	And he was casting out a devil, and it was dumb. And it came to pass, when the devil was gone out, the dumb spake; and the people wondered.
25421	984	15	But some of them said, He casteth out devils through Beelzebub the chief of the devils.
25422	984	16	And others, tempting him, sought of him a sign from heaven.
25423	984	17	But he, knowing their thoughts, said unto them, Every kingdom divided against itself is brought to desolation; and a house divided against a house falleth.
25424	984	18	If Satan also be divided against himself, how shall his kingdom stand? because ye say that I cast out devils through Beelzebub.
25425	984	19	And if I by Beelzebub cast out devils, by whom do your sons cast them out? therefore shall they be your judges.
25426	984	20	But if I with the finger of God cast out devils, no doubt the kingdom of God is come upon you.
25427	984	21	When a strong man armed keepeth his palace, his goods are in peace:
25428	984	22	But when a stronger than he shall come upon him, and overcome him, he taketh from him all his armour wherein he trusted, and divideth his spoils.
25429	984	23	He that is not with me is against me: and he that gathereth not with me scattereth.
25430	984	24	When the unclean spirit is gone out of a man, he walketh through dry places, seeking rest; and finding none, he saith, I will return unto my house whence I came out.
25431	984	25	And when he cometh, he findeth it swept and garnished.
25432	984	26	Then goeth he, and taketh to him seven other spirits more wicked than himself; and they enter in, and dwell there: and the last state of that man is worse than the first.
25433	984	27	And it came to pass, as he spake these things, a certain woman of the company lifted up her voice, and said unto him, Blessed is the womb that bare thee, and the paps which thou hast sucked.
25434	984	28	But he said, Yea rather, blessed are they that hear the word of God, and keep it.
25435	984	29	And when the people were gathered thick together, he began to say, This is an evil generation: they seek a sign; and there shall no sign be given it, but the sign of Jonas the prophet.
25436	984	30	For as Jonas was a sign unto the Ninevites, so shall also the Son of man be to this generation.
25437	984	31	The queen of the south shall rise up in the judgment with the men of this generation, and condemn them: for she came from the utmost parts of the earth to hear the wisdom of Solomon; and, behold, a greater than Solomon is here.
25438	984	32	The men of Nineve shall rise up in the judgment with this generation, and shall condemn it: for they repented at the preaching of Jonas; and, behold, a greater than Jonas is here.
25439	984	33	No man, when he hath lighted a candle, putteth it in a secret place, neither under a bushel, but on a candlestick, that they which come in may see the light.
25440	984	34	The light of the body is the eye: therefore when thine eye is single, thy whole body also is full of light; but when thine eye is evil, thy body also is full of darkness.
25441	984	35	Take heed therefore that the light which is in thee be not darkness.
25442	984	36	If thy whole body therefore be full of light, having no part dark, the whole shall be full of light, as when the bright shining of a candle doth give thee light.
25443	984	37	And as he spake, a certain Pharisee besought him to dine with him: and he went in, and sat down to meat.
25444	984	38	And when the Pharisee saw it, he marvelled that he had not first washed before dinner.
25445	984	39	And the Lord said unto him, Now do ye Pharisees make clean the outside of the cup and the platter; but your inward part is full of ravening and wickedness.
25446	984	40	Ye fools, did not he that made that which is without make that which is within also?
25447	984	41	But rather give alms of such things as ye have; and, behold, all things are clean unto you.
25448	984	42	But woe unto you, Pharisees! for ye tithe mint and rue and all manner of herbs, and pass over judgment and the love of God: these ought ye to have done, and not to leave the other undone.
25449	984	43	Woe unto you, Pharisees! for ye love the uppermost seats in the synagogues, and greetings in the markets.
25450	984	44	Woe unto you, scribes and Pharisees, hypocrites! for ye are as graves which appear not, and the men that walk over them are not aware of them.
25451	984	45	Then answered one of the lawyers, and said unto him, Master, thus saying thou reproachest us also.
25452	984	46	And he said, Woe unto you also, ye lawyers! for ye lade men with burdens grievous to be borne, and ye yourselves touch not the burdens with one of your fingers.
25453	984	47	Woe unto you! for ye build the sepulchres of the prophets, and your fathers killed them.
25454	984	48	Truly ye bear witness that ye allow the deeds of your fathers: for they indeed killed them, and ye build their sepulchres.
25455	984	49	Therefore also said the wisdom of God, I will send them prophets and apostles, and some of them they shall slay and persecute:
25456	984	50	That the blood of all the prophets, which was shed from the foundation of the world, may be required of this generation;
25457	984	51	From the blood of Abel unto the blood of Zacharias, which perished between the altar and the temple: verily I say unto you, It shall be required of this generation.
25458	984	52	Woe unto you, lawyers! for ye have taken away the key of knowledge: ye entered not in yourselves, and them that were entering in ye hindered.
25459	984	53	And as he said these things unto them, the scribes and the Pharisees began to urge him vehemently, and to provoke him to speak of many things:
25460	984	54	Laying wait for him, and seeking to catch something out of his mouth, that they might accuse him.
25461	985	1	IN the mean time, when there were gathered together an innumerable multitude of people, insomuch that they trode one upon another, he began to say unto his disciples first of all, Beware ye of the leaven of the Pharisees, which is hypocrisy.
25462	985	2	For there is nothing covered, that shall not be revealed; neither hid, that shall not be known.
25463	985	3	Therefore whatsoever ye have spoken in darkness shall be heard in the light; and that which ye have spoken in the ear in closets shall be proclaimed upon the housetops.
25464	985	4	And I say unto you my friends, Be not afraid of them that kill the body, and after that have no more that they can do.
25465	985	5	But I will forewarn you whom ye shall fear: Fear him, which after he hath killed hath power to cast into hell; yea, I say unto you, Fear him.
25466	985	6	Are not five sparrows sold for two farthings, and not one of them is forgotten before God?
25467	985	7	But even the very hairs of your head are all numbered. Fear not therefore: ye are of more value than many sparrows.
25468	985	8	Also I say unto you, Whosoever shall confess me before men, him shall the Son of man also confess before the angels of God:
25469	985	9	But he that denieth me before men shall be denied before the angels of God.
25470	985	10	And whosoever shall speak a word against the Son of man, it shall be forgiven him: but unto him that blasphemeth against the Holy Ghost it shall not be forgiven.
25471	985	11	And when they bring you unto the synagogues, and unto magistrates, and powers, take ye no thought how or what thing ye shall answer, or what ye shall say:
25472	985	12	For the Holy Ghost shall teach you in the same hour what ye ought to say.
25473	985	13	And one of the company said unto him, Master, speak to my brother, that he divide the inheritance with me.
25474	985	14	And he said unto him, Man, who made me a judge or a divider over you?
25475	985	15	And he said unto them, Take heed, and beware of covetousness: for a man's life consisteth not in the abundance of the things which he possesseth.
25476	985	16	And he spake a parable unto them, saying, The ground of a certain rich man brought forth plentifully:
25477	985	17	And he thought within himself, saying, What shall I do, because I have no room where to bestow my fruits?
25478	985	18	And he said, This will I do: I will pull down my barns, and build greater; and there will I bestow all my fruits and my goods.
25479	985	19	And I will say to my soul, Soul, thou hast much goods laid up for many years; take thine ease, eat, drink, and be merry.
25480	985	20	But God said unto him, Thou fool, this night thy soul shall be required of thee: then whose shall those things be, which thou hast provided?
25481	985	21	So is he that layeth up treasure for himself, and is not rich toward God.
25482	985	22	And he said unto his disciples, Therefore I say unto you, Take no thought for your life, what ye shall eat; neither for the body, what ye shall put on.
25483	985	23	The life is more than meat, and the body is more than raiment.
25484	985	24	Consider the ravens: for they neither sow nor reap; which neither have storehouse nor barn; and God feedeth them: how much more are ye better than the fowls?
25485	985	25	And which of you with taking thought can add to his stature one cubit?
25486	985	26	If ye then be not able to do that thing which is least, why take ye thought for the rest?
25487	985	27	Consider the lilies how they grow: they toil not, they spin not; and yet I say unto you, that Solomon in all his glory was not arrayed like one of these.
25488	985	28	If then God so clothe the grass, which is to day in the field, and to morrow is cast into the oven; how much more will he clothe you, O ye of little faith?
25489	985	29	And seek not ye what ye shall eat, or what ye shall drink, neither be ye of doubtful mind.
25490	985	30	For all these things do the nations of the world seek after: and your Father knoweth that ye have need of these things.
25491	985	31	But rather seek ye the kingdom of God; and all these things shall be added unto you.
25492	985	32	Fear not, little flock; for it is your Father's good pleasure to give you the kingdom.
25493	985	33	Sell that ye have, and give alms; provide yourselves bags which wax not old, a treasure in the heavens that faileth not, where no thief approacheth, neither moth corrupteth.
25494	985	34	For where your treasure is, there will your heart be also.
25495	985	35	Let your loins be girded about, and your lights burning;
25496	985	36	And ye yourselves like unto men that wait for their lord, when he will return from the wedding; that when he cometh and knocketh, they may open unto him immediately.
25497	985	37	Blessed are those servants, whom the lord when he cometh shall find watching: verily I say unto you, that he shall gird himself, and make them to sit down to meat, and will come forth and serve them.
25498	985	38	And if he shall come in the second watch, or come in the third watch, and find them so, blessed are those servants.
25499	985	39	And this know, that if the goodman of the house had known what hour the thief would come, he would have watched, and not have suffered his house to be broken through.
25500	985	40	Be ye therefore ready also: for the Son of man cometh at an hour when ye think not.
25501	985	41	Then Peter said unto him, Lord, speakest thou this parable unto us, or even to all?
25502	985	42	And the Lord said, Who then is that faithful and wise steward, whom his lord shall make ruler over his household, to give them their portion of meat in due season?
25503	985	43	Blessed is that servant, whom his lord when he cometh shall find so doing.
25504	985	44	Of a truth I say unto you, that he will make him ruler over all that he hath.
25505	985	45	But and if that servant say in his heart, My lord delayeth his coming; and shall begin to beat the menservants and maidens, and to eat and drink, and to be drunken;
25506	985	46	The lord of that servant will come in a day when he looketh not for him, and at an hour when he is not aware, and will cut him in sunder, and will appoint him his portion with the unbelievers.
25507	985	47	And that servant, which knew his lord's will, and prepared not himself, neither did according to his will, shall be beaten with many stripes.
25508	985	48	But he that knew not, and did commit things worthy of stripes, shall be beaten with few stripes. For unto whomsoever much is given, of him shall be much required: and to whom men have committed much, of him they will ask the more.
25509	985	49	I am come to send fire on the earth; and what will I, if it be already kindled?
25510	985	50	But I have a baptism to be baptized with; and how am I straitened till it be accomplished!
25511	985	51	Suppose ye that I am come to give peace on earth? I tell you, Nay; but rather division:
25512	985	52	For from henceforth there shall be five in one house divided, three against two, and two against three.
25513	985	53	The father shall be divided against the son, and the son against the father; the mother against the daughter, and the daughter against the mother; the mother in law against her daughter in law, and the daughter in law against her mother in law.
25514	985	54	And he said also to the people, When ye see a cloud rise out of the west, straightway ye say, There cometh a shower; and so it is.
25515	985	55	And when ye see the south wind blow, ye say, There will be heat; and it cometh to pass.
25516	985	56	Ye hypocrites, ye can discern the face of the sky and of the earth; but how is it that ye do not discern this time?
25517	985	57	Yea, and why even of yourselves judge ye not what is right?
25518	985	58	When thou goest with thine adversary to the magistrate, as thou art in the way, give diligence that thou mayest be delivered from him; lest he hale thee to the judge, and the judge deliver thee to the officer, and the officer cast thee into prison.
25519	985	59	I tell thee, thou shalt not depart thence, till thou hast paid the very last mite.
25520	986	1	THERE were present at that season some that told him of the Galilaeans, whose blood Pilate had mingled with their sacrifices.
25521	986	2	And Jesus answering said unto them, Suppose ye that these Galilaeans were sinners above all the Galilaeans, because they suffered such things?
25522	986	3	I tell you, Nay: but, except ye repent, ye shall all likewise perish.
25523	986	4	Or those eighteen, upon whom the tower in Siloam fell, and slew them, think ye that they were sinners above all men that dwelt in Jerusalem?
25524	986	5	I tell you, Nay: but, except ye repent, ye shall all likewise perish.
25525	986	6	He spake also this parable; A certain man had a fig tree planted in his vineyard; and he came and sought fruit thereon, and found none.
25526	986	7	Then said he unto the dresser of his vineyard, Behold, these three years I come seeking fruit on this fig tree, and find none: cut it down; why cumbereth it the ground?
25527	986	8	And he answering said unto him, Lord, let it alone this year also, till I shall dig about it, and dung it:
25528	986	9	And if it bear fruit, well: and if not, then after that thou shalt cut it down.
25529	986	10	And he was teaching in one of the synagogues on the sabbath.
25530	986	11	And, behold, there was a woman which had a spirit of infirmity eighteen years, and was bowed together, and could in no wise lift up herself.
25531	986	12	And when Jesus saw her, he called her to him, and said unto her, Woman, thou art loosed from thine infirmity.
25532	986	13	And he laid his hands on her: and immediately she was made straight, and glorified God.
25533	986	14	And the ruler of the synagogue answered with indignation, because that Jesus had healed on the sabbath day, and said unto the people, There are six days in which men ought to work: in them therefore come and be healed, and not on the sabbath day.
25534	986	15	The Lord then answered him, and said, Thou hypocrite, doth not each one of you on the sabbath loose his ox or his ass from the stall, and lead him away to watering?
25535	986	16	And ought not this woman, being a daughter of Abraham, whom Satan hath bound, lo, these eighteen years, be loosed from this bond on the sabbath day?
25536	986	17	And when he had said these things, all his adversaries were ashamed: and all the people rejoiced for all the glorious things that were done by him.
25537	986	18	Then said he, Unto what is the kingdom of God like? and whereunto shall I resemble it?
25538	986	19	It is like a grain of mustard seed, which a man took, and cast into his garden; and it grew, and waxed a great tree; and the fowls of the air lodged in the branches of it.
25539	986	20	And again he said, Whereunto shall I liken the kingdom of God?
25540	986	21	It is like leaven, which a woman took and hid in three measures of meal, till the whole was leavened.
25541	986	22	And he went through the cities and villages, teaching, and journeying toward Jerusalem.
25542	986	23	Then said one unto him, Lord, are there few that be saved? And he said unto them,
25543	986	24	Strive to enter in at the strait gate: for many, I say unto you, will seek to enter in, and shall not be able.
25544	986	25	When once the master of the house is risen up, and hath shut to the door, and ye begin to stand without, and to knock at the door, saying, Lord, Lord, open unto us; and he shall answer and say unto you, I know you not whence ye are:
25545	986	26	Then shall ye begin to say, We have eaten and drunk in thy presence, and thou hast taught in our streets.
25546	986	27	But he shall say, I tell you, I know you not whence ye are; depart from me, all ye workers of iniquity.
25547	986	28	There shall be weeping and gnashing of teeth, when ye shall see Abraham, and Isaac, and Jacob, and all the prophets, in the kingdom of God, and you yourselves thrust out.
25548	986	29	And they shall come from the east, and from the west, and from the north, and from the south, and shall sit down in the kingdom of God.
25549	986	30	And, behold, there are last which shall be first, and there are first which shall be last.
25550	986	31	The same day there came certain of the Pharisees, saying unto him, Get thee out, and depart hence: for Herod will kill thee.
25551	986	32	And he said unto them, Go ye, and tell that fox, Behold, I cast out devils, and I do cures to day and to morrow, and the third day I shall be perfected.
25552	986	33	Nevertheless I must walk to day, and to morrow, and the day following: for it cannot be that a prophet perish out of Jerusalem.
25553	986	34	O Jerusalem, Jerusalem, which killest the prophets, and stonest them that are sent unto thee; how often would I have gathered thy children together, as a hen doth gather her brood under her wings, and ye would not!
25554	986	35	Behold, your house is left unto you desolate: and verily I say unto you, Ye shall not see me, until the time come when ye shall say, Blessed is he that cometh in the name of the Lord.
25555	987	1	AND it came to pass, as he went into the house of one of the chief Pharisees to eat bread on the sabbath day, that they watched him.
25556	987	2	And, behold, there was a certain man before him which had the dropsy.
25557	987	3	And Jesus answering spake unto the lawyers and Pharisees, saying, Is it lawful to heal on the sabbath day?
25558	987	4	And they held their peace. And he took him, and healed him, and let him go;
25559	987	5	And answered them, saying, Which of you shall have an ass or an ox fallen into a pit, and will not straightway pull him out on the sabbath day?
25560	987	6	And they could not answer him again to these things.
25561	987	7	And he put forth a parable to those which were bidden, when he marked how they chose out the chief rooms; saying unto them,
25562	987	8	When thou art bidden of any man to a wedding, sit not down in the highest room; lest a more honourable man than thou be bidden of him;
25563	987	9	And he that bade thee and him come and say to thee, Give this man place; and thou begin with shame to take the lowest room.
25564	987	10	But when thou art bidden, go and sit down in the lowest room; that when he that bade thee cometh, he may say unto thee, Friend, go up higher: then shalt thou have worship in the presence of them that sit at meat with thee.
25565	987	11	For whosoever exalteth himself shall be abased; and he that humbleth himself shall be exalted.
25566	987	12	Then said he also to him that bade him, When thou makest a dinner or a supper, call not thy friends, nor thy brethren, neither thy kinsmen, nor thy rich neighbours; lest they also bid thee again, and a recompence be made thee.
25567	987	13	But when thou makest a feast, call the poor, the maimed, the lame, the blind:
25568	987	14	And thou shalt be blessed; for they cannot recompense thee: for thou shalt be recompensed at the resurrection of the just.
25569	987	15	And when one of them that sat at meat with him heard these things, he said unto him, Blessed is he that shall eat bread in the kingdom of God.
25570	987	16	Then said he unto him, A certain man made a great supper, and bade many:
25571	987	17	And sent his servant at supper time to say to them that were bidden, Come; for all things are now ready.
25572	987	18	And they all with one consent began to make excuse. The first said unto him, I have bought a piece of ground, and I must needs go and see it: I pray thee have me excused.
25573	987	19	And another said, I have bought five yoke of oxen, and I go to prove them: I pray thee have me excused.
25574	987	20	And another said, I have married a wife, and therefore I cannot come.
25575	987	21	So that servant came, and shewed his lord these things. Then the master of the house being angry said to his servant, Go out quickly into the streets and lanes of the city, and bring in hither the poor, and the maimed, and the halt, and the blind.
25576	987	22	And the servant said, Lord, it is done as thou hast commanded, and yet there is room.
25577	987	23	And the lord said unto the servant, Go out into the highways and hedges, and compel them to come in, that my house may be filled.
25578	987	24	For I say unto you, That none of those men which were bidden shall taste of my supper.
25579	987	25	And there went great multitudes with him: and he turned, and said unto them,
25580	987	26	If any man come to me, and hate not his father, and mother, and wife, and children, and brethren, and sisters, yea, and his own life also, he cannot be my disciple.
25581	987	27	And whosoever doth not bear his cross, and come after me, cannot be my disciple.
25582	987	28	For which of you, intending to build a tower, sitteth not down first, and counteth the cost, whether he have sufficient to finish it?
25583	987	29	Lest haply, after he hath laid the foundation, and is not able to finish it, all that behold it begin to mock him,
25584	987	30	Saying, This man began to build, and was not able to finish.
25585	987	31	Or what king, going to make war against another king, sitteth not down first, and consulteth whether he be able with ten thousand to meet him that cometh against him with twenty thousand?
25586	987	32	Or else, while the other is yet a great way off, he sendeth an ambassage, and desireth conditions of peace.
25587	987	33	So likewise, whosoever he be of you that forsaketh not all that he hath, he cannot be my disciple.
25588	987	34	Salt is good: but if the salt have lost his savour, wherewith shall it be seasoned?
25589	987	35	It is neither fit for the land, nor yet for the dunghill; but men cast it out. He that hath ears to hear, let him hear.
25590	988	1	THEN drew near unto him all the publicans and sinners for to hear him.
25591	988	2	And the Pharisees and scribes murmured, saying, This man receiveth sinners, and eateth with them.
25592	988	3	And he spake this parable unto them, saying,
25593	988	4	What man of you, having an hundred sheep, if he lose one of them, doth not leave the ninety and nine in the wilderness, and go after that which is lost, until he find it?
25594	988	5	And when he hath found it, he layeth it on his shoulders, rejoicing.
25595	988	6	And when he cometh home, he calleth together his friends and neighbours, saying unto them, Rejoice with me; for I have found my sheep which was lost.
25596	988	7	I say unto you, that likewise joy shall be in heaven over one sinner that repenteth, more than over ninety and nine just persons, which need no repentance.
25597	988	8	Either what woman having ten pieces of silver, if she lose one piece, doth not light a candle, and sweep the house, and seek diligently till she find it?
25598	988	9	And when she hath found it, she calleth her friends and her neighbours together, saying, Rejoice with me; for I have found the piece which I had lost.
25599	988	10	Likewise, I say unto you, there is joy in the presence of the angels of God over one sinner that repenteth.
25600	988	11	And he said, A certain man had two sons:
25601	988	12	And the younger of them said to his father, Father, give me the portion of goods that falleth to me. And he divided unto them his living.
25602	988	13	And not many days after the younger son gathered all together, and took his journey into a far country, and there wasted his substance with riotous living.
25603	988	14	And when he had spent all, there arose a mighty famine in that land; and he began to be in want.
25604	988	15	And he went and joined himself to a citizen of that country; and he sent him into his fields to feed swine.
25605	988	16	And he would fain have filled his belly with the husks that the swine did eat: and no man gave unto him.
25606	988	17	And when he came to himself, he said, How many hired servants of my father's have bread enough and to spare, and I perish with hunger!
25607	988	18	I will arise and go to my father, and will say unto him, Father, I have sinned against heaven, and before thee,
25608	988	19	And am no more worthy to be called thy son: make me as one of thy hired servants.
25609	988	20	And he arose, and came to his father. But when he was yet a great way off, his father saw him, and had compassion, and ran, and fell on his neck, and kissed him.
25610	988	21	And the son said unto him, Father, I have sinned against heaven, and in thy sight, and am no more worthy to be called thy son.
25611	988	22	But the father said to his servants, Bring forth the best robe, and put it on him; and put a ring on his hand, and shoes on his feet:
25612	988	23	And bring hither the fatted calf, and kill it; and let us eat, and be merry:
25613	988	24	For this my son was dead, and is alive again; he was lost, and is found. And they began to be merry.
25614	988	25	Now his elder son was in the field: and as he came and drew nigh to the house, he heard musick and dancing.
25615	988	26	And he called one of the servants, and asked what these things meant.
25616	988	27	And he said unto him, Thy brother is come; and thy father hath killed the fatted calf, because he hath received him safe and sound.
25617	988	28	And he was angry, and would not go in: therefore came his father out, and intreated him.
25618	988	29	And he answering said to his father, Lo, these many years do I serve thee, neither transgressed I at any time thy commandment: and yet thou never gavest me a kid, that I might make merry with my friends:
25619	988	30	But as soon as this thy son was come, which hath devoured thy living with harlots, thou hast killed for him the fatted calf.
25620	988	31	And he said unto him, Son, thou art ever with me, and all that I have is thine.
25621	988	32	It was meet that we should make merry, and be glad: for this thy brother was dead, and is alive again; and was lost, and is found.
25622	989	1	AND he said also unto his disciples, There was a certain rich man, which had a steward; and the same was accused unto him that he had wasted his goods.
25623	989	2	And he called him, and said unto him, How is it that I hear this of thee? give an account of thy stewardship; for thou mayest be no longer steward.
25624	989	3	Then the steward said within himself, What shall I do? for my lord taketh away from me the stewardship: I cannot dig; to beg I am ashamed.
25625	989	4	I am resolved what to do, that, when I am put out of the stewardship, they may receive me into their houses.
25626	989	5	So he called every one of his lord's debtors unto him, and said unto the first, How much owest thou unto my lord?
25627	989	6	And he said, An hundred measures of oil. And he said unto him, Take thy bill, and sit down quickly, and write fifty.
25628	989	7	Then said he to another, And how much owest thou? And he said, An hundred measures of wheat. And he said unto him, Take thy bill, and write fourscore.
25629	989	8	And the lord commended the unjust steward, because he had done wisely: for the children of this world are in their generation wiser than the children of light.
25630	989	9	And I say unto you, Make to yourselves friends of the mammon of unrighteousness; that, when ye fail, they may receive you into everlasting habitations.
25631	989	10	He that is faithful in that which is least is faithful also in much: and he that is unjust in the least is unjust also in much.
25632	989	11	If therefore ye have not been faithful in the unrighteous mammon, who will commit to your trust the true riches?
25633	989	12	And if ye have not been faithful in that which is another man's, who shall give you that which is your own?
25634	989	13	No servant can serve two masters: for either he will hate the one, and love the other; or else he will hold to the one, and despise the other. Ye cannot serve God and mammon.
25635	989	14	And the Pharisees also, who were covetous, heard all these things: and they derided him.
25636	989	15	And he said unto them, Ye are they which justify yourselves before men; but God knoweth your hearts: for that which is highly esteemed among men is abomination in the sight of God.
25637	989	16	The law and the prophets were until John: since that time the kingdom of God is preached, and every man presseth into it.
25638	989	17	And it is easier for heaven and earth to pass, than one tittle of the law to fail.
25639	989	18	Whosoever putteth away his wife, and marrieth another, committeth adultery: and whosoever marrieth her that is put away from her husband committeth adultery.
25640	989	19	There was a certain rich man, which was clothed in purple and fine linen, and fared sumptuously every day:
25641	989	20	And there was a certain beggar named Lazarus, which was laid at his gate, full of sores,
25642	989	21	And desiring to be fed with the crumbs which fell from the rich man's table: moreover the dogs came and licked his sores.
25643	989	22	And it came to pass, that the beggar died, and was carried by the angels into Abraham's bosom: the rich man also died, and was buried;
25644	989	23	And in hell he lift up his eyes, being in torments, and seeth Abraham afar off, and Lazarus in his bosom.
25645	989	24	And he cried and said, Father Abraham, have mercy on me, and send Lazarus, that he may dip the tip of his finger in water, and cool my tongue; for I am tormented in this flame.
25646	989	25	But Abraham said, Son, remember that thou in thy lifetime receivedst thy good things, and likewise Lazarus evil things: but now he is comforted, and thou art tormented.
25647	989	26	And beside all this, between us and you there is a great gulf fixed: so that they which would pass from hence to you cannot; neither can they pass to us, that would come from thence.
25648	989	27	Then he said, I pray thee therefore, father, that thou wouldest send him to my father's house:
25649	989	28	For I have five brethren; that he may testify unto them, lest they also come into this place of torment.
25650	989	29	Abraham saith unto him, They have Moses and the prophets; let them hear them.
25651	989	30	And he said, Nay, father Abraham: but if one went unto them from the dead, they will repent.
25652	989	31	And he said unto him, If they hear not Moses and the prophets, neither will they be persuaded, though one rose from the dead.
25653	990	1	THEN said he unto the disciples, It is impossible but that offences will come: but woe unto him, through whom they come!
25654	990	2	It were better for him that a millstone were hanged about his neck, and he cast into the sea, than that he should offend one of these little ones.
25655	990	3	Take heed to yourselves: If thy brother trespass against thee, rebuke him; and if he repent, forgive him.
25656	990	4	And if he trespass against thee seven times in a day, and seven times in a day turn again to thee, saying, I repent; thou shalt forgive him.
25657	990	5	And the apostles said unto the Lord, Increase our faith.
25658	990	6	And the Lord said, If ye had faith as a grain of mustard seed, ye might say unto this sycamine tree, Be thou plucked up by the root, and be thou planted in the sea; and it should obey you.
25659	990	7	But which of you, having a servant plowing or feeding cattle, will say unto him by and by, when he is come from the field, Go and sit down to meat?
25660	990	8	And will not rather say unto him, Make ready wherewith I may sup, and gird thyself, and serve me, till I have eaten and drunken; and afterward thou shalt eat and drink?
25661	990	9	Doth he thank that servant because he did the things that were commanded him? I trow not.
25662	990	10	So likewise ye, when ye shall have done all those things which are commanded you, say, We are unprofitable servants: we have done that which was our duty to do.
25663	990	11	And it came to pass, as he went to Jerusalem, that he passed through the midst of Samaria and Galilee.
25664	990	12	And as he entered into a certain village, there met him ten men that were lepers, which stood afar off:
25665	990	13	And they lifted up their voices, and said, Jesus, Master, have mercy on us.
25666	990	14	And when he saw them, he said unto them, Go shew yourselves unto the priests. And it came to pass, that, as they went, they were cleansed.
25667	990	15	And one of them, when he saw that he was healed, turned back, and with a loud voice glorified God,
25668	990	16	And fell down on his face at his feet, giving him thanks: and he was a Samaritan.
25669	990	17	And Jesus answering said, Were there not ten cleansed? but where are the nine?
25670	990	18	There are not found that returned to give glory to God, save this stranger.
25671	990	19	And he said unto him, Arise, go thy way: thy faith hath made thee whole.
25672	990	20	And when he was demanded of the Pharisees, when the kingdom of God should come, he answered them and said, The kingdom of God cometh not with observation:
25673	990	21	Neither shall they say, Lo here! or, lo there! for, behold, the kingdom of God is within you.
25674	990	22	And he said unto the disciples, The days will come, when ye shall desire to see one of the days of the Son of man, and ye shall not see it.
25675	990	23	And they shall say to you, See here; or, see there: go not after them, nor follow them.
25676	990	24	For as the lightning, that lighteneth out of the one part under heaven, shineth unto the other part under heaven; so shall also the Son of man be in his day.
25677	990	25	But first must he suffer many things, and be rejected of this generation.
25678	990	26	And as it was in the days of Noe, so shall it be also in the days of the Son of man.
25679	990	27	They did eat, they drank, they married wives, they were given in marriage, until the day that Noe entered into the ark, and the flood came, and destroyed them all.
25680	990	28	Likewise also as it was in the days of Lot; they did eat, they drank, they bought, they sold, they planted, they builded;
25681	990	29	But the same day that Lot went out of Sodom it rained fire and brimstone from heaven, and destroyed them all.
25682	990	30	Even thus shall it be in the day when the Son of man is revealed.
25683	990	31	In that day, he which shall be upon the housetop, and his stuff in the house, let him not come down to take it away: and he that is in the field, let him likewise not return back.
25684	990	32	Remember Lot's wife.
25685	990	33	Whosoever shall seek to save his life shall lose it; and whosoever shall lose his life shall preserve it.
25686	990	34	I tell you, in that night there shall be two men in one bed; the one shall be taken, and the other shall be left.
25687	990	35	Two women shall be grinding together; the one shall be taken, and the other left.
25688	990	36	Two men shall be in the field; the one shall be taken, and the other left.
25689	990	37	And they answered and said unto him, Where, Lord? And he said unto them, Wheresoever the body is, thither will the eagles be gathered together.
25690	991	1	AND he spake a parable unto them to this end, that men ought always to pray, and not to faint;
25691	991	2	Saying, There was in a city a judge, which feared not God, neither regarded man:
25692	991	3	And there was a widow in that city; and she came unto him, saying, Avenge me of mine adversary.
25693	991	4	And he would not for a while: but afterward he said within himself, Though I fear not God, nor regard man;
25694	991	5	Yet because this widow troubleth me, I will avenge her, lest by her continual coming she weary me.
25695	991	6	And the Lord said, Hear what the unjust judge saith.
25696	991	7	And shall not God avenge his own elect, which cry day and night unto him, though he bear long with them?
25697	991	8	I tell you that he will avenge them speedily. Nevertheless when the Son of man cometh, shall he find faith on the earth?
25698	991	9	And he spake this parable unto certain which trusted in themselves that they were righteous, and despised others:
25699	991	10	Two men went up into the temple to pray; the one a Pharisee, and the other a publican.
25700	991	11	The Pharisee stood and prayed thus with himself, God, I thank thee, that I am not as other men are, extortioners, unjust, adulterers, or even as this publican.
25701	991	12	I fast twice in the week, I give tithes of all that I possess.
25702	991	13	And the publican, standing afar off, would not lift up so much as his eyes unto heaven, but smote upon his breast, saying, God be merciful to me a sinner.
25703	991	14	I tell you, this man went down to his house justified rather than the other: for every one that exalteth himself shall be abased; and he that humbleth himself shall be exalted.
25704	991	15	And they brought unto him also infants, that he would touch them: but when his disciples saw it, they rebuked them.
25705	991	16	But Jesus called them unto him, and said, Suffer little children to come unto me, and forbid them not: for of such is the kingdom of God.
25706	991	17	Verily I say unto you, Whosoever shall not receive the kingdom of God as a little child shall in no wise enter therein.
25707	991	18	And a certain ruler asked him, saying, Good Master, what shall I do to inherit eternal life?
25708	991	19	And Jesus said unto him, Why callest thou me good? none is good, save one, that is, God.
25709	991	20	Thou knowest the commandments, Do not commit adultery, Do not kill, Do not steal, Do not bear false witness, Honour thy father and thy mother.
25710	991	21	And he said, All these have I kept from my youth up.
25711	991	22	Now when Jesus heard these things, he said unto him, Yet lackest thou one thing: sell all that thou hast, and distribute unto the poor, and thou shalt have treasure in heaven: and come, follow me.
25712	991	23	And when he heard this, he was very sorrowful: for he was very rich.
25713	991	24	And when Jesus saw that he was very sorrowful, he said, How hardly shall they that have riches enter into the kingdom of God!
25714	991	25	For it is easier for a camel to go through a needle's eye, than for a rich man to enter into the kingdom of God.
25715	991	26	And they that heard it said, Who then can be saved?
25716	991	27	And he said, The things which are impossible with men are possible with God.
25717	991	28	Then Peter said, Lo, we have left all, and followed thee.
25718	991	29	And he said unto them, Verily I say unto you, There is no man that hath left house, or parents, or brethren, or wife, or children, for the kingdom of God's sake,
25719	991	30	Who shall not receive manifold more in this present time, and in the world to come life everlasting.
25720	991	31	Then he took unto him the twelve, and said unto them, Behold, we go up to Jerusalem, and all things that are written by the prophets concerning the Son of man shall be accomplished.
25721	991	32	For he shall be delivered unto the Gentiles, and shall be mocked, and spitefully entreated, and spitted on:
25722	991	33	And they shall scourge him, and put him to death: and the third day he shall rise again.
25723	991	34	And they understood none of these things: and this saying was hid from them, neither knew they the things which were spoken.
25724	991	35	And it came to pass, that as he was come nigh unto Jericho, a certain blind man sat by the way side begging:
25725	991	36	And hearing the multitude pass by, he asked what it meant.
25726	991	37	And they told him, that Jesus of Nazareth passeth by.
25727	991	38	And he cried, saying, Jesus, thou Son of David, have mercy on me.
25728	991	39	And they which went before rebuked him, that he should hold his peace: but he cried so much the more, Thou Son of David, have mercy on me.
25729	991	40	And Jesus stood, and commanded him to be brought unto him: and when he was come near, he asked him,
25730	991	41	Saying, What wilt thou that I shall do unto thee? And he said, Lord, that I may receive my sight.
25731	991	42	And Jesus said unto him, Receive thy sight: thy faith hath saved thee.
25732	991	43	And immediately he received his sight, and followed him, glorifying God: and all the people, when they saw it, gave praise unto God.
25733	992	1	AND Jesus entered and passed through Jericho.
25734	992	2	And, behold, there was a man named Zacchaeus, which was the chief among the publicans, and he was rich.
25735	992	3	And he sought to see Jesus who he was; and could not for the press, because he was little of stature.
25736	992	4	And he ran before, and climbed up into a sycomore tree to see him: for he was to pass that way.
25737	992	5	And when Jesus came to the place, he looked up, and saw him, and said unto him, Zacchaeus, make haste, and come down; for to day I must abide at thy house.
25738	992	6	And he made haste, and came down, and received him joyfully.
25739	992	7	And when they saw it, they all murmured, saying, That he was gone to be guest with a man that is a sinner.
25740	992	8	And Zacchaeus stood, and said unto the Lord; Behold, Lord, the half of my goods I give to the poor; and if I have taken any thing from any man by false accusation, I restore him fourfold.
25741	992	9	And Jesus said unto him, This day is salvation come to this house, forsomuch as he also is a son of Abraham.
25742	992	10	For the Son of man is come to seek and to save that which was lost.
25743	992	11	And as they heard these things, he added and spake a parable, because he was nigh to Jerusalem, and because they thought that the kingdom of God should immediately appear.
25744	992	12	He said therefore, A certain nobleman went into a far country to receive for himself a kingdom, and to return.
25745	992	13	And he called his ten servants, and delivered them ten pounds, and said unto them, Occupy till I come.
25746	992	14	But his citizens hated him, and sent a message after him, saying, We will not have this man to reign over us.
25747	992	15	And it came to pass, that when he was returned, having received the kingdom, then he commanded these servants to be called unto him, to whom he had given the money, that he might know how much every man had gained by trading.
25748	992	16	Then came the first, saying, Lord, thy pound hath gained ten pounds.
25749	992	17	And he said unto him, Well, thou good servant: because thou hast been faithful in a very little, have thou authority over ten cities.
25750	992	18	And the second came, saying, Lord, thy pound hath gained five pounds.
25751	992	19	And he said likewise to him, Be thou also over five cities.
25752	992	20	And another came, saying, Lord, behold, here is thy pound, which I have kept laid up in a napkin:
25753	992	21	For I feared thee, because thou art an austere man: thou takest up that thou layedst not down, and reapest that thou didst not sow.
25754	992	22	And he saith unto him, Out of thine own mouth will I judge thee, thou wicked servant. Thou knewest that I was an austere man, taking up that I laid not down, and reaping that I did not sow:
25755	992	23	Wherefore then gavest not thou my money into the bank, that at my coming I might have required mine own with usury?
25756	992	24	And he said unto them that stood by, Take from him the pound, and give it to him that hath ten pounds.
25757	992	25	(And they said unto him, Lord, he hath ten pounds.)
25758	992	26	For I say unto you, That unto every one which hath shall be given; and from him that hath not, even that he hath shall be taken away from him.
25759	992	27	But those mine enemies, which would not that I should reign over them, bring hither, and slay them before me.
25760	992	28	And when he had thus spoken, he went before, ascending up to Jerusalem.
25761	992	29	And it came to pass, when he was come nigh to Bethphage and Bethany, at the mount called the mount of Olives, he sent two of his disciples,
25762	992	30	Saying, Go ye into the village over against you; in the which at your entering ye shall find a colt tied, whereon yet never man sat: loose him, and bring him hither.
25763	992	31	And if any man ask you, Why do ye loose him? thus shall ye say unto him, Because the Lord hath need of him.
25764	992	32	And they that were sent went their way, and found even as he had said unto them.
25765	992	33	And as they were loosing the colt, the owners thereof said unto them, Why loose ye the colt?
25766	992	34	And they said, The Lord hath need of him.
25767	992	35	And they brought him to Jesus: and they cast their garments upon the colt, and they set Jesus thereon.
25768	992	36	And as he went, they spread their clothes in the way.
25769	992	37	And when he was come nigh, even now at the descent of the mount of Olives, the whole multitude of the disciples began to rejoice and praise God with a loud voice for all the mighty works that they had seen;
25770	992	38	Saying, Blessed be the King that cometh in the name of the Lord: peace in heaven, and glory in the highest.
25771	992	39	And some of the Pharisees from among the multitude said unto him, Master, rebuke thy disciples.
25772	992	40	And he answered and said unto them, I tell you that, if these should hold their peace, the stones would immediately cry out.
25773	992	41	And when he was come near, he beheld the city, and wept over it,
25774	992	42	Saying, If thou hadst known, even thou, at least in this thy day, the things which belong unto thy peace! but now they are hid from thine eyes.
25775	992	43	For the days shall come upon thee, that thine enemies shall cast a trench about thee, and compass thee round, and keep thee in on every side,
25776	992	44	And shall lay thee even with the ground, and thy children within thee; and they shall not leave in thee one stone upon another; because thou knewest not the time of thy visitation.
25777	992	45	And he went into the temple, and began to cast out them that sold therein, and them that bought;
25778	992	46	Saying unto them, It is written, My house is the house of prayer: but ye have made it a den of thieves.
25779	992	47	And he taught daily in the temple. But the chief priests and the scribes and the chief of the people sought to destroy him,
25780	992	48	And could not find what they might do: for all the people were very attentive to hear him.
25781	993	1	AND it came to pass, that on one of those days, as he taught the people in the temple, and preached the gospel, the chief priests and the scribes came upon him with the elders,
25782	993	2	And spake unto him, saying, Tell us, by what authority doest thou these things? or who is he that gave thee this authority?
25783	993	3	And he answered and said unto them, I will also ask you one thing; and answer me:
25784	993	4	The baptism of John, was it from heaven, or of men?
25785	993	5	And they reasoned with themselves, saying, If we shall say, From heaven; he will say, Why then believed ye him not?
25786	993	6	But and if we say, Of men; all the people will stone us: for they be persuaded that John was a prophet.
25787	993	7	And they answered, that they could not tell whence it was.
25788	993	8	And Jesus said unto them, Neither tell I you by what authority I do these things.
25789	993	9	Then began he to speak to the people this parable; A certain man planted a vineyard, and let it forth to husbandmen, and went into a far country for a long time.
25790	993	10	And at the season he sent a servant to the husbandmen, that they should give him of the fruit of the vineyard: but the husbandmen beat him, and sent him away empty.
25791	993	11	And again he sent another servant: and they beat him also, and entreated him shamefully, and sent him away empty.
25792	993	12	And again he sent a third: and they wounded him also, and cast him out.
25793	993	13	Then said the lord of the vineyard, What shall I do? I will send my beloved son: it may be they will reverence him when they see him.
25794	993	14	But when the husbandmen saw him, they reasoned among themselves, saying, This is the heir: come, let us kill him, that the inheritance may be ours.
25795	993	15	So they cast him out of the vineyard, and killed him. What therefore shall the lord of the vineyard do unto them?
25796	993	16	He shall come and destroy these husbandmen, and shall give the vineyard to others. And when they heard it, they said, God forbid.
25797	993	17	And he beheld them, and said, What is this then that is written, The stone which the builders rejected, the same is become the head of the corner?
25798	993	18	Whosoever shall fall upon that stone shall be broken; but on whomsoever it shall fall, it will grind him to powder.
25799	993	19	And the chief priests and the scribes the same hour sought to lay hands on him; and they feared the people: for they perceived that he had spoken this parable against them.
25800	993	20	And they watched him, and sent forth spies, which should feign themselves just men, that they might take hold of his words, that so they might deliver him unto the power and authority of the governor.
25801	993	21	And they asked him, saying, Master, we know that thou sayest and teachest rightly, neither acceptest thou the person of any, but teachest the way of God truly:
25802	993	22	Is it lawful for us to give tribute unto Caesar, or no?
25803	993	23	But he perceived their craftiness, and said unto them, Why tempt ye me?
25804	993	24	Shew me a penny. Whose image and superscription hath it? They answered and said, Caesar's.
25805	993	25	And he said unto them, Render therefore unto Caesar the things which be Caesar's, and unto God the things which be God's.
25806	993	26	And they could not take hold of his words before the people: and they marvelled at his answer, and held their peace.
25807	993	27	Then came to him certain of the Sadducees, which deny that there is any resurrection; and they asked him,
25808	993	28	Saying, Master, Moses wrote unto us, If any man's brother die, having a wife, and he die without children, that his brother should take his wife, and raise up seed unto his brother.
25809	993	29	There were therefore seven brethren: and the first took a wife, and died without children.
25810	993	30	And the second took her to wife, and he died childless.
25811	993	31	And the third took her; and in like manner the seven also: and they left no children, and died.
25812	993	32	Last of all the woman died also.
25813	993	33	Therefore in the resurrection whose wife of them is she? for seven had her to wife.
25814	993	34	And Jesus answering said unto them, The children of this world marry, and are given in marriage:
25815	993	35	But they which shall be accounted worthy to obtain that world, and the resurrection from the dead, neither marry, nor are given in marriage:
25816	993	36	Neither can they die any more: for they are equal unto the angels; and are the children of God, being the children of the resurrection.
25817	993	37	Now that the dead are raised, even Moses shewed at the bush, when he calleth the Lord the God of Abraham, and the God of Isaac, and the God of Jacob.
25818	993	38	For he is not a God of the dead, but of the living: for all live unto him.
25819	993	39	Then certain of the scribes answering said, Master, thou hast well said.
25820	993	40	And after that they durst not ask him any question at all.
25821	993	41	And he said unto them, How say they that Christ is David's son?
25822	993	42	And David himself saith in the book of Psalms, The LORD said unto my Lord, Sit thou on my right hand,
25823	993	43	Till I make thine enemies thy footstool.
25824	993	44	David therefore calleth him Lord, how is he then his son?
25825	993	45	Then in the audience of all the people he said unto his disciples,
25826	993	46	Beware of the scribes, which desire to walk in long robes, and love greetings in the markets, and the highest seats in the synagogues, and the chief rooms at feasts;
25827	993	47	Which devour widows' houses, and for a shew make long prayers: the same shall receive greater damnation.
25828	994	1	AND he looked up, and saw the rich men casting their gifts into the treasury.
25829	994	2	And he saw also a certain poor widow casting in thither two mites.
25830	994	3	And he said, Of a truth I say unto you, that this poor widow hath cast in more than they all:
25831	994	4	For all these have of their abundance cast in unto the offerings of God: but she of her penury hath cast in all the living that she had.
25832	994	5	And as some spake of the temple, how it was adorned with goodly stones and gifts, he said,
25833	994	6	As for these things which ye behold, the days will come, in the which there shall not be left one stone upon another, that shall not be thrown down.
25834	994	7	And they asked him, saying, Master, but when shall these things be? and what sign will there be when these things shall come to pass?
25835	994	8	And he said, Take heed that ye be not deceived: for many shall come in my name, saying, I am Christ; and the time draweth near: go ye not therefore after them.
25836	994	9	But when ye shall hear of wars and commotions, be not terrified: for these things must first come to pass; but the end is not by and by.
25837	994	10	Then said he unto them, Nation shall rise against nation, and kingdom against kingdom:
25838	994	11	And great earthquakes shall be in divers places, and famines, and pestilences; and fearful sights and great signs shall there be from heaven.
25839	994	12	But before all these, they shall lay their hands on you, and persecute you, delivering you up to the synagogues, and into prisons, being brought before kings and rulers for my name's sake.
25840	994	13	And it shall turn to you for a testimony.
25841	994	14	Settle it therefore in your hearts, not to meditate before what ye shall answer:
25842	994	15	For I will give you a mouth and wisdom, which all your adversaries shall not be able to gainsay nor resist.
25843	994	16	And ye shall be betrayed both by parents, and brethren, and kinsfolks, and friends; and some of you shall they cause to be put to death.
25844	994	17	And ye shall be hated of all men for my name's sake.
25845	994	18	But there shall not an hair of your head perish.
25846	994	19	In your patience possess ye your souls.
25847	994	20	And when ye shall see Jerusalem compassed with armies, then know that the desolation thereof is nigh.
25848	994	21	Then let them which are in Judaea flee to the mountains; and let them which are in the midst of it depart out; and let not them that are in the countries enter thereinto.
25849	994	22	For these be the days of vengeance, that all things which are written may be fulfilled.
25850	994	23	But woe unto them that are with child, and to them that give suck, in those days! for there shall be great distress in the land, and wrath upon this people.
25851	994	24	And they shall fall by the edge of the sword, and shall be led away captive into all nations: and Jerusalem shall be trodden down of the Gentiles, until the times of the Gentiles be fulfilled.
25852	994	25	And there shall be signs in the sun, and in the moon, and in the stars; and upon the earth distress of nations, with perplexity; the sea and the waves roaring;
25853	994	26	Men's hearts failing them for fear, and for looking after those things which are coming on the earth: for the powers of heaven shall be shaken.
25854	994	27	And then shall they see the Son of man coming in a cloud with power and great glory.
25855	994	28	And when these things begin to come to pass, then look up, and lift up your heads; for your redemption draweth nigh.
25856	994	29	And he spake to them a parable; Behold the fig tree, and all the trees;
25857	994	30	When they now shoot forth, ye see and know of your own selves that summer is now nigh at hand.
25858	994	31	So likewise ye, when ye see these things come to pass, know ye that the kingdom of God is nigh at hand.
25859	994	32	Verily I say unto you, This generation shall not pass away, till all be fulfilled.
25860	994	33	Heaven and earth shall pass away: but my words shall not pass away.
25861	994	34	And take heed to yourselves, lest at any time your hearts be overcharged with surfeiting, and drunkenness, and cares of this life, and so that day come upon you unawares.
25862	994	35	For as a snare shall it come on all them that dwell on the face of the whole earth.
25863	994	36	Watch ye therefore, and pray always, that ye may be accounted worthy to escape all these things that shall come to pass, and to stand before the Son of man.
25864	994	37	And in the day time he was teaching in the temple; and at night he went out, and abode in the mount that is called the mount of Olives.
25865	994	38	And all the people came early in the morning to him in the temple, for to hear him.
25866	995	1	NOW the feast of unleavened bread drew nigh, which is called the Passover.
25867	995	2	And the chief priests and scribes sought how they might kill him; for they feared the people.
25868	995	3	Then entered Satan into Judas surnamed Iscariot, being of the number of the twelve.
25869	995	4	And he went his way, and communed with the chief priests and captains, how he might betray him unto them.
25870	995	5	And they were glad, and covenanted to give him money.
25871	995	6	And he promised, and sought opportunity to betray him unto them in the absence of the multitude.
25872	995	7	Then came the day of unleavened bread, when the passover must be killed.
25873	995	8	And he sent Peter and John, saying, Go and prepare us the passover, that we may eat.
25874	995	9	And they said unto him, Where wilt thou that we prepare?
25875	995	10	And he said unto them, Behold, when ye are entered into the city, there shall a man meet you, bearing a pitcher of water; follow him into the house where he entereth in.
25876	995	11	And ye shall say unto the goodman of the house, The Master saith unto thee, Where is the guestchamber, where I shall eat the passover with my disciples?
25877	995	12	And he shall shew you a large upper room furnished: there make ready.
25878	995	13	And they went, and found as he had said unto them: and they made ready the passover.
25879	995	14	And when the hour was come, he sat down, and the twelve apostles with him.
25880	995	15	And he said unto them, With desire I have desired to eat this passover with you before I suffer:
25881	995	16	For I say unto you, I will not any more eat thereof, until it be fulfilled in the kingdom of God.
25882	995	17	And he took the cup, and gave thanks, and said, Take this, and divide it among yourselves:
25883	995	18	For I say unto you, I will not drink of the fruit of the vine, until the kingdom of God shall come.
25884	995	19	And he took bread, and gave thanks, and brake it, and gave unto them, saying, This is my body which is given for you: this do in remembrance of me.
25885	995	20	Likewise also the cup after supper, saying, This cup is the new testament in my blood, which is shed for you.
25886	995	21	But, behold, the hand of him that betrayeth me is with me on the table.
25887	995	22	And truly the Son of man goeth, as it was determined: but woe unto that man by whom he is betrayed!
25888	995	23	And they began to enquire among themselves, which of them it was that should do this thing.
25889	995	24	And there was also a strife among them, which of them should be accounted the greatest.
25890	995	25	And he said unto them, The kings of the Gentiles exercise lordship over them; and they that exercise authority upon them are called benefactors.
25891	995	26	But ye shall not be so: but he that is greatest among you, let him be as the younger; and he that is chief, as he that doth serve.
25892	995	27	For whether is greater, he that sitteth at meat, or he that serveth? is not he that sitteth at meat? but I am among you as he that serveth.
25893	995	28	Ye are they which have continued with me in my temptations.
25894	995	29	And I appoint unto you a kingdom, as my Father hath appointed unto me;
25895	995	30	That ye may eat and drink at my table in my kingdom, and sit on thrones judging the twelve tribes of Israel.
25896	995	31	And the Lord said, Simon, Simon, behold, Satan hath desired to have you, that he may sift you as wheat:
25897	995	32	But I have prayed for thee, that thy faith fail not: and when thou art converted, strengthen thy brethren.
25898	995	33	And he said unto him, Lord, I am ready to go with thee, both into prison, and to death.
25899	995	34	And he said, I tell thee, Peter, the cock shall not crow this day, before that thou shalt thrice deny that thou knowest me.
25900	995	35	And he said unto them, When I sent you without purse, and scrip, and shoes, lacked ye any thing? And they said, Nothing.
25901	995	36	Then said he unto them, But now, he that hath a purse, let him take it, and likewise his scrip: and he that hath no sword, let him sell his garment, and buy one.
25902	995	37	For I say unto you, that this that is written must yet be accomplished in me, And he was reckoned among the transgressors: for the things concerning me have an end.
25903	995	38	And they said, Lord, behold, here are two swords. And he said unto them, It is enough.
25904	995	39	And he came out, and went, as he was wont, to the mount of Olives; and his disciples also followed him.
25905	995	40	And when he was at the place, he said unto them, Pray that ye enter not into temptation.
25906	995	41	And he was withdrawn from them about a stone's cast, and kneeled down, and prayed,
25907	995	42	Saying, Father, if thou be willing, remove this cup from me: nevertheless not my will, but thine, be done.
25908	995	43	And there appeared an angel unto him from heaven, strengthening him.
25909	995	44	And being in an agony he prayed more earnestly: and his sweat was as it were great drops of blood falling down to the ground.
25910	995	45	And when he rose up from prayer, and was come to his disciples, he found them sleeping for sorrow,
25911	995	46	And said unto them, Why sleep ye? rise and pray, lest ye enter into temptation.
25912	995	47	And while he yet spake, behold a multitude, and he that was called Judas, one of the twelve, went before them, and drew near unto Jesus to kiss him.
25913	995	48	But Jesus said unto him, Judas, betrayest thou the Son of man with a kiss?
25914	995	49	When they which were about him saw what would follow, they said unto him, Lord, shall we smite with the sword?
25915	995	50	And one of them smote the servant of the high priest, and cut off his right ear.
25916	995	51	And Jesus answered and said, Suffer ye thus far. And he touched his ear, and healed him.
25917	995	52	Then Jesus said unto the chief priests, and captains of the temple, and the elders, which were come to him, Be ye come out, as against a thief, with swords and staves?
25918	995	53	When I was daily with you in the temple, ye stretched forth no hands against me: but this is your hour, and the power of darkness.
25919	995	54	Then took they him, and led him, and brought him into the high priest's house. And Peter followed afar off.
25920	995	55	And when they had kindled a fire in the midst of the hall, and were set down together, Peter sat down among them.
25921	995	56	But a certain maid beheld him as he sat by the fire, and earnestly looked upon him, and said, This man was also with him.
25922	995	57	And he denied him, saying, Woman, I know him not.
25923	995	58	And after a little while another saw him, and said, Thou art also of them. And Peter said, Man, I am not.
25924	995	59	And about the space of one hour after another confidently affirmed, saying, Of a truth this fellow also was with him: for he is a Galilaean.
25925	995	60	And Peter said, Man, I know not what thou sayest. And immediately, while he yet spake, the cock crew.
25926	995	61	And the Lord turned, and looked upon Peter. And Peter remembered the word of the Lord, how he had said unto him, Before the cock crow, thou shalt deny me thrice.
25927	995	62	And Peter went out, and wept bitterly.
25928	995	63	And the men that held Jesus mocked him, and smote him.
25929	995	64	And when they had blindfolded him, they struck him on the face, and asked him, saying, Prophesy, who is it that smote thee?
25930	995	65	And many other things blasphemously spake they against him.
25931	995	66	And as soon as it was day, the elders of the people and the chief priests and the scribes came together, and led him into their council, saying,
25932	995	67	Art thou the Christ? tell us. And he said unto them, If I tell you, ye will not believe:
25933	995	68	And if I also ask you, ye will not answer me, nor let me go.
25934	995	69	Hereafter shall the Son of man sit on the right hand of the power of God.
25935	995	70	Then said they all, Art thou then the Son of God? And he said unto them, Ye say that I am.
25936	995	71	And they said, What need we any further witness? for we ourselves have heard of his own mouth.
25937	996	1	AND the whole multitude of them arose, and led him unto Pilate.
25938	996	2	And they began to accuse him, saying, We found this fellow perverting the nation, and forbidding to give tribute to Caesar, saying that he himself is Christ a King.
25939	996	3	And Pilate asked him, saying, Art thou the King of the Jews? And he answered him and said, Thou sayest it.
25940	996	4	Then said Pilate to the chief priests and to the people, I find no fault in this man.
25941	996	5	And they were the more fierce, saying, He stirreth up the people, teaching throughout all Jewry, beginning from Galilee to this place.
25942	996	6	When Pilate heard of Galilee, he asked whether the man were a Galilaean.
25943	996	7	And as soon as he knew that he belonged unto Herod's jurisdiction, he sent him to Herod, who himself also was at Jerusalem at that time.
25944	996	8	And when Herod saw Jesus, he was exceeding glad: for he was desirous to see him of a long season, because he had heard many things of him; and he hoped to have seen some miracle done by him.
25945	996	9	Then he questioned with him in many words; but he answered him nothing.
25946	996	10	And the chief priests and scribes stood and vehemently accused him.
25947	996	11	And Herod with his men of war set him at nought, and mocked him, and arrayed him in a gorgeous robe, and sent him again to Pilate.
25948	996	12	And the same day Pilate and Herod were made friends together: for before they were at enmity between themselves.
25949	996	13	And Pilate, when he had called together the chief priests and the rulers and the people,
25950	996	14	Said unto them, Ye have brought this man unto me, as one that perverteth the people: and, behold, I, having examined him before you, have found no fault in this man touching those things whereof ye accuse him:
25951	996	15	No, nor yet Herod: for I sent you to him; and, lo, nothing worthy of death is done unto him.
25952	996	16	I will therefore chastise him, and release him.
25953	996	17	(For of necessity he must release one unto them at the feast.)
25954	996	18	And they cried out all at once, saying, Away with this man, and release unto us Barabbas:
25955	996	19	(Who for a certain sedition made in the city, and for murder, was cast into prison.)
25956	996	20	Pilate therefore, willing to release Jesus, spake again to them.
25957	996	21	But they cried, saying, Crucify him, crucify him.
25958	996	22	And he said unto them the third time, Why, what evil hath he done? I have found no cause of death in him: I will therefore chastise him, and let him go.
25959	996	23	And they were instant with loud voices, requiring that he might be crucified. And the voices of them and of the chief priests prevailed.
25960	996	24	And Pilate gave sentence that it should be as they required.
25961	996	25	And he released unto them him that for sedition and murder was cast into prison, whom they had desired; but he delivered Jesus to their will.
25962	996	26	And as they led him away, they laid hold upon one Simon, a Cyrenian, coming out of the country, and on him they laid the cross, that he might bear it after Jesus.
25963	996	27	And there followed him a great company of people, and of women, which also bewailed and lamented him.
25964	996	28	But Jesus turning unto them said, Daughters of Jerusalem, weep not for me, but weep for yourselves, and for your children.
25965	996	29	For, behold, the days are coming, in the which they shall say, Blessed are the barren, and the wombs that never bare, and the paps which never gave suck.
25966	996	30	Then shall they begin to say to the mountains, Fall on us; and to the hills, Cover us.
25967	996	31	For if they do these things in a green tree, what shall be done in the dry?
25968	996	32	And there were also two other, malefactors, led with him to be put to death.
25969	996	33	And when they were come to the place, which is called Calvary, there they crucified him, and the malefactors, one on the right hand, and the other on the left.
25970	996	34	Then said Jesus, Father, forgive them; for they know not what they do. And they parted his raiment, and cast lots.
25971	996	35	And the people stood beholding. And the rulers also with them derided him, saying, He saved others; let him save himself, if he be Christ, the chosen of God.
25972	996	36	And the soldiers also mocked him, coming to him, and offering him vinegar,
25973	996	37	And saying, If thou be the king of the Jews, save thyself.
25974	996	38	And a superscription also was written over him in letters of Greek, and Latin, and Hebrew, THIS IS THE KING OF THE JEWS.
25975	996	39	And one of the malefactors which were hanged railed on him, saying, If thou be Christ, save thyself and us.
25976	996	40	But the other answering rebuked him, saying, Dost not thou fear God, seeing thou art in the same condemnation?
25977	996	41	And we indeed justly; for we receive the due reward of our deeds: but this man hath done nothing amiss.
25978	996	42	And he said unto Jesus, Lord, remember me when thou comest into thy kingdom.
25979	996	43	And Jesus said unto him, Verily I say unto thee, To day shalt thou be with me in paradise.
25980	996	44	And it was about the sixth hour, and there was a darkness over all the earth until the ninth hour.
25981	996	45	And the sun was darkened, and the veil of the temple was rent in the midst.
25982	996	46	And when Jesus had cried with a loud voice, he said, Father, into thy hands I commend my spirit: and having said thus, he gave up the ghost.
25983	996	47	Now when the centurion saw what was done, he glorified God, saying, Certainly this was a righteous man.
25984	996	48	And all the people that came together to that sight, beholding the things which were done, smote their breasts, and returned.
25985	996	49	And all his acquaintance, and the women that followed him from Galilee, stood afar off, beholding these things.
25986	996	50	And, behold, there was a man named Joseph, a counsellor; and he was a good man, and a just:
25987	996	51	(The same had not consented to the counsel and deed of them;) he was of Arimathaea, a city of the Jews: who also himself waited for the kingdom of God.
25988	996	52	This man went unto Pilate, and begged the body of Jesus.
25989	996	53	And he took it down, and wrapped it in linen, and laid it in a sepulchre that was hewn in stone, wherein never man before was laid.
25990	996	54	And that day was the preparation, and the sabbath drew on.
25991	996	55	And the women also, which came with him from Galilee, followed after, and beheld the sepulchre, and how his body was laid.
25992	996	56	And they returned, and prepared spices and ointments; and rested the sabbath day according to the commandment.
25993	997	1	NOW upon the first day of the week, very early in the morning, they came unto the sepulchre, bringing the spices which they had prepared, and certain others with them.
25994	997	2	And they found the stone rolled away from the sepulchre.
25995	997	3	And they entered in, and found not the body of the Lord Jesus.
25996	997	4	And it came to pass, as they were much perplexed thereabout, behold, two men stood by them in shining garments:
25997	997	5	And as they were afraid, and bowed down their faces to the earth, they said unto them, Why seek ye the living among the dead?
25998	997	6	He is not here, but is risen: remember how he spake unto you when he was yet in Galilee,
25999	997	7	Saying, The Son of man must be delivered into the hands of sinful men, and be crucified, and the third day rise again.
26000	997	8	And they remembered his words,
26001	997	9	And returned from the sepulchre, and told all these things unto the eleven, and to all the rest.
26002	997	10	It was Mary Magdalene, and Joanna, and Mary the mother of James, and other women that were with them, which told these things unto the apostles.
26003	997	11	And their words seemed to them as idle tales, and they believed them not.
26004	997	12	Then arose Peter, and ran unto the sepulchre; and stooping down, he beheld the linen clothes laid by themselves, and departed, wondering in himself at that which was come to pass.
26005	997	13	And, behold, two of them went that same day to a village called Emmaus, which was from Jerusalem about threescore furlongs.
26006	997	14	And they talked together of all these things which had happened.
26007	997	15	And it came to pass, that, while they communed together and reasoned, Jesus himself drew near, and went with them.
26008	997	16	But their eyes were holden that they should not know him.
26009	997	17	And he said unto them, What manner of communications are these that ye have one to another, as ye walk, and are sad?
26010	997	18	And the one of them, whose name was Cleopas, answering said unto him, Art thou only a stranger in Jerusalem, and hast not known the things which are come to pass therein these days?
26011	997	19	And he said unto them, What things? And they said unto him, Concerning Jesus of Nazareth, which was a prophet mighty in deed and word before God and all the people:
26012	997	20	And how the chief priests and our rulers delivered him to be condemned to death, and have crucified him.
26013	997	21	But we trusted that it had been he which should have redeemed Israel: and beside all this, to day is the third day since these things were done.
26014	997	22	Yea, and certain women also of our company made us astonished, which were early at the sepulchre;
26015	997	23	And when they found not his body, they came, saying, that they had also seen a vision of angels, which said that he was alive.
26016	997	24	And certain of them which were with us went to the sepulchre, and found it even so as the women had said: but him they saw not.
26017	997	25	Then he said unto them, O fools, and slow of heart to believe all that the prophets have spoken:
26018	997	26	Ought not Christ to have suffered these things, and to enter into his glory?
26019	997	27	And beginning at Moses and all the prophets, he expounded unto them in all the scriptures the things concerning himself.
26020	997	28	And they drew nigh unto the village, whither they went: and he made as though he would have gone further.
26021	997	29	But they constrained him, saying, Abide with us: for it is toward evening, and the day is far spent. And he went in to tarry with them.
26022	997	30	And it came to pass, as he sat at meat with them, he took bread, and blessed it, and brake, and gave to them.
26023	997	31	And their eyes were opened, and they knew him; and he vanished out of their sight.
26024	997	32	And they said one to another, Did not our heart burn within us, while he talked with us by the way, and while he opened to us the scriptures?
26025	997	33	And they rose up the same hour, and returned to Jerusalem, and found the eleven gathered together, and them that were with them,
26026	997	34	Saying, The Lord is risen indeed, and hath appeared to Simon.
26027	997	35	And they told what things were done in the way, and how he was known of them in breaking of bread.
26028	997	36	And as they thus spake, Jesus himself stood in the midst of them, and saith unto them, Peace be unto you.
26029	997	37	But they were terrified and affrighted, and supposed that they had seen a spirit.
26030	997	38	And he said unto them, Why are ye troubled? and why do thoughts arise in your hearts?
26031	997	39	Behold my hands and my feet, that it is I myself: handle me, and see; for a spirit hath not flesh and bones, as ye see me have.
26032	997	40	And when he had thus spoken, he shewed them his hands and his feet.
26033	997	41	And while they yet believed not for joy, and wondered, he said unto them, Have ye here any meat?
26034	997	42	And they gave him a piece of a broiled fish, and of an honeycomb.
26035	997	43	And he took it, and did eat before them.
26036	997	44	And he said unto them, These are the words which I spake unto you, while I was yet with you, that all things must be fulfilled, which were written in the law of Moses, and in the prophets, and in the psalms, concerning me.
26037	997	45	Then opened he their understanding, that they might understand the scriptures,
26038	997	46	And said unto them, Thus it is written, and thus it behoved Christ to suffer, and to rise from the dead the third day:
26039	997	47	And that repentance and remission of sins should be preached in his name among all nations, beginning at Jerusalem.
26040	997	48	And ye are witnesses of these things.
26041	997	49	And, behold, I send the promise of my Father upon you: but tarry ye in the city of Jerusalem, until ye be endued with power from on high.
26042	997	50	And he led them out as far as to Bethany, and he lifted up his hands, and blessed them.
26043	997	51	And it came to pass, while he blessed them, he was parted from them, and carried up into heaven.
26044	997	52	And they worshipped him, and returned to Jerusalem with great joy:
26045	997	53	And were continually in the temple, praising and blessing God. Amen.
26046	998	1	IN the beginning was the Word, and the Word was with God, and the Word was God.
26047	998	2	The same was in the beginning with God.
26048	998	3	All things were made by him; and without him was not any thing made that was made.
26049	998	4	In him was life; and the life was the light of men.
26050	998	5	And the light shineth in darkness; and the darkness comprehended it not.
26051	998	6	There was a man sent from God, whose name was John.
26052	998	7	The same came for a witness, to bear witness of the Light, that all men through him might believe.
26053	998	8	He was not that Light, but was sent to bear witness of that Light.
26054	998	9	That was the true Light, which lighteth every man that cometh into the world.
26055	998	10	He was in the world, and the world was made by him, and the world knew him not.
26056	998	11	He came unto his own, and his own received him not.
26057	998	12	But as many as received him, to them gave he power to become the sons of God, even to them that believe on his name:
26058	998	13	Which were born, not of blood, nor of the will of the flesh, nor of the will of man, but of God.
26059	998	14	And the Word was made flesh, and dwelt among us, (and we beheld his glory, the glory as of the only begotten of the Father,) full of grace and truth.
26060	998	15	John bare witness of him, and cried, saying, This was he of whom I spake, He that cometh after me is preferred before me: for he was before me.
26061	998	16	And of his fulness have all we received, and grace for grace.
26062	998	17	For the law was given by Moses, but grace and truth came by Jesus Christ.
26063	998	18	No man hath seen God at any time; the only begotten Son, which is in the bosom of the Father, he hath declared him.
26064	998	19	And this is the record of John, when the Jews sent priests and Levites from Jerusalem to ask him, Who art thou?
26065	998	20	And he confessed, and denied not; but confessed, I am not the Christ.
26066	998	21	And they asked him, What then? Art thou Elias? And he saith, I am not. Art thou that prophet? And he answered, No.
26067	998	22	Then said they unto him, Who art thou? that we may give an answer to them that sent us. What sayest thou of thyself?
26068	998	23	He said, I am the voice of one crying in the wilderness, Make straight the way of the Lord, as said the prophet Esaias.
26069	998	24	And they which were sent were of the Pharisees.
26070	998	25	And they asked him, and said unto him, Why baptizest thou then, if thou be not that Christ, nor Elias, neither that prophet?
26071	998	26	John answered them, saying, I baptize with water: but there standeth one among you, whom ye know not;
26072	998	27	He it is, who coming after me is preferred before me, whose shoe's latchet I am not worthy to unloose.
26073	998	28	These things were done in Bethabara beyond Jordan, where John was baptizing.
26074	998	29	The next day John seeth Jesus coming unto him, and saith, Behold the Lamb of God, which taketh away the sin of the world.
26075	998	30	This is he of whom I said, After me cometh a man which is preferred before me: for he was before me.
26076	998	31	And I knew him not: but that he should be made manifest to Israel, therefore am I come baptizing with water.
26077	998	32	And John bare record, saying, I saw the Spirit descending from heaven like a dove, and it abode upon him.
26078	998	33	And I knew him not: but he that sent me to baptize with water, the same said unto me, Upon whom thou shalt see the Spirit descending, and remaining on him, the same is he which baptizeth with the Holy Ghost.
26079	998	34	And I saw, and bare record that this is the Son of God.
26080	998	35	Again the next day after John stood, and two of his disciples;
26081	998	36	And looking upon Jesus as he walked, he saith, Behold the Lamb of God!
26082	998	37	And the two disciples heard him speak, and they followed Jesus.
26083	998	38	Then Jesus turned, and saw them following, and saith unto them, What seek ye? They said unto him, Rabbi, (which is to say, being interpreted, Master,) where dwellest thou?
26084	998	39	He saith unto them, Come and see. They came and saw where he dwelt, and abode with him that day: for it was about the tenth hour.
26085	998	40	One of the two which heard John speak, and followed him, was Andrew, Simon Peter's brother.
26086	998	41	He first findeth his own brother Simon, and saith unto him, We have found the Messias, which is, being interpreted, the Christ.
26087	998	42	And he brought him to Jesus. And when Jesus beheld him, he said, Thou art Simon the son of Jona: thou shalt be called Cephas, which is by interpretation, A stone.
26088	998	43	The day following Jesus would go forth into Galilee, and findeth Philip, and saith unto him, Follow me.
26089	998	44	Now Philip was of Bethsaida, the city of Andrew and Peter.
26090	998	45	Philip findeth Nathanael, and saith unto him, We have found him, of whom Moses in the law, and the prophets, did write, Jesus of Nazareth, the son of Joseph.
26091	998	46	And Nathanael said unto him, Can there any good thing come out of Nazareth? Philip saith unto him, Come and see.
26092	998	47	Jesus saw Nathanael coming to him, and saith of him, Behold an Israelite indeed, in whom is no guile!
26093	998	48	Nathanael saith unto him, Whence knowest thou me? Jesus answered and said unto him, Before that Philip called thee, when thou wast under the fig tree, I saw thee.
26094	998	49	Nathanael answered and saith unto him, Rabbi, thou art the Son of God; thou art the King of Israel.
26095	998	50	Jesus answered and said unto him, Because I said unto thee, I saw thee under the fig tree, believest thou? thou shalt see greater things than these.
26096	998	51	And he saith unto him, Verily, verily, I say unto you, Hereafter ye shall see heaven open, and the angels of God ascending and descending upon the Son of man.
26097	999	1	AND the third day there was a marriage in Cana of Galilee; and the mother of Jesus was there:
26098	999	2	And both Jesus was called, and his disciples, to the marriage.
26099	999	3	And when they wanted wine, the mother of Jesus saith unto him, They have no wine.
26100	999	4	Jesus saith unto her, Woman, what have I to do with thee? mine hour is not yet come.
26101	999	5	His mother saith unto the servants, Whatsoever he saith unto you, do it.
26102	999	6	And there were set there six waterpots of stone, after the manner of the purifying of the Jews, containing two or three firkins apiece.
26103	999	7	Jesus saith unto them, Fill the waterpots with water. And they filled them up to the brim.
26104	999	8	And he saith unto them, Draw out now, and bear unto the governor of the feast. And they bare it.
26105	999	9	When the ruler of the feast had tasted the water that was made wine, and knew not whence it was: (but the servants which drew the water knew;) the governor of the feast called the bridegroom,
26106	999	10	And saith unto him, Every man at the beginning doth set forth good wine; and when men have well drunk, then that which is worse: but thou hast kept the good wine until now.
26107	999	11	This beginning of miracles did Jesus in Cana of Galilee, and manifested forth his glory; and his disciples believed on him.
26108	999	12	After this he went down to Capernaum, he, and his mother, and his brethren, and his disciples: and they continued there not many days.
26109	999	13	And the Jews' passover was at hand, and Jesus went up to Jerusalem,
26110	999	14	And found in the temple those that sold oxen and sheep and doves, and the changers of money sitting:
26111	999	15	And when he had made a scourge of small cords, he drove them all out of the temple, and the sheep, and the oxen; and poured out the changers' money, and overthrew the tables;
26112	999	16	And said unto them that sold doves, Take these things hence; make not my Father's house an house of merchandise.
26113	999	17	And his disciples remembered that it was written, The zeal of thine house hath eaten me up.
26114	999	18	Then answered the Jews and said unto him, What sign shewest thou unto us, seeing that thou doest these things?
26115	999	19	Jesus answered and said unto them, Destroy this temple, and in three days I will raise it up.
26116	999	20	Then said the Jews, Forty and six years was this temple in building, and wilt thou rear it up in three days?
26117	999	21	But he spake of the temple of his body.
26118	999	22	When therefore he was risen from the dead, his disciples remembered that he had said this unto them; and they believed the scripture, and the word which Jesus had said.
26119	999	23	Now when he was in Jerusalem at the passover, in the feast day, many believed in his name, when they saw the miracles which he did.
26120	999	24	But Jesus did not commit himself unto them, because he knew all men,
26121	999	25	And needed not that any should testify of man: for he knew what was in man.
26122	1000	1	THERE was a man of the Pharisees, named Nicodemus, a ruler of the Jews:
26123	1000	2	The same came to Jesus by night, and said unto him, Rabbi, we know that thou art a teacher come from God: for no man can do these miracles that thou doest, except God be with him.
26124	1000	3	Jesus answered and said unto him, Verily, verily, I say unto thee, Except a man be born again, he cannot see the kingdom of God.
26125	1000	4	Nicodemus saith unto him, How can a man be born when he is old? can he enter the second time into his mother's womb, and be born?
26126	1000	5	Jesus answered, Verily, verily, I say unto thee, Except a man be born of water and of the Spirit, he cannot enter into the kingdom of God.
26127	1000	6	That which is born of the flesh is flesh; and that which is born of the Spirit is spirit.
26128	1000	7	Marvel not that I said unto thee, Ye must be born again.
26129	1000	8	The wind bloweth where it listeth, and thou hearest the sound thereof, but canst not tell whence it cometh, and whither it goeth: so is every one that is born of the Spirit.
26130	1000	9	Nicodemus answered and said unto him, How can these things be?
26131	1000	10	Jesus answered and said unto him, Art thou a master of Israel, and knowest not these things?
26132	1000	11	Verily, verily, I say unto thee, We speak that we do know, and testify that we have seen; and ye receive not our witness.
26133	1000	12	If I have told you earthly things, and ye believe not, how shall ye believe, if I tell you of heavenly things?
26134	1000	13	And no man hath ascended up to heaven, but he that came down from heaven, even the Son of man which is in heaven.
26135	1000	14	And as Moses lifted up the serpent in the wilderness, even so must the Son of man be lifted up:
26136	1000	15	That whosoever believeth in him should not perish, but have eternal life.
26137	1000	16	For God so loved the world, that he gave his only begotten Son, that whosoever believeth in him should not perish, but have everlasting life.
26138	1000	17	For God sent not his Son into the world to condemn the world; but that the world through him might be saved.
26139	1000	18	He that believeth on him is not condemned: but he that believeth not is condemned already, because he hath not believed in the name of the only begotten Son of God.
26140	1000	19	And this is the condemnation, that light is come into the world, and men loved darkness rather than light, because their deeds were evil.
26141	1000	20	For every one that doeth evil hateth the light, neither cometh to the light, lest his deeds should be reproved.
26142	1000	21	But he that doeth truth cometh to the light, that his deeds may be made manifest, that they are wrought in God.
26143	1000	22	After these things came Jesus and his disciples into the land of Judaea; and there he tarried with them, and baptized.
26144	1000	23	And John also was baptizing in Aenon near to Salim, because there was much water there: and they came, and were baptized.
26145	1000	24	For John was not yet cast into prison.
26146	1000	25	Then there arose a question between some of John's disciples and the Jews about purifying.
26147	1000	26	And they came unto John, and said unto him, Rabbi, he that was with thee beyond Jordan, to whom thou barest witness, behold, the same baptizeth, and all men come to him.
26148	1000	27	John answered and said, A man can receive nothing, except it be given him from heaven.
26149	1000	28	Ye yourselves bear me witness, that I said, I am not the Christ, but that I am sent before him.
26150	1000	29	He that hath the bride is the bridegroom: but the friend of the bridegroom, which standeth and heareth him, rejoiceth greatly because of the bridegroom's voice: this my joy therefore is fulfilled.
26151	1000	30	He must increase, but I must decrease.
26152	1000	31	He that cometh from above is above all: he that is of the earth is earthly, and speaketh of the earth: he that cometh from heaven is above all.
26153	1000	32	And what he hath seen and heard, that he testifieth; and no man receiveth his testimony.
26154	1000	33	He that hath received his testimony hath set to his seal that God is true.
26155	1000	34	For he whom God hath sent speaketh the words of God: for God giveth not the Spirit by measure unto him.
26156	1000	35	The Father loveth the Son, and hath given all things into his hand.
26157	1000	36	He that believeth on the Son hath everlasting life: and he that believeth not the Son shall not see life; but the wrath of God abideth on him.
26158	1001	1	WHEN therefore the Lord knew how the Pharisees had heard that Jesus made and baptized more disciples than John,
26159	1001	2	(Though Jesus himself baptized not, but his disciples,)
26160	1001	3	He left Judaea, and departed again into Galilee.
26161	1001	4	And he must needs go through Samaria.
26162	1001	5	Then cometh he to a city of Samaria, which is called Sychar, near to the parcel of ground that Jacob gave to his son Joseph.
26163	1001	6	Now Jacob's well was there. Jesus therefore, being wearied with his journey, sat thus on the well: and it was about the sixth hour.
26164	1001	7	There cometh a woman of Samaria to draw water: Jesus saith unto her, Give me to drink.
26165	1001	8	(For his disciples were gone away unto the city to buy meat.)
26166	1001	9	Then saith the woman of Samaria unto him, How is it that thou, being a Jew, askest drink of me, which am a woman of Samaria? for the Jews have no dealings with the Samaritans.
26167	1001	10	Jesus answered and said unto her, If thou knewest the gift of God, and who it is that saith to thee, Give me to drink; thou wouldest have asked of him, and he would have given thee living water.
26168	1001	11	The woman saith unto him, Sir, thou hast nothing to draw with, and the well is deep: from whence then hast thou that living water?
26169	1001	12	Art thou greater than our father Jacob, which gave us the well, and drank thereof himself, and his children, and his cattle?
26170	1001	13	Jesus answered and said unto her, Whosoever drinketh of this water shall thirst again:
26171	1001	14	But whosoever drinketh of the water that I shall give him shall never thirst; but the water that I shall give him shall be in him a well of water springing up into everlasting life.
26172	1001	15	The woman saith unto him, Sir, give me this water, that I thirst not, neither come hither to draw.
26173	1001	16	Jesus saith unto her, Go, call thy husband, and come hither.
26174	1001	17	The woman answered and said, I have no husband. Jesus said unto her, Thou hast well said, I have no husband:
26175	1001	18	For thou hast had five husbands; and he whom thou now hast is not thy husband: in that saidst thou truly.
26176	1001	19	The woman saith unto him, Sir, I perceive that thou art a prophet.
26177	1001	20	Our fathers worshipped in this mountain; and ye say, that in Jerusalem is the place where men ought to worship.
26178	1001	21	Jesus saith unto her, Woman, believe me, the hour cometh, when ye shall neither in this mountain, nor yet at Jerusalem, worship the Father.
26179	1001	22	Ye worship ye know not what: we know what we worship: for salvation is of the Jews.
26180	1001	23	But the hour cometh, and now is, when the true worshippers shall worship the Father in spirit and in truth: for the Father seeketh such to worship him.
26181	1001	24	God is a Spirit: and they that worship him must worship him in spirit and in truth.
26182	1001	25	The woman saith unto him, I know that Messias cometh, which is called Christ: when he is come, he will tell us all things.
26183	1001	26	Jesus saith unto her, I that speak unto thee am he.
26184	1001	27	And upon this came his disciples, and marvelled that he talked with the woman: yet no man said, What seekest thou? or, Why talkest thou with her?
26185	1001	28	The woman then left her waterpot, and went her way into the city, and saith to the men,
26186	1001	29	Come, see a man, which told me all things that ever I did: is not this the Christ?
26187	1001	30	Then they went out of the city, and came unto him.
26188	1001	31	In the mean while his disciples prayed him, saying, Master, eat.
26189	1001	32	But he said unto them, I have meat to eat that ye know not of.
26190	1001	33	Therefore said the disciples one to another, Hath any man brought him ought to eat?
26191	1001	34	Jesus saith unto them, My meat is to do the will of him that sent me, and to finish his work.
26192	1001	35	Say not ye, There are yet four months, and then cometh harvest? behold, I say unto you, Lift up your eyes, and look on the fields; for they are white already to harvest.
26193	1001	36	And he that reapeth receiveth wages, and gathereth fruit unto life eternal: that both he that soweth and he that reapeth may rejoice together.
26194	1001	37	And herein is that saying true, One soweth, and another reapeth.
26195	1001	38	I sent you to reap that whereon ye bestowed no labour: other men laboured, and ye are entered into their labours.
26196	1001	39	And many of the Samaritans of that city believed on him for the saying of the woman, which testified, He told me all that ever I did.
26197	1001	40	So when the Samaritans were come unto him, they besought him that he would tarry with them: and he abode there two days.
26198	1001	41	And many more believed because of his own word;
26199	1001	42	And said unto the woman, Now we believe, not because of thy saying: for we have heard him ourselves, and know that this is indeed the Christ, the Saviour of the world.
26200	1001	43	Now after two days he departed thence, and went into Galilee.
26201	1001	44	For Jesus himself testified, that a prophet hath no honour in his own country.
26202	1001	45	Then when he was come into Galilee, the Galilaeans received him, having seen all the things that he did at Jerusalem at the feast: for they also went unto the feast.
26203	1001	46	So Jesus came again into Cana of Galilee, where he made the water wine. And there was a certain nobleman, whose son was sick at Capernaum.
26204	1001	47	When he heard that Jesus was come out of Judaea into Galilee, he went unto him, and besought him that he would come down, and heal his son: for he was at the point of death.
26205	1001	48	Then said Jesus unto him, Except ye see signs and wonders, ye will not believe.
26206	1001	49	The nobleman saith unto him, Sir, come down ere my child die.
26207	1001	50	Jesus saith unto him, Go thy way; thy son liveth. And the man believed the word that Jesus had spoken unto him, and he went his way.
26208	1001	51	And as he was now going down, his servants met him, and told him, saying, Thy son liveth.
26209	1001	52	Then enquired he of them the hour when he began to amend. And they said unto him, Yesterday at the seventh hour the fever left him.
26210	1001	53	So the father knew that it was at the same hour, in the which Jesus said unto him, Thy son liveth: and himself believed, and his whole house.
26211	1001	54	This is again the second miracle that Jesus did, when he was come out of Judaea into Galilee.
26212	1002	1	AFTER this there was a feast of the Jews; and Jesus went up to Jerusalem.
26213	1002	2	Now there is at Jerusalem by the sheep market a pool, which is called in the Hebrew tongue Bethesda, having five porches.
26214	1002	3	In these lay a great multitude of impotent folk, of blind, halt, withered, waiting for the moving of the water.
26215	1002	4	For an angel went down at a certain season into the pool, and troubled the water: whosoever then first after the troubling of the water stepped in was made whole of whatsoever disease he had.
26216	1002	5	And a certain man was there, which had an infirmity thirty and eight years.
26217	1002	6	When Jesus saw him lie, and knew that he had been now a long time in that case, he saith unto him, Wilt thou be made whole?
26218	1002	7	The impotent man answered him, Sir, I have no man, when the water is troubled, to put me into the pool: but while I am coming, another steppeth down before me.
26219	1002	8	Jesus saith unto him, Rise, take up thy bed, and walk.
26220	1002	9	And immediately the man was made whole, and took up his bed, and walked: and on the same day was the sabbath.
26221	1002	10	The Jews therefore said unto him that was cured, It is the sabbath day: it is not lawful for thee to carry thy bed.
26222	1002	11	He answered them, He that made me whole, the same said unto me, Take up thy bed, and walk.
26223	1002	12	Then asked they him, What man is that which said unto thee, Take up thy bed, and walk?
26224	1002	13	And he that was healed wist not who it was: for Jesus had conveyed himself away, a multitude being in that place.
26225	1002	14	Afterward Jesus findeth him in the temple, and said unto him, Behold, thou art made whole: sin no more, lest a worse thing come unto thee.
26226	1002	15	The man departed, and told the Jews that it was Jesus, which had made him whole.
26227	1002	16	And therefore did the Jews persecute Jesus, and sought to slay him, because he had done these things on the sabbath day.
26228	1002	17	But Jesus answered them, My Father worketh hitherto, and I work.
26229	1002	18	Therefore the Jews sought the more to kill him, because he not only had broken the sabbath, but said also that God was his Father, making himself equal with God.
26230	1002	19	Then answered Jesus and said unto them, Verily, verily, I say unto you, The Son can do nothing of himself, but what he seeth the Father do: for what things soever he doeth, these also doeth the Son likewise.
26231	1002	20	For the Father loveth the Son, and sheweth him all things that himself doeth: and he will shew him greater works than these, that ye may marvel.
26232	1002	21	For as the Father raiseth up the dead, and quickeneth them; even so the Son quickeneth whom he will.
26233	1002	22	For the Father judgeth no man, but hath committed all judgment unto the Son:
26234	1002	23	That all men should honour the Son, even as they honour the Father. He that honoureth not the Son honoureth not the Father which hath sent him.
26235	1002	24	Verily, verily, I say unto you, He that heareth my word, and believeth on him that sent me, hath everlasting life, and shall not come into condemnation; but is passed from death unto life.
26236	1002	25	Verily, verily, I say unto you, The hour is coming, and now is, when the dead shall hear the voice of the Son of God: and they that hear shall live.
26237	1002	26	For as the Father hath life in himself; so hath he given to the Son to have life in himself;
26238	1002	27	And hath given him authority to execute judgment also, because he is the Son of man.
26239	1002	28	Marvel not at this: for the hour is coming, in the which all that are in the graves shall hear his voice,
26240	1002	29	And shall come forth; they that have done good, unto the resurrection of life; and they that have done evil, unto the resurrection of damnation.
26241	1002	30	I can of mine own self do nothing: as I hear, I judge: and my judgment is just; because I seek not mine own will, but the will of the Father which hath sent me.
26242	1002	31	If I bear witness of myself, my witness is not true.
26243	1002	32	There is another that beareth witness of me; and I know that the witness which he witnesseth of me is true.
26244	1002	33	Ye sent unto John, and he bare witness unto the truth.
26245	1002	34	But I receive not testimony from man: but these things I say, that ye might be saved.
26246	1002	35	He was a burning and a shining light: and ye were willing for a season to rejoice in his light.
26247	1002	36	But I have greater witness than that of John: for the works which the Father hath given me to finish, the same works that I do, bear witness of me, that the Father hath sent me.
26248	1002	37	And the Father himself, which hath sent me, hath borne witness of me. Ye have neither heard his voice at any time, nor seen his shape.
26249	1002	38	And ye have not his word abiding in you: for whom he hath sent, him ye believe not.
26250	1002	39	Search the scriptures; for in them ye think ye have eternal life: and they are they which testify of me.
26251	1002	40	And ye will not come to me, that ye might have life.
26252	1002	41	I receive not honour from men.
26253	1002	42	But I know you, that ye have not the love of God in you.
26254	1002	43	I am come in my Father's name, and ye receive me not: if another shall come in his own name, him ye will receive.
26255	1002	44	How can ye believe, which receive honour one of another, and seek not the honour that cometh from God only?
26256	1002	45	Do not think that I will accuse you to the Father: there is one that accuseth you, even Moses, in whom ye trust.
26257	1002	46	For had ye believed Moses, ye would have believed me: for he wrote of me.
26258	1002	47	But if ye believe not his writings, how shall ye believe my words?
26259	1003	1	AFTER these things Jesus went over the sea of Galilee, which is the sea of Tiberias.
26260	1003	2	And a great multitude followed him, because they saw his miracles which he did on them that were diseased.
26261	1003	3	And Jesus went up into a mountain, and there he sat with his disciples.
26262	1003	4	And the passover, a feast of the Jews, was nigh.
26263	1003	5	When Jesus then lifted up his eyes, and saw a great company come unto him, he saith unto Philip, Whence shall we buy bread, that these may eat?
26264	1003	6	And this he said to prove him: for he himself knew what he would do.
26265	1003	7	Philip answered him, Two hundred pennyworth of bread is not sufficient for them, that every one of them may take a little.
26266	1003	8	One of his disciples, Andrew, Simon Peter's brother, saith unto him,
26267	1003	9	There is a lad here, which hath five barley loaves, and two small fishes: but what are they among so many?
26268	1003	10	And Jesus said, Make the men sit down. Now there was much grass in the place. So the men sat down, in number about five thousand.
26269	1003	11	And Jesus took the loaves; and when he had given thanks, he distributed to the disciples, and the disciples to them that were set down; and likewise of the fishes as much as they would.
26270	1003	12	When they were filled, he said unto his disciples, Gather up the fragments that remain, that nothing be lost.
26271	1003	13	Therefore they gathered them together, and filled twelve baskets with the fragments of the five barley loaves, which remained over and above unto them that had eaten.
26272	1003	14	Then those men, when they had seen the miracle that Jesus did, said, This is of a truth that prophet that should come into the world.
26273	1003	15	When Jesus therefore perceived that they would come and take him by force, to make him a king, he departed again into a mountain himself alone.
26274	1003	16	And when even was now come, his disciples went down unto the sea,
26275	1003	17	And entered into a ship, and went over the sea toward Capernaum. And it was now dark, and Jesus was not come to them.
26276	1003	18	And the sea arose by reason of a great wind that blew.
26277	1003	19	So when they had rowed about five and twenty or thirty furlongs, they see Jesus walking on the sea, and drawing nigh unto the ship: and they were afraid.
26278	1003	20	But he saith unto them, It is I; be not afraid.
26279	1003	21	Then they willingly received him into the ship: and immediately the ship was at the land whither they went.
26280	1003	22	The day following, when the people which stood on the other side of the sea saw that there was none other boat there, save that one whereinto his disciples were entered, and that Jesus went not with his disciples into the boat, but that his disciples were gone away alone;
26281	1003	23	(Howbeit there came other boats from Tiberias nigh unto the place where they did eat bread, after that the Lord had given thanks:)
26282	1003	24	When the people therefore saw that Jesus was not there, neither his disciples, they also took shipping, and came to Capernaum, seeking for Jesus.
26283	1003	25	And when they had found him on the other side of the sea, they said unto him, Rabbi, when camest thou hither?
26284	1003	26	Jesus answered them and said, Verily, verily, I say unto you, Ye seek me, not because ye saw the miracles, but because ye did eat of the loaves, and were filled.
26285	1003	27	Labour not for the meat which perisheth, but for that meat which endureth unto everlasting life, which the Son of man shall give unto you: for him hath God the Father sealed.
26286	1003	28	Then said they unto him, What shall we do, that we might work the works of God?
26287	1003	29	Jesus answered and said unto them, This is the work of God, that ye believe on him whom he hath sent.
26288	1003	30	They said therefore unto him, What sign shewest thou then, that we may see, and believe thee? what dost thou work?
26289	1003	31	Our fathers did eat manna in the desert; as it is written, He gave them bread from heaven to eat.
26290	1003	32	Then Jesus said unto them, Verily, verily, I say unto you, Moses gave you not that bread from heaven; but my Father giveth you the true bread from heaven.
26291	1003	33	For the bread of God is he which cometh down from heaven, and giveth life unto the world.
26292	1003	34	Then said they unto him, Lord, evermore give us this bread.
26293	1003	35	And Jesus said unto them, I am the bread of life: he that cometh to me shall never hunger; and he that believeth on me shall never thirst.
26294	1003	36	But I said unto you, That ye also have seen me, and believe not.
26295	1003	37	All that the Father giveth me shall come to me; and him that cometh to me I will in no wise cast out.
26296	1003	38	For I came down from heaven, not to do mine own will, but the will of him that sent me.
26297	1003	39	And this is the Father's will which hath sent me, that of all which he hath given me I should lose nothing, but should raise it up again at the last day.
26298	1003	40	And this is the will of him that sent me, that every one which seeth the Son, and believeth on him, may have everlasting life: and I will raise him up at the last day.
26299	1003	41	The Jews then murmured at him, because he said, I am the bread which came down from heaven.
26300	1003	42	And they said, Is not this Jesus, the son of Joseph, whose father and mother we know? how is it then that he saith, I came down from heaven?
26301	1003	43	Jesus therefore answered and said unto them, Murmur not among yourselves.
26302	1003	44	No man can come to me, except the Father which hath sent me draw him: and I will raise him up at the last day.
26303	1003	45	It is written in the prophets, And they shall be all taught of God. Every man therefore that hath heard, and hath learned of the Father, cometh unto me.
26304	1003	46	Not that any man hath seen the Father, save he which is of God, he hath seen the Father.
26305	1003	47	Verily, verily, I say unto you, He that believeth on me hath everlasting life.
26306	1003	48	I am that bread of life.
26307	1003	49	Your fathers did eat manna in the wilderness, and are dead.
26308	1003	50	This is the bread which cometh down from heaven, that a man may eat thereof, and not die.
26309	1003	51	I am the living bread which came down from heaven: if any man eat of this bread, he shall live for ever: and the bread that I will give is my flesh, which I will give for the life of the world.
26310	1003	52	The Jews therefore strove among themselves, saying, How can this man give us his flesh to eat?
26311	1003	53	Then Jesus said unto them, Verily, verily, I say unto you, Except ye eat the flesh of the Son of man, and drink his blood, ye have no life in you.
26312	1003	54	Whoso eateth my flesh, and drinketh my blood, hath eternal life; and I will raise him up at the last day.
26313	1003	55	For my flesh is meat indeed, and my blood is drink indeed.
26314	1003	56	He that eateth my flesh, and drinketh my blood, dwelleth in me, and I in him.
26315	1003	57	As the living Father hath sent me, and I live by the Father: so he that eateth me, even he shall live by me.
26316	1003	58	This is that bread which came down from heaven: not as your fathers did eat manna, and are dead: he that eateth of this bread shall live for ever.
26317	1003	59	These things said he in the synagogue, as he taught in Capernaum.
26318	1003	60	Many therefore of his disciples, when they had heard this, said, This is an hard saying; who can hear it?
26319	1003	61	When Jesus knew in himself that his disciples murmured at it, he said unto them, Doth this offend you?
26320	1003	62	What and if ye shall see the Son of man ascend up where he was before?
26321	1003	63	It is the spirit that quickeneth; the flesh profiteth nothing: the words that I speak unto you, they are spirit, and they are life.
26322	1003	64	But there are some of you that believe not. For Jesus knew from the beginning who they were that believed not, and who should betray him.
26323	1003	65	And he said, Therefore said I unto you, that no man can come unto me, except it were given unto him of my Father.
26324	1003	66	From that time many of his disciples went back, and walked no more with him.
26325	1003	67	Then said Jesus unto the twelve, Will ye also go away?
26326	1003	68	Then Simon Peter answered him, Lord, to whom shall we go? thou hast the words of eternal life.
26327	1003	69	And we believe and are sure that thou art that Christ, the Son of the living God.
26328	1003	70	Jesus answered them, Have not I chosen you twelve, and one of you is a devil?
26329	1003	71	He spake of Judas Iscariot the son of Simon: for he it was that should betray him, being one of the twelve.
26330	1004	1	AFTER these things Jesus walked in Galilee: for he would not walk in Jewry, because the Jews sought to kill him.
26331	1004	2	Now the Jews' feast of tabernacles was at hand.
26332	1004	3	His brethren therefore said unto him, Depart hence, and go into Judaea, that thy disciples also may see the works that thou doest.
26333	1004	4	For there is no man that doeth any thing in secret, and he himself seeketh to be known openly. If thou do these things, shew thyself to the world.
26334	1004	5	For neither did his brethren believe in him.
26335	1004	6	Then Jesus said unto them, My time is not yet come: but your time is alway ready.
26336	1004	7	The world cannot hate you; but me it hateth, because I testify of it, that the works thereof are evil.
26337	1004	8	Go ye up unto this feast: I go not up yet unto this feast; for my time is not yet full come.
26338	1004	9	When he had said these words unto them, he abode still in Galilee.
26339	1004	10	But when his brethren were gone up, then went he also up unto the feast, not openly, but as it were in secret.
26340	1004	11	Then the Jews sought him at the feast, and said, Where is he?
26341	1004	12	And there was much murmuring among the people concerning him: for some said, He is a good man: others said, Nay; but he deceiveth the people.
26342	1004	13	Howbeit no man spake openly of him for fear of the Jews.
26343	1004	14	Now about the midst of the feast Jesus went up into the temple, and taught.
26344	1004	15	And the Jews marvelled, saying, How knoweth this man letters, having never learned?
26345	1004	16	Jesus answered them, and said, My doctrine is not mine, but his that sent me.
26346	1004	17	If any man will do his will, he shall know of the doctrine, whether it be of God, or whether I speak of myself.
26347	1004	18	He that speaketh of himself seeketh his own glory: but he that seeketh his glory that sent him, the same is true, and no unrighteousness is in him.
26348	1004	19	Did not Moses give you the law, and yet none of you keepeth the law? Why go ye about to kill me?
26349	1004	20	The people answered and said, Thou hast a devil: who goeth about to kill thee?
26350	1004	21	Jesus answered and said unto them, I have done one work, and ye all marvel.
26351	1004	22	Moses therefore gave unto you circumcision; (not because it is of Moses, but of the fathers;) and ye on the sabbath day circumcise a man.
26352	1004	23	If a man on the sabbath day receive circumcision, that the law of Moses should not be broken; are ye angry at me, because I have made a man every whit whole on the sabbath day?
26353	1004	24	Judge not according to the appearance, but judge righteous judgment.
26354	1004	25	Then said some of them of Jerusalem, Is not this he, whom they seek to kill?
26355	1004	26	But, lo, he speaketh boldly, and they say nothing unto him. Do the rulers know indeed that this is the very Christ?
26356	1004	27	Howbeit we know this man whence he is: but when Christ cometh, no man knoweth whence he is.
26357	1004	28	Then cried Jesus in the temple as he taught, saying, Ye both know me, and ye know whence I am: and I am not come of myself, but he that sent me is true, whom ye know not.
26358	1004	29	But I know him: for I am from him, and he hath sent me.
26359	1004	30	Then they sought to take him: but no man laid hands on him, because his hour was not yet come.
26360	1004	31	And many of the people believed on him, and said, When Christ cometh, will he do more miracles than these which this man hath done?
26361	1004	32	The Pharisees heard that the people murmured such things concerning him; and the Pharisees and the chief priests sent officers to take him.
26362	1004	33	Then said Jesus unto them, Yet a little while am I with you, and then I go unto him that sent me.
26363	1004	34	Ye shall seek me, and shall not find me: and where I am, thither ye cannot come.
26364	1004	35	Then said the Jews among themselves, Whither will he go, that we shall not find him? will he go unto the dispersed among the Gentiles, and teach the Gentiles?
26365	1004	36	What manner of saying is this that he said, Ye shall seek me, and shall not find me: and where I am, thither ye cannot come?
26366	1004	37	In the last day, that great day of the feast, Jesus stood and cried, saying, If any man thirst, let him come unto me, and drink.
26367	1004	38	He that believeth on me, as the scripture hath said, out of his belly shall flow rivers of living water.
26368	1004	39	(But this spake he of the Spirit, which they that believe on him should receive: for the Holy Ghost was not yet given; because that Jesus was not yet glorified.)
26369	1004	40	Many of the people therefore, when they heard this saying, said, Of a truth this is the Prophet.
26370	1004	41	Others said, This is the Christ. But some said, Shall Christ come out of Galilee?
26371	1004	42	Hath not the scripture said, That Christ cometh of the seed of David, and out of the town of Bethlehem, where David was?
26372	1004	43	So there was a division among the people because of him.
26373	1004	44	And some of them would have taken him; but no man laid hands on him.
26374	1004	45	Then came the officers to the chief priests and Pharisees; and they said unto them, Why have ye not brought him?
26375	1004	46	The officers answered, Never man spake like this man.
26376	1004	47	Then answered them the Pharisees, Are ye also deceived?
26377	1004	48	Have any of the rulers or of the Pharisees believed on him?
26378	1004	49	But this people who knoweth not the law are cursed.
26379	1004	50	Nicodemus saith unto them, (he that came to Jesus by night, being one of them,)
26380	1004	51	Doth our law judge any man, before it hear him, and know what he doeth?
26381	1004	52	They answered and said unto him, Art thou also of Galilee? Search, and look: for out of Galilee ariseth no prophet.
26382	1004	53	And every man went unto his own house.
26383	1005	1	JESUS went unto the mount of Olives.
26384	1005	2	And early in the morning he came again into the temple, and all the people came unto him; and he sat down, and taught them.
26385	1005	3	And the scribes and Pharisees brought unto him a woman taken in adultery; and when they had set her in the midst,
26386	1005	4	They say unto him, Master, this woman was taken in adultery, in the very act.
26387	1005	5	Now Moses in the law commanded us, that such should be stoned: but what sayest thou?
26388	1005	6	This they said, tempting him, that they might have to accuse him. But Jesus stooped down, and with his finger wrote on the ground, as though he heard them not.
26389	1005	7	So when they continued asking him, he lifted up himself, and said unto them, He that is without sin among you, let him first cast a stone at her.
26390	1005	8	And again he stooped down, and wrote on the ground.
26391	1005	9	And they which heard it, being convicted by their own conscience, went out one by one, beginning at the eldest, even unto the last: and Jesus was left alone, and the woman standing in the midst.
26392	1005	10	When Jesus had lifted up himself, and saw none but the woman, he said unto her, Woman, where are those thine accusers? hath no man condemned thee?
26393	1005	11	She said, No man, Lord. And Jesus said unto her, Neither do I condemn thee: go, and sin no more.
26394	1005	12	Then spake Jesus again unto them, saying, I am the light of the world: he that followeth me shall not walk in darkness, but shall have the light of life.
26395	1005	13	The Pharisees therefore said unto him, Thou bearest record of thyself; thy record is not true.
26396	1005	14	Jesus answered and said unto them, Though I bear record of myself, yet my record is true: for I know whence I came, and whither I go; but ye cannot tell whence I come, and whither I go.
26397	1005	15	Ye judge after the flesh; I judge no man.
26398	1005	16	And yet if I judge, my judgment is true: for I am not alone, but I and the Father that sent me.
26399	1005	17	It is also written in your law, that the testimony of two men is true.
26400	1005	18	I am one that bear witness of myself, and the Father that sent me beareth witness of me.
26401	1005	19	Then said they unto him, Where is thy Father? Jesus answered, Ye neither know me, nor my Father: if ye had known me, ye should have known my Father also.
26402	1005	20	These words spake Jesus in the treasury, as he taught in the temple: and no man laid hands on him; for his hour was not yet come.
26403	1005	21	Then said Jesus again unto them, I go my way, and ye shall seek me, and shall die in your sins: whither I go, ye cannot come.
26404	1005	22	Then said the Jews, Will he kill himself? because he saith, Whither I go, ye cannot come.
26405	1005	23	And he said unto them, Ye are from beneath; I am from above: ye are of this world; I am not of this world.
26406	1005	24	I said therefore unto you, that ye shall die in your sins: for if ye believe not that I am he, ye shall die in your sins.
26407	1005	25	Then said they unto him, Who art thou? And Jesus saith unto them, Even the same that I said unto you from the beginning.
26408	1005	26	I have many things to say and to judge of you: but he that sent me is true; and I speak to the world those things which I have heard of him.
26409	1005	27	They understood not that he spake to them of the Father.
26410	1005	28	Then said Jesus unto them, When ye have lifted up the Son of man, then shall ye know that I am he, and that I do nothing of myself; but as my Father hath taught me, I speak these things.
26411	1005	29	And he that sent me is with me: the Father hath not left me alone; for I do always those things that please him.
26412	1005	30	As he spake these words, many believed on him.
26413	1005	31	Then said Jesus to those Jews which believed on him, If ye continue in my word, then are ye my disciples indeed;
26414	1005	32	And ye shall know the truth, and the truth shall make you free.
26415	1005	33	They answered him, We be Abraham's seed, and were never in bondage to any man: how sayest thou, Ye shall be made free?
26416	1005	34	Jesus answered them, Verily, verily, I say unto you, Whosoever committeth sin is the servant of sin.
26417	1005	35	And the servant abideth not in the house for ever: but the Son abideth ever.
26418	1005	36	If the Son therefore shall make you free, ye shall be free indeed.
26419	1005	37	I know that ye are Abraham's seed; but ye seek to kill me, because my word hath no place in you.
26420	1005	38	I speak that which I have seen with my Father: and ye do that which ye have seen with your father.
26421	1005	39	They answered and said unto him, Abraham is our father. Jesus saith unto them, If ye were Abraham's children, ye would do the works of Abraham.
26422	1005	40	But now ye seek to kill me, a man that hath told you the truth, which I have heard of God: this did not Abraham.
26423	1005	41	Ye do the deeds of your father. Then said they to him, We be not born of fornication; we have one Father, even God.
26424	1005	42	Jesus said unto them, If God were your Father, ye would love me: for I proceeded forth and came from God; neither came I of myself, but he sent me.
26425	1005	43	Why do ye not understand my speech? even because ye cannot hear my word.
26426	1005	44	Ye are of your father the devil, and the lusts of your father ye will do. He was a murderer from the beginning, and abode not in the truth, because there is no truth in him. When he speaketh a lie, he speaketh of his own: for he is a liar, and the father of it.
26427	1005	45	And because I tell you the truth, ye believe me not.
26428	1005	46	Which of you convinceth me of sin? And if I say the truth, why do ye not believe me?
26429	1005	47	He that is of God heareth God's words: ye therefore hear them not, because ye are not of God.
26430	1005	48	Then answered the Jews, and said unto him, Say we not well that thou art a Samaritan, and hast a devil?
26431	1005	49	Jesus answered, I have not a devil; but I honour my Father, and ye do dishonour me.
26432	1005	50	And I seek not mine own glory: there is one that seeketh and judgeth.
26433	1005	51	Verily, verily, I say unto you, If a man keep my saying, he shall never see death.
26434	1005	52	Then said the Jews unto him, Now we know that thou hast a devil. Abraham is dead, and the prophets; and thou sayest, If a man keep my saying, he shall never taste of death.
26435	1005	53	Art thou greater than our father Abraham, which is dead? and the prophets are dead: whom makest thou thyself?
26436	1005	54	Jesus answered, If I honour myself, my honour is nothing: it is my Father that honoureth me; of whom ye say, that he is your God:
26437	1005	55	Yet ye have not known him; but I know him: and if I should say, I know him not, I shall be a liar like unto you: but I know him, and keep his saying.
26438	1005	56	Your father Abraham rejoiced to see my day: and he saw it, and was glad.
26439	1005	57	Then said the Jews unto him, Thou art not yet fifty years old, and hast thou seen Abraham?
26440	1005	58	Jesus said unto them, Verily, verily, I say unto you, Before Abraham was, I am.
26441	1005	59	Then took they up stones to cast at him: but Jesus hid himself, and went out of the temple, going through the midst of them, and so passed by.
26442	1006	1	AND as Jesus passed by, he saw a man which was blind from his birth.
26443	1006	2	And his disciples asked him, saying, Master, who did sin, this man, or his parents, that he was born blind?
26444	1006	3	Jesus answered, Neither hath this man sinned, nor his parents: but that the works of God should be made manifest in him.
26445	1006	4	I must work the works of him that sent me, while it is day: the night cometh, when no man can work.
26446	1006	5	As long as I am in the world, I am the light of the world.
26447	1006	6	When he had thus spoken, he spat on the ground, and made clay of the spittle, and he anointed the eyes of the blind man with the clay,
26448	1006	7	And said unto him, Go, wash in the pool of Siloam, (which is by interpretation, Sent.) He went his way therefore, and washed, and came seeing.
26449	1006	8	The neighbours therefore, and they which before had seen him that he was blind, said, Is not this he that sat and begged?
26450	1006	9	Some said, This is he: others said, He is like him: but he said, I am he.
26451	1006	10	Therefore said they unto him, How were thine eyes opened?
26452	1006	11	He answered and said, A man that is called Jesus made clay, and anointed mine eyes, and said unto me, Go to the pool of Siloam, and wash: and I went and washed, and I received sight.
26453	1006	12	Then said they unto him, Where is he? He said, I know not.
26454	1006	13	They brought to the Pharisees him that aforetime was blind.
26455	1006	14	And it was the sabbath day when Jesus made the clay, and opened his eyes.
26456	1006	15	Then again the Pharisees also asked him how he had received his sight. He said unto them, He put clay upon mine eyes, and I washed, and do see.
26457	1006	16	Therefore said some of the Pharisees, This man is not of God, because he keepeth not the sabbath day. Others said, How can a man that is a sinner do such miracles? And there was a division among them.
26458	1006	17	They say unto the blind man again, What sayest thou of him, that he hath opened thine eyes? He said, He is a prophet.
26459	1006	18	But the Jews did not believe concerning him, that he had been blind, and received his sight, until they called the parents of him that had received his sight.
26460	1006	19	And they asked them, saying, Is this your son, who ye say was born blind? how then doth he now see?
26461	1006	20	His parents answered them and said, We know that this is our son, and that he was born blind:
26462	1006	21	But by what means he now seeth, we know not; or who hath opened his eyes, we know not: he is of age; ask him: he shall speak for himself.
26463	1006	22	These words spake his parents, because they feared the Jews: for the Jews had agreed already, that if any man did confess that he was Christ, he should be put out of the synagogue.
26464	1006	23	Therefore said his parents, He is of age; ask him.
26465	1006	24	Then again called they the man that was blind, and said unto him, Give God the praise: we know that this man is a sinner.
26466	1006	25	He answered and said, Whether he be a sinner or no, I know not: one thing I know, that, whereas I was blind, now I see.
26467	1006	26	Then said they to him again, What did he to thee? how opened he thine eyes?
26468	1006	27	He answered them, I have told you already, and ye did not hear: wherefore would ye hear it again? will ye also be his disciples?
26469	1006	28	Then they reviled him, and said, Thou art his disciple; but we are Moses' disciples.
26470	1006	29	We know that God spake unto Moses: as for this fellow, we know not from whence he is.
26471	1006	30	The man answered and said unto them, Why herein is a marvellous thing, that ye know not from whence he is, and yet he hath opened mine eyes.
26472	1006	31	Now we know that God heareth not sinners: but if any man be a worshipper of God, and doeth his will, him he heareth.
26473	1006	32	Since the world began was it not heard that any man opened the eyes of one that was born blind.
26474	1006	33	If this man were not of God, he could do nothing.
26475	1006	34	They answered and said unto him, Thou wast altogether born in sins, and dost thou teach us? And they cast him out.
26476	1006	35	Jesus heard that they had cast him out; and when he had found him, he said unto him, Dost thou believe on the Son of God?
26477	1006	36	He answered and said, Who is he, Lord, that I might believe on him?
26478	1006	37	And Jesus said unto him, Thou hast both seen him, and it is he that talketh with thee.
26479	1006	38	And he said, Lord, I believe. And he worshipped him.
26480	1006	39	And Jesus said, For judgment I am come into this world, that they which see not might see; and that they which see might be made blind.
26481	1006	40	And some of the Pharisees which were with him heard these words, and said unto him, Are we blind also?
26482	1006	41	Jesus said unto them, If ye were blind, ye should have no sin: but now ye say, We see; therefore your sin remaineth.
26483	1007	1	VERILY, verily, I say unto you, He that entereth not by the door into the sheepfold, but climbeth up some other way, the same is a thief and a robber.
26484	1007	2	But he that entereth in by the door is the shepherd of the sheep.
26485	1007	3	To him the porter openeth; and the sheep hear his voice: and he calleth his own sheep by name, and leadeth them out.
26486	1007	4	And when he putteth forth his own sheep, he goeth before them, and the sheep follow him: for they know his voice.
26487	1007	5	And a stranger will they not follow, but will flee from him: for they know not the voice of strangers.
26488	1007	6	This parable spake Jesus unto them: but they understood not what things they were which he spake unto them.
26489	1007	7	Then said Jesus unto them again, Verily, verily, I say unto you, I am the door of the sheep.
26490	1007	8	All that ever came before me are thieves and robbers: but the sheep did not hear them.
26491	1007	9	I am the door: by me if any man enter in, he shall be saved, and shall go in and out, and find pasture.
26492	1007	10	The thief cometh not, but for to steal, and to kill, and to destroy: I am come that they might have life, and that they might have it more abundantly.
26493	1007	11	I am the good shepherd: the good shepherd giveth his life for the sheep.
26494	1007	12	But he that is an hireling, and not the shepherd, whose own the sheep are not, seeth the wolf coming, and leaveth the sheep, and fleeth: and the wolf catcheth them, and scattereth the sheep.
26495	1007	13	The hireling fleeth, because he is an hireling, and careth not for the sheep.
26496	1007	14	I am the good shepherd, and know my sheep, and am known of mine.
26497	1007	15	As the Father knoweth me, even so know I the Father: and I lay down my life for the sheep.
26498	1007	16	And other sheep I have, which are not of this fold: them also I must bring, and they shall hear my voice; and there shall be one fold, and one shepherd.
26499	1007	17	Therefore doth my Father love me, because I lay down my life, that I might take it again.
26500	1007	18	No man taketh it from me, but I lay it down of myself. I have power to lay it down, and I have power to take it again. This commandment have I received of my Father.
26501	1007	19	There was a division therefore again among the Jews for these sayings.
26502	1007	20	And many of them said, He hath a devil, and is mad; why hear ye him?
26503	1007	21	Others said, These are not the words of him that hath a devil. Can a devil open the eyes of the blind?
26504	1007	22	And it was at Jerusalem the feast of the dedication, and it was winter.
26505	1007	23	And Jesus walked in the temple in Solomon's porch.
26506	1007	24	Then came the Jews round about him, and said unto him, How long dost thou make us to doubt? If thou be the Christ, tell us plainly.
26507	1007	25	Jesus answered them, I told you, and ye believed not: the works that I do in my Father's name, they bear witness of me.
26508	1007	26	But ye believe not, because ye are not of my sheep, as I said unto you.
26509	1007	27	My sheep hear my voice, and I know them, and they follow me:
26510	1007	28	And I give unto them eternal life; and they shall never perish, neither shall any man pluck them out of my hand.
26511	1007	29	My Father, which gave them me, is greater than all; and no man is able to pluck them out of my Father's hand.
26512	1007	30	I and my Father are one.
26513	1007	31	Then the Jews took up stones again to stone him.
26514	1007	32	Jesus answered them, Many good works have I shewed you from my Father; for which of those works do ye stone me?
26515	1007	33	The Jews answered him, saying, For a good work we stone thee not; but for blasphemy; and because that thou, being a man, makest thyself God.
26516	1007	34	Jesus answered them, Is it not written in your law, I said, Ye are gods?
26517	1007	35	If he called them gods, unto whom the word of God came, and the scripture cannot be broken;
26518	1007	36	Say ye of him, whom the Father hath sanctified, and sent into the world, Thou blasphemest; because I said, I am the Son of God?
26519	1007	37	If I do not the works of my Father, believe me not.
26520	1007	38	But if I do, though ye believe not me, believe the works: that ye may know, and believe, that the Father is in me, and I in him.
26521	1007	39	Therefore they sought again to take him: but he escaped out of their hand,
26522	1007	40	And went away again beyond Jordan into the place where John at first baptized; and there he abode.
26523	1007	41	And many resorted unto him, and said, John did no miracle: but all things that John spake of this man were true.
26524	1007	42	And many believed on him there.
26525	1008	1	NOW a certain man was sick, named Lazarus, of Bethany, the town of Mary and her sister Martha.
26526	1008	2	(It was that Mary which anointed the Lord with ointment, and wiped his feet with her hair, whose brother Lazarus was sick.)
26527	1008	3	Therefore his sisters sent unto him, saying, Lord, behold, he whom thou lovest is sick.
26528	1008	4	When Jesus heard that, he said, This sickness is not unto death, but for the glory of God, that the Son of God might be glorified thereby.
26529	1008	5	Now Jesus loved Martha, and her sister, and Lazarus.
26530	1008	6	When he had heard therefore that he was sick, he abode two days still in the same place where he was.
26531	1008	7	Then after that saith he to his disciples, Let us go into Judaea again.
26532	1008	8	His disciples say unto him, Master, the Jews of late sought to stone thee; and goest thou thither again?
26533	1008	9	Jesus answered, Are there not twelve hours in the day? If any man walk in the day, he stumbleth not, because he seeth the light of this world.
26534	1008	10	But if a man walk in the night, he stumbleth, because there is no light in him.
26535	1008	11	These things said he: and after that he saith unto them, Our friend Lazarus sleepeth; but I go, that I may awake him out of sleep.
26536	1008	12	Then said his disciples, Lord, if he sleep, he shall do well.
26537	1008	13	Howbeit Jesus spake of his death: but they thought that he had spoken of taking of rest in sleep.
26538	1008	14	Then said Jesus unto them plainly, Lazarus is dead.
26539	1008	15	And I am glad for your sakes that I was not there, to the intent ye may believe; nevertheless let us go unto him.
26540	1008	16	Then said Thomas, which is called Didymus, unto his fellowdisciples, Let us also go, that we may die with him.
26541	1008	17	Then when Jesus came, he found that he had lain in the grave four days already.
26542	1008	18	Now Bethany was nigh unto Jerusalem, about fifteen furlongs off:
26543	1008	19	And many of the Jews came to Martha and Mary, to comfort them concerning their brother.
26544	1008	20	Then Martha, as soon as she heard that Jesus was coming, went and met him: but Mary sat still in the house.
26545	1008	21	Then said Martha unto Jesus, Lord, if thou hadst been here, my brother had not died.
26546	1008	22	But I know, that even now, whatsoever thou wilt ask of God, God will give it thee.
26547	1008	23	Jesus saith unto her, Thy brother shall rise again.
26548	1008	24	Martha saith unto him, I know that he shall rise again in the resurrection at the last day.
26549	1008	25	Jesus said unto her, I am the resurrection, and the life: he that believeth in me, though he were dead, yet shall he live:
26550	1008	26	And whosoever liveth and believeth in me shall never die. Believest thou this?
26551	1008	27	She saith unto him, Yea, Lord: I believe that thou art the Christ, the Son of God, which should come into the world.
26552	1008	28	And when she had so said, she went her way, and called Mary her sister secretly, saying, The Master is come, and calleth for thee.
26553	1008	29	As soon as she heard that, she arose quickly, and came unto him.
26554	1008	30	Now Jesus was not yet come into the town, but was in that place where Martha met him.
26555	1008	31	The Jews then which were with her in the house, and comforted her, when they saw Mary, that she rose up hastily and went out, followed her, saying, She goeth unto the grave to weep there.
26556	1008	32	Then when Mary was come where Jesus was, and saw him, she fell down at his feet, saying unto him, Lord, if thou hadst been here, my brother had not died.
26557	1008	33	When Jesus therefore saw her weeping, and the Jews also weeping which came with her, he groaned in the spirit, and was troubled,
26558	1008	34	And said, Where have ye laid him? They said unto him, Lord, come and see.
26559	1008	35	Jesus wept.
26560	1008	36	Then said the Jews, Behold how he loved him!
26561	1008	37	And some of them said, Could not this man, which opened the eyes of the blind, have caused that even this man should not have died?
26562	1008	38	Jesus therefore again groaning in himself cometh to the grave. It was a cave, and a stone lay upon it.
26563	1008	39	Jesus said, Take ye away the stone. Martha, the sister of him that was dead, saith unto him, Lord, by this time he stinketh: for he hath been dead four days.
26564	1008	40	Jesus saith unto her, Said I not unto thee, that, if thou wouldest believe, thou shouldest see the glory of God?
26565	1008	41	Then they took away the stone from the place where the dead was laid. And Jesus lifted up his eyes, and said, Father, I thank thee that thou hast heard me.
26566	1008	42	And I knew that thou hearest me always: but because of the people which stand by I said it, that they may believe that thou hast sent me.
26567	1008	43	And when he thus had spoken, he cried with a loud voice, Lazarus, come forth.
26568	1008	44	And he that was dead came forth, bound hand and foot with graveclothes: and his face was bound about with a napkin. Jesus saith unto them, Loose him, and let him go.
26569	1008	45	Then many of the Jews which came to Mary, and had seen the things which Jesus did, believed on him.
26570	1008	46	But some of them went their ways to the Pharisees, and told them what things Jesus had done.
26571	1008	47	Then gathered the chief priests and the Pharisees a council, and said, What do we? for this man doeth many miracles.
26572	1008	48	If we let him thus alone, all men will believe on him: and the Romans shall come and take away both our place and nation.
26573	1008	49	And one of them, named Caiaphas, being the high priest that same year, said unto them, Ye know nothing at all,
26574	1008	50	Nor consider that it is expedient for us, that one man should die for the people, and that the whole nation perish not.
26575	1008	51	And this spake he not of himself: but being high priest that year, he prophesied that Jesus should die for that nation;
26576	1008	52	And not for that nation only, but that also he should gather together in one the children of God that were scattered abroad.
26577	1008	53	Then from that day forth they took counsel together for to put him to death.
26578	1008	54	Jesus therefore walked no more openly among the Jews; but went thence unto a country near to the wilderness, into a city called Ephraim, and there continued with his disciples.
26579	1008	55	And the Jews' passover was nigh at hand: and many went out of the country up to Jerusalem before the passover, to purify themselves.
26580	1008	56	Then sought they for Jesus, and spake among themselves, as they stood in the temple, What think ye, that he will not come to the feast?
26581	1008	57	Now both the chief priests and the Pharisees had given a commandment, that, if any man knew where he were, he should shew it, that they might take him.
26582	1009	1	THEN Jesus six days before the passover came to Bethany, where Lazarus was which had been dead, whom he raised from the dead.
26583	1009	2	There they made him a supper; and Martha served: but Lazarus was one of them that sat at the table with him.
26584	1009	3	Then took Mary a pound of ointment of spikenard, very costly, and anointed the feet of Jesus, and wiped his feet with her hair: and the house was filled with the odour of the ointment.
26585	1009	4	Then saith one of his disciples, Judas Iscariot, Simon's son, which should betray him,
26586	1009	5	Why was not this ointment sold for three hundred pence, and given to the poor?
26587	1009	6	This he said, not that he cared for the poor; but because he was a thief, and had the bag, and bare what was put therein.
26588	1009	7	Then said Jesus, Let her alone: against the day of my burying hath she kept this.
26589	1009	8	For the poor always ye have with you; but me ye have not always.
26590	1009	9	Much people of the Jews therefore knew that he was there: and they came not for Jesus' sake only, but that they might see Lazarus also, whom he had raised from the dead.
26591	1009	10	But the chief priests consulted that they might put Lazarus also to death;
26592	1009	11	Because that by reason of him many of the Jews went away, and believed on Jesus.
26593	1009	12	On the next day much people that were come to the feast, when they heard that Jesus was coming to Jerusalem,
26594	1009	13	Took branches of palm trees, and went forth to meet him, and cried, Hosanna: Blessed is the King of Israel that cometh in the name of the Lord.
26595	1009	14	And Jesus, when he had found a young ass, sat thereon; as it is written,
26596	1009	15	Fear not, daughter of Sion: behold, thy King cometh, sitting on an ass's colt.
26597	1009	16	These things understood not his disciples at the first: but when Jesus was glorified, then remembered they that these things were written of him, and that they had done these things unto him.
26598	1009	17	The people therefore that was with him when he called Lazarus out of his grave, and raised him from the dead, bare record.
26599	1009	18	For this cause the people also met him, for that they heard that he had done this miracle.
26600	1009	19	The Pharisees therefore said among themselves, Perceive ye how ye prevail nothing? behold, the world is gone after him.
26601	1009	20	And there were certain Greeks among them that came up to worship at the feast:
26602	1009	21	The same came therefore to Philip, which was of Bethsaida of Galilee, and desired him, saying, Sir, we would see Jesus.
26603	1009	22	Philip cometh and telleth Andrew: and again Andrew and Philip tell Jesus.
26604	1009	23	And Jesus answered them, saying, The hour is come, that the Son of man should be glorified.
26605	1009	24	Verily, verily, I say unto you, Except a corn of wheat fall into the ground and die, it abideth alone: but if it die, it bringeth forth much fruit.
26606	1009	25	He that loveth his life shall lose it; and he that hateth his life in this world shall keep it unto life eternal.
26607	1009	26	If any man serve me, let him follow me; and where I am, there shall also my servant be: if any man serve me, him will my Father honour.
26608	1009	27	Now is my soul troubled; and what shall I say? Father, save me from this hour: but for this cause came I unto this hour.
26609	1009	28	Father, glorify thy name. Then came there a voice from heaven, saying, I have both glorified it, and will glorify it again.
26610	1009	29	The people therefore, that stood by, and heard it, said that it thundered: others said, An angel spake to him.
26611	1009	30	Jesus answered and said, This voice came not because of me, but for your sakes.
26612	1009	31	Now is the judgment of this world: now shall the prince of this world be cast out.
26613	1009	32	And I, if I be lifted up from the earth, will draw all men unto me.
26614	1009	33	This he said, signifying what death he should die.
26615	1009	34	The people answered him, We have heard out of the law that Christ abideth for ever: and how sayest thou, The Son of man must be lifted up? who is this Son of man?
26616	1009	35	Then Jesus said unto them, Yet a little while is the light with you. Walk while ye have the light, lest darkness come upon you: for he that walketh in darkness knoweth not whither he goeth.
26617	1009	36	While ye have light, believe in the light, that ye may be the children of light. These things spake Jesus, and departed, and did hide himself from them.
26618	1009	37	But though he had done so many miracles before them, yet they believed not on him:
26619	1009	38	That the saying of Esaias the prophet might be fulfilled, which he spake, Lord, who hath believed our report? and to whom hath the arm of the Lord been revealed?
26620	1009	39	Therefore they could not believe, because that Esaias said again,
26621	1009	40	He hath blinded their eyes, and hardened their heart; that they should not see with their eyes, nor understand with their heart, and be converted, and I should heal them.
26622	1009	41	These things said Esaias, when he saw his glory, and spake of him.
26623	1009	42	Nevertheless among the chief rulers also many believed on him; but because of the Pharisees they did not confess him, lest they should be put out of the synagogue:
26624	1009	43	For they loved the praise of men more than the praise of God.
26625	1009	44	Jesus cried and said, He that believeth on me, believeth not on me, but on him that sent me.
26626	1009	45	And he that seeth me seeth him that sent me.
26627	1009	46	I am come a light into the world, that whosoever believeth on me should not abide in darkness.
26628	1009	47	And if any man hear my words, and believe not, I judge him not: for I came not to judge the world, but to save the world.
26629	1009	48	He that rejecteth me, and receiveth not my words, hath one that judgeth him: the word that I have spoken, the same shall judge him in the last day.
26630	1009	49	For I have not spoken of myself; but the Father which sent me, he gave me a commandment, what I should say, and what I should speak.
26631	1009	50	And I know that his commandment is life everlasting: whatsoever I speak therefore, even as the Father said unto me, so I speak.
26632	1010	1	NOW before the feast of the passover, when Jesus knew that his hour was come that he should depart out of this world unto the Father, having loved his own which were in the world, he loved them unto the end.
26633	1010	2	And supper being ended, the devil having now put into the heart of Judas Iscariot, Simon's son, to betray him;
26634	1010	3	Jesus knowing that the Father had given all things into his hands, and that he was come from God, and went to God;
26635	1010	4	He riseth from supper, and laid aside his garments; and took a towel, and girded himself.
26636	1010	5	After that he poureth water into a bason, and began to wash the disciples' feet, and to wipe them with the towel wherewith he was girded.
26637	1010	6	Then cometh he to Simon Peter: and Peter saith unto him, Lord, dost thou wash my feet?
26638	1010	7	Jesus answered and said unto him, What I do thou knowest not now; but thou shalt know hereafter.
26639	1010	8	Peter saith unto him, Thou shalt never wash my feet. Jesus answered him, If I wash thee not, thou hast no part with me.
26640	1010	9	Simon Peter saith unto him, Lord, not my feet only, but also my hands and my head.
26641	1010	10	Jesus saith to him, He that is washed needeth not save to wash his feet, but is clean every whit: and ye are clean, but not all.
26642	1010	11	For he knew who should betray him; therefore said he, Ye are not all clean.
26643	1010	12	So after he had washed their feet, and had taken his garments, and was set down again, he said unto them, Know ye what I have done to you?
26644	1010	13	Ye call me Master and Lord: and ye say well; for so I am.
26645	1010	14	If I then, your Lord and Master, have washed your feet; ye also ought to wash one another's feet.
26646	1010	15	For I have given you an example, that ye should do as I have done to you.
26647	1010	16	Verily, verily, I say unto you, The servant is not greater than his lord; neither he that is sent greater than he that sent him.
26648	1010	17	If ye know these things, happy are ye if ye do them.
26649	1010	18	I speak not of you all: I know whom I have chosen: but that the scripture may be fulfilled, He that eateth bread with me hath lifted up his heel against me.
26650	1010	19	Now I tell you before it come, that, when it is come to pass, ye may believe that I am he.
26651	1010	20	Verily, verily, I say unto you, He that receiveth whomsoever I send receiveth me; and he that receiveth me receiveth him that sent me.
26652	1010	21	When Jesus had thus said, he was troubled in spirit, and testified, and said, Verily, verily, I say unto you, that one of you shall betray me.
26653	1010	22	Then the disciples looked one on another, doubting of whom he spake.
26654	1010	23	Now there was leaning on Jesus' bosom one of his disciples, whom Jesus loved.
26655	1010	24	Simon Peter therefore beckoned to him, that he should ask who it should be of whom he spake.
26656	1010	25	He then lying on Jesus' breast saith unto him, Lord, who is it?
26657	1010	26	Jesus answered, He it is, to whom I shall give a sop, when I have dipped it. And when he had dipped the sop, he gave it to Judas Iscariot, the son of Simon.
26658	1010	27	And after the sop Satan entered into him. Then said Jesus unto him, That thou doest, do quickly.
26659	1010	28	Now no man at the table knew for what intent he spake this unto him.
26660	1010	29	For some of them thought, because Judas had the bag, that Jesus had said unto him, Buy those things that we have need of against the feast; or, that he should give something to the poor.
26661	1010	30	He then having received the sop went immediately out: and it was night.
26662	1010	31	Therefore, when he was gone out, Jesus said, Now is the Son of man glorified, and God is glorified in him.
26663	1010	32	If God be glorified in him, God shall also glorify him in himself, and shall straightway glorify him.
26664	1010	33	Little children, yet a little while I am with you. Ye shall seek me: and as I said unto the Jews, Whither I go, ye cannot come; so now I say to you.
26665	1010	34	A new commandment I give unto you, That ye love one another; as I have loved you, that ye also love one another.
26666	1010	35	By this shall all men know that ye are my disciples, if ye have love one to another.
26667	1010	36	Simon Peter said unto him, Lord, whither goest thou? Jesus answered him, Whither I go, thou canst not follow me now; but thou shalt follow me afterwards.
26668	1010	37	Peter said unto him, Lord, why cannot I follow thee now? I will lay down my life for thy sake.
26669	1010	38	Jesus answered him, Wilt thou lay down thy life for my sake? Verily, verily, I say unto thee, The cock shall not crow, till thou hast denied me thrice.
26670	1011	1	LET not your heart be troubled: ye believe in God, believe also in me.
26671	1011	2	In my Father's house are many mansions: if it were not so, I would have told you. I go to prepare a place for you.
26672	1011	3	And if I go and prepare a place for you, I will come again, and receive you unto myself; that where I am, there ye may be also.
26673	1011	4	And whither I go ye know, and the way ye know.
26674	1011	5	Thomas saith unto him, Lord, we know not whither thou goest; and how can we know the way?
26675	1011	6	Jesus saith unto him, I am the way, the truth, and the life: no man cometh unto the Father, but by me.
26676	1011	7	If ye had known me, ye should have known my Father also: and from henceforth ye know him, and have seen him.
26677	1011	8	Philip saith unto him, Lord, shew us the Father, and it sufficeth us.
26678	1011	9	Jesus saith unto him, Have I been so long time with you, and yet hast thou not known me, Philip? he that hath seen me hath seen the Father; and how sayest thou then, Shew us the Father?
26679	1011	10	Believest thou not that I am in the Father, and the Father in me? the words that I speak unto you I speak not of myself: but the Father that dwelleth in me, he doeth the works.
26680	1011	11	Believe me that I am in the Father, and the Father in me: or else believe me for the very works' sake.
26681	1011	12	Verily, verily, I say unto you, He that believeth on me, the works that I do shall he do also; and greater works than these shall he do; because I go unto my Father.
26682	1011	13	And whatsoever ye shall ask in my name, that will I do, that the Father may be glorified in the Son.
26683	1011	14	If ye shall ask any thing in my name, I will do it.
26684	1011	15	If ye love me, keep my commandments.
26685	1011	16	And I will pray the Father, and he shall give you another Comforter, that he may abide with you for ever;
26686	1011	17	Even the Spirit of truth; whom the world cannot receive, because it seeth him not, neither knoweth him: but ye know him; for he dwelleth with you, and shall be in you.
26687	1011	18	I will not leave you comfortless: I will come to you.
26688	1011	19	Yet a little while, and the world seeth me no more; but ye see me: because I live, ye shall live also.
26689	1011	20	At that day ye shall know that I am in my Father, and ye in me, and I in you.
26690	1011	21	He that hath my commandments, and keepeth them, he it is that loveth me: and he that loveth me shall be loved of my Father, and I will love him, and will manifest myself to him.
26691	1011	22	Judas saith unto him, not Iscariot, Lord, how is it that thou wilt manifest thyself unto us, and not unto the world?
26692	1011	23	Jesus answered and said unto him, If a man love me, he will keep my words: and my Father will love him, and we will come unto him, and make our abode with him.
26693	1011	24	He that loveth me not keepeth not my sayings: and the word which ye hear is not mine, but the Father's which sent me.
26694	1011	25	These things have I spoken unto you, being yet present with you.
26695	1011	26	But the Comforter, which is the Holy Ghost, whom the Father will send in my name, he shall teach you all things, and bring all things to your remembrance, whatsoever I have said unto you.
26696	1011	27	Peace I leave with you, my peace I give unto you: not as the world giveth, give I unto you. Let not your heart be troubled, neither let it be afraid.
26697	1011	28	Ye have heard how I said unto you, I go away, and come again unto you. If ye loved me, ye would rejoice, because I said, I go unto the Father: for my Father is greater than I.
26698	1011	29	And now I have told you before it come to pass, that, when it is come to pass, ye might believe.
26699	1011	30	Hereafter I will not talk much with you: for the prince of this world cometh, and hath nothing in me.
26700	1011	31	But that the world may know that I love the Father; and as the Father gave me commandment, even so I do. Arise, let us go hence.
26701	1012	1	I AM the true vine, and my Father is the husbandman.
26702	1012	2	Every branch in me that beareth not fruit he taketh away: and every branch that beareth fruit, he purgeth it, that it may bring forth more fruit.
26703	1012	3	Now ye are clean through the word which I have spoken unto you.
26704	1012	4	Abide in me, and I in you. As the branch cannot bear fruit of itself, except it abide in the vine; no more can ye, except ye abide in me.
26705	1012	5	I am the vine, ye are the branches: He that abideth in me, and I in him, the same bringeth forth much fruit: for without me ye can do nothing.
26706	1012	6	If a man abide not in me, he is cast forth as a branch, and is withered; and men gather them, and cast them into the fire, and they are burned.
26707	1012	7	If ye abide in me, and my words abide in you, ye shall ask what ye will, and it shall be done unto you.
26708	1012	8	Herein is my Father glorified, that ye bear much fruit; so shall ye be my disciples.
26709	1012	9	As the Father hath loved me, so have I loved you: continue ye in my love.
26710	1012	10	If ye keep my commandments, ye shall abide in my love; even as I have kept my Father's commandments, and abide in his love.
26711	1012	11	These things have I spoken unto you, that my joy might remain in you, and that your joy might be full.
26712	1012	12	This is my commandment, That ye love one another, as I have loved you.
26713	1012	13	Greater love hath no man than this, that a man lay down his life for his friends.
26714	1012	14	Ye are my friends, if ye do whatsoever I command you.
26715	1012	15	Henceforth I call you not servants; for the servant knoweth not what his lord doeth: but I have called you friends; for all things that I have heard of my Father I have made known unto you.
26716	1012	16	Ye have not chosen me, but I have chosen you, and ordained you, that ye should go and bring forth fruit, and that your fruit should remain: that whatsoever ye shall ask of the Father in my name, he may give it you.
26717	1012	17	These things I command you, that ye love one another.
26718	1012	18	If the world hate you, ye know that it hated me before it hated you.
26719	1012	19	If ye were of the world, the world would love his own: but because ye are not of the world, but I have chosen you out of the world, therefore the world hateth you.
26720	1012	20	Remember the word that I said unto you, The servant is not greater than his lord. If they have persecuted me, they will also persecute you; if they have kept my saying, they will keep yours also.
26721	1012	21	But all these things will they do unto you for my name's sake, because they know not him that sent me.
26722	1012	22	If I had not come and spoken unto them, they had not had sin: but now they have no cloke for their sin.
26723	1012	23	He that hateth me hateth my Father also.
26724	1012	24	If I had not done among them the works which none other man did, they had not had sin: but now have they both seen and hated both me and my Father.
26725	1012	25	But this cometh to pass, that the word might be fulfilled that is written in their law, They hated me without a cause.
26726	1012	26	But when the Comforter is come, whom I will send unto you from the Father, even the Spirit of truth, which proceedeth from the Father, he shall testify of me:
26727	1012	27	And ye also shall bear witness, because ye have been with me from the beginning.
26728	1013	1	THESE things have I spoken unto you, that ye should not be offended.
26729	1013	2	They shall put you out of the synagogues: yea, the time cometh, that whosoever killeth you will think that he doeth God service.
26730	1013	3	And these things will they do unto you, because they have not known the Father, nor me.
26731	1013	4	But these things have I told you, that when the time shall come, ye may remember that I told you of them. And these things I said not unto you at the beginning, because I was with you.
26732	1013	5	But now I go my way to him that sent me; and none of you asketh me, Whither goest thou?
26733	1013	6	But because I have said these things unto you, sorrow hath filled your heart.
26734	1013	7	Nevertheless I tell you the truth; It is expedient for you that I go away: for if I go not away, the Comforter will not come unto you; but if I depart, I will send him unto you.
26735	1013	8	And when he is come, he will reprove the world of sin, and of righteousness, and of judgment:
26736	1013	9	Of sin, because they believe not on me;
26737	1013	10	Of righteousness, because I go to my Father, and ye see me no more;
26738	1013	11	Of judgment, because the prince of this world is judged.
26739	1013	12	I have yet many things to say unto you, but ye cannot bear them now.
26740	1013	13	Howbeit when he, the Spirit of truth, is come, he will guide you into all truth: for he shall not speak of himself; but whatsoever he shall hear, that shall he speak: and he will shew you things to come.
26741	1013	14	He shall glorify me: for he shall receive of mine, and shall shew it unto you.
26742	1013	15	All things that the Father hath are mine: therefore said I, that he shall take of mine, and shall shew it unto you.
26743	1013	16	A little while, and ye shall not see me: and again, a little while, and ye shall see me, because I go to the Father.
26744	1013	17	Then said some of his disciples among themselves, What is this that he saith unto us, A little while, and ye shall not see me: and again, a little while, and ye shall see me: and, Because I go to the Father?
26745	1013	18	They said therefore, What is this that he saith, A little while? we cannot tell what he saith.
26746	1013	19	Now Jesus knew that they were desirous to ask him, and said unto them, Do ye enquire among yourselves of that I said, A little while, and ye shall not see me: and again, a little while, and ye shall see me?
26747	1013	20	Verily, verily, I say unto you, That ye shall weep and lament, but the world shall rejoice: and ye shall be sorrowful, but your sorrow shall be turned into joy.
26748	1013	21	A woman when she is in travail hath sorrow, because her hour is come: but as soon as she is delivered of the child, she remembereth no more the anguish, for joy that a man is born into the world.
26749	1013	22	And ye now therefore have sorrow: but I will see you again, and your heart shall rejoice, and your joy no man taketh from you.
26750	1013	23	And in that day ye shall ask me nothing. Verily, verily, I say unto you, Whatsoever ye shall ask the Father in my name, he will give it you.
26751	1013	24	Hitherto have ye asked nothing in my name: ask, and ye shall receive, that your joy may be full.
26752	1013	25	These things have I spoken unto you in proverbs: but the time cometh, when I shall no more speak unto you in proverbs, but I shall shew you plainly of the Father.
26753	1013	26	At that day ye shall ask in my name: and I say not unto you, that I will pray the Father for you:
26754	1013	27	For the Father himself loveth you, because ye have loved me, and have believed that I came out from God.
26755	1013	28	I came forth from the Father, and am come into the world: again, I leave the world, and go to the Father.
26756	1013	29	His disciples said unto him, Lo, now speakest thou plainly, and speakest no proverb.
26757	1013	30	Now are we sure that thou knowest all things, and needest not that any man should ask thee: by this we believe that thou camest forth from God.
26758	1013	31	Jesus answered them, Do ye now believe?
26759	1013	32	Behold, the hour cometh, yea, is now come, that ye shall be scattered, every man to his own, and shall leave me alone: and yet I am not alone, because the Father is with me.
26760	1013	33	These things I have spoken unto you, that in me ye might have peace. In the world ye shall have tribulation: but be of good cheer; I have overcome the world.
26761	1014	1	THESE words spake Jesus, and lifted up his eyes to heaven, and said, Father, the hour is come; glorify thy Son, that thy Son also may glorify thee:
26762	1014	2	As thou hast given him power over all flesh, that he should give eternal life to as many as thou hast given him.
26763	1014	3	And this is life eternal, that they might know thee the only true God, and Jesus Christ, whom thou hast sent.
26764	1014	4	I have glorified thee on the earth: I have finished the work which thou gavest me to do.
26765	1014	5	And now, O Father, glorify thou me with thine own self with the glory which I had with thee before the world was.
26766	1014	6	I have manifested thy name unto the men which thou gavest me out of the world: thine they were, and thou gavest them me; and they have kept thy word.
26767	1014	7	Now they have known that all things whatsoever thou hast given me are of thee.
26768	1014	8	For I have given unto them the words which thou gavest me; and they have received them, and have known surely that I came out from thee, and they have believed that thou didst send me.
26769	1014	9	I pray for them: I pray not for the world, but for them which thou hast given me; for they are thine.
26770	1014	10	And all mine are thine, and thine are mine; and I am glorified in them.
26771	1014	11	And now I am no more in the world, but these are in the world, and I come to thee. Holy Father, keep through thine own name those whom thou hast given me, that they may be one, as we are.
26772	1014	12	While I was with them in the world, I kept them in thy name: those that thou gavest me I have kept, and none of them is lost, but the son of perdition; that the scripture might be fulfilled.
26773	1014	13	And now come I to thee; and these things I speak in the world, that they might have my joy fulfilled in themselves.
26774	1014	14	I have given them thy word; and the world hath hated them, because they are not of the world, even as I am not of the world.
26775	1014	15	I pray not that thou shouldest take them out of the world, but that thou shouldest keep them from the evil.
26776	1014	16	They are not of the world, even as I am not of the world.
26777	1014	17	Sanctify them through thy truth: thy word is truth.
26778	1014	18	As thou hast sent me into the world, even so have I also sent them into the world.
26779	1014	19	And for their sakes I sanctify myself, that they also might be sanctified through the truth.
26780	1014	20	Neither pray I for these alone, but for them also which shall believe on me through their word;
26781	1014	21	That they all may be one; as thou, Father, art in me, and I in thee, that they also may be one in us: that the world may believe that thou hast sent me.
26782	1014	22	And the glory which thou gavest me I have given them; that they may be one, even as we are one:
26783	1014	23	I in them, and thou in me, that they may be made perfect in one; and that the world may know that thou hast sent me, and hast loved them, as thou hast loved me.
26784	1014	24	Father, I will that they also, whom thou hast given me, be with me where I am; that they may behold my glory, which thou hast given me: for thou lovedst me before the foundation of the world.
26785	1014	25	O righteous Father, the world hath not known thee: but I have known thee, and these have known that thou hast sent me.
26786	1014	26	And I have declared unto them thy name, and will declare it: that the love wherewith thou hast loved me may be in them, and I in them.
26787	1015	1	WHEN Jesus had spoken these words, he went forth with his disciples over the brook Cedron, where was a garden, into the which he entered, and his disciples.
26788	1015	2	And Judas also, which betrayed him, knew the place: for Jesus ofttimes resorted thither with his disciples.
26789	1015	3	Judas then, having received a band of men and officers from the chief priests and Pharisees, cometh thither with lanterns and torches and weapons.
26790	1015	4	Jesus therefore, knowing all things that should come upon him, went forth, and said unto them, Whom seek ye?
26791	1015	5	They answered him, Jesus of Nazareth. Jesus saith unto them, I am he. And Judas also, which betrayed him, stood with them.
26792	1015	6	As soon then as he had said unto them, I am he, they went backward, and fell to the ground.
26793	1015	7	Then asked he them again, Whom seek ye? And they said, Jesus of Nazareth.
26794	1015	8	Jesus answered, I have told you that I am he: if therefore ye seek me, let these go their way:
26795	1015	9	That the saying might be fulfilled, which he spake, Of them which thou gavest me have I lost none.
26796	1015	10	Then Simon Peter having a sword drew it, and smote the high priest's servant, and cut off his right ear. The servant's name was Malchus.
26797	1015	11	Then said Jesus unto Peter, Put up thy sword into the sheath: the cup which my Father hath given me, shall I not drink it?
26798	1015	12	Then the band and the captain and officers of the Jews took Jesus, and bound him,
26799	1015	13	And led him away to Annas first; for he was father in law to Caiaphas, which was the high priest that same year.
26800	1015	14	Now Caiaphas was he, which gave counsel to the Jews, that it was expedient that one man should die for the people.
26801	1015	15	And Simon Peter followed Jesus, and so did another disciple: that disciple was known unto the high priest, and went in with Jesus into the palace of the high priest.
26802	1015	16	But Peter stood at the door without. Then went out that other disciple, which was known unto the high priest, and spake unto her that kept the door, and brought in Peter.
26803	1015	17	Then saith the damsel that kept the door unto Peter, Art not thou also one of this man's disciples? He saith, I am not.
26804	1015	18	And the servants and officers stood there, who had made a fire of coals; for it was cold: and they warmed themselves: and Peter stood with them, and warmed himself.
26805	1015	19	The high priest then asked Jesus of his disciples, and of his doctrine.
26806	1015	20	Jesus answered him, I spake openly to the world; I ever taught in the synagogue, and in the temple, whither the Jews always resort; and in secret have I said nothing.
26807	1015	21	Why askest thou me? ask them which heard me, what I have said unto them: behold, they know what I said.
26808	1015	22	And when he had thus spoken, one of the officers which stood by struck Jesus with the palm of his hand, saying, Answerest thou the high priest so?
26809	1015	23	Jesus answered him, If I have spoken evil, bear witness of the evil: but if well, why smitest thou me?
26810	1015	24	Now Annas had sent him bound unto Caiaphas the high priest.
26811	1015	25	And Simon Peter stood and warmed himself. They said therefore unto him, Art not thou also one of his disciples? He denied it, and said, I am not.
26812	1015	26	One of the servants of the high priest, being his kinsman whose ear Peter cut off, saith, Did not I see thee in the garden with him?
26813	1015	27	Peter then denied again: and immediately the cock crew.
26814	1015	28	Then led they Jesus from Caiaphas unto the hall of judgment: and it was early; and they themselves went not into the judgment hall, lest they should be defiled; but that they might eat the passover.
26815	1015	29	Pilate then went out unto them, and said, What accusation bring ye against this man?
26816	1015	30	They answered and said unto him, If he were not a malefactor, we would not have delivered him up unto thee.
26817	1015	31	Then said Pilate unto them, Take ye him, and judge him according to your law. The Jews therefore said unto him, It is not lawful for us to put any man to death:
26818	1015	32	That the saying of Jesus might be fulfilled, which he spake, signifying what death he should die.
26819	1015	33	Then Pilate entered into the judgment hall again, and called Jesus, and said unto him, Art thou the King of the Jews?
26820	1015	34	Jesus answered him, Sayest thou this thing of thyself, or did others tell it thee of me?
26821	1015	35	Pilate answered, Am I a Jew? Thine own nation and the chief priests have delivered thee unto me: what hast thou done?
26822	1015	36	Jesus answered, My kingdom is not of this world: if my kingdom were of this world, then would my servants fight, that I should not be delivered to the Jews: but now is my kingdom not from hence.
26823	1015	37	Pilate therefore said unto him, Art thou a king then? Jesus answered, Thou sayest that I am a king. To this end was I born, and for this cause came I into the world, that I should bear witness unto the truth. Every one that is of the truth heareth my voice.
26824	1015	38	Pilate saith unto him, What is truth? And when he had said this, he went out again unto the Jews, and saith unto them, I find in him no fault at all.
26825	1015	39	But ye have a custom, that I should release unto you one at the passover: will ye therefore that I release unto you the King of the Jews?
26826	1015	40	Then cried they all again, saying, Not this man, but Barabbas. Now Barabbas was a robber.
26827	1016	1	THEN Pilate therefore took Jesus, and scourged him.
26828	1016	2	And the soldiers platted a crown of thorns, and put it on his head, and they put on him a purple robe,
26829	1016	3	And said, Hail, King of the Jews! and they smote him with their hands.
26830	1016	4	Pilate therefore went forth again, and saith unto them, Behold, I bring him forth to you, that ye may know that I find no fault in him.
26831	1016	5	Then came Jesus forth, wearing the crown of thorns, and the purple robe. And Pilate saith unto them, Behold the man!
26832	1016	6	When the chief priests therefore and officers saw him, they cried out, saying, Crucify him, crucify him. Pilate saith unto them, Take ye him, and crucify him: for I find no fault in him.
26833	1016	7	The Jews answered him, We have a law, and by our law he ought to die, because he made himself the Son of God.
26834	1016	8	When Pilate therefore heard that saying, he was the more afraid;
26835	1016	9	And went again into the judgment hall, and saith unto Jesus, Whence art thou? But Jesus gave him no answer.
26836	1016	10	Then saith Pilate unto him, Speakest thou not unto me? knowest thou not that I have power to crucify thee, and have power to release thee?
26837	1016	11	Jesus answered, Thou couldest have no power at all against me, except it were given thee from above: therefore he that delivered me unto thee hath the greater sin.
26838	1016	12	And from thenceforth Pilate sought to release him: but the Jews cried out, saying, If thou let this man go, thou art not Caesar's friend: whosoever maketh himself a king speaketh against Caesar.
26839	1016	13	When Pilate therefore heard that saying, he brought Jesus forth, and sat down in the judgment seat in a place that is called the Pavement, but in the Hebrew, Gabbatha.
26840	1016	14	And it was the preparation of the passover, and about the sixth hour: and he saith unto the Jews, Behold your King!
26841	1016	15	But they cried out, Away with him, away with him, crucify him. Pilate saith unto them, Shall I crucify your King? The chief priest answered, We have no king but Caesar.
26842	1016	16	Then delivered he him therefore unto them to be crucified. And they took Jesus, and led him away.
26843	1016	17	And he bearing his cross went forth into a place called the place of a skull, which is called in the Hebrew Golgotha:
26844	1016	18	Where they crucified him, and two other with him, on either side one, and Jesus in the midst.
26845	1016	19	And Pilate wrote a title, and put it on the cross. And the writing was, JESUS OF NAZARETH THE KING OF THE JEWS.
26846	1016	20	This title then read many of the Jews: for the place where Jesus was crucified was nigh to the city: and it was written in Hebrew, and Greek, and Latin.
26847	1016	21	Then said the chief priests of the Jews to Pilate, Write not, The King of the Jews; but that he said, I am King of the Jews.
26848	1016	22	Pilate answered, What I have written I have written.
26849	1016	23	Then the soldiers, when they had crucified Jesus, took his garments, and made four parts, to every soldier a part; and also his coat: now the coat was without seam, woven from the top throughout.
26850	1016	24	They said therefore among themselves, Let us not rend it, but cast lots for it, whose it shall be: that the scripture might be fulfilled, which saith, They parted my raiment among them, and for my vesture they did cast lots. These things therefore the soldiers did.
26851	1016	25	Now there stood by the cross of Jesus his mother, and his mother's sister, Mary the wife of Cleophas, and Mary Magdalene.
26852	1016	26	When Jesus therefore saw his mother, and the disciple standing by, whom he loved, he saith unto his mother, Woman, behold thy son!
26853	1016	27	Then saith he to the disciple, Behold thy mother! And from that hour that disciple took her unto his own home.
26854	1016	28	After this, Jesus knowing that all things were now accomplished, that the scripture might be fulfilled, saith, I thirst.
26855	1016	29	Now there was set a vessel full of vinegar: and they filled a spunge with vinegar, and put it upon hyssop, and put it to his mouth.
26856	1016	30	When Jesus therefore had received the vinegar, he said, It is finished: and he bowed his head, and gave up the ghost.
26857	1016	31	The Jews therefore, because it was the preparation, that the bodies should not remain upon the cross on the sabbath day, (for that sabbath day was an high day,) besought Pilate that their legs might be broken, and that they might be taken away.
26858	1016	32	Then came the soldiers, and brake the legs of the first, and of the other which was crucified with him.
26859	1016	33	But when they came to Jesus, and saw that he was dead already, they brake not his legs:
26860	1016	34	But one of the soldiers with a spear pierced his side, and forthwith came there out blood and water.
26861	1016	35	And he that saw it bare record, and his record is true: and he knoweth that he saith true, that ye might believe.
26862	1016	36	For these things were done, that the scripture should be fulfilled, A bone of him shall not be broken.
26863	1016	37	And again another scripture saith, They shall look on him whom they pierced.
26864	1016	38	And after this Joseph of Arimathaea, being a disciple of Jesus, but secretly for fear of the Jews, besought Pilate that he might take away the body of Jesus: and Pilate gave him leave. He came therefore, and took the body of Jesus.
26865	1016	39	And there came also Nicodemus, which at the first came to Jesus by night, and brought a mixture of myrrh and aloes, about an hundred pound weight.
26866	1016	40	Then took they the body of Jesus, and wound it in linen clothes with the spices, as the manner of the Jews is to bury.
26867	1016	41	Now in the place where he was crucified there was a garden; and in the garden a new sepulchre, wherein was never man yet laid.
26868	1016	42	There laid they Jesus therefore because of the Jews' preparation day; for the sepulchre was nigh at hand.
26869	1017	1	THE first day of the week cometh Mary Magdalene early, when it was yet dark, unto the sepulchre, and seeth the stone taken away from the sepulchre.
26870	1017	2	Then she runneth, and cometh to Simon Peter, and to the other disciple, whom Jesus loved, and saith unto them, They have taken away the Lord out of the sepulchre, and we know not where they have laid him.
26871	1017	3	Peter therefore went forth, and that other disciple, and came to the sepulchre.
26872	1017	4	So they ran both together: and the other disciple did outrun Peter, and came first to the sepulchre.
26873	1017	5	And he stooping down, and looking in, saw the linen clothes lying; yet went he not in.
26874	1017	6	Then cometh Simon Peter following him, and went into the sepulchre, and seeth the linen clothes lie,
26875	1017	7	And the napkin, that was about his head, not lying with the linen clothes, but wrapped together in a place by itself.
26876	1017	8	Then went in also that other disciple, which came first to the sepulchre, and he saw, and believed.
26877	1017	9	For as yet they knew not the scripture, that he must rise again from the dead.
26878	1017	10	Then the disciples went away again unto their own home.
26879	1017	11	But Mary stood without at the sepulchre weeping: and as she wept, she stooped down, and looked into the sepulchre,
26880	1017	12	And seeth two angels in white sitting, the one at the head, and the other at the feet, where the body of Jesus had lain.
26881	1017	13	And they say unto her, Woman, why weepest thou? She saith unto them, Because they have taken away my Lord, and I know not where they have laid him.
26882	1017	14	And when she had thus said, she turned herself back, and saw Jesus standing, and knew not that it was Jesus.
26883	1017	15	Jesus saith unto her, Woman, why weepest thou? whom seekest thou? She, supposing him to be the gardener, saith unto him, Sir, if thou have borne him hence, tell me where thou hast laid him, and I will take him away.
26884	1017	16	Jesus saith unto her, Mary. She turned herself, and saith unto him, Rabboni; which is to say, Master.
26885	1017	17	Jesus saith unto her, Touch me not; for I am not yet ascended to my Father: but go to my brethren, and say unto them, I ascend unto my Father, and your Father; and to my God, and your God.
26886	1017	18	Mary Magdalene came and told the disciples that she had seen the Lord, and that he had spoken these things unto her.
26887	1017	19	Then the same day at evening, being the first day of the week, when the doors were shut where the disciples were assembled for fear of the Jews, came Jesus and stood in the midst, and saith unto them, Peace be unto you.
26888	1017	20	And when he had so said, he shewed unto them his hands and his side. Then were the disciples glad, when they saw the Lord.
26889	1017	21	Then said Jesus to them again, Peace be unto you: as my Father hath sent me, even so send I you.
26890	1017	22	And when he had said this, he breathed on them, and saith unto them, Receive ye the Holy Ghost:
26891	1017	23	Whose soever sins ye remit, they are remitted unto them; and whose soever sins ye retain, they are retained.
26892	1017	24	But Thomas, one of the twelve, called Didymus, was not with them when Jesus came.
26893	1017	25	The other disciples therefore said unto him, We have seen the Lord. But he said unto them, Except I shall see in his hands the print of the nails, and put my finger into the print of the nails, and thrust my hand into his side, I will not believe.
26894	1017	26	And after eight days again his disciples were within, and Thomas with them: then came Jesus, the doors being shut, and stood in the midst, and said, Peace be unto you.
26895	1017	27	Then saith he to Thomas, Reach hither thy finger, and behold my hands; and reach hither thy hand, and thrust it into my side: and be not faithless, but believing.
26896	1017	28	And Thomas answered and said unto him, My Lord and my God.
26897	1017	29	Jesus saith unto him, Thomas, because thou hast seen me, thou hast believed: blessed are they that have not seen, and yet have believed.
26898	1017	30	And many other signs truly did Jesus in the presence of his disciples, which are not written in this book:
26899	1017	31	But these are written, that ye might believe that Jesus is the Christ, the Son of God; and that believing ye might have life through his name.
26900	1018	1	AFTER these things Jesus shewed himself again to the disciples at the sea of Tiberias; and on this wise shewed he himself.
26901	1018	2	There were together Simon Peter, and Thomas called Didymus, and Nathanael of Cana in Galilee, and the sons of Zebedee, and two other of his disciples.
26902	1018	3	Simon Peter saith unto them, I go a fishing. They say unto him, We also go with thee. They went forth, and entered into a ship immediately; and that night they caught nothing.
26903	1018	4	But when the morning was now come, Jesus stood on the shore: but the disciples knew not that it was Jesus.
26904	1018	5	Then Jesus saith unto them, Children, have ye any meat? They answered him, No.
26905	1018	6	And he said unto them, Cast the net on the right side of the ship, and ye shall find. They cast therefore, and now they were not able to draw it for the multitude of fishes.
26906	1018	7	Therefore that disciple whom Jesus loved saith unto Peter, It is the Lord. Now when Simon Peter heard that it was the Lord, he girt his fisher's coat unto him, (for he was naked,) and did cast himself into the sea.
26907	1018	8	And the other disciples came in a little ship; (for they were not far from land, but as it were two hundred cubits,) dragging the net with fishes.
26908	1018	9	As soon then as they were come to land, they saw a fire of coals there, and fish laid thereon, and bread.
26909	1018	10	Jesus saith unto them, Bring of the fish which ye have now caught.
26910	1018	11	Simon Peter went up, and drew the net to land full of great fishes, and hundred and fifty and three: and for all there were so many, yet was not the net broken.
26911	1018	12	Jesus saith unto them, Come and dine. And none of the disciples durst ask him, Who art thou? knowing that it was the Lord.
26912	1018	13	Jesus then cometh, and taketh bread, and giveth them, and fish likewise.
26913	1018	14	This is now the third time that Jesus shewed himself to his disciples, after that he was risen from the dead.
26914	1018	15	So when they had dined, Jesus saith to Simon Peter, Simon, son of Jonas, lovest thou me more than these? He saith unto him, Yea, Lord; thou knowest that I love thee. He saith unto him, Feed my lambs.
26915	1018	16	He saith to him again the second time, Simon, son of Jonas, lovest thou me? He saith unto him, Yea, Lord; thou knowest that I love thee. He saith unto him, Feed my sheep.
26916	1018	17	He saith unto him the third time, Simon, son of Jonas, lovest thou me? Peter was grieved because he said unto him the third time, Lovest thou me? And he said unto him, Lord, thou knowest all things; thou knowest that I love thee. Jesus saith unto him, Feed my sheep.
26917	1018	18	Verily, verily, I say unto thee, When thou wast young, thou girdedst thyself, and walkedst whither thou wouldest: but when thou shalt be old, thou shalt stretch forth thy hands, and another shall gird thee, and carry thee whither thou wouldest not.
26918	1018	19	This spake he, signifying by what death he should glorify God. And when he had spoken this, he saith unto him, Follow me.
26919	1018	20	Then Peter, turning about, seeth the disciple whom Jesus loved following; which also leaned on his breast at supper, and said, Lord, which is he that betrayeth thee?
26920	1018	21	Peter seeing him saith to Jesus, Lord, and what shall this man do?
26921	1018	22	Jesus saith unto him, If I will that he tarry till I come, what is that to thee? follow thou me.
26922	1018	23	Then went this saying abroad among the brethren, that that disciple should not die: yet Jesus said not unto him, He shall not die; but, If I will that he tarry till I come, what is that to thee?
26923	1018	24	This is the disciple which testifieth of these things, and wrote these things: and we know that his testimony is true.
26924	1018	25	And there are also many other things which Jesus did, the which, if they should be written every one, I suppose that even the world itself could not contain the books that should be written. Amen.
26925	1019	1	THE former treatise have I made, O Theophilus, of all that Jesus began both to do and teach,
26926	1019	2	Until the day in which he was taken up, after that he through the Holy Ghost had given commandments unto the apostles whom he had chosen:
26927	1019	3	To whom also he shewed himself alive after his passion by many infallible proofs, being seen of them forty days, and speaking of the things pertaining to the kingdom of God:
26928	1019	4	And, being assembled together with them, commanded them that they should not depart from Jerusalem, but wait for the promise of the Father, which, saith he, ye have heard of me.
26929	1019	5	For John truly baptized with water; but ye shall be baptized with the Holy Ghost not many days hence.
26930	1019	6	When they therefore were come together, they asked of him, saying, Lord, wilt thou at this time restore again the kingdom to Israel?
26931	1019	7	And he said unto them, It is not for you to know the times or the seasons, which the Father hath put in his own power.
26932	1019	8	But ye shall receive power, after that the Holy Ghost is come upon you: and ye shall be witnesses unto me both in Jerusalem, and in all Judaea, and in Samaria, and unto the uttermost part of the earth.
26933	1019	9	And when he had spoken these things, while they beheld, he was taken up; and a cloud received him out of their sight.
26934	1019	10	And while they looked stedfastly toward heaven as he went up, behold, two men stood by them in white apparel;
26935	1019	11	Which also said, Ye men of Galilee, why stand ye gazing up into heaven? this same Jesus, which is taken up from you into heaven, shall so come in like manner as ye have seen him go into heaven.
26936	1019	12	Then returned they unto Jerusalem from the mount called Olivet, which is from Jerusalem a sabbath day's journey.
26937	1019	13	And when they were come in, they went up into an upper room, where abode both Peter, and James, and John, and Andrew, Philip, and Thomas, Bartholomew, and Matthew, James the son of Alphaeus, and Simon Zelotes, and Judas the brother of James.
26938	1019	14	These all continued with one accord in prayer and supplication, with the women, and Mary the mother of Jesus, and with his brethren.
26939	1019	15	And in those days Peter stood up in the midst of the disciples, and said, (the number of names together were about an hundred and twenty,)
26940	1019	16	Men and brethren, this scripture must needs have been fulfilled, which the Holy Ghost by the mouth of David spake before concerning Judas, which was guide to them that took Jesus.
26941	1019	17	For he was numbered with us, and had obtained part of this ministry.
26942	1019	18	Now this man purchased a field with the reward of iniquity; and falling headlong, he burst asunder in the midst, and all his bowels gushed out.
26943	1019	19	And it was known unto all the dwellers at Jerusalem; insomuch as that field is called in their proper tongue, Aceldama, that is to say, The field of blood.
26944	1019	20	For it is written in the book of Psalms, Let his habitation be desolate, and let no man dwell therein: and his bishoprick let another take.
26945	1019	21	Wherefore of these men which have companied with us all the time that the Lord Jesus went in and out among us,
26946	1019	22	Beginning from the baptism of John, unto that same day that he was taken up from us, must one be ordained to be a witness with us of his resurrection.
26947	1019	23	And they appointed two, Joseph called Barsabas, who was surnamed Justus, and Matthias.
26948	1019	24	And they prayed, and said, Thou, Lord, which knowest the hearts of all men, shew whether of these two thou hast chosen,
26949	1019	25	That he may take part of this ministry and apostleship, from which Judas by transgression fell, that he might go to his own place.
26950	1019	26	And they gave forth their lots; and the lot fell upon Matthias; and he was numbered with the eleven apostles.
26951	1020	1	AND when the day of Pentecost was fully come, they were all with one accord in one place.
26952	1020	2	And suddenly there came a sound from heaven as of a rushing mighty wind, and it filled all the house where they were sitting.
26953	1020	3	And there appeared unto them cloven tongues like as of fire, and it sat upon each of them.
26954	1020	4	And they were all filled with the Holy Ghost, and began to speak with other tongues, as the Spirit gave them utterance.
26955	1020	5	And there were dwelling at Jerusalem Jews, devout men, out of every nation under heaven.
26956	1020	6	Now when this was noised abroad, the multitude came together, and were confounded, because that every man heard them speak in his own language.
26957	1020	7	And they were all amazed and marvelled, saying one to another, Behold, are not all these which speak Galilaeans?
26958	1020	8	And how hear we every man in our own tongue, wherein we were born?
26959	1020	9	Parthians, and Medes, and Elamites, and the dwellers in Mesopotamia, and in Judaea, and Cappadocia, in Pontus, and Asia,
26960	1020	10	Phrygia, and Pamphylia, in Egypt, and in the parts of Libya about Cyrene, and strangers of Rome, Jews and proselytes,
26961	1020	11	Cretes and Arabians, we do hear them speak in our tongues the wonderful works of God.
26962	1020	12	And they were all amazed, and were in doubt, saying one to another, What meaneth this?
26963	1020	13	Others mocking said, These men are full of new wine.
26964	1020	14	But Peter, standing up with the eleven, lifted up his voice, and said unto them, Ye men of Judaea, and all ye that dwell at Jerusalem, be this known unto you, and hearken to my words:
26965	1020	15	For these are not drunken, as ye suppose, seeing it is but the third hour of the day.
26966	1020	16	But this is that which was spoken by the prophet Joel;
26967	1020	17	And it shall come to pass in the last days, saith God, I will pour out of my Spirit upon all flesh: and your sons and your daughters shall prophesy, and your young men shall see visions, and your old men shall dream dreams:
26968	1020	18	And on my servants and on my handmaidens I will pour out in those days of my Spirit; and they shall prophesy:
26969	1020	19	And I will shew wonders in heaven above, and signs in the earth beneath; blood, and fire, and vapour of smoke:
26970	1020	20	The sun shall be turned into darkness, and the moon into blood, before that great and notable day of the Lord come:
26971	1020	21	And it shall come to pass, that whosoever shall call on the name of the Lord shall be saved.
26972	1020	22	Ye men of Israel, hear these words; Jesus of Nazareth, a man approved of God among you by miracles and wonders and signs, which God did by him in the midst of you, as ye yourselves also know:
26973	1020	23	Him, being delivered by the determinate counsel and foreknowledge of God, ye have taken, and by wicked hands have crucified and slain:
26974	1020	24	Whom God hath raised up, having loosed the pains of death: because it was not possible that he should be holden of it.
26975	1020	25	For David speaketh concerning him, I foresaw the Lord always before my face, for he is on my right hand, that I should not be moved:
26976	1020	26	Therefore did my heart rejoice, and my tongue was glad; moreover also my flesh shall rest in hope:
26977	1020	27	Because thou wilt not leave my soul in hell, neither wilt thou suffer thine Holy One to see corruption.
26978	1020	28	Thou hast made known to me the ways of life; thou shalt make me full of joy with thy countenance.
26979	1020	29	Men and brethren, let me freely speak unto you of the patriarch David, that he is both dead and buried, and his sepulchre is with us unto this day.
26980	1020	30	Therefore being a prophet, and knowing that God had sworn with an oath to him, that of the fruit of his loins, according to the flesh, he would raise up Christ to sit on his throne;
26981	1020	31	He seeing this before spake of the resurrection of Christ, that his soul was not left in hell, neither his flesh did see corruption.
26982	1020	32	This Jesus hath God raised up, whereof we all are witnesses.
26983	1020	33	Therefore being by the right hand of God exalted, and having received of the Father the promise of the Holy Ghost, he hath shed forth this, which ye now see and hear.
26984	1020	34	For David is not ascended into the heavens: but he saith himself, The LORD said unto my Lord, Sit thou on my right hand,
26985	1020	35	Until I make thy foes thy footstool.
26986	1020	36	Therefore let all the house of Israel know assuredly, that God hath made that same Jesus, whom ye have crucified, both Lord and Christ.
26987	1020	37	Now when they heard this, they were pricked in their heart, and said unto Peter and to the rest of the apostles, Men and brethren, what shall we do?
26988	1020	38	Then Peter said unto them, Repent, and be baptized every one of you in the name of Jesus Christ for the remission of sins, and ye shall receive the gift of the Holy Ghost.
26989	1020	39	For the promise is unto you, and to your children, and to all that are afar off, even as many as the Lord our God shall call.
26990	1020	40	And with many other words did he testify and exhort, saying, Save yourselves from this untoward generation.
26991	1020	41	Then they that gladly received his word were baptized: and the same day there were added unto them about three thousand souls.
26992	1020	42	And they continued stedfastly in the apostles' doctrine and fellowship, and in breaking of bread, and in prayers.
26993	1020	43	And fear came upon every soul: and many wonders and signs were done by the apostles.
26994	1020	44	And all that believed were together, and had all things common;
26995	1020	45	And sold their possessions and goods, and parted them to all men, as every man had need.
26996	1020	46	And they, continuing daily with one accord in the temple, and breaking bread from house to house, did eat their meat with gladness and singleness of heart,
26997	1020	47	Praising God, and having favour with all the people. And the Lord added to the church daily such as should be saved.
26998	1021	1	NOW Peter and John went up together into the temple at the hour of prayer, being the ninth hour.
26999	1021	2	And a certain man lame from his mother's womb was carried, whom they laid daily at the gate of the temple which is called Beautiful, to ask alms of them that entered into the temple;
27000	1021	3	Who seeing Peter and John about to go into the temple asked an alms.
27001	1021	4	And Peter, fastening his eyes upon him with John, said, Look on us.
27002	1021	5	And he gave heed unto them, expecting to receive something of them.
27003	1021	6	Then Peter said, Silver and gold have I none; but such as I have give I thee: In the name of Jesus Christ of Nazareth rise up and walk.
27004	1021	7	And he took him by the right hand, and lifted him up: and immediately his feet and ankle bones received strength.
27005	1021	8	And he leaping up stood, and walked, and entered with them into the temple, walking, and leaping, and praising God.
27006	1021	9	And all the people saw him walking and praising God:
27007	1021	10	And they knew that it was he which sat for alms at the Beautiful gate of the temple: and they were filled with wonder and amazement at that which had happened unto him.
27008	1021	11	And as the lame man which was healed held Peter and John, all the people ran together unto them in the porch that is called Solomon's, greatly wondering.
27009	1021	12	And when Peter saw it, he answered unto the people, Ye men of Israel, why marvel ye at this? or why look ye so earnestly on us, as though by our own power or holiness we had made this man to walk?
27010	1021	13	The God of Abraham, and of Isaac, and of Jacob, the God of our fathers, hath glorified his Son Jesus; whom ye delivered up, and denied him in the presence of Pilate, when he was determined to let him go.
27011	1021	14	But ye denied the Holy One and the Just, and desired a murderer to be granted unto you;
27012	1021	15	And killed the Prince of life, whom God hath raised from the dead; whereof we are witnesses.
27013	1021	16	And his name through faith in his name hath made this man strong, whom ye see and know: yea, the faith which is by him hath given him this perfect soundness in the presence of you all.
27014	1021	17	And now, brethren, I wot that through ignorance ye did it, as did also your rulers.
27015	1021	18	But those things, which God before had shewed by the mouth of all his prophets, that Christ should suffer, he hath so fulfilled.
27016	1021	19	Repent ye therefore, and be converted, that your sins may be blotted out, when the times of refreshing shall come from the presence of the Lord;
27017	1021	20	And he shall send Jesus Christ, which before was preached unto you:
27018	1021	21	Whom the heaven must receive until the times of restitution of all things, which God hath spoken by the mouth of all his holy prophets since the world began.
27019	1021	22	For Moses truly said unto the fathers, A prophet shall the Lord your God raise up unto you of your brethren, like unto me; him shall ye hear in all things whatsoever he shall say unto you.
27020	1021	23	And it shall come to pass, that every soul, which will not hear that prophet, shall be destroyed from among the people.
27021	1021	24	Yea, and all the prophets from Samuel and those that follow after, as many as have spoken, have likewise foretold of these days.
27022	1021	25	Ye are the children of the prophets, and of the covenant which God made with our fathers, saying unto Abraham, And in thy seed shall all the kindreds of the earth be blessed.
27023	1021	26	Unto you first God, having raised up his Son Jesus, sent him to bless you, in turning away every one of you from his iniquities.
27024	1022	1	AND as they spake unto the people, the priests, and the captain of the temple, and the Sadducees, came upon them,
27025	1022	2	Being grieved that they taught the people, and preached through Jesus the resurrection from the dead.
27026	1022	3	And they laid hands on them, and put them in hold unto the next day: for it was now eventide.
27027	1022	4	Howbeit many of them which heard the word believed; and the number of the men was about five thousand.
27028	1022	5	And it came to pass on the morrow, that their rulers, and elders, and scribes,
27029	1022	6	And Annas the high priest, and Caiaphas, and John, and Alexander, and as many as were of the kindred of the high priest, were gathered together at Jerusalem.
27030	1022	7	And when they had set them in the midst, they asked, By what power, or by what name, have ye done this?
27031	1022	8	Then Peter, filled with the Holy Ghost, said unto them, Ye rulers of the people, and elders of Israel,
27032	1022	9	If we this day be examined of the good deed done to the impotent man, by what means he is made whole;
27033	1022	10	Be it known unto you all, and to all the people of Israel, that by the name of Jesus Christ of Nazareth, whom ye crucified, whom God raised from the dead, even by him doth this man stand here before you whole.
27034	1022	11	This is the stone which was set at nought of you builders, which is become the head of the corner.
27035	1022	12	Neither is there salvation in any other: for there is none other name under heaven given among men, whereby we must be saved.
27036	1022	13	Now when they saw the boldness of Peter and John, and perceived that they were unlearned and ignorant men, they marvelled; and they took knowledge of them, that they had been with Jesus.
27037	1022	14	And beholding the man which was healed standing with them, they could say nothing against it.
27038	1022	15	But when they had commanded them to go aside out of the council, they conferred among themselves,
27039	1022	16	Saying, What shall we do to these men? for that indeed a notable miracle hath been done by them is manifest to all them that dwell in Jerusalem; and we cannot deny it.
27040	1022	17	But that it spread no further among the people, let us straitly threaten them, that they speak henceforth to no man in this name.
27041	1022	18	And they called them, and commanded them not to speak at all nor teach in the name of Jesus.
27042	1022	19	But Peter and John answered and said unto them, Whether it be right in the sight of God to hearken unto you more than unto God, judge ye.
27043	1022	20	For we cannot but speak the things which we have seen and heard.
27044	1022	21	So when they had further threatened them, they let them go, finding nothing how they might punish them, because of the people: for all men glorified God for that which was done.
27045	1022	22	For the man was above forty years old, on whom this miracle of healing was shewed.
27046	1022	23	And being let go, they went to their own company, and reported all that the chief priests and elders had said unto them.
27047	1022	24	And when they heard that, they lifted up their voice to God with one accord, and said, Lord, thou art God, which hast made heaven, and earth, and the sea, and all that in them is:
27048	1022	25	Who by the mouth of thy servant David hast said, Why did the heathen rage, and the people imagine vain things?
27049	1022	26	The kings of the earth stood up, and the rulers were gathered together against the Lord, and against his Christ.
27050	1022	27	For of a truth against thy holy child Jesus, whom thou hast anointed, both Herod, and Pontius Pilate, with the Gentiles, and the people of Israel, were gathered together,
27051	1022	28	For to do whatsoever thy hand and thy counsel determined before to be done.
27052	1022	29	And now, Lord, behold their threatenings: and grant unto thy servants, that with all boldness they may speak thy word,
27053	1022	30	By stretching forth thine hand to heal; and that signs and wonders may be done by the name of thy holy child Jesus.
27054	1022	31	And when they had prayed, the place was shaken where they were assembled together; and they were all filled with the Holy Ghost, and they spake the word of God with boldness.
27055	1022	32	And the multitude of them that believed were of one heart and of one soul: neither said any of them that ought of the things which he possessed was his own; but they had all things common.
27056	1022	33	And with great power gave the apostles witness of the resurrection of the Lord Jesus: and great grace was upon them all.
27057	1022	34	Neither was there any among them that lacked: for as many as were possessors of lands or houses sold them, and brought the prices of the things that were sold,
27058	1022	35	And laid them down at the apostles' feet: and distribution was made unto every man according as he had need.
27059	1022	36	And Joses, who by the apostles was surnamed Barnabas, (which is, being interpreted, The son of consolation,) a Levite, and of the country of Cyprus,
27060	1022	37	Having land, sold it, and brought the money, and laid it at the apostles' feet.
27061	1023	1	BUT a certain man named Ananias, with Sapphira his wife, sold a possession,
27062	1023	2	And kept back part of the price, his wife also being privy to it, and brought a certain part, and laid it at the apostles' feet.
27063	1023	3	But Peter said, Ananias, why hath Satan filled thine heart to lie to the Holy Ghost, and to keep back part of the price of the land?
27064	1023	4	Whiles it remained, was it not thine own? and after it was sold, was it not in thine own power? why hast thou conceived this thing in thine heart? thou hast not lied unto men, but unto God.
27065	1023	5	And Ananias hearing these words fell down, and gave up the ghost: and great fear came on all them that heard these things.
27066	1023	6	And the young men arose, wound him up, and carried him out, and buried him.
27067	1023	7	And it was about the space of three hours after, when his wife, not knowing what was done, came in.
27068	1023	8	And Peter answered unto her, Tell me whether ye sold the land for so much? And she said, Yea, for so much.
27069	1023	9	Then Peter said unto her, How is it that ye have agreed together to tempt the Spirit of the Lord? behold, the feet of them which have buried thy husband are at the door, and shall carry thee out.
27070	1023	10	Then fell she down straightway at his feet, and yielded up the ghost: and the young men came in, and found her dead, and, carrying her forth, buried her by her husband.
27071	1023	11	And great fear came upon all the church, and upon as many as heard these things.
27072	1023	12	And by the hands of the apostles were many signs and wonders wrought among the people; (and they were all with one accord in Solomon's porch.
27073	1023	13	And of the rest durst no man join himself to them: but the people magnified them.
27074	1023	14	And believers were the more added to the Lord, multitudes both of men and women.)
27075	1023	15	Insomuch that they brought forth the sick into the streets, and laid them on beds and couches, that at the least the shadow of Peter passing by might overshadow some of them.
27076	1023	16	There came also a multitude out of the cities round about unto Jerusalem, bringing sick folks, and them which were vexed with unclean spirits: and they were healed every one.
27077	1023	17	Then the high priest rose up, and all they that were with him, (which is the sect of the Sadducees,) and were filled with indignation,
27078	1023	18	And laid their hands on the apostles, and put them in the common prison.
27079	1023	19	But the angel of the Lord by night opened the prison doors, and brought them forth, and said,
27080	1023	20	Go, stand and speak in the temple to the people all the words of this life.
27081	1023	21	And when they heard that, they entered into the temple early in the morning, and taught. But the high priest came, and they that were with him, and called the council together, and all the senate of the children of Israel, and sent to the prison to have them brought.
27082	1023	22	But when the officers came, and found them not in the prison, they returned, and told,
27083	1023	23	Saying, The prison truly found we shut with all safety, and the keepers standing without before the doors: but when we had opened, we found no man within.
27084	1023	24	Now when the high priest and the captain of the temple and the chief priests heard these things, they doubted of them whereunto this would grow.
27085	1023	25	Then came one and told them, saying, Behold, the men whom ye put in prison are standing in the temple, and teaching the people.
27086	1023	26	Then went the captain with the officers, and brought them without violence: for they feared the people, lest they should have been stoned.
27087	1023	27	And when they had brought them, they set them before the council: and the high priest asked them,
27088	1023	28	Saying, Did not we straitly command you that ye should not teach in this name? and, behold, ye have filled Jerusalem with your doctrine, and intend to bring this man's blood upon us.
27089	1023	29	Then Peter and the other apostles answered and said, We ought to obey God rather than men.
27090	1023	30	The God of our fathers raised up Jesus, whom ye slew and hanged on a tree.
27091	1023	31	Him hath God exalted with his right hand to be a Prince and a Saviour, for to give repentance to Israel, and forgiveness of sins.
27092	1023	32	And we are his witnesses of these things; and so is also the Holy Ghost, whom God hath given to them that obey him.
27093	1023	33	When they heard that, they were cut to the heart, and took counsel to slay them.
27094	1023	34	Then stood there up one in the council, a Pharisee, named Gamaliel, a doctor of the law, had in reputation among all the people, and commanded to put the apostles forth a little space;
27095	1023	35	And said unto them, Ye men of Israel, take heed to yourselves what ye intend to do as touching these men.
27096	1023	36	For before these days rose up Theudas, boasting himself to be somebody; to whom a number of men, about four hundred, joined themselves: who was slain; and all, as many as obeyed him, were scattered, and brought to nought.
27097	1023	37	After this man rose up Judas of Galilee in the days of the taxing, and drew away much people after him: he also perished; and all, even as many as obeyed him, were dispersed.
27098	1023	38	And now I say unto you, Refrain from these men, and let them alone: for if this counsel or this work be of men, it will come to nought:
27099	1023	39	But if it be of God, ye cannot overthrow it; lest haply ye be found even to fight against God.
27100	1023	40	And to him they agreed: and when they had called the apostles, and beaten them, they commanded that they should not speak in the name of Jesus, and let them go.
27101	1023	41	And they departed from the presence of the council, rejoicing that they were counted worthy to suffer shame for his name.
27102	1023	42	And daily in the temple, and in every house, they ceased not to teach and preach Jesus Christ.
27103	1024	1	AND in those days, when the number of the disciples was multiplied, there arose a murmuring of the Grecians against the Hebrews, because their widows were neglected in the daily ministration.
27104	1024	2	Then the twelve called the multitude of the disciples unto them, and said, It is not reason that we should leave the word of God, and serve tables.
27105	1024	3	Wherefore, brethren, look ye out among you seven men of honest report, full of the Holy Ghost and wisdom, whom we may appoint over this business.
27106	1024	4	But we will give ourselves continually to prayer, and to the ministry of the word.
27107	1024	5	And the saying pleased the whole multitude: and they chose Stephen, a man full of faith and of the Holy Ghost, and Philip, and Prochorus, and Nicanor, and Timon, and Parmenas, and Nicolas a proselyte of Antioch:
27108	1024	6	Whom they set before the apostles: and when they had prayed, they laid their hands on them.
27109	1024	7	And the word of God increased; and the number of the disciples multiplied in Jerusalem greatly; and a great company of the priests were obedient to the faith.
27110	1024	8	And Stephen, full of faith and power, did great wonders and miracles among the people.
27111	1024	9	Then there arose certain of the synagogue, which is called the synagogue of the Libertines, and Cyrenians, and Alexandrians, and of them of Cilicia and of Asia, disputing with Stephen.
27112	1024	10	And they were not able to resist the wisdom and the spirit by which he spake.
27113	1024	11	Then they suborned men, which said, We have heard him speak blasphemous words against Moses, and against God.
27114	1024	12	And they stirred up the people, and the elders, and the scribes, and came upon him, and caught him, and brought him to the council,
27115	1024	13	And set up false witnesses, which said, This man ceaseth not to speak blasphemous words against this holy place, and the law:
27116	1024	14	For we have heard him say, that this Jesus of Nazareth shall destroy this place, and shall change the customs which Moses delivered us.
27117	1024	15	And all that sat in the council, looking stedfastly on him, saw his face as it had been the face of an angel.
27118	1025	1	THEN said the high priest, Are these things so?
27119	1025	2	And he said, Men, brethren, and fathers, hearken; The God of glory appeared unto our father Abraham, when he was in Mesopotamia, before he dwelt in Charran,
27120	1025	3	And said unto him, Get thee out of thy country, and from thy kindred, and come into the land which I shall shew thee.
27121	1025	4	Then came he out of the land of the Chaldaeans, and dwelt in Charran: and from thence, when his father was dead, he removed him into this land, wherein ye now dwell.
27122	1025	5	And he gave him none inheritance in it, no, not so much as to set his foot on: yet he promised that he would give it to him for a possession, and to his seed after him, when as yet he had no child.
27123	1025	6	And God spake on this wise, That his seed should sojourn in a strange land; and that they should bring them into bondage, and entreat them evil four hundred years.
27124	1025	7	And the nation to whom they shall be in bondage will I judge, said God: and after that shall they come forth, and serve me in this place.
27125	1025	8	And he gave him the covenant of circumcision: and so Abraham begat Isaac, and circumcised him the eighth day; and Isaac begat Jacob; and Jacob begat the twelve patriarchs.
27126	1025	9	And the patriarchs, moved with envy, sold Joseph into Egypt: but God was with him,
27127	1025	10	And delivered him out of all his afflictions, and gave him favour and wisdom in the sight of Pharaoh king of Egypt; and he made him governor over Egypt and all his house.
27128	1025	11	Now there came a dearth over all the land of Egypt and Chanaan, and great affliction: and our fathers found no sustenance.
27129	1025	12	But when Jacob heard that there was corn in Egypt, he sent out our fathers first.
27130	1025	13	And at the second time Joseph was made known to his brethren; and Joseph's kindred was made known unto Pharaoh.
27131	1025	14	Then sent Joseph, and called his father Jacob to him, and all his kindred, threescore and fifteen souls.
27132	1025	15	So Jacob went down into Egypt, and died, he, and our fathers,
27133	1025	16	And were carried over into Sychem, and laid in the sepulchre that Abraham bought for a sum of money of the sons of Emmor the father of Sychem.
27134	1025	17	But when the time of the promise drew nigh, which God had sworn to Abraham, the people grew and multiplied in Egypt,
27135	1025	18	Till another king arose, which knew not Joseph.
27136	1025	19	The same dealt subtilly with our kindred, and evil entreated our fathers, so that they cast out their young children, to the end they might not live.
27137	1025	20	In which time Moses was born, and was exceeding fair, and nourished up in his father's house three months:
27138	1025	21	And when he was cast out, Pharaoh's daughter took him up, and nourished him for her own son.
27139	1025	22	And Moses was learned in all the wisdom of the Egyptians, and was mighty in words and in deeds.
27140	1025	23	And when he was full forty years old, it came into his heart to visit his brethren the children of Israel.
27141	1025	24	And seeing one of them suffer wrong, he defended him, and avenged him that was oppressed, and smote the Egyptian:
27142	1025	25	For he supposed his brethren would have understood how that God by his hand would deliver them: but they understood not.
27143	1025	26	And the next day he shewed himself unto them as they strove, and would have set them at one again, saying, Sirs, ye are brethren; why do ye wrong one to another?
27144	1025	27	But he that did his neighbour wrong thrust him away, saying, Who made thee a ruler and a judge over us?
27145	1025	28	Wilt thou kill me, as thou diddest the Egyptian yesterday?
27146	1025	29	Then fled Moses at this saying, and was a stranger in the land of Madian, where he begat two sons.
27147	1025	30	And when forty years were expired, there appeared to him in the wilderness of mount Sina an angel of the Lord in a flame of fire in a bush.
27148	1025	31	When Moses saw it, he wondered at the sight: and as he drew near to behold it, the voice of the Lord came unto him,
27149	1025	32	Saying, I am the God of thy fathers, the God of Abraham, and the God of Isaac, and the God of Jacob. Then Moses trembled, and durst not behold.
27150	1025	33	Then said the Lord to him, Put off thy shoes from thy feet: for the place where thou standest is holy ground.
27151	1025	34	I have seen, I have seen the affliction of my people which is in Egypt, and I have heard their groaning, and am come down to deliver them. And now come, I will send thee into Egypt.
27152	1025	35	This Moses whom they refused, saying, Who made thee a ruler and a judge? the same did God send to be a ruler and a deliverer by the hand of the angel which appeared to him in the bush.
27153	1025	36	He brought them out, after that he had shewed wonders and signs in the land of Egypt, and in the Red sea, and in the wilderness forty years.
27154	1025	37	This is that Moses, which said unto the children of Israel, A prophet shall the Lord your God raise up unto you of your brethren, like unto me; him shall ye hear.
27155	1025	38	This is he, that was in the church in the wilderness with the angel which spake to him in the mount Sina, and with our fathers: who received the lively oracles to give unto us:
27156	1025	39	To whom our fathers would not obey, but thrust him from them, and in their hearts turned back again into Egypt,
27157	1025	40	Saying unto Aaron, Make us gods to go before us: for as for this Moses, which brought us out of the land of Egypt, we wot not what is become of him.
27158	1025	41	And they made a calf in those days, and offered sacrifice unto the idol, and rejoiced in the works of their own hands.
27159	1025	42	Then God turned, and gave them up to worship the host of heaven; as it is written in the book of the prophets, O ye house of Israel, have ye offered to me slain beasts and sacrifices by the space of forty years in the wilderness?
27160	1025	43	Yea, ye took up the tabernacle of Moloch, and the star of your god Remphan, figures which ye made to worship them: and I will carry you away beyond Babylon.
27161	1025	44	Our fathers had the tabernacle of witness in the wilderness, as he had appointed, speaking unto Moses, that he should make it according to the fashion that he had seen.
27162	1025	45	Which also our fathers that came after brought in with Jesus into the possession of the Gentiles, whom God drave out before the face of our fathers, unto the days of David;
27163	1025	46	Who found favour before God, and desired to find a tabernacle for the God of Jacob.
27164	1025	47	But Solomon built him an house.
27165	1025	48	Howbeit the most High dwelleth not in temples made with hands; as saith the prophet,
27166	1025	49	Heaven is my throne, and earth is my footstool: what house will ye build me? saith the Lord: or what is the place of my rest?
27167	1025	50	Hath not my hand made all these things?
27168	1025	51	Ye stiffnecked and uncircumcised in heart and ears, ye do always resist the Holy Ghost: as your fathers did, so do ye.
27169	1025	52	Which of the prophets have not your fathers persecuted? and they have slain them which shewed before of the coming of the Just One; of whom ye have been now the betrayers and murderers:
27170	1025	53	Who have received the law by the disposition of angels, and have not kept it.
27171	1025	54	When they heard these things, they were cut to the heart, and they gnashed on him with their teeth.
27172	1025	55	But he, being full of the Holy Ghost, looked up stedfastly into heaven, and saw the glory of God, and Jesus standing on the right hand of God,
27173	1025	56	And said, Behold, I see the heavens opened, and the Son of man standing on the right hand of God.
27174	1025	57	Then they cried out with a loud voice, and stopped their ears, and ran upon him with one accord,
27175	1025	58	And cast him out of the city, and stoned him: and the witnesses laid down their clothes at a young man's feet, whose name was Saul.
27176	1025	59	And they stoned Stephen, calling upon God, and saying, Lord Jesus, receive my spirit.
27177	1025	60	And he kneeled down, and cried with a loud voice, Lord, lay not this sin to their charge. And when he had said this, he fell asleep.
27178	1026	1	AND Saul was consenting unto his death. And at that time there was a great persecution against the church which was at Jerusalem; and they were all scattered abroad throughout the regions of Judaea and Samaria, except the apostles.
27179	1026	2	And devout men carried Stephen to his burial, and made great lamentation over him.
27180	1026	3	As for Saul, he made havock of the church, entering into every house, and haling men and women committed them to prison.
27181	1026	4	Therefore they that were scattered abroad went every where preaching the word.
27182	1026	5	Then Philip went down to the city of Samaria, and preached Christ unto them.
27183	1026	6	And the people with one accord gave heed unto those things which Philip spake, hearing and seeing the miracles which he did.
27184	1026	7	For unclean spirits, crying with loud voice, came out of many that were possessed with them: and many taken with palsies, and that were lame, were healed.
27185	1026	8	And there was great joy in that city.
27186	1026	9	But there was a certain man, called Simon, which beforetime in the same city used sorcery, and bewitched the people of Samaria, giving out that himself was some great one:
27187	1026	10	To whom they all gave heed, from the least to the greatest, saying, This man is the great power of God.
27188	1026	11	And to him they had regard, because that of long time he had bewitched them with sorceries.
27189	1026	12	But when they believed Philip preaching the things concerning the kingdom of God, and the name of Jesus Christ, they were baptized, both men and women.
27190	1026	13	Then Simon himself believed also: and when he was baptized, he continued with Philip, and wondered, beholding the miracles and signs which were done.
27191	1026	14	Now when the apostles which were at Jerusalem heard that Samaria had received the word of God, they sent unto them Peter and John:
27192	1026	15	Who, when they were come down, prayed for them, that they might receive the Holy Ghost:
27193	1026	16	(For as yet he was fallen upon none of them: only they were baptized in the name of the Lord Jesus.)
27194	1026	17	Then laid they their hands on them, and they received the Holy Ghost.
27195	1026	18	And when Simon saw that through laying on of the apostles' hands the Holy Ghost was given, he offered them money,
27196	1026	19	Saying, Give me also this power, that on whomsoever I lay hands, he may receive the Holy Ghost.
27197	1026	20	But Peter said unto him, Thy money perish with thee, because thou hast thought that the gift of God may be purchased with money.
27198	1026	21	Thou hast neither part nor lot in this matter: for thy heart is not right in the sight of God.
27199	1026	22	Repent therefore of this thy wickedness, and pray God, if perhaps the thought of thine heart may be forgiven thee.
27200	1026	23	For I perceive that thou art in the gall of bitterness, and in the bond of iniquity.
27201	1026	24	Then answered Simon, and said, Pray ye to the Lord for me, that none of these things which ye have spoken come upon me.
27202	1026	25	And they, when they had testified and preached the word of the Lord, returned to Jerusalem, and preached the gospel in many villages of the Samaritans.
27203	1026	26	And the angel of the Lord spake unto Philip, saying, Arise, and go toward the south unto the way that goeth down from Jerusalem unto Gaza, which is desert.
27204	1026	27	And he arose and went: and, behold, a man of Ethiopia, an eunuch of great authority under Candace queen of the Ethiopians, who had the charge of all her treasure, and had come to Jerusalem for to worship,
27205	1026	28	Was returning, and sitting in his chariot read Esaias the prophet.
27206	1026	29	Then the Spirit said unto Philip, Go near, and join thyself to this chariot.
27207	1026	30	And Philip ran thither to him, and heard him read the prophet Esaias, and said, Understandest thou what thou readest?
27208	1026	31	And he said, How can I, except some man should guide me? And he desired Philip that he would come up and sit with him.
27209	1026	32	The place of the scripture which he read was this, He was led as a sheep to the slaughter; and like a lamb dumb before his shearer, so opened he not his mouth:
27210	1026	33	In his humiliation his judgment was taken away: and who shall declare his generation? for his life is taken from the earth.
27211	1026	34	And the eunuch answered Philip, and said, I pray thee, of whom speaketh the prophet this? of himself, or of some other man?
27212	1026	35	Then Philip opened his mouth, and began at the same scripture, and preached unto him Jesus.
27213	1026	36	And as they went on their way, they came unto a certain water: and the eunuch said, See, here is water; what doth hinder me to be baptized?
27214	1026	37	And Philip said, If thou believest with all thine heart, thou mayest. And he answered and said, I believe that Jesus Christ is the Son of God.
27215	1026	38	And he commanded the chariot to stand still: and they went down both into the water, both Philip and the eunuch; and he baptized him.
27216	1026	39	And when they were come up out of the water, the Spirit of the Lord caught away Philip, that the eunuch saw him no more: and he went on his way rejoicing.
27217	1026	40	But Philip was found at Azotus: and passing through he preached in all the cities, till he came to Caesarea.
27218	1027	1	AND Saul, yet breathing out threatenings and slaughter against the disciples of the Lord, went unto the high priest,
27219	1027	2	And desired of him letters to Damascus to the synagogues, that if he found any of this way, whether they were men or women, he might bring them bound unto Jerusalem.
27220	1027	3	And as he journeyed, he came near Damascus: and suddenly there shined round about him a light from heaven:
27221	1027	4	And he fell to the earth, and heard a voice saying unto him, Saul, Saul, why persecutest thou me?
27222	1027	5	And he said, Who art thou, Lord? And the Lord said, I am Jesus whom thou persecutest: it is hard for thee to kick against the pricks.
27223	1027	6	And he trembling and astonished said, Lord, what wilt thou have me to do? And the Lord said unto him, Arise, and go into the city, and it shall be told thee what thou must do.
27224	1027	7	And the men which journeyed with him stood speechless, hearing a voice, but seeing no man.
27225	1027	8	And Saul arose from the earth; and when his eyes were opened, he saw no man: but they led him by the hand, and brought him into Damascus.
27226	1027	9	And he was three days without sight, and neither did eat nor drink.
27227	1027	10	And there was a certain disciple at Damascus, named Ananias; and to him said the Lord in a vision, Ananias. And he said, Behold, I am here, Lord.
27228	1027	11	And the Lord said unto him, Arise, and go into the street which is called Straight, and enquire in the house of Judas for one called Saul, of Tarsus: for, behold, he prayeth,
27229	1027	12	And hath seen in a vision a man named Ananias coming in, and putting his hand on him, that he might receive his sight.
27230	1027	13	Then Ananias answered, Lord, I have heard by many of this man, how much evil he hath done to thy saints at Jerusalem:
27231	1027	14	And here he hath authority from the chief priests to bind all that call on thy name.
27232	1027	15	But the Lord said unto him, Go thy way: for he is a chosen vessel unto me, to bear my name before the Gentiles, and kings, and the children of Israel:
27233	1027	16	For I will shew him how great things he must suffer for my name's sake.
27234	1027	17	And Ananias went his way, and entered into the house; and putting his hands on him said, Brother Saul, the Lord, even Jesus, that appeared unto thee in the way as thou camest, hath sent me, that thou mightest receive thy sight, and be filled with the Holy Ghost.
27235	1027	18	And immediately there fell from his eyes as it had been scales: and he received sight forthwith, and arose, and was baptized.
27236	1027	19	And when he had received meat, he was strengthened. Then was Saul certain days with the disciples which were at Damascus.
27237	1027	20	And straightway he preached Christ in the synagogues, that he is the Son of God.
27238	1027	21	But all that heard him were amazed, and said; Is not this he that destroyed them which called on this name in Jerusalem, and came hither for that intent, that he might bring them bound unto the chief priests?
27239	1027	22	But Saul increased the more in strength, and confounded the Jews which dwelt at Damascus, proving that this is very Christ.
27240	1027	23	And after that many days were fulfilled, the Jews took counsel to kill him:
27241	1027	24	But their laying await was known of Saul. And they watched the gates day and night to kill him.
27242	1027	25	Then the disciples took him by night, and let him down by the wall in a basket.
27243	1027	26	And when Saul was come to Jerusalem, he assayed to join himself to the disciples: but they were all afraid of him, and believed not that he was a disciple.
27244	1027	27	But Barnabas took him, and brought him to the apostles, and declared unto them how he had seen the Lord in the way, and that he had spoken to him, and how he had preached boldly at Damascus in the name of Jesus.
27245	1027	28	And he was with them coming in and going out at Jerusalem.
27246	1027	29	And he spake boldly in the name of the Lord Jesus, and disputed against the Grecians: but they went about to slay him.
27247	1027	30	Which when the brethren knew, they brought him down to Caesarea, and sent him forth to Tarsus.
27248	1027	31	Then had the churches rest throughout all Judaea and Galilee and Samaria, and were edified; and walking in the fear of the Lord, and in the comfort of the Holy Ghost, were multiplied.
27249	1027	32	And it came to pass, as Peter passed throughout all quarters, he came down also to the saints which dwelt at Lydda.
27250	1027	33	And there he found a certain man named Aeneas, which had kept his bed eight years, and was sick of the palsy.
27251	1027	34	And Peter said unto him, Aeneas, Jesus Christ maketh thee whole: arise, and make thy bed. And he arose immediately.
27252	1027	35	And all that dwelt at Lydda and Saron saw him, and turned to the Lord.
27253	1027	36	Now there was at Joppa a certain disciple named Tabitha, which by interpretation is called Dorcas: this woman was full of good works and almsdeeds which she did.
27254	1027	37	And it came to pass in those days, that she was sick, and died: whom when they had washed, they laid her in an upper chamber.
27255	1027	38	And forasmuch as Lydda was nigh to Joppa, and the disciples had heard that Peter was there, they sent unto him two men, desiring him that he would not delay to come to them.
27256	1027	39	Then Peter arose and went with them. When he was come, they brought him into the upper chamber: and all the widows stood by him weeping, and shewing the coats and garments which Dorcas made, while she was with them.
27257	1027	40	But Peter put them all forth, and kneeled down, and prayed; and turning him to the body said, Tabitha, arise. And she opened her eyes: and when she saw Peter, she sat up.
27258	1027	41	And he gave her his hand, and lifted her up, and when he had called the saints and widows, presented her alive.
27259	1027	42	And it was known throughout all Joppa; and many believed in the Lord.
27260	1027	43	And it came to pass, that he tarried many days in Joppa with one Simon a tanner.
27261	1028	1	THERE was a certain man in Caesarea called Cornelius, a centurion of the band called the Italian band,
27262	1028	2	A devout man, and one that feared God with all his house, which gave much alms to the people, and prayed to God alway.
27263	1028	3	He saw in a vision evidently about the ninth hour of the day an angel of God coming in to him, and saying unto him, Cornelius.
27264	1028	4	And when he looked on him, he was afraid, and said, What is it, Lord? And he said unto him, Thy prayers and thine alms are come up for a memorial before God.
27265	1028	5	And now send men to Joppa, and call for one Simon, whose surname is Peter:
27266	1028	6	He lodgeth with one Simon a tanner, whose house is by the sea side: he shall tell thee what thou oughtest to do.
27267	1028	7	And when the angel which spake unto Cornelius was departed, he called two of his household servants, and a devout soldier of them that waited on him continually;
27268	1028	8	And when he had declared all these things unto them, he sent them to Joppa.
27269	1028	9	On the morrow, as they went on their journey, and drew nigh unto the city, Peter went up upon the housetop to pray about the sixth hour:
27270	1028	10	And he became very hungry, and would have eaten: but while they made ready, he fell into a trance,
27271	1028	11	And saw heaven opened, and a certain vessel descending unto him, as it had been a great sheet knit at the four corners, and let down to the earth:
27272	1028	12	Wherein were all manner of fourfooted beasts of the earth, and wild beasts, and creeping things, and fowls of the air.
27273	1028	13	And there came a voice to him, Rise, Peter; kill, and eat.
27274	1028	14	But Peter said, Not so, Lord; for I have never eaten any thing that is common or unclean.
27275	1028	15	And the voice spake unto him again the second time, What God hath cleansed, that call not thou common.
27276	1028	16	This was done thrice: and the vessel was received up again into heaven.
27277	1028	17	Now while Peter doubted in himself what this vision which he had seen should mean, behold, the men which were sent from Cornelius had made enquiry for Simon's house, and stood before the gate,
27278	1028	18	And called, and asked whether Simon, which was surnamed Peter, were lodged there.
27279	1028	19	While Peter thought on the vision, the Spirit said unto him, Behold, three men seek thee.
27280	1028	20	Arise therefore, and get thee down, and go with them, doubting nothing: for I have sent them.
27281	1028	21	Then Peter went down to the men which were sent unto him from Cornelius; and said, Behold, I am he whom ye seek: what is the cause wherefore ye are come?
27282	1028	22	And they said, Cornelius the centurion, a just man, and one that feareth God, and of good report among all the nation of the Jews, was warned from God by an holy angel to send for thee into his house, and to hear words of thee.
27283	1028	23	Then called he them in, and lodged them. And on the morrow Peter went away with them, and certain brethren from Joppa accompanied him.
27284	1028	24	And the morrow after they entered into Caesarea. And Cornelius waited for them, and had called together his kinsmen and near friends.
27285	1028	25	And as Peter was coming in, Cornelius met him, and fell down at his feet, and worshipped him.
27286	1028	26	But Peter took him up, saying, Stand up; I myself also am a man.
27287	1028	27	And as he talked with him, he went in, and found many that were come together.
27288	1028	28	And he said unto them, Ye know how that it is an unlawful thing for a man that is a Jew to keep company, or come unto one of another nation; but God hath shewed me that I should not call any man common or unclean.
27289	1028	29	Therefore came I unto you without gainsaying, as soon as I was sent for: I ask therefore for what intent ye have sent for me?
27290	1028	30	And Cornelius said, Four days ago I was fasting until this hour; and at the ninth hour I prayed in my house, and, behold, a man stood before me in bright clothing,
27291	1028	31	And said, Cornelius, thy prayer is heard, and thine alms are had in remembrance in the sight of God.
27292	1028	32	Send therefore to Joppa, and call hither Simon, whose surname is Peter; he is lodged in the house of one Simon a tanner by the sea side: who, when he cometh, shall speak unto thee.
27293	1028	33	Immediately therefore I sent to thee; and thou hast well done that thou art come. Now therefore are we all here present before God, to hear all things that are commanded thee of God.
27294	1028	34	Then Peter opened his mouth, and said, Of a truth I perceive that God is no respecter of persons:
27295	1028	35	But in every nation he that feareth him, and worketh righteousness, is accepted with him.
27296	1028	36	The word which God sent unto the children of Israel, preaching peace by Jesus Christ: (he is Lord of all:)
27297	1028	37	That word, I say, ye know, which was published throughout all Judaea, and began from Galilee, after the baptism which John preached;
27298	1028	38	How God anointed Jesus of Nazareth with the Holy Ghost and with power: who went about doing good, and healing all that were oppressed of the devil; for God was with him.
27299	1028	39	And we are witnesses of all things which he did both in the land of the Jews, and in Jerusalem; whom they slew and hanged on a tree:
27300	1028	40	Him God raised up the third day, and shewed him openly;
27301	1028	41	Not to all the people, but unto witnesses chosen before of God, even to us, who did eat and drink with him after he rose from the dead.
27302	1028	42	And he commanded us to preach unto the people, and to testify that it is he which was ordained of God to be the Judge of quick and dead.
27303	1028	43	To him give all the prophets witness, that through his name whosoever believeth in him shall receive remission of sins.
27304	1028	44	While Peter yet spake these words, the Holy Ghost fell on all them which heard the word.
27305	1028	45	And they of the circumcision which believed were astonished, as many as came with Peter, because that on the Gentiles also was poured out the gift of the Holy Ghost.
27306	1028	46	For they heard them speak with tongues, and magnify God. Then answered Peter,
27307	1028	47	Can any man forbid water, that these should not be baptized, which have received the Holy Ghost as well as we?
27308	1028	48	And he commanded them to be baptized in the name of the Lord. Then prayed they him to tarry certain days.
27309	1029	1	AND the apostles and brethren that were in Judaea heard that the Gentiles had also received the word of God.
27310	1029	2	And when Peter was come up to Jerusalem, they that were of the circumcision contended with him,
27311	1029	3	Saying, Thou wentest in to men uncircumcised, and didst eat with them.
27312	1029	4	But Peter rehearsed the matter from the beginning, and expounded it by order unto them, saying,
27313	1029	5	I was in the city of Joppa praying: and in a trance I saw a vision, A certain vessel descend, as it had been a great sheet, let down from heaven by four corners; and it came even to me:
27314	1029	6	Upon the which when I had fastened mine eyes, I considered, and saw fourfooted beasts of the earth, and wild beasts, and creeping things, and fowls of the air.
27315	1029	7	And I heard a voice saying unto me, Arise, Peter; slay and eat.
27316	1029	8	But I said, Not so, Lord: for nothing common or unclean hath at any time entered into my mouth.
27317	1029	9	But the voice answered me again from heaven, What God hath cleansed, that call not thou common.
27318	1029	10	And this was done three times: and all were drawn up again into heaven.
27319	1029	11	And, behold, immediately there were three men already come unto the house where I was, sent from Caesarea unto me.
27320	1029	12	And the Spirit bade me go with them, nothing doubting. Moreover these six brethren accompanied me, and we entered into the man's house:
27321	1029	13	And he shewed us how he had seen an angel in his house, which stood and said unto him, Send men to Joppa, and call for Simon, whose surname is Peter;
27322	1029	14	Who shall tell thee words, whereby thou and all thy house shall be saved.
27323	1029	15	And as I began to speak, the Holy Ghost fell on them, as on us at the beginning.
27324	1029	16	Then remembered I the word of the Lord, how that he said, John indeed baptized with water; but ye shall be baptized with the Holy Ghost.
27325	1029	17	Forasmuch then as God gave them the like gift as he did unto us, who believed on the Lord Jesus Christ; what was I, that I could withstand God?
27326	1029	18	When they heard these things, they held their peace, and glorified God, saying, Then hath God also to the Gentiles granted repentance unto life.
27327	1029	19	Now they which were scattered abroad upon the persecution that arose about Stephen travelled as far as Phenice, and Cyprus, and Antioch, preaching the word to none but unto the Jews only.
27328	1029	20	And some of them were men of Cyprus and Cyrene, which, when they were come to Antioch, spake unto the Grecians, preaching the Lord Jesus.
27329	1029	21	And the hand of the Lord was with them: and a great number believed, and turned unto the Lord.
27330	1029	22	Then tidings of these things came unto the ears of the church which was in Jerusalem: and they sent forth Barnabas, that he should go as far as Antioch.
27331	1029	23	Who, when he came, and had seen the grace of God, was glad, and exhorted them all, that with purpose of heart they would cleave unto the Lord.
27332	1029	24	For he was a good man, and full of the Holy Ghost and of faith: and much people was added unto the Lord.
27333	1029	25	Then departed Barnabas to Tarsus, for to seek Saul:
27334	1029	26	And when he had found him, he brought him unto Antioch. And it came to pass, that a whole year they assembled themselves with the church, and taught much people. And the disciples were called Christians first in Antioch.
27335	1029	27	And in these days came prophets from Jerusalem unto Antioch.
27336	1029	28	And there stood up one of them named Agabus, and signified by the Spirit that there should be great dearth throughout all the world: which came to pass in the days of Claudius Caesar.
27337	1029	29	Then the disciples, every man according to his ability, determined to send relief unto the brethren which dwelt in Judaea:
27338	1029	30	Which also they did, and sent it to the elders by the hands of Barnabas and Saul.
27339	1030	1	NOW about that time Herod the king stretched forth his hands to vex certain of the church.
27340	1030	2	And he killed James the brother of John with the sword.
27341	1030	3	And because he saw it pleased the Jews, he proceeded further to take Peter also. (Then were the days of unleavened bread.)
27342	1030	4	And when he had apprehended him, he put him in prison, and delivered him to four quaternions of soldiers to keep him; intending after Easter to bring him forth to the people.
27343	1030	5	Peter therefore was kept in prison: but prayer was made without ceasing of the church unto God for him.
27344	1030	6	And when Herod would have brought him forth, the same night Peter was sleeping between two soldiers, bound with two chains: and the keepers before the door kept the prison.
27345	1030	7	And, behold, the angel of the Lord came upon him, and a light shined in the prison: and he smote Peter on the side, and raised him up, saying, Arise up quickly. And his chains fell off from his hands.
27346	1030	8	And the angel said unto him, Gird thyself, and bind on thy sandals. And so he did. And he saith unto him, Cast thy garment about thee, and follow me.
27347	1030	9	And he went out, and followed him; and wist not that it was true which was done by the angel; but thought he saw a vision.
27348	1030	10	When they were past the first and the second ward, they came unto the iron gate that leadeth unto the city; which opened to them of his own accord: and they went out, and passed on through one street; and forthwith the angel departed from him.
27349	1030	11	And when Peter was come to himself, he said, Now I know of a surety, that the Lord hath sent his angel, and hath delivered me out of the hand of Herod, and from all the expectation of the people of the Jews.
27350	1030	12	And when he had considered the thing, he came to the house of Mary the mother of John, whose surname was Mark; where many were gathered together praying.
27351	1030	13	And as Peter knocked at the door of the gate, a damsel came to hearken, named Rhoda.
27352	1030	14	And when she knew Peter's voice, she opened not the gate for gladness, but ran in, and told how Peter stood before the gate.
27353	1030	15	And they said unto her, Thou art mad. But she constantly affirmed that it was even so. Then said they, It is his angel.
27354	1030	16	But Peter continued knocking: and when they had opened the door, and saw him, they were astonished.
27355	1030	17	But he, beckoning unto them with the hand to hold their peace, declared unto them how the Lord had brought him out of the prison. And he said, Go shew these things unto James, and to the brethren. And he departed, and went into another place.
27356	1030	18	Now as soon as it was day, there was no small stir among the soldiers, what was become of Peter.
27357	1030	19	And when Herod had sought for him, and found him not, he examined the keepers, and commanded that they should be put to death. And he went down from Judaea to Caesarea, and there abode.
27358	1030	20	And Herod was highly displeased with them of Tyre and Sidon: but they came with one accord to him, and, having made Blastus the king's chamberlain their friend, desired peace; because their country was nourished by the king's country.
27359	1030	21	And upon a set day Herod, arrayed in royal apparel, sat upon his throne, and made an oration unto them.
27360	1030	22	And the people gave a shout, saying, It is the voice of a god, and not of a man.
27361	1030	23	And immediately the angel of the Lord smote him, because he gave not God the glory: and he was eaten of worms, and gave up the ghost.
27362	1030	24	But the word of God grew and multiplied.
27363	1030	25	And Barnabas and Saul returned from Jerusalem, when they had fulfilled their ministry, and took with them John, whose surname was Mark.
27364	1031	1	NOW there were in the church that was at Antioch certain prophets and teachers; as Barnabas, and Simeon that was called Niger, and Lucius of Cyrene, and Manaen, which had been brought up with Herod the tetrarch, and Saul.
27365	1031	2	As they ministered to the Lord, and fasted, the Holy Ghost said, Separate me Barnabas and Saul for the work whereunto I have called them.
27366	1031	3	And when they had fasted and prayed, and laid their hands on them, they sent them away.
27367	1031	4	So they, being sent forth by the Holy Ghost, departed unto Seleucia; and from thence they sailed to Cyprus.
27368	1031	5	And when they were at Salamis, they preached the word of God in the synagogues of the Jews: and they had also John to their minister.
27369	1031	6	And when they had gone through the isle unto Paphos, they found a certain sorcerer, a false prophet, a Jew, whose name was Bar-jesus:
27370	1031	7	Which was with the deputy of the country, Sergius Paulus, a prudent man; who called for Barnabas and Saul, and desired to hear the word of God.
27371	1031	8	But Elymas the sorcerer (for so is his name by interpretation) withstood them, seeking to turn away the deputy from the faith.
27372	1031	9	Then Saul, (who also is called Paul,) filled with the Holy Ghost, set his eyes on him,
27373	1031	10	And said, O full of all subtilty and all mischief, thou child of the devil, thou enemy of all righteousness, wilt thou not cease to pervert the right ways of the Lord?
27374	1031	11	And now, behold, the hand of the Lord is upon thee, and thou shalt be blind, not seeing the sun for a season. And immediately there fell on him a mist and a darkness; and he went about seeking some to lead him by the hand.
27375	1031	12	Then the deputy, when he saw what was done, believed, being astonished at the doctrine of the Lord.
27376	1031	13	Now when Paul and his company loosed from Paphos, they came to Perga in Pamphylia: and John departing from them returned to Jerusalem.
27377	1031	14	But when they departed from Perga, they came to Antioch in Pisidia, and went into the synagogue on the sabbath day, and sat down.
27378	1031	15	And after the reading of the law and the prophets the rulers of the synagogue sent unto them, saying, Ye men and brethren, if ye have any word of exhortation for the people, say on.
27379	1031	16	Then Paul stood up, and beckoning with his hand said, Men of Israel, and ye that fear God, give audience.
27380	1031	17	The God of this people of Israel chose our fathers, and exalted the people when they dwelt as strangers in the land of Egypt, and with an high arm brought he them out of it.
27381	1031	18	And about the time of forty years suffered he their manners in the wilderness.
27382	1031	19	And when he had destroyed seven nations in the land of Chanaan, he divided their land to them by lot.
27383	1031	20	And after that he gave unto them judges about the space of four hundred and fifty years, until Samuel the prophet.
27384	1031	21	And afterward they desired a king: and God gave unto them Saul the son of Cis, a man of the tribe of Benjamin, by the space of forty years.
27385	1031	22	And when he had removed him, he raised up unto them David to be their king; to whom also he gave testimony, and said, I have found David the son of Jesse, a man after mine own heart, which shall fulfil all my will.
27386	1031	23	Of this man's seed hath God according to his promise raised unto Israel a Saviour, Jesus:
27387	1031	24	When John had first preached before his coming the baptism of repentance to all the people of Israel.
27388	1031	25	And as John fulfilled his course, he said, Whom think ye that I am? I am not he. But, behold, there cometh one after me, whose shoes of his feet I am not worthy to loose.
27389	1031	26	Men and brethren, children of the stock of Abraham, and whosoever among you feareth God, to you is the word of this salvation sent.
27390	1031	27	For they that dwell at Jerusalem, and their rulers, because they knew him not, nor yet the voices of the prophets which are read every sabbath day, they have fulfilled them in condemning him.
27391	1031	28	And though they found no cause of death in him, yet desired they Pilate that he should be slain.
27392	1031	29	And when they had fulfilled all that was written of him, they took him down from the tree, and laid him in a sepulchre.
27393	1031	30	But God raised him from the dead:
27394	1031	31	And he was seen many days of them which came up with him from Galilee to Jerusalem, who are his witnesses unto the people.
27395	1031	32	And we declare unto you glad tidings, how that the promise which was made unto the fathers,
27396	1031	33	God hath fulfilled the same unto us their children, in that he hath raised up Jesus again; as it is also written in the second psalm, Thou art my Son, this day have I begotten thee.
27397	1031	34	And as concerning that he raised him up from the dead, now no more to return to corruption, he said on this wise, I will give you the sure mercies of David.
27398	1031	35	Wherefore he saith also in another psalm, Thou shalt not suffer thine Holy One to see corruption.
27399	1031	36	For David, after he had served his own generation by the will of God, fell on sleep, and was laid unto his fathers, and saw corruption:
27400	1031	37	But he, whom God raised again, saw no corruption.
27401	1031	38	Be it known unto you therefore, men and brethren, that through this man is preached unto you the forgiveness of sins:
27402	1031	39	And by him all that believe are justified from all things, from which ye could not be justified by the law of Moses.
27403	1031	40	Beware therefore, lest that come upon you, which is spoken of in the prophets;
27404	1031	41	Behold, ye despisers, and wonder, and perish: for I work a work in your days, a work which ye shall in no wise believe, though a man declare it unto you.
27405	1031	42	And when the Jews were gone out of the synagogue, the Gentiles besought that these words might be preached to them the next sabbath.
27406	1031	43	Now when the congregation was broken up, many of the Jews and religious proselytes followed Paul and Barnabas: who, speaking to them, persuaded them to continue in the grace of God.
27407	1031	44	And the next sabbath day came almost the whole city together to hear the word of God.
27408	1031	45	But when the Jews saw the multitudes, they were filled with envy, and spake against those things which were spoken by Paul, contradicting and blaspheming.
27409	1031	46	Then Paul and Barnabas waxed bold, and said, It was necessary that the word of God should first have been spoken to you: but seeing ye put it from you, and judge yourselves unworthy of everlasting life, lo, we turn to the Gentiles.
27410	1031	47	For so hath the Lord commanded us, saying, I have set thee to be a light of the Gentiles, that thou shouldest be for salvation unto the ends of the earth.
27411	1031	48	And when the Gentiles heard this, they were glad, and glorified the word of the Lord: and as many as were ordained to eternal life believed.
27412	1031	49	And the word of the Lord was published throughout all the region.
27413	1031	50	But the Jews stirred up the devout and honourable women, and the chief men of the city, and raised persecution against Paul and Barnabas, and expelled them out of their coasts.
27414	1031	51	But they shook off the dust of their feet against them, and came unto Iconium.
27415	1031	52	And the disciples were filled with joy, and with the Holy Ghost.
27416	1032	1	AND it came to pass in Iconium, that they went both together into the synagogue of the Jews, and so spake, that a great multitude both of the Jews and also of the Greeks believed.
27417	1032	2	But the unbelieving Jews stirred up the Gentiles, and made their minds evil affected against the brethren.
27418	1032	3	Long time therefore abode they speaking boldly in the Lord, which gave testimony unto the word of his grace, and granted signs and wonders to be done by their hands.
27419	1032	4	But the multitude of the city was divided: and part held with the Jews, and part with the apostles.
27420	1032	5	And when there was an assault made both of the Gentiles, and also of the Jews with their rulers, to use them despitefully, and to stone them,
27421	1032	6	They were ware of it, and fled unto Lystra and Derbe, cities of Lycaonia, and unto the region that lieth round about:
27422	1032	7	And there they preached the gospel.
27423	1032	8	And there sat a certain man at Lystra, impotent in his feet, being a cripple from his mother's womb, who never had walked:
27424	1032	9	The same heard Paul speak: who stedfastly beholding him, and perceiving that he had faith to be healed,
27425	1032	10	Said with a loud voice, Stand upright on thy feet. And he leaped and walked.
27426	1032	11	And when the people saw what Paul had done, they lifted up their voices, saying in the speech of Lycaonia, The gods are come down to us in the likeness of men.
27427	1032	12	And they called Barnabas, Jupiter; and Paul, Mercurius, because he was the chief speaker.
27428	1032	13	Then the priest of Jupiter, which was before their city, brought oxen and garlands unto the gates, and would have done sacrifice with the people.
27429	1032	14	Which when the apostles, Barnabas and Paul, heard of, they rent their clothes, and ran in among the people, crying out,
27430	1032	15	And saying, Sirs, why do ye these things? We also are men of like passions with you, and preach unto you that ye should turn from these vanities unto the living God, which made heaven, and earth, and the sea, and all things that are therein:
27431	1032	16	Who in times past suffered all nations to walk in their own ways.
27432	1032	17	Nevertheless he left not himself without witness, in that he did good, and gave us rain from heaven, and fruitful seasons, filling our hearts with food and gladness.
27433	1032	18	And with these sayings scarce restrained they the people, that they had not done sacrifice unto them.
27434	1032	19	And there came thither certain Jews from Antioch and Iconium, who persuaded the people, and, having stoned Paul, drew him out of the city, supposing he had been dead.
27435	1032	20	Howbeit, as the disciples stood round about him, he rose up, and came into the city: and the next day he departed with Barnabas to Derbe.
27436	1032	21	And when they had preached the gospel to that city, and had taught many, they returned again to Lystra, and to Iconium, and Antioch,
27437	1032	22	Confirming the souls of the disciples, and exhorting them to continue in the faith, and that we must through much tribulation enter into the kingdom of God.
27438	1032	23	And when they had ordained them elders in every church, and had prayed with fasting, they commended them to the Lord, on whom they believed.
27439	1032	24	And after they had passed throughout Pisidia, they came to Pamphylia.
27440	1032	25	And when they had preached the word in Perga, they went down into Attalia:
27441	1032	26	And thence sailed to Antioch, from whence they had been recommended to the grace of God for the work which they fulfilled.
27442	1032	27	And when they were come, and had gathered the church together, they rehearsed all that God had done with them, and how he had opened the door of faith unto the Gentiles.
27443	1032	28	And there they abode long time with the disciples.
27444	1033	1	AND certain men which came down from Judaea taught the brethren, and said, Except ye be circumcised after the manner of Moses, ye cannot be saved.
27445	1033	2	When therefore Paul and Barnabas had no small dissension and disputation with them, they determined that Paul and Barnabas, and certain other of them, should go up to Jerusalem unto the apostles and elders about this question.
27446	1033	3	And being brought on their way by the church, they passed through Phenice and Samaria, declaring the conversion of the Gentiles: and they caused great joy unto all the brethren.
27447	1033	4	And when they were come to Jerusalem, they were received of the church, and of the apostles and elders, and they declared all things that God had done with them.
27448	1033	5	But there rose up certain of the sect of the Pharisees which believed, saying, That it was needful to circumcise them, and to command them to keep the law of Moses.
27449	1033	6	And the apostles and elders came together for to consider of this matter.
27450	1033	7	And when there had been much disputing, Peter rose up, and said unto them, Men and brethren, ye know how that a good while ago God made choice among us, that the Gentiles by my mouth should hear the word of the gospel, and believe.
27451	1033	8	And God, which knoweth the hearts, bare them witness, giving them the Holy Ghost, even as he did unto us;
27452	1033	9	And put no difference between us and them, purifying their hearts by faith.
27453	1033	10	Now therefore why tempt ye God, to put a yoke upon the neck of the disciples, which neither our fathers nor we were able to bear?
27454	1033	11	But we believe that through the grace of the Lord Jesus Christ we shall be saved, even as they.
27455	1033	12	Then all the multitude kept silence, and gave audience to Barnabas and Paul, declaring what miracles and wonders God had wrought among the Gentiles by them.
27456	1033	13	And after they had held their peace, James answered, saying, Men and brethren, hearken unto me:
27457	1033	14	Simeon hath declared how God at the first did visit the Gentiles, to take out of them a people for his name.
27458	1033	15	And to this agree the words of the prophets; as it is written,
27459	1033	16	After this I will return, and will build again the tabernacle of David, which is fallen down; and I will build again the ruins thereof, and I will set it up:
27460	1033	17	That the residue of men might seek after the Lord, and all the Gentiles, upon whom my name is called, saith the Lord, who doeth all these things.
27461	1033	18	Known unto God are all his works from the beginning of the world.
27462	1033	19	Wherefore my sentence is, that we trouble not them, which from among the Gentiles are turned to God:
27463	1033	20	But that we write unto them, that they abstain from pollutions of idols, and from fornication, and from things strangled, and from blood.
27464	1033	21	For Moses of old time hath in every city them that preach him, being read in the synagogues every sabbath day.
27465	1033	22	Then pleased it the apostles and elders, with the whole church, to send chosen men of their own company to Antioch with Paul and Barnabas; namely, Judas surnamed Barsabas, and Silas, chief men among the brethren:
27466	1033	23	And they wrote letters by them after this manner; The apostles and elders and brethren send greeting unto the brethren which are of the Gentiles in Antioch and Syria and Cilicia:
27467	1033	24	Forasmuch as we have heard, that certain which went out from us have troubled you with words, subverting your souls, saying, Ye must be circumcised, and keep the law: to whom we gave no such commandment:
27468	1033	25	It seemed good unto us, being assembled with one accord, to send chosen men unto you with our beloved Barnabas and Paul,
27469	1033	26	Men that have hazarded their lives for the name of our Lord Jesus Christ.
27470	1033	27	We have sent therefore Judas and Silas, who shall also tell you the same things by mouth.
27471	1033	28	For it seemed good to the Holy Ghost, and to us, to lay upon you no greater burden than these necessary things;
27472	1033	29	That ye abstain from meats offered to idols, and from blood, and from things strangled, and from fornication: from which if ye keep yourselves, ye shall do well. Fare ye well.
27473	1033	30	So when they were dismissed, they came to Antioch: and when they had gathered the multitude together, they delivered the epistle:
27474	1033	31	Which when they had read, they rejoiced for the consolation.
27475	1033	32	And Judas and Silas, being prophets also themselves, exhorted the brethren with many words, and confirmed them.
27476	1033	33	And after they had tarried there a space, they were let go in peace from the brethren unto the apostles.
27477	1033	34	Notwithstanding it pleased Silas to abide there still.
27478	1033	35	Paul also and Barnabas continued in Antioch, teaching and preaching the word of the Lord, with many others also.
27479	1033	36	And some days after Paul said unto Barnabas, Let us go again and visit our brethren in every city where we have preached the word of the Lord, and see how they do.
27480	1033	37	And Barnabas determined to take with them John, whose surname was Mark.
27481	1033	38	But Paul thought not good to take him with them, who departed from them from Pamphylia, and went not with them to the work.
27482	1033	39	And the contention was so sharp between them, that they departed asunder one from the other: and so Barnabas took Mark, and sailed unto Cyprus;
27483	1033	40	And Paul chose Silas, and departed, being recommended by the brethren unto the grace of God.
27484	1033	41	And he went through Syria and Cilicia, confirming the churches.
27485	1034	1	THEN came he to Derbe and Lystra: and, behold, a certain disciple was there, named Timotheus, the son of a certain woman, which was a Jewess, and believed; but his father was a Greek:
27486	1034	2	Which was well reported of by the brethren that were at Lystra and Iconium.
27487	1034	3	Him would Paul have to go forth with him; and took and circumcised him because of the Jews which were in those quarters: for they knew all that his father was a Greek.
27488	1034	4	And as they went through the cities, they delivered them the decrees for to keep, that were ordained of the apostles and elders which were at Jerusalem.
27489	1034	5	And so were the churches established in the faith, and increased in number daily.
27490	1034	6	Now when they had gone throughout Phrygia and the region of Galatia, and were forbidden of the Holy Ghost to preach the word in Asia,
27491	1034	7	After they were come to Mysia, they assayed to go into Bithynia: but the Spirit suffered them not.
27492	1034	8	And they passing by Mysia came down to Troas.
27493	1034	9	And a vision appeared to Paul in the night; There stood a man of Macedonia, and prayed him, saying, Come over into Macedonia, and help us.
27494	1034	10	And after he had seen the vision, immediately we endeavoured to go into Macedonia, assuredly gathering that the Lord had called us for to preach the gospel unto them.
27495	1034	11	Therefore loosing from Troas, we came with a straight course to Samothracia, and the next day to Neapolis;
27496	1034	12	And from thence to Philippi, which is the chief city of that part of Macedonia, and a colony: and we were in that city abiding certain days.
27497	1034	13	And on the sabbath we went out of the city by a river side, where prayer was wont to be made; and we sat down, and spake unto the women which resorted thither.
27498	1034	14	And a certain woman named Lydia, a seller of purple, of the city of Thyatira, which worshipped God, heard us: whose heart the Lord opened, that she attended unto the things which were spoken of Paul.
27499	1034	15	And when she was baptized, and her household, she besought us, saying, If ye have judged me to be faithful to the Lord, come into my house, and abide there. And she constrained us.
27500	1034	16	And it came to pass, as we went to prayer, a certain damsel possessed with a spirit of divination met us, which brought her masters much gain by soothsaying:
27501	1034	17	The same followed Paul and us, and cried, saying, These men are the servants of the most high God, which shew unto us the way of salvation.
27502	1034	18	And this did she many days. But Paul, being grieved, turned and said to the spirit, I command thee in the name of Jesus Christ to come out of her. And he came out the same hour.
27503	1034	19	And when her masters saw that the hope of their gains was gone, they caught Paul and Silas, and drew them into the marketplace unto the rulers,
27504	1034	20	And brought them to the magistrates, saying, These men, being Jews, do exceedingly trouble our city,
27505	1034	21	And teach customs, which are not lawful for us to receive, neither to observe, being Romans.
27506	1034	22	And the multitude rose up together against them: and the magistrates rent off their clothes, and commanded to beat them.
27507	1034	23	And when they had laid many stripes upon them, they cast them into prison, charging the jailor to keep them safely:
27508	1034	24	Who, having received such a charge, thrust them into the inner prison, and made their feet fast in the stocks.
27509	1034	25	And at midnight Paul and Silas prayed, and sang praises unto God: and the prisoners heard them.
27510	1034	26	And suddenly there was a great earthquake, so that the foundations of the prison were shaken: and immediately all the doors were opened, and every one's bands were loosed.
27511	1034	27	And the keeper of the prison awaking out of his sleep, and seeing the prison doors open, he drew out his sword, and would have killed himself, supposing that the prisoners had been fled.
27512	1034	28	But Paul cried with a loud voice, saying, Do thyself no harm: for we are all here.
27513	1034	29	Then he called for a light, and sprang in, and came trembling, and fell down before Paul and Silas,
27514	1034	30	And brought them out, and said, Sirs, what must I do to be saved?
27515	1034	31	And they said, Believe on the Lord Jesus Christ, and thou shalt be saved, and thy house.
27516	1034	32	And they spake unto him the word of the Lord, and to all that were in his house.
27517	1034	33	And he took them the same hour of the night, and washed their stripes; and was baptized, he and all his, straightway.
27518	1034	34	And when he had brought them into his house, he set meat before them, and rejoiced, believing in God with all his house.
27519	1034	35	And when it was day, the magistrates sent the serjeants, saying, Let those men go.
27520	1034	36	And the keeper of the prison told this saying to Paul, The magistrates have sent to let you go: now therefore depart, and go in peace.
27521	1034	37	But Paul said unto them, They have beaten us openly uncondemned, being Romans, and have cast us into prison; and now do they thrust us out privily? nay verily; but let them come themselves and fetch us out.
27522	1034	38	And the serjeants told these words unto the magistrates: and they feared, when they heard that they were Romans.
27523	1034	39	And they came and besought them, and brought them out, and desired them to depart out of the city.
27524	1034	40	And they went out of the prison, and entered into the house of Lydia and when they had seen the brethren, they comforted them, and departed.
27525	1035	1	NOW when they had passed through Amphipolis and Apollonia, they came to Thessalonica, where was a synagogue of the Jews:
27526	1035	2	And Paul, as his manner was, went in unto them, and three sabbath days reasoned with them out of the scriptures,
27527	1035	3	Opening and alleging, that Christ must needs have suffered, and risen again from the dead; and that this Jesus, whom I preach unto you, is Christ.
27528	1035	4	And some of them believed, and consorted with Paul and Silas; and of the devout Greeks a great multitude, and of the chief women not a few.
27529	1035	5	But the Jews which believed not, moved with envy, took unto them certain lewd fellows of the baser sort, and gathered a company, and set all the city on an uproar, and assaulted the house of Jason, and sought to bring them out to the people.
27530	1035	6	And when they found them not, they drew Jason and certain brethren unto the rulers of the city, crying, These that have turned the world upside down are come hither also;
27531	1035	7	Whom Jason hath received: and these all do contrary to the decrees of Caesar, saying that there is another king, one Jesus.
27532	1035	8	And they troubled the people and the rulers of the city, when they heard these things.
27533	1035	9	And when they had taken security of Jason, and of the other, they let them go.
27534	1035	10	And the brethren immediately sent away Paul and Silas by night unto Berea: who coming thither went into the synagogue of the Jews.
27535	1035	11	These were more noble than those in Thessalonica, in that they received the word with all readiness of mind, and searched the scriptures daily, whether those things were so.
27536	1035	12	Therefore many of them believed; also of honourable women which were Greeks, and of men, not a few.
27537	1035	13	But when the Jews of Thessalonica had knowledge that the word of God was preached of Paul at Berea, they came thither also, and stirred up the people.
27538	1035	14	And then immediately the brethren sent away Paul to go as it were to the sea: but Silas and Timotheus abode there still.
27539	1035	15	And they that conducted Paul brought him unto Athens: and receiving a commandment unto Silas and Timotheus for to come to him with all speed, they departed.
27540	1035	16	Now while Paul waited for them at Athens, his spirit was stirred in him, when he saw the city wholly given to idolatry.
27541	1035	17	Therefore disputed he in the synagogue with the Jews, and with the devout persons, and in the market daily with them that met with him.
27542	1035	18	Then certain philosophers of the Epicureans, and of the Stoicks, encountered him. And some said, What will this babbler say? other some, He seemeth to be a setter forth of strange gods: because he preached unto them Jesus, and the resurrection.
27543	1035	19	And they took him, and brought him unto Areopagus, saying, May we know what this new doctrine, whereof thou speakest, is?
27544	1035	20	For thou bringest certain strange things to our ears: we would know therefore what these things mean.
27545	1035	21	(For all the Athenians and strangers which were there spent their time in nothing else, but either to tell, or to hear some new thing.)
27546	1035	22	Then Paul stood in the midst of Mars' hill, and said, Ye men of Athens, I perceive that in all things ye are too superstitious.
27547	1035	23	For as I passed by, and beheld your devotions, I found an altar with this inscription, TO THE UNKNOWN GOD. Whom therefore ye ignorantly worship, him declare I unto you.
27548	1035	24	God that made the world and all things therein, seeing that he is Lord of heaven and earth, dwelleth not in temples made with hands;
27549	1035	25	Neither is worshipped with men's hands, as though he needed any thing, seeing he giveth to all life, and breath, and all things;
27550	1035	26	And hath made of one blood all nations of men for to dwell on all the face of the earth, and hath determined the times before appointed, and the bounds of their habitation;
27551	1035	27	That they should seek the Lord, if haply they might feel after him, and find him, though he be not far from every one of us:
27552	1035	28	For in him we live, and move, and have our being; as certain also of your own poets have said, For we are also his offspring.
27553	1035	29	Forasmuch then as we are the offspring of God, we ought not to think that the Godhead is like unto gold, or silver, or stone, graven by art and man's device.
27554	1035	30	And the times of this ignorance God winked at; but now commandeth all men every where to repent:
27555	1035	31	Because he hath appointed a day, in the which he will judge the world in righteousness by that man whom he hath ordained; whereof he hath given assurance unto all men, in that he hath raised him from the dead.
27556	1035	32	And when they heard of the resurrection of the dead, some mocked: and others said, We will hear thee again of this matter.
27557	1035	33	So Paul departed from among them.
27558	1035	34	Howbeit certain men clave unto him, and believed: among the which was Dionysius the Areopagite, and a woman named Damaris, and others with them.
27559	1036	1	AFTER these things Paul departed from Athens, and came to Corinth;
27560	1036	2	And found a certain Jew named Aquila, born in Pontus, lately come from Italy, with his wife Priscilla; (because that Claudius had commanded all Jews to depart from Rome:) and came unto them.
27561	1036	3	And because he was of the same craft, he abode with them, and wrought: for by their occupation they were tentmakers.
27562	1036	4	And he reasoned in the synagogue every sabbath, and persuaded the Jews and the Greeks.
27563	1036	5	And when Silas and Timotheus were come from Macedonia, Paul was pressed in the spirit, and testified to the Jews that Jesus was Christ.
27564	1036	6	And when they opposed themselves, and blasphemed, he shook his raiment, and said unto them, Your blood be upon your own heads; I am clean: from henceforth I will go unto the Gentiles.
27565	1036	7	And he departed thence, and entered into a certain man's house, named Justus, one that worshipped God, whose house joined hard to the synagogue.
27566	1036	8	And Crispus, the chief ruler of the synagogue, believed on the Lord with all his house; and many of the Corinthians hearing believed, and were baptized.
27567	1036	9	Then spake the Lord to Paul in the night by a vision, Be not afraid, but speak, and hold not thy peace:
27568	1036	10	For I am with thee, and no man shall set on thee to hurt thee: for I have much people in this city.
27569	1036	11	And he continued there a year and six months, teaching the word of God among them.
27570	1036	12	And when Gallio was the deputy of Achaia, the Jews made insurrection with one accord against Paul, and brought him to the judgment seat,
27571	1036	13	Saying, This fellow persuadeth men to worship God contrary to the law.
27572	1036	14	And when Paul was now about to open his mouth, Gallio said unto the Jews, If it were a matter of wrong or wicked lewdness, O ye Jews, reason would that I should bear with you:
27573	1036	15	But if it be a question of words and names, and of your law, look ye to it; for I will be no judge of such matters.
27574	1036	16	And he drave them from the judgment seat.
27575	1036	17	Then all the Greeks took Sosthenes, the chief ruler of the synagogue, and beat him before the judgment seat. And Gallio cared for none of those things.
27576	1036	18	And Paul after this tarried there yet a good while, and then took his leave of the brethren, and sailed thence into Syria, and with him Priscilla and Aquila; having shorn his head in Cenchrea: for he had a vow.
27577	1036	19	And he came to Ephesus, and left them there: but he himself entered into the synagogue, and reasoned with the Jews.
27578	1036	20	When they desired him to tarry longer time with them, he consented not;
27579	1036	21	But bade them farewell, saying, I must by all means keep this feast that cometh in Jerusalem: but I will return again unto you, if God will. And he sailed from Ephesus.
27580	1036	22	And when he had landed at Caesarea, and gone up, and saluted the church, he went down to Antioch.
27581	1036	23	And after he had spent some time there, he departed, and went over all the country of Galatia and Phrygia in order, strengthening all the disciples.
27582	1036	24	And a certain Jew named Apollos, born at Alexandria, an eloquent man, and mighty in the scriptures, came to Ephesus.
27583	1036	25	This man was instructed in the way of the Lord; and being fervent in the spirit, he spake and taught diligently the things of the Lord, knowing only the baptism of John.
27584	1036	26	And he began to speak boldly in the synagogue: whom when Aquila and Priscilla had heard, they took him unto them, and expounded unto him the way of God more perfectly.
27585	1036	27	And when he was disposed to pass into Achaia, the brethren wrote, exhorting the disciples to receive him: who, when he was come, helped them much which had believed through grace:
27586	1036	28	For he mightily convinced the Jews, and that publickly, shewing by the scriptures that Jesus was Christ.
27587	1037	1	AND it came to pass, that, while Apollos was at Corinth, Paul having passed through the upper coasts came to Ephesus: and finding certain disciples,
27588	1037	2	He said unto them, Have ye received the Holy Ghost since ye believed? And they said unto him, We have not so much as heard whether there be any Holy Ghost.
27589	1037	3	And he said unto them, Unto what then were ye baptized? And they said, Unto John's baptism.
27590	1037	4	Then said Paul, John verily baptized with the baptism of repentance, saying unto the people, that they should believe on him which should come after him, that is, on Christ Jesus.
27591	1037	5	When they heard this, they were baptized in the name of the Lord Jesus.
27592	1037	6	And when Paul had laid his hands upon them, the Holy Ghost came on them; and they spake with tongues, and prophesied.
27593	1037	7	And all the men were about twelve.
27594	1037	8	And he went into the synagogue, and spake boldly for the space of three months, disputing and persuading the things concerning the kingdom of God.
27595	1037	9	But when divers were hardened, and believed not, but spake evil of that way before the multitude, he departed from them, and separated the disciples, disputing daily in the school of one Tyrannus.
27596	1037	10	And this continued by the space of two years; so that all they which dwelt in Asia heard the word of the Lord Jesus, both Jews and Greeks.
27597	1037	11	And God wrought special miracles by the hands of Paul:
27598	1037	12	So that from his body were brought unto the sick handkerchiefs or aprons, and the diseases departed from them, and the evil spirits went out of them.
27599	1037	13	Then certain of the vagabond Jews, exorcists, took upon them to call over them which had evil spirits the name of the Lord Jesus, saying, We adjure you by Jesus whom Paul preacheth.
27600	1037	14	And there were seven sons of one Sceva, a Jew, and chief of the priests, which did so.
27601	1037	15	And the evil spirit answered and said, Jesus I know, and Paul I know; but who are ye?
27602	1037	16	And the man in whom the evil spirit was leaped on them, and overcame them, and prevailed against them, so that they fled out of that house naked and wounded.
27603	1037	17	And this was known to all the Jews and Greeks also dwelling at Ephesus; and fear fell on them all, and the name of the Lord Jesus was magnified.
27604	1037	18	And many that believed came, and confessed, and shewed their deeds.
27605	1037	19	Many of them also which used curious arts brought their books together, and burned them before all men: and they counted the price of them, and found it fifty thousand pieces of silver.
27606	1037	20	So mightily grew the word of God and prevailed.
27607	1037	21	After these things were ended, Paul purposed in the spirit, when he had passed through Macedonia and Achaia, to go to Jerusalem, saying, After I have been there, I must also see Rome.
27608	1037	22	So he sent into Macedonia two of them that ministered unto him, Timotheus and Erastus; but he himself stayed in Asia for a season.
27609	1037	23	And the same time there arose no small stir about that way.
27610	1037	24	For a certain man named Demetrius, a silversmith, which made silver shrines for Diana, brought no small gain unto the craftsmen;
27611	1037	25	Whom he called together with the workmen of like occupation, and said, Sirs, ye know that by this craft we have our wealth.
27612	1037	26	Moreover ye see and hear, that not alone at Ephesus, but almost throughout all Asia, this Paul hath persuaded and turned away much people, saying that they be no gods, which are made with hands:
27613	1037	27	So that not only this our craft is in danger to be set at nought; but also that the temple of the great goddess Diana should be despised, and her magnificence should be destroyed, whom all Asia and the world worshippeth.
27614	1037	28	And when they heard these sayings, they were full of wrath, and cried out, saying, Great is Diana of the Ephesians.
27615	1037	29	And the whole city was filled with confusion: and having caught Gaius and Aristarchus, men of Macedonia, Paul's companions in travel, they rushed with one accord into the theatre.
27616	1037	30	And when Paul would have entered in unto the people, the disciples suffered him not.
27617	1037	31	And certain of the chief of Asia, which were his friends, sent unto him, desiring him that he would not adventure himself into the theatre.
27618	1037	32	Some therefore cried one thing, and some another: for the assembly was confused; and the more part knew not wherefore they were come together.
27619	1037	33	And they drew Alexander out of the multitude, the Jews putting him forward. And Alexander beckoned with the hand, and would have made his defence unto the people.
27620	1037	34	But when they knew that he was a Jew, all with one voice about the space of two hours cried out, Great is Diana of the Ephesians.
27621	1037	35	And when the townclerk had appeased the people, he said, Ye men of Ephesus, what man is there that knoweth not how that the city of the Ephesians is a worshipper of the great goddess Diana, and of the image which fell down from Jupiter?
27622	1037	36	Seeing then that these things cannot be spoken against, ye ought to be quiet, and to do nothing rashly.
27623	1037	37	For ye have brought hither these men, which are neither robbers of churches, nor yet blasphemers of your goddess.
27624	1037	38	Wherefore if Demetrius, and the craftsmen which are with him, have a matter against any man, the law is open, and there are deputies: let them implead one another.
27625	1037	39	But if ye enquire any thing concerning other matters, it shall be determined in a lawful assembly.
27626	1037	40	For we are in danger to be called in question for this day's uproar, there being no cause whereby we may give an account of this concourse.
27627	1037	41	And when he had thus spoken, he dismissed the assembly.
27628	1038	1	AND after the uproar was ceased, Paul called unto him the disciples, and embraced them, and departed for to go into Macedonia.
27629	1038	2	And when he had gone over those parts, and had given them much exhortation, he came into Greece,
27630	1038	3	And there abode three months. And when the Jews laid wait for him, as he was about to sail into Syria, he purposed to return through Macedonia.
27631	1038	4	And there accompanied him into Asia Sopater of Berea; and of the Thessalonians, Aristarchus and Secundus; and Gaius of Derbe, and Timotheus; and of Asia, Tychicus and Trophimus.
27632	1038	5	These going before tarried for us at Troas.
27633	1038	6	And we sailed away from Philippi after the days of unleavened bread, and came unto them to Troas in five days; where we abode seven days.
27634	1038	7	And upon the first day of the week, when the disciples came together to break bread, Paul preached unto them, ready to depart on the morrow; and continued his speech until midnight.
27635	1038	8	And there were many lights in the upper chamber, where they were gathered together.
27636	1038	9	And there sat in a window a certain young man named Eutychus, being fallen into a deep sleep: and as Paul was long preaching, he sunk down with sleep, and fell down from the third loft, and was taken up dead.
27637	1038	10	And Paul went down, and fell on him, and embracing him said, Trouble not yourselves; for his life is in him.
27638	1038	11	When he therefore was come up again, and had broken bread, and eaten, and talked a long while, even till break of day, so he departed.
27639	1038	12	And they brought the young man alive, and were not a little comforted.
27640	1038	13	And we went before to ship, and sailed unto Assos, there intending to take in Paul: for so had he appointed, minding himself to go afoot.
27641	1038	14	And when he met with us at Assos, we took him in, and came to Mitylene.
27642	1038	15	And we sailed thence, and came the next day over against Chios; and the next day we arrived at Samos, and tarried at Trogyllium; and the next day we came to Miletus.
27643	1038	16	For Paul had determined to sail by Ephesus, because he would not spend the time in Asia: for he hasted, if it were possible for him, to be at Jerusalem the day of Pentecost.
27644	1038	17	And from Miletus he sent to Ephesus, and called the elders of the church.
27645	1038	18	And when they were come to him, he said unto them, Ye know, from the first day that I came into Asia, after what manner I have been with you at all seasons,
27646	1038	19	Serving the Lord with all humility of mind, and with many tears, and temptations, which befell me by the lying in wait of the Jews:
27647	1038	20	And how I kept back nothing that was profitable unto you, but have shewed you, and have taught you publickly, and from house to house,
27648	1038	21	Testifying both to the Jews, and also to the Greeks, repentance toward God, and faith toward our Lord Jesus Christ.
27649	1038	22	And now, behold, I go bound in the spirit unto Jerusalem, not knowing the things that shall befall me there:
27650	1038	23	Save that the Holy Ghost witnesseth in every city, saying that bonds and afflictions abide me.
27651	1038	24	But none of these things move me, neither count I my life dear unto myself, so that I might finish my course with joy, and the ministry, which I have received of the Lord Jesus, to testify the gospel of the grace of God.
27652	1038	25	And now, behold, I know that ye all, among whom I have gone preaching the kingdom of God, shall see my face no more.
27653	1038	26	Wherefore I take you to record this day, that I am pure from the blood of all men.
27654	1038	27	For I have not shunned to declare unto you all the counsel of God.
27655	1038	28	Take heed therefore unto yourselves, and to all the flock, over the which the Holy Ghost hath made you overseers, to feed the church of God, which he hath purchased with his own blood.
27656	1038	29	For I know this, that after my departing shall grievous wolves enter in among you, not sparing the flock.
27657	1038	30	Also of your own selves shall men arise, speaking perverse things, to draw away disciples after them.
27658	1038	31	Therefore watch, and remember, that by the space of three years I ceased not to warn every one night and day with tears.
27659	1038	32	And now, brethren, I commend you to God, and to the word of his grace, which is able to build you up, and to give you an inheritance among all them which are sanctified.
27660	1038	33	I have coveted no man's silver, or gold, or apparel.
27661	1038	34	Yea, ye yourselves know, that these hands have ministered unto my necessities, and to them that were with me.
27662	1038	35	I have shewed you all things, how that so labouring ye ought to support the weak, and to remember the words of the Lord Jesus, how he said, It is more blessed to give than to receive.
27663	1038	36	And when he had thus spoken, he kneeled down, and prayed with them all.
27664	1038	37	And they all wept sore, and fell on Paul's neck, and kissed him,
27665	1038	38	Sorrowing most of all for the words which he spake, that they should see his face no more. And they accompanied him unto the ship.
27666	1039	1	AND it came to pass, that after we were gotten from them, and had launched, we came with a straight course unto Coos, and the day following unto Rhodes, and from thence unto Patara:
27667	1039	2	And finding a ship sailing over unto Phenicia, we went aboard, and set forth.
27668	1039	3	Now when we had discovered Cyprus, we left it on the left hand, and sailed into Syria, and landed at Tyre: for there the ship was to unlade her burden.
27669	1039	4	And finding disciples, we tarried there seven days: who said to Paul through the Spirit, that he should not go up to Jerusalem.
27670	1039	5	And when we had accomplished those days, we departed and went our way; and they all brought us on our way, with wives and children, till we were out of the city: and we kneeled down on the shore, and prayed.
27671	1039	6	And when we had taken our leave one of another, we took ship; and they returned home again.
27672	1039	7	And when we had finished our course from Tyre, we came to Ptolemais, and saluted the brethren, and abode with them one day.
27673	1039	8	And the next day we that were of Paul's company departed, and came unto Caesarea: and we entered into the house of Philip the evangelist, which was one of the seven; and abode with him.
27674	1039	9	And the same man had four daughters, virgins, which did prophesy.
27675	1039	10	And as we tarried there many days, there came down from Judaea a certain prophet, named Agabus.
27676	1039	11	And when he was come unto us, he took Paul's girdle, and bound his own hands and feet, and said, Thus saith the Holy Ghost, So shall the Jews at Jerusalem bind the man that owneth this girdle, and shall deliver him into the hands of the Gentiles.
27677	1039	12	And when we heard these things, both we, and they of that place, besought him not to go up to Jerusalem.
27678	1039	13	Then Paul answered, What mean ye to weep and to break mine heart? for I am ready not to be bound only, but also to die at Jerusalem for the name of the Lord Jesus.
27679	1039	14	And when he would not be persuaded, we ceased, saying, The will of the Lord be done.
27680	1039	15	And after those days we took up our carriages, and went up to Jerusalem.
27681	1039	16	There went with us also certain of the disciples of Caesarea, and brought with them one Mnason of Cyprus, an old disciple, with whom we should lodge.
27682	1039	17	And when we were come to Jerusalem, the brethren received us gladly.
27683	1039	18	And the day following Paul went in with us unto James; and all the elders were present.
27684	1039	19	And when he had saluted them, he declared particularly what things God had wrought among the Gentiles by his ministry.
27685	1039	20	And when they heard it, they glorified the Lord, and said unto him, Thou seest, brother, how many thousands of Jews there are which believe; and they are all zealous of the law:
27686	1039	21	And they are informed of thee, that thou teachest all the Jews which are among the Gentiles to forsake Moses, saying that they ought not to circumcise their children, neither to walk after the customs.
27687	1039	22	What is it therefore? the multitude must needs come together: for they will hear that thou art come.
27688	1039	23	Do therefore this that we say to thee: We have four men which have a vow on them;
27689	1039	24	Them take, and purify thyself with them, and be at charges with them, that they may shave their heads: and all may know that those things, whereof they were informed concerning thee, are nothing; but that thou thyself also walkest orderly, and keepest the law.
27690	1039	25	As touching the Gentiles which believe, we have written and concluded that they observe no such thing, save only that they keep themselves from things offered to idols, and from blood, and from strangled, and from fornication.
27691	1039	26	Then Paul took the men, and the next day purifying himself with them entered into the temple, to signify the accomplishment of the days of purification, until that an offering should be offered for every one of them.
27692	1039	27	And when the seven days were almost ended, the Jews which were of Asia, when they saw him in the temple, stirred up all the people, and laid hands on him,
27693	1039	28	Crying out, Men of Israel, help: This is the man, that teacheth all men every where against the people, and the law, and this place: and further brought Greeks also into the temple, and hath polluted this holy place.
27694	1039	29	(For they had seen before with him in the city Trophimus an Ephesian, whom they supposed that Paul had brought into the temple.)
27695	1039	30	And all the city was moved, and the people ran together: and they took Paul, and drew him out of the temple: and forthwith the doors were shut.
27696	1039	31	And as they went about to kill him, tidings came unto the chief captain of the band, that all Jerusalem was in an uproar.
27697	1039	32	Who immediately took soldiers and centurions, and ran down unto them: and when they saw the chief captain and the soldiers, they left beating of Paul.
27698	1039	33	Then the chief captain came near, and took him, and commanded him to be bound with two chains; and demanded who he was, and what he had done.
27699	1039	34	And some cried one thing, some another, among the multitude: and when he could not know the certainty for the tumult, he commanded him to be carried into the castle.
27700	1039	35	And when he came upon the stairs, so it was, that he was borne of the soldiers for the violence of the people.
27701	1039	36	For the multitude of the people followed after, crying, Away with him.
27702	1039	37	And as Paul was to be led into the castle, he said unto the chief captain, May I speak unto thee? Who said, Canst thou speak Greek?
27703	1039	38	Art not thou that Egyptian, which before these days madest an uproar, and leddest out into the wilderness four thousand men that were murderers?
27704	1039	39	But Paul said, I am a man which am a Jew of Tarsus, a city in Cilicia, a citizen of no mean city: and, I beseech thee, suffer me to speak unto the people.
27705	1039	40	And when he had given him licence, Paul stood on the stairs, and beckoned with the hand unto the people. And when there was made a great silence, he spake unto them in the Hebrew tongue, saying,
27706	1040	1	MEN, brethren, and fathers, hear ye my defence which I make now unto you.
27707	1040	2	(And when they heard that he spake in the Hebrew tongue to them, they kept the more silence: and he saith,)
27708	1040	3	I am verily a man which am a Jew, born in Tarsus, a city in Cilicia, yet brought up in this city at the feet of Gamaliel, and taught according to the perfect manner of the law of the fathers, and was zealous toward God, as ye all are this day.
27709	1040	4	And I persecuted this way unto the death, binding and delivering into prisons both men and women.
27710	1040	5	As also the high priest doth bear me witness, and all the estate of the elders: from whom also I received letters unto the brethren, and went to Damascus, to bring them which were there bound unto Jerusalem, for to be punished.
27711	1040	6	And it came to pass, that, as I made my journey, and was come nigh unto Damascus about noon, suddenly there shone from heaven a great light round about me.
27712	1040	7	And I fell unto the ground, and heard a voice saying unto me, Saul, Saul, why persecutest thou me?
27713	1040	8	And I answered, Who art thou, Lord? And he said unto me, I am Jesus of Nazareth, whom thou persecutest.
27714	1040	9	And they that were with me saw indeed the light, and were afraid; but they heard not the voice of him that spake to me.
27715	1040	10	And I said, What shall I do, Lord? And the Lord said unto me, Arise, and go into Damascus; and there it shall be told thee of all things which are appointed for thee to do.
27716	1040	11	And when I could not see for the glory of that light, being led by the hand of them that were with me, I came into Damascus.
27717	1040	12	And one Ananias, a devout man according to the law, having a good report of all the Jews which dwelt there,
27718	1040	13	Came unto me, and stood, and said unto me, Brother Saul, receive thy sight. And the same hour I looked up upon him.
27719	1040	14	And he said, The God of our fathers hath chosen thee, that thou shouldest know his will, and see that Just One, and shouldest hear the voice of his mouth.
27720	1040	15	For thou shalt be his witness unto all men of what thou hast seen and heard.
27721	1040	16	And now why tarriest thou? arise, and be baptized, and wash away thy sins, calling on the name of the Lord.
27722	1040	17	And it came to pass, that, when I was come again to Jerusalem, even while I prayed in the temple, I was in a trance;
27723	1040	18	And saw him saying unto me, Make haste, and get thee quickly out of Jerusalem: for they will not receive thy testimony concerning me.
27724	1040	19	And I said, Lord, they know that I imprisoned and beat in every synagogue them that believed on thee:
27725	1040	20	And when the blood of thy martyr Stephen was shed, I also was standing by, and consenting unto his death, and kept the raiment of them that slew him.
27726	1040	21	And he said unto me, Depart: for I will send thee far hence unto the Gentiles.
27727	1040	22	And they gave him audience unto this word, and then lifted up their voices, and said, Away with such a fellow from the earth: for it is not fit that he should live.
27728	1040	23	And as they cried out, and cast off their clothes, and threw dust into the air,
27729	1040	24	The chief captain commanded him to be brought into the castle, and bade that he should be examined by scourging; that he might know wherefore they cried so against him.
27730	1040	25	And as they bound him with thongs, Paul said unto the centurion that stood by, Is it lawful for you to scourge a man that is a Roman, and uncondemned?
27731	1040	26	When the centurion heard that, he went and told the chief captain, saying, Take heed what thou doest: for this man is a Roman.
27732	1040	27	Then the chief captain came, and said unto him, Tell me, art thou a Roman? He said, Yea.
27733	1040	28	And the chief captain answered, With a great sum obtained I this freedom. And Paul said, But I was free born.
27734	1040	29	Then straightway they departed from him which should have examined him: and the chief captain also was afraid, after he knew that he was a Roman, and because he had bound him.
27735	1040	30	On the morrow, because he would have known the certainty wherefore he was accused of the Jews, he loosed him from his bands, and commanded the chief priests and all their council to appear, and brought Paul down, and set him before them.
27736	1041	1	AND Paul, earnestly beholding the council, said, Men and brethren, I have lived in all good conscience before God until this day.
27737	1041	2	And the high priest Ananias commanded them that stood by him to smite him on the mouth.
27738	1041	3	Then said Paul unto him, God shall smite thee, thou whited wall: for sittest thou to judge me after the law, and commandest me to be smitten contrary to the law?
27739	1041	4	And they that stood by said, Revilest thou God's high priest?
27740	1041	5	Then said Paul, I wist not, brethren, that he was the high priest: for it is written, Thou shalt not speak evil of the ruler of thy people.
27741	1041	6	But when Paul perceived that the one part were Sadducees, and the other Pharisees, he cried out in the council, Men and brethren, I am a Pharisee, the son of a Pharisee: of the hope and resurrection of the dead I am called in question.
27742	1041	7	And when he had so said, there arose a dissension between the Pharisees and the Sadducees: and the multitude was divided.
27743	1041	8	For the Sadducees say that there is no resurrection, neither angel, nor spirit: but the Pharisees confess both.
27744	1041	9	And there arose a great cry: and the scribes that were of the Pharisees' part arose, and strove, saying, We find no evil in this man: but if a spirit or an angel hath spoken to him, let us not fight against God.
27745	1041	10	And when there arose a great dissension, the chief captain, fearing lest Paul should have been pulled in pieces of them, commanded the soldiers to go down, and to take him by force from among them, and to bring him into the castle.
27746	1041	11	And the night following the Lord stood by him, and said, Be of good cheer, Paul: for as thou hast testified of me in Jerusalem, so must thou bear witness also at Rome.
27747	1041	12	And when it was day, certain of the Jews banded together, and bound themselves under a curse, saying that they would neither eat nor drink till they had killed Paul.
27748	1041	13	And they were more than forty which had made this conspiracy.
27749	1041	14	And they came to the chief priests and elders, and said, We have bound ourselves under a great curse, that we will eat nothing until we have slain Paul.
27750	1041	15	Now therefore ye with the council signify to the chief captain that he bring him down unto you to morrow, as though ye would enquire something more perfectly concerning him: and we, or ever he come near, are ready to kill him.
27751	1041	16	And when Paul's sister's son heard of their lying in wait, he went and entered into the castle, and told Paul.
27752	1041	17	Then Paul called one of the centurions unto him, and said, Bring this young man unto the chief captain: for he hath a certain thing to tell him.
27753	1041	18	So he took him, and brought him to the chief captain, and said, Paul the prisoner called me unto him, and prayed me to bring this young man unto thee, who hath something to say unto thee.
27754	1041	19	Then the chief captain took him by the hand, and went with him aside privately, and asked him, What is that thou hast to tell me?
27755	1041	20	And he said, The Jews have agreed to desire thee that thou wouldest bring down Paul to morrow into the council, as though they would enquire somewhat of him more perfectly.
27756	1041	21	But do not thou yield unto them: for there lie in wait for him of them more than forty men, which have bound themselves with an oath, that they will neither eat nor drink till they have killed him: and now are they ready, looking for a promise from thee.
27757	1041	22	So the chief captain then let the young man depart, and charged him, See thou tell no man that thou hast shewed these things to me.
27758	1041	23	And he called unto him two centurions, saying, Make ready two hundred soldiers to go to Caesarea, and horsemen threescore and ten, and spearmen two hundred, at the third hour of the night;
27759	1041	24	And provide them beasts, that they may set Paul on, and bring him safe unto Felix the governor.
27760	1041	25	And he wrote a letter after this manner:
27761	1041	26	Claudius Lysias unto the most excellent governor Felix sendeth greeting.
27762	1041	27	This man was taken of the Jews, and should have been killed of them: then came I with an army, and rescued him, having understood that he was a Roman.
27763	1041	28	And when I would have known the cause wherefore they accused him, I brought him forth into their council:
27764	1041	29	Whom I perceived to be accused of questions of their law, but to have nothing laid to his charge worthy of death or of bonds.
27765	1041	30	And when it was told me how that the Jews laid wait for the man, I sent straightway to thee, and gave commandment to his accusers also to say before thee what they had against him. Farewell.
27766	1041	31	Then the soldiers, as it was commanded them, took Paul, and brought him by night to Antipatris.
27767	1041	32	On the morrow they left the horsemen to go with him, and returned to the castle:
27768	1041	33	Who, when they came to Caesarea, and delivered the epistle to the governor, presented Paul also before him.
27769	1041	34	And when the governor had read the letter, he asked of what province he was. And when he understood that he was of Cilicia;
27770	1041	35	I will hear thee, said he, when thine accusers are also come. And he commanded him to be kept in Herod's judgment hall.
27771	1042	1	AND after five days Ananias the high priest descended with the elders, and with a certain orator named Tertullus, who informed the governor against Paul.
27772	1042	2	And when he was called forth, Tertullus began to accuse him, saying, Seeing that by thee we enjoy great quietness, and that very worthy deeds are done unto this nation by thy providence,
27773	1042	3	We accept it always, and in all places, most noble Felix, with all thankfulness.
27774	1042	4	Notwithstanding, that I be not further tedious unto thee, I pray thee that thou wouldest hear us of thy clemency a few words.
27775	1042	5	For we have found this man a pestilent fellow, and a mover of sedition among all the Jews throughout the world, and a ringleader of the sect of the Nazarenes:
27776	1042	6	Who also hath gone about to profane the temple: whom we took, and would have judged according to our law.
27777	1042	7	But the chief captain Lysias came upon us, and with great violence took him away out of our hands,
27778	1042	8	Commanding his accusers to come unto thee: by examining of whom thyself mayest take knowledge of all these things, whereof we accuse him.
27779	1042	9	And the Jews also assented, saying that these things were so.
27780	1042	10	Then Paul, after that the governor had beckoned unto him to speak, answered, Forasmuch as I know that thou hast been of many years a judge unto this nation, I do the more cheerfully answer for myself:
27781	1042	11	Because that thou mayest understand, that there are yet but twelve days since I went up to Jerusalem for to worship.
27782	1042	12	And they neither found me in the temple disputing with any man, neither raising up the people, neither in the synagogues, nor in the city:
27783	1042	13	Neither can they prove the things whereof they now accuse me.
27784	1042	14	But this I confess unto thee, that after the way which they call heresy, so worship I the God of my fathers, believing all things which are written in the law and in the prophets:
27785	1042	15	And have hope toward God, which they themselves also allow, that there shall be a resurrection of the dead, both of the just and unjust.
27786	1042	16	And herein do I exercise myself, to have always a conscience void of offence toward God, and toward men.
27787	1042	17	Now after many years I came to bring alms to my nation, and offerings.
27788	1042	18	Whereupon certain Jews from Asia found me purified in the temple, neither with multitude, nor with tumult.
27789	1042	19	Who ought to have been here before thee, and object, if they had ought against me.
27790	1042	20	Or else let these same here say, if they have found any evil doing in me, while I stood before the council,
27791	1042	21	Except it be for this one voice, that I cried standing among them, Touching the resurrection of the dead I am called in question by you this day.
27792	1042	22	And when Felix heard these things, having more perfect knowledge of that way, he deferred them, and said, When Lysias the chief captain shall come down, I will know the uttermost of your matter.
27793	1042	23	And he commanded a centurion to keep Paul, and to let him have liberty, and that he should forbid none of his acquaintance to minister or come unto him.
27794	1042	24	And after certain days, when Felix came with his wife Drusilla, which was a Jewess, he sent for Paul, and heard him concerning the faith in Christ.
27795	1042	25	And as he reasoned of righteousness, temperance, and judgment to come, Felix trembled, and answered, Go thy way for this time; when I have a convenient season, I will call for thee.
27796	1042	26	He hoped also that money should have been given him of Paul, that he might loose him: wherefore he sent for him the oftener, and communed with him.
27797	1042	27	But after two years Porcius Festus came into Felix' room: and Felix, willing to shew the Jews a pleasure, left Paul bound.
27798	1043	1	NOW when Festus was come into the province, after three days he ascended from Caesarea to Jerusalem.
27799	1043	2	Then the high priest and the chief of the Jews informed him against Paul, and besought him,
27800	1043	3	And desired favour against him, that he would send for him to Jerusalem, laying wait in the way to kill him.
27801	1043	4	But Festus answered, that Paul should be kept at Caesarea, and that he himself would depart shortly thither.
27802	1043	5	Let them therefore, said he, which among you are able, go down with me, and accuse this man, if there be any wickedness in him.
27803	1043	6	And when he had tarried among them more than ten days, he went down unto Caesarea; and the next day sitting on the judgment seat commanded Paul to be brought.
27804	1043	7	And when he was come, the Jews which came down from Jerusalem stood round about, and laid many and grievous complaints against Paul, which they could not prove.
27805	1043	8	While he answered for himself, Neither against the law of the Jews, neither against the temple, nor yet against Caesar, have I offended any thing at all.
27806	1043	9	But Festus, willing to do the Jews a pleasure, answered Paul, and said, Wilt thou go up to Jerusalem, and there be judged of these things before me?
27807	1043	10	Then said Paul, I stand at Caesar's judgment seat, where I ought to be judged: to the Jews have I done no wrong, as thou very well knowest.
27808	1043	11	For if I be an offender, or have committed any thing worthy of death, I refuse not to die: but if there be none of these things whereof these accuse me, no man may deliver me unto them. I appeal unto Caesar.
27809	1043	12	Then Festus, when he had conferred with the council, answered, Hast thou appealed unto Caesar? unto Caesar shalt thou go.
27810	1043	13	And after certain days king Agrippa and Bernice came unto Caesarea to salute Festus.
27811	1043	14	And when they had been there many days, Festus declared Paul's cause unto the king, saying, There is a certain man left in bonds by Felix:
27812	1043	15	About whom, when I was at Jerusalem, the chief priests and the elders of the Jews informed me, desiring to have judgment against him.
27813	1043	16	To whom I answered, It is not the manner of the Romans to deliver any man to die, before that he which is accused have the accusers face to face, and have licence to answer for himself concerning the crime laid against him.
27814	1043	17	Therefore, when they were come hither, without any delay on the morrow I sat on the judgment seat, and commanded the man to be brought forth.
27815	1043	18	Against whom when the accusers stood up, they brought none accusation of such things as I supposed:
27816	1043	19	But had certain questions against him of their own superstition, and of one Jesus, which was dead, whom Paul affirmed to be alive.
27817	1043	20	And because I doubted of such manner of questions, I asked him whether he would go to Jerusalem, and there be judged of these matters.
27818	1043	21	But when Paul had appealed to be reserved unto the hearing of Augustus, I commanded him to be kept till I might send him to Caesar.
27819	1043	22	Then Agrippa said unto Festus, I would also hear the man myself. To morrow, said he, thou shalt hear him.
27820	1043	23	And on the morrow, when Agrippa was come, and Bernice, with great pomp, and was entered into the place of hearing, with the chief captains, and principal men of the city, at Festus' commandment Paul was brought forth.
27821	1043	24	And Festus said, King Agrippa, and all men which are here present with us, ye see this man, about whom all the multitude of the Jews have dealt with me, both at Jerusalem, and also here, crying that he ought not to live any longer.
27822	1043	25	But when I found that he had committed nothing worthy of death, and that he himself hath appealed to Augustus, I have determined to send him.
27823	1043	26	Of whom I have no certain thing to write unto my lord. Wherefore I have brought him forth before you, and specially before thee, O king Agrippa, that, after examination had, I might have somewhat to write.
27824	1043	27	For it seemeth to me unreasonable to send a prisoner, and not withal to signify the crimes laid against him.
27825	1044	1	THEN Agrippa said unto Paul, Thou art permitted to speak for thyself. Then Paul stretched forth the hand, and answered for himself:
27826	1044	2	I think myself happy, king Agrippa, because I shall answer for myself this day before thee touching all the things whereof I am accused of the Jews:
27827	1044	3	Especially because I know thee to be expert in all customs and questions which are among the Jews: wherefore I beseech thee to hear me patiently.
27828	1044	4	My manner of life from my youth, which was at the first among mine own nation at Jerusalem, know all the Jews;
27829	1044	5	Which knew me from the beginning, if they would testify, that after the most straitest sect of our religion I lived a Pharisee.
27830	1044	6	And now I stand and am judged for the hope of the promise made of God unto our fathers:
27831	1044	7	Unto which promise our twelve tribes, instantly serving God day and night, hope to come. For which hope's sake, king Agrippa, I am accused of the Jews.
27832	1044	8	Why should it be thought a thing incredible with you, that God should raise the dead?
27833	1044	9	I verily thought with myself, that I ought to do many things contrary to the name of Jesus of Nazareth.
27834	1044	10	Which thing I also did in Jerusalem: and many of the saints did I shut up in prison, having received authority from the chief priests; and when they were put to death, I gave my voice against them.
27835	1044	11	And I punished them oft in every synagogue, and compelled them to blaspheme; and being exceedingly mad against them, I persecuted them even unto strange cities.
27836	1044	12	Whereupon as I went to Damascus with authority and commission from the chief priests,
27837	1044	13	At midday, O king, I saw in the way a light from heaven, above the brightness of the sun, shining round about me and them which journeyed with me.
27838	1044	14	And when we were all fallen to the earth, I heard a voice speaking unto me, and saying in the Hebrew tongue, Saul, Saul, why persecutest thou me? it is hard for thee to kick against the pricks.
27839	1044	15	And I said, Who art thou, Lord? And he said, I am Jesus whom thou persecutest.
27840	1044	16	But rise, and stand upon thy feet: for I have appeared unto thee for this purpose, to make thee a minister and a witness both of these things which thou hast seen, and of those things in the which I will appear unto thee;
27841	1044	17	Delivering thee from the people, and from the Gentiles, unto whom now I send thee,
27842	1044	18	To open their eyes, and to turn them from darkness to light, and from the power of Satan unto God, that they may receive forgiveness of sins, and inheritance among them which are sanctified by faith that is in me.
27843	1044	19	Whereupon, O king Agrippa, I was not disobedient unto the heavenly vision:
27844	1044	20	But shewed first unto them of Damascus, and at Jerusalem, and throughout all the coasts of Judaea, and then to the Gentiles, that they should repent and turn to God, and do works meet for repentance.
27845	1044	21	For these causes the Jews caught me in the temple, and went about to kill me.
27846	1044	22	Having therefore obtained help of God, I continue unto this day, witnessing both to small and great, saying none other things than those which the prophets and Moses did say should come:
27847	1044	23	That Christ should suffer, and that he should be the first that should rise from the dead, and should shew light unto the people, and to the Gentiles.
27848	1044	24	And as he thus spake for himself, Festus said with a loud voice, Paul, thou art beside thyself; much learning doth make thee mad.
27849	1044	25	But he said, I am not mad, most noble Festus; but speak forth the words of truth and soberness.
27850	1044	26	For the king knoweth of these things, before whom also I speak freely: for I am persuaded that none of these things are hidden from him; for this thing was not done in a corner.
27851	1044	27	King Agrippa, believest thou the prophets? I know that thou believest.
27852	1044	28	Then Agrippa said unto Paul, Almost thou persuadest me to be a Christian.
27853	1044	29	And Paul said, I would to God, that not only thou, but also all that hear me this day, were both almost, and altogether such as I am, except these bonds.
27854	1044	30	And when he had thus spoken, the king rose up, and the governor, and Bernice, and they that sat with them:
27855	1044	31	And when they were gone aside, they talked between themselves, saying, This man doeth nothing worthy of death or of bonds.
27856	1044	32	Then said Agrippa unto Festus, This man might have been set at liberty, if he had not appealed unto Caesar.
27857	1045	1	AND when it was determined that we should sail into Italy, they delivered Paul and certain other prisoners unto one named Julius, a centurion of Augustus' band.
27858	1045	2	And entering into a ship of Adramyttium, we launched, meaning to sail by the coasts of Asia; one Aristarchus, a Macedonian of Thessalonica, being with us.
27859	1045	3	And the next day we touched at Sidon. And Julius courteously entreated Paul, and gave him liberty to go unto his friends to refresh himself.
27860	1045	4	And when we had launched from thence, we sailed under Cyprus, because the winds were contrary.
27861	1045	5	And when we had sailed over the sea of Cilicia and Pamphylia, we came to Myra, a city of Lycia.
27862	1045	6	And there the centurion found a ship of Alexandria sailing into Italy; and he put us therein.
27863	1045	7	And when we had sailed slowly many days, and scarce were come over against Cnidus, the wind not suffering us, we sailed under Crete, over against Salmone;
27864	1045	8	And, hardly passing it, came unto a place which is called The fair havens; nigh whereunto was the city of Lasea.
27865	1045	9	Now when much time was spent, and when sailing was now dangerous, because the fast was now already past, Paul admonished them,
27866	1045	10	And said unto them, Sirs, I perceive that this voyage will be with hurt and much damage, not only of the lading and ship, but also of our lives.
27867	1045	11	Nevertheless the centurion believed the master and the owner of the ship, more than those things which were spoken by Paul.
27868	1045	12	And because the haven was not commodious to winter in, the more part advised to depart thence also, if by any means they might attain to Phenice, and there to winter; which is an haven of Crete, and lieth toward the south west and north west.
27869	1045	13	And when the south wind blew softly, supposing that they had obtained their purpose, loosing thence, they sailed close by Crete.
27870	1045	14	But not long after there arose against it a tempestuous wind, called Euroclydon.
27871	1045	15	And when the ship was caught, and could not bear up into the wind, we let her drive.
27872	1045	16	And running under a certain island which is called Clauda, we had much work to come by the boat:
27873	1045	17	Which when they had taken up, they used helps, undergirding the ship; and, fearing lest they should fall into the quicksands, strake sail, and so were driven.
27874	1045	18	And we being exceedingly tossed with a tempest, the next day they lightened the ship;
27875	1045	19	And the third day we cast out with our own hands the tackling of the ship.
27876	1045	20	And when neither sun nor stars in many days appeared, and no small tempest lay on us, all hope that we should be saved was then taken away.
27877	1045	21	But after long abstinence Paul stood forth in the midst of them, and said, Sirs, ye should have hearkened unto me, and not have loosed from Crete, and to have gained this harm and loss.
27878	1045	22	And now I exhort you to be of good cheer: for there shall be no loss of any man's life among you, but of the ship.
27879	1045	23	For there stood by me this night the angel of God, whose I am, and whom I serve,
27880	1045	24	Saying, Fear not, Paul; thou must be brought before Caesar: and, lo, God hath given thee all them that sail with thee.
27881	1045	25	Wherefore, sirs, be of good cheer: for I believe God, that it shall be even as it was told me.
27882	1045	26	Howbeit we must be cast upon a certain island.
27883	1045	27	But when the fourteenth night was come, as we were driven up and down in Adria, about midnight the shipmen deemed that they drew near to some country;
27884	1045	28	And sounded, and found it twenty fathoms: and when they had gone a little further, they sounded again, and found it fifteen fathoms.
27885	1045	29	Then fearing lest we should have fallen upon rocks, they cast four anchors out of the stern, and wished for the day.
27886	1045	30	And as the shipmen were about to flee out of the ship, when they had let down the boat into the sea, under colour as though they would have cast anchors out of the foreship,
27887	1045	31	Paul said to the centurion and to the soldiers, Except these abide in the ship, ye cannot be saved.
27888	1045	32	Then the soldiers cut off the ropes of the boat, and let her fall off.
27889	1045	33	And while the day was coming on, Paul besought them all to take meat, saying, This day is the fourteenth day that ye have tarried and continued fasting, having taken nothing.
27890	1045	34	Wherefore I pray you to take some meat: for this is for your health: for there shall not an hair fall from the head of any of you.
27891	1045	35	And when he had thus spoken, he took bread, and gave thanks to God in presence of them all: and when he had broken it, he began to eat.
27892	1045	36	Then were they all of good cheer, and they also took some meat.
27893	1045	37	And we were in all in the ship two hundred threescore and sixteen souls.
27894	1045	38	And when they had eaten enough, they lightened the ship, and cast out the wheat into the sea.
27895	1045	39	And when it was day, they knew not the land: but they discovered a certain creek with a shore, into the which they were minded, if it were possible, to thrust in the ship.
27896	1045	40	And when they had taken up the anchors, they committed themselves unto the sea, and loosed the rudder bands, and hoised up the mainsail to the wind, and made toward shore.
27897	1045	41	And falling into a place where two seas met, they ran the ship aground; and the forepart stuck fast, and remained unmoveable, but the hinder part was broken with the violence of the waves.
27898	1045	42	And the soldiers' counsel was to kill the prisoners, lest any of them should swim out, and escape.
27899	1045	43	But the centurion, willing to save Paul, kept them from their purpose; and commanded that they which could swim should cast themselves first into the sea, and get to land:
27900	1045	44	And the rest, some on boards, and some on broken pieces of the ship. And so it came to pass, that they escaped all safe to land.
27901	1046	1	AND when they were escaped, then they knew that the island was called Melita.
27902	1046	2	And the barbarous people shewed us no little kindness: for they kindled a fire, and received us every one, because of the present rain, and because of the cold.
27903	1046	3	And when Paul had gathered a bundle of sticks, and laid them on the fire, there came a viper out of the heat, and fastened on his hand.
27904	1046	4	And when the barbarians saw the venomous beast hang on his hand, they said among themselves, No doubt this man is a murderer, whom, though he hath escaped the sea, yet vengeance suffereth not to live.
27905	1046	5	And he shook off the beast into the fire, and felt no harm.
27906	1046	6	Howbeit they looked when he should have swollen, or fallen down dead suddenly: but after they had looked a great while, and saw no harm come to him, they changed their minds, and said that he was a god.
27907	1046	7	In the same quarters were possessions of the chief man of the island, whose name was Publius; who received us, and lodged us three days courteously.
27908	1046	8	And it came to pass, that the father of Publius lay sick of a fever and of a bloody flux: to whom Paul entered in, and prayed, and laid his hands on him, and healed him.
27909	1046	9	So when this was done, others also, which had diseases in the island, came, and were healed:
27910	1046	10	Who also honoured us with many honours; and when we departed, they laded us with such things as were necessary.
27911	1046	11	And after three months we departed in a ship of Alexandria, which had wintered in the isle, whose sign was Castor and Pollux.
27912	1046	12	And landing at Syracuse, we tarried there three days.
27913	1046	13	And from thence we fetched a compass, and came to Rhegium: and after one day the south wind blew, and we came the next day to Puteoli:
27914	1046	14	Where we found brethren, and were desired to tarry with them seven days: and so we went toward Rome.
27915	1046	15	And from thence, when the brethren heard of us, they came to meet us as far as Appii forum, and The three taverns: whom when Paul saw, he thanked God, and took courage.
27916	1046	16	And when we came to Rome, the centurion delivered the prisoners to the captain of the guard: but Paul was suffered to dwell by himself with a soldier that kept him.
27917	1046	17	And it came to pass, that after three days Paul called the chief of the Jews together: and when they were come together, he said unto them, Men and brethren, though I have committed nothing against the people, or customs of our fathers, yet was I delivered prisoner from Jerusalem into the hands of the Romans.
27918	1046	18	Who, when they had examined me, would have let me go, because there was no cause of death in me.
27919	1046	19	But when the Jews spake against it, I was constrained to appeal unto Caesar; not that I had ought to accuse my nation of.
27920	1046	20	For this cause therefore have I called for you, to see you, and to speak with you: because that for the hope of Israel I am bound with this chain.
27921	1046	21	And they said unto him, We neither received letters out of Judaea concerning thee, neither any of the brethren that came shewed or spake any harm of thee.
27922	1046	22	But we desire to hear of thee what thou thinkest: for as concerning this sect, we know that every where it is spoken against.
27923	1046	23	And when they had appointed him a day, there came many to him into his lodging; to whom he expounded and testified the kingdom of God, persuading them concerning Jesus, both out of the law of Moses, and out of the prophets, from morning till evening.
27924	1046	24	And some believed the things which were spoken, and some believed not.
27925	1046	25	And when they agreed not among themselves, they departed, after that Paul had spoken one word, Well spake the Holy Ghost by Esaias the prophet unto our fathers,
27926	1046	26	Saying, Go unto this people, and say, Hearing ye shall hear, and shall not understand; and seeing ye shall see, and not perceive:
27927	1046	27	For the heart of this people is waxed gross, and their ears are dull of hearing, and their eyes have they closed; lest they should see with their eyes, and hear with their ears, and understand with their heart, and should be converted, and I should heal them.
27928	1046	28	Be it known therefore unto you, that the salvation of God is sent unto the Gentiles, and that they will hear it.
27929	1046	29	And when he had said these words, the Jews departed, and had great reasoning among themselves.
27930	1046	30	And Paul dwelt two whole years in his own hired house, and received all that came in unto him,
27931	1046	31	Preaching the kingdom of God, and teaching those things which concern the Lord Jesus Christ, with all confidence, no man forbidding him.
27932	1047	1	PAUL, a servant of Jesus Christ, called to be an apostle, separated unto the gospel of God,
27933	1047	2	(Which he had promised afore by his prophets in the holy scriptures,)
27934	1047	3	Concerning his Son Jesus Christ our Lord, which was made of the seed of David according to the flesh;
27935	1047	4	And declared to be the Son of God with power, according to the spirit of holiness, by the resurrection from the dead:
27936	1047	5	By whom we have received grace and apostleship, for obedience to the faith among all nations, for his name:
27937	1047	6	Among whom are ye also the called of Jesus Christ:
27938	1047	7	To all that be in Rome, beloved of God, called to be saints: Grace to you and peace from God our Father, and the Lord Jesus Christ.
27939	1047	8	First, I thank my God through Jesus Christ for you all, that your faith is spoken of throughout the whole world.
27940	1047	9	For God is my witness, whom I serve with my spirit in the gospel of his Son, that without ceasing I make mention of you always in my prayers;
27941	1047	10	Making request, if by any means now at length I might have a prosperous journey by the will of God to come unto you.
27942	1047	11	For I long to see you, that I may impart unto you some spiritual gift, to the end ye may be established;
27943	1047	12	That is, that I may be comforted together with you by the mutual faith both of you and me.
27944	1047	13	Now I would not have you ignorant, brethren, that oftentimes I purposed to come unto you, (but was let hitherto,) that I might have some fruit among you also, even as among other Gentiles.
27945	1047	14	I am debtor both to the Greeks, and to the Barbarians; both to the wise, and to the unwise.
27946	1047	15	So, as much as in me is, I am ready to preach the gospel to you that are at Rome also.
27947	1047	16	For I am not ashamed of the gospel of Christ: for it is the power of God unto salvation to every one that believeth; to the Jew first, and also to the Greek.
27948	1047	17	For therein is the righteousness of God revealed from faith to faith: as it is written, The just shall live by faith.
27949	1047	18	For the wrath of God is revealed from heaven against all ungodliness and unrighteousness of men, who hold the truth in unrighteousness;
27950	1047	19	Because that which may be known of God is manifest in them; for God hath shewed it unto them.
27951	1047	20	For the invisible things of him from the creation of the world are clearly seen, being understood by the things that are made, even his eternal power and Godhead; so that they are without excuse:
27952	1047	21	Because that, when they knew God, they glorified him not as God, neither were thankful; but became vain in their imaginations, and their foolish heart was darkened.
27953	1047	22	Professing themselves to be wise, they became fools,
27954	1047	23	And changed the glory of the uncorruptible God into an image made like to corruptible man, and to birds, and fourfooted beasts, and creeping things.
27955	1047	24	Wherefore God also gave them up to uncleanness through the lusts of their own hearts, to dishonour their own bodies between themselves:
27956	1047	25	Who changed the truth of God into a lie, and worshipped and served the creature more than the Creator, who is blessed for ever. Amen.
27957	1047	26	For this cause God gave them up unto vile affections: for even their women did change the natural use into that which is against nature:
27958	1047	27	And likewise also the men, leaving the natural use of the woman, burned in their lust one toward another; men with men working that which is unseemly, and receiving in themselves that recompence of their error which was meet.
27959	1047	28	And even as they did not like to retain God in their knowledge, God gave them over to a reprobate mind, to do those things which are not convenient;
27960	1047	29	Being filled with all unrighteousness, fornication, wickedness, covetousness, maliciousness; full of envy, murder, debate, deceit, malignity; whisperers,
27961	1047	30	Backbiters, haters of God, despiteful, proud, boasters, inventors of evil things, disobedient to parents,
27962	1047	31	Without understanding, covenantbreakers, without natural affection, implacable, unmerciful:
27963	1047	32	Who knowing the judgment of God, that they which commit such things are worthy of death, not only do the same, but have pleasure in them that do them.
27964	1048	1	THEREFORE thou art inexcusable, O man, whosoever thou art that judgest: for wherein thou judgest another, thou condemnest thyself; for thou that judgest doest the same things.
27965	1048	2	But we are sure that the judgment of God is according to truth against them which commit such things.
27966	1048	3	And thinkest thou this, O man, that judgest them which do such things, and doest the same, that thou shalt escape the judgment of God?
27967	1048	4	Or despisest thou the riches of his goodness and forbearance and longsuffering; not knowing that the goodness of God leadeth thee to repentance?
27968	1048	5	But after thy hardness and impenitent heart treasurest up unto thyself wrath against the day of wrath and revelation of the righteous judgment of God;
27969	1048	6	Who will render to every man according to his deeds:
27970	1048	7	To them who by patient continuance in well doing seek for glory and honour and immortality, eternal life:
27971	1048	8	But unto them that are contentious, and do not obey the truth, but obey unrighteousness, indignation and wrath,
27972	1048	9	Tribulation and anguish, upon every soul of man that doeth evil, of the Jew first, and also of the Gentile;
27973	1048	10	But glory, honour, and peace, to every man that worketh good, to the Jew first, and also to the Gentile:
27974	1048	11	For there is no respect of persons with God.
27975	1048	12	For as many as have sinned without law shall also perish without law: and as many as have sinned in the law shall be judged by the law;
27976	1048	13	(For not the hearers of the law are just before God, but the doers of the law shall be justified.
27977	1048	14	For when the Gentiles, which have not the law, do by nature the things contained in the law, these, having not the law, are a law unto themselves:
27978	1048	15	Which shew the work of the law written in their hearts, their conscience also bearing witness, and their thoughts the mean while accusing or else excusing one another;)
27979	1048	16	In the day when God shall judge the secrets of men by Jesus Christ according to my gospel.
27980	1048	17	Behold, thou art called a Jew, and restest in the law, and makest thy boast of God,
27981	1048	18	And knowest his will, and approvest the things that are more excellent, being instructed out of the law;
27982	1048	19	And art confident that thou thyself art a guide of the blind, a light of them which are in darkness,
27983	1048	20	An instructor of the foolish, a teacher of babes, which hast the form of knowledge and of the truth in the law.
27984	1048	21	Thou therefore which teachest another, teachest thou not thyself? thou that preachest a man should not steal, dost thou steal?
27985	1048	22	Thou that sayest a man should not commit adultery, dost thou commit adultery? thou that abhorrest idols, dost thou commit sacrilege?
27986	1048	23	Thou that makest thy boast of the law, through breaking the law dishonourest thou God?
27987	1048	24	For the name of God is blasphemed among the Gentiles through you, as it is written.
27988	1048	25	For circumcision verily profiteth, if thou keep the law: but if thou be a breaker of the law, thy circumcision is made uncircumcision.
27989	1048	26	Therefore if the uncircumcision keep the righteousness of the law, shall not his uncircumcision be counted for circumcision?
27990	1048	27	And shall not uncircumcision which is by nature, if it fulfil the law, judge thee, who by the letter and circumcision dost transgress the law?
27991	1048	28	For he is not a Jew, which is one outwardly; neither is that circumcision, which is outward in the flesh:
27992	1048	29	But he is a Jew, which is one inwardly; and circumcision is that of the heart, in the spirit, and not in the letter; whose praise is not of men, but of God.
27993	1049	1	WHAT advantage then hath the Jew? or what profit is there of circumcision?
27994	1049	2	Much every way: chiefly, because that unto them were committed the oracles of God.
27995	1049	3	For what if some did not believe? shall their unbelief make the faith of God without effect?
27996	1049	4	God forbid: yea, let God be true, but every man a liar; as it is written, That thou mightest be justified in thy sayings, and mightest overcome when thou art judged.
27997	1049	5	But if our unrighteousness commend the righteousness of God, what shall we say? Is God unrighteous who taketh vengeance? (I speak as a man)
27998	1049	6	God forbid: for then how shall God judge the world?
27999	1049	7	For if the truth of God hath more abounded through my lie unto his glory; why yet am I also judged as a sinner?
28000	1049	8	And not rather, (as we be slanderously reported, and as some affirm that we say,) Let us do evil, that good may come? whose damnation is just.
28001	1049	9	What then? are we better than they? No, in no wise: for we have before proved both Jews and Gentiles, that they are all under sin;
28002	1049	10	As it is written, There is none righteous, no, not one:
28003	1049	11	There is none that understandeth, there is none that seeketh after God.
28004	1049	12	They are all gone out of the way, they are together become unprofitable; there is none that doeth good, no, not one.
28005	1049	13	Their throat is an open sepulchre; with their tongues they have used deceit; the poison of asps is under their lips:
28006	1049	14	Whose mouth is full of cursing and bitterness:
28007	1049	15	Their feet are swift to shed blood:
28008	1049	16	Destruction and misery are in their ways:
28009	1049	17	And the way of peace have they not known:
28010	1049	18	There is no fear of God before their eyes.
28011	1049	19	Now we know that what things soever the law saith, it saith to them who are under the law: that every mouth may be stopped, and all the world may become guilty before God.
28012	1049	20	Therefore by the deeds of the law there shall no flesh be justified in his sight: for by the law is the knowledge of sin.
28013	1049	21	But now the righteousness of God without the law is manifested, being witnessed by the law and the prophets;
28014	1049	22	Even the righteousness of God which is by faith of Jesus Christ unto all and upon all them that believe: for there is no difference:
28015	1049	23	For all have sinned, and come short of the glory of God;
28016	1049	24	Being justified freely by his grace through the redemption that is in Christ Jesus:
28017	1049	25	Whom God hath set forth to be a propitiation through faith in his blood, to declare his righteousness for the remission of sins that are past, through the forbearance of God;
28018	1049	26	To declare, I say, at this time his righteousness: that he might be just, and the justifier of him which believeth in Jesus.
28019	1049	27	Where is boasting then? It is excluded. By what law? of works? Nay: but by the law of faith.
28020	1049	28	Therefore we conclude that a man is justified by faith without the deeds of the law.
28021	1049	29	Is he the God of the Jews only? is he not also of the Gentiles? Yes, of the Gentiles also:
28022	1049	30	Seeing it is one God, which shall justify the circumcision by faith, and uncircumcision through faith.
28023	1049	31	Do we then make void the law through faith? God forbid: yea, we establish the law.
28024	1050	1	WHAT shall we say then that Abraham our father, as pertaining to the flesh, hath found?
28025	1050	2	For if Abraham were justified by works, he hath whereof to glory; but not before God.
28026	1050	3	For what saith the scripture? Abraham believed God, and it was counted unto him for righteousness.
28027	1050	4	Now to him that worketh is the reward not reckoned of grace, but of debt.
28028	1050	5	But to him that worketh not, but believeth on him that justifieth the ungodly, his faith is counted for righteousness.
28029	1050	6	Even as David also describeth the blessedness of the man, unto whom God imputeth righteousness without works,
28030	1050	7	Saying, Blessed are they whose iniquities are forgiven, and whose sins are covered.
28031	1050	8	Blessed is the man to whom the Lord will not impute sin.
28032	1050	9	Cometh this blessedness then upon the circumcision only, or upon the uncircumcision also? for we say that faith was reckoned to Abraham for righteousness.
28033	1050	10	How was it then reckoned? when he was in circumcision, or in uncircumcision? Not in circumcision, but in uncircumcision.
28034	1050	11	And he received the sign of circumcision, a seal of the righteousness of the faith which he had yet being uncircumcised: that he might be the father of all them that believe, though they be not circumcised; that righteousness might be imputed unto them also:
28035	1050	12	And the father of circumcision to them who are not of the circumcision only, but who also walk in the steps of that faith of our father Abraham, which he had being yet uncircumcised.
28036	1050	13	For the promise, that he should be the heir of the world, was not to Abraham, or to his seed, through the law, but through the righteousness of faith.
28037	1050	14	For if they which are of the law be heirs, faith is made void, and the promise made of none effect:
28038	1050	15	Because the law worketh wrath: for where no law is, there is no transgression.
28039	1050	16	Therefore it is of faith, that it might be by grace; to the end the promise might be sure to all the seed; not to that only which is of the law, but to that also which is of the faith of Abraham; who is the father of us all,
28040	1050	17	(As it is written, I have made thee a father of many nations,) before him whom he believed, even God, who quickeneth the dead, and calleth those things which be not as though they were.
28041	1050	18	Who against hope believed in hope, that he might become the father of many nations, according to that which was spoken, So shall thy seed be.
28042	1050	19	And being not weak in faith, he considered not his own body now dead, when he was about an hundred years old, neither yet the deadness of Sara's womb:
28043	1050	20	He staggered not at the promise of God through unbelief; but was strong in faith, giving glory to God;
28044	1050	21	And being fully persuaded that, what he had promised, he was able also to perform.
28045	1050	22	And therefore it was imputed to him for righteousness.
28046	1050	23	Now it was not written for his sake alone, that it was imputed to him;
28047	1050	24	But for us also, to whom it shall be imputed, if we believe on him that raised up Jesus our Lord from the dead;
28048	1050	25	Who was delivered for our offences, and was raised again for our justification.
28049	1051	1	THEREFORE being justified by faith, we have peace with God through our Lord Jesus Christ:
28050	1051	2	By whom also we have access by faith into this grace wherein we stand, and rejoice in hope of the glory of God.
28051	1051	3	And not only so, but we glory in tribulations also: knowing that tribulation worketh patience;
28052	1051	4	And patience, experience; and experience, hope:
28053	1051	5	And hope maketh not ashamed; because the love of God is shed abroad in our hearts by the Holy Ghost which is given unto us.
28054	1051	6	For when we were yet without strength, in due time Christ died for the ungodly.
28055	1051	7	For scarcely for a righteous man will one die: yet peradventure for a good man some would even dare to die.
28056	1051	8	But God commendeth his love toward us, in that, while we were yet sinners, Christ died for us.
28057	1051	9	Much more then, being now justified by his blood, we shall be saved from wrath through him.
28058	1051	10	For if, when we were enemies, we were reconciled to God by the death of his Son, much more, being reconciled, we shall be saved by his life.
28059	1051	11	And not only so, but we also joy in God through our Lord Jesus Christ, by whom we have now received the atonement.
28060	1051	12	Wherefore, as by one man sin entered into the world, and death by sin; and so death passed upon all men, for that all have sinned:
28061	1051	13	(For until the law sin was in the world: but sin is not imputed when there is no law.
28062	1051	14	Nevertheless death reigned from Adam to Moses, even over them that had not sinned after the similitude of Adam's transgression, who is the figure of him that was to come.
28063	1051	15	But not as the offence, so also is the free gift. For if through the offence of one many be dead, much more the grace of God, and the gift by grace, which is by one man, Jesus Christ, hath abounded unto many.
28064	1051	16	And not as it was by one that sinned, so is the gift: for the judgment was by one to condemnation, but the free gift is of many offences unto justification.
28065	1051	17	For if by one man's offence death reigned by one; much more they which receive abundance of grace and of the gift of righteousness shall reign in life by one, Jesus Christ.)
28066	1051	18	Therefore as by the offence of one judgment came upon all men to condemnation; even so by the righteousness of one the free gift came upon all men unto justification of life.
28067	1051	19	For as by one man's disobedience many were made sinners, so by the obedience of one shall many be made righteous.
28068	1051	20	Moreover the law entered, that the offence might abound. But where sin abounded, grace did much more abound:
28069	1051	21	That as sin hath reigned unto death, even so might grace reign through righteousness unto eternal life by Jesus Christ our Lord.
28070	1052	1	WHAT shall we say then? Shall we continue in sin, that grace may abound?
28071	1052	2	God forbid. How shall we, that are dead to sin, live any longer therein?
28072	1052	3	Know ye not, that so many of us as were baptized into Jesus Christ were baptized into his death?
28073	1052	4	Therefore we are buried with him by baptism into death: that like as Christ was raised up from the dead by the glory of the Father, even so we also should walk in newness of life.
28074	1052	5	For if we have been planted together in the likeness of his death, we shall be also in the likeness of his resurrection:
28075	1052	6	Knowing this, that our old man is crucified with him, that the body of sin might be destroyed, that henceforth we should not serve sin.
28076	1052	7	For he that is dead is freed from sin.
28077	1052	8	Now if we be dead with Christ, we believe that we shall also live with him:
28078	1052	9	Knowing that Christ being raised from the dead dieth no more; death hath no more dominion over him.
28079	1052	10	For in that he died, he died unto sin once: but in that he liveth, he liveth unto God.
28080	1052	11	Likewise reckon ye also yourselves to be dead indeed unto sin, but alive unto God through Jesus Christ our Lord.
28081	1052	12	Let not sin therefore reign in your mortal body, that ye should obey it in the lusts thereof.
28082	1052	13	Neither yield ye your members as instruments of unrighteousness unto sin: but yield yourselves unto God, as those that are alive from the dead, and your members as instruments of righteousness unto God.
28083	1052	14	For sin shall not have dominion over you: for ye are not under the law, but under grace.
28084	1052	15	What then? shall we sin, because we are not under the law, but under grace? God forbid.
28085	1052	16	Know ye not, that to whom ye yield yourselves servants to obey, his servants ye are to whom ye obey; whether of sin unto death, or of obedience unto righteousness?
28086	1052	17	But God be thanked, that ye were the servants of sin, but ye have obeyed from the heart that form of doctrine which was delivered you.
28087	1052	18	Being then made free from sin, ye became the servants of righteousness.
28088	1052	19	I speak after the manner of men because of the infirmity of your flesh: for as ye have yielded your members servants to uncleanness and to iniquity unto iniquity; even so now yield your members servants to righteousness unto holiness.
28089	1052	20	For when ye were the servants of sin, ye were free from righteousness.
28090	1052	21	What fruit had ye then in those things whereof ye are now ashamed? for the end of those things is death.
28091	1052	22	But now being made free from sin, and become servants to God, ye have your fruit unto holiness, and the end everlasting life.
28092	1052	23	For the wages of sin is death; but the gift of God is eternal life through Jesus Christ our Lord.
28093	1053	1	KNOW ye not, brethren, (for I speak to them that know the law,) how that the law hath dominion over a man as long as he liveth?
28094	1053	2	For the woman which hath an husband is bound by the law to her husband so long as he liveth; but if the husband be dead, she is loosed from the law of her husband.
28095	1053	3	So then if, while her husband liveth, she be married to another man, she shall be called an adulteress: but if her husband be dead, she is free from that law; so that she is no adulteress, though she be married to another man.
28096	1053	4	Wherefore, my brethren, ye also are become dead to the law by the body of Christ; that ye should be married to another, even to him who is raised from the dead, that we should bring forth fruit unto God.
28097	1053	5	For when we were in the flesh, the motions of sins, which were by the law, did work in our members to bring forth fruit unto death.
28098	1053	6	But now we are delivered from the law, that being dead wherein we were held; that we should serve in newness of spirit, and not in the oldness of the letter.
28099	1053	7	What shall we say then? Is the law sin? God forbid. Nay, I had not known sin, but by the law: for I had not known lust, except the law had said, Thou shalt not covet.
28100	1053	8	But sin, taking occasion by the commandment, wrought in me all manner of concupiscence. For without the law sin was dead.
28101	1053	9	For I was alive without the law once: but when the commandment came, sin revived, and I died.
28102	1053	10	And the commandment, which was ordained to life, I found to be unto death.
28103	1053	11	For sin, taking occasion by the commandment, deceived me, and by it slew me.
28104	1053	12	Wherefore the law is holy, and the commandment holy, and just, and good.
28105	1053	13	Was then that which is good made death unto me? God forbid. But sin, that it might appear sin, working death in me by that which is good; that sin by the commandment might become exceeding sinful.
28106	1053	14	For we know that the law is spiritual: but I am carnal, sold under sin.
28107	1053	15	For that which I do I allow not: for what I would, that do I not; but what I hate, that do I.
28108	1053	16	If then I do that which I would not, I consent unto the law that it is good.
28109	1053	17	Now then it is no more I that do it, but sin that dwelleth in me.
28110	1053	18	For I know that in me (that is, in my flesh,) dwelleth no good thing: for to will is present with me; but how to perform that which is good I find not.
28111	1053	19	For the good that I would I do not: but the evil which I would not, that I do.
28112	1053	20	Now if I do that I would not, it is no more I that do it, but sin that dwelleth in me.
28113	1053	21	I find then a law, that, when I would do good, evil is present with me.
28114	1053	22	For I delight in the law of God after the inward man:
28115	1053	23	But I see another law in my members, warring against the law of my mind, and bringing me into captivity to the law of sin which is in my members.
28116	1053	24	O wretched man that I am! who shall deliver me from the body of this death?
28117	1053	25	I thank God through Jesus Christ our Lord. So then with the mind I myself serve the law of God; but with the flesh the law of sin.
28118	1054	1	THERE is therefore now no condemnation to them which are in Christ Jesus, who walk not after the flesh, but after the Spirit.
28119	1054	2	For the law of the Spirit of life in Christ Jesus hath made me free from the law of sin and death.
28120	1054	3	For what the law could not do, in that it was weak through the flesh, God sending his own Son in the likeness of sinful flesh, and for sin, condemned sin in the flesh:
28121	1054	4	That the righteousness of the law might be fulfilled in us, who walk not after the flesh, but after the Spirit.
28122	1054	5	For they that are after the flesh do mind the things of the flesh; but they that are after the Spirit the things of the Spirit.
28123	1054	6	For to be carnally minded is death; but to be spiritually minded is life and peace.
28124	1054	7	Because the carnal mind is enmity against God: for it is not subject to the law of God, neither indeed can be.
28125	1054	8	So then they that are in the flesh cannot please God.
28126	1054	9	But ye are not in the flesh, but in the Spirit, if so be that the Spirit of God dwell in you. Now if any man have not the Spirit of Christ, he is none of his.
28127	1054	10	And if Christ be in you, the body is dead because of sin; but the Spirit is life because of righteousness.
28128	1054	11	But if the Spirit of him that raised up Jesus from the dead dwell in you, he that raised up Christ from the dead shall also quicken your mortal bodies by his Spirit that dwelleth in you.
28129	1054	12	Therefore, brethren, we are debtors, not to the flesh, to live after the flesh.
28130	1054	13	For if ye live after the flesh, ye shall die: but if ye through the Spirit do mortify the deeds of the body, ye shall live.
28131	1054	14	For as many as are led by the Spirit of God, they are the sons of God.
28132	1054	15	For ye have not received the spirit of bondage again to fear; but ye have received the Spirit of adoption, whereby we cry, Abba, Father.
28133	1054	16	The Spirit itself beareth witness with our spirit, that we are the children of God:
28134	1054	17	And if children, then heirs; heirs of God, and joint-heirs with Christ; if so be that we suffer with him, that we may be also glorified together.
28135	1054	18	For I reckon that the sufferings of this present time are not worthy to be compared with the glory which shall be revealed in us.
28136	1054	19	For the earnest expectation of the creature waiteth for the manifestation of the sons of God.
28137	1054	20	For the creature was made subject to vanity, not willingly, but by reason of him who hath subjected the same in hope,
28138	1054	21	Because the creature itself also shall be delivered from the bondage of corruption into the glorious liberty of the children of God.
28139	1054	22	For we know that the whole creation groaneth and travaileth in pain together until now.
28140	1054	23	And not only they, but ourselves also, which have the firstfruits of the Spirit, even we ourselves groan within ourselves, waiting for the adoption, to wit, the redemption of our body.
28141	1054	24	For we are saved by hope: but hope that is seen is not hope: for what a man seeth, why doth he yet hope for?
28142	1054	25	But if we hope for that we see not, then do we with patience wait for it.
28143	1054	26	Likewise the Spirit also helpeth our infirmities: for we know not what we should pray for as we ought: but the Spirit itself maketh intercession for us with groanings which cannot be uttered.
28144	1054	27	And he that searcheth the hearts knoweth what is the mind of the Spirit, because he maketh intercession for the saints according to the will of God.
28145	1054	28	And we know that all things work together for good to them that love God, to them who are the called according to his purpose.
28146	1054	29	For whom he did foreknow, he also did predestinate to be conformed to the image of his Son, that he might be the firstborn among many brethren.
28147	1054	30	Moreover whom he did predestinate, them he also called: and whom he called, them he also justified: and whom he justified, them he also glorified.
28148	1054	31	What shall we then say to these things? If God be for us, who can be against us?
28149	1054	32	He that spared not his own Son, but delivered him up for us all, how shall he not with him also freely give us all things?
28150	1054	33	Who shall lay any thing to the charge of God's elect? It is God that justifieth.
28151	1054	34	Who is he that condemneth? It is Christ that died, yea rather, that is risen again, who is even at the right hand of God, who also maketh intercession for us.
28152	1054	35	Who shall separate us from the love of Christ? shall tribulation, or distress, or persecution, or famine, or nakedness, or peril, or sword?
28153	1054	36	As it is written, For thy sake we are killed all the day long; we are accounted as sheep for the slaughter.
28154	1054	37	Nay, in all these things we are more than conquerors through him that loved us.
28155	1054	38	For I am persuaded, that neither death, nor life, nor angels, nor principalities, nor powers, nor things present, nor things to come,
28156	1054	39	Nor height, nor depth, nor any other creature, shall be able to separate us from the love of God, which is in Christ Jesus our Lord.
28157	1055	1	I SAY the truth in Christ, I lie not, my conscience also bearing me witness in the Holy Ghost,
28158	1055	2	That I have great heaviness and continual sorrow in my heart.
28159	1055	3	For I could wish that myself were accursed from Christ for my brethren, my kinsmen according to the flesh:
28160	1055	4	Who are Israelites; to whom pertaineth the adoption, and the glory, and the covenants, and the giving of the law, and the service of God, and the promises;
28161	1055	5	Whose are the fathers, and of whom as concerning the flesh Christ came, who is over all, God blessed for ever. Amen.
28162	1055	6	Not as though the word of God hath taken none effect. For they are not all Israel, which are of Israel:
28163	1055	7	Neither, because they are the seed of Abraham, are they all children: but, In Isaac shall thy seed be called.
28164	1055	8	That is, They which are the children of the flesh, these are not the children of God: but the children of the promise are counted for the seed.
28165	1055	9	For this is the word of promise, At this time will I come, and Sara shall have a son.
28166	1055	10	And not only this; but when Rebecca also had conceived by one, even by our father Isaac;
28167	1055	11	(For the children being not yet born, neither having done any good or evil, that the purpose of God according to election might stand, not of works, but of him that calleth;)
28168	1055	12	It was said unto her, The elder shall serve the younger.
28169	1055	13	As it is written, Jacob have I loved, but Esau have I hated.
28170	1055	14	What shall we say then? Is there unrighteousness with God? God forbid.
28171	1055	15	For he saith to Moses, I will have mercy on whom I will have mercy, and I will have compassion on whom I will have compassion.
28172	1055	16	So then it is not of him that willeth, nor of him that runneth, but of God that sheweth mercy.
28173	1055	17	For the scripture saith unto Pharaoh, Even for this same purpose have I raised thee up, that I might shew my power in thee, and that my name might be declared throughout all the earth.
28174	1055	18	Therefore hath he mercy on whom he will have mercy, and whom he will he hardeneth.
28175	1055	19	Thou wilt say then unto me, Why doth he yet find fault? For who hath resisted his will?
28176	1055	20	Nay but, O man, who art thou that repliest against God? Shall the thing formed say to him that formed it, Why hast thou made me thus?
28177	1055	21	Hath not the potter power over the clay, of the same lump to make one vessel unto honour, and another unto dishonour?
28178	1055	22	What if God, willing to shew his wrath, and to make his power known, endured with much longsuffering the vessels of wrath fitted to destruction:
28179	1055	23	And that he might make known the riches of his glory on the vessels of mercy, which he had afore prepared unto glory,
28180	1055	24	Even us, whom he hath called, not of the Jews only, but also of the Gentiles?
28181	1055	25	As he saith also in Osee, I will call them my people, which were not my people; and her beloved, which was not beloved.
28182	1055	26	And it shall come to pass, that in the place where it was said unto them, Ye are not my people; there shall they be called the children of the living God.
28183	1055	27	Esaias also crieth concerning Israel, Though the number of the children of Israel be as the sand of the sea, a remnant shall be saved:
28184	1055	28	For he will finish the work, and cut it short in righteousness: because a short work will the Lord make upon the earth.
28185	1055	29	And as Esaias said before, Except the Lord of Sabaoth had left us a seed, we had been as Sodoma, and been made like unto Gomorrha.
28186	1055	30	What shall we say then? That the Gentiles, which followed not after righteousness, have attained to righteousness, even the righteousness which is of faith.
28187	1055	31	But Israel, which followed after the law of righteousness, hath not attained to the law of righteousness.
28188	1055	32	Wherefore? Because they sought it not by faith, but as it were by the works of the law. For they stumbled at that stumblingstone;
28189	1055	33	As it is written, Behold, I lay in Sion a stumblingstone and rock of offence: and whosoever believeth on him shall not be ashamed.
28190	1056	1	BRETHREN, my heart's desire and prayer to God for Israel is, that they might be saved.
28191	1056	2	For I bear them record that they have a zeal of God, but not according to knowledge.
28192	1056	3	For they being ignorant of God's righteousness, and going about to establish their own righteousness, have not submitted themselves unto the righteousness of God.
28193	1056	4	For Christ is the end of the law for righteousness to every one that believeth.
28194	1056	5	For Moses describeth the righteousness which is of the law, That the man which doeth those things shall live by them.
28195	1056	6	But the righteousness which is of faith speaketh on this wise, Say not in thine heart, Who shall ascend into heaven? (that is, to bring Christ down from above:)
28196	1056	7	Or, Who shall descend into the deep? (that is, to bring up Christ again from the dead.)
28197	1056	8	But what saith it? The word is nigh thee, even in thy mouth, and in thy heart: that is, the word of faith, which we preach;
28198	1056	9	That if thou shalt confess with thy mouth the Lord Jesus, and shalt believe in thine heart that God hath raised him from the dead, thou shalt be saved.
28199	1056	10	For with the heart man believeth unto righteousness; and with the mouth confession is made unto salvation.
28200	1056	11	For the scripture saith, Whosoever believeth on him shall not be ashamed.
28201	1056	12	For there is no difference between the Jew and the Greek: for the same Lord over all is rich unto all that call upon him.
28202	1056	13	For whosoever shall call upon the name of the Lord shall be saved.
28203	1056	14	How then shall they call on him in whom they have not believed? and how shall they believe in him of whom they have not heard? and how shall they hear without a preacher?
28204	1056	15	And how shall they preach, except they be sent? as it is written, How beautiful are the feet of them that preach the gospel of peace, and bring glad tidings of good things!
28205	1056	16	But they have not all obeyed the gospel. For Esaias saith, Lord, who hath believed our report?
28206	1056	17	So then faith cometh by hearing, and hearing by the word of God.
28207	1056	18	But I say, Have they not heard? Yes verily, their sound went into all the earth, and their words unto the ends of the world.
28208	1056	19	But I say, Did not Israel know? First Moses saith, I will provoke you to jealousy by them that are no people, and by a foolish nation I will anger you.
28209	1056	20	But Esaias is very bold, and saith, I was found of them that sought me not; I was made manifest unto them that asked not after me.
28210	1056	21	But to Israel he saith, All day long I have stretched forth my hands unto a disobedient and gainsaying people.
28211	1057	1	I SAY then, Hath God cast away his people? God forbid. For I also am an Israelite, of the seed of Abraham, of the tribe of Benjamin.
28212	1057	2	God hath not cast away his people which he foreknew. Wot ye not what the scripture saith of Elias? how he maketh intercession to God against Israel, saying,
28213	1057	3	Lord, they have killed thy prophets, and digged down thine altars; and I am left alone, and they seek my life.
28214	1057	4	But what saith the answer of God unto him? I have reserved to myself seven thousand men, who have not bowed the knee to the image of Baal.
28215	1057	5	Even so then at this present time also there is a remnant according to the election of grace.
28216	1057	6	And if by grace, then is it no more of works: otherwise grace is no more grace. But if it be of works, then is it no more grace: otherwise work is no more work.
28217	1057	7	What then? Israel hath not obtained that which he seeketh for; but the election hath obtained it, and the rest were blinded
28218	1057	8	(According as it is written, God hath given them the spirit of slumber, eyes that they should not see, and ears that they should not hear;) unto this day.
28219	1057	9	And David saith, Let their table be made a snare, and a trap, and a stumbling block, and a recompence unto them:
28220	1057	10	Let their eyes be darkened, that they may not see, and bow down their back alway.
28221	1057	11	I say then, Have they stumbled that they should fall? God forbid: but rather through their fall salvation is come unto the Gentiles, for to provoke them to jealousy.
28222	1057	12	Now if the fall of them be the riches of the world, and the diminishing of them the riches of the Gentiles; how much more their fulness?
28223	1057	13	For I speak to you Gentiles, inasmuch as I am the apostle of the Gentiles, I magnify mine office:
28224	1057	14	If by any means I may provoke to emulation them which are my flesh, and might save some of them.
28225	1057	15	For if the casting away of them be the reconciling of the world, what shall the receiving of them be, but life from the dead?
28226	1057	16	For if the firstfruit be holy, the lump is also holy: and if the root be holy, so are the branches.
28227	1057	17	And if some of the branches be broken off, and thou, being a wild olive tree, wert graffed in among them, and with them partakest of the root and fatness of the olive tree;
28228	1057	18	Boast not against the branches. But if thou boast, thou bearest not the root, but the root thee.
28229	1057	19	Thou wilt say then, The branches were broken off, that I might be graffed in.
28230	1057	20	Well; because of unbelief they were broken off, and thou standest by faith. Be not highminded, but fear:
28231	1057	21	For if God spared not the natural branches, take heed lest he also spare not thee.
28232	1057	22	Behold therefore the goodness and severity of God: on them which fell, severity; but toward thee, goodness, if thou continue in his goodness: otherwise thou also shalt be cut off.
28233	1057	23	And they also, if they abide not still in unbelief, shall be graffed in: for God is able to graff them in again.
28234	1057	24	For if thou wert cut out of the olive tree which is wild by nature, and wert graffed contrary to nature into a good olive tree: how much more shall these, which be the natural branches, be graffed into their own olive tree?
28235	1057	25	For I would not, brethren, that ye should be ignorant of this mystery, lest ye should be wise in your own conceits; that blindness in part is happened to Israel, until the fulness of the Gentiles be come in.
28236	1057	26	And so all Israel shall be saved: as it is written, There shall come out of Sion the Deliverer, and shall turn away ungodliness from Jacob:
28237	1057	27	For this is my covenant unto them, when I shall take away their sins.
28238	1057	28	As concerning the gospel, they are enemies for your sakes: but as touching the election, they are beloved for the fathers' sakes.
28239	1057	29	For the gifts and calling of God are without repentance.
28240	1057	30	For as ye in times past have not believed God, yet have now obtained mercy through their unbelief:
28241	1057	31	Even so have these also now not believed, that through your mercy they also may obtain mercy.
28242	1057	32	For God hath concluded them all in unbelief, that he might have mercy upon all.
28243	1057	33	O the depth of the riches both of the wisdom and knowledge of God! how unsearchable are his judgments, and his ways past finding out!
28244	1057	34	For who hath known the mind of the Lord? or who hath been his counsellor?
28245	1057	35	Or who hath first given to him, and it shall be recompensed unto him again?
28246	1057	36	For of him, and through him, and to him, are all things: to whom be glory for ever. Amen.
28247	1058	1	I BESEECH you therefore, brethren, by the mercies of God, that ye present your bodies a living sacrifice, holy, acceptable unto God, which is your reasonable service.
28248	1058	2	And be not conformed to this world: but be ye transformed by the renewing of your mind, that ye may prove what is that good, and acceptable, and perfect, will of God.
28249	1058	3	For I say, through the grace given unto me, to every man that is among you, not to think of himself more highly than he ought to think; but to think soberly, according as God hath dealt to every man the measure of faith.
28250	1058	4	For as we have many members in one body, and all members have not the same office:
28251	1058	5	So we, being many, are one body in Christ, and every one members one of another.
28252	1058	6	Having then gifts differing according to the grace that is given to us, whether prophecy, let us prophesy according to the proportion of faith;
28253	1058	7	Or ministry, let us wait on our ministering: or he that teacheth, on teaching;
28254	1058	8	Or he that exhorteth, on exhortation: he that giveth, let him do it with simplicity; he that ruleth, with diligence; he that sheweth mercy, with cheerfulness.
28255	1058	9	Let love be without dissimulation. Abhor that which is evil; cleave to that which is good.
28256	1058	10	Be kindly affectioned one to another with brotherly love; in honour preferring one another;
28257	1058	11	Not slothful in business; fervent in spirit; serving the Lord;
28258	1058	12	Rejoicing in hope; patient in tribulation; continuing instant in prayer;
28259	1058	13	Distributing to the necessity of saints; given to hospitality.
28260	1058	14	Bless them which persecute you: bless, and curse not.
28261	1058	15	Rejoice with them that do rejoice, and weep with them that weep.
28262	1058	16	Be of the same mind one toward another. Mind not high things, but condescend to men of low estate. Be not wise in your own conceits.
28263	1058	17	Recompense to no man evil for evil. Provide things honest in the sight of all men.
28264	1058	18	If it be possible, as much as lieth in you, live peaceably with all men.
28265	1058	19	Dearly beloved, avenge not yourselves, but rather give place unto wrath: for it is written, Vengeance is mine; I will repay, saith the Lord.
28266	1058	20	Therefore if thine enemy hunger, feed him; if he thirst, give him drink: for in so doing thou shalt heap coals of fire on his head.
28267	1058	21	Be not overcome of evil, but overcome evil with good.
28268	1059	1	LET every soul be subject unto the higher powers. For there is no power but of God: the powers that be are ordained of God.
28269	1059	2	Whosoever therefore resisteth the power, resisteth the ordinance of God: and they that resist shall receive to themselves damnation.
28270	1059	3	For rulers are not a terror to good works, but to the evil. Wilt thou then not be afraid of the power? do that which is good, and thou shalt have praise of the same:
28271	1059	4	For he is the minister of God to thee for good. But if thou do that which is evil, be afraid; for he beareth not the sword in vain: for he is the minister of God, a revenger to execute wrath upon him that doeth evil.
28272	1059	5	Wherefore ye must needs be subject, not only for wrath, but also for conscience sake.
28273	1059	6	For for this cause pay ye tribute also: for they are God's ministers, attending continually upon this very thing.
28274	1059	7	Render therefore to all their dues: tribute to whom tribute is due; custom to whom custom; fear to whom fear; honour to whom honour.
28275	1059	8	Owe no man any thing, but to love one another: for he that loveth another hath fulfilled the law.
28276	1059	9	For this, Thou shalt not commit adultery, Thou shalt not kill, Thou shalt not steal, Thou shalt not bear false witness, Thou shalt not covet; and if there be any other commandment, it is briefly comprehended in this saying, namely, Thou shalt love thy neighbour as thyself.
28277	1059	10	Love worketh no ill to his neighbour: therefore love is the fulfilling of the law.
28278	1059	11	And that, knowing the time, that now it is high time to awake out of sleep: for now is our salvation nearer than when we believed.
28279	1059	12	The night is far spent, the day is at hand: let us therefore cast off the works of darkness, and let us put on the armour of light.
28280	1059	13	Let us walk honestly, as in the day; not in rioting and drunkenness, not in chambering and wantonness, not in strife and envying.
28281	1059	14	But put ye on the Lord Jesus Christ, and make not provision for the flesh, to fulfil the lusts thereof.
28282	1060	1	HIM that is weak in the faith receive ye, but not to doubtful disputations.
28283	1060	2	For one believeth that he may eat all things: another, who is weak, eateth herbs.
28284	1060	3	Let not him that eateth despise him that eateth not; and let not him which eateth not judge him that eateth: for God hath received him.
28285	1060	4	Who art thou that judgest another man's servant? to his own master he standeth or falleth. Yea, he shall be holden up: for God is able to make him stand.
28286	1060	5	One man esteemeth one day above another: another esteemeth every day alike. Let every man be fully persuaded in his own mind.
28287	1060	6	He that regardeth the day, regardeth it unto the Lord; and he that regardeth not the day, to the Lord he doth not regard it. He that eateth, eateth to the Lord, for he giveth God thanks; and he that eateth not, to the Lord he eateth not, and giveth God thanks.
28288	1060	7	For none of us liveth to himself, and no man dieth to himself.
28289	1060	8	For whether we live, we live unto the Lord; and whether we die, we die unto the Lord: whether we live therefore, or die, we are the Lord's.
28290	1060	9	For to this end Christ both died, and rose, and revived, that he might be Lord both of the dead and living.
28291	1060	10	But why dost thou judge thy brother? or why dost thou set at nought thy brother? for we shall all stand before the judgment seat of Christ.
28292	1060	11	For it is written, As I live, saith the Lord, every knee shall bow to me, and every tongue shall confess to God.
28293	1060	12	So then every one of us shall give account of himself to God.
28294	1060	13	Let us not therefore judge one another any more: but judge this rather, that no man put a stumblingblock or an occasion to fall in his brother's way.
28295	1060	14	I know, and am persuaded by the Lord Jesus, that there is nothing unclean of itself: but to him that esteemeth any thing to be unclean, to him it is unclean.
28296	1060	15	But if thy brother be grieved with thy meat, now walkest thou not charitably. Destroy not him with thy meat, for whom Christ died.
28297	1060	16	Let not then your good be evil spoken of:
28298	1060	17	For the kingdom of God is not meat and drink; but righteousness, and peace, and joy in the Holy Ghost.
28299	1060	18	For he that in these things serveth Christ is acceptable to God, and approved of men.
28300	1060	19	Let us therefore follow after the things which make for peace, and things wherewith one may edify another.
28301	1060	20	For meat destroy not the work of God. All things indeed are pure; but it is evil for that man who eateth with offence.
28302	1060	21	It is good neither to eat flesh, nor to drink wine, nor any thing whereby thy brother stumbleth, or is offended, or is made weak.
28303	1060	22	Hast thou faith? have it to thyself before God. Happy is he that condemneth not himself in that thing which he alloweth.
28304	1060	23	And he that doubteth is damned if he eat, because he eateth not of faith: for whatsoever is not of faith is sin.
28305	1061	1	WE then that are strong ought to bear the infirmities of the weak, and not to please ourselves.
28306	1061	2	Let every one of us please his neighbour for his good to edification.
28307	1061	3	For even Christ pleased not himself; but, as it is written, The reproaches of them that reproached thee fell on me.
28308	1061	4	For whatsoever things were written aforetime were written for our learning, that we through patience and comfort of the scriptures might have hope.
28309	1061	5	Now the God of patience and consolation grant you to be likeminded one toward another according to Christ Jesus:
28310	1061	6	That ye may with one mind and one mouth glorify God, even the Father of our Lord Jesus Christ.
28311	1061	7	Wherefore receive ye one another, as Christ also received us to the glory of God.
28312	1061	8	Now I say that Jesus Christ was a minister of the circumcision for the truth of God, to confirm the promises made unto the fathers:
28313	1061	9	And that the Gentiles might glorify God for his mercy; as it is written, For this cause I will confess to thee among the Gentiles, and sing unto thy name.
28314	1061	10	And again he saith, Rejoice, ye Gentiles, with his people.
28315	1061	11	And again, Praise the Lord, all ye Gentiles; and laud him, all ye people.
28316	1061	12	And again, Esaias saith, There shall be a root of Jesse, and he that shall rise to reign over the Gentiles; in him shall the Gentiles trust.
28317	1061	13	Now the God of hope fill you with all joy and peace in believing, that ye may abound in hope, through the power of the Holy Ghost.
28318	1061	14	And I myself also am persuaded of you, my brethren, that ye also are full of goodness, filled with all knowledge, able also to admonish one another.
28319	1061	15	Nevertheless, brethren, I have written the more boldly unto you in some sort, as putting you in mind, because of the grace that is given to me of God,
28320	1061	16	That I should be the minister of Jesus Christ to the Gentiles, ministering the gospel of God, that the offering up of the Gentiles might be acceptable, being sanctified by the Holy Ghost.
28321	1061	17	I have therefore whereof I may glory through Jesus Christ in those things which pertain to God.
28322	1061	18	For I will not dare to speak of any of those things which Christ hath not wrought by me, to make the Gentiles obedient, by word and deed,
28323	1061	19	Through mighty signs and wonders, by the power of the Spirit of God; so that from Jerusalem, and round about unto Illyricum, I have fully preached the gospel of Christ.
28324	1061	20	Yea, so have I strived to preach the gospel, not where Christ was named, lest I should build upon another man's foundation:
28325	1061	21	But as it is written, To whom he was not spoken of, they shall see: and they that have not heard shall understand.
28326	1061	22	For which cause also I have been much hindered from coming to you.
28327	1061	23	But now having no more place in these parts, and having a great desire these many years to come unto you;
28328	1061	24	Whensoever I take my journey into Spain, I will come to you: for I trust to see you in my journey, and to be brought on my way thitherward by you, if first I be somewhat filled with your company.
28329	1061	25	But now I go unto Jerusalem to minister unto the saints.
28330	1061	26	For it hath pleased them of Macedonia and Achaia to make a certain contribution for the poor saints which are at Jerusalem.
28331	1061	27	It hath pleased them verily; and their debtors they are. For if the Gentiles have been made partakers of their spiritual things, their duty is also to minister unto them in carnal things.
28332	1061	28	When therefore I have performed this, and have sealed to them this fruit, I will come by you into Spain.
28333	1061	29	And I am sure that, when I come unto you, I shall come in the fulness of the blessing of the gospel of Christ.
28334	1061	30	Now I beseech you, brethren, for the Lord Jesus Christ's sake, and for the love of the Spirit, that ye strive together with me in your prayers to God for me;
28335	1061	31	That I may be delivered from them that do not believe in Judaea; and that my service which I have for Jerusalem may be accepted of the saints;
28336	1061	32	That I may come unto you with joy by the will of God, and may with you be refreshed.
28337	1061	33	Now the God of peace be with you all. Amen.
28338	1062	1	I COMMEND unto you Phebe our sister, which is a servant of the church which is at Cenchrea:
28339	1062	2	That ye receive her in the Lord, as becometh saints, and that ye assist her in whatsoever business she hath need of you: for she hath been a succourer of many, and of myself also.
28340	1062	3	Greet Priscilla and Aquila my helpers in Christ Jesus:
28341	1062	4	Who have for my life laid down their own necks: unto whom not only I give thanks, but also all the churches of the Gentiles.
28342	1062	5	Likewise greet the church that is in their house. Salute my wellbeloved Epaenetus, who is the firstfruits of Achaia unto Christ.
28343	1062	6	Greet Mary, who bestowed much labour on us.
28344	1062	7	Salute Andronicus and Junia, my kinsmen, and my fellowprisoners, who are of note among the apostles, who also were in Christ before me.
28345	1062	8	Greet Amplias my beloved in the Lord.
28346	1062	9	Salute Urbane, our helper in Christ, and Stachys my beloved.
28347	1062	10	Salute Apelles approved in Christ. Salute them which are of Aristobulus' household.
28348	1062	11	Salute Herodion my kinsman. Greet them that be of the household of Narcissus, which are in the Lord.
28349	1062	12	Salute Tryphena and Tryphosa, who labour in the Lord. Salute the beloved Persis, which laboured much in the Lord.
28350	1062	13	Salute Rufus chosen in the Lord, and his mother and mine.
28351	1062	14	Salute Asyncritus, Phlegon, Hermas, Patrobas, Hermes, and the brethren which are with them.
28352	1062	15	Salute Philologus, and Julia, Nereus, and his sister, and Olympas, and all the saints which are with them.
28353	1062	16	Salute one another with an holy kiss. The churches of Christ salute you.
28354	1062	17	Now I beseech you, brethren, mark them which cause divisions and offences contrary to the doctrine which ye have learned; and avoid them.
28355	1062	18	For they that are such serve not our Lord Jesus Christ, but their own belly; and by good words and fair speeches deceive the hearts of the simple.
28356	1062	19	For your obedience is come abroad unto all men. I am glad therefore on your behalf: but yet I would have you wise unto that which is good, and simple concerning evil.
28357	1062	20	And the God of peace shall bruise Satan under your feet shortly. The grace of our Lord Jesus Christ be with you. Amen.
28358	1062	21	Timotheus my workfellow, and Lucius, and Jason, and Sosipater, my kinsmen, salute you.
28359	1062	22	I Tertius, who wrote this epistle, salute you in the Lord.
28360	1062	23	Gaius mine host, and of the whole church, saluteth you. Erastus the chamberlain of the city saluteth you, and Quartus a brother.
28361	1062	24	The grace of our Lord Jesus Christ be with you all. Amen.
28362	1062	25	Now to him that is of power to stablish you according to my gospel, and the preaching of Jesus Christ, according to the revelation of the mystery, which was kept secret since the world began,
28363	1062	26	But now is made manifest, and by the scriptures of the prophets, according to the commandment of the everlasting God, made known to all nations for the obedience of faith:
28364	1062	27	To God only wise, be glory through Jesus Christ for ever. Amen.
28365	1063	1	PAUL, called to be an apostle of Jesus Christ through the will of God, and Sosthenes our brother,
28366	1063	2	Unto the church of God which is at Corinth, to them that are sanctified in Christ Jesus, called to be saints, with all that in every place call upon the name of Jesus Christ our Lord, both theirs and ours:
28367	1063	3	Grace be unto you, and peace, from God our Father, and from the Lord Jesus Christ.
28368	1063	4	I thank my God always on your behalf, for the grace of God which is given you by Jesus Christ;
28369	1063	5	That in every thing ye are enriched by him, in all utterance, and in all knowledge;
28370	1063	6	Even as the testimony of Christ was confirmed in you:
28371	1063	7	So that ye come behind in no gift; waiting for the coming of our Lord Jesus Christ:
28372	1063	8	Who shall also confirm you unto the end, that ye may be blameless in the day of our Lord Jesus Christ.
28373	1063	9	God is faithful, by whom ye were called unto the fellowship of his Son Jesus Christ our Lord.
28374	1063	10	Now I beseech you, brethren, by the name of our Lord Jesus Christ, that ye all speak the same thing, and that there be no divisions among you; but that ye be perfectly joined together in the same mind and in the same judgment.
28375	1063	11	For it hath been declared unto me of you, my brethren, by them which are of the house of Chloe, that there are contentions among you.
28376	1063	12	Now this I say, that every one of you saith, I am of Paul; and I of Apollos; and I of Cephas; and I of Christ.
28377	1063	13	Is Christ divided? was Paul crucified for you? or were ye baptized in the name of Paul?
28378	1063	14	I thank God that I baptized none of you, but Crispus and Gaius;
28379	1063	15	Lest any should say that I had baptized in mine own name.
28380	1063	16	And I baptized also the household of Stephanas: besides, I know not whether I baptized any other.
28381	1063	17	For Christ sent me not to baptize, but to preach the gospel: not with wisdom of words, lest the cross of Christ should be made of none effect.
28382	1063	18	For the preaching of the cross is to them that perish foolishness; but unto us which are saved it is the power of God.
28383	1063	19	For it is written, I will destroy the wisdom of the wise, and will bring to nothing the understanding of the prudent.
28384	1063	20	Where is the wise? where is the scribe? where is the disputer of this world? hath not God made foolish the wisdom of this world?
28385	1063	21	For after that in the wisdom of God the world by wisdom knew not God, it pleased God by the foolishness of preaching to save them that believe.
28386	1063	22	For the Jews require a sign, and the Greeks seek after wisdom:
28387	1063	23	But we preach Christ crucified, unto the Jews a stumblingblock, and unto the Greeks foolishness;
28388	1063	24	But unto them which are called, both Jews and Greeks, Christ the power of God, and the wisdom of God.
28389	1063	25	Because the foolishness of God is wiser than men; and the weakness of God is stronger than men.
28390	1063	26	For ye see your calling, brethren, how that not many wise men after the flesh, not many mighty, not many noble, are called:
28391	1063	27	But God hath chosen the foolish things of the world to confound the wise; and God hath chosen the weak things of the world to confound the things which are mighty;
28392	1063	28	And base things of the world, and things which are despised, hath God chosen, yea, and things which are not, to bring to nought things that are:
28393	1063	29	That no flesh should glory in his presence.
28394	1063	30	But of him are ye in Christ Jesus, who of God is made unto us wisdom, and righteousness, and sanctification, and redemption:
28395	1063	31	That, according as it is written, He that glorieth, let him glory in the Lord.
28396	1064	1	AND I, brethren, when I came to you, came not with excellency of speech or of wisdom, declaring unto you the testimony of God.
28397	1064	2	For I determined not to know any thing among you, save Jesus Christ, and him crucified.
28398	1064	3	And I was with you in weakness, and in fear, and in much trembling.
28399	1064	4	And my speech and my preaching was not with enticing words of man's wisdom, but in demonstration of the Spirit and of power:
28400	1064	5	That your faith should not stand in the wisdom of men, but in the power of God.
28401	1064	6	Howbeit we speak wisdom among them that are perfect: yet not the wisdom of this world, nor of the princes of this world, that come to nought:
28402	1064	7	But we speak the wisdom of God in a mystery, even the hidden wisdom, which God ordained before the world unto our glory:
28403	1064	8	Which none of the princes of this world knew: for had they known it, they would not have crucified the Lord of glory.
28404	1064	9	But as it is written, Eye hath not seen, nor ear heard, neither have entered into the heart of man, the things which God hath prepared for them that love him.
28405	1064	10	But God hath revealed them unto us by his Spirit: for the Spirit searcheth all things, yea, the deep things of God.
28406	1064	11	For what man knoweth the things of a man, save the spirit of man which is in him? even so the things of God knoweth no man, but the Spirit of God.
28407	1064	12	Now we have received, not the spirit of the world, but the spirit which is of God; that we might know the things that are freely given to us of God.
28408	1064	13	Which things also we speak, not in the words which man's wisdom teacheth, but which the Holy Ghost teacheth; comparing spiritual things with spiritual.
28409	1064	14	But the natural man receiveth not the things of the Spirit of God: for they are foolishness unto him: neither can he know them, because they are spiritually discerned.
28410	1064	15	But he that is spiritual judgeth all things, yet he himself is judged of no man.
28411	1064	16	For who hath known the mind of the Lord, that he may instruct him? But we have the mind of Christ.
28412	1065	1	AND I, brethren, could not speak unto you as unto spiritual, but as unto carnal, even as unto babes in Christ.
28413	1065	2	I have fed you with milk, and not with meat: for hitherto ye were not able to bear it, neither yet now are ye able.
28414	1065	3	For ye are yet carnal: for whereas there is among you envying, and strife, and divisions, are ye not carnal, and walk as men?
28415	1065	4	For while one saith, I am of Paul; and another, I am of Apollos; are ye not carnal?
28416	1065	5	Who then is Paul, and who is Apollos, but ministers by whom ye believed, even as the Lord gave to every man?
28417	1065	6	I have planted, Apollos watered; but God gave the increase.
28418	1065	7	So then neither is he that planteth any thing, neither he that watereth; but God that giveth the increase.
28419	1065	8	Now he that planteth and he that watereth are one: and every man shall receive his own reward according to his own labour.
28420	1065	9	For we are labourers together with God: ye are God's husbandry, ye are God's building.
28421	1065	10	According to the grace of God which is given unto me, as a wise masterbuilder, I have laid the foundation, and another buildeth thereon. But let every man take heed how he buildeth thereupon.
28422	1065	11	For other foundation can no man lay than that is laid, which is Jesus Christ.
28423	1065	12	Now if any man build upon this foundation gold, silver, precious stones, wood, hay, stubble;
28424	1065	13	Every man's work shall be made manifest: for the day shall declare it, because it shall be revealed by fire; and the fire shall try every man's work of what sort it is.
28425	1065	14	If any man's work abide which he hath built thereupon, he shall receive a reward.
28426	1065	15	If any man's work shall be burned, he shall suffer loss: but he himself shall be saved; yet so as by fire.
28427	1065	16	Know ye not that ye are the temple of God, and that the Spirit of God dwelleth in you?
28428	1065	17	If any man defile the temple of God, him shall God destroy; for the temple of God is holy, which temple ye are.
28429	1065	18	Let no man deceive himself. If any man among you seemeth to be wise in this world, let him become a fool, that he may be wise.
28430	1065	19	For the wisdom of this world is foolishness with God. For it is written, He taketh the wise in their own craftiness.
28431	1065	20	And again, The Lord knoweth the thoughts of the wise, that they are vain.
28432	1065	21	Therefore let no man glory in men. For all things are yours;
28433	1065	22	Whether Paul, or Apollos, or Cephas, or the world, or life, or death, or things present, or things to come; all are yours;
28434	1065	23	And ye are Christ's; and Christ is God's.
28435	1066	1	LET a man so account of us, as of the ministers of Christ, and stewards of the mysteries of God.
28436	1066	2	Moreover it is required in stewards, that a man be found faithful.
28437	1066	3	But with me it is a very small thing that I should be judged of you, or of man's judgment: yea, I judge not mine own self.
28438	1066	4	For I know nothing by myself; yet am I not hereby justified: but he that judgeth me is the Lord.
28439	1066	5	Therefore judge nothing before the time, until the Lord come, who both will bring to light the hidden things of darkness, and will make manifest the counsels of the hearts: and then shall every man have praise of God.
28440	1066	6	And these things, brethren, I have in a figure transferred to myself and to Apollos for your sakes; that ye might learn in us not to think of men above that which is written, that no one of you be puffed up for one against another.
28441	1066	7	For who maketh thee to differ from another? and what hast thou that thou didst not receive? now if thou didst receive it, why dost thou glory, as if thou hadst not received it?
28442	1066	8	Now ye are full, now ye are rich, ye have reigned as kings without us: and I would to God ye did reign, that we also might reign with you.
28443	1066	9	For I think that God hath set forth us the apostles last, as it were appointed to death: for we are made a spectacle unto the world, and to angels, and to men.
28444	1066	10	We are fools for Christ's sake, but ye are wise in Christ; we are weak, but ye are strong; ye are honourable, but we are despised.
28445	1066	11	Even unto this present hour we both hunger, and thirst, and are naked, and are buffeted, and have no certain dwellingplace;
28446	1066	12	And labour, working with our own hands: being reviled, we bless; being persecuted, we suffer it:
28447	1066	13	Being defamed, we intreat: we are made as the filth of the world, and are the offscouring of all things unto this day.
28448	1066	14	I write not these things to shame you, but as my beloved sons I warn you.
28449	1066	15	For though ye have ten thousand instructors in Christ, yet have ye not many fathers: for in Christ Jesus I have begotten you through the gospel.
28450	1066	16	Wherefore I beseech you, be ye followers of me.
28451	1066	17	For this cause have I sent unto you Timotheus, who is my beloved son, and faithful in the Lord, who shall bring you into remembrance of my ways which be in Christ, as I teach every where in every church.
28452	1066	18	Now some are puffed up, as though I would not come to you.
28453	1066	19	But I will come to you shortly, if the Lord will, and will know, not the speech of them which are puffed up, but the power.
28454	1066	20	For the kingdom of God is not in word, but in power.
28455	1066	21	What will ye? shall I come unto you with a rod, or in love, and in the spirit of meekness?
28456	1067	1	IT is reported commonly that there is fornication among you, and such fornication as is not so much as named among the Gentiles, that one should have his father's wife.
28457	1067	2	And ye are puffed up, and have not rather mourned, that he that hath done this deed might be taken away from among you.
28458	1067	3	For I verily, as absent in body, but present in spirit, have judged already, as though I were present, concerning him that hath so done this deed,
28459	1067	4	In the name of our Lord Jesus Christ, when ye are gathered together, and my spirit, with the power of our Lord Jesus Christ,
28460	1067	5	To deliver such an one unto Satan for the destruction of the flesh, that the spirit may be saved in the day of the Lord Jesus.
28461	1067	6	Your glorying is not good. Know ye not that a little leaven leaveneth the whole lump?
28462	1067	7	Purge out therefore the old leaven, that ye may be a new lump, as ye are unleavened. For even Christ our passover is sacrificed for us:
28463	1067	8	Therefore let us keep the feast, not with old leaven, neither with the leaven of malice and wickedness; but with the unleavened bread of sincerity and truth.
28464	1067	9	I wrote unto you in an epistle not to company with fornicators:
28465	1067	10	Yet not altogether with the fornicators of this world, or with the covetous, or extortioners, or with idolaters; for then must ye needs go out of the world.
28466	1067	11	But now I have written unto you not to keep company, if any man that is called a brother be a fornicator, or covetous, or an idolater, or a railer, or a drunkard, or an extortioner; with such an one no not to eat.
28467	1067	12	For what have I to do to judge them also that are without? do not ye judge them that are within?
28468	1067	13	But them that are without God judgeth. Therefore put away from among yourselves that wicked person.
28469	1068	1	DARE any of you, having a matter against another, go to law before the unjust, and not before the saints?
28470	1068	2	Do ye not know that the saints shall judge the world? and if the world shall be judged by you, are ye unworthy to judge the smallest matters?
28471	1068	3	Know ye not that we shall judge angels? how much more things that pertain to this life?
28472	1068	4	If then ye have judgments of things pertaining to this life, set them to judge who are least esteemed in the church.
28473	1068	5	I speak to your shame. Is it so, that there is not a wise man among you? no, not one that shall be able to judge between his brethren?
28474	1068	6	But brother goeth to law with brother, and that before the unbelievers.
28475	1068	7	Now therefore there is utterly a fault among you, because ye go to law one with another. Why do ye not rather take wrong? why do ye not rather suffer yourselves to be defrauded?
28476	1068	8	Nay, ye do wrong, and defraud, and that your brethren.
28477	1068	9	Know ye not that the unrighteous shall not inherit the kingdom of God? Be not deceived: neither fornicators, nor idolaters, nor adulterers, nor effeminate, nor abusers of themselves with mankind,
28478	1068	10	Nor thieves, nor covetous, nor drunkards, nor revilers, nor extortioners, shall inherit the kingdom of God.
28479	1068	11	And such were some of you: but ye are washed, but ye are sanctified, but ye are justified in the name of the Lord Jesus, and by the Spirit of our God.
28480	1068	12	All things are lawful unto me, but all things are not expedient: all things are lawful for me, but I will not be brought under the power of any.
28481	1068	13	Meats for the belly, and the belly for meats: but God shall destroy both it and them. Now the body is not for fornication, but for the Lord; and the Lord for the body.
28482	1068	14	And God hath both raised up the Lord, and will also raise up us by his own power.
28483	1068	15	Know ye not that your bodies are the members of Christ? shall I then take the members of Christ, and make them the members of an harlot? God forbid.
28484	1068	16	What? know ye not that he which is joined to an harlot is one body? for two, saith he, shall be one flesh.
28485	1068	17	But he that is joined unto the Lord is one spirit.
28486	1068	18	Flee fornication. Every sin that a man doeth is without the body; but he that committeth fornication sinneth against his own body.
28487	1068	19	What? know ye not that your body is the temple of the Holy Ghost which is in you, which ye have of God, and ye are not your own?
28488	1068	20	For ye are bought with a price: therefore glorify God in your body, and in your spirit, which are God's.
28489	1069	1	NOW concerning the things whereof ye wrote unto me: It is good for a man not to touch a woman.
28490	1069	2	Nevertheless, to avoid fornication, let every man have his own wife, and let every woman have her own husband.
28491	1069	3	Let the husband render unto the wife due benevolence: and likewise also the wife unto the husband.
28492	1069	4	The wife hath not power of her own body, but the husband: and likewise also the husband hath not power of his own body, but the wife.
28493	1069	5	Defraud ye not one the other, except it be with consent for a time, that ye may give yourselves to fasting and prayer; and come together again, that Satan tempt you not for your incontinency.
28494	1069	6	But I speak this by permission, and not of commandment.
28495	1069	7	For I would that all men were even as I myself. But every man hath his proper gift of God, one after this manner, and another after that.
28496	1069	8	I say therefore to the unmarried and widows, It is good for them if they abide even as I.
28497	1069	9	But if they cannot contain, let them marry: for it is better to marry than to burn.
28498	1069	10	And unto the married I command, yet not I, but the Lord, Let not the wife depart from her husband:
28499	1069	11	But and if she depart, let her remain unmarried, or be reconciled to her husband: and let not the husband put away his wife.
28500	1069	12	But to the rest speak I, not the Lord: If any brother hath a wife that believeth not, and she be pleased to dwell with him, let him not put her away.
28501	1069	13	And the woman which hath an husband that believeth not, and if he be pleased to dwell with her, let her not leave him.
28502	1069	14	For the unbelieving husband is sanctified by the wife, and the unbelieving wife is sanctified by the husband: else were your children unclean; but now are they holy.
28503	1069	15	But if the unbelieving depart, let him depart. A brother or a sister is not under bondage in such cases: but God hath called us to peace.
28504	1069	16	For what knowest thou, O wife, whether thou shalt save thy husband? or how knowest thou, O man, whether thou shalt save thy wife?
28505	1069	17	But as God hath distributed to every man, as the Lord hath called every one, so let him walk. And so ordain I in all churches.
28506	1069	18	Is any man called being circumcised? let him not become uncircumcised. Is any called in uncircumcision? let him not be circumcised.
28507	1069	19	Circumcision is nothing, and uncircumcision is nothing, but the keeping of the commandments of God.
28508	1069	20	Let every man abide in the same calling wherein he was called.
28509	1069	21	Art thou called being a servant? care not for it: but if thou mayest be made free, use it rather.
28510	1069	22	For he that is called in the Lord, being a servant, is the Lord's freeman: likewise also he that is called, being free, is Christ's servant.
28511	1069	23	Ye are bought with a price; be not ye the servants of men.
28512	1069	24	Brethren, let every man, wherein he is called, therein abide with God.
28513	1069	25	Now concerning virgins I have no commandment of the Lord: yet I give my judgment, as one that hath obtained mercy of the Lord to be faithful.
28514	1069	26	I suppose therefore that this is good for the present distress, I say, that it is good for a man so to be.
28515	1069	27	Art thou bound unto a wife? seek not to be loosed. Art thou loosed from a wife? seek not a wife.
28516	1069	28	But and if thou marry, thou hast not sinned; and if a virgin marry, she hath not sinned. Nevertheless such shall have trouble in the flesh: but I spare you.
28517	1069	29	But this I say, brethren, the time is short: it remaineth, that both they that have wives be as though they had none;
28518	1069	30	And they that weep, as though they wept not; and they that rejoice, as though they rejoiced not; and they that buy, as though they possessed not;
28519	1069	31	And they that use this world, as not abusing it: for the fashion of this world passeth away.
28520	1069	32	But I would have you without carefulness. He that is unmarried careth for the things that belong to the Lord, how he may please the Lord:
28521	1069	33	But he that is married careth for the things that are of the world, how he may please his wife.
28522	1069	34	There is difference also between a wife and a virgin. The unmarried woman careth for the things of the Lord, that she may be holy both in body and in spirit: but she that is married careth for the things of the world, how she may please her husband.
28523	1069	35	And this I speak for your own profit; not that I may cast a snare upon you, but for that which is comely, and that ye may attend upon the Lord without distraction.
28524	1069	36	But if any man think that he behaveth himself uncomely toward his virgin, if she pass the flower of her age, and need so require, let him do what he will, he sinneth not: let them marry.
28525	1069	37	Nevertheless, he that standeth stedfast in his heart, having no necessity, but hath power over his own will, and hath so decreed in his heart that he will keep his virgin, doeth well.
28526	1069	38	So then he that giveth her in marriage doeth well; but he that giveth her not in marriage doeth better.
28527	1069	39	The wife is bound by the law as long as her husband liveth; but if her husband be dead, she is at liberty to be married to whom she will; only in the Lord.
28528	1069	40	But she is happier if she so abide, after my judgment: and I think also that I have the Spirit of God.
28529	1070	1	NOW as touching things offered unto idols, we know that we all have knowledge. Knowledge puffeth up, but charity edifieth.
28530	1070	2	And if any man think that he knoweth any thing, he knoweth nothing yet as he ought to know.
28531	1070	3	But if any man love God, the same is known of him.
28532	1070	4	As concerning therefore the eating of those things that are offered in sacrifice unto idols, we know that an idol is nothing in the world, and that there is none other God but one.
28533	1070	5	For though there be that are called gods, whether in heaven or in earth, (as there be gods many, and lords many,)
28534	1070	6	But to us there is but one God, the Father, of whom are all things, and we in him; and one Lord Jesus Christ, by whom are all things, and we by him.
28535	1070	7	Howbeit there is not in every man that knowledge: for some with conscience of the idol unto this hour eat it as a thing offered unto an idol; and their conscience being weak is defiled.
28536	1070	8	But meat commendeth us not to God: for neither, if we eat, are we the better; neither, if we eat not, are we the worse.
28537	1070	9	But take heed lest by any means this liberty of yours become a stumblingblock to them that are weak.
28538	1070	10	For if any man see thee which hast knowledge sit at meat in the idol's temple, shall not the conscience of him which is weak be emboldened to eat those things which are offered to idols;
28539	1070	11	And through thy knowledge shall the weak brother perish, for whom Christ died?
28540	1070	12	But when ye sin so against the brethren, and wound their weak conscience, ye sin against Christ.
28541	1070	13	Wherefore, if meat make my brother to offend, I will eat no flesh while the world standeth, lest I make my brother to offend.
28542	1071	1	AM I not an apostle? am I not free? have I not seen Jesus Christ our Lord? are not ye my work in the Lord?
28543	1071	2	If I be not an apostle unto others, yet doubtless I am to you: for the seal of mine apostleship are ye in the Lord.
28544	1071	3	Mine answer to them that do examine me is this,
28545	1071	4	Have we not power to eat and to drink?
28546	1071	5	Have we not power to lead about a sister, a wife, as well as other apostles, and as the brethren of the Lord, and Cephas?
28547	1071	6	Or I only and Barnabas, have not we power to forbear working?
28548	1071	7	Who goeth a warfare any time at his own charges? who planteth a vineyard, and eateth not of the fruit thereof? or who feedeth a flock, and eateth not of the milk of the flock?
28549	1071	8	Say I these things as a man? or saith not the law the same also?
28550	1071	9	For it is written in the law of Moses, Thou shalt not muzzle the mouth of the ox that treadeth out the corn. Doth God take care for oxen?
28551	1071	10	Or saith he it altogether for our sakes? For our sakes, no doubt, this is written: that he that ploweth should plow in hope; and that he that thresheth in hope should be partaker of his hope.
28552	1071	11	If we have sown unto you spiritual things, is it a great thing if we shall reap your carnal things?
28553	1071	12	If others be partakers of this power over you, are not we rather? Nevertheless we have not used this power; but suffer all things, lest we should hinder the gospel of Christ.
28554	1071	13	Do ye not know that they which minister about holy things live of the things of the temple? and they which wait at the alter are partakers with the alter?
28555	1071	14	Even so hath the Lord ordained that they which preach the gospel should live of the gospel.
28556	1071	15	But I have used none of these things: neither have I written these things, that it should be so done unto me: for it were better for me to die, than that any man should make my glorying void.
28557	1071	16	For though I preach the gospel, I have nothing to glory of: for necessity is laid upon me; yea, woe is unto me, if I preach not the gospel!
28558	1071	17	For if I do this thing willingly, I have a reward: but if against my will, a dispensation of the gospel is committed unto me.
28559	1071	18	What is my reward then? Verily that, when I preach the gospel, I may make the gospel of Christ without charge, that I abuse not my power in the gospel.
28560	1071	19	For though I be free from all men, yet have I made myself servant unto all, that I might gain the more.
28561	1071	20	And unto the Jews I became as a Jew, that I might gain the Jews; to them that are under the law, as under the law, that I might gain them that are under the law;
28562	1071	21	To them that are without law, as without law, (being not without law to God, but under the law to Christ,) that I might gain them that are without law.
28563	1071	22	To the weak became I as weak, that I might gain the weak: I am made all things to all men, that I might by all means save some.
28564	1071	23	And this I do for the gospel's sake, that I might be partaker thereof with you.
28565	1071	24	Know ye not that they which run in a race run all, but one receiveth the prize? So run, that ye may obtain.
28566	1071	25	And every man that striveth for the mastery is temperate in all things. Now they do it to obtain a corruptible crown; but we an incorruptible.
28567	1071	26	I therefore so run, not as uncertainly; so fight I, not as one that beateth the air:
28568	1071	27	But I keep under my body, and bring it into subjection: lest that by any means, when I have preached to others, I myself should be a castaway.
28569	1072	1	MOREOVER, brethren, I would not that ye should be ignorant, how that all our fathers were under the cloud, and all passed through the sea;
28570	1072	2	And were all baptized unto Moses in the cloud and in the sea;
28571	1072	3	And did all eat the same spiritual meat;
28572	1072	4	And did all drink the same spiritual drink: for they drank of that spiritual Rock that followed them: and that Rock was Christ.
28573	1072	5	But with many of them God was not well pleased: for they were overthrown in the wilderness.
28574	1072	6	Now these things were our examples, to the intent we should not lust after evil things, as they also lusted.
28575	1072	7	Neither be ye idolaters, as were some of them; as it is written, The people sat down to eat and drink, and rose up to play.
28576	1072	8	Neither let us commit fornication, as some of them committed, and fell in one day three and twenty thousand.
28577	1072	9	Neither let us tempt Christ, as some of them also tempted, and were destroyed of serpents.
28578	1072	10	Neither murmur ye, as some of them also murmured, and were destroyed of the destroyer.
28579	1072	11	Now all these things happened unto them for ensamples: and they are written for our admonition, upon whom the ends of the world are come.
28580	1072	12	Wherefore let him that thinketh he standeth take heed lest he fall.
28581	1072	13	There hath no temptation taken you but such as is common to man: but God is faithful, who will not suffer you to be tempted above that ye are able; but will with the temptation also make a way to escape, that ye may be able to bear it.
28582	1072	14	Wherefore, my dearly beloved, flee from idolatry.
28583	1072	15	I speak as to wise men; judge ye what I say.
28584	1072	16	The cup of blessing which we bless, is it not the communion of the blood of Christ? The bread which we break, is it not the communion of the body of Christ?
28585	1072	17	For we being many are one bread, and one body: for we are all partakers of that one bread.
28586	1072	18	Behold Israel after the flesh: are not they which eat of the sacrifices partakers of the alter?
28587	1072	19	What say I then? that the idol is any thing, or that which is offered in sacrifice to idols is any thing?
28588	1072	20	But I say, that the things which the Gentiles sacrifice, they sacrifice to devils, and not to God: and I would not that ye should have fellowship with devils.
28589	1072	21	Ye cannot drink the cup of the Lord, and the cup of devils: ye cannot be partakers of the Lord's table, and of the table of devils.
28590	1072	22	Do we provoke the Lord to jealousy? are we stronger than he?
28591	1072	23	All things are lawful for me, but all things are not expedient: all things are lawful for me, but all things edify not.
28592	1072	24	Let no man seek his own, but every man another's wealth.
28593	1072	25	Whatsoever is sold in the shambles, that eat, asking no question for conscience sake:
28594	1072	26	For the earth is the Lord's, and the fulness thereof.
28595	1072	27	If any of them that believe not bid you to a feast, and ye be disposed to go; whatsoever is set before you, eat, asking no question for conscience sake.
28596	1072	28	But if any man say unto you, This is offered in sacrifice unto idols, eat not for his sake that shewed it, and for conscience sake: for the earth is the Lord's, and the fulness thereof:
28597	1072	29	Conscience, I say, not thine own, but of the other: for why is my liberty judged of another man's conscience?
28598	1072	30	For if I by grace be a partaker, why am I evil spoken of for that for which I give thanks?
28599	1072	31	Whether therefore ye eat, or drink, or whatsoever ye do, do all to the glory of God.
28600	1072	32	Give none offence, neither to the Jews, nor to the Gentiles, nor to the church of God:
28601	1072	33	Even as I please all men in all things, not seeking mine own profit, but the profit of many, that they may be saved.
28602	1073	1	BE ye followers of me, even as I also am of Christ.
28603	1073	2	Now I praise you, brethren, that ye remember me in all things, and keep the ordinances, as I delivered them to you.
28604	1073	3	But I would have you know, that the head of every man is Christ; and the head of the woman is the man; and the head of Christ is God.
28605	1073	4	Every man praying or prophesying, having his head covered, dishonoureth his head.
28606	1073	5	But every woman that prayeth or prophesieth with her head uncovered dishonoureth her head: for that is even all one as if she were shaven.
28607	1073	6	For if the woman be not covered, let her also be shorn: but if it be a shame for a woman to be shorn or shaven, let her be covered.
28608	1073	7	For a man indeed ought not to cover his head, forasmuch as he is the image and glory of God: but the woman is the glory of the man.
28609	1073	8	For the man is not of the woman; but the woman of the man.
28610	1073	9	Neither was the man created for the woman; but the woman for the man.
28611	1073	10	For this cause ought the woman to have power on her head because of the angels.
28612	1073	11	Nevertheless neither is the man without the woman, neither the woman without the man, in the Lord.
28613	1073	12	For as the woman is of the man, even so is the man also by the woman; but all things of God.
28614	1073	13	Judge in yourselves: is it comely that a woman pray unto God uncovered?
28615	1073	14	Doth not even nature itself teach you, that, if a man have long hair, it is a shame unto him?
28616	1073	15	But if a woman have long hair, it is a glory to her: for her hair is given her for a covering.
28617	1073	16	But if any man seem to be contentious, we have no such custom, neither the churches of God.
28618	1073	17	Now in this that I declare unto you I praise you not, that ye come together not for the better, but for the worse.
28619	1073	18	For first of all, when ye come together in the church, I hear that there be divisions among you; and I partly believe it.
28620	1073	19	For there must be also heresies among you, that they which are approved may be made manifest among you.
28621	1073	20	When ye come together therefore into one place, this is not to eat the Lord's supper.
28622	1073	21	For in eating every one taketh before other his own supper: and one is hungry, and another is drunken.
28623	1073	22	What? have ye not houses to eat and to drink in? or despise ye the church of God, and shame them that have not? What shall I say to you? shall I praise you in this? I praise you not.
28624	1073	23	For I have received of the Lord that which also I delivered unto you, That the Lord Jesus the same night in which he was betrayed took bread:
28625	1073	24	And when he had given thanks, he brake it, and said, Take, eat: this is my body, which is broken for you: this do in remembrance of me.
28626	1073	25	After the same manner also he took the cup, when he had supped, saying, This cup is the new testament in my blood: this do ye, as oft as ye drink it, in remembrance of me.
28627	1073	26	For as often as ye eat this bread, and drink this cup, ye do shew the Lord's death till he come.
28628	1073	27	Wherefore whosoever shall eat this bread, and drink this cup of the Lord, unworthily, shall be guilty of the body and blood of the Lord.
28629	1073	28	But let a man examine himself, and so let him eat of that bread, and drink of that cup.
28630	1073	29	For he that eateth and drinketh unworthily, eateth and drinketh damnation to himself, not discerning the Lord's body.
28631	1073	30	For this cause many are weak and sickly among you, and many sleep.
28632	1073	31	For if we would judge ourselves, we should not be judged.
28633	1073	32	But when we are judged, we are chastened of the Lord, that we should not be condemned with the world.
28634	1073	33	Wherefore, my brethren, when ye come together to eat, tarry one for another.
28635	1073	34	And if any man hunger, let him eat at home; that ye come not together unto condemnation. And the rest will I set in order when I come.
28636	1074	1	NOW concerning spiritual gifts, brethren, I would not have you ignorant.
28637	1074	2	Ye know that ye were Gentiles, carried away unto these dumb idols, even as ye were led.
28638	1074	3	Wherefore I give you to understand, that no man speaking by the Spirit of God calleth Jesus accursed: and that no man can say that Jesus is the Lord, but by the Holy Ghost.
28639	1074	4	Now there are diversities of gifts, but the same Spirit.
28640	1074	5	And there are differences of administrations, but the same Lord.
28641	1074	6	And there are diversities of operations, but it is the same God which worketh all in all.
28642	1074	7	But the manifestation of the Spirit is given to every man to profit withal.
28643	1074	8	For to one is given by the Spirit the word of wisdom; to another the word of knowledge by the same Spirit;
28644	1074	9	To another faith by the same Spirit; to another the gifts of healing by the same Spirit;
28645	1074	10	To another the working of miracles; to another prophecy; to another discerning of spirits; to another divers kinds of tongues; to another the interpretation of tongues:
28646	1074	11	But all these worketh that one and the selfsame Spirit, dividing to every man severally as he will.
28647	1074	12	For as the body is one, and hath many members, and all the members of that one body, being many, are one body: so also is Christ.
28648	1074	13	For by one Spirit are we all baptized into one body, whether we be Jews or Gentiles, whether we be bond or free; and have been all made to drink into one Spirit.
28649	1074	14	For the body is not one member, but many.
28650	1074	15	If the foot shall say, Because I am not the hand, I am not of the body; is it therefore not of the body?
28651	1074	16	And if the ear shall say, Because I am not the eye, I am not of the body; is it therefore not of the body?
28652	1074	17	If the whole body were an eye, where were the hearing? If the whole were hearing, where were the smelling?
28653	1074	18	But now hath God set the members every one of them in the body, as it hath pleased him.
28654	1074	19	And if they were all one member, where were the body?
28655	1074	20	But now are they many members, yet but one body.
28656	1074	21	And the eye cannot say unto the hand, I have no need of thee: nor again the head to the feet, I have no need of you.
28657	1074	22	Nay, much more those members of the body, which seem to be more feeble, are necessary:
28658	1074	23	And those members of the body, which we think to be less honourable, upon these we bestow more abundant honour; and our uncomely parts have more abundant comeliness.
28659	1074	24	For our comely parts have no need: but God hath tempered the body together, having given more abundant honour to that part which lacked:
28660	1074	25	That there should be no schism in the body; but that the members should have the same care one for another.
28661	1074	26	And whether one member suffer, all the members suffer with it; or one member be honoured, all the members rejoice with it.
28662	1074	27	Now ye are the body of Christ, and members in particular.
28663	1074	28	And God hath set some in the church, first apostles, secondarily prophets, thirdly teachers, after that miracles, then gifts of healings, helps, governments, diversities of tongues.
28664	1074	29	Are all apostles? are all prophets? are all teachers? are all workers of miracles?
28665	1074	30	Have all the gifts of healing? do all speak with tongues? do all interpret?
28666	1074	31	But covet earnestly the best gifts: and yet shew I unto you a more excellent way.
28667	1075	1	THOUGH I speak with the tongues of men and of angels, and have not charity, I am become as sounding brass, or a tinkling cymbal.
28668	1075	2	And though I have the gift of prophecy, and understand all mysteries, and all knowledge; and though I have all faith, so that I could remove mountains, and have not charity, I am nothing.
28669	1075	3	And though I bestow all my goods to feed the poor, and though I give my body to be burned, and have not charity, it profiteth me nothing.
28670	1075	4	Charity suffereth long, and is kind; charity envieth not; charity vaunteth not itself, is not puffed up,
28671	1075	5	Doth not behave itself unseemly, seeketh not her own, is not easily provoked, thinketh no evil;
28672	1075	6	Rejoiceth not in iniquity, but rejoiceth in the truth;
28673	1075	7	Beareth all things, believeth all things, hopeth all things, endureth all things.
28674	1075	8	Charity never faileth: but whether there be prophecies, they shall fail; whether there be tongues, they shall cease; whether there be knowledge, it shall vanish away.
28675	1075	9	For we know in part, and we prophesy in part.
28676	1075	10	But when that which is perfect is come, then that which is in part shall be done away.
28677	1075	11	When I was a child, I spake as a child, I understood as a child, I thought as a child: but when I became a man, I put away childish things.
28678	1075	12	For now we see through a glass, darkly; but then face to face: now I know in part; but then shall I know even as also I am known.
28679	1075	13	And now abideth faith, hope, charity, these three; but the greatest of these is charity.
28680	1076	1	FOLLOW after charity, and desire spiritual gifts, but rather that ye may prophesy.
28681	1076	2	For he that speaketh in an unknown tongue speaketh not unto men, but unto God: for no man understandeth him; howbeit in the spirit he speaketh mysteries.
28682	1076	3	But he that prophesieth speaketh unto men to edification, and exhortation, and comfort.
28683	1076	4	He that speaketh in an unknown tongue edifieth himself; but he that prophesieth edifieth the church.
28684	1076	5	I would that ye all spake with tongues, but rather that ye prophesied: for greater is he that prophesieth than he that speaketh with tongues, except he interpret, that the church may receive edifying.
28685	1076	6	Now, brethren, if I come unto you speaking with tongues, what shall I profit you, except I shall speak to you either by revelation, or by knowledge, or by prophesying, or by doctrine?
28686	1076	7	And even things without life giving sound, whether pipe or harp, except they give a distinction in the sounds, how shall it be known what is piped or harped?
28687	1076	8	For if the trumpet give an uncertain sound, who shall prepare himself to the battle?
28688	1076	9	So likewise ye, except ye utter by the tongue words easy to be understood, how shall it be known what is spoken? for ye shall speak into the air.
28689	1076	10	There are, it may be, so many kinds of voices in the world, and none of them is without signification.
28690	1076	11	Therefore if I know not the meaning of the voice, I shall be unto him that speaketh a barbarian, and he that speaketh shall be a barbarian unto me.
28691	1076	12	Even so ye, forasmuch as ye are zealous of spiritual gifts, seek that ye may excel to the edifying of the church.
28692	1076	13	Wherefore let him that speaketh in an unknown tongue pray that he may interpret.
28693	1076	14	For if I pray in an unknown tongue, my spirit prayeth, but my understanding is unfruitful.
28694	1076	15	What is it then? I will pray with the spirit, and I will pray with the understanding also: I will sing with the spirit, and I will sing with the understanding also.
28695	1076	16	Else when thou shalt bless with the spirit, how shall he that occupieth the room of the unlearned say Amen at thy giving of thanks, seeing he understandeth not what thou sayest?
28696	1076	17	For thou verily givest thanks well, but the other is not edified.
28697	1076	18	I thank my God, I speak with tongues more than ye all:
28698	1076	19	Yet in the church I had rather speak five words with my understanding, that by my voice I might teach others also, than ten thousand words in an unknown tongue.
28699	1076	20	Brethren, be not children in understanding: howbeit in malice be ye children, but in understanding be men.
28700	1076	21	In the law it is written, With men of other tongues and other lips will I speak unto this people; and yet for all that will they not hear me, saith the Lord.
28701	1076	22	Wherefore tongues are for a sign, not to them that believe, but to them that believe not: but prophesying serveth not for them that believe not, but for them which believe.
28702	1076	23	If therefore the whole church be come together into one place, and all speak with tongues, and there come in those that are unlearned, or unbelievers, will they not say that ye are mad?
28703	1076	24	But if all prophesy, and there come in one that believeth not, or one unlearned, he is convinced of all, he is judged of all:
28704	1076	25	And thus are the secrets of his heart made manifest; and so falling down on his face he will worship God, and report that God is in you of a truth.
28705	1076	26	How is it then, brethren? when ye come together, every one of you hath a psalm, hath a doctrine, hath a tongue, hath a revelation, hath an interpretation. Let all things be done unto edifying.
28706	1076	27	If any man speak in an unknown tongue, let it be by two, or at the most by three, and that by course; and let one interpret.
28707	1076	28	But if there be no interpreter, let him keep silence in the church; and let him speak to himself, and to God.
28708	1076	29	Let the prophets speak two or three, and let the other judge.
28709	1076	30	If any thing be revealed to another that sitteth by, let the first hold his peace.
28710	1076	31	For ye may all prophesy one by one, that all may learn, and all may be comforted.
28711	1076	32	And the spirits of the prophets are subject to the prophets.
28712	1076	33	For God is not the author of confusion, but of peace, as in all churches of the saints.
28713	1076	34	Let your women keep silence in the churches: for it is not permitted unto them to speak; but they are commanded to be under obedience, as also saith the law.
28714	1076	35	And if they will learn any thing, let them ask their husbands at home: for it is a shame for women to speak in the church.
28715	1076	36	What? came the word of God out from you? or came it unto you only?
28716	1076	37	If any man think himself to be a prophet, or spiritual, let him acknowledge that the things that I write unto you are the commandments of the Lord.
28717	1076	38	But if any man be ignorant, let him be ignorant.
28718	1076	39	Wherefore, brethren, covet to prophesy, and forbid not to speak with tongues.
28719	1076	40	Let all things be done decently and in order.
28720	1077	1	MOREOVER, brethren, I declare unto you the gospel which I preached unto you, which also ye have received, and wherein ye stand;
28721	1077	2	By which also ye are saved, if ye keep in memory what I preached unto you, unless ye have believed in vain.
28722	1077	3	For I delivered unto you first of all that which I also received, how that Christ died for our sins according to the scriptures;
28723	1077	4	And that he was buried, and that he rose again the third day according to the scriptures:
28724	1077	5	And that he was seen of Cephas, then of the twelve:
28725	1077	6	After that, he was seen of above five hundred brethren at once; of whom the greater part remain unto this present, but some are fallen asleep.
28726	1077	7	After that, he was seen of James; then of all the apostles.
28727	1077	8	And last of all he was seen of me also, as of one born out of due time.
28728	1077	9	For I am the least of the apostles, that am not meet to be called an apostle, because I persecuted the church of God.
28729	1077	10	But by the grace of God I am what I am: and his grace which was bestowed upon me was not in vain; but I laboured more abundantly than they all: yet not I, but the grace of God which was with me.
28730	1077	11	Therefore whether it were I or they, so we preach, and so ye believed.
28731	1077	12	Now if Christ be preached that he rose from the dead, how say some among you that there is no resurrection of the dead?
28732	1077	13	But if there be no resurrection of the dead, then is Christ not risen:
28733	1077	14	And if Christ be not risen, then is our preaching vain, and your faith is also vain.
28734	1077	15	Yea, and we are found false witnesses of God; because we have testified of God that he raised up Christ: whom he raised not up, if so be that the dead rise not.
28735	1077	16	For if the dead rise not, then is not Christ raised:
28736	1077	17	And if Christ be not raised, your faith is vain; ye are yet in your sins.
28737	1077	18	Then they also which are fallen asleep in Christ are perished.
28738	1077	19	If in this life only we have hope in Christ, we are of all men most miserable.
28739	1077	20	But now is Christ risen from the dead, and become the firstfruits of them that slept.
28740	1077	21	For since by man came death, by man came also the resurrection of the dead.
28741	1077	22	For as in Adam all die, even so in Christ shall all be made alive.
28742	1077	23	But every man in his own order: Christ the firstfruits; afterward they that are Christ's at his coming.
28743	1077	24	Then cometh the end, when he shall have delivered up the kingdom to God, even the Father; when he shall have put down all rule and all authority and power.
28744	1077	25	For he must reign, till he hath put all enemies under his feet.
28745	1077	26	The last enemy that shall be destroyed is death.
28746	1077	27	For he hath put all things under his feet. But when he saith all things are put under him, it is manifest that he is excepted, which did put all things under him.
28747	1077	28	And when all things shall be subdued unto him, then shall the Son also himself be subject unto him that put all things under him, that God may be all in all.
28748	1077	29	Else what shall they do which are baptized for the dead, if the dead rise not at all? why are they then baptized for the dead?
28749	1077	30	And why stand we in jeopardy every hour?
28750	1077	31	I protest by your rejoicing which I have in Christ Jesus our Lord, I die daily.
28751	1077	32	If after the manner of men I have fought with beasts at Ephesus, what advantageth it me, if the dead rise not? let us eat and drink; for to morrow we die.
28752	1077	33	Be not deceived: evil communications corrupt good manners.
28753	1077	34	Awake to righteousness, and sin not; for some have not the knowledge of God: I speak this to your shame.
28754	1077	35	But some man will say, How are the dead raised up? and with what body do they come?
28755	1077	36	Thou fool, that which thou sowest is not quickened, except it die:
28756	1077	37	And that which thou sowest, thou sowest not that body that shall be, but bare grain, it may chance of wheat, or of some other grain:
28757	1077	38	But God giveth it a body as it hath pleased him, and to every seed his own body.
28758	1077	39	All flesh is not the same flesh: but there is one kind of flesh of men, another flesh of beasts, another of fishes, and another of birds.
28759	1077	40	There are also celestial bodies, and bodies terrestrial: but the glory of the celestial is one, and the glory of the terrestrial is another.
28760	1077	41	There is one glory of the sun, and another glory of the moon, and another glory of the stars: for one star differeth from another star in glory.
28761	1077	42	So also is the resurrection of the dead. It is sown in corruption; it is raised in incorruption:
28762	1077	43	It is sown in dishonour; it is raised in glory: it is sown in weakness; it is raised in power:
28763	1077	44	It is sown a natural body; it is raised a spiritual body. There is a natural body, and there is a spiritual body.
28764	1077	45	And so it is written, The first man Adam was made a living soul; the last Adam was made a quickening spirit.
28765	1077	46	Howbeit that was not first which is spiritual, but that which is natural; and afterward that which is spiritual.
28766	1077	47	The first man is of the earth, earthy: the second man is the Lord from heaven.
28767	1077	48	As is the earthy, such are they also that are earthy: and as is the heavenly, such are they also that are heavenly.
28768	1077	49	And as we have borne the image of the earthy, we shall also bear the image of the heavenly.
28769	1077	50	Now this I say, brethren, that flesh and blood cannot inherit the kingdom of God; neither doth corruption inherit incorruption.
28770	1077	51	Behold, I shew you a mystery; We shall not all sleep, but we shall all be changed,
28771	1077	52	In a moment, in the twinkling of an eye, at the last trump: for the trumpet shall sound, and the dead shall be raised incorruptible, and we shall be changed.
28772	1077	53	For this corruptible must put on incorruption, and this mortal must put on immortality.
28773	1077	54	So when this corruptible shall have put on incorruption, and this mortal shall have put on immortality, then shall be brought to pass the saying that is written, Death is swallowed up in victory.
28774	1077	55	O death, where is thy sting? O grave, where is thy victory?
28775	1077	56	The sting of death is sin; and the strength of sin is the law.
28776	1077	57	But thanks be to God, which giveth us the victory through our Lord Jesus Christ.
28777	1077	58	Therefore, my beloved brethren, be ye stedfast, unmoveable, always abounding in the work of the Lord, forasmuch as ye know that your labour is not in vain in the Lord.
28778	1078	1	NOW concerning the collection for the saints, as I have given order to the churches of Galatia, even so do ye.
28779	1078	2	Upon the first day of the week let every one of you lay by him in store, as God hath prospered him, that there be no gatherings when I come.
28780	1078	3	And when I come, whomsoever ye shall approve by your letters, them will I send to bring your liberality unto Jerusalem.
28781	1078	4	And if it be meet that I go also, they shall go with me.
28782	1078	5	Now I will come unto you, when I shall pass through Macedonia: for I do pass through Macedonia.
28783	1078	6	And it may be that I will abide, yea, and winter with you, that ye may bring me on my journey whithersoever I go.
28784	1078	7	For I will not see you now by the way; but I trust to tarry a while with you, if the Lord permit.
28785	1078	8	But I will tarry at Ephesus until Pentecost.
28786	1078	9	For a great door and effectual is opened unto me, and there are many adversaries.
28787	1078	10	Now if Timotheus come, see that he may be with you without fear: for he worketh the work of the Lord, as I also do.
28788	1078	11	Let no man therefore despise him: but conduct him forth in peace, that he may come unto me: for I look for him with the brethren.
28789	1078	12	As touching our brother Apollos, I greatly desired him to come unto you with the brethren: but his will was not at all to come at this time; but he will come when he shall have convenient time.
28790	1078	13	Watch ye, stand fast in the faith, quit you like men, be strong.
28791	1078	14	Let all your things be done with charity.
28792	1078	15	I beseech you, brethren, (ye know the house of Stephanas, that it is the firstfruits of Achaia, and that they have addicted themselves to the ministry of the saints,)
28793	1078	16	That ye submit yourselves unto such, and to every one that helpeth with us, and laboureth.
28794	1078	17	I am glad of the coming of Stephanas and Fortunatus and Achaicus: for that which was lacking on your part they have supplied.
28795	1078	18	For they have refreshed my spirit and yours: therefore acknowledge ye them that are such.
28796	1078	19	The churches of Asia salute you. Aquila and Priscilla salute you much in the Lord, with the church that is in their house.
28797	1078	20	All the brethren greet you. Greet ye one another with an holy kiss.
28798	1078	21	The salutation of me Paul with mine own hand.
28799	1078	22	If any man love not the Lord Jesus Christ, let him be Anathema Maran-atha.
28800	1078	23	The grace of our Lord Jesus Christ be with you.
28801	1078	24	My love be with you all in Christ Jesus. Amen.
28802	1079	1	PAUL, an apostle of Jesus Christ by the will of God, and Timothy our brother, unto the church of God which is at Corinth, with all the saints which are in all Achaia:
28803	1079	2	Grace be to you and peace from God our Father, and from the Lord Jesus Christ.
28804	1079	3	Blessed be God, even the Father of our Lord Jesus Christ, the Father of mercies, and the God of all comfort;
28805	1079	4	Who comforteth us in all our tribulation, that we may be able to comfort them which are in any trouble, by the comfort wherewith we ourselves are comforted of God.
28806	1079	5	For as the sufferings of Christ abound in us, so our consolation also aboundeth by Christ.
28807	1079	6	And whether we be afflicted, it is for your consolation and salvation, which is effectual in the enduring of the same sufferings which we also suffer: or whether we be comforted, it is for your consolation and salvation.
28808	1079	7	And our hope of you is stedfast, knowing, that as ye are partakers of the sufferings, so shall ye be also of the consolation.
28809	1079	8	For we would not, brethren, have you ignorant of our trouble which came to us in Asia, that we were pressed out of measure, above strength, insomuch that we despaired even of life:
28810	1079	9	But we had the sentence of death in ourselves, that we should not trust in ourselves, but in God which raiseth the dead:
28811	1079	10	Who delivered us from so great a death, and doth deliver: in whom we trust that he will yet deliver us;
28812	1079	11	Ye also helping together by prayer for us, that for the gift bestowed upon us by the means of many persons thanks may be given by many on our behalf.
28813	1079	12	For our rejoicing is this, the testimony of our conscience, that in simplicity and godly sincerity, not with fleshly wisdom, but by the grace of God, we have had our conversation in the world, and more abundantly to you-ward.
28814	1079	13	For we write none other things unto you, than what ye read or acknowledge; and I trust ye shall acknowledge even to the end;
28815	1079	14	As also ye have acknowledged us in part, that we are your rejoicing, even as ye also are ours in the day of the Lord Jesus.
28816	1079	15	And in this confidence I was minded to come unto you before, that ye might have a second benefit;
28817	1079	16	And to pass by you into Macedonia, and to come again out of Macedonia unto you, and of you to be brought on my way toward Judaea.
28818	1079	17	When I therefore was thus minded, did I use lightness? or the things that I purpose, do I purpose according to the flesh, that with me there should be yea yea, and nay nay?
28819	1079	18	But as God is true, our word toward you was not yea and nay.
28820	1079	19	For the Son of God, Jesus Christ, who was preached among you by us, even by me and Silvanus and Timotheus, was not yea and nay, but in him was yea.
28821	1079	20	For all the promises of God in him are yea, and in him Amen, unto the glory of God by us.
28822	1079	21	Now he which stablisheth us with you in Christ, and hath anointed us, is God;
28823	1079	22	Who hath also sealed us, and given the earnest of the Spirit in our hearts.
28824	1079	23	Moreover I call God for a record upon my soul, that to spare you I came not as yet unto Corinth.
28825	1079	24	Not for that we have dominion over your faith, but are helpers of your joy: for by faith ye stand.
28826	1080	1	BUT I determined this with myself, that I would not come again to you in heaviness.
28827	1080	2	For if I make you sorry, who is he then that maketh me glad, but the same which is made sorry by me?
28828	1080	3	And I wrote this same unto you, lest, when I came, I should have sorrow from them of whom I ought to rejoice; having confidence in you all, that my joy is the joy of you all.
28829	1080	4	For out of much affliction and anguish of heart I wrote unto you with many tears; not that ye should be grieved, but that ye might know the love which I have more abundantly unto you.
28830	1080	5	But if any have caused grief, he hath not grieved me, but in part: that I may not overcharge you all.
28831	1080	6	Sufficient to such a man is this punishment, which was inflicted of many.
28832	1080	7	So that contrariwise ye ought rather to forgive him, and comfort him, lest perhaps such a one should be swallowed up with overmuch sorrow.
28833	1080	8	Wherefore I beseech you that ye would confirm your love toward him.
28834	1080	9	For to this end also did I write, that I might know the proof of you, whether ye be obedient in all things.
28835	1080	10	To whom ye forgive any thing, I forgive also: for if I forgave any thing, to whom I forgave it, for your sakes forgave I it in the person of Christ;
28836	1080	11	Lest Satan should get an advantage of us: for we are not ignorant of his devices.
28837	1080	12	Furthermore, when I came to Troas to preach Christ's gospel, and a door was opened unto me of the Lord,
28838	1080	13	I had no rest in my spirit, because I found not Titus my brother: but taking my leave of them, I went from thence into Macedonia.
28839	1080	14	Now thanks be unto God, which always causeth us to triumph in Christ, and maketh manifest the savour of his knowledge by us in every place.
28840	1080	15	For we are unto God a sweet savour of Christ, in them that are saved, and in them that perish:
28841	1080	16	To the one we are the savour of death unto death; and to the other the savour of life unto life. And who is sufficient for these things?
28842	1080	17	For we are not as many, which corrupt the word of God: but as of sincerity, but as of God, in the sight of God speak we in Christ.
28843	1081	1	DO we begin again to commend ourselves? or need we, as some others, epistles of commendation to you, or letters of commendation from you?
28844	1081	2	Ye are our epistle written in our hearts, known and read of all men:
28845	1081	3	Forasmuch as ye are manifestly declared to be the epistle of Christ ministered by us, written not with ink, but with the Spirit of the living God; not in tables of stone, but in fleshy tables of the heart.
28846	1081	4	And such trust have we through Christ to God-ward:
28847	1081	5	Not that we are sufficient of ourselves to think any thing as of ourselves; but our sufficiency is of God;
28848	1081	6	Who also hath made us able ministers of the new testament; not of the letter, but of the spirit: for the letter killeth, but the spirit giveth life.
28849	1081	7	But if the ministration of death, written and engraven in stones, was glorious, so that the children of Israel could not stedfastly behold the face of Moses for the glory of his countenance; which glory was to be done away:
28850	1081	8	How shall not the ministration of the spirit be rather glorious?
28851	1081	9	For if the ministration of condemnation be glory, much more doth the ministration of righteousness exceed in glory.
28852	1081	10	For even that which was made glorious had no glory in this respect, by reason of the glory that excelleth.
28853	1081	11	For if that which is done away was glorious, much more that which remaineth is glorious.
28854	1081	12	Seeing then that we have such hope, we use great plainness of speech:
28855	1081	13	And not as Moses, which put a vail over his face, that the children of Israel could not stedfastly look to the end of that which is abolished:
28856	1081	14	But their minds were blinded: for until this day remaineth the same vail untaken away in the reading of the old testament; which vail is done away in Christ.
28857	1081	15	But even unto this day, when Moses is read, the vail is upon their heart.
28858	1081	16	Nevertheless when it shall turn to the Lord, the vail shall be taken away.
28859	1081	17	Now the Lord is that Spirit: and where the Spirit of the Lord is, there is liberty.
28860	1081	18	But we all, with open face beholding as in a glass the glory of the Lord, are changed into the same image from glory to glory, even as by the Spirit of the Lord.
28861	1082	1	THEREFORE seeing we have this ministry, as we have received mercy, we faint not;
28862	1082	2	But have renounced the hidden things of dishonesty, not walking in craftiness, nor handling the word of God deceitfully; but by manifestation of the truth commending ourselves to every man's conscience in the sight of God.
28863	1082	3	But if our gospel be hid, it is hid to them that are lost:
28864	1082	4	In whom the god of this world hath blinded the minds of them which believe not, lest the light of the glorious gospel of Christ, who is the image of God, should shine unto them.
28865	1082	5	For we preach not ourselves, but Christ Jesus the Lord; and ourselves your servants for Jesus' sake.
28866	1082	6	For God, who commanded the light to shine out of darkness, hath shined in our hearts, to give the light of the knowledge of the glory of God in the face of Jesus Christ.
28867	1082	7	But we have this treasure in earthen vessels, that the excellency of the power may be of God, and not of us.
28868	1082	8	We are troubled on every side, yet not distressed; we are perplexed, but not in despair;
28869	1082	9	Persecuted, but not forsaken; cast down, but not destroyed;
28870	1082	10	Always bearing about in the body the dying of the Lord Jesus, that the life also of Jesus might be made manifest in our body.
28871	1082	11	For we which live are alway delivered unto death for Jesus' sake, that the life also of Jesus might be made manifest in our mortal flesh.
28872	1082	12	So then death worketh in us, but life in you.
28873	1082	13	We having the same spirit of faith, according as it is written, I believed, and therefore have I spoken; we also believe, and therefore speak;
28874	1082	14	Knowing that he which raised up the Lord Jesus shall raise up us also by Jesus, and shall present us with you.
28875	1082	15	For all things are for your sakes, that the abundant grace might through the thanksgiving of many redound to the glory of God.
28876	1082	16	For which cause we faint not; but though our outward man perish, yet the inward man is renewed day by day.
28877	1082	17	For our light affliction, which is but for a moment, worketh for us a far more exceeding and eternal weight of glory;
28878	1082	18	While we look not at the things which are seen, but at the things which are not seen: for the things which are seen are temporal; but the things which are not seen are eternal.
28879	1083	1	FOR we know that if our earthly house of this tabernacle were dissolved, we have a building of God, an house not made with hands, eternal in the heavens.
28880	1083	2	For in this we groan, earnestly desiring to be clothed upon with our house which is from heaven:
28881	1083	3	If so be that being clothed we shall not be found naked.
28882	1083	4	For we that are in this tabernacle do groan, being burdened: not for that we would be unclothed, but clothed upon, that mortality might be swallowed up of life.
28883	1083	5	Now he that hath wrought us for the selfsame thing is God, who also hath given unto us the earnest of the Spirit.
28884	1083	6	Therefore we are always confident, knowing that, whilst we are at home in the body, we are absent from the Lord:
28885	1083	7	(For we walk by faith, not by sight:)
28886	1083	8	We are confident, I say, and willing rather to be absent from the body, and to be present with the Lord.
28887	1083	9	Wherefore we labour, that, whether present or absent, we may be accepted of him.
28888	1083	10	For we must all appear before the judgment seat of Christ; that every one may receive the things done in his body, according to that he hath done, whether it be good or bad.
28889	1083	11	Knowing therefore the terror of the Lord, we persuade men; but we are made manifest unto God; and I trust also are made manifest in your consciences.
28890	1083	12	For we commend not ourselves again unto you, but give you occasion to glory on our behalf, that ye may have somewhat to answer them which glory in appearance, and not in heart.
28891	1083	13	For whether we be beside ourselves, it is to God: or whether we be sober, it is for your cause.
28892	1083	14	For the love of Christ constraineth us; because we thus judge, that if one died for all, then were all dead:
28893	1083	15	And that he died for all, that they which live should not henceforth live unto themselves, but unto him which died for them, and rose again.
28894	1083	16	Wherefore henceforth know we no man after the flesh: yea, though we have known Christ after the flesh, yet now henceforth know we him no more.
28895	1083	17	Therefore if any man be in Christ, he is a new creature: old things are passed away; behold, all things are become new.
28896	1083	18	And all things are of God, who hath reconciled us to himself by Jesus Christ, and hath given to us the ministry of reconciliation;
28897	1083	19	To wit, that God was in Christ, reconciling the world unto himself, not imputing their trespasses unto them; and hath committed unto us the word of reconciliation.
28898	1083	20	Now then we are ambassadors for Christ, as though God did beseech you by us: we pray you in Christ's stead, be ye reconciled to God.
28899	1083	21	For he hath made him to be sin for us, who knew no sin; that we might be made the righteousness of God in him.
28900	1084	1	WE then, as workers together with him, beseech you also that ye receive not the grace of God in vain.
28901	1084	2	(For he saith, I have heard thee in a time accepted, and in the day of salvation have I succoured thee: behold, now is the accepted time; behold, now is the day of salvation.)
28902	1084	3	Giving no offence in any thing, that the ministry be not blamed:
28903	1084	4	But in all things approving ourselves as the ministers of God, in much patience, in afflictions, in necessities, in distresses,
28904	1084	5	In stripes, in imprisonments, in tumults, in labours, in watchings, in fastings;
28905	1084	6	By pureness, by knowledge, by longsuffering, by kindness, by the Holy Ghost, by love unfeigned,
28906	1084	7	By the word of truth, by the power of God, by the armour of righteousness on the right hand and on the left,
28907	1084	8	By honour and dishonour, by evil report and good report: as deceivers, and yet true;
28908	1084	9	As unknown, and yet well known; as dying, and, behold, we live; as chastened, and not killed;
28909	1084	10	As sorrowful, yet alway rejoicing; as poor, yet making many rich; as having nothing, and yet possessing all things.
28910	1084	11	O ye Corinthians, our mouth is open unto you, our heart is enlarged.
28911	1084	12	Ye are not straitened in us, but ye are straitened in your own bowels.
28912	1084	13	Now for a recompence in the same, (I speak as unto my children,) be ye also enlarged.
28913	1084	14	Be ye not unequally yoked together with unbelievers: for what fellowship hath righteousness with unrighteousness? and what communion hath light with darkness?
28914	1084	15	And what concord hath Christ with Belial? or what part hath he that believeth with an infidel?
28915	1084	16	And what agreement hath the temple of God with idols? for ye are the temple of the living God; as God hath said, I will dwell in them, and walk in them; and I will be their God, and they shall be my people.
28916	1084	17	Wherefore come out from among them, and be ye separate, saith the Lord, and touch not the unclean thing; and I will receive you,
28917	1084	18	And will be a Father unto you, and ye shall be my sons and daughters, saith the Lord Almighty.
28918	1085	1	HAVING therefore these promises, dearly beloved, let us cleanse ourselves from all filthiness of the flesh and spirit, perfecting holiness in the fear of God.
28919	1085	2	Receive us; we have wronged no man, we have corrupted no man, we have defrauded no man.
28920	1085	3	I speak not this to condemn you: for I have said before, that ye are in our hearts to die and live with you.
28921	1085	4	Great is my boldness of speech toward you, great is my glorying of you: I am filled with comfort, I am exceeding joyful in all our tribulation.
28922	1085	5	For, when we were come into Macedonia, our flesh had no rest, but we were troubled on every side; without were fightings, within were fears.
28923	1085	6	Nevertheless God, that comforteth those that are cast down, comforted us by the coming of Titus;
28924	1085	7	And not by his coming only, but by the consolation wherewith he was comforted in you, when he told us your earnest desire, your mourning, your fervent mind toward me; so that I rejoiced the more.
28925	1085	8	For though I made you sorry with a letter, I do not repent, though I did repent: for I perceive that the same epistle hath made you sorry, though it were but for a season.
28926	1085	9	Now I rejoice, not that ye were made sorry, but that ye sorrowed to repentance: for ye were made sorry after a godly manner, that ye might receive damage by us in nothing.
28927	1085	10	For godly sorrow worketh repentance to salvation not to be repented of: but the sorrow of the world worketh death.
28928	1085	11	For behold this selfsame thing, that ye sorrowed after a godly sort, what carefulness it wrought in you, yea, what clearing of yourselves, yea, what indignation, yea, what fear, yea, what vehement desire, yea, what zeal, yea, what revenge! In all things ye have approved yourselves to be clear in this matter.
28929	1085	12	Wherefore, though I wrote unto you, I did it not for his cause that had done the wrong, nor for his cause that suffered wrong, but that our care for you in the sight of God might appear unto you.
28930	1085	13	Therefore we were comforted in your comfort: yea, and exceedingly the more joyed we for the joy of Titus, because his spirit was refreshed by you all.
28931	1085	14	For if I have boasted any thing to him of you, I am not ashamed; but as we spake all things to you in truth, even so our boasting, which I made before Titus, is found a truth.
28932	1085	15	And his inward affection is more abundant toward you, whilst he remembereth the obedience of you all, how with fear and trembling ye received him.
28933	1085	16	I rejoice therefore that I have confidence in you in all things.
28934	1086	1	MOREOVER, brethren, we do you to wit of the grace of God bestowed on the churches of Macedonia;
28935	1086	2	How that in a great trial of affliction the abundance of their joy and their deep poverty abounded unto the riches of their liberality.
28936	1086	3	For to their power, I bear record, yea, and beyond their power they were willing of themselves;
28937	1086	4	Praying us with much intreaty that we would receive the gift, and take upon us the fellowship of the ministering to the saints.
28938	1086	5	And this they did, not as we hoped, but first gave their own selves to the Lord, and unto us by the will of God.
28939	1086	6	Insomuch that we desired Titus, that as he had begun, so he would also finish in you the same grace also.
28940	1086	7	Therefore, as ye abound in every thing, in faith, and utterance, and knowledge, and in all diligence, and in your love to us, see that ye abound in this grace also.
28941	1086	8	I speak not by commandment, but by occasion of the forwardness of others, and to prove the sincerity of your love.
28942	1086	9	For ye know the grace of our Lord Jesus Christ, that, though he was rich, yet for your sakes he became poor, that ye through his poverty might be rich.
28943	1086	10	And herein I give my advice: for this is expedient for you, who have begun before, not only to do, but also to be forward a year ago.
28944	1086	11	Now therefore perform the doing of it; that as there was a readiness to will, so there may be a performance also out of that which ye have.
28945	1086	12	For if there be first a willing mind, it is accepted according to that a man hath, and not according to that he hath not.
28946	1086	13	For I mean not that other men be eased, and ye burdened:
28947	1086	14	But by an equality, that now at this time your abundance may be a supply for their want, that their abundance also may be a supply for your want: that there may be equality:
28948	1086	15	As it is written, He that had gathered much had nothing over; and he that had gathered little had no lack.
28949	1086	16	But thanks be to God, which put the same earnest care into the heart of Titus for you.
28950	1086	17	For indeed he accepted the exhortation; but being more forward, of his own accord he went unto you.
28951	1086	18	And we have sent with him the brother, whose praise is in the gospel throughout all the churches;
28952	1086	19	And not that only, but who was also chosen of the churches to travel with us with this grace, which is administered by us to the glory of the same Lord, and declaration of your ready mind:
28953	1086	20	Avoiding this, that no man should blame us in this abundance which is administered by us:
28954	1086	21	Providing for honest things, not only in the sight of the Lord, but also in the sight of men.
28955	1086	22	And we have sent with them our brother, whom we have oftentimes proved diligent in many things, but now much more diligent, upon the great confidence which I have in you.
28956	1086	23	Whether any do enquire of Titus, he is my partner and fellowhelper concerning you: or our brethren be enquired of, they are the messengers of the churches, and the glory of Christ.
28957	1086	24	Wherefore shew ye to them, and before the churches, the proof of your love, and of our boasting on your behalf.
28958	1087	1	FOR as touching the ministering to the saints, it is superfluous for me to write to you:
28959	1087	2	For I know the forwardness of your mind, for which I boast of you to them of Macedonia, that Achaia was ready a year ago; and your zeal hath provoked very many.
28960	1087	3	Yet have I sent the brethren, lest our boasting of you should be in vain in this behalf; that, as I said, ye may be ready:
28961	1087	4	Lest haply if they of Macedonia come with me, and find you unprepared, we (that we say not, ye) should be ashamed in this same confident boasting.
28962	1087	5	Therefore I thought it necessary to exhort the brethren, that they would go before unto you, and make up beforehand your bounty, whereof ye had notice before, that the same might be ready, as a matter of bounty, and not as of covetousness.
28963	1087	6	But this I say, He which soweth sparingly shall reap also sparingly; and he which soweth bountifully shall reap also bountifully.
28964	1087	7	Every man according as he purposeth in his heart, so let him give; not grudgingly, or of necessity: for God loveth a cheerful giver.
28965	1087	8	And God is able to make all grace abound toward you; that ye, always having all sufficiency in all things, may abound to every good work:
28966	1087	9	(As it is written, He hath dispersed abroad; he hath given to the poor: his righteousness remaineth for ever.
28967	1087	10	Now he that ministereth seed to the sower both minister bread for your food, and multiply your seed sown, and increase the fruits of your righteousness;)
28968	1087	11	Being enriched in every thing to all bountifulness, which causeth through us thanksgiving to God.
28969	1087	12	For the administration of this service not only supplieth the want of the saints, but is abundant also by many thanksgivings unto God;
28970	1087	13	Whiles by the experiment of this ministration they glorify God for your professed subjection unto the gospel of Christ, and for your liberal distribution unto them, and unto all men;
28971	1087	14	And by their prayer for you, which long after you for the exceeding grace of God in you.
28972	1087	15	Thanks be unto God for his unspeakable gift.
28973	1088	1	NOW I Paul myself beseech you by the meekness and gentleness of Christ, who in presence am base among you, but being absent am bold toward you:
28974	1088	2	But I beseech you, that I may not be bold when I am present with that confidence, wherewith I think to be bold against some, which think of us as if we walked according to the flesh.
28975	1088	3	For though we walk in the flesh, we do not war after the flesh:
28976	1088	4	(For the weapons of our warfare are not carnal, but mighty through God to the pulling down of strong holds;)
28977	1088	5	Casting down imaginations, and every high thing that exalteth itself against the knowledge of God, and bringing into captivity every thought to the obedience of Christ;
28978	1088	6	And having in a readiness to revenge all disobedience, when your obedience is fulfilled.
28979	1088	7	Do ye look on things after the outward appearance? If any man trust to himself that he is Christ's, let him of himself think this again, that, as he is Christ's, even so are we Christ's.
28980	1088	8	For though I should boast somewhat more of our authority, which the Lord hath given us for edification, and not for your destruction, I should not be ashamed:
28981	1088	9	That I may not seem as if I would terrify you by letters.
28982	1088	10	For his letters, say they, are weighty and powerful; but his bodily presence is weak, and his speech contemptible.
28983	1088	11	Let such an one think this, that, such as we are in word by letters when we are absent, such will we be also in deed when we are present.
28984	1088	12	For we dare not make ourselves of the number, or compare ourselves with some that commend themselves: but they measuring themselves by themselves, and comparing themselves among themselves, are not wise.
28985	1088	13	But we will not boast of things without our measure, but according to the measure of the rule which God hath distributed to us, a measure to reach even unto you.
28986	1088	14	For we stretch not ourselves beyond our measure, as though we reached not unto you: for we are come as far as to you also in preaching the gospel of Christ:
28987	1088	15	Not boasting of things without our measure, that is, of other men's labours; but having hope, when your faith is increased, that we shall be enlarged by you according to our rule abundantly,
28988	1088	16	To preach the gospel in the regions beyond you, and not to boast in another man's line of things made ready to our hand.
28989	1088	17	But he that glorieth, let him glory in the Lord.
28990	1088	18	For not he that commendeth himself is approved, but whom the Lord commendeth.
28991	1089	1	WOULD to God ye could bear with me a little in my folly: and indeed bear with me.
28992	1089	2	For I am jealous over you with godly jealousy: for I have espoused you to one husband, that I may present you as a chaste virgin to Christ.
28993	1089	3	But I fear, lest by any means, as the serpent beguiled Eve through his subtilty, so your minds should be corrupted from the simplicity that is in Christ.
28994	1089	4	For if he that cometh preacheth another Jesus, whom we have not preached, or if ye receive another spirit, which ye have not received, or another gospel, which ye have not accepted, ye might well bear with him.
28995	1089	5	For I suppose I was not a whit behind the very chiefest apostles.
28996	1089	6	But though I be rude in speech, yet not in knowledge; but we have been throughly made manifest among you in all things.
28997	1089	7	Have I committed an offence in abasing myself that ye might be exalted, because I have preached to you the gospel of God freely?
28998	1089	8	I robbed other churches, taking wages of them, to do you service.
28999	1089	9	And when I was present with you, and wanted, I was chargeable to no man: for that which was lacking to me the brethren which came from Macedonia supplied: and in all things I have kept myself from being burdensome unto you, and so will I keep myself.
29000	1089	10	As the truth of Christ is in me, no man shall stop me of this boasting in the regions of Achaia.
29001	1089	11	Wherefore? because I love you not? God knoweth.
29002	1089	12	But what I do, that I will do, that I may cut off occasion from them which desire occasion; that wherein they glory, they may be found even as we.
29003	1089	13	For such are false apostles, deceitful workers, transforming themselves into the apostles of Christ.
29004	1089	14	And no marvel; for Satan himself is transformed into an angel of light.
29005	1089	15	Therefore it is no great thing if his ministers also be transformed as the ministers of righteousness; whose end shall be according to their works.
29006	1089	16	I say again, Let no man think me a fool; if otherwise, yet as a fool receive me, that I may boast myself a little.
29007	1089	17	That which I speak, I speak it not after the Lord, but as it were foolishly, in this confidence of boasting.
29008	1089	18	Seeing that many glory after the flesh, I will glory also.
29009	1089	19	For ye suffer fools gladly, seeing ye yourselves are wise.
29010	1089	20	For ye suffer, if a man bring you into bondage, if a man devour you, if a man take of you, if a man exalt himself, if a man smite you on the face.
29011	1089	21	I speak as concerning reproach, as though we had been weak. Howbeit whereinsoever any is bold, (I speak foolishly,) I am bold also.
29012	1089	22	Are they Hebrews? so am I. Are they Israelites? so am I. Are they the seed of Abraham? so am I.
29013	1089	23	Are they ministers of Christ? (I speak as a fool) I am more; in labours more abundant, in stripes above measure, in prisons more frequent, in deaths oft.
29014	1089	24	Of the Jews five times received I forty stripes save one.
29015	1089	25	Thrice was I beaten with rods, once was I stoned, thrice I suffered shipwreck, a night and a day I have been in the deep;
29016	1089	26	In journeyings often, in perils of waters, in perils of robbers, in perils by mine own countrymen, in perils by the heathen, in perils in the city, in perils in the wilderness, in perils in the sea, in perils among false brethren;
29017	1089	27	In weariness and painfulness, in watchings often, in hunger and thirst, in fastings often, in cold and nakedness.
29018	1089	28	Beside those things that are without, that which cometh upon me daily, the care of all the churches.
29019	1089	29	Who is weak, and I am not weak? who is offended, and I burn not?
29020	1089	30	If I must needs glory, I will glory of the things which concern mine infirmities.
29021	1089	31	The God and Father of our Lord Jesus Christ, which is blessed for evermore, knoweth that I lie not.
29022	1089	32	In Damascus the governor under Aretas the king kept the city of the Damascenes with a garrison, desirous to apprehend me:
29023	1089	33	And through a window in a basket was I let down by the wall, and escaped his hands.
29024	1090	1	IT is not expedient for me doubtless to glory. I will come to visions and revelations of the Lord.
29025	1090	2	I knew a man in Christ above fourteen years ago, (whether in the body, I cannot tell; or whether out of the body, I cannot tell: God knoweth;) such an one caught up to the third heaven.
29026	1090	3	And I knew such a man, (whether in the body, or out of the body, I cannot tell: God knoweth;)
29027	1090	4	How that he was caught up into paradise, and heard unspeakable words, which it is not lawful for a man to utter.
29028	1090	5	Of such an one will I glory: yet of myself I will not glory, but in mine infirmities.
29029	1090	6	For though I would desire to glory, I shall not be a fool; for I will say the truth: but now I forbear, lest any man should think of me above that which he seeth me to be, or that he heareth of me.
29030	1090	7	And lest I should be exalted above measure through the abundance of the revelations, there was given to me a thorn in the flesh, the messenger of Satan to buffet me, lest I should be exalted above measure.
29031	1090	8	For this thing I besought the Lord thrice, that it might depart from me.
29032	1090	9	And he said unto me, My grace is sufficient for thee: for my strength is made perfect in weakness. Most gladly therefore will I rather glory in my infirmities, that the power of Christ may rest upon me.
29033	1090	10	Therefore I take pleasure in infirmities, in reproaches, in necessities, in persecutions, in distresses for Christ's sake: for when I am weak, then am I strong.
29034	1090	11	I am become a fool in glorying; ye have compelled me: for I ought to have been commended of you: for in nothing am I behind the very chiefest apostles, though I be nothing.
29035	1090	12	Truly the signs of an apostle were wrought among you in all patience, in signs, and wonders, and mighty deeds.
29036	1090	13	For what is it wherein ye were inferior to other churches, except it be that I myself was not burdensome to you? forgive me this wrong.
29037	1090	14	Behold, the third time I am ready to come to you; and I will not be burdensome to you: for I seek not yours, but you: for the children ought not to lay up for the parents, but the parents for the children.
29038	1090	15	And I will very gladly spend and be spent for you; though the more abundantly I love you, the less I be loved.
29039	1090	16	But be it so, I did not burden you: nevertheless, being crafty, I caught you with guile.
29040	1090	17	Did I make a gain of you by any of them whom I sent unto you?
29041	1090	18	I desired Titus, and with him I sent a brother. Did Titus make a gain of you? walked we not in the same spirit? walked we not in the same steps?
29042	1090	19	Again, think ye that we excuse ourselves unto you? we speak before God in Christ: but we do all things, dearly beloved, for your edifying.
29043	1090	20	For I fear, lest, when I come, I shall not find you such as I would, and that I shall be found unto you such as ye would not: lest there be debates, envyings, wraths, strifes, backbitings, whisperings, swellings, tumults:
29044	1090	21	And lest, when I come again, my God will humble me among you, and that I shall bewail many which have sinned already, and have not repented of the uncleanness and fornication and lasciviousness which they have committed.
29045	1091	1	THIS is the third time I am coming to you. In the mouth of two or three witnesses shall every word be established.
29046	1091	2	I told you before, and foretell you, as if I were present, the second time; and being absent now I write to them which heretofore have sinned, and to all other, that, if I come again, I will not spare:
29047	1091	3	Since ye seek a proof of Christ speaking in me, which to you-ward is not weak, but is mighty in you.
29048	1091	4	For though he was crucified through weakness, yet he liveth by the power of God. For we also are weak in him, but we shall live with him by the power of God toward you.
29049	1091	5	Examine yourselves, whether ye be in the faith; prove your own selves. Know ye not your own selves, how that Jesus Christ is in you, except ye be reprobates?
29050	1091	6	But I trust that ye shall know that we are not reprobates.
29051	1091	7	Now I pray to God that ye do no evil; not that we should appear approved, but that ye should do that which is honest, though we be as reprobates.
29052	1091	8	For we can do nothing against the truth, but for the truth.
29053	1091	9	For we are glad, when we are weak, and ye are strong: and this also we wish, even your perfection.
29054	1091	10	Therefore I write these things being absent, lest being present I should use sharpness, according to the power which the Lord hath given me to edification, and not to destruction.
29055	1091	11	Finally, brethren, farewell. Be perfect, be of good comfort, be of one mind, live in peace; and the God of love and peace shall be with you.
29056	1091	12	Greet one another with an holy kiss.
29057	1091	13	All the saints salute you.
29058	1091	14	The grace of the Lord Jesus Christ, and the love of God, and the communion of the Holy Ghost, be with you all. Amen.
29059	1092	1	PAUL, an apostle, (not of men, neither by man, but by Jesus Christ, and God the Father, who raised him from the dead;)
29060	1092	2	And all the brethren which are with me, unto the churches of Galatia:
29061	1092	3	Grace be to you and peace from God the Father, and from our Lord Jesus Christ,
29062	1092	4	Who gave himself for our sins, that he might deliver us from this present evil world, according to the will of God and our Father:
29063	1092	5	To whom be glory for ever and ever. Amen.
29064	1092	6	I marvel that ye are so soon removed from him that called you into the grace of Christ unto another gospel:
29065	1092	7	Which is not another; but there be some that trouble you, and would pervert the gospel of Christ.
29066	1092	8	But though we, or an angel from heaven, preach any other gospel unto you than that which we have preached unto you, let him be accursed.
29067	1092	9	As we said before, so say I now again, If any man preach any other gospel unto you than that ye have received, let him be accursed.
29068	1092	10	For do I now persuade men, or God? or do I seek to please men? for if I yet pleased men, I should not be the servant of Christ.
29069	1092	11	But I certify you, brethren, that the gospel which was preached of me is not after man.
29070	1092	12	For I neither received it of man, neither was I taught it, but by the revelation of Jesus Christ.
29071	1092	13	For ye have heard of my conversation in time past in the Jews' religion, how that beyond measure I persecuted the church of God, and wasted it:
29072	1092	14	And profited in the Jews' religion above many my equals in mine own nation, being more exceedingly zealous of the traditions of my fathers.
29073	1092	15	But when it pleased God, who separated me from my mother's womb, and called me by his grace,
29074	1092	16	To reveal his Son in me, that I might preach him among the heathen; immediately I conferred not with flesh and blood:
29075	1092	17	Neither went I up to Jerusalem to them which were apostles before me; but I went into Arabia, and returned again unto Damascus.
29076	1092	18	Then after three years I went up to Jerusalem to see Peter, and abode with him fifteen days.
29077	1092	19	But other of the apostles saw I none, save James the Lord's brother.
29078	1092	20	Now the things which I write unto you, behold, before God, I lie not.
29079	1092	21	Afterwards I came into the regions of Syria and Cilicia;
29080	1092	22	And was unknown by face unto the churches of Judaea which were in Christ:
29081	1092	23	But they had heard only, That he which persecuted us in times past now preacheth the faith which once he destroyed.
29082	1092	24	And they glorified God in me.
29083	1093	1	THEN fourteen years after I went up again to Jerusalem with Barnabas, and took Titus with me also.
29084	1093	2	And I went up by revelation, and communicated unto them that gospel which I preach among the Gentiles, but privately to them which were of reputation, lest by any means I should run, or had run, in vain.
29085	1093	3	But neither Titus, who was with me, being a Greek, was compelled to be circumcised:
29086	1093	4	And that because of false brethren unawares brought in, who came in privily to spy out our liberty which we have in Christ Jesus, that they might bring us into bondage:
29087	1093	5	To whom we gave place by subjection, no, not for an hour; that the truth of the gospel might continue with you.
29088	1093	6	But of these who seemed to be somewhat, (whatsoever they were, it maketh no matter to me: God accepteth no man's person:) for they who seemed to be somewhat in conference added nothing to me:
29089	1093	7	But contrariwise, when they saw that the gospel of the uncircumcision was committed unto me, as the gospel of the circumcision was unto Peter;
29090	1093	8	(For he that wrought effectually in Peter to the apostleship of the circumcision, the same was mighty in me toward the Gentiles:)
29091	1093	9	And when James, Cephas, and John, who seemed to be pillars, perceived the grace that was given unto me, they gave to me and Barnabas the right hands of fellowship; that we should go unto the heathen, and they unto the circumcision.
29092	1093	10	Only they would that we should remember the poor; the same which I also was forward to do.
29093	1093	11	But when Peter was come to Antioch, I withstood him to the face, because he was to be blamed.
29094	1093	12	For before that certain came from James, he did eat with the Gentiles: but when they were come, he withdrew and separated himself, fearing them which were of the circumcision.
29095	1093	13	And the other Jews dissembled likewise with him; insomuch that Barnabas also was carried away with their dissimulation.
29096	1093	14	But when I saw that they walked not uprightly according to the truth of the gospel, I said unto Peter before them all, If thou, being a Jew, livest after the manner of Gentiles, and not as do the Jews, why compellest thou the Gentiles to live as do the Jews?
29097	1093	15	We who are Jews by nature, and not sinners of the Gentiles,
29098	1093	16	Knowing that a man is not justified by the works of the law, but by the faith of Jesus Christ, even we have believed in Jesus Christ, that we might be justified by the faith of Christ, and not by the works of the law: for by the works of the law shall no flesh be justified.
29099	1093	17	But if, while we seek to be justified by Christ, we ourselves also are found sinners, is therefore Christ the minister of sin? God forbid.
29100	1093	18	For if I build again the things which I destroyed, I make myself a transgressor.
29101	1093	19	For I through the law am dead to the law, that I might live unto God.
29102	1093	20	I am crucified with Christ: nevertheless I live; yet not I, but Christ liveth in me: and the life which I now live in the flesh I live by the faith of the Son of God, who loved me, and gave himself for me.
29103	1093	21	I do not frustrate the grace of God: for if righteousness come by the law, then Christ is dead in vain.
29104	1094	1	O FOOLISH Galatians, who hath bewitched you, that ye should not obey the truth, before whose eyes Jesus Christ hath been evidently set forth, crucified among you?
29105	1094	2	This only would I learn of you, Received ye the Spirit by the works of the law, or by the hearing of faith?
29106	1094	3	Are ye so foolish? having begun in the Spirit, are ye now made perfect by the flesh?
29107	1094	4	Have ye suffered so many things in vain? if it be yet in vain.
29108	1094	5	He therefore that ministereth to you the Spirit, and worketh miracles among you, doeth he it by the works of the law, or by the hearing of faith?
29109	1094	6	Even as Abraham believed God, and it was accounted to him for righteousness.
29110	1094	7	Know ye therefore that they which are of faith, the same are the children of Abraham.
29111	1094	8	And the scripture, foreseeing that God would justify the heathen through faith, preached before the gospel unto Abraham, saying, In thee shall all nations be blessed.
29112	1094	9	So then they which be of faith are blessed with faithful Abraham.
29113	1094	10	For as many as are of the works of the law are under the curse: for it is written, Cursed is every one that continueth not in all things which are written in the book of the law to do them.
29114	1094	11	But that no man is justified by the law in the sight of God, it is evident: for, The just shall live by faith.
29115	1094	12	And the law is not of faith: but, The man that doeth them shall live in them.
29116	1094	13	Christ hath redeemed us from the curse of the law, being made a curse for us: for it is written, Cursed is every one that hangeth on a tree:
29117	1094	14	That the blessing of Abraham might come on the Gentiles through Jesus Christ; that we might receive the promise of the Spirit through faith.
29118	1094	15	Brethren, I speak after the manner of men; Though it be but a man's covenant, yet if it be confirmed, no man disannulleth, or addeth thereto.
29119	1094	16	Now to Abraham and his seed were the promises made. He saith not, And to seeds, as of many; but as of one, And to thy seed, which is Christ.
29120	1094	17	And this I say, that the covenant, that was confirmed before of God in Christ, the law, which was four hundred and thirty years after, cannot disannul, that it should make the promise of none effect.
29121	1094	18	For if the inheritance be of the law, it is no more of promise: but God gave it to Abraham by promise.
29122	1094	19	Wherefore then serveth the law? It was added because of transgressions, till the seed should come to whom the promise was made; and it was ordained by angels in the hand of a mediator.
29123	1094	20	Now a mediator is not a mediator of one, but God is one.
29124	1094	21	Is the law then against the promises of God? God forbid: for if there had been a law given which could have given life, verily righteousness should have been by the law.
29125	1094	22	But the scripture hath concluded all under sin, that the promise by faith of Jesus Christ might be given to them that believe.
29126	1094	23	But before faith came, we were kept under the law, shut up unto the faith which should afterwards be revealed.
29127	1094	24	Wherefore the law was our schoolmaster to bring us unto Christ, that we might be justified by faith.
29128	1094	25	But after that faith is come, we are no longer under a schoolmaster.
29129	1094	26	For ye are all the children of God by faith in Christ Jesus.
29130	1094	27	For as many of you as have been baptized into Christ have put on Christ.
29131	1094	28	There is neither Jew nor Greek, there is neither bond nor free, there is neither male nor female: for ye are all one in Christ Jesus.
29132	1094	29	And if ye be Christ's, then are ye Abraham's seed, and heirs according to the promise.
29133	1095	1	NOW I say, That the heir, as long as he is a child, differeth nothing from a servant, though he be lord of all;
29134	1095	2	But is under tutors and governors until the time appointed of the father.
29135	1095	3	Even so we, when we were children, were in bondage under the elements of the world:
29136	1095	4	But when the fulness of the time was come, God sent forth his Son, made of a woman, made under the law,
29137	1095	5	To redeem them that were under the law, that we might receive the adoption of sons.
29138	1095	6	And because ye are sons, God hath sent forth the Spirit of his Son into your hearts, crying, Abba, Father.
29139	1095	7	Wherefore thou art no more a servant, but a son; and if a son, then an heir of God through Christ.
29140	1095	8	Howbeit then, when ye knew not God, ye did service unto them which by nature are no gods.
29141	1095	9	But now, after that ye have known God, or rather are known of God, how turn ye again to the weak and beggarly elements, whereunto ye desire again to be in bondage?
29142	1095	10	Ye observe days, and months, and times, and years.
29143	1095	11	I am afraid of you, lest I have bestowed upon you labour in vain.
29144	1095	12	Brethren, I beseech you, be as I am; for I am as ye are: ye have not injured me at all.
29145	1095	13	Ye know how through infirmity of the flesh I preached the gospel unto you at the first.
29146	1095	14	And my temptation which was in my flesh ye despised not, nor rejected; but received me as an angel of God, even as Christ Jesus.
29147	1095	15	Where is then the blessedness ye spake of? for I bear you record, that, if it had been possible, ye would have plucked out your own eyes, and have given them to me.
29148	1095	16	Am I therefore become your enemy, because I tell you the truth?
29149	1095	17	They zealously affect you, but not well; yea, they would exclude you, that ye might affect them.
29150	1095	18	But it is good to be zealously affected always in a good thing, and not only when I am present with you.
29151	1095	19	My little children, of whom I travail in birth again until Christ be formed in you,
29152	1095	20	I desire to be present with you now, and to change my voice; for I stand in doubt of you.
29153	1095	21	Tell me, ye that desire to be under the law, do ye not hear the law?
29154	1095	22	For it is written, that Abraham had two sons, the one by a bondmaid, the other by a freewoman.
29155	1095	23	But he who was of the bondwoman was born after the flesh; but he of the freewoman was by promise.
29156	1095	24	Which things are an allegory: for these are the two covenants; the one from the mount Sinai, which gendereth to bondage, which is Agar.
29157	1095	25	For this Agar is mount Sinai in Arabia, and answereth to Jerusalem which now is, and is in bondage with her children.
29158	1095	26	But Jerusalem which is above is free, which is the mother of us all.
29159	1095	27	For it is written, Rejoice, thou barren that bearest not; break forth and cry, thou that travailest not: for the desolate hath many more children than she which hath an husband.
29160	1095	28	Now we, brethren, as Isaac was, are the children of promise.
29161	1095	29	But as then he that was born after the flesh persecuted him that was born after the Spirit, even so it is now.
29162	1095	30	Nevertheless what saith the scripture? Cast out the bondwoman and her son: for the son of the bondwoman shall not be heir with the son of the freewoman.
29163	1095	31	So then, brethren, we are not children of the bondwoman, but of the free.
29164	1096	1	STAND fast therefore in the liberty wherewith Christ hath made us free, and be not entangled again with the yoke of bondage.
29165	1096	2	Behold, I Paul say unto you, that if ye be circumcised, Christ shall profit you nothing.
29166	1096	3	For I testify again to every man that is circumcised, that he is a debtor to do the whole law.
29167	1096	4	Christ is become of no effect unto you, whosoever of you are justified by the law; ye are fallen from grace.
29168	1096	5	For we through the Spirit wait for the hope of righteousness by faith.
29169	1096	6	For in Jesus Christ neither circumcision availeth any thing, nor uncircumcision; but faith which worketh by love.
29170	1096	7	Ye did run well; who did hinder you that ye should not obey the truth?
29171	1096	8	This persuasion cometh not of him that calleth you.
29172	1096	9	A little leaven leaveneth the whole lump.
29173	1096	10	I have confidence in you through the Lord, that ye will be none otherwise minded: but he that troubleth you shall bear his judgment, whosoever he be.
29174	1096	11	And I, brethren, if I yet preach circumcision, why do I yet suffer persecution? then is the offence of the cross ceased.
29175	1096	12	I would they were even cut off which trouble you.
29176	1096	13	For, brethren, ye have been called unto liberty; only use not liberty for an occasion to the flesh, but by love serve one another.
29177	1096	14	For all the law is fulfilled in one word, even in this; Thou shalt love thy neighbour as thyself.
29178	1096	15	But if ye bite and devour one another, take heed that ye be not consumed one of another.
29179	1096	16	This I say then, Walk in the Spirit, and ye shall not fulfil the lust of the flesh.
29180	1096	17	For the flesh lusteth against the Spirit, and the Spirit against the flesh: and these are contrary the one to the other: so that ye cannot do the things that ye would.
29181	1096	18	But if ye be led of the Spirit, ye are not under the law.
29182	1096	19	Now the works of the flesh are manifest, which are these; Adultery, fornication, uncleanness, lasciviousness,
29183	1096	20	Idolatry, witchcraft, hatred, variance, emulations, wrath, strife, seditions, heresies,
29184	1096	21	Envyings, murders, drunkenness, revellings, and such like: of the which I tell you before, as I have also told you in time past, that they which do such things shall not inherit the kingdom of God.
29185	1096	22	But the fruit of the Spirit is love, joy, peace, longsuffering, gentleness, goodness, faith,
29186	1096	23	Meekness, temperance: against such there is no law.
29187	1096	24	And they that are Christ's have crucified the flesh with the affections and lusts.
29188	1096	25	If we live in the Spirit, let us also walk in the Spirit.
29189	1096	26	Let us not be desirous of vain glory, provoking one another, envying one another.
29190	1097	1	BRETHREN, if a man be overtaken in a fault, ye which are spiritual, restore such an one in the spirit of meekness; considering thyself, lest thou also be tempted.
29191	1097	2	Bear ye one another's burdens, and so fulfil the law of Christ.
29192	1097	3	For if a man think himself to be something, when he is nothing, he deceiveth himself.
29193	1097	4	But let every man prove his own work, and then shall he have rejoicing in himself alone, and not in another.
29194	1097	5	For every man shall bear his own burden.
29195	1097	6	Let him that is taught in the word communicate unto him that teacheth in all good things.
29196	1097	7	Be not deceived; God is not mocked: for whatsoever a man soweth, that shall he also reap.
29197	1097	8	For he that soweth to his flesh shall of the flesh reap corruption; but he that soweth to the Spirit shall of the Spirit reap life everlasting.
29198	1097	9	And let us not be weary in well doing: for in due season we shall reap, if we faint not.
29199	1097	10	As we have therefore opportunity, let us do good unto all men, especially unto them who are of the household of faith.
29200	1097	11	Ye see how large a letter I have written unto you with mine own hand.
29201	1097	12	As many as desire to make a fair shew in the flesh, they constrain you to be circumcised; only lest they should suffer persecution for the cross of Christ.
29202	1097	13	For neither they themselves who are circumcised keep the law; but desire to have you circumcised, that they may glory in your flesh.
29203	1097	14	But God forbid that I should glory, save in the cross of our Lord Jesus Christ, by whom the world is crucified unto me, and I unto the world.
29204	1097	15	For in Christ Jesus neither circumcision availeth any thing, nor uncircumcision, but a new creature.
29205	1097	16	And as many as walk according to this rule, peace be on them, and mercy, and upon the Israel of God.
29206	1097	17	From henceforth let no man trouble me: for I bear in my body the marks of the Lord Jesus.
29207	1097	18	Brethren, the grace of our Lord Jesus Christ be with your spirit. Amen.
29208	1098	1	PAUL, an apostle of Jesus Christ by the will of God, to the saints which are at Ephesus, and to the faithful in Christ Jesus:
29209	1098	2	Grace be to you, and peace, from God our Father, and from the Lord Jesus Christ.
29210	1098	3	Blessed be the God and Father of our Lord Jesus Christ, who hath blessed us with all spiritual blessings in heavenly places in Christ:
29211	1098	4	According as he hath chosen us in him before the foundation of the world, that we should be holy and without blame before him in love:
29212	1098	5	Having predestinated us unto the adoption of children by Jesus Christ to himself, according to the good pleasure of his will,
29213	1098	6	To the praise of the glory of his grace, wherein he hath made us accepted in the beloved.
29214	1098	7	In whom we have redemption through his blood, the forgiveness of sins, according to the riches of his grace;
29215	1098	8	Wherein he hath abounded toward us in all wisdom and prudence;
29216	1098	9	Having made known unto us the mystery of his will, according to his good pleasure which he hath purposed in himself:
29217	1098	10	That in the dispensation of the fulness of times he might gather together in one all things in Christ, both which are in heaven, and which are on earth; even in him:
29218	1098	11	In whom also we have obtained an inheritance, being predestinated according to the purpose of him who worketh all things after the counsel of his own will:
29219	1098	12	That we should be to the praise of his glory, who first trusted in Christ.
29220	1098	13	In whom ye also trusted, after that ye heard the word of truth, the gospel of your salvation: in whom also after that ye believed, ye were sealed with that holy Spirit of promise,
29221	1098	14	Which is the earnest of our inheritance until the redemption of the purchased possession, unto the praise of his glory.
29222	1098	15	Wherefore I also, after I heard of your faith in the Lord Jesus, and love unto all the saints,
29223	1098	16	Cease not to give thanks for you, making mention of you in my prayers;
29224	1098	17	That the God of our Lord Jesus Christ, the Father of glory, may give unto you the spirit of wisdom and revelation in the knowledge of him:
29225	1098	18	The eyes of your understanding being enlightened; that ye may know what is the hope of his calling, and what the riches of the glory of his inheritance in the saints,
29226	1098	19	And what is the exceeding greatness of his power to us-ward who believe, according to the working of his mighty power,
29227	1098	20	Which he wrought in Christ, when he raised him from the dead, and set him at his own right hand in the heavenly places,
29228	1098	21	Far above all principality, and power, and might, and dominion, and every name that is named, not only in this world, but also in that which is to come:
29229	1098	22	And hath put all things under his feet, and gave him to be the head over all things to the church,
29230	1098	23	Which is his body, the fulness of him that filleth all in all.
29231	1099	1	AND you hath he quickened, who were dead in trespasses and sins;
29232	1099	2	Wherein in time past ye walked according to the course of this world, according to the prince of the power of the air, the spirit that now worketh in the children of disobedience:
29233	1099	3	Among whom also we all had our conversation in times past in the lusts of our flesh, fulfilling the desires of the flesh and of the mind; and were by nature the children of wrath, even as others.
29234	1099	4	But God, who is rich in mercy, for his great love wherewith he loved us,
29235	1099	5	Even when we were dead in sins, hath quickened us together with Christ, (by grace ye are saved;)
29236	1099	6	And hath raised us up together, and made us sit together in heavenly places in Christ Jesus:
29237	1099	7	That in the ages to come he might shew the exceeding riches of his grace in his kindness toward us through Christ Jesus.
29238	1099	8	For by grace are ye saved through faith; and that not of yourselves: it is the gift of God:
29239	1099	9	Not of works, lest any man should boast.
29240	1099	10	For we are his workmanship, created in Christ Jesus unto good works, which God hath before ordained that we should walk in them.
29241	1099	11	Wherefore remember, that ye being in time past Gentiles in the flesh, who are called Uncircumcision by that which is called the Circumcision in the flesh made by hands;
29242	1099	12	That at that time ye were without Christ, being aliens from the commonwealth of Israel, and strangers from the covenants of promise, having no hope, and without God in the world:
29243	1099	13	But now in Christ Jesus ye who sometimes were far off are made nigh by the blood of Christ.
29244	1099	14	For he is our peace, who hath made both one, and hath broken down the middle wall of partition between us;
29245	1099	15	Having abolished in his flesh the enmity, even the law of commandments contained in ordinances; for to make in himself of twain one new man, so making peace;
29246	1099	16	And that he might reconcile both unto God in one body by the cross, having slain the enmity thereby:
29247	1099	17	And came and preached peace to you which were afar off, and to them that were nigh.
29248	1099	18	For through him we both have access by one Spirit unto the Father.
29249	1099	19	Now therefore ye are no more strangers and foreigners, but fellowcitizens with the saints, and of the household of God;
29250	1099	20	And are built upon the foundation of the apostles and prophets, Jesus Christ himself being the chief corner stone;
29251	1099	21	In whom all the building fitly framed together groweth unto an holy temple in the Lord:
29252	1099	22	In whom ye also are builded together for an habitation of God through the Spirit.
29253	1100	1	FOR this cause I Paul, the prisoner of Jesus Christ for you Gentiles,
29254	1100	2	If ye have heard of the dispensation of the grace of God which is given me to you-ward:
29255	1100	3	How that by revelation he made known unto me the mystery; (as I wrote afore in few words,
29256	1100	4	Whereby, when ye read, ye may understand my knowledge in the mystery of Christ)
29257	1100	5	Which in other ages was not made known unto the sons of men, as it is now revealed unto his holy apostles and prophets by the Spirit;
29258	1100	6	That the Gentiles should be fellowheirs, and of the same body, and partakers of his promise in Christ by the gospel:
29259	1100	7	Whereof I was made a minister, according to the gift of the grace of God given unto me by the effectual working of his power.
29260	1100	8	Unto me, who am less than the least of all saints, is this grace given, that I should preach among the Gentiles the unsearchable riches of Christ;
29261	1100	9	And to make all men see what is the fellowship of the mystery, which from the beginning of the world hath been hid in God, who created all things by Jesus Christ:
29262	1100	10	To the intent that now unto the principalities and powers in heavenly places might be known by the church the manifold wisdom of God,
29263	1100	11	According to the eternal purpose which he purposed in Christ Jesus our Lord:
29264	1100	12	In whom we have boldness and access with confidence by the faith of him.
29265	1100	13	Wherefore I desire that ye faint not at my tribulations for you, which is your glory.
29266	1100	14	For this cause I bow my knees unto the Father of our Lord Jesus Christ,
29267	1100	15	Of whom the whole family in heaven and earth is named,
29268	1100	16	That he would grant you, according to the riches of his glory, to be strengthened with might by his Spirit in the inner man;
29269	1100	17	That Christ may dwell in your hearts by faith; that ye, being rooted and grounded in love,
29270	1100	18	May be able to comprehend with all saints what is the breadth, and length, and depth, and height;
29271	1100	19	And to know the love of Christ, which passeth knowledge, that ye might be filled with all the fulness of God.
29272	1100	20	Now unto him that is able to do exceeding abundantly above all that we ask or think, according to the power that worketh in us,
29273	1100	21	Unto him be glory in the church by Christ Jesus throughout all ages, world without end. Amen.
29274	1101	1	I THEREFORE, the prisoner of the Lord, beseech you that ye walk worthy of the vocation wherewith ye are called,
29275	1101	2	With all lowliness and meekness, with longsuffering, forbearing one another in love;
29276	1101	3	Endeavouring to keep the unity of the Spirit in the bond of peace.
29277	1101	4	There is one body, and one Spirit, even as ye are called in one hope of your calling;
29278	1101	5	One Lord, one faith, one baptism,
29279	1101	6	One God and Father of all, who is above all, and through all, and in you all.
29280	1101	7	But unto every one of us is given grace according to the measure of the gift of Christ.
29281	1101	8	Wherefore he saith, When he ascended up on high, he led captivity captive, and gave gifts unto men.
29282	1101	9	(Now that he ascended, what is it but that he also descended first into the lower parts of the earth?
29283	1101	10	He that descended is the same also that ascended up far above all heavens, that he might fill all things.)
29284	1101	11	And he gave some, apostles; and some, prophets; and some, evangelists; and some, pastors and teachers;
29285	1101	12	For the perfecting of the saints, for the work of the ministry, for the edifying of the body of Christ:
29286	1101	13	Till we all come in the unity of the faith, and of the knowledge of the Son of God, unto a perfect man, unto the measure of the stature of the fulness of Christ:
29287	1101	14	That we henceforth be no more children, tossed to and fro, and carried about with every wind of doctrine, by the sleight of men, and cunning craftiness, whereby they lie in wait to deceive;
29288	1101	15	But speaking the truth in love, may grow up into him in all things, which is the head, even Christ:
29289	1101	16	From whom the whole body fitly joined together and compacted by that which every joint supplieth, according to the effectual working in the measure of every part, maketh increase of the body unto the edifying of itself in love.
29290	1101	17	This I say therefore, and testify in the Lord, that ye henceforth walk not as other Gentiles walk, in the vanity of their mind,
29291	1101	18	Having the understanding darkened, being alienated from the life of God through the ignorance that is in them, because of the blindness of their heart:
29292	1101	19	Who being past feeling have given themselves over unto lasciviousness, to work all uncleanness with greediness.
29293	1101	20	But ye have not so learned Christ;
29294	1101	21	If so be that ye have heard him, and have been taught by him, as the truth is in Jesus:
29295	1101	22	That ye put off concerning the former conversation the old man, which is corrupt according to the deceitful lusts;
29296	1101	23	And be renewed in the spirit of your mind;
29297	1101	24	And that ye put on the new man, which after God is created in righteousness and true holiness.
29298	1101	25	Wherefore putting away lying, speak every man truth with his neighbour: for we are members one of another.
29299	1101	26	Be ye angry, and sin not: let not the sun go down upon your wrath:
29300	1101	27	Neither give place to the devil.
29301	1101	28	Let him that stole steal no more: but rather let him labour, working with his hands the thing which is good, that he may have to give to him that needeth.
29302	1101	29	Let no corrupt communication proceed out of your mouth, but that which is good to the use of edifying, that it may minister grace unto the hearers.
29303	1101	30	And grieve not the holy Spirit of God, whereby ye are sealed unto the day of redemption.
29304	1101	31	Let all bitterness, and wrath, and anger, and clamour, and evil speaking, be put away from you, with all malice:
29305	1101	32	And be ye kind one to another, tenderhearted, forgiving one another, even as God for Christ's sake hath forgiven you.
29306	1102	1	BE ye therefore followers of God, as dear children;
29307	1102	2	And walk in love, as Christ also hath loved us, and hath given himself for us an offering and a sacrifice to God for a sweetsmelling savour.
29308	1102	3	But fornication, and all uncleanness, or covetousness, let it not be once named among you, as becometh saints;
29309	1102	4	Neither filthiness, nor foolish talking, nor jesting, which are not convenient: but rather giving of thanks.
29310	1102	5	For this ye know, that no whoremonger, nor unclean person, nor covetous man, who is an idolater, hath any inheritance in the kingdom of Christ and of God.
29311	1102	6	Let no man deceive you with vain words: for because of these things cometh the wrath of God upon the children of disobedience.
29312	1102	7	Be not ye therefore partakers with them.
29313	1102	8	For ye were sometimes darkness, but now are ye light in the Lord: walk as children of light:
29314	1102	9	(For the fruit of the Spirit is in all goodness and righteousness and truth;)
29315	1102	10	Proving what is acceptable unto the Lord.
29316	1102	11	And have no fellowship with the unfruitful works of darkness, but rather reprove them.
29317	1102	12	For it is a shame even to speak of those things which are done of them in secret.
29318	1102	13	But all things that are reproved are made manifest by the light: for whatsoever doth make manifest is light.
29319	1102	14	Wherefore he saith, Awake thou that sleepest, and arise from the dead, and Christ shall give thee light.
29320	1102	15	See then that ye walk circumspectly, not as fools, but as wise,
29321	1102	16	Redeeming the time, because the days are evil.
29322	1102	17	Wherefore be ye not unwise, but understanding what the will of the Lord is.
29323	1102	18	And be not drunk with wine, wherein is excess; but be filled with the Spirit;
29324	1102	19	Speaking to yourselves in psalms and hymns and spiritual songs, singing and making melody in your heart to the Lord;
29325	1102	20	Giving thanks always for all things unto God and the Father in the name of our Lord Jesus Christ;
29326	1102	21	Submitting yourselves one to another in the fear of God.
29327	1102	22	Wives, submit yourselves unto your own husbands, as unto the Lord.
29328	1102	23	For the husband is the head of the wife, even as Christ is the head of the church: and he is the saviour of the body.
29329	1102	24	Therefore as the church is subject unto Christ, so let the wives be to their own husbands in every thing.
29330	1102	25	Husbands, love your wives, even as Christ also loved the church, and gave himself for it;
29331	1102	26	That he might sanctify and cleanse it with the washing of water by the word,
29332	1102	27	That he might present it to himself a glorious church, not having spot, or wrinkle, or any such thing; but that it should be holy and without blemish.
29333	1102	28	So ought men to love their wives as their own bodies. He that loveth his wife loveth himself.
29334	1102	29	For no man ever yet hated his own flesh; but nourisheth and cherisheth it, even as the Lord the church:
29335	1102	30	For we are members of his body, of his flesh, and of his bones.
29336	1102	31	For this cause shall a man leave his father and mother, and shall be joined unto his wife, and they two shall be one flesh.
29337	1102	32	This is a great mystery: but I speak concerning Christ and the church.
29338	1102	33	Nevertheless let every one of you in particular so love his wife even as himself; and the wife see that she reverence her husband.
29339	1103	1	CHILDREN, obey your parents in the Lord: for this is right.
29340	1103	2	Honour thy father and mother; (which is the first commandment with promise;)
29341	1103	3	That it may be well with thee, and thou mayest live long on the earth.
29342	1103	4	And, ye fathers, provoke not your children to wrath: but bring them up in the nurture and admonition of the Lord.
29343	1103	5	Servants, be obedient to them that are your masters according to the flesh, with fear and trembling, in singleness of your heart, as unto Christ;
29344	1103	6	Not with eyeservice, as menpleasers; but as the servants of Christ, doing the will of God from the heart;
29345	1103	7	With good will doing service, as to the Lord, and not to men:
29346	1103	8	Knowing that whatsoever good thing any man doeth, the same shall he receive of the Lord, whether he be bond or free.
29347	1103	9	And, ye masters, do the same things unto them, forbearing threatening: knowing that your Master also is in heaven; neither is there respect of persons with him.
29348	1103	10	Finally, my brethren, be strong in the Lord, and in the power of his might.
29349	1103	11	Put on the whole armour of God, that ye may be able to stand against the wiles of the devil.
29350	1103	12	For we wrestle not against flesh and blood, but against principalities, against powers, against the rulers of the darkness of this world, against spiritual wickedness in high places.
29351	1103	13	Wherefore take unto you the whole armour of God, that ye may be able to withstand in the evil day, and having done all, to stand.
29352	1103	14	Stand therefore, having your loins girt about with truth, and having on the breastplate of righteousness;
29353	1103	15	And your feet shod with the preparation of the gospel of peace;
29354	1103	16	Above all, taking the shield of faith, wherewith ye shall be able to quench all the fiery darts of the wicked.
29355	1103	17	And take the helmet of salvation, and the sword of the Spirit, which is the word of God:
29356	1103	18	Praying always with all prayer and supplication in the Spirit, and watching thereunto with all perseverance and supplication for all saints;
29357	1103	19	And for me, that utterance may be given unto me, that I may open my mouth boldly, to make known the mystery of the gospel,
29358	1103	20	For which I am an ambassador in bonds: that therein I may speak boldly, as I ought to speak.
29359	1103	21	But that ye also may know my affairs, and how I do, Tychicus, a beloved brother and faithful minister in the Lord, shall make known to you all things:
29360	1103	22	Whom I have sent unto you for the same purpose, that ye might know our affairs, and that he might comfort your hearts.
29361	1103	23	Peace be to the brethren, and love with faith, from God the Father and the Lord Jesus Christ.
29362	1103	24	Grace be with all them that love our Lord Jesus Christ in sincerity. Amen.
29363	1104	1	PAUL and Timotheus, the servants of Jesus Christ, to all the saints in Christ Jesus which are at Philippi, with the bishops and deacons:
29364	1104	2	Grace be unto you, and peace, from God our Father, and from the Lord Jesus Christ.
29365	1104	3	I thank my God upon every remembrance of you,
29366	1104	4	Always in every prayer of mine for you all making request with joy,
29367	1104	5	For your fellowship in the gospel from the first day until now;
29368	1104	6	Being confident of this very thing, that he which hath begun a good work in you will perform it until the day of Jesus Christ:
29369	1104	7	Even as it is meet for me to think this of you all, because I have you in my heart; inasmuch as both in my bonds, and in the defence and confirmation of the gospel, ye all are partakers of my grace.
29370	1104	8	For God is my record, how greatly I long after you all in the bowels of Jesus Christ.
29371	1104	9	And this I pray, that your love may abound yet more and more in knowledge and in all judgment;
29372	1104	10	That ye may approve things that are excellent; that ye may be sincere and without offence till the day of Christ;
29373	1104	11	Being filled with the fruits of righteousness, which are by Jesus Christ, unto the glory and praise of God.
29374	1104	12	But I would ye should understand, brethren, that the things which happened unto me have fallen out rather unto the furtherance of the gospel;
29375	1104	13	So that my bonds in Christ are manifest in all the palace, and in all other places;
29376	1104	14	And many of the brethren in the Lord, waxing confident by my bonds, are much more bold to speak the word without fear.
29377	1104	15	Some indeed preach Christ even of envy and strife; and some also of good will:
29378	1104	16	The one preach Christ of contention, not sincerely, supposing to add affliction to my bonds:
29379	1104	17	But the other of love, knowing that I am set for the defence of the gospel.
29380	1104	18	What then? notwithstanding, every way, whether in pretence, or in truth, Christ is preached; and I therein do rejoice, yea, and will rejoice.
29381	1104	19	For I know that this shall turn to my salvation through your prayer, and the supply of the Spirit of Jesus Christ,
29382	1104	20	According to my earnest expectation and my hope, that in nothing I shall be ashamed, but that with all boldness, as always, so now also Christ shall be magnified in my body, whether it be by life, or by death.
29383	1104	21	For to me to live is Christ, and to die is gain.
29384	1104	22	But if I live in the flesh, this is the fruit of my labour: yet what I shall choose I wot not.
29385	1104	23	For I am in a strait betwixt two, having a desire to depart, and to be with Christ; which is far better:
29386	1104	24	Nevertheless to abide in the flesh is more needful for you.
29387	1104	25	And having this confidence, I know that I shall abide and continue with you all for your furtherance and joy of faith;
29388	1104	26	That your rejoicing may be more abundant in Jesus Christ for me by my coming to you again.
29389	1104	27	Only let your conversation be as it becometh the gospel of Christ: that whether I come and see you, or else be absent, I may hear of your affairs, that ye stand fast in one spirit, with one mind striving together for the faith of the gospel;
29390	1104	28	And in nothing terrified by your adversaries: which is to them an evident token of perdition, but to you of salvation, and that of God.
29391	1104	29	For unto you it is given in the behalf of Christ, not only to believe on him, but also to suffer for his sake;
29392	1104	30	Having the same conflict which ye saw in me, and now hear to be in me.
29393	1105	1	IF there be therefore any consolation in Christ, if any comfort of love, if any fellowship of the Spirit, if any bowels and mercies,
29394	1105	2	Fulfil ye my joy, that ye be likeminded, having the same love, being of one accord, of one mind.
29395	1105	3	Let nothing be done through strife or vainglory; but in lowliness of mind let each esteem other better than themselves.
29396	1105	4	Look not every man on his own things, but every man also on the things of others.
29397	1105	5	Let this mind be in you, which was also in Christ Jesus:
29398	1105	6	Who, being in the form of God, thought it not robbery to be equal with God:
29399	1105	7	But made himself of no reputation, and took upon him the form of a servant, and was made in the likeness of men:
29400	1105	8	And being found in fashion as a man, he humbled himself, and became obedient unto death, even the death of the cross.
29401	1105	9	Wherefore God also hath highly exalted him, and given him a name which is above every name:
29402	1105	10	That at the name of Jesus every knee should bow, of things in heaven, and things in earth, and things under the earth;
29403	1105	11	And that every tongue should confess that Jesus Christ is Lord, to the glory of God the Father.
29404	1105	12	Wherefore, my beloved, as ye have always obeyed, not as in my presence only, but now much more in my absence, work out your own salvation with fear and trembling.
29405	1105	13	For it is God which worketh in you both to will and to do of his good pleasure.
29406	1105	14	Do all things without murmurings and disputings:
29407	1105	15	That ye may be blameless and harmless, the sons of God, without rebuke, in the midst of a crooked and perverse nation, among whom ye shine as lights in the world;
29408	1105	16	Holding forth the word of life; that I may rejoice in the day of Christ, that I have not run in vain, neither laboured in vain.
29409	1105	17	Yea, and if I be offered upon the sacrifice and service of your faith, I joy, and rejoice with you all.
29410	1105	18	For the same cause also do ye joy, and rejoice with me.
29411	1105	19	But I trust in the Lord Jesus to send Timotheus shortly unto you, that I also may be of good comfort, when I know your state.
29412	1105	20	For I have no man likeminded, who will naturally care for your state.
29413	1105	21	For all seek their own, not the things which are Jesus Christ's.
29414	1105	22	But ye know the proof of him, that, as a son with the father, he hath served with me in the gospel.
29415	1105	23	Him therefore I hope to send presently, so soon as I shall see how it will go with me.
29416	1105	24	But I trust in the Lord that I also myself shall come shortly.
29417	1105	25	Yet I supposed it necessary to send to you Epaphroditus, my brother, and companion in labour, and fellowsoldier, but your messenger, and he that ministered to my wants.
29418	1105	26	For he longed after you all, and was full of heaviness, because that ye had heard that he had been sick.
29419	1105	27	For indeed he was sick nigh unto death: but God had mercy on him; and not on him only, but on me also, lest I should have sorrow upon sorrow.
29420	1105	28	I sent him therefore the more carefully, that, when ye see him again, ye may rejoice, and that I may be the less sorrowful.
29421	1105	29	Receive him therefore in the Lord with all gladness; and hold such in reputation:
29422	1105	30	Because for the work of Christ he was nigh unto death, not regarding his life, to supply your lack of service toward me.
29423	1106	1	FINALLY, my brethren, rejoice in the Lord. To write the same things to you, to me indeed is not grievous, but for you it is safe.
29424	1106	2	Beware of dogs, beware of evil workers, beware of the concision.
29425	1106	3	For we are the circumcision, which worship God in the spirit, and rejoice in Christ Jesus, and have no confidence in the flesh.
29426	1106	4	Though I might also have confidence in the flesh. If any other man thinketh that he hath whereof he might trust in the flesh, I more:
29427	1106	5	Circumcised the eighth day, of the stock of Israel, of the tribe of Benjamin, an Hebrew of the Hebrews; as touching the law, a Pharisee;
29428	1106	6	Concerning zeal, persecuting the church; touching the righteousness which is in the law, blameless.
29429	1106	7	But what things were gain to me, those I counted loss for Christ.
29430	1106	8	Yea doubtless, and I count all things but loss for the excellency of the knowledge of Christ Jesus my Lord: for whom I have suffered the loss of all things, and do count them but dung, that I may win Christ,
29431	1106	9	And be found in him, not having mine own righteousness, which is of the law, but that which is through the faith of Christ, the righteousness which is of God by faith:
29432	1106	10	That I may know him, and the power of his resurrection, and the fellowship of his sufferings, being made conformable unto his death;
29433	1106	11	If by any means I might attain unto the resurrection of the dead.
29434	1106	12	Not as though I had already attained, either were already perfect: but I follow after, if that I may apprehend that for which also I am apprehended of Christ Jesus.
29435	1106	13	Brethren, I count not myself to have apprehended: but this one thing I do, forgetting those things which are behind, and reaching forth unto those things which are before,
29436	1106	14	I press toward the mark for the prize of the high calling of God in Christ Jesus.
29437	1106	15	Let us therefore, as many as be perfect, be thus minded: and if in any thing ye be otherwise minded, God shall reveal even this unto you.
29438	1106	16	Nevertheless, whereto we have already attained, let us walk by the same rule, let us mind the same thing.
29439	1106	17	Brethren, be followers together of me, and mark them which walk so as ye have us for an ensample.
29440	1106	18	(For many walk, of whom I have told you often, and now tell you even weeping, that they are the enemies of the cross of Christ:
29441	1106	19	Whose end is destruction, whose God is their belly, and whose glory is in their shame, who mind earthly things.)
29442	1106	20	For our conversation is in heaven; from whence also we look for the Saviour, the Lord Jesus Christ:
29443	1106	21	Who shall change our vile body, that it may be fashioned like unto his glorious body, according to the working whereby he is able even to subdue all things unto himself.
29444	1107	1	THEREFORE, my brethren dearly beloved and longed for, my joy and crown, so stand fast in the Lord, my dearly beloved.
29445	1107	2	I beseech Euodias, and beseech Syntyche, that they be of the same mind in the Lord.
29446	1107	3	And I intreat thee also, true yokefellow, help those women which laboured with me in the gospel, with Clement also, and with other my fellowlabourers, whose names are in the book of life.
29447	1107	4	Rejoice in the Lord alway: and again I say, Rejoice.
29448	1107	5	Let your moderation be known unto all men. The Lord is at hand.
29449	1107	6	Be careful for nothing; but in every thing by prayer and supplication with thanksgiving let your requests be made known unto God.
29450	1107	7	And the peace of God, which passeth all understanding, shall keep your hearts and minds through Christ Jesus.
29451	1107	8	Finally, brethren, whatsoever things are true, whatsoever things are honest, whatsoever things are just, whatsoever things are pure, whatsoever things are lovely, whatsoever things are of good report; if there be any virtue, and if there be any praise, think on these things.
29452	1107	9	Those things, which ye have both learned, and received, and heard, and seen in me, do: and the God of peace shall be with you.
29453	1107	10	But I rejoiced in the Lord greatly, that now at the last your care of me hath flourished again; wherein ye were also careful, but ye lacked opportunity.
29454	1107	11	Not that I speak in respect of want: for I have learned, in whatsoever state I am, therewith to be content.
29455	1107	12	I know both how to be abased, and I know how to abound: every where and in all things I am instructed both to be full and to be hungry, both to abound and to suffer need.
29456	1107	13	I can do all things through Christ which strengtheneth me.
29457	1107	14	Notwithstanding ye have well done, that ye did communicate with my affliction.
29458	1107	15	Now ye Philippians know also, that in the beginning of the gospel, when I departed from Macedonia, no church communicated with me as concerning giving and receiving, but ye only.
29459	1107	16	For even in Thessalonica ye sent once and again unto my necessity.
29460	1107	17	Not because I desire a gift: but I desire fruit that may abound to your account.
29461	1107	18	But I have all, and abound: I am full, having received of Epaphroditus the things which were sent from you, an odour of a sweet smell, a sacrifice acceptable, wellpleasing to God.
29462	1107	19	But my God shall supply all your need according to his riches in glory by Christ Jesus.
29463	1107	20	Now unto God and our Father be glory for ever and ever. Amen.
29464	1107	21	Salute every saint in Christ Jesus. The brethren which are with me greet you.
29465	1107	22	All the saints salute you, chiefly they that are of Caesar's household.
29466	1107	23	The grace of our Lord Jesus Christ be with you all. Amen.
29467	1108	1	PAUL, an apostle of Jesus Christ by the will of God, and Timotheus our brother,
29468	1108	2	To the saints and faithful brethren in Christ which are at Colosse: Grace be unto you, and peace, from God our Father and the Lord Jesus Christ.
29469	1108	3	We give thanks to God and the Father of our Lord Jesus Christ, praying always for you,
29470	1108	4	Since we heard of your faith in Christ Jesus, and of the love which ye have to all the saints,
29471	1108	5	For the hope which is laid up for you in heaven, whereof ye heard before in the word of the truth of the gospel;
29472	1108	6	Which is come unto you, as it is in all the world; and bringeth forth fruit, as it doth also in you, since the day ye heard of it, and knew the grace of God in truth:
29473	1108	7	As ye also learned of Epaphras our dear fellowservant, who is for you a faithful minister of Christ;
29474	1108	8	Who also declared unto us your love in the Spirit.
29475	1108	9	For this cause we also, since the day we heard it, do not cease to pray for you, and to desire that ye might be filled with the knowledge of his will in all wisdom and spiritual understanding;
29476	1108	10	That ye might walk worthy of the Lord unto all pleasing, being fruitful in every good work, and increasing in the knowledge of God;
29477	1108	11	Strengthened with all might, according to his glorious power, unto all patience and longsuffering with joyfulness;
29478	1108	12	Giving thanks unto the Father, which hath made us meet to be partakers of the inheritance of the saints in light:
29479	1108	13	Who hath delivered us from the power of darkness, and hath translated us into the kingdom of his dear Son:
29480	1108	14	In whom we have redemption through his blood, even the forgiveness of sins:
29481	1108	15	Who is the image of the invisible God, the firstborn of every creature:
29482	1108	16	For by him were all things created, that are in heaven, and that are in earth, visible and invisible, whether they be thrones, or dominions, or principalities, or powers: all things were created by him, and for him:
29483	1108	17	And he is before all things, and by him all things consist.
29484	1108	18	And he is the head of the body, the church: who is the beginning, the firstborn from the dead; that in all things he might have the preeminence.
29485	1108	19	For it pleased the Father that in him should all fulness dwell;
29486	1108	20	And, having made peace through the blood of his cross, by him to reconcile all things unto himself; by him, I say, whether they be things in earth, or things in heaven.
29487	1108	21	And you, that were sometime alienated and enemies in your mind by wicked works, yet now hath he reconciled
29488	1108	22	In the body of his flesh through death, to present you holy and unblameable and unreproveable in his sight:
29489	1108	23	If ye continue in the faith grounded and settled, and be not moved away from the hope of the gospel, which ye have heard, and which was preached to every creature which is under heaven; whereof I Paul am made a minister;
29490	1108	24	Who now rejoice in my sufferings for you, and fill up that which is behind of the afflictions of Christ in my flesh for his body's sake, which is the church:
29491	1108	25	Whereof I am made a minister, according to the dispensation of God which is given to me for you, to fulfil the word of God;
29492	1108	26	Even the mystery which hath been hid from ages and from generations, but now is made manifest to his saints:
29493	1108	27	To whom God would make known what is the riches of the glory of this mystery among the Gentiles; which is Christ in you, the hope of glory:
29494	1108	28	Whom we preach, warning every man, and teaching every man in all wisdom; that we may present every man perfect in Christ Jesus:
29495	1108	29	Whereunto I also labour, striving according to his working, which worketh in me mightily.
29496	1109	1	FOR I would that ye knew what great conflict I have for you, and for them at Laodicea, and for as many as have not seen my face in the flesh;
29497	1109	2	That their hearts might be comforted, being knit together in love, and unto all riches of the full assurance of understanding, to the acknowledgement of the mystery of God, and of the Father, and of Christ;
29498	1109	3	In whom are hid all the treasures of wisdom and knowledge.
29499	1109	4	And this I say, lest any man should beguile you with enticing words.
29500	1109	5	For though I be absent in the flesh, yet am I with you in the spirit, joying and beholding your order, and the stedfastness of your faith in Christ.
29501	1109	6	As ye have therefore received Christ Jesus the Lord, so walk ye in him:
29502	1109	7	Rooted and built up in him, and stablished in the faith, as ye have been taught, abounding therein with thanksgiving.
29503	1109	8	Beware lest any man spoil you through philosophy and vain deceit, after the tradition of men, after the rudiments of the world, and not after Christ.
29504	1109	9	For in him dwelleth all the fulness of the Godhead bodily.
29505	1109	10	And ye are complete in him, which is the head of all principality and power:
29506	1109	11	In whom also ye are circumcised with the circumcision made without hands, in putting off the body of the sins of the flesh by the circumcision of Christ:
29507	1109	12	Buried with him in baptism, wherein also ye are risen with him through the faith of the operation of God, who hath raised him from the dead.
29508	1109	13	And you, being dead in your sins and the uncircumcision of your flesh, hath he quickened together with him, having forgiven you all trespasses;
29509	1109	14	Blotting out the handwriting of ordinances that was against us, which was contrary to us, and took it out of the way, nailing it to his cross;
29510	1109	15	And having spoiled principalities and powers, he made a shew of them openly, triumphing over them in it.
29511	1109	16	Let no man therefore judge you in meat, or in drink, or in respect of an holyday, or of the new moon, or of the sabbath days:
29512	1109	17	Which are a shadow of things to come; but the body is of Christ.
29513	1109	18	Let no man beguile you of your reward in a voluntary humility and worshipping of angels, intruding into those things which he hath not seen, vainly puffed up by his fleshly mind,
29514	1109	19	And not holding the Head, from which all the body by joints and bands having nourishment ministered, and knit together, increaseth with the increase of God.
29515	1109	20	Wherefore if ye be dead with Christ from the rudiments of the world, why, as though living in the world, are ye subject to ordinances,
29516	1109	21	(Touch not; taste not; handle not;
29517	1109	22	Which all are to perish with the using;) after the commandments and doctrines of men?
29518	1109	23	Which things have indeed a shew of wisdom in will worship, and humility, and neglecting of the body; not in any honour to the satisfying of the flesh.
29519	1110	1	IF ye then be risen with Christ, seek those things which are above, where Christ sitteth on the right hand of God.
29520	1110	2	Set your affection on things above, not on things on the earth.
29521	1110	3	For ye are dead, and your life is hid with Christ in God.
29522	1110	4	When Christ, who is our life, shall appear, then shall ye also appear with him in glory.
29523	1110	5	Mortify therefore your members which are upon the earth; fornication, uncleanness, inordinate affection, evil concupiscence, and covetousness, which is idolatry:
29524	1110	6	For which things' sake the wrath of God cometh on the children of disobedience:
29525	1110	7	In the which ye also walked some time, when ye lived in them.
29526	1110	8	But now ye also put off all these; anger, wrath, malice, blasphemy, filthy communication out of your mouth.
29527	1110	9	Lie not one to another, seeing that ye have put off the old man with his deeds;
29528	1110	10	And have put on the new man, which is renewed in knowledge after the image of him that created him:
29529	1110	11	Where there is neither Greek nor Jew, circumcision nor uncircumcision, Barbarian, Scythian, bond nor free: but Christ is all, and in all.
29530	1110	12	Put on therefore, as the elect of God, holy and beloved, bowels of mercies, kindness, humbleness of mind, meekness, longsuffering;
29531	1110	13	Forbearing one another, and forgiving one another, if any man have a quarrel against any: even as Christ forgave you, so also do ye.
29532	1110	14	And above all these things put on charity, which is the bond of perfectness.
29533	1110	15	And let the peace of God rule in your hearts, to the which also ye are called in one body; and be ye thankful.
29534	1110	16	Let the word of Christ dwell in you richly in all wisdom; teaching and admonishing one another in psalms and hymns and spiritual songs, singing with grace in your hearts to the Lord.
29535	1110	17	And whatsoever ye do in word or deed, do all in the name of the Lord Jesus, giving thanks to God and the Father by him.
29536	1110	18	Wives, submit yourselves unto your own husbands, as it is fit in the Lord.
29537	1110	19	Husbands, love your wives, and be not bitter against them.
29538	1110	20	Children, obey your parents in all things: for this is well pleasing unto the Lord.
29539	1110	21	Fathers, provoke not your children to anger, lest they be discouraged.
29540	1110	22	Servants, obey in all things your masters according to the flesh; not with eyeservice, as menpleasers; but in singleness of heart, fearing God:
29541	1110	23	And whatsoever ye do, do it heartily, as to the Lord, and not unto men;
29542	1110	24	Knowing that of the Lord ye shall receive the reward of the inheritance: for ye serve the Lord Christ.
29543	1110	25	But he that doeth wrong shall receive for the wrong which he hath done: and there is no respect of persons.
29544	1111	1	MASTERS, give unto your servants that which is just and equal; knowing that ye also have a Master in heaven.
29545	1111	2	Continue in prayer, and watch in the same with thanksgiving;
29546	1111	3	Withal praying also for us, that God would open unto us a door of utterance, to speak the mystery of Christ, for which I am also in bonds:
29547	1111	4	That I may make it manifest, as I ought to speak.
29548	1111	5	Walk in wisdom toward them that are without, redeeming the time.
29549	1111	6	Let your speech be alway with grace, seasoned with salt, that ye may know how ye ought to answer every man.
29550	1111	7	All my state shall Tychicus declare unto you, who is a beloved brother, and a faithful minister and fellowservant in the Lord:
29551	1111	8	Whom I have sent unto you for the same purpose, that he might know your estate, and comfort your hearts;
29552	1111	9	With Onesimus, a faithful and beloved brother, who is one of you. They shall make known unto you all things which are done here.
29553	1111	10	Aristarchus my fellowprisoner saluteth you, and Marcus, sister's son to Barnabas, (touching whom ye received commandments: if he come unto you, receive him;)
29554	1111	11	And Jesus, which is called Justus, who are of the circumcision. These only are my fellowworkers unto the kingdom of God, which have been a comfort unto me.
29555	1111	12	Epaphras, who is one of you, a servant of Christ, saluteth you, always labouring fervently for you in prayers, that ye may stand perfect and complete in all the will of God.
29556	1111	13	For I bear him record, that he hath a great zeal for you, and them that are in Laodicea, and them in Hierapolis.
29557	1111	14	Luke, the beloved physician, and Demas, greet you.
29558	1111	15	Salute the brethren which are in Laodicea, and Nymphas, and the church which is in his house.
29559	1111	16	And when this epistle is read among you, cause that it be read also in the church of the Laodiceans; and that ye likewise read the epistle from Laodicea.
29560	1111	17	And say to Archippus, Take heed to the ministry which thou hast received in the Lord, that thou fulfil it.
29561	1111	18	The salutation by the hand of me Paul. Remember my bonds. Grace be with you. Amen.
29562	1112	1	PAUL, and Silvanus, and Timotheus, unto the church of the Thessalonians which is in God the Father and in the Lord Jesus Christ: Grace be unto you, and peace, from God our Father, and the Lord Jesus Christ.
29563	1112	2	We give thanks to God always for you all, making mention of you in our prayers;
29564	1112	3	Remembering without ceasing your work of faith, and labour of love, and patience of hope in our Lord Jesus Christ, in the sight of God and our Father;
29565	1112	4	Knowing, brethren beloved, your election of God.
29566	1112	5	For our gospel came not unto you in word only, but also in power, and in the Holy Ghost, and in much assurance; as ye know what manner of men we were among you for your sake.
29567	1112	6	And ye became followers of us, and of the Lord, having received the word in much affliction, with joy of the Holy Ghost:
29568	1112	7	So that ye were ensamples to all that believe in Macedonia and Achaia.
29569	1112	8	For from you sounded out the word of the Lord not only in Macedonia and Achaia, but also in every place your faith to God-ward is spread abroad; so that we need not to speak any thing.
29570	1112	9	For they themselves shew of us what manner of entering in we had unto you, and how ye turned to God from idols to serve the living and true God;
29571	1112	10	And to wait for his Son from heaven, whom he raised from the dead, even Jesus, which delivered us from the wrath to come.
29572	1113	1	FOR yourselves, brethren, know our entrance in unto you, that it was not in vain:
29573	1113	2	But even after that we had suffered before, and were shamefully entreated, as ye know, at Philippi, we were bold in our God to speak unto you the gospel of God with much contention.
29574	1113	3	For our exhortation was not of deceit, nor of uncleanness, nor in guile:
29575	1113	4	But as we were allowed of God to be put in trust with the gospel, even so we speak; not as pleasing men, but God, which trieth our hearts.
29576	1113	5	For neither at any time used we flattering words, as ye know, nor a cloke of covetousness; God is witness:
29577	1113	6	Nor of men sought we glory, neither of you, nor yet of others, when we might have been burdensome, as the apostles of Christ.
29578	1113	7	But we were gentle among you, even as a nurse cherisheth her children:
29579	1113	8	So being affectionately desirous of you, we were willing to have imparted unto you, not the gospel of God only, but also our own souls, because ye were dear unto us.
29580	1113	9	For ye remember, brethren, our labour and travail: for labouring night and day, because we would not be chargeable unto any of you, we preached unto you the gospel of God.
29581	1113	10	Ye are witnesses, and God also, how holily and justly and unblameably we behaved ourselves among you that believe:
29582	1113	11	As ye know how we exhorted and comforted and charged every one of you, as a father doth his children,
29583	1113	12	That ye would walk worthy of God, who hath called you unto his kingdom and glory.
29584	1113	13	For this cause also thank we God without ceasing, because, when ye received the word of God which ye heard of us, ye received it not as the word of men, but as it is in truth, the word of God, which effectually worketh also in you that believe.
29585	1113	14	For ye, brethren, became followers of the churches of God which in Judaea are in Christ Jesus: for ye also have suffered like things of your own countrymen, even as they have of the Jews:
29586	1113	15	Who both killed the Lord Jesus, and their own prophets, and have persecuted us; and they please not God, and are contrary to all men:
29587	1113	16	Forbidding us to speak to the Gentiles that they might be saved, to fill up their sins alway: for the wrath is come upon them to the uttermost.
29588	1113	17	But we, brethren, being taken from you for a short time in presence, not in heart, endeavoured the more abundantly to see your face with great desire.
29589	1113	18	Wherefore we would have come unto you, even I Paul, once and again; but Satan hindered us.
29590	1113	19	For what is our hope, or joy, or crown of rejoicing? Are not even ye in the presence of our Lord Jesus Christ at his coming?
29591	1113	20	For ye are our glory and joy.
29592	1114	1	WHEREFORE when we could no longer forbear, we thought it good to be left at Athens alone;
29593	1114	2	And sent Timotheus, our brother, and minister of God, and our fellowlabourer in the gospel of Christ, to establish you, and to comfort you concerning your faith:
29594	1114	3	That no man should be moved by these afflictions: for yourselves know that we are appointed thereunto.
29595	1114	4	For verily, when we were with you, we told you before that we should suffer tribulation; even as it came to pass, and ye know.
29596	1114	5	For this cause, when I could no longer forbear, I sent to know your faith, lest by some means the tempter have tempted you, and our labour be in vain.
29597	1114	6	But now when Timotheus came from you unto us, and brought us good tidings of your faith and charity, and that ye have good remembrance of us always, desiring greatly to see us, as we also to see you:
29598	1114	7	Therefore, brethren, we were comforted over you in all our affliction and distress by your faith:
29599	1114	8	For now we live, if ye stand fast in the Lord.
29600	1114	9	For what thanks can we render to God again for you, for all the joy wherewith we joy for your sakes before our God;
29601	1114	10	Night and day praying exceedingly that we might see your face, and might perfect that which is lacking in your faith?
29602	1114	11	Now God himself and our Father, and our Lord Jesus Christ, direct our way unto you.
29603	1114	12	And the Lord make you to increase and abound in love one toward another, and toward all men, even as we do toward you:
29604	1114	13	To the end he may stablish your hearts unblameable in holiness before God, even our Father, at the coming of our Lord Jesus Christ with all his saints.
29605	1115	1	FURTHERMORE then we beseech you, brethren, and exhort you by the Lord Jesus, that as ye have received of us how ye ought to walk and to please God, so ye would abound more and more.
29606	1115	2	For ye know what commandments we gave you by the Lord Jesus.
29607	1115	3	For this is the will of God, even your sanctification, that ye should abstain from fornication:
29608	1115	4	That every one of you should know how to possess his vessel in sanctification and honour;
29609	1115	5	Not in the lust of concupiscence, even as the Gentiles which know not God:
29610	1115	6	That no man go beyond and defraud his brother in any matter: because that the Lord is the avenger of all such, as we also have forewarned you and testified.
29611	1115	7	For God hath not called us unto uncleanness, but unto holiness.
29612	1115	8	He therefore that despiseth, despiseth not man, but God, who hath also given unto us his holy Spirit.
29613	1115	9	But as touching brotherly love ye need not that I write unto you: for ye yourselves are taught of God to love one another.
29614	1115	10	And indeed ye do it toward all the brethren which are in all Macedonia: but we beseech you, brethren, that ye increase more and more;
29615	1115	11	And that ye study to be quiet, and to do your own business, and to work with your own hands, as we commanded you;
29616	1115	12	That ye may walk honestly toward them that are without, and that ye may have lack of nothing.
29617	1115	13	But I would not have you to be ignorant, brethren, concerning them which are asleep, that ye sorrow not, even as others which have no hope.
29618	1115	14	For if we believe that Jesus died and rose again, even so them also which sleep in Jesus will God bring with him.
29619	1115	15	For this we say unto you by the word of the Lord, that we which are alive and remain unto the coming of the Lord shall not prevent them which are asleep.
29620	1115	16	For the Lord himself shall descend from heaven with a shout, with the voice of the archangel, and with the trump of God: and the dead in Christ shall rise first:
29621	1115	17	Then we which are alive and remain shall be caught up together with them in the clouds, to meet the Lord in the air: and so shall we ever be with the Lord.
29622	1115	18	Wherefore comfort one another with these words.
29623	1116	1	BUT of the times and the seasons, brethren, ye have no need that I write unto you.
29624	1116	2	For yourselves know perfectly that the day of the Lord so cometh as a thief in the night.
29625	1116	3	For when they shall say, Peace and safety; then sudden destruction cometh upon them, as travail upon a woman with child; and they shall not escape.
29626	1116	4	But ye, brethren, are not in darkness, that that day should overtake you as a thief.
29627	1116	5	Ye are all the children of light, and the children of the day: we are not of the night, nor of darkness.
29628	1116	6	Therefore let us not sleep, as do others; but let us watch and be sober.
29629	1116	7	For they that sleep sleep in the night; and they that be drunken are drunken in the night.
29630	1116	8	But let us, who are of the day, be sober, putting on the breastplate of faith and love; and for an helmet, the hope of salvation.
29631	1116	9	For God hath not appointed us to wrath, but to obtain salvation by our Lord Jesus Christ,
29632	1116	10	Who died for us, that, whether we wake or sleep, we should live together with him.
29633	1116	11	Wherefore comfort yourselves together, and edify one another, even as also ye do.
29634	1116	12	And we beseech you, brethren, to know them which labour among you, and are over you in the Lord, and admonish you;
29635	1116	13	And to esteem them very highly in love for their work's sake. And be at peace among yourselves.
29636	1116	14	Now we exhort you, brethren, warn them that are unruly, comfort the feebleminded, support the weak, be patient toward all men.
29637	1116	15	See that none render evil for evil unto any man; but ever follow that which is good, both among yourselves, and to all men.
29638	1116	16	Rejoice evermore.
29639	1116	17	Pray without ceasing.
29640	1116	18	In every thing give thanks: for this is the will of God in Christ Jesus concerning you.
29641	1116	19	Quench not the Spirit.
29642	1116	20	Despise not prophesyings.
29643	1116	21	Prove all things; hold fast that which is good.
29644	1116	22	Abstain from all appearance of evil.
29645	1116	23	And the very God of peace sanctify you wholly; and I pray God your whole spirit and soul and body be preserved blameless unto the coming of our Lord Jesus Christ.
29646	1116	24	Faithful is he that calleth you, who also will do it.
29647	1116	25	Brethren, pray for us.
29648	1116	26	Greet all the brethren with an holy kiss.
29649	1116	27	I charge you by the Lord that this epistle be read unto all the holy brethren.
29650	1116	28	The grace of our Lord Jesus Christ be with you. Amen.
29651	1117	1	PAUL, and Silvanus, and Timotheus, unto the church of the Thessalonians in God our Father and the Lord Jesus Christ:
29652	1117	2	Grace unto you, and peace, from God our Father and the Lord Jesus Christ.
29653	1117	3	We are bound to thank God always for you, brethren, as it is meet, because that your faith groweth exceedingly, and the charity of every one of you all toward each other aboundeth;
29654	1117	4	So that we ourselves glory in you in the churches of God for your patience and faith in all your persecutions and tribulations that ye endure:
29655	1117	5	Which is a manifest token of the righteous judgment of God, that ye may be counted worthy of the kingdom of God, for which ye also suffer:
29656	1117	6	Seeing it is a righteous thing with God to recompense tribulation to them that trouble you;
29657	1117	7	And to you who are troubled rest with us, when the Lord Jesus shall be revealed from heaven with his mighty angels,
29658	1117	8	In flaming fire taking vengeance on them that know not God, and that obey not the gospel of our Lord Jesus Christ:
29659	1117	9	Who shall be punished with everlasting destruction from the presence of the Lord, and from the glory of his power;
29660	1117	10	When he shall come to be glorified in his saints, and to be admired in all them that believe (because our testimony among you was believed) in that day.
29661	1117	11	Wherefore also we pray always for you, that our God would count you worthy of this calling, and fulfil all the good pleasure of his goodness, and the work of faith with power:
29662	1117	12	That the name of our Lord Jesus Christ may be glorified in you, and ye in him, according to the grace of our God and the Lord Jesus Christ.
29663	1118	1	NOW we beseech you, brethren, by the coming of our Lord Jesus Christ, and by our gathering together unto him,
29664	1118	2	That ye be not soon shaken in mind, or be troubled, neither by spirit, nor by word, nor by letter as from us, as that the day of Christ is at hand.
29665	1118	3	Let no man deceive you by any means: for that day shall not come, except there come a falling away first, and that man of sin be revealed, the son of perdition;
29666	1118	4	Who opposeth and exalteth himself above all that is called God, or that is worshipped; so that he as God sitteth in the temple of God, shewing himself that he is God.
29667	1118	5	Remember ye not, that, when I was yet with you, I told you these things?
29668	1118	6	And now ye know what withholdeth that he might be revealed in his time.
29669	1118	7	For the mystery of iniquity doth already work: only he who now letteth will let, until he be taken out of the way.
29670	1118	8	And then shall that Wicked be revealed, whom the Lord shall consume with the spirit of his mouth, and shall destroy with the brightness of his coming:
29671	1118	9	Even him, whose coming is after the working of Satan with all power and signs and lying wonders,
29672	1118	10	And with all deceivableness of unrighteousness in them that perish; because they received not the love of the truth, that they might be saved.
29673	1118	11	And for this cause God shall send them strong delusion, that they should believe a lie:
29674	1118	12	That they all might be damned who believed not the truth, but had pleasure in unrighteousness.
29675	1118	13	But we are bound to give thanks alway to God for you, brethren beloved of the Lord, because God hath from the beginning chosen you to salvation through sanctification of the Spirit and belief of the truth:
29676	1118	14	Whereunto he called you by our gospel, to the obtaining of the glory of our Lord Jesus Christ.
29677	1118	15	Therefore, brethren, stand fast, and hold the traditions which ye have been taught, whether by word, or our epistle.
29678	1118	16	Now our Lord Jesus Christ himself, and God, even our Father, which hath loved us, and hath given us everlasting consolation and good hope through grace,
29679	1118	17	Comfort your hearts, and stablish you in every good word and work.
29680	1119	1	FINALLY, brethren, pray for us, that the word of the Lord may have free course, and be glorified, even as it is with you:
29681	1119	2	And that we may be delivered from unreasonable and wicked men: for all men have not faith.
29682	1119	3	But the Lord is faithful, who shall stablish you, and keep you from evil.
29683	1119	4	And we have confidence in the Lord touching you, that ye both do and will do the things which we command you.
29684	1119	5	And the Lord direct your hearts into the love of God, and into the patient waiting for Christ.
29685	1119	6	Now we command you, brethren, in the name of our Lord Jesus Christ, that ye withdraw yourselves from every brother that walketh disorderly, and not after the tradition which he received of us.
29686	1119	7	For yourselves know how ye ought to follow us: for we behaved not ourselves disorderly among you;
29687	1119	8	Neither did we eat any man's bread for nought; but wrought with labour and travail night and day, that we might not be chargeable to any of you:
29688	1119	9	Not because we have not power, but to make ourselves an ensample unto you to follow us.
29689	1119	10	For even when we were with you, this we commanded you, that if any would not work, neither should he eat.
29690	1119	11	For we hear that there are some which walk among you disorderly, working not at all, but are busybodies.
29691	1119	12	Now them that are such we command and exhort by our Lord Jesus Christ, that with quietness they work, and eat their own bread.
29692	1119	13	But ye, brethren, be not weary in well doing.
29693	1119	14	And if any man obey not our word by this epistle, note that man, and have no company with him, that he may be ashamed.
29694	1119	15	Yet count him not as an enemy, but admonish him as a brother.
29695	1119	16	Now the Lord of peace himself give you peace always by all means. The Lord be with you all.
29696	1119	17	The salutation of Paul with mine own hand, which is the token in every epistle: so I write.
29697	1119	18	The grace of our Lord Jesus Christ be with you all. Amen.
29698	1120	1	PAUL, an apostle of Jesus Christ by the commandment of God our Saviour, and Lord Jesus Christ, which is our hope;
29699	1120	2	Unto Timothy, my own son in the faith: Grace, mercy, and peace, from God our Father and Jesus Christ our Lord.
29700	1120	3	As I besought thee to abide still at Ephesus, when I went into Macedonia, that thou mightest charge some that they teach no other doctrine,
29701	1120	4	Neither give heed to fables and endless genealogies, which minister questions, rather than godly edifying which is in faith: so do.
29702	1120	5	Now the end of the commandment is charity out of a pure heart, and of a good conscience, and of faith unfeigned:
29703	1120	6	From which some having swerved have turned aside unto vain jangling;
29704	1120	7	Desiring to be teachers of the law; understanding neither what they say, nor whereof they affirm.
29705	1120	8	But we know that the law is good, if a man use it lawfully;
29706	1120	9	Knowing this, that the law is not made for a righteous man, but for the lawless and disobedient, for the ungodly and for sinners, for unholy and profane, for murderers of fathers and murderers of mothers, for manslayers,
29707	1120	10	For whoremongers, for them that defile themselves with mankind, for menstealers, for liars, for perjured persons, and if there be any other thing that is contrary to sound doctrine;
29708	1120	11	According to the glorious gospel of the blessed God, which was committed to my trust.
29709	1120	12	And I thank Christ Jesus our Lord, who hath enabled me, for that he counted me faithful, putting me into the ministry;
29710	1120	13	Who was before a blasphemer, and a persecutor, and injurious: but I obtained mercy, because I did it ignorantly in unbelief.
29711	1120	14	And the grace of our Lord was exceeding abundant with faith and love which is in Christ Jesus.
29712	1120	15	This is a faithful saying, and worthy of all acceptation, that Christ Jesus came into the world to save sinners; of whom I am chief.
29713	1120	16	Howbeit for this cause I obtained mercy, that in me first Jesus Christ might shew forth all longsuffering, for a pattern to them which should hereafter believe on him to life everlasting.
29714	1120	17	Now unto the King eternal, immortal, invisible, the only wise God, be honour and glory for ever and ever. Amen.
29715	1120	18	This charge I commit unto thee, son Timothy, according to the prophecies which went before on thee, that thou by them mightest war a good warfare;
29716	1120	19	Holding faith, and a good conscience; which some having put away concerning faith have made shipwreck:
29717	1120	20	Of whom is Hymenaeus and Alexander; whom I have delivered unto Satan, that they may learn not to blaspheme.
29718	1121	1	I EXHORT therefore, that, first of all, supplications, prayers, intercessions, and giving of thanks, be made for all men;
29719	1121	2	For kings, and for all that are in authority; that we may lead a quiet and peaceable life in all godliness and honesty.
29720	1121	3	For this is good and acceptable in the sight of God our Saviour;
29721	1121	4	Who will have all men to be saved, and to come unto the knowledge of the truth.
29722	1121	5	For there is one God, and one mediator between God and men, the man Christ Jesus;
29723	1121	6	Who gave himself a ransom for all, to be testified in due time.
29724	1121	7	Whereunto I am ordained a preacher, and an apostle, (I speak the truth in Christ, and lie not;) a teacher of the Gentiles in faith and verity.
29725	1121	8	I will therefore that men pray every where, lifting up holy hands, without wrath and doubting.
29726	1121	9	In like manner also, that women adorn themselves in modest apparel, with shamefacedness and sobriety; not with broided hair, or gold, or pearls, or costly array;
29727	1121	10	But (which becometh women professing godliness) with good works.
29728	1121	11	Let the woman learn in silence with all subjection.
29729	1121	12	But I suffer not a woman to teach, nor to usurp authority over the man, but to be in silence.
29730	1121	13	For Adam was first formed, then Eve.
29731	1121	14	And Adam was not deceived, but the woman being deceived was in the transgression.
29732	1121	15	Notwithstanding she shall be saved in childbearing, if they continue in faith and charity and holiness with sobriety.
29733	1122	1	THIS is a true saying, If a man desire the office of a bishop, he desireth a good work.
29734	1122	2	A bishop then must be blameless, the husband of one wife, vigilant, sober, of good behaviour, given to hospitality, apt to teach;
29735	1122	3	Not given to wine, no striker, not greedy of filthy lucre; but patient, not a brawler, not covetous;
29736	1122	4	One that ruleth well his own house, having his children in subjection with all gravity;
29737	1122	5	(For if a man know not how to rule his own house, how shall he take care of the church of God?)
29738	1122	6	Not a novice, lest being lifted up with pride he fall into the condemnation of the devil.
29739	1122	7	Moreover he must have a good report of them which are without; lest he fall into reproach and the snare of the devil.
29740	1122	8	Likewise must the deacons be grave, not doubletongued, not given to much wine, not greedy of filthy lucre;
29741	1122	9	Holding the mystery of the faith in a pure conscience.
29742	1122	10	And let these also first be proved; then let them use the office of a deacon, being found blameless.
29743	1122	11	Even so must their wives be grave, not slanderers, sober, faithful in all things.
29744	1122	12	Let the deacons be the husbands of one wife, ruling their children and their own houses well.
29745	1122	13	For they that have used the office of a deacon well purchase to themselves a good degree, and great boldness in the faith which is in Christ Jesus.
29746	1122	14	These things write I unto thee, hoping to come unto thee shortly:
29747	1122	15	But if I tarry long, that thou mayest know how thou oughtest to behave thyself in the house of God, which is the church of the living God, the pillar and ground of the truth.
29748	1122	16	And without controversy great is the mystery of godliness: God was manifest in the flesh, justified in the Spirit, seen of angels, preached unto the Gentiles, believed on in the world, received up into glory.
29749	1123	1	NOW the Spirit speaketh expressly, that in the latter times some shall depart from the faith, giving heed to seducing spirits, and doctrines of devils;
29750	1123	2	Speaking lies in hypocrisy; having their conscience seared with a hot iron;
29751	1123	3	Forbidding to marry, and commanding to abstain from meats, which God hath created to be received with thanksgiving of them which believe and know the truth.
29752	1123	4	For every creature of God is good, and nothing to be refused, if it be received with thanksgiving:
29753	1123	5	For it is sanctified by the word of God and prayer.
29754	1123	6	If thou put the brethren in remembrance of these things, thou shalt be a good minister of Jesus Christ, nourished up in the words of faith and of good doctrine, whereunto thou hast attained.
29755	1123	7	But refuse profane and old wives' fables, and exercise thyself rather unto godliness.
29756	1123	8	For bodily exercise profiteth little: but godliness is profitable unto all things, having promise of the life that now is, and of that which is to come.
29757	1123	9	This is a faithful saying and worthy of all acceptation.
29758	1123	10	For therefore we both labour and suffer reproach, because we trust in the living God, who is the Saviour of all men, specially of those that believe.
29759	1123	11	These things command and teach.
29760	1123	12	Let no man despise thy youth; but be thou an example of the believers, in word, in conversation, in charity, in spirit, in faith, in purity.
29761	1123	13	Till I come, give attendance to reading, to exhortation, to doctrine.
29762	1123	14	Neglect not the gift that is in thee, which was given thee by prophecy, with the laying on of the hands of the presbytery.
29763	1123	15	Meditate upon these things; give thyself wholly to them; that thy profiting may appear to all.
29764	1123	16	Take heed unto thyself, and unto the doctrine; continue in them: for in doing this thou shalt both save thyself, and them that hear thee.
29765	1124	1	REBUKE not an elder, but intreat him as a father; and the younger men as brethren;
29766	1124	2	The elder women as mothers; the younger as sisters, with all purity.
29767	1124	3	Honour widows that are widows indeed.
29768	1124	4	But if any widow have children or nephews, let them learn first to shew piety at home, and to requite their parents: for that is good and acceptable before God.
29769	1124	5	Now she that is a widow indeed, and desolate, trusteth in God, and continueth in supplications and prayers night and day.
29770	1124	6	But she that liveth in pleasure is dead while she liveth.
29771	1124	7	And these things give in charge, that they may be blameless.
29772	1124	8	But if any provide not for his own, and specially for those of his own house, he hath denied the faith, and is worse than an infidel.
29773	1124	9	Let not a widow be taken into the number under threescore years old, having been the wife of one man,
29774	1124	10	Well reported of for good works; if she have brought up children, if she have lodged strangers, if she have washed the saints' feet, if she have relieved the afflicted, if she have diligently followed every good work.
29775	1124	11	But the younger widows refuse: for when they have begun to wax wanton against Christ, they will marry;
29776	1124	12	Having damnation, because they have cast off their first faith.
29777	1124	13	And withal they learn to be idle, wandering about from house to house; and not only idle, but tattlers also and busybodies, speaking things which they ought not.
29778	1124	14	I will therefore that the younger women marry, bear children, guide the house, give none occasion to the adversary to speak reproachfully.
29779	1124	15	For some are already turned aside after Satan.
29780	1124	16	If any man or woman that believeth have widows, let them relieve them, and let not the church be charged; that it may relieve them that are widows indeed.
29781	1124	17	Let the elders that rule well be counted worthy of double honour, especially they who labour in the word and doctrine.
29782	1124	18	For the scripture saith, Thou shalt not muzzle the ox that treadeth out the corn. And, The labourer is worthy of his reward.
29783	1124	19	Against an elder receive not an accusation, but before two or three witnesses.
29784	1124	20	Them that sin rebuke before all, that others also may fear.
29785	1124	21	I charge thee before God, and the Lord Jesus Christ, and the elect angels, that thou observe these things without preferring one before another, doing nothing by partiality.
29786	1124	22	Lay hands suddenly on no man, neither be partaker of other men's sins: keep thyself pure.
29787	1124	23	Drink no longer water, but use a little wine for thy stomach's sake and thine often infirmities.
29788	1124	24	Some men's sins are open beforehand, going before to judgment; and some men they follow after.
29789	1124	25	Likewise also the good works of some are manifest beforehand; and they that are otherwise cannot be hid.
29790	1125	1	LET as many servants as are under the yoke count their own masters worthy of all honour, that the name of God and his doctrine be not blasphemed.
29791	1125	2	And they that have believing masters, let them not despise them, because they are brethren; but rather do them service, because they are faithful and beloved, partakers of the benefit. These things teach and exhort.
29792	1125	3	If any man teach otherwise, and consent not to wholesome words, even the words of our Lord Jesus Christ, and to the doctrine which is according to godliness;
29793	1125	4	He is proud, knowing nothing, but doting about questions and strifes of words, whereof cometh envy, strife, railings, evil surmisings,
29794	1125	5	Perverse disputings of men of corrupt minds, and destitute of the truth, supposing that gain is godliness: from such withdraw thyself.
29795	1125	6	But godliness with contentment is great gain.
29796	1125	7	For we brought nothing into this world, and it is certain we can carry nothing out.
29797	1125	8	And having food and raiment let us be therewith content.
29798	1125	9	But they that will be rich fall into temptation and a snare, and into many foolish and hurtful lusts, which drown men in destruction and perdition.
29799	1125	10	For the love of money is the root of all evil: which while some coveted after, they have erred from the faith, and pierced themselves through with many sorrows.
29800	1125	11	But thou, O man of God, flee these things; and follow after righteousness, godliness, faith, love, patience, meekness.
29801	1125	12	Fight the good fight of faith, lay hold on eternal life, whereunto thou art also called, and hast professed a good profession before many witnesses.
29802	1125	13	I give thee charge in the sight of God, who quickeneth all things, and before Christ Jesus, who before Pontius Pilate witnessed a good confession;
29803	1125	14	That thou keep this commandment without spot, unrebukeable, until the appearing of our Lord Jesus Christ:
29804	1125	15	Which in his times he shall shew, who is the blessed and only Potentate, the King of kings, and Lord of lords;
29805	1125	16	Who only hath immortality, dwelling in the light which no man can approach unto; whom no man hath seen, nor can see: to whom be honour and power everlasting. Amen.
29806	1125	17	Charge them that are rich in this world, that they be not highminded, nor trust in uncertain riches, but in the living God, who giveth us richly all things to enjoy;
29807	1125	18	That they do good, that they be rich in good works, ready to distribute, willing to communicate;
29808	1125	19	Laying up in store for themselves a good foundation against the time to come, that they may lay hold on eternal life.
29809	1125	20	O Timothy, keep that which is committed to thy trust, avoiding profane and vain babblings, and oppositions of science falsely so called:
29810	1125	21	Which some professing have erred concerning the faith. Grace be with thee. Amen.
29811	1126	1	PAUL, an apostle of Jesus Christ by the will of God, according to the promise of life which is in Christ Jesus,
29812	1126	2	To Timothy, my dearly beloved son: Grace, mercy, and peace, from God the Father and Christ Jesus our Lord.
29813	1126	3	I thank God, whom I serve from my forefathers with pure conscience, that without ceasing I have remembrance of thee in my prayers night and day;
29814	1126	4	Greatly desiring to see thee, being mindful of thy tears, that I may be filled with joy;
29815	1126	5	When I call to remembrance the unfeigned faith that is in thee, which dwelt first in thy grandmother Lois, and thy mother Eunice; and I am persuaded that in thee also.
29816	1126	6	Wherefore I put thee in remembrance that thou stir up the gift of God, which is in thee by the putting on of my hands.
29817	1126	7	For God hath not given us the spirit of fear; but of power, and of love, and of a sound mind.
29818	1126	8	Be not thou therefore ashamed of the testimony of our Lord, nor of me his prisoner: but be thou partaker of the afflictions of the gospel according to the power of God;
29819	1126	9	Who hath saved us, and called us with an holy calling, not according to our works, but according to his own purpose and grace, which was given us in Christ Jesus before the world began,
29820	1126	10	But is now made manifest by the appearing of our Saviour Jesus Christ, who hath abolished death, and hath brought life and immortality to light through the gospel:
29821	1126	11	Whereunto I am appointed a preacher, and an apostle, and a teacher of the Gentiles.
29822	1126	12	For the which cause I also suffer these things: nevertheless I am not ashamed: for I know whom I have believed, and am persuaded that he is able to keep that which I have committed unto him against that day.
29823	1126	13	Hold fast the form of sound words, which thou hast heard of me, in faith and love which is in Christ Jesus.
29824	1126	14	That good thing which was committed unto thee keep by the Holy Ghost which dwelleth in us.
29825	1126	15	This thou knowest, that all they which are in Asia be turned away from me; of whom are Phygellus and Hermogenes.
29826	1126	16	The Lord give mercy unto the house of Onesiphorus; for he oft refreshed me, and was not ashamed of my chain:
29827	1126	17	But, when he was in Rome, he sought me out very diligently, and found me.
29828	1126	18	The Lord grant unto him that he may find mercy of the Lord in that day: and in how many things he ministered unto me at Ephesus, thou knowest very well.
29829	1127	1	THOU therefore, my son, be strong in the grace that is in Christ Jesus.
29830	1127	2	And the things that thou hast heard of me among many witnesses, the same commit thou to faithful men, who shall be able to teach others also.
29831	1127	3	Thou therefore endure hardness, as a good soldier of Jesus Christ.
29832	1127	4	No man that warreth entangleth himself with the affairs of this life; that he may please him who hath chosen him to be a soldier.
29833	1127	5	And if a man also strive for masteries, yet is he not crowned, except he strive lawfully.
29834	1127	6	The husbandman that laboureth must be first partaker of the fruits.
29835	1127	7	Consider what I say; and the Lord give thee understanding in all things.
29836	1127	8	Remember that Jesus Christ of the seed of David was raised from the dead according to my gospel:
29837	1127	9	Wherein I suffer trouble, as an evil doer, even unto bonds; but the word of God is not bound.
29838	1127	10	Therefore I endure all things for the elect's sakes, that they may also obtain the salvation which is in Christ Jesus with eternal glory.
29839	1127	11	It is a faithful saying: For if we be dead with him, we shall also live with him:
29840	1127	12	If we suffer, we shall also reign with him: if we deny him, he also will deny us:
29841	1127	13	If we believe not, yet he abideth faithful: he cannot deny himself.
29842	1127	14	Of these things put them in remembrance, charging them before the Lord that they strive not about words to no profit, but to the subverting of the hearers.
29843	1127	15	Study to shew thyself approved unto God, a workman that needeth not to be ashamed, rightly dividing the word of truth.
29844	1127	16	But shun profane and vain babblings: for they will increase unto more ungodliness.
29845	1127	17	And their word will eat as doth a canker: of whom is Hymenaeus and Philetus;
29846	1127	18	Who concerning the truth have erred, saying that the resurrection is past already; and overthrow the faith of some.
29847	1127	19	Nevertheless the foundation of God standeth sure, having this seal, The Lord knoweth them that are his. And, Let every one that nameth the name of Christ depart from iniquity.
29848	1127	20	But in a great house there are not only vessels of gold and of silver, but also of wood and of earth; and some to honour, and some to dishonour.
29849	1127	21	If a man therefore purge himself from these, he shall be a vessel unto honour, sanctified, and meet for the master's use, and prepared unto every good work.
29850	1127	22	Flee also youthful lusts: but follow righteousness, faith, charity, peace, with them that call on the Lord out of a pure heart.
29851	1127	23	But foolish and unlearned questions avoid, knowing that they do gender strifes.
29852	1127	24	And the servant of the Lord must not strive; but be gentle unto all men, apt to teach, patient,
29853	1127	25	In meekness instructing those that oppose themselves; if God peradventure will give them repentance to the acknowledging of the truth;
29854	1127	26	And that they may recover themselves out of the snare of the devil, who are taken captive by him at his will.
29855	1128	1	THIS know also, that in the last days perilous times shall come.
29856	1128	2	For men shall be lovers of their own selves, covetous, boasters, proud, blasphemers, disobedient to parents, unthankful, unholy,
29857	1128	3	Without natural affection, trucebreakers, false accusers, incontinent, fierce, despisers of those that are good,
29858	1128	4	Traitors, heady, highminded, lovers of pleasures more than lovers of God;
29859	1128	5	Having a form of godliness, but denying the power thereof: from such turn away.
29860	1128	6	For of this sort are they which creep into houses, and lead captive silly women laden with sins, led away with divers lusts,
29861	1128	7	Ever learning, and never able to come to the knowledge of the truth.
29862	1128	8	Now as Jannes and Jambres withstood Moses, so do these also resist the truth: men of corrupt minds, reprobate concerning the faith.
29863	1128	9	But they shall proceed no further: for their folly shall be manifest unto all men, as theirs also was.
29864	1128	10	But thou hast fully known my doctrine, manner of life, purpose, faith, longsuffering, charity, patience,
29865	1128	11	Persecutions, afflictions, which came unto me at Antioch, at Iconium, at Lystra; what persecutions I endured: but out of them all the Lord delivered me.
29866	1128	12	Yea, and all that will live godly in Christ Jesus shall suffer persecution.
29867	1128	13	But evil men and seducers shall wax worse and worse, deceiving, and being deceived.
29868	1128	14	But continue thou in the things which thou hast learned and hast been assured of, knowing of whom thou hast learned them;
29869	1128	15	And that from a child thou hast known the holy scriptures, which are able to make thee wise unto salvation through faith which is in Christ Jesus.
29870	1128	16	All scripture is given by inspiration of God, and is profitable for doctrine, for reproof, for correction, for instruction in righteousness:
29871	1128	17	That the man of God may be perfect, throughly furnished unto all good works.
29872	1129	1	I CHARGE thee therefore before God, and the Lord Jesus Christ, who shall judge the quick and the dead at his appearing and his kingdom;
29873	1129	2	Preach the word; be instant in season, out of season; reprove, rebuke, exhort with all longsuffering and doctrine.
29874	1129	3	For the time will come when they will not endure sound doctrine; but after their own lusts shall they heap to themselves teachers, having itching ears;
29875	1129	4	And they shall turn away their ears from the truth, and shall be turned unto fables.
29876	1129	5	But watch thou in all things, endure afflictions, do the work of an evangelist, make full proof of thy ministry.
29877	1129	6	For I am now ready to be offered, and the time of my departure is at hand.
29878	1129	7	I have fought a good fight, I have finished my course, I have kept the faith:
29879	1129	8	Henceforth there is laid up for me a crown of righteousness, which the Lord, the righteous judge, shall give me at that day: and not to me only, but unto all them also that love his appearing.
29880	1129	9	Do thy diligence to come shortly unto me:
29881	1129	10	For Demas hath forsaken me, having loved this present world, and is departed unto Thessalonica; Crescens to Galatia, Titus unto Dalmatia.
29882	1129	11	Only Luke is with me. Take Mark, and bring him with thee: for he is profitable to me for the ministry.
29883	1129	12	And Tychicus have I sent to Ephesus.
29884	1129	13	The cloke that I left at Troas with Carpus, when thou comest, bring with thee, and the books, but especially the parchments.
29885	1129	14	Alexander the coppersmith did me much evil: the Lord reward him according to his works:
29886	1129	15	Of whom be thou ware also; for he hath greatly withstood our words.
29887	1129	16	At my first answer no man stood with me, but all men forsook me: I pray God that it may not be laid to their charge.
29888	1129	17	Notwithstanding the Lord stood with me, and strengthened me; that by me the preaching might be fully known, and that all the Gentiles might hear: and I was delivered out of the mouth of the lion.
29889	1129	18	And the Lord shall deliver me from every evil work, and will preserve me unto his heavenly kingdom: to whom be glory for ever and ever. Amen.
29890	1129	19	Salute Prisca and Aquila, and the household of Onesiphorus.
29891	1129	20	Erastus abode at Corinth: but Trophimus have I left at Miletum sick.
29892	1129	21	Do thy diligence to come before winter. Eubulus greeteth thee, and Pudens, and Linus, and Claudia, and all the brethren.
29893	1129	22	The Lord Jesus Christ be with thy spirit. Grace be with you. Amen.
29894	1130	1	PAUL, a servant of God, and an apostle of Jesus Christ, according to the faith of God's elect, and the acknowledging of the truth which is after godliness;
29895	1130	2	In hope of eternal life, which God, that cannot lie, promised before the world began;
29896	1130	3	But hath in due times manifested his word through preaching, which is committed unto me according to the commandment of God our Saviour;
29897	1130	4	To Titus, mine own son after the common faith: Grace, mercy, and peace, from God the Father and the Lord Jesus Christ our Saviour.
29898	1130	5	For this cause left I thee in Crete, that thou shouldest set in order the things that are wanting, and ordain elders in every city, as I had appointed thee:
29899	1130	6	If any be blameless, the husband of one wife, having faithful children not accused of riot or unruly.
29900	1130	7	For a bishop must be blameless, as the steward of God; not selfwilled, not soon angry, not given to wine, no striker, not given to filthy lucre;
29901	1130	8	But a lover of hospitality, a lover of good men, sober, just, holy, temperate;
29902	1130	9	Holding fast the faithful word as he hath been taught, that he may be able by sound doctrine both to exhort and to convince the gainsayers.
29903	1130	10	For there are many unruly and vain talkers and deceivers, specially they of the circumcision:
29904	1130	11	Whose mouths must be stopped, who subvert whole houses, teaching things which they ought not, for filthy lucre's sake.
29905	1130	12	One of themselves, even a prophet of their own, said, The Cretians are alway liars, evil beasts, slow bellies.
29906	1130	13	This witness is true. Wherefore rebuke them sharply, that they may be sound in the faith;
29907	1130	14	Not giving heed to Jewish fables, and commandments of men, that turn from the truth.
29908	1130	15	Unto the pure all things are pure: but unto them that are defiled and unbelieving is nothing pure; but even their mind and conscience is defiled.
29909	1130	16	They profess that they know God; but in works they deny him, being abominable, and disobedient, and unto every good work reprobate.
29910	1131	1	BUT speak thou the things which become sound doctrine:
29911	1131	2	That the aged men be sober, grave, temperate, sound in faith, in charity, in patience.
29912	1131	3	The aged women likewise, that they be in behaviour as becometh holiness, not false accusers, not given to much wine, teachers of good things;
29913	1131	4	That they may teach the young women to be sober, to love their husbands, to love their children,
29914	1131	5	To be discreet, chaste, keepers at home, good, obedient to their own husbands, that the word of God be not blasphemed.
29915	1131	6	Young men likewise exhort to be sober minded.
29916	1131	7	In all things shewing thyself a pattern of good works: in doctrine shewing uncorruptness, gravity, sincerity,
29917	1131	8	Sound speech, that cannot be condemned; that he that is of the contrary part may be ashamed, having no evil thing to say of you.
29918	1131	9	Exhort servants to be obedient unto their own masters, and to please them well in all things; not answering again;
29919	1131	10	Not purloining, but shewing all good fidelity; that they may adorn the doctrine of God our Saviour in all things.
29920	1131	11	For the grace of God that bringeth salvation hath appeared to all men,
29921	1131	12	Teaching us that, denying ungodliness and worldly lusts, we should live soberly, righteously, and godly, in this present world;
29922	1131	13	Looking for that blessed hope, and the glorious appearing of the great God and our Saviour Jesus Christ;
29923	1131	14	Who gave himself for us, that he might redeem us from all iniquity, and purify unto himself a peculiar people, zealous of good works.
29924	1131	15	These things speak, and exhort, and rebuke with all authority. Let no man despise thee.
29925	1132	1	PUT them in mind to be subject to principalities and powers, to obey magistrates, to be ready to every good work,
29926	1132	2	To speak evil of no man, to be no brawlers, but gentle, shewing all meekness unto all men.
29927	1132	3	For we ourselves also were sometimes foolish, disobedient, deceived, serving divers lusts and pleasures, living in malice and envy, hateful, and hating one another.
29928	1132	4	But after that the kindness and love of God our Saviour toward man appeared,
29929	1132	5	Not by works of righteousness which we have done, but according to his mercy he saved us, by the washing of regeneration, and renewing of the Holy Ghost;
29930	1132	6	Which he shed on us abundantly through Jesus Christ our Saviour;
29931	1132	7	That being justified by his grace, we should be made heirs according to the hope of eternal life.
29932	1132	8	This is a faithful saying, and these things I will that thou affirm constantly, that they which have believed in God might be careful to maintain good works. These things are good and profitable unto men.
29933	1132	9	But avoid foolish questions, and genealogies, and contentions, and strivings about the law; for they are unprofitable and vain.
29934	1132	10	A man that is an heretick after the first and second admonition reject;
29935	1132	11	Knowing that he that is such is subverted, and sinneth, being condemned of himself.
29936	1132	12	When I shall send Artemas unto thee, or Tychicus, be diligent to come unto me to Nicopolis: for I have determined there to winter.
29937	1132	13	Bring Zenas the lawyer and Apollos on their journey diligently, that nothing be wanting unto them.
29938	1132	14	And let ours also learn to maintain good works for necessary uses, that they be not unfruitful.
29939	1132	15	All that are with me salute thee. Greet them that love us in the faith. Grace be with you all. Amen.
29940	1133	1	PAUL, a prisoner of Jesus Christ, and Timothy our brother, unto Philemon our dearly beloved, and fellowlabourer,
29941	1133	2	And to our beloved Apphia, and Archippus our fellowsoldier, and to the church in thy house:
29942	1133	3	Grace to you, and peace, from God our Father and the Lord Jesus Christ.
29943	1133	4	I thank my God, making mention of thee always in my prayers,
29944	1133	5	Hearing of thy love and faith, which thou hast toward the Lord Jesus, and toward all saints;
29945	1133	6	That the communication of thy faith may become effectual by the acknowledging of every good thing which is in you in Christ Jesus.
29946	1133	7	For we have great joy and consolation in thy love, because the bowels of the saints are refreshed by thee, brother.
29947	1133	8	Wherefore, though I might be much bold in Christ to enjoin thee that which is convenient,
29948	1133	9	Yet for love's sake I rather beseech thee, being such an one as Paul the aged, and now also a prisoner of Jesus Christ.
29949	1133	10	I beseech thee for my son Onesimus, whom I have begotten in my bonds:
29950	1133	11	Which in time past was to thee unprofitable, but now profitable to thee and to me:
29951	1133	12	Whom I have sent again: thou therefore receive him, that is, mine own bowels:
29952	1133	13	Whom I would have retained with me, that in thy stead he might have ministered unto me in the bonds of the gospel:
29953	1133	14	But without thy mind would I do nothing; that thy benefit should not be as it were of necessity, but willingly.
29954	1133	15	For perhaps he therefore departed for a season, that thou shouldest receive him for ever;
29955	1133	16	Not now as a servant, but above a servant, a brother beloved, specially to me, but how much more unto thee, both in the flesh, and in the Lord?
29956	1133	17	If thou count me therefore a partner, receive him as myself.
29957	1133	18	If he hath wronged thee, or oweth thee ought, put that on mine account;
29958	1133	19	I Paul have written it with mine own hand, I will repay it: albeit I do not say to thee how thou owest unto me even thine own self besides.
29959	1133	20	Yea, brother, let me have joy of thee in the Lord: refresh my bowels in the Lord.
29960	1133	21	Having confidence in thy obedience I wrote unto thee, knowing that thou wilt also do more than I say.
29961	1133	22	But withal prepare me also a lodging: for I trust that through your prayers I shall be given unto you.
29962	1133	23	There salute thee Epaphras, my fellowprisoner in Christ Jesus;
29963	1133	24	Marcus, Aristarchus, Demas, Lucas, my fellowlabourers.
29964	1133	25	The grace of our Lord Jesus Christ be with your spirit. Amen.
29965	1134	1	GOD, who at sundry times and in divers manners spake in time past unto the fathers by the prophets,
29966	1134	2	Hath in these last days spoken unto us by his Son, whom he hath appointed heir of all things, by whom also he made the worlds;
29967	1134	3	Who being the brightness of his glory, and the express image of his person, and upholding all things by the word of his power, when he had by himself purged our sins, sat down on the right hand of the Majesty on high;
29968	1134	4	Being made so much better than the angels, as he hath by inheritance obtained a more excellent name than they.
29969	1134	5	For unto which of the angels said he at any time, Thou art my Son, this day have I begotten thee? And again, I will be to him a Father, and he shall be to me a Son?
29970	1134	6	And again, when he bringeth in the firstbegotten into the world, he saith, And let all the angels of God worship him.
29971	1134	7	And of the angels he saith, Who maketh his angels spirits, and his ministers a flame of fire.
29972	1134	8	But unto the Son he saith, Thy throne, O God, is for ever and ever: a sceptre of righteousness is the sceptre of thy kingdom.
29973	1134	9	Thou hast loved righteousness, and hated iniquity; therefore God, even thy God, hath anointed thee with the oil of gladness above thy fellows.
29974	1134	10	And, Thou, Lord, in the beginning hast laid the foundation of the earth; and the heavens are the works of thine hands:
29975	1134	11	They shall perish; but thou remainest; and they all shall wax old as doth a garment;
29976	1134	12	And as a vesture shalt thou fold them up, and they shall be changed: but thou art the same, and thy years shall not fail.
29977	1134	13	But to which of the angels said he at any time, Sit on my right hand, until I make thine enemies thy footstool?
29978	1134	14	Are they not all ministering spirits, sent forth to minister for them who shall be heirs of salvation?
29979	1135	1	THEREFORE we ought to give the more earnest heed to the things which we have heard, lest at any time we should let them slip.
29980	1135	2	For if the word spoken by angels was stedfast, and every transgression and disobedience received a just recompence of reward;
29981	1135	3	How shall we escape, if we neglect so great salvation; which at the first began to be spoken by the Lord, and was confirmed unto us by them that heard him;
29982	1135	4	God also bearing them witness, both with signs and wonders, and with divers miracles, and gifts of the Holy Ghost, according to his own will?
29983	1135	5	For unto the angels hath he not put in subjection the world to come, whereof we speak.
29984	1135	6	But one in a certain place testified, saying, What is man, that thou art mindful of him? or the son of man, that thou visitest him?
29985	1135	7	Thou madest him a little lower than the angels; thou crownedst him with glory and honour, and didst set him over the works of thy hands:
29986	1135	8	Thou hast put all things in subjection under his feet. For in that he put all in subjection under him, he left nothing that is not put under him. But now we see not yet all things put under him.
29987	1135	9	But we see Jesus, who was made a little lower than the angels for the suffering of death, crowned with glory and honour; that he by the grace of God should taste death for every man.
29988	1135	10	For it became him, for whom are all things, and by whom are all things, in bringing many sons unto glory, to make the captain of their salvation perfect through sufferings.
29989	1135	11	For both he that sanctifieth and they who are sanctified are all of one: for which cause he is not ashamed to call them brethren,
29990	1135	12	Saying, I will declare thy name unto my brethren, in the midst of the church will I sing praise unto thee.
29991	1135	13	And again, I will put my trust in him. And again, Behold I and the children which God hath given me.
29992	1135	14	Forasmuch then as the children are partakers of flesh and blood, he also himself likewise took part of the same; that through death he might destroy him that had the power of death, that is, the devil;
29993	1135	15	And deliver them who through fear of death were all their lifetime subject to bondage.
29994	1135	16	For verily he took not on him the nature of angels; but he took on him the seed of Abraham.
29995	1135	17	Wherefore in all things it behoved him to be made like unto his brethren, that he might be a merciful and faithful high priest in things pertaining to God, to make reconciliation for the sins of the people.
29996	1135	18	For in that he himself hath suffered being tempted, he is able to succour them that are tempted.
29997	1136	1	WHEREFORE, holy brethren, partakers of the heavenly calling, consider the Apostle and High Priest of our profession, Christ Jesus;
29998	1136	2	Who was faithful to him that appointed him, as also Moses was faithful in all his house.
29999	1136	3	For this man was counted worthy of more glory than Moses, inasmuch as he who hath builded the house hath more honour than the house.
30000	1136	4	For every house is builded by some man; but he that built all things is God.
30001	1136	5	And Moses verily was faithful in all his house, as a servant, for a testimony of those things which were to be spoken after;
30002	1136	6	But Christ as a son over his own house; whose house are we, if we hold fast the confidence and the rejoicing of the hope firm unto the end.
30003	1136	7	Wherefore (as the Holy Ghost saith, To day if ye will hear his voice,
30004	1136	8	Harden not your hearts, as in the provocation, in the day of temptation in the wilderness:
30005	1136	9	When your fathers tempted me, proved me, and saw my works forty years.
30006	1136	10	Wherefore I was grieved with that generation, and said, They do alway err in their heart; and they have not known my ways.
30007	1136	11	So I sware in my wrath, They shall not enter into my rest.)
30008	1136	12	Take heed, brethren, lest there be in any of you an evil heart of unbelief, in departing from the living God.
30009	1136	13	But exhort one another daily, while it is called To day; lest any of you be hardened through the deceitfulness of sin.
30010	1136	14	For we are made partakers of Christ, if we hold the beginning of our confidence stedfast unto the end;
30011	1136	15	While it is said, To day if ye will hear his voice, harden not your hearts, as in the provocation.
30012	1136	16	For some, when they had heard, did provoke: howbeit not all that came out of Egypt by Moses.
30013	1136	17	But with whom was he grieved forty years? was it not with them that had sinned, whose carcases fell in the wilderness?
30014	1136	18	And to whom sware he that they should not enter into his rest, but to them that believed not?
30015	1136	19	So we see that they could not enter in because of unbelief.
30016	1137	1	LET us therefore fear, lest, a promise being left us of entering into his rest, any of you should seem to come short of it.
30017	1137	2	For unto us was the gospel preached, as well as unto them: but the word preached did not profit them, not being mixed with faith in them that heard it.
30018	1137	3	For we which have believed do enter into rest, as he said, As I have sworn in my wrath, if they shall enter into my rest: although the works were finished from the foundation of the world.
30019	1137	4	For he spake in a certain place of the seventh day on this wise, And God did rest the seventh day from all his works.
30020	1137	5	And in this place again, If they shall enter into my rest.
30021	1137	6	Seeing therefore it remaineth that some must enter therein, and they to whom it was first preached entered not in because of unbelief:
30022	1137	7	Again, he limiteth a certain day, saying in David, To day, after so long a time; as it is said, To day if ye will hear his voice, harden not your hearts.
30023	1137	8	For if Jesus had given them rest, then would he not afterward have spoken of another day.
30024	1137	9	There remaineth therefore a rest to the people of God.
30025	1137	10	For he that is entered into his rest, he also hath ceased from his own works, as God did from his.
30026	1137	11	Let us labour therefore to enter into that rest, lest any man fall after the same example of unbelief.
30027	1137	12	For the word of God is quick, and powerful, and sharper than any two-edged sword, piercing even to the dividing asunder of soul and spirit, and of the joints and marrow, and is a discerner of the thoughts and intents of the heart.
30028	1137	13	Neither is there any creature that is not manifest in his sight: but all things are naked and opened unto the eyes of him with whom we have to do.
30029	1137	14	Seeing then that we have a great high priest, that is passed into the heavens, Jesus the Son of God, let us hold fast our profession.
30030	1137	15	For we have not an high priest which cannot be touched with the feeling of our infirmities; but was in all points tempted like as we are, yet without sin.
30031	1137	16	Let us therefore come boldly unto the throne of grace, that we may obtain mercy, and find grace to help in time of need.
30032	1138	1	FOR every high priest taken from among men is ordained for men in things pertaining to God, that he may offer both gifts and sacrifices for sins:
30033	1138	2	Who can have compassion on the ignorant, and on them that are out of the way; for that he himself also is compassed with infirmity.
30034	1138	3	And by reason hereof he ought, as for the people, so also for himself, to offer for sins.
30035	1138	4	And no man taketh this honour unto himself, but he that is called of God, as was Aaron.
30036	1138	5	So also Christ glorified not himself to be made an high priest; but he that said unto him, Thou art my Son, to day have I begotten thee.
30037	1138	6	As he saith also in another place, Thou art a priest for ever after the order of Melchisedec.
30038	1138	7	Who in the days of his flesh, when he had offered up prayers and supplications with strong crying and tears unto him that was able to save him from death, and was heard in that he feared;
30039	1138	8	Though he were a Son, yet learned he obedience by the things which he suffered;
30040	1138	9	And being made perfect, he became the author of eternal salvation unto all them that obey him;
30041	1138	10	Called of God an high priest after the order of Melchisedec.
30042	1138	11	Of whom we have many things to say, and hard to be uttered, seeing ye are dull of hearing.
30043	1138	12	For when for the time ye ought to be teachers, ye have need that one teach you again which be the first principles of the oracles of God; and are become such as have need of milk, and not of strong meat.
30044	1138	13	For every one that useth milk is unskilful in the word of righteousness: for he is a babe.
30045	1138	14	But strong meat belongeth to them that are of full age, even those who by reason of use have their senses exercised to discern both good and evil.
30046	1139	1	THEREFORE leaving the principles of the doctrine of Christ, let us go on unto perfection; not laying again the foundation of repentance from dead works, and of faith toward God,
30047	1139	2	Of the doctrine of baptisms, and of laying on of hands, and of resurrection of the dead, and of eternal judgment.
30048	1139	3	And this will we do, if God permit.
30049	1139	4	For it is impossible for those who were once enlightened, and have tasted of the heavenly gift, and were made partakers of the Holy Ghost,
30050	1139	5	And have tasted the good word of God, and the powers of the world to come,
30051	1139	6	If they shall fall away, to renew them again unto repentance; seeing they crucify to themselves the Son of God afresh, and put him to an open shame.
30052	1139	7	For the earth which drinketh in the rain that cometh oft upon it, and bringeth forth herbs meet for them by whom it is dressed, receiveth blessing from God:
30053	1139	8	But that which beareth thorns and briers is rejected, and is nigh unto cursing; whose end is to be burned.
30054	1139	9	But, beloved, we are persuaded better things of you, and things that accompany salvation, though we thus speak.
30055	1139	10	For God is not unrighteous to forget your work and labour of love, which ye have shewed toward his name, in that ye have ministered to the saints, and do minister.
30056	1139	11	And we desire that every one of you do shew the same diligence to the full assurance of hope unto the end:
30057	1139	12	That ye be not slothful, but followers of them who through faith and patience inherit the promises.
30058	1139	13	For when God made promise to Abraham, because he could swear by no greater, he sware by himself,
30059	1139	14	Saying, Surely blessing I will bless thee, and multiplying I will multiply thee.
30060	1139	15	And so, after he had patiently endured, he obtained the promise.
30061	1139	16	For men verily swear by the greater: and an oath for confirmation is to them an end of all strife.
30062	1139	17	Wherein God, willing more abundantly to shew unto the heirs of promise the immutability of his counsel, confirmed it by an oath:
30063	1139	18	That by two immutable things, in which it was impossible for God to lie, we might have a strong consolation, who have fled for refuge to lay hold upon the hope set before us:
30064	1139	19	Which hope we have as an anchor of the soul, both sure and stedfast, and which entereth into that within the veil;
30065	1139	20	Whither the forerunner is for us entered, even Jesus, made an high priest for ever after the order of Melchisedec.
30066	1140	1	FOR this Melchisedec, king of Salem, priest of the most high God, who met Abraham returning from the slaughter of the kings, and blessed him;
30067	1140	2	To whom also Abraham gave a tenth part of all; first being by interpretation King of righteousness, and after that also King of Salem, which is, King of peace;
30068	1140	3	Without father, without mother, without descent, having neither beginning of days, nor end of life; but made like unto the Son of God; abideth a priest continually.
30069	1140	4	Now consider how great this man was, unto whom even the patriarch Abraham gave the tenth of the spoils.
30070	1140	5	And verily they that are of the sons of Levi, who receive the office of the priesthood, have a commandment to take tithes of the people according to the law, that is, of their brethren, though they come out of the loins of Abraham:
30071	1140	6	But he whose descent is not counted from them received tithes of Abraham, and blessed him that had the promises.
30072	1140	7	And without all contradiction the less is blessed of the better.
30073	1140	8	And here men that die receive tithes; but there he receiveth them, of whom it is witnessed that he liveth.
30074	1140	9	And as I may so say, Levi also, who receiveth tithes, payed tithes in Abraham.
30075	1140	10	For he was yet in the loins of his father, when Melchisedec met him.
30076	1140	11	If therefore perfection were by the Levitical priesthood, (for under it the people received the law,) what further need was there that another priest should rise after the order of Melchisedec, and not be called after the order of Aaron?
30077	1140	12	For the priesthood being changed, there is made of necessity a change also of the law.
30078	1140	13	For he of whom these things are spoken pertaineth to another tribe, of which no man gave attendance at the altar.
30079	1140	14	For it is evident that our Lord sprang out of Juda; of which tribe Moses spake nothing concerning priesthood.
30080	1140	15	And it is yet far more evident: for that after the similitude of Melchisedec there ariseth another priest,
30081	1140	16	Who is made, not after the law of a carnal commandment, but after the power of an endless life.
30082	1140	17	For he testifieth, Thou art a priest for ever after the order of Melchisedec.
30083	1140	18	For there is verily a disannulling of the commandment going before for the weakness and unprofitableness thereof.
30084	1140	19	For the law made nothing perfect, but the bringing in of a better hope did; by the which we draw nigh unto God.
30085	1140	20	And inasmuch as not without an oath he was made priest:
30086	1140	21	(For those priests were made without an oath; but this with an oath by him that said unto him, The Lord sware and will not repent, Thou art a priest for ever after the order of Melchisedec:)
30087	1140	22	By so much was Jesus made a surety of a better testament.
30088	1140	23	And they truly were many priests, because they were not suffered to continue by reason of death:
30089	1140	24	But this man, because he continueth ever, hath an unchangeable priesthood.
30090	1140	25	Wherefore he is able also to save them to the uttermost that come unto God by him, seeing he ever liveth to make intercession for them.
30091	1140	26	For such an high priest became us, who is holy, harmless, undefiled, separate from sinners, and made higher than the heavens;
30092	1140	27	Who needeth not daily, as those high priests, to offer up sacrifice, first for his own sins, and then for the people's: for this he did once, when he offered up himself.
30093	1140	28	For the law maketh men high priests which have infirmity; but the word of the oath, which was since the law, maketh the Son, who is consecrated for evermore.
30094	1141	1	NOW of the things which we have spoken this is the sum: We have such an high priest, who is set on the right hand of the throne of the Majesty in the heavens;
30095	1141	2	A minister of the sanctuary, and of the true tabernacle, which the Lord pitched, and not man.
30096	1141	3	For every high priest is ordained to offer gifts and sacrifices: wherefore it is of necessity that this man have somewhat also to offer.
30097	1141	4	For if he were on earth, he should not be a priest, seeing that there are priests that offer gifts according to the law:
30098	1141	5	Who serve unto the example and shadow of heavenly things, as Moses was admonished of God when he was about to make the tabernacle: for, See, saith he, that thou make all things according to the pattern shewed to thee in the mount.
30099	1141	6	But now hath he obtained a more excellent ministry, by how much also he is the mediator of a better covenant, which was established upon better promises.
30100	1141	7	For if that first covenant had been faultless, then should no place have been sought for the second.
30101	1141	8	For finding fault with them, he saith, Behold, the days come, saith the Lord, when I will make a new covenant with the house of Israel and with the house of Judah:
30102	1141	9	Not according to the covenant that I made with their fathers in the day when I took them by the hand to lead them out of the land of Egypt; because they continued not in my covenant, and I regarded them not, saith the Lord.
30103	1141	10	For this is the covenant that I will make with the house of Israel after those days, saith the Lord; I will put my laws into their mind, and write them in their hearts: and I will be to them a God, and they shall be to me a people:
30104	1141	11	And they shall not teach every man his neighbour, and every man his brother, saying, Know the Lord: for all shall know me, from the least to the greatest.
30105	1141	12	For I will be merciful to their unrighteousness, and their sins and their iniquities will I remember no more.
30106	1141	13	In that he saith, A new covenant, he hath made the first old. Now that which decayeth and waxeth old is ready to vanish away.
30107	1142	1	THEN verily the first covenant had also ordinances of divine service, and a worldly sanctuary.
30108	1142	2	For there was a tabernacle made; the first, wherein was the candlestick, and the table, and the shewbread; which is called the sanctuary.
30109	1142	3	And after the second veil, the tabernacle which is called the Holiest of all;
30110	1142	4	Which had the golden censer, and the ark of the covenant overlaid round about with gold, wherein was the golden pot that had manna, and Aaron's rod that budded, and the tables of the covenant;
30111	1142	5	And over it the cherubims of glory shadowing the mercyseat; of which we cannot now speak particularly.
30112	1142	6	Now when these things were thus ordained, the priests went always into the first tabernacle, accomplishing the service of God.
30113	1142	7	But into the second went the high priest alone once every year, not without blood, which he offered for himself, and for the errors of the people:
30114	1142	8	The Holy Ghost this signifying, that the way into the holiest of all was not yet made manifest, while as the first tabernacle was yet standing:
30115	1142	9	Which was a figure for the time then present, in which were offered both gifts and sacrifices, that could not make him that did the service perfect, as pertaining to the conscience;
30116	1142	10	Which stood only in meats and drinks, and divers washings, and carnal ordinances, imposed on them until the time of reformation.
30117	1142	11	But Christ being come an high priest of good things to come, by a greater and more perfect tabernacle, not made with hands, that is to say, not of this building;
30118	1142	12	Neither by the blood of goats and calves, but by his own blood he entered in once into the holy place, having obtained eternal redemption for us.
30119	1142	13	For if the blood of bulls and of goats, and the ashes of an heifer sprinkling the unclean, sanctifieth to the purifying of the flesh:
30120	1142	14	How much more shall the blood of Christ, who through the eternal Spirit offered himself without spot to God, purge your conscience from dead works to serve the living God?
30121	1142	15	And for this cause he is the mediator of the new testament, that by means of death, for the redemption of the transgressions that were under the first testament, they which are called might receive the promise of eternal inheritance.
30122	1142	16	For where a testament is, there must also of necessity be the death of the testator.
30123	1142	17	For a testament is of force after men are dead: otherwise it is of no strength at all while the testator liveth.
30124	1142	18	Whereupon neither the first testament was dedicated without blood.
30125	1142	19	For when Moses had spoken every precept to all the people according to the law, he took the blood of calves and of goats, with water, and scarlet wool, and hyssop, and sprinkled both the book, and all the people,
30126	1142	20	Saying, This is the blood of the testament which God hath enjoined unto you.
30127	1142	21	Moreover he sprinkled with blood both the tabernacle, and all the vessels of the ministry.
30128	1142	22	And almost all things are by the law purged with blood; and without shedding of blood is no remission.
30129	1142	23	It was therefore necessary that the patterns of things in the heavens should be purified with these; but the heavenly things themselves with bettersacrifices than these.
30130	1142	24	For Christ is not entered into the holy places made with hands, which are the figures of the true; but into heaven itself, now to appear in the presence of God for us:
30131	1142	25	Nor yet that he should offer himself often, as the high priest entereth into the holy place every year with blood of others;
30132	1142	26	For then must he often have suffered since the foundation of the world: but now once in the end of the world hath he appeared to put away sin by the sacrifice of himself.
30133	1142	27	And as it is appointed unto men once to die, but after this the judgment:
30134	1142	28	So Christ was once offered to bear the sins of many; and unto them that look for him shall he appear the second time without sin unto salvation.
30135	1143	1	FOR the law having a shadow of good things to come, and not the very image of the things, can never with those sacrifices which they offered year by year continually make the comers thereunto perfect.
30136	1143	2	For then would they not have ceased to be offered? because that the worshippers once purged should have had no more conscience of sins.
30137	1143	3	But in those sacrifices there is a remembrance again made of sins every year.
30138	1143	4	For it is not possible that the blood of bulls and of goats should take away sins.
30139	1143	5	Wherefore when he cometh into the world, he saith, Sacrifice and offering thou wouldest not, but a body hast thou prepared me:
30140	1143	6	In burnt offerings and sacrifices for sin thou hast had no pleasure.
30141	1143	7	Then said I, Lo, I come (in the volume of the book it is written of me,) to do thy will, O God.
30142	1143	8	Above when he said, Sacrifice and offering and burnt offerings and offering for sin thou wouldest not, neither hadst pleasure therein; which are offered by the law;
30143	1143	9	Then said he, Lo, I come to do thy will, O God. He taketh away the first, that he may establish the second.
30144	1143	10	By the which will we are sanctified through the offering of the body of Jesus Christ once for all.
30145	1143	11	And every priest standeth daily ministering and offering oftentimes the same sacrifices, which can never take away sins:
30146	1143	12	But this man, after he had offered one sacrifice for sins for ever, sat down on the right hand of God;
30147	1143	13	From henceforth expecting till his enemies be made his footstool.
30148	1143	14	For by one offering he hath perfected for ever them that are sanctified.
30149	1143	15	Whereof the Holy Ghost also is a witness to us: for after that he had said before,
30150	1143	16	This is the covenant that I will make with them after those days, saith the Lord, I will put my laws into their hearts, and in their minds will I write them;
30151	1143	17	And their sins and iniquities will I remember no more.
30152	1143	18	Now where remission of these is, there is no more offering for sin.
30153	1143	19	Having therefore, brethren, boldness to enter into the holiest by the blood of Jesus,
30154	1143	20	By a new and living way, which he hath consecrated for us, through the veil, that is to say, his flesh;
30155	1143	21	And having an high priest over the house of God;
30156	1143	22	Let us draw near with a true heart in full assurance of faith, having our hearts sprinkled from an evil conscience, and our bodies washed with pure water.
30157	1143	23	Let us hold fast the profession of our faith without wavering; (for he is faithful that promised;)
30158	1143	24	And let us consider one another to provoke unto love and to good works:
30159	1143	25	Not forsaking the assembling of ourselves together, as the manner of some is; but exhorting one another: and so much the more, as ye see the day approaching.
30160	1143	26	For if we sin wilfully after that we have received the knowledge of the truth, there remaineth no more sacrifice for sins,
30161	1143	27	But a certain fearful looking for of judgment and fiery indignation, which shall devour the adversaries.
30162	1143	28	He that despised Moses' law died without mercy under two or three witnesses:
30163	1143	29	Of how much sorer punishment, suppose ye, shall he be thought worthy, who hath trodden under foot the Son of God, and hath counted the blood of the covenant, wherewith he was sanctified, an unholy thing, and hath done despite unto the Spirit of grace?
30164	1143	30	For we know him that hath said, Vengeance belongeth unto me, I will recompense, saith the Lord. And again, The Lord shall judge his people.
30165	1143	31	It is a fearful thing to fall into the hands of the living God.
30166	1143	32	But call to remembrance the former days, in which, after ye were illuminated, ye endured a great fight of afflictions;
30167	1143	33	Partly, whilst ye were made a gazingstock both by reproaches and afflictions; and partly, whilst ye became companions of them that were so used.
30168	1143	34	For ye had compassion of me in my bonds, and took joyfully the spoiling of your goods, knowing in yourselves that ye have in heaven a better and an enduring substance.
30169	1143	35	Cast not away therefore your confidence, which hath great recompence of reward.
30170	1143	36	For ye have need of patience, that, after ye have done the will of God, ye might receive the promise.
30171	1143	37	For yet a little while, and he that shall come will come, and will not tarry.
30172	1143	38	Now the just shall live by faith: but if any man draw back, my soul shall have no pleasure in him.
30173	1143	39	But we are not of them who draw back unto perdition; but of them that believe to the saving of the soul.
30174	1144	1	NOW faith is the substance of things hoped for, the evidence of things not seen.
30175	1144	2	For by it the elders obtained a good report.
30176	1144	3	Through faith we understand that the worlds were framed by the word of God, so that things which are seen were not made of things which do appear.
30177	1144	4	By faith Abel offered unto God a more excellent sacrifice than Cain, by which he obtained witness that he was righteous, God testifying of his gifts: and by it he being dead yet speaketh.
30178	1144	5	By faith Enoch was translated that he should not see death; and was not found, because God had translated him: for before his translation he had this testimony, that he pleased God.
30179	1144	6	But without faith it is impossible to please him: for he that cometh to God must believe that he is, and that he is a rewarder of them that diligently seek him.
30180	1144	7	By faith Noah, being warned of God of things not seen as yet, moved with fear, prepared an ark to the saving of his house; by the which he condemned the world, and became heir of the righteousness which is by faith.
30181	1144	8	By faith Abraham, when he was called to go out into a place which he should after receive for an inheritance, obeyed; and he went out, not knowing whither he went.
30182	1144	9	By faith he sojourned in the land of promise, as in a strange country, dwelling in tabernacles with Isaac and Jacob, the heirs with him of the same promise:
30183	1144	10	For he looked for a city which hath foundations, whose builder and maker is God.
30184	1144	11	Through faith also Sara herself received strength to conceive seed, and was delivered of a child when she was past age, because she judged him faithful who had promised.
30185	1144	12	Therefore sprang there even of one, and him as good as dead, so many as the stars of the sky in multitude, and as the sand which is by the sea shore innumerable.
30186	1144	13	These all died in faith, not having received the promises, but having seen them afar off, and were persuaded of them, and embraced them, and confessed that they were strangers and pilgrims on the earth.
30187	1144	14	For they that say such things declare plainly that they seek a country.
30188	1144	15	And truly, if they had been mindful of that country from whence they came out, they might have had opportunity to have returned.
30189	1144	16	But now they desire a better country, that is, an heavenly: wherefore God is not ashamed to be called their God: for he hath prepared for them a city.
30190	1144	17	By faith Abraham, when he was tried, offered up Isaac: and he that had received the promises offered up his only begotten son,
30191	1144	18	Of whom it was said, That in Isaac shall thy seed be called:
30192	1144	19	Accounting that God was able to raise him up, even from the dead; from whence also he received him in a figure.
30193	1144	20	By faith Isaac blessed Jacob and Esau concerning things to come.
30194	1144	21	By faith Jacob, when he was a dying, blessed both the sons of Joseph; and worshipped, leaning upon the top of his staff.
30195	1144	22	By faith Joseph, when he died, made mention of the departing of the children of Israel; and gave commandment concerning his bones.
30196	1144	23	By faith Moses, when he was born, was hid three months of his parents, because they saw he was a proper child; and they were not afraid of the king's commandment.
30197	1144	24	By faith Moses, when he was come to years, refused to be called the son of Pharaoh's daughter;
30198	1144	25	Choosing rather to suffer affliction with the people of God, than to enjoy the pleasures of sin for a season;
30199	1144	26	Esteeming the reproach of Christ greater riches than the treasures in Egypt: for he had respect unto the recompence of the reward.
30200	1144	27	By faith he forsook Egypt, not fearing the wrath of the king: for he endured, as seeing him who is invisible.
30201	1144	28	Through faith he kept the passover, and the sprinkling of blood, lest he that destroyed the firstborn should touch them.
30202	1144	29	By faith they passed through the Red sea as by dry land: which the Egyptians assaying to do were drowned.
30203	1144	30	By faith the walls of Jericho fell down, after they were compassed about seven days.
30204	1144	31	By faith the harlot Rahab perished not with them that believed not, when she had received the spies with peace.
30205	1144	32	And what shall I more say? for the time would fail me to tell of Gedeon, and of Barak, and of Samson, and of Jephthae; of David also, and Samuel, and of the prophets:
30206	1144	33	Who through faith subdued kingdoms, wrought righteousness, obtained promises, stopped the mouths of lions,
30207	1144	34	Quenched the violence of fire, escaped the edge of the sword, out of weakness were made strong, waxed valiant in fight, turned to flight the armies of the aliens.
30208	1144	35	Women received their dead raised to life again: and others were tortured, not accepting deliverance; that they might obtain a better resurrection:
30209	1144	36	And others had trial of cruel mockings and scourgings, yea, moreover of bonds and imprisonment:
30210	1144	37	They were stoned, they were sawn asunder, were tempted, were slain with the sword: they wandered about in sheepskins and goatskins; being destitute, afflicted, tormented;
30211	1144	38	(Of whom the world was not worthy:) they wandered in deserts, and inmountains, and in dens and caves of the earth.
30212	1144	39	And these all, having obtained a good report through faith, received not the promise:
30213	1144	40	God having provided some better thing for us, that they without us should not be made perfect.
30214	1145	1	WHEREFORE seeing we also are compassed about with so great a cloud of witnesses, let us lay aside every weight, and the sin which doth so easily beset us, and let us run with patience the race that is set before us,
30215	1145	2	Looking unto Jesus the author and finisher of our faith; who for the joy that was set before him endured the cross, despising the shame, and is set down at the right hand of the throne of God.
30216	1145	3	For consider him that endured such contradiction of sinners against himself, lest ye be wearied and faint in your minds.
30217	1145	4	Ye have not yet resisted unto blood, striving against sin.
30218	1145	5	And ye have forgotten the exhortation which speaketh unto you as unto children, My son, despise not thou the chastening of the Lord, nor faint when thou art rebuked of him:
30219	1145	6	For whom the Lord loveth he chasteneth, and scourgeth every son whom he receiveth.
30220	1145	7	If ye endure chastening, God dealeth with you as with sons; for what son is he whom the father chasteneth not?
30221	1145	8	But if ye be without chastisement, whereof all are partakers, then are ye bastards, and not sons.
30222	1145	9	Furthermore we have had fathers of our flesh which corrected us, and we gave them reverence: shall we not much rather be in subjection unto the Father of spirits, and live?
30223	1145	10	For they verily for a few days chastened us after their own pleasure; but he for our profit, that we might be partakers of his holiness.
30224	1145	11	Now no chastening for the present seemeth to be joyous, but grievous: nevertheless afterward it yieldeth the peaceable fruit of righteousness unto them which are exercised thereby.
30225	1145	12	Wherefore lift up the hands which hang down, and the feeble knees;
30226	1145	13	And make straight paths for your feet, lest that which is lame be turned out of the way; but let it rather be healed.
30227	1145	14	Follow peace with all men, and holiness, without which no man shall see the Lord:
30228	1145	15	Looking diligently lest any man fail of the grace of God; lest any root of bitterness springing up trouble you, and thereby many be defiled;
30229	1145	16	Lest there be any fornicator, or profane person, as Esau, who for one morsel of meat sold his birthright.
30230	1145	17	For ye know how that afterward, when he would have inherited the blessing, he was rejected: for he found no place of repentance, though he sought it carefully with tears.
30231	1145	18	For ye are not come unto the mount that might be touched, and that burned with fire, nor unto blackness, and darkness, and tempest,
30232	1145	19	And the sound of a trumpet, and the voice of words; which voice they that heard intreated that the word should not be spoken to them any more:
30233	1145	20	(For they could not endure that which was commanded, And if so much as a beast touch the mountain, it shall be stoned, or thrust through with a dart:
30234	1145	21	And so terrible was the sight, that Moses said, I exceedingly fear and quake:)
30235	1145	22	But ye are come unto mount Sion, and unto the city of the living God, the heavenly Jerusalem, and to an innumerable company of angels,
30236	1145	23	To the general assembly and church of the firstborn, which are written in heaven, and to God the Judge of all, and to the spirits of just men made perfect,
30237	1145	24	And to Jesus the mediator of the new covenant, and to the blood of sprinkling, that speaketh better things than that of Abel.
30238	1145	25	See that ye refuse not him that speaketh. For if they escaped not who refused him that spake on earth, much more shall not we escape, if we turn away from him that speaketh from heaven:
30239	1145	26	Whose voice then shook the earth: but now he hath promised, saying, Yet once more I shake not the earth only, but also heaven.
30240	1145	27	And this word, Yet once more, signifieth the removing of those things that are shaken, as of things that are made, that those things which cannot be shaken may remain.
30241	1145	28	Wherefore we receiving a kingdom which cannot be moved, let us have grace, whereby we may serve God acceptably with reverence and godly fear:
30242	1145	29	For our God is a consuming fire.
30243	1146	1	LET brotherly love continue.
30244	1146	2	Be not forgetful to entertain strangers: for thereby some have entertained angels unawares.
30245	1146	3	Remember them that are in bonds, as bound with them; and them which suffer adversity, as being yourselves also in the body.
30246	1146	4	Marriage is honourable in all, and the bed undefiled: but whoremongers and adulterers God will judge.
30247	1146	5	Let your conversation be without covetousness; and be content with such things as ye have: for he hath said, I will never leave thee, nor forsake thee.
30248	1146	6	So that we may boldly say, The Lord is my helper, and I will not fear what man shall do unto me.
30249	1146	7	Remember them which have the rule over you, who have spoken unto you the word of God: whose faith follow, considering the end of their conversation.
30250	1146	8	Jesus Christ the same yesterday, and to day, and for ever.
30251	1146	9	Be not carried about with divers and strange doctrines. For it is a good thing that the heart be established with grace; not with meats, which have not profited them that have been occupied therein.
30252	1146	10	We have an altar, whereof they have no right to eat which serve the tabernacle.
30253	1146	11	For the bodies of those beasts, whose blood is brought into the sanctuary by the high priest for sin, are burned without the camp.
30254	1146	12	Wherefore Jesus also, that he might sanctify the people with his own blood, suffered without the gate.
30255	1146	13	Let us go forth therefore unto him without the camp, bearing his reproach.
30256	1146	14	For here have we no continuing city, but we seek one to come.
30257	1146	15	By him therefore let us offer the sacrifice of praise to God continually, that is, the fruit of our lips giving thanks to his name.
30258	1146	16	But to do good and to communicate forget not: for with such sacrifices God is well pleased.
30259	1146	17	Obey them that have the rule over you, and submit yourselves: for they watch for your souls, as they that must give account, that they may do it with joy, and not with grief: for that is unprofitable for you.
30260	1146	18	Pray for us: for we trust we have a good conscience, in all things willing to live honestly.
30261	1146	19	But I beseech you the rather to do this, that I may be restored to you the sooner.
30262	1146	20	Now the God of peace, that brought again from the dead our Lord Jesus, that great shepherd of the sheep, through the blood of the everlasting covenant,
30263	1146	21	Make you perfect in every good work to do his will, working in you that which is wellpleasing in his sight, through Jesus Christ; to whom be glory for ever and ever. Amen.
30264	1146	22	And I beseech you, brethren, suffer the word of exhortation: for I have written a letter unto you in few words.
30265	1146	23	Know ye that our brother Timothy is set at liberty; with whom, if he come shortly, I will see you.
30266	1146	24	Salute all them that have the rule over you, and all the saints. They of Italy salute you.
30267	1146	25	Grace be with you all. Amen.
30268	1147	1	JAMES, a servant of God and of the Lord Jesus Christ, to the twelve tribes which are scattered abroad, greeting.
30269	1147	2	My brethren, count it all joy when ye fall into divers temptations;
30270	1147	3	Knowing this, that the trying of your faith worketh patience.
30271	1147	4	But let patience have her perfect work, that ye may be perfect and entire, wanting nothing.
30272	1147	5	If any of you lack wisdom, let him ask of God, that giveth to all men liberally, and upbraideth not; and it shall be given him.
30273	1147	6	But let him ask in faith, nothing wavering. For he that wavereth is like a wave of the sea driven with the wind and tossed.
30274	1147	7	For let not that man think that he shall receive any thing of the Lord.
30275	1147	8	A double minded man is unstable in all his ways.
30276	1147	9	Let the brother of low degree rejoice in that he is exalted:
30277	1147	10	But the rich, in that he is made low: because as the flower of the grass he shall pass away.
30278	1147	11	For the sun is no sooner risen with a burning heat, but it withereth the grass, and the flower thereof falleth, and the grace of the fashion of it perisheth: so also shall the rich man fade away in his ways.
30279	1147	12	Blessed is the man that endureth temptation: for when he is tried, he shall receive the crown of life, which the Lord hath promised to them that love him.
30280	1147	13	Let no man say when he is tempted, I am tempted of God: for God cannot be tempted with evil, neither tempteth he any man:
30281	1147	14	But every man is tempted, when he is drawn away of his own lust, and enticed.
30282	1147	15	Then when lust hath conceived, it bringeth forth sin: and sin, when it is finished, bringeth forth death.
30283	1147	16	Do not err, my beloved brethren.
30284	1147	17	Every good gift and every perfect gift is from above, and cometh down from the Father of lights, with whom is no variableness, neither shadow of turning.
30285	1147	18	Of his own will begat he us with the word of truth, that we should be a kind of firstfruits of his creatures.
30286	1147	19	Wherefore, my beloved brethren, let every man be swift to hear, slow to speak, slow to wrath:
30287	1147	20	For the wrath of man worketh not the righteousness of God.
30288	1147	21	Wherefore lay apart all filthiness and superfluity of naughtiness, and receive with meekness the engrafted word, which is able to save your souls.
30289	1147	22	But be ye doers of the word, and not hearers only, deceiving your own selves.
30290	1147	23	For if any be a hearer of the word, and not a doer, he is like unto a man beholding his natural face in a glass:
30291	1147	24	For he beholdeth himself, and goeth his way, and straightway forgetteth what manner of man he was.
30292	1147	25	But whoso looketh into the perfect law of liberty, and continueth therein, he being not a forgetful hearer, but a doer of the work, this man shall be blessed in his deed.
30293	1147	26	If any man among you seem to be religious, and bridleth not his tongue, but deceiveth his own heart, this man's religion is vain.
30294	1147	27	Pure religion and undefiled before God and the Father is this, To visit the fatherless and widows in their affliction, and to keep himself unspotted from the world.
30295	1148	1	MY brethren, have not the faith of our Lord Jesus Christ, the Lord of glory, with respect of persons.
30296	1148	2	For if there come unto your assembly a man with a gold ring, in goodly apparel, and there come in also a poor man in vile raiment;
30297	1148	3	And ye have respect to him that weareth the gay clothing, and say unto him, Sit thou here in a good place; and say to the poor, Stand thou there, or sit here under my footstool:
30298	1148	4	Are ye not then partial in yourselves, and are become judges of evil thoughts?
30299	1148	5	Hearken, my beloved brethren, Hath not God chosen the poor of this world rich in faith, and heirs of the kingdom which he hath promised to them that love him?
30300	1148	6	But ye have despised the poor. Do not rich men oppress you, and draw you before the judgment seats?
30301	1148	7	Do not they blaspheme that worthy name by the which ye are called?
30302	1148	8	If ye fulfil the royal law according to the scripture, Thou shalt love thy neighbour as thyself, ye do well:
30303	1148	9	But if ye have respect to persons, ye commit sin, and are convinced of the law as transgressors.
30304	1148	10	For whosoever shall keep the whole law, and yet offend in one point, he is guilty of all.
30305	1148	11	For he that said, Do not commit adultery, said also, Do not kill. Now if thou commit no adultery, yet if thou kill, thou art become a transgressor of the law.
30306	1148	12	So speak ye, and so do, as they that shall be judged by the law of liberty.
30307	1148	13	For he shall have judgment without mercy, that hath shewed no mercy; and mercy rejoiceth against judgment.
30308	1148	14	What doth it profit, my brethren, though a man say he hath faith, and have not works? can faith save him?
30309	1148	15	If a brother or sister be naked, and destitute of daily food,
30310	1148	16	And one of you say unto them, Depart in peace, be ye warmed and filled; notwithstanding ye give them not those things which are needful to the body; what doth it profit?
30311	1148	17	Even so faith, if it hath not works, is dead, being alone.
30312	1148	18	Yea, a man may say, Thou hast faith, and I have works: shew me thy faith without thy works, and I will shew thee my faith by my works.
30313	1148	19	Thou believest that there is one God; thou doest well: the devils also believe, and tremble.
30314	1148	20	But wilt thou know, O vain man, that faith without works is dead?
30315	1148	21	Was not Abraham our father justified by works, when he had offered Isaac his son upon the altar?
30316	1148	22	Seest thou how faith wrought with his works, and by works was faith made perfect?
30317	1148	23	And the scripture was fulfilled which saith, Abraham believed God, and it was imputed unto him for righteousness: and he was called the Friend of God.
30318	1148	24	Ye see then how that by works a man is justified, and not by faith only.
30319	1148	25	Likewise also was not Rahab the harlot justified by works, when she had received the messengers, and had sent them out another way?
30320	1148	26	For as the body without the spirit is dead, so faith without works is dead also.
30321	1149	1	MY brethren, be not many masters, knowing that we shall receive the greater condemnation.
30322	1149	2	For in many things we offend all. If any man offend not in word, the same is a perfect man, and able also to bridle the whole body.
30323	1149	3	Behold, we put bits in the horses' mouths, that they may obey us; and we turn about their whole body.
30324	1149	4	Behold also the ships, which though they be so great, and are driven of fierce winds, yet are they turned about with a very small helm, whithersoever the governor listeth.
30325	1149	5	Even so the tongue is a little member, and boasteth great things. Behold, how great a matter a little fire kindleth!
30326	1149	6	And the tongue is a fire, a world of iniquity: so is the tongue among our members, that it defileth the whole body, and setteth on fire the course of nature; and it is set on fire of hell.
30327	1149	7	For every kind of beasts, and of birds, and of serpents, and of things in the sea, is tamed, and hath been tamed of mankind:
30328	1149	8	But the tongue can no man tame; it is an unruly evil, full of deadly poison.
30329	1149	9	Therewith bless we God, even the Father; and therewith curse we men, which are made after the similitude of God.
30330	1149	10	Out of the same mouth proceedeth blessing and cursing. My brethren, these things ought not so to be.
30331	1149	11	Doth a fountain send forth at the same place sweet water and bitter?
30332	1149	12	Can the fig tree, my brethren, bear olive berries? either a vine, figs? so can no fountain both yield salt water and fresh.
30333	1149	13	Who is a wise man and endued with knowledge among you? let him shew out of a good conversation his works with meekness of wisdom.
30334	1149	14	But if ye have bitter envying and strife in your hearts, glory not, and lie not against the truth.
30335	1149	15	This wisdom descendeth not from above, but is earthly, sensual, devilish.
30336	1149	16	For where envying and strife is, there is confusion and every evil work.
30337	1149	17	But the wisdom that is from above is first pure, then peaceable, gentle, and easy to be intreated, full of mercy and good fruits, without partiality, and without hypocrisy.
30338	1149	18	And the fruit of righteousness is sown in peace of them that make peace.
30339	1150	1	FROM whence come wars and fightings among you? come they not hence, even of your lusts that war in your members?
30340	1150	2	Ye lust, and have not: ye kill, and desire to have, and cannot obtain: ye fight and war, yet ye have not, because ye ask not.
30341	1150	3	Ye ask, and receive not, because ye ask amiss, that ye may consume it upon your lusts.
30342	1150	4	Ye adulterers and adulteresses, know ye not that the friendship of the world is enmity with God? whosoever therefore will be a friend of the world is the enemy of God.
30343	1150	5	Do ye think that the scripture saith in vain, The spirit that dwelleth in us lusteth to envy?
30344	1150	6	But he giveth more grace. Wherefore he saith, God resisteth the proud, but giveth grace unto the humble.
30345	1150	7	Submit yourselves therefore to God. Resist the devil, and he will flee from you.
30346	1150	8	Draw nigh to God, and he will draw nigh to you. Cleanse your hands, ye sinners; and purify your hearts, ye double minded.
30347	1150	9	Be afflicted, and mourn, and weep: let your laughter be turned to mourning, and your joy to heaviness.
30348	1150	10	Humble yourselves in the sight of the Lord, and he shall lift you up.
30349	1150	11	Speak not evil one of another, brethren. He that speaketh evil of his brother, and judgeth his brother, speaketh evil of the law, and judgeth the law: but if thou judge the law, thou art not a doer of the law, but a judge.
30350	1150	12	There is one lawgiver, who is able to save and to destroy: who art thou that judgest another?
30351	1150	13	Go to now, ye that say, To day or to morrow we will go into such a city, and continue there a year, and buy and sell, and get gain:
30352	1150	14	Whereas ye know not what shall be on the morrow. For what is your life? It is even a vapour, that appeareth for a little time, and then vanisheth away.
30353	1150	15	For that ye ought to say, If the Lord will, we shall live, and do this, or that.
30354	1150	16	But now ye rejoice in your boastings: all such rejoicing is evil.
30355	1150	17	Therefore to him that knoweth to do good, and doeth it not, to him it is sin.
30356	1151	1	GO to now, ye rich men, weep and howl for your miseries that shall come upon you.
30357	1151	2	Your riches are corrupted, and your garments are motheaten.
30358	1151	3	Your gold and silver is cankered; and the rust of them shall be a witness against you, and shall eat your flesh as it were fire. Ye have heaped treasure together for the last days.
30359	1151	4	Behold, the hire of the labourers who have reaped down your fields, which is of you kept back by fraud, crieth: and the cries of them which have reaped are entered into the ears of the Lord of sabaoth.
30360	1151	5	Ye have lived in pleasure on the earth, and been wanton; ye have nourished your hearts, as in a day of slaughter.
30361	1151	6	Ye have condemned and killed the just; and he doth not resist you.
30362	1151	7	Be patient therefore, brethren, unto the coming of the Lord. Behold, the husbandman waiteth for the precious fruit of the earth, and hath long patience for it, until he receive the early and latter rain.
30363	1151	8	Be ye also patient; stablish your hearts: for the coming of the Lord draweth nigh.
30364	1151	9	Grudge not one against another, brethren, lest ye be condemned: behold, the judge standeth before the door.
30365	1151	10	Take, my brethren, the prophets, who have spoken in the name of the Lord, for an example of suffering affliction, and of patience.
30366	1151	11	Behold, we count them happy which endure. Ye have heard of the patience of Job, and have seen the end of the Lord; that the Lord is very pitiful, and of tender mercy.
30367	1151	12	But above all things, my brethren, swear not, neither by heaven, neither by the earth, neither by any other oath: but let your yea be yea; and your nay, nay; lest ye fall into condemnation.
30368	1151	13	Is any among you afflicted? let him pray. Is any merry? let him sing psalms.
30369	1151	14	Is any sick among you? let him call for the elders of the church; and let them pray over him, anointing him with oil in the name of the Lord:
30370	1151	15	And the prayer of faith shall save the sick, and the Lord shall raise him up; and if he have committed sins, they shall be forgiven him.
30371	1151	16	Confess your faults one to another, and pray one for another, that ye may be healed. The effectual fervent prayer of a righteous man availeth much.
30372	1151	17	Elias was a man subject to like passions as we are, and he prayed earnestly that it might not rain: and it rained not on the earth by the space of three years and six months.
30373	1151	18	And he prayed again, and the heaven gave rain, and the earth brought forth her fruit.
30374	1151	19	Brethren, if any of you do err from the truth, and one convert him;
30375	1151	20	Let him know, that he which converteth the sinner from the error of his way shall save a soul from death, and shall hide a multitude of sins.
30376	1152	1	PETER, an apostle of Jesus Christ, to the strangers scattered throughout Pontus, Galatia, Cappadocia, Asia, and Bithynia,
30377	1152	2	Elect according to the foreknowledge of God the Father, through sanctification of the Spirit, unto obedience and sprinkling of the blood of Jesus Christ: Grace unto you, and peace, be multiplied.
30378	1152	3	Blessed be the God and Father of our Lord Jesus Christ, which according to his abundant mercy hath begotten us again unto a lively hope by the resurrection of Jesus Christ from the dead,
30379	1152	4	To an inheritance incorruptible, and undefiled, and that fadeth not away, reserved in heaven for you,
30380	1152	5	Who are kept by the power of God through faith unto salvation ready to be revealed in the last time.
30381	1152	6	Wherein ye greatly rejoice, though now for a season, if need be, ye are in heaviness through manifold temptations:
30382	1152	7	That the trial of your faith, being much more precious than of gold that perisheth, though it be tried with fire, might be found unto praise and honour and glory at the appearing of Jesus Christ:
30383	1152	8	Whom having not seen, ye love; in whom, though now ye see him not, yet believing, ye rejoice with joy unspeakable and full of glory:
30384	1152	9	Receiving the end of your faith, even the salvation of your souls.
30385	1152	10	Of which salvation the prophets have enquired and searched diligently, who prophesied of the grace that should come unto you:
30386	1152	11	Searching what, or what manner of time the Spirit of Christ which was in them did signify, when it testified beforehand the sufferings of Christ, and the glory that should follow.
30387	1152	12	Unto whom it was revealed, that not unto themselves, but unto us they did minister the things, which are now reported unto you by them that have preached the gospel unto you with the Holy Ghost sent down from heaven; which things the angels desire to look into.
30388	1152	13	Wherefore gird up the loins of your mind, be sober, and hope to the end for the grace that is to be brought unto you at the revelation of Jesus Christ;
30389	1152	14	As obedient children, not fashioning yourselves according to the former lusts in your ignorance:
30390	1152	15	But as he which hath called you is holy, so be ye holy in all manner of conversation;
30391	1152	16	Because it is written, Be ye holy; for I am holy.
30392	1152	17	And if ye call on the Father, who without respect of persons judgeth according to every man's work, pass the time of your sojourning here in fear:
30393	1152	18	Forasmuch as ye know that ye were not redeemed with corruptible things, as silver and gold, from your vain conversation received by tradition from your fathers;
30394	1152	19	But with the precious blood of Christ, as of a lamb without blemish and without spot:
30395	1152	20	Who verily was foreordained before the foundation of the world, but was manifest in these last times for you,
30396	1152	21	Who by him do believe in God, that raised him up from the dead, and gave him glory; that your faith and hope might be in God.
30397	1152	22	Seeing ye have purified your souls in obeying the truth through the Spirit unto unfeigned love of the brethren, see that ye love one another with a pure heart fervently:
30398	1152	23	Being born again, not of corruptible seed, but of incorruptible, by the word of God, which liveth and abideth for ever.
30399	1152	24	For all flesh is as grass, and all the glory of man as the flower of grass. The grass withereth, and the flower thereof falleth away:
30400	1152	25	But the word of the Lord endureth for ever. And this is the word which by the gospel is preached unto you.
30401	1153	1	WHEREFORE laying aside all malice, and all guile, and hypocrisies, and envies, and all evil speakings,
30402	1153	2	As newborn babes, desire the sincere milk of the word, that ye may grow thereby:
30403	1153	3	If so be ye have tasted that the Lord is gracious.
30404	1153	4	To whom coming, as unto a living stone, disallowed indeed of men, but chosen of God, and precious,
30405	1153	5	Ye also, as lively stones, are built up a spiritual house, an holy priesthood, to offer up spiritual sacrifices, acceptable to God by Jesus Christ.
30406	1153	6	Wherefore also it is contained in the scripture, Behold, I lay in Sion a chief corner stone, elect, precious: and he that believeth on him shall not be confounded.
30407	1153	7	Unto you therefore which believe he is precious: but unto them which be disobedient, the stone which the builders disallowed, the same is made the head of the corner,
30408	1153	8	And a stone of stumbling, and a rock of offence, even to them which stumble at the word, being disobedient: whereunto also they were appointed.
30409	1153	9	But ye are a chosen generation, a royal priesthood, an holy nation, a peculiar people; that ye should shew forth the praises of him who hath called you out of darkness into his marvellous light:
30410	1153	10	Which in time past were not a people, but are now the people of God: which had not obtained mercy, but now have obtained mercy.
30411	1153	11	Dearly beloved, I beseech you as strangers and pilgrims, abstain from fleshly lusts, which war against the soul;
30412	1153	12	Having your conversation honest among the Gentiles: that, whereas they speak against you as evildoers, they may by your good works, which they shall behold, glorify God in the day of visitation.
30413	1153	13	Submit yourselves to every ordinance of man for the Lord's sake: whether it be to the king, as supreme;
30414	1153	14	Or unto governors, as unto them that are sent by him for the punishment of evildoers, and for the praise of them that do well.
30415	1153	15	For so is the will of God, that with well doing ye may put to silence the ignorance of foolish men:
30416	1153	16	As free, and not using your liberty for a cloke of maliciousness, but as the servants of God.
30417	1153	17	Honour all men. Love the brotherhood. Fear God. Honour the king.
30418	1153	18	Servants, be subject to your masters with all fear; not only to the good and gentle, but also to the froward.
30419	1153	19	For this is thankworthy, if a man for conscience toward God endure grief, suffering wrongfully.
30420	1153	20	For what glory is it, if, when ye be buffeted for your faults, ye shall take it patiently? but if, when ye do well, and suffer for it, ye take it patiently, this is acceptable with God.
30421	1153	21	For even hereunto were ye called: because Christ also suffered for us, leaving us an example, that ye should follow his steps:
30422	1153	22	Who did no sin, neither was guile found in his mouth:
30423	1153	23	Who, when he was reviled, reviled not again; when he suffered, he threatened not; but committed himself to him that judgeth righteously:
30424	1153	24	Who his own self bare our sins in his own body on the tree, that we, being dead to sins, should live unto righteousness: by whose stripes ye were healed.
30425	1153	25	For ye were as sheep going astray; but are now returned unto the Shepherd and Bishop of your souls.
30426	1154	1	LIKEWISE, ye wives, be in subjection to your own husbands; that, if any obey not the word, they also may without the word be won by the conversation of the wives;
30427	1154	2	While they behold your chaste conversation coupled with fear.
30428	1154	3	Whose adorning let it not be that outward adorning of plaiting the hair, and of wearing of gold, or of putting on of apparel;
30429	1154	4	But let it be the hidden man of the heart, in that which is not corruptible, even the ornament of a meek and quiet spirit, which is in the sight of God of great price.
30430	1154	5	For after this manner in the old time the holy women also, who trusted in God, adorned themselves, being in subjection unto their own husbands:
30431	1154	6	Even as Sara obeyed Abraham, calling him lord: whose daughters ye are, as long as ye do well, and are not afraid with any amazement.
30432	1154	7	Likewise, ye husbands, dwell with them according to knowledge, giving honour unto the wife, as unto the weaker vessel, and as being heirs together of the grace of life; that your prayers be not hindered.
30433	1154	8	Finally, be ye all of one mind, having compassion one of another, love as brethren, be pitiful, be courteous:
30434	1154	9	Not rendering evil for evil, or railing for railing: but contrariwise blessing; knowing that ye are thereunto called, that ye should inherit a blessing.
30435	1154	10	For he that will love life, and see good days, let him refrain his tongue from evil, and his lips that they speak no guile:
30436	1154	11	Let him eschew evil, and do good; let him seek peace, and ensue it.
30437	1154	12	For the eyes of the Lord are over the righteous, and his ears are open unto their prayers: but the face of the Lord is against them that do evil.
30438	1154	13	And who is he that will harm you, if ye be followers of that which is good?
30439	1154	14	But and if ye suffer for righteousness' sake, happy are ye: and be not afraid of their terror, neither be troubled;
30440	1154	15	But sanctify the Lord God in your hearts: and be ready always to give an answer to every man that asketh you a reason of the hope that is in you with meekness and fear:
30441	1154	16	Having a good conscience; that, whereas they speak evil of you, as of evildoers, they may be ashamed that falsely accuse your good conversation in Christ.
30442	1154	17	For it is better, if the will of God be so, that ye suffer for well doing, than for evil doing.
30443	1154	18	For Christ also hath once suffered for sins, the just for the unjust, that he might bring us to God, being put to death in the flesh, but quickened by the Spirit:
30444	1154	19	By which also he went and preached unto the spirits in prison;
30445	1154	20	Which sometime were disobedient, when once the longsuffering of God waited in the days of Noah, while the ark was a preparing, wherein few, that is, eight souls were saved by water.
30446	1154	21	The like figure whereunto even baptism doth also now save us (not the putting away of the filth of the flesh, but the answer of a good conscience toward God,) by the resurrection of Jesus Christ:
30447	1154	22	Who is gone into heaven, and is on the right hand of God; angels and authorities and powers being made subject unto him.
30448	1155	1	FORASMUCH then as Christ hath suffered for us in the flesh, arm yourselves likewise with the same mind: for he that hath suffered in the flesh hath ceased from sin;
30449	1155	2	That he no longer should live the rest of his time in the flesh to the lusts of men, but to the will of God.
30450	1155	3	For the time past of our life may suffice us to have wrought the will of the Gentiles, when we walked in lasciviousness, lusts, excess of wine, revellings, banquetings, and abominable idolatries:
30451	1155	4	Wherein they think it strange that ye run not with them to the same excess of riot, speaking evil of you:
30452	1155	5	Who shall give account to him that is ready to judge the quick and the dead.
30453	1155	6	For for this cause was the gospel preached also to them that are dead, that they might be judged according to men in the flesh, but live according to God in the spirit.
30454	1155	7	But the end of all things is at hand: be ye therefore sober, and watch unto prayer.
30455	1155	8	And above all things have fervent charity among yourselves: for charity shall cover the multitude of sins.
30456	1155	9	Use hospitality one to another without grudging.
30457	1155	10	As every man hath received the gift, even so minister the same one to another, as good stewards of the manifold grace of God.
30458	1155	11	If any man speak, let him speak as the oracles of God; if any man minister, let him do it as of the ability which God giveth: that God in all things may be glorified through Jesus Christ, to whom be praise and dominion for ever and ever. Amen.
30459	1155	12	Beloved, think it not strange concerning the fiery trial which is to try you, as though some strange thing happened unto you:
30460	1155	13	But rejoice, inasmuch as ye are partakers of Christ's sufferings; that, when his glory shall be revealed, ye may be glad also with exceeding joy.
30461	1155	14	If ye be reproached for the name of Christ, happy are ye; for the spirit of glory and of God resteth upon you: on their part he is evil spoken of, but on your part he is glorified.
30462	1155	15	But let none of you suffer as a murderer, or as a thief, or as an evildoer, or as a busybody in other men's matters.
30463	1155	16	Yet if any man suffer as a Christian, let him not be ashamed; but let him glorify God on this behalf.
30464	1155	17	For the time is come that judgment must begin at the house of God: and if it first begin at us, what shall the end be of them that obey not the gospel of God?
30465	1155	18	And if the righteous scarcely be saved, where shall the ungodly and the sinner appear?
30466	1155	19	Wherefore let them that suffer according to the will of God commit the keeping of their souls to him in well doing, as unto a faithful Creator.
30467	1156	1	THE elders which are among you I exhort, who am also an elder, and a witness of the sufferings of Christ, and also a partaker of the glory that shall be revealed:
30468	1156	2	Feed the flock of God which is among you, taking the oversight thereof, not by constraint, but willingly; not for filthy lucre, but of a ready mind;
30469	1156	3	Neither as being lords over God's heritage, but being ensamples to the flock.
30470	1156	4	And when the chief Shepherd shall appear, ye shall receive a crown of glory that fadeth not away.
30471	1156	5	Likewise, ye younger, submit yourselves unto the elder. Yea, all of you be subject one to another, and be clothed with humility: for God resisteth the proud, and giveth grace to the humble.
30472	1156	6	Humble yourselves therefore under the mighty hand of God, that he may exalt you in due time:
30473	1156	7	Casting all your care upon him; for he careth for you.
30474	1156	8	Be sober, be vigilant; because your adversary the devil, as a roaring lion, walketh about, seeking whom he may devour:
30475	1156	9	Whom resist stedfast in the faith, knowing that the same afflictions are accomplished in your brethren that are in the world.
30476	1156	10	But the God of all grace, who hath called us unto his eternal glory by Christ Jesus, after that ye have suffered a while, make you perfect, stablish, strengthen, settle you.
30477	1156	11	To him be glory and dominion for ever and ever. Amen.
30478	1156	12	By Silvanus, a faithful brother unto you, as I suppose, I have written briefly, exhorting, and testifying that this is the true grace of God wherein ye stand.
30479	1156	13	The church that is at Babylon, elected together with you, saluteth you; and so doth Marcus my son.
30480	1156	14	Greet ye one another with a kiss of charity. Peace be with you all that are in Christ Jesus. Amen.
30481	1157	1	SIMON Peter, a servant and an apostle of Jesus Christ, to them that have obtained like precious faith with us through the righteousness of God and our Saviour Jesus Christ:
30482	1157	2	Grace and peace be multiplied unto you through the knowledge of God, and of Jesus our Lord,
30483	1157	3	According as his divine power hath given unto us all things that pertain unto life and godliness, through the knowledge of him that hath called us to glory and virtue:
30484	1157	4	Whereby are given unto us exceeding great and precious promises: that by these ye might be partakers of the divine nature, having escaped the corruption that is in the world through lust.
30485	1157	5	And beside this, giving all diligence, add to your faith virtue; and to virtue knowledge;
30486	1157	6	And to knowledge temperance; and to temperance patience; and to patience godliness;
30487	1157	7	And to godliness brotherly kindness; and to brotherly kindness charity.
30488	1157	8	For if these things be in you, and abound, they make you that ye shall neither be barren nor unfruitful in the knowledge of our Lord Jesus Christ.
30489	1157	9	But he that lacketh these things is blind, and cannot see afar off, and hath forgotten that he was purged from his old sins.
30490	1157	10	Wherefore the rather, brethren, give diligence to make your calling and election sure: for if ye do these things, ye shall never fall:
30491	1157	11	For so an entrance shall be ministered unto you abundantly into the everlasting kingdom of our Lord and Saviour Jesus Christ.
30492	1157	12	Wherefore I will not be negligent to put you always in remembrance of these things, though ye know them, and be established in the present truth.
30493	1157	13	Yea, I think it meet, as long as I am in this tabernacle, to stir you up by putting you in remembrance;
30494	1157	14	Knowing that shortly I must put off this my tabernacle, even as our Lord Jesus Christ hath shewed me.
30495	1157	15	Moreover I will endeavour that ye may be able after my decease to have these things always in remembrance.
30496	1157	16	For we have not followed cunningly devised fables, when we made known unto you the power and coming of our Lord Jesus Christ, but were eyewitnesses of his majesty.
30497	1157	17	For he received from God the Father honour and glory, when there came such a voice to him from the excellent glory, This is my beloved Son, in whom I am well pleased.
30498	1157	18	And this voice which came from heaven we heard, when we were with him in the holy mount.
30499	1157	19	We have also a more sure word of prophecy; whereunto ye do well that ye take heed, as unto a light that shineth in a dark place, until the day dawn, and the day star arise in your hearts:
30500	1157	20	Knowing this first, that no prophecy of the scripture is of any private interpretation.
30501	1157	21	For the prophecy came not in old time by the will of man: but holy men of God spake as they were moved by the Holy Ghost.
30502	1158	1	BUT there were false prophets also among the people, even as there shall be false teachers among you, who privily shall bring in damnable heresies, even denying the Lord that bought them, and bring upon themselves swift destruction.
30503	1158	2	And many shall follow their pernicious ways; by reason of whom the way of truth shall be evil spoken of.
30504	1158	3	And through covetousness shall they with feigned words make merchandise of you: whose judgment now of a long time lingereth not, and their damnation slumbereth not.
30505	1158	4	For if God spared not the angels that sinned, but cast them down to hell, and delivered them into chains of darkness, to be reserved unto judgment;
30506	1158	5	And spared not the old world, but saved Noah the eighth person, a preacher of righteousness, bringing in the flood upon the world of the ungodly;
30507	1158	6	And turning the cities of Sodom and Gomorrha into ashes condemned them with an overthrow, making them an ensample unto those that after should live ungodly;
30508	1158	7	And delivered just Lot, vexed with the filthy conversation of the wicked:
30509	1158	8	(For that righteous man dwelling among them, in seeing and hearing, vexed his righteous soul from day to day with their unlawful deeds;)
30510	1158	9	The Lord knoweth how to deliver the godly out of temptations, and to reserve the unjust unto the day of judgment to be punished:
30511	1158	10	But chiefly them that walk after the flesh in the lust of uncleanness, and despise government. Presumptuous are they, selfwilled, they are not afraid to speak evil of dignities.
30512	1158	11	Whereas angels, which are greater in power and might, bring not railing accusation against them before the Lord.
30513	1158	12	But these, as natural brute beasts, made to be taken and destroyed, speak evil of the things that they understand not; and shall utterly perish in their own corruption;
30514	1158	13	And shall receive the reward of unrighteousness, as they that count it pleasure to riot in the day time. Spots they are and blemishes, sporting themselves with their own deceivings while they feast with you;
30515	1158	14	Having eyes full of adultery, and that cannot cease from sin; beguiling unstable souls: an heart they have exercised with covetous practices; cursed children:
30516	1158	15	Which have forsaken the right way, and are gone astray, following the way of Balaam the son of Bosor, who loved the wages of unrighteousness;
30517	1158	16	But was rebuked for his iniquity: the dumb ass speaking with man's voice forbad the madness of the prophet.
30518	1158	17	These are wells without water, clouds that are carried with a tempest; to whom the mist of darkness is reserved for ever.
30519	1158	18	For when they speak great swelling words of vanity, they allure through the lusts of the flesh, through much wantonness, those that were clean escaped from them who live in error.
30520	1158	19	While they promise them liberty, they themselves are the servants of corruption: for of whom a man is overcome, of the same is he brought in bondage.
30521	1158	20	For if after they have escaped the pollutions of the world through the knowledge of the Lord and Saviour Jesus Christ, they are again entangled therein, and overcome, the latter end is worse with them than the beginning.
30522	1158	21	For it had been better for them not to have known the way of righteousness, than, after they have known it, to turn from the holy commandment delivered unto them.
30523	1158	22	But it is happened unto them according to the true proverb, The dog is turned to his own vomit again; and the sow that was washed to her wallowing in the mire.
30524	1159	1	THIS second epistle, beloved, I now write unto you; in both which I stir up your pure minds by way of remembrance:
30525	1159	2	That ye may be mindful of the words which were spoken before by the holy prophets, and of the commandment of us the apostles of the Lord and Saviour:
30526	1159	3	Knowing this first, that there shall come in the last days scoffers, walking after their own lusts,
30527	1159	4	And saying, Where is the promise of his coming? for since the fathers fell asleep, all things continue as they were from the beginning of the creation.
30528	1159	5	For this they willingly are ignorant of, that by the word of God the heavens were of old, and the earth standing out of the water and in the water:
30529	1159	6	Whereby the world that then was, being overflowed with water, perished:
30530	1159	7	But the heavens and the earth, which are now, by the same word are kept in store, reserved unto fire against the day of judgment and perdition of ungodly men.
30531	1159	8	But, beloved, be not ignorant of this one thing, that one day is with the Lord as a thousand years, and a thousand years as one day.
30532	1159	9	The Lord is not slack concerning his promise, as some men count slackness; but is longsuffering to us-ward, not willing that any should perish, but that all should come to repentance.
30533	1159	10	But the day of the Lord will come as a thief in the night; in the which the heavens shall pass away with a great noise, and the elements shall melt with fervent heat, the earth also and the works that are therein shall be burned up.
30534	1159	11	Seeing then that all these things shall be dissolved, what manner of persons ought ye to be in all holy conversation and godliness,
30535	1159	12	Looking for and hasting unto the coming of the day of God, wherein the heavens being on fire shall be dissolved, and the elements shall melt with fervent heat?
30536	1159	13	Nevertheless we, according to his promise, look for new heavens and a new earth, wherein dwelleth righteousness.
30537	1159	14	Wherefore, beloved, seeing that ye look for such things, be diligent that ye may be found of him in peace, without spot, and blameless.
30538	1159	15	And account that the longsuffering of our Lord is salvation; even as our beloved brother Paul also according to the wisdom given unto him hath written unto you;
30539	1159	16	As also in all his epistles, speaking in them of these things; in which are some things hard to be understood, which they that are unlearned and unstable wrest, as they do also the other scriptures, unto their own destruction.
30540	1159	17	Ye therefore, beloved, seeing ye know these things before, beware lest ye also, being led away with the error of the wicked, fall from your own stedfastness.
30541	1159	18	But grow in grace, and in the knowledge of our Lord and Saviour Jesus Christ. To him be glory both now and for ever. Amen.
30542	1160	1	THAT which was from the beginning, which we have heard, which we have seen with our eyes, which we have looked upon, and our hands have handled, of the Word of life;
30543	1160	2	(For the life was manifested, and we have seen it, and bear witness, and shew unto you that eternal life, which was with the Father, and was manifested unto us;)
30544	1160	3	That which we have seen and heard declare we unto you, that ye also may have fellowship with us: and truly our fellowship is with the Father, and with his Son Jesus Christ.
30545	1160	4	And these things write we unto you, that your joy may be full.
30546	1160	5	This then is the message which we have heard of him, and declare unto you, that God is light, and in him is no darkness at all.
30547	1160	6	If we say that we have fellowship with him, and walk in darkness, we lie, and do not the truth:
30548	1160	7	But if we walk in the light, as he is in the light, we have fellowship one with another, and the blood of Jesus Christ his Son cleanseth us from all sin.
30549	1160	8	If we say that we have no sin, we deceive ourselves, and the truth is not in us.
30550	1160	9	If we confess our sins, he is faithful and just to forgive us our sins, and to cleanse us from all unrighteousness.
30551	1160	10	If we say that we have not sinned, we make him a liar, and his word is not in us.
30552	1161	1	MY little children, these things write I unto you, that ye sin not. And if any man sin, we have an advocate with the Father, Jesus Christ the righteous:
30553	1161	2	And he is the propitiation for our sins: and not for ours only, but also for the sins of the whole world.
30554	1161	3	And hereby we do know that we know him, if we keep his commandments.
30555	1161	4	He that saith, I know him, and keepeth not his commandments, is a liar, and the truth is not in him.
30556	1161	5	But whoso keepeth his word, in him verily is the love of God perfected: hereby know we that we are in him.
30557	1161	6	He that saith he abideth in him ought himself also so to walk, even as he walked.
30558	1161	7	Brethren, I write no new commandment unto you, but an old commandment which ye had from the beginning. The old commandment is the word which ye have heard from the beginning.
30559	1161	8	Again, a new commandment I write unto you, which thing is true in him and in you: because the darkness is past, and the true light now shineth.
30560	1161	9	He that saith he is in the light, and hateth his brother, is in darkness even until now.
30561	1161	10	He that loveth his brother abideth in the light, and there is none occasion of stumbling in him.
30562	1161	11	But he that hateth his brother is in darkness, and walketh in darkness, and knoweth not whither he goeth, because that darkness hath blinded his eyes.
30563	1161	12	I write unto you, little children, because your sins are forgiven you for his name's sake.
30564	1161	13	I write unto you, fathers, because ye have known him that is from the beginning. I write unto you, young men, because ye have overcome the wicked one. I write unto you, little children, because ye have known the Father.
30565	1161	14	I have written unto you, fathers, because ye have known him that is from the beginning. I have written unto you, young men, because ye are strong, and the word of God abideth in you, and ye have overcome the wicked one.
30566	1161	15	Love not the world, neither the things that are in the world. If any man love the world, the love of the Father is not in him.
30567	1161	16	For all that is in the world, the lust of the flesh, and the lust of the eyes, and the pride of life, is not of the Father, but is of the world.
30568	1161	17	And the world passeth away, and the lust thereof: but he that doeth the will of God abideth for ever.
30569	1161	18	Little children, it is the last time: and as ye have heard that antichrist shall come, even now are there many antichrists; whereby we know that it is the last time.
30570	1161	19	They went out from us, but they were not of us; for if they had been of us, they would no doubt have continued with us: but they went out, that they might be made manifest that they were not all of us.
30571	1161	20	But ye have an unction from the Holy One, and ye know all things.
30572	1161	21	I have not written unto you because ye know not the truth, but because ye know it, and that no lie is of the truth.
30573	1161	22	Who is a liar but he that denieth that Jesus is the Christ? He is antichrist, that denieth the Father and the Son.
30574	1161	23	Whosoever denieth the Son, the same hath not the Father: [but] he that acknowledgeth the Son hath the Father also.
30575	1161	24	Let that therefore abide in you, which ye have heard from the beginning. If that which ye have heard from the beginning shall remain in you, ye also shall continue in the Son, and in the Father.
30576	1161	25	And this is the promise that he hath promised us, even eternal life.
30577	1161	26	These things have I written unto you concerning them that seduce you.
30578	1161	27	But the anointing which ye have received of him abideth in you, and ye need not that any man teach you: but as the same anointing teacheth you of all things, and is truth, and is no lie, and even as it hath taught you, ye shall abide in him.
30579	1161	28	And now, little children, abide in him; that, when he shall appear, we may have confidence, and not be ashamed before him at his coming.
30580	1161	29	If ye know that he is righteous, ye know that every one that doeth righteousness is born of him.
30581	1162	1	BEHOLD, what manner of love the Father hath bestowed upon us, that we should be called the sons of God: therefore the world knoweth us not, because it knew him not.
30582	1162	2	Beloved, now are we the sons of God, and it doth not yet appear what we shall be: but we know that, when he shall appear, we shall be like him; for we shall see him as he is.
30583	1162	3	And every man that hath this hope in him purifieth himself, even as he is pure.
30584	1162	4	Whosoever committeth sin transgresseth also the law: for sin is the transgression of the law.
30585	1162	5	And ye know that he was manifested to take away our sins; and in him is no sin.
30586	1162	6	Whosoever abideth in him sinneth not: whosoever sinneth hath not seen him, neither known him.
30587	1162	7	Little children, let no man deceive you: he that doeth righteousness is righteous, even as he is righteous.
30588	1162	8	He that committeth sin is of the devil; for the devil sinneth from the beginning. For this purpose the Son of God was manifested, that he might destroy the works of the devil.
30589	1162	9	Whosoever is born of God doth not commit sin; for his seed remaineth in him: and he cannot sin, because he is born of God.
30590	1162	10	In this the children of God are manifest, and the children of the devil: whosoever doeth not righteousness is not of God, neither he that loveth not his brother.
30591	1162	11	For this is the message that ye heard from the beginning, that we should love one another.
30592	1162	12	Not as Cain, who was of that wicked one, and slew his brother. And wherefore slew he him? Because his own works were evil, and his brother's righteous.
30593	1162	13	Marvel not, my brethren, if the world hate you.
30594	1162	14	We know that we have passed from death unto life, because we love the brethren. He that loveth not his brother abideth in death.
30595	1162	15	Whosoever hateth his brother is a murderer: and ye know that no murderer hath eternal life abiding in him.
30596	1162	16	Hereby perceive we the love of God, because he laid down his life for us: and we ought to lay down our lives for the brethren.
30597	1162	17	But whoso hath this world's good, and seeth his brother have need, and shutteth up his bowels of compassion from him, how dwelleth the love of God in him?
30598	1162	18	My little children, let us not love in word, neither in tongue; but in deed and in truth.
30599	1162	19	And hereby we know that we are of the truth, and shall assure our hearts before him.
30600	1162	20	For if our heart condemn us, God is greater than our heart, and knoweth all things.
30601	1162	21	Beloved, if our heart condemn us not, then have we confidence toward God.
30602	1162	22	And whatsoever we ask, we receive of him, because we keep his commandments, and do those things that are pleasing in his sight.
30603	1162	23	And this is his commandment, That we should believe on the name of his Son Jesus Christ, and love one another, as he gave us commandment.
30604	1162	24	And he that keepeth his commandments dwelleth in him, and he in him. And hereby we know that he abideth in us, by the Spirit which he hath given us.
30605	1163	1	BELOVED, believe not every spirit, but try the spirits whether they are of God: because many false prophets are gone out into the world.
30606	1163	2	Hereby know ye the Spirit of God: Every spirit that confesseth that Jesus Christ is come in the flesh is of God:
30607	1163	3	And every spirit that confesseth not that Jesus Christ is come in the flesh is not of God: and this is that spirit of antichrist, whereof ye have heard that it should come; and even now already is it in the world.
30608	1163	4	Ye are of God, little children, and have overcome them: because greater is he that is in you, than he that is in the world.
30609	1163	5	They are of the world: therefore speak they of the world, and the world heareth them.
30610	1163	6	We are of God: he that knoweth God heareth us; he that is not of God heareth not us. Hereby know we the spirit of truth, and the spirit of error.
30611	1163	7	Beloved, let us love one another: for love is of God; and every one that loveth is born of God, and knoweth God.
30612	1163	8	He that loveth not knoweth not God; for God is love.
30613	1163	9	In this was manifested the love of God toward us, because that God sent his only begotten Son into the world, that we might live through him.
30614	1163	10	Herein is love, not that we loved God, but that he loved us, and sent his Son to be the propitiation for our sins.
30615	1163	11	Beloved, if God so loved us, we ought also to love one another.
30616	1163	12	No man hath seen God at any time. If we love one another, God dwelleth in us, and his love is perfected in us.
30617	1163	13	Hereby know we that we dwell in him, and he in us, because he hath given us of his Spirit.
30618	1163	14	And we have seen and do testify that the Father sent the Son to be the Saviour of the world.
30619	1163	15	Whosoever shall confess that Jesus is the Son of God, God dwelleth in him, and he in God.
30620	1163	16	And we have known and believed the love that God hath to us. God is love; and he that dwelleth in love dwelleth in God, and God in him.
30621	1163	17	Herein is our love made perfect, that we may have boldness in the day of judgment: because as he is, so are we in this world.
30622	1163	18	There is no fear in love; but perfect love casteth out fear: because fear hath torment. He that feareth is not made perfect in love.
30623	1163	19	We love him, because he first loved us.
30624	1163	20	If a man say, I love God, and hateth his brother, he is a liar: for he that loveth not his brother whom he hath seen, how can he love God whom he hath not seen?
30625	1163	21	And this commandment have we from him, That he who loveth God love his brother also.
30626	1164	1	WHOSOEVER believeth that Jesus is the Christ is born of God: and every one that loveth him that begat loveth him also that is begotten of him.
30627	1164	2	By this we know that we love the children of God, when we love God, and keep his commandments.
30628	1164	3	For this is the love of God, that we keep his commandments: and his commandments are not grievous.
30629	1164	4	For whatsoever is born of God overcometh the world: and this is the victory that overcometh the world, even our faith.
30630	1164	5	Who is he that overcometh the world, but he that believeth that Jesus is the Son of God?
30631	1164	6	This is he that came by water and blood, even Jesus Christ; not by water only, but by water and blood. And it is the Spirit that beareth witness, because the Spirit is truth.
30632	1164	7	For there are three that bear record in heaven, the Father, the Word, and the Holy Ghost: and these three are one.
30633	1164	8	And there are three that bear witness in earth, the Spirit, and the water, and the blood: and these three agree in one.
30634	1164	9	If we receive the witness of men, the witness of God is greater: for this is the witness of God which he hath testified of his Son.
30635	1164	10	He that believeth on the Son of God hath the witness in himself: he that believeth not God hath made him a liar; because he believeth not the record that God gave of his Son.
30636	1164	11	And this is the record, that God hath given to us eternal life, and this life is in his Son.
30637	1164	12	He that hath the Son hath life; and he that hath not the Son of God hath not life.
30638	1164	13	These things have I written unto you that believe on the name of the Son of God; that ye may know that ye have eternal life, and that ye may believe on the name of the Son of God.
30639	1164	14	And this is the confidence that we have in him, that, if we ask any thing according to his will, he heareth us:
30640	1164	15	And if we know that he hear us, whatsoever we ask, we know that we have the petitions that we desired of him.
30641	1164	16	If any man see his brother sin a sin which is not unto death, he shall ask, and he shall give him life for them that sin not unto death. There is a sin unto death: I do not say that he shall pray for it.
30642	1164	17	All unrighteousness is sin: and there is a sin not unto death.
30643	1164	18	We know that whosoever is born of God sinneth not; but he that is begotten of God keepeth himself, and that wicked one toucheth him not.
30644	1164	19	And we know that we are of God, and the whole world lieth in wickedness.
30645	1164	20	And we know that the Son of God is come, and hath given us an understanding, that we may know him that is true, and we are in him that is true, even in his Son Jesus Christ. This is the true God, and eternal life.
30646	1164	21	Little children, keep yourselves from idols. Amen.
30647	1165	1	THE elder unto the elect lady and her children, whom I love in the truth; and not I only, but also all they that have known the truth;
30648	1165	2	For the truth's sake, which dwelleth in us, and shall be with us for ever.
30649	1165	3	Grace be with you, mercy, and peace, from God the Father, and from the Lord Jesus Christ, the Son of the Father, in truth and love.
30650	1165	4	I rejoiced greatly that I found of thy children walking in truth, as we have received a commandment from the Father.
30651	1165	5	And now I beseech thee, lady, not as though I wrote a new commandment unto thee, but that which we had from the beginning, that we love one another.
30652	1165	6	And this is love, that we walk after his commandments. This is the commandment, That, as ye have heard from the beginning, ye should walk in it.
30653	1165	7	For many deceivers are entered into the world, who confess not that Jesus Christ is come in the flesh. This is a deceiver and an antichrist.
30654	1165	8	Look to yourselves, that we lose not those things which we have wrought, but that we receive a full reward.
30655	1165	9	Whosoever transgresseth, and abideth not in the doctrine of Christ, hath not God. He that abideth in the doctrine of Christ, he hath both the Father and the Son.
30656	1165	10	If there come any unto you, and bring not this doctrine, receive him not into your house, neither bid him God speed:
30657	1165	11	For he that biddeth him God speed is partaker of his evil deeds.
30658	1165	12	Having many things to write unto you, I would not write with paper and ink: but I trust to come unto you, and speak face to face, that our joy may be full.
30659	1165	13	The children of thy elect sister greet thee. Amen.
30660	1166	1	THE elder unto the wellbeloved Gaius, whom I love in the truth.
30661	1166	2	Beloved, I wish above all things that thou mayest prosper and be in health, even as thy soul prospereth.
30662	1166	3	For I rejoiced greatly, when the brethren came and testified of the truth that is in thee, even as thou walkest in the truth.
30663	1166	4	I have no greater joy than to hear that my children walk in truth.
30664	1166	5	Beloved, thou doest faithfully whatsoever thou doest to the brethren, and to strangers;
30665	1166	6	Which have borne witness of thy charity before the church: whom if thou bring forward on their journey after a godly sort, thou shalt do well:
30666	1166	7	Because that for his name's sake they went forth, taking nothing of the Gentiles.
30667	1166	8	We therefore ought to receive such, that we might be fellowhelpers to the truth.
30668	1166	9	I wrote unto the church: but Diotrephes, who loveth to have the preeminence among them, receiveth us not.
30669	1166	10	Wherefore, if I come, I will remember his deeds which he doeth, prating against us with malicious words: and not content therewith, neither doth he himself receive the brethren, and forbiddeth them that would, and casteth them out of the church.
30670	1166	11	Beloved, follow not that which is evil, but that which is good. He that doeth good is of God: but he that doeth evil hath not seen God.
30671	1166	12	Demetrius hath good report of all men, and of the truth itself: yea, and we also bear record; and ye know that our record is true.
30672	1166	13	I had many things to write, but I will not with ink and pen write unto thee:
30673	1166	14	But I trust I shall shortly see thee, and we shall speak face to face. Peace be to thee. Our friends salute thee. Greet the friends by name.
30674	1167	1	JUDE, the servant of Jesus Christ, and brother of James, to them that are sanctified by God the Father, and preserved in Jesus Christ, and called:
30675	1167	2	Mercy unto you, and peace, and love, be multiplied.
30676	1167	3	Beloved, when I gave all diligence to write unto you of the common salvation, it was needful for me to write unto you, and exhort you that ye should earnestly contend for the faith which was once delivered unto the saints.
30677	1167	4	For there are certain men crept in unawares, who were before of old ordained to this condemnation, ungodly men, turning the grace of our God into lasciviousness, and denying the only Lord God, and our Lord Jesus Christ.
30678	1167	5	I will therefore put you in remembrance, though ye once knew this, how that the Lord, having saved the people out of the land of Egypt, afterward destroyed them that believed not.
30679	1167	6	And the angels which kept not their first estate, but left their own habitation, he hath reserved in everlasting chains under darkness unto the judgment of the great day.
30680	1167	7	Even as Sodom and Gomorrha, and the cities about them in like manner, giving themselves over to fornication, and going after strange flesh, are set forth for an example, suffering the vengeance of eternal fire.
30681	1167	8	Likewise also these filthy dreamers defile the flesh, despise dominion, and speak evil of dignities.
30682	1167	9	Yet Michael the archangel, when contending with the devil he disputed about the body of Moses, durst not bring against him a railing accusation, but said, The Lord rebuke thee.
30683	1167	10	But these speak evil of those things which they know not: but what they know naturally, as brute beasts, in those things they corrupt themselves.
30684	1167	11	Woe unto them! for they have gone in the way of Cain, and ran greedily after the error of Balaam for reward, and perished in the gainsaying of Core.
30685	1167	12	These are spots in your feasts of charity, when they feast with you, feeding themselves without fear: clouds they are without water, carried about of winds; trees whose fruit withereth, without fruit, twice dead, plucked up by the roots;
30686	1167	13	Raging waves of the sea, foaming out their own shame; wandering stars, to whom is reserved the blackness of darkness for ever.
30687	1167	14	And Enoch also, the seventh from Adam, prophesied of these, saying, Behold, the Lord cometh with ten thousands of his saints,
30688	1167	15	To execute judgment upon all, and to convince all that are ungodly among them of all their ungodly deeds which they have ungodly committed, and of all their hard speeches which ungodly sinners have spoken against him.
30689	1167	16	These are murmurers, complainers, walking after their own lusts; and their mouth speaketh great swelling words, having men's persons in admiration because of advantage.
30690	1167	17	But, beloved, remember ye the words which were spoken before of the apostles of our Lord Jesus Christ;
30691	1167	18	How that they told you there should be mockers in the last time, who should walk after their own ungodly lusts.
30692	1167	19	These be they who separate themselves, sensual, having not the Spirit.
30693	1167	20	But ye, beloved, building up yourselves on your most holy faith, praying in the Holy Ghost,
30694	1167	21	Keep yourselves in the love of God, looking for the mercy of our Lord Jesus Christ unto eternal life.
30695	1167	22	And of some have compassion, making a difference:
30696	1167	23	And others save with fear, pulling them out of the fire; hating even the garment spotted by the flesh.
30697	1167	24	Now unto him that is able to keep you from falling, and to present you faultless before the presence of his glory with exceeding joy,
30698	1167	25	To the only wise God our Saviour, be glory and majesty, dominion and power, both now and ever. Amen.
30699	1168	1	THE Revelation of Jesus Christ, which God gave unto him, to shew unto his servants things which must shortly come to pass; and he sent and signified it by his angel unto his servant John:
30700	1168	2	Who bare record of the word of God, and of the testimony of Jesus Christ, and of all things that he saw.
30701	1168	3	Blessed is he that readeth, and they that hear the words of this prophecy, and keep those things which are written therein: for the time is at hand.
30702	1168	4	JOHN to the seven churches which are in Asia: Grace be unto you, and peace, from him which is, and which was, and which is to come; and from the seven Spirits which are before his throne;
30703	1168	5	And from Jesus Christ, who is the faithful witness, and the first begotten of the dead, and the prince of the kings of the earth. Unto him that loved us, and washed us from our sins in his own blood,
30704	1168	6	And hath made us kings and priests unto God and his Father; to him be glory and dominion for ever and ever. Amen.
30705	1168	7	Behold, he cometh with clouds; and every eye shall see him, and they also which pierced him: and all kindreds of the earth shall wail because of him. Even so, Amen.
30706	1168	8	I am Alpha and Omega, the beginning and the ending, saith the Lord, which is, and which was, and which is to come, the Almighty.
30707	1168	9	I John, who also am your brother, and companion in tribulation, and in the kingdom and patience of Jesus Christ, was in the isle that is called Patmos, for the word of God, and for the testimony of Jesus Christ.
30708	1168	10	I was in the Spirit on the Lord's day, and heard behind me a great voice, as of a trumpet,
30709	1168	11	Saying, I am Alpha and Omega, the first and the last: and, What thou seest, write in a book, and send it unto the seven churches which are in Asia; unto Ephesus, and unto Smyrna, and unto Pergamos, and unto Thyatira, and unto Sardis, and unto Philadelphia, and unto Laodicea.
30710	1168	12	And I turned to see the voice that spake with me. And being turned, I saw seven golden candlesticks;
30711	1168	13	And in the midst of the seven candlesticks one like unto the Son of man, clothed with a garment down to the foot, and girt about the paps with a golden girdle.
30712	1168	14	His head and his hairs were white like wool, as white as snow; and his eyes were as a flame of fire;
30713	1168	15	And his feet like unto fine brass, as if they burned in a furnace; and his voice as the sound of many waters.
30714	1168	16	And he had in his right hand seven stars: and out of his mouth went a sharp twoedged sword: and his countenance was as the sun shineth in his strength.
30715	1168	17	And when I saw him, I fell at his feet as dead. And he laid his right hand upon me, saying unto me, Fear not; I am the first and the last:
30716	1168	18	I am he that liveth, and was dead; and, behold, I am alive for evermore, Amen; and have the keys of hell and of death.
30717	1168	19	Write the things which thou hast seen, and the things which are, and the things which shall be hereafter;
30718	1168	20	The mystery of the seven stars which thou sawest in my right hand, and the seven golden candlesticks. The seven stars are the angels of the seven churches: and the seven candlesticks which thou sawest are the seven churches.
30719	1169	1	UNTO the angel of the church of Ephesus write; These things saith he that holdeth the seven stars in his right hand, who walketh in the midst of the seven golden candlesticks;
30720	1169	2	I know thy works, and thy labour, and thy patience, and how thou canst not bear them which are evil: and thou hast tried them which say they are apostles, and are not, and hast found them liars:
30721	1169	3	And hast borne, and hast patience, and for my name's sake hast laboured, and hast not fainted.
30722	1169	4	Nevertheless I have somewhat against thee, because thou hast left thy first love.
30723	1169	5	Remember therefore from whence thou art fallen, and repent, and do the first works; or else I will come unto thee quickly, and will remove thy candlestick out of his place, except thou repent.
30724	1169	6	But this thou hast, that thou hatest the deeds of the Nicolaitans, which I also hate.
30725	1169	7	He that hath an ear, let him hear what the Spirit saith unto the churches; To him that overcometh will I give to eat of the tree of life, which is in the midst of the paradise of God.
30726	1169	8	And unto the angel of the church in Smyrna write; These things saith the first and the last, which was dead, and is alive;
30727	1169	9	I know thy works, and tribulation, and poverty, (but thou art rich) and I know the blasphemy of them which say they are Jews, and are not, but are the synagogue of Satan.
30728	1169	10	Fear none of those things which thou shalt suffer: behold, the devil shall cast some of you into prison, that ye may be tried; and ye shall have tribulation ten days: be thou faithful unto death, and I will give thee a crown of life.
30729	1169	11	He that hath an ear, let him hear what the Spirit saith unto the churches; He that overcometh shall not be hurt of the second death.
30730	1169	12	And to the angel of the church in Pergamos write; These things saith he which hath the sharp sword with two edges;
30731	1169	13	I know thy works, and where thou dwellest, even where Satan's seat is: and thou holdest fast my name, and hast not denied my faith, even in those days wherein Antipas was my faithful martyr, who was slain among you, where Satan dwelleth.
30732	1169	14	But I have a few things against thee, because thou hast there them that hold the doctrine of Balaam, who taught Balac to cast a stumblingblock before the children of Israel, to eat things sacrificed unto idols, and to commit fornication.
30733	1169	15	So hast thou also them that hold the doctrine of the Nicolaitans, which thing I hate.
30734	1169	16	Repent; or else I will come unto thee quickly, and will fight against them with the sword of my mouth.
30735	1169	17	He that hath an ear, let him hear what the Spirit saith unto the churches; To him that overcometh will I give to eat of the hidden manna, and will give him a white stone, and in the stone a new name written, which no man knoweth saving he that receiveth it.
30736	1169	18	And unto the angel of the church in Thyatira write; These things saith the Son of God, who hath his eyes like unto a flame of fire, and his feet are like fine brass;
30737	1169	19	I know thy works, and charity, and service, and faith, and thy patience, and thy works; and the last to be more than the first.
30738	1169	20	Notwithstanding I have a few things against thee, because thou sufferest that woman Jezebel, which calleth herself a prophetess, to teach and to seduce my servants to commit fornication, and to eat things sacrificed unto idols.
30739	1169	21	And I gave her space to repent of her fornication; and she repented not.
30740	1169	22	Behold, I will cast her into a bed, and them that commit adultery with her into great tribulation, except they repent of their deeds.
30741	1169	23	And I will kill her children with death; and all the churches shall know that I am he which searcheth the reins and hearts: and I will give unto every one of you according to your works.
30742	1169	24	But unto you I say, and unto the rest in Thyatira, as many as have not this doctrine, and which have not known the depths of Satan, as they speak; I will put upon you none other burden.
30743	1169	25	But that which ye have already hold fast till I come.
30744	1169	26	And he that overcometh, and keepeth my works unto the end, to him will I give power over the nations:
30745	1169	27	And he shall rule them with a rod of iron; as the vessels of a potter shall they be broken to shivers: even as I received of my Father.
30746	1169	28	And I will give him the morning star.
30747	1169	29	He that hath an ear, let him hear what the Spirit saith unto the churches.
30748	1170	1	AND unto the angel of the church in Sardis write; These things saith he that hath the seven Spirits of God, and the seven stars; I know thy works, that thou hast a name that thou livest, and art dead.
30749	1170	2	Be watchful, and strengthen the things which remain, that are ready to die: for I have not found thy works perfect before God.
30750	1170	3	Remember therefore how thou hast received and heard, and hold fast, and repent. If therefore thou shalt not watch, I will come on thee as a thief, and thou shalt not know what hour I will come upon thee.
30751	1170	4	Thou hast a few names even in Sardis which have not defiled their garments; and they shall walk with me in white: for they are worthy.
30752	1170	5	He that overcometh, the same shall be clothed in white raiment; and I will not blot out his name out of the book of life, but I will confess his name before my Father, and before his angels.
30753	1170	6	He that hath an ear, let him hear what the Spirit saith unto the churches.
30754	1170	7	And to the angel of the church in Philadelphia write; These things saith he that is holy, he that is true, he that hath the key of David, he that openeth, and no man shutteth; and shutteth, and no man openeth;
30755	1170	8	I know thy works: behold, I have set before thee an open door, and no man can shut it: for thou hast a little strength, and hast kept my word, and hast not denied my name.
30756	1170	9	Behold, I will make them of the synagogue of Satan, which say they are Jews, and are not, but do lie; behold, I will make them to come and worship before thy feet, and to know that I have loved thee.
30757	1170	10	Because thou hast kept the word of my patience, I also will keep thee from the hour of temptation, which shall come upon all the world, to try them that dwell upon the earth.
30758	1170	11	Behold, I come quickly: hold that fast which thou hast, that no man take thy crown.
30759	1170	12	Him that overcometh will I make a pillar in the temple of my God, and he shall go no more out: and I will write upon him the name of my God, and the name of the city of my God, which is new Jerusalem, which cometh down out of heaven from my God: and I will write upon him my new name.
30760	1170	13	He that hath an ear, let him hear what the Spirit saith unto the churches.
30761	1170	14	And unto the angel of the church of the Laodiceans write; These things saith the Amen, the faithful and true witness, the beginning of the creation of God;
30762	1170	15	I know thy works, that thou art neither cold nor hot: I would thou wert cold or hot.
30763	1170	16	So then because thou art lukewarm, and neither cold nor hot, I will spue thee out of my mouth.
30764	1170	17	Because thou sayest, I am rich, and increased with goods, and have need of nothing; and knowest not that thou art wretched, and miserable, and poor, and blind, and naked:
30765	1170	18	I counsel thee to buy of me gold tried in the fire, that thou mayest be rich; and white raiment, that thou mayest be clothed, and that the shame of thy nakedness do not appear; and anoint thine eyes with eyesalve, that thou mayest see.
30766	1170	19	As many as I love, I rebuke and chasten: be zealous therefore, and repent.
30767	1170	20	Behold, I stand at the door, and knock: if any man hear my voice, and open the door, I will come in to him, and will sup with him, and he with me.
30768	1170	21	To him that overcometh will I grant to sit with me in my throne, even as I also overcame, and am set down with my Father in his throne.
30769	1170	22	He that hath an ear, let him hear what the Spirit saith unto the churches.
30770	1171	1	AFTER this I looked, and, behold, a door was opened in heaven: and the first voice which I heard was as it were of a trumpet talking with me; which said, Come up hither, and I will shew thee things which must be hereafter.
30771	1171	2	And immediately I was in the spirit: and, behold, a throne was set in heaven, and one sat on the throne.
30772	1171	3	And he that sat was to look upon like a jasper and a sardine stone: and there was a rainbow round about the throne, in sight like unto an emerald.
30773	1171	4	And round about the throne were four and twenty seats: and upon the seats I saw four and twenty elders sitting, clothed in white raiment; and they had on their heads crowns of gold.
30774	1171	5	And out of the throne proceeded lightnings and thunderings and voices: and there were seven lamps of fire burning before the throne, which are the seven Spirits of God.
30775	1171	6	And before the throne there was a sea of glass like unto crystal: and in the midst of the throne, and round about the throne, were four beasts full of eyes before and behind.
30776	1171	7	And the first beast was like a lion, and the second beast like a calf, and the third beast had a face as a man, and the fourth beast was like a flying eagle.
30777	1171	8	And the four beasts had each of them six wings about him; and they were full of eyes within: and they rest not day and night, saying, Holy, holy, holy, Lord God Almighty, which was, and is, and is to come.
30778	1171	9	And when those beasts give glory and honour and thanks to him that sat on the throne, who liveth for ever and ever,
30779	1171	10	The four and twenty elders fall down before him that sat on the throne, and worship him that liveth for ever and ever, and cast their crowns before the throne, saying,
30780	1171	11	Thou art worthy, O Lord, to receive glory and honour and power: for thou hast created all things, and for thy pleasure they are and were created.
30781	1172	1	AND I saw in the right hand of him that sat on the throne a book written within and on the backside, sealed with seven seals.
30782	1172	2	And I saw a strong angel proclaiming with a loud voice, Who is worthy to open the book, and to loose the seals thereof?
30783	1172	3	And no man in heaven, nor in earth, neither under the earth, was able to open the book, neither to look thereon.
30784	1172	4	And I wept much, because no man was found worthy to open and to read the book, neither to look thereon.
30785	1172	5	And one of the elders saith unto me, Weep not: behold, the Lion of the tribe of Juda, the Root of David, hath prevailed to open the book, and to loose the seven seals thereof.
30786	1172	6	And I beheld, and, lo, in the midst of the throne and of the four beasts, and in the midst of the elders, stood a Lamb as it had been slain, having seven horns and seven eyes, which are the seven Spirits of God sent forth into all the earth.
30787	1172	7	And he came and took the book out of the right hand of him that sat upon the throne.
30788	1172	8	And when he had taken the book, the four beasts and four and twenty elders fell down before the Lamb, having every one of them harps, and golden vials full of odours, which are the prayers of saints.
30789	1172	9	And they sung a new song, saying, Thou art worthy to take the book, and to open the seals thereof: for thou wast slain, and hast redeemed us to God by thy blood out of every kindred, and tongue, and people, and nation;
30790	1172	10	And hast made us unto our God kings and priests: and we shall reign on the earth.
30791	1172	11	And I beheld, and I heard the voice of many angels round about the throne and the beasts and the elders: and the number of them was ten thousand times ten thousand, and thousands of thousands;
30792	1172	12	Saying with a loud voice, Worthy is the Lamb that was slain to receive power, and riches, and wisdom, and strength, and honour, and glory, and blessing.
30793	1172	13	And every creature which is in heaven, and on the earth, and under the earth, and such as are in the sea, and all that are in them, heard I saying, Blessing, and honour, and glory, and power, be unto him that sitteth upon the throne, and unto the Lamb for ever and ever.
30794	1172	14	And the four beasts said, Amen. And the four and twenty elders fell down and worshipped him that liveth for ever and ever.
30795	1173	1	AND I saw when the Lamb opened one of the seals, and I heard, as it were the noise of thunder, one of the four beasts saying, Come and see.
30796	1173	2	And I saw, and behold a white horse: and he that sat on him had a bow; and a crown was given unto him: and he went forth conquering, and to conquer.
30797	1173	3	And when he had opened the second seal, I heard the second beast say, Come and see.
30798	1173	4	And there went out another horse that was red: and power was given to him that sat thereon to take peace from the earth, and that they should kill one another: and there was given unto him a great sword.
30799	1173	5	And when he had opened the third seal, I heard the third beast say, Come and see. And I beheld, and lo a black horse; and he that sat on him had a pair of balances in his hand.
30800	1173	6	And I heard a voice in the midst of the four beasts say, A measure of wheat for a penny, and three measures of barley for a penny; and see thou hurt not the oil and the wine.
30801	1173	7	And when he had opened the fourth seal, I heard the voice of the fourth beast say, Come and see.
30802	1173	8	And I looked, and behold a pale horse: and his name that sat on him was Death, and Hell followed with him. And power was given unto them over the fourth part of the earth, to kill with sword, and with hunger, and with death, and with the beasts of the earth.
30803	1173	9	And when he had opened the fifth seal, I saw under the altar the souls of them that were slain for the word of God, and for the testimony which they held:
30804	1173	10	And they cried with a loud voice, saying, How long, O Lord, holy and true, dost thou not judge and avenge our blood on them that dwell on the earth?
30805	1173	11	And white robes were given unto every one of them; and it was said unto them, that they should rest yet for a little season, until their fellowservants also and their brethren, that should be killed as they were, should be fulfilled.
30806	1173	12	And I beheld when he had opened the sixth seal, and, lo, there was a great earthquake; and the sun became black as sackcloth of hair, and the moon became as blood;
30807	1173	13	And the stars of heaven fell unto the earth, even as a fig tree casteth her untimely figs, when she is shaken of a mighty wind.
30808	1173	14	And the heaven departed as a scroll when it is rolled together; and every mountain and island were moved out of their places.
30809	1173	15	And the kings of the earth, and the great men, and the rich men, and the chief captains, and the mighty men, and every bondman, and every free man, hid themselves in the dens and in the rocks of the mountains;
30810	1173	16	And said to the mountains and rocks, Fall on us, and hide us from the face of him that sitteth on the throne, and from the wrath of the Lamb:
30811	1173	17	For the great day of his wrath is come; and who shall be able to stand?
30812	1174	1	AND after these things I saw four angels standing on the four corners of the earth, holding the four winds of the earth, that the wind should not blow on the earth, nor on the sea, nor on any tree.
30813	1174	2	And I saw another angel ascending from the east, having the seal of the living God: and he cried with a loud voice to the four angels, to whom it was given to hurt the earth and the sea,
30814	1174	3	Saying, Hurt not the earth, neither the sea, nor the trees, till we have sealed the servants of our God in their foreheads.
30815	1174	4	And I heard the number of them which were sealed: and there were sealed an hundred and forty and four thousand of all the tribes of the children of Israel.
30816	1174	5	Of the tribe of Juda were sealed twelve thousand. Of the tribe of Reuben were sealed twelve thousand. Of the tribe of Gad were sealed twelve thousand.
30817	1174	6	Of the tribe of Aser were sealed twelve thousand. Of the tribe of Nepthalim were sealed twelve thousand. Of the tribe of Manasses were sealed twelve thousand.
30818	1174	7	Of the tribe of Simeon were sealed twelve thousand. Of the tribe of Levi were sealed twelve thousand. Of the tribe of Issachar were sealed twelve thousand.
30819	1174	8	Of the tribe of Zabulon were sealed twelve thousand. Of the tribe of Joseph were sealed twelve thousand. Of the tribe of Benjamin were sealed twelve thousand.
30820	1174	9	After this I beheld, and, lo, a great multitude, which no man could number, of all nations, and kindreds, and people, and tongues, stood before the throne, and before the Lamb, clothed with white robes, and palms in their hands;
30821	1174	10	And cried with a loud voice, saying, Salvation to our God which sitteth upon the throne, and unto the Lamb.
30822	1174	11	And all the angels stood round about the throne, and about the elders and the four beasts, and fell before the throne on their faces, and worshipped God,
30823	1174	12	Saying, Amen: Blessing, and glory, and wisdom, and thanksgiving, and honour, and power, and might, be unto our God for ever and ever. Amen.
30824	1174	13	And one of the elders answered, saying unto me, What are these which are arrayed in white robes? and whence came they?
30825	1174	14	And I said unto him, Sir, thou knowest. And he said to me, These are they which came out of great tribulation, and have washed their robes, and made them white in the blood of the Lamb.
30826	1174	15	Therefore are they before the throne of God, and serve him day and night in his temple: and he that sitteth on the throne shall dwell among them.
30827	1174	16	They shall hunger no more, neither thirst any more; neither shall the sun light on them, nor any heat.
30828	1174	17	For the Lamb which is in the midst of the throne shall feed them, and shall lead them unto living fountains of waters: and God shall wipe away all tears from their eyes.
30829	1175	1	AND when he had opened the seventh seal, there was silence in heaven about the space of half an hour.
30830	1175	2	And I saw the seven angels which stood before God; and to them were given seven trumpets.
30831	1175	3	And another angel came and stood at the altar, having a golden censer; and there was given unto him much incense, that he should offer it with the prayers of all saints upon the golden altar which was before the throne.
30832	1175	4	And the smoke of the incense, which came with the prayers of the saints, ascended up before God out of the angel's hand.
30833	1175	5	And the angel took the censer, and filled it with fire of the altar, and cast it into the earth: and there were voices, and thunderings, and lightnings, and an earthquake.
30834	1175	6	And the seven angels which had the seven trumpets prepared themselves to sound.
30835	1175	7	The first angel sounded, and there followed hail and fire mingled with blood, and they were cast upon the earth: and the third part of trees was burnt up, and all green grass was burnt up.
30836	1175	8	And the second angel sounded, and as it were a great mountain burning with fire was cast into the sea: and the third part of the sea became blood;
30837	1175	9	And the third part of the creatures which were in the sea, and had life, died; and the third part of the ships were destroyed.
30838	1175	10	And the third angel sounded, and there fell a great star from heaven, burning as it were a lamp, and it fell upon the third part of the rivers, and upon the fountains of waters;
30839	1175	11	And the name of the star is called Wormwood: and the third part of the waters became wormwood; and many men died of the waters, because they were made bitter.
30840	1175	12	And the fourth angel sounded, and the third part of the sun was smitten, and the third part of the moon, and the third part of the stars; so as the third part of them was darkened, and the day shone not for a third part of it, and the night likewise.
30841	1175	13	And I beheld, and heard an angel flying through the midst of heaven, saying with a loud voice, Woe, woe, woe, to the inhabiters of the earth by reason of the other voices of the trumpet of the three angels, which are yet to sound!
30842	1176	1	AND the fifth angel sounded, and I saw a star fall from heaven unto the earth: and to him was given the key of the bottomless pit.
30843	1176	2	And he opened the bottomless pit; and there arose a smoke out of the pit, as the smoke of a great furnace; and the sun and the air were darkened by reason of the smoke of the pit.
30844	1176	3	And there came out of the smoke locusts upon the earth: and unto them was given power, as the scorpions of the earth have power.
30845	1176	4	And it was commanded them that they should not hurt the grass of the earth, neither any green thing, neither any tree; but only those men which have not the seal of God in their foreheads.
30846	1176	5	And to them it was given that they should not kill them, but that they should be tormented five months: and their torment was as the torment of a scorpion, when he striketh a man.
30847	1176	6	And in those days shall men seek death, and shall not find it; and shall desire to die, and death shall flee from them.
30848	1176	7	And the shapes of the locusts were like unto horses prepared unto battle; and on their heads were as it were crowns like gold, and their faces were as the faces of men.
30849	1176	8	And they had hair as the hair of women, and their teeth were as the teeth of lions.
30850	1176	9	And they had breastplates, as it were breastplates of iron; and the sound of their wings was as the sound of chariots of many horses running to battle.
30851	1176	10	And they had tails like unto scorpions, and there were stings in their tails: and their power was to hurt men five months.
30852	1176	11	And they had a king over them, which is the angel of the bottomless pit, whose name in the Hebrew tongue is Abaddon, but in the Greek tongue hath his name Apollyon.
30853	1176	12	One woe is past; and, behold, there come two woes more hereafter.
30854	1176	13	And the sixth angel sounded, and I heard a voice from the four horns of the golden altar which is before God,
30855	1176	14	Saying to the sixth angel which had the trumpet, Loose the four angels which are bound in the great river Euphrates.
30856	1176	15	And the four angels were loosed, which were prepared for an hour, and a day, and a month, and a year, for to slay the third part of men.
30857	1176	16	And the number of the army of the horsemen were two hundred thousand thousand: and I heard the number of them.
30858	1176	17	And thus I saw the horses in the vision, and them that sat on them, having breastplates of fire, and of jacinth, and brimstone: and the heads of the horses were as the heads of lions; and out of their mouths issued fire and smoke and brimstone.
30859	1176	18	By these three was the third part of men killed, by the fire, and by the smoke, and by the brimstone, which issued out of their mouths.
30860	1176	19	For their power is in their mouth, and in their tails: for their tails were like unto serpents, and had heads, and with them they do hurt.
30861	1176	20	And the rest of the men which were not killed by these plagues yet repented not of the works of their hands, that they should not worship devils, and idols of gold, and silver, and brass, and stone, and of wood: which neither can see, nor hear, nor walk:
30862	1176	21	Neither repented they of their murders, nor of their sorceries, nor of their fornication, nor of their thefts.
30863	1177	1	AND I saw another mighty angel come down from heaven, clothed with a cloud: and a rainbow was upon his head, and his face was as it were the sun, and his feet as pillars of fire:
30864	1177	2	And he had in his hand a little book open: and he set his right foot upon the sea, and his left foot on the earth,
30865	1177	3	And cried with a loud voice, as when a lion roareth: and when he had cried, seven thunders uttered their voices.
30866	1177	4	And when the seven thunders had uttered their voices, I was about to write: and I heard a voice from heaven saying unto me, Seal up those things which the seven thunders uttered, and write them not.
30867	1177	5	And the angel which I saw stand upon the sea and upon the earth lifted up his hand to heaven,
30868	1177	6	And sware by him that liveth for ever and ever, who created heaven, and the things that therein are, and the earth, and the things that therein are, and the sea, and the things which are therein, that there should be time no longer:
30869	1177	7	But in the days of the voice of the seventh angel, when he shall begin to sound, the mystery of God should be finished, as he hath declared to his servants the prophets.
30870	1177	8	And the voice which I heard from heaven spake unto me again, and said, Go and take the little book which is open in the hand of the angel which standeth upon the sea and upon the earth.
30871	1177	9	And I went unto the angel, and said unto him, Give me the little book. And he said unto me, Take it, and eat it up; and it shall make thy belly bitter, but it shall be in thy mouth sweet as honey.
30872	1177	10	And I took the little book out of the angel's hand, and ate it up; and it was in my mouth sweet as honey: and as soon as I had eaten it, my belly was bitter.
30873	1177	11	And he said unto me, Thou must prophesy again before many peoples, and nations, and tongues, and kings.
30874	1178	1	AND there was given me a reed like unto a rod: and the angel stood, saying, Rise, and measure the temple of God, and the altar, and them that worship therein.
30875	1178	2	But the court which is without the temple leave out, and measure it not; for it is given unto the Gentiles: and the holy city shall they tread under foot forty and two months.
30876	1178	3	And I will give power unto my two witnesses, and they shall prophesy a thousand two hundred and threescore days, clothed in sackcloth.
30877	1178	4	These are the two olive trees, and the two candlesticks standing before the God of the earth.
30878	1178	5	And if any man will hurt them, fire proceedeth out of their mouth, and devoureth their enemies: and if any man will hurt them, he must in this manner be killed.
30879	1178	6	These have power to shut heaven, that it rain not in the days of their prophecy: and have power over waters to turn them to blood, and to smite the earth with all plagues, as often as they will.
30880	1178	7	And when they shall have finished their testimony, the beast that ascendeth out of the bottomless pit shall make war against them, and shall overcome them, and kill them.
30881	1178	8	And their dead bodies shall lie in the street of the great city, which spiritually is called Sodom and Egypt, where also our Lord was crucified.
30882	1178	9	And they of the people and kindreds and tongues and nations shall see their dead bodies three days and an half, and shall not suffer their dead bodies to be put in graves.
30883	1178	10	And they that dwell upon the earth shall rejoice over them, and make merry, and shall send gifts one to another; because these two prophets tormented them that dwelt on the earth.
30884	1178	11	And after three days and an half the Spirit of life from God entered into them, and they stood upon their feet; and great fear fell upon them which saw them.
30885	1178	12	And they heard a great voice from heaven saying unto them, Come up hither. And they ascended up to heaven in a cloud; and their enemies beheld them.
30886	1178	13	And the same hour was there a great earthquake, and the tenth part of the city fell, and in the earthquake were slain of men seven thousand: and the remnant were affrighted, and gave glory to the God of heaven.
30887	1178	14	The second woe is past; and, behold, the third woe cometh quickly.
30888	1178	15	And the seventh angel sounded; and there were great voices in heaven, saying, The kingdoms of this world are become the kingdoms of our Lord, and of his Christ; and he shall reign for ever and ever.
30889	1178	16	And the four and twenty elders, which sat before God on their seats, fell upon their faces, and worshipped God,
30890	1178	17	Saying, We give thee thanks, O Lord God Almighty, which art, and wast, and art to come; because thou hast taken to thee thy great power, and hast reigned.
30891	1178	18	And the nations were angry, and thy wrath is come, and the time of the dead, that they should be judged, and that thou shouldest give reward unto thy servants the prophets, and to the saints, and them that fear thy name, small and great; and shouldest destroy them which destroy the earth.
30892	1178	19	And the temple of God was opened in heaven, and there was seen in his temple the ark of his testament: and there were lightnings, and voices, and thunderings, and an earthquake, and great hail.
30893	1179	1	AND there appeared a great wonder in heaven; a woman clothed with the sun, and the moon under her feet, and upon her head a crown of twelve stars:
30894	1179	2	And she being with child cried, travailing in birth, and pained to be delivered.
30895	1179	3	And there appeared another wonder in heaven; and behold a great red dragon, having seven heads and ten horns, and seven crowns upon his heads.
30896	1179	4	And his tail drew the third part of the stars of heaven, and did cast them to the earth: and the dragon stood before the woman which was ready to be delivered, for to devour her child as soon as it was born.
30897	1179	5	And she brought forth a man child, who was to rule all nations with a rod of iron: and her child was caught up unto God, and to his throne.
30898	1179	6	And the woman fled into the wilderness, where she hath a place prepared of God, that they should feed her there a thousand two hundred and threescore days.
30899	1179	7	And there was war in heaven: Michael and his angels fought against the dragon; and the dragon fought and his angels,
30900	1179	8	And prevailed not; neither was their place found any more in heaven.
30901	1179	9	And the great dragon was cast out, that old serpent, called the Devil, and Satan, which deceiveth the whole world: he was cast out into the earth, and his angels were cast out with him.
30902	1179	10	And I heard a loud voice saying in heaven, Now is come salvation, and strength, and the kingdom of our God, and the power of his Christ: for the accuser of our brethren is cast down, which accused them before our God day and night.
30903	1179	11	And they overcame him by the blood of the Lamb, and by the word of their testimony; and they loved not their lives unto the death.
30904	1179	12	Therefore rejoice, ye heavens, and ye that dwell in them. Woe to the inhabiters of the earth and of the sea! for the devil is come down unto you, having great wrath, because he knoweth that he hath but a short time.
30905	1179	13	And when the dragon saw that he was cast unto the earth, he persecuted the woman which brought forth the man child.
30906	1179	14	And to the woman were given two wings of a great eagle, that she might fly into the wilderness, into her place, where she is nourished for a time, and times, and half a time, from the face of the serpent.
30907	1179	15	And the serpent cast out of his mouth water as a flood after the woman, that he might cause her to be carried away of the flood.
30908	1179	16	And the earth helped the woman, and the earth opened her mouth, and swallowed up the flood which the dragon cast out of his mouth.
30909	1179	17	And the dragon was wroth with the woman, and went to make war with the remnant of her seed, which keep the commandments of God, and have the testimony of Jesus Christ.
30910	1180	1	AND I stood upon the sand of the sea, and saw a beast rise up out of the sea, having seven heads and ten horns, and upon his horns ten crowns, and upon his heads the name of blasphemy.
30911	1180	2	And the beast which I saw was like unto a leopard, and his feet were as the feet of a bear, and his mouth as the mouth of a lion: and the dragon gave him his power, and his seat, and great authority.
30912	1180	3	And I saw one of his heads as it were wounded to death; and his deadly wound was healed: and all the world wondered after the beast.
30913	1180	4	And they worshipped the dragon which gave power unto the beast: and they worshipped the beast, saying, Who is like unto the beast? who is able to make war with him?
30914	1180	5	And there was given unto him a mouth speaking great things and blasphemies; and power was given unto him to continue forty and two months.
30915	1180	6	And he opened his mouth in blasphemy against God, to blaspheme his name, and his tabernacle, and them that dwell in heaven.
30916	1180	7	And it was given unto him to make war with the saints, and to overcome them: and power was given him over all kindreds, and tongues, and nations.
30917	1180	8	And all that dwell upon the earth shall worship him, whose names are not written in the book of life of the Lamb slain from the foundation of the world.
30918	1180	9	If any man have an ear, let him hear.
30919	1180	10	He that leadeth into captivity shall go into captivity: he that killeth with the sword must be killed with the sword. Here is the patience and the faith of the saints.
30920	1180	11	And I beheld another beast coming up out of the earth; and he had two horns like a lamb, and he spake as a dragon.
30921	1180	12	And he exerciseth all the power of the first beast before him, and causeth the earth and them which dwell therein to worship the first beast, whose deadly wound was healed.
30922	1180	13	And he doeth great wonders, so that he maketh fire come down from heaven on the earth in the sight of men,
30923	1180	14	And deceiveth them that dwell on the earth by the means of those miracles which he had power to do in the sight of the beast; saying to them that dwell on the earth, that they should make an image to the beast, which had the wound by a sword, and did live.
30924	1180	15	And he had power to give life unto the image of the beast, that the image of the beast should both speak, and cause that as many as would not worship the image of the beast should be killed.
30925	1180	16	And he causeth all, both small and great, rich and poor, free and bond, to receive a mark in their right hand, or in their foreheads:
30926	1180	17	And that no man might buy or sell, save he that had the mark, or the name of the beast, or the number of his name.
30927	1180	18	Here is wisdom. Let him that hath understanding count the number of the beast: for it is the number of a man; and his number is Six hundred threescore and six.
30928	1181	1	AND I looked, and, lo, a Lamb stood on the mount Sion, and with him an hundred forty and four thousand, having his Father's name written in their foreheads.
30929	1181	2	And I heard a voice from heaven, as the voice of many waters, and as the voice of a great thunder: and I heard the voice of harpers harping with their harps:
30930	1181	3	And they sung as it were a new song before the throne, and before the four beasts, and the elders: and no man could learn that song but the hundred and forty and four thousand, which were redeemed from the earth.
30931	1181	4	These are they which were not defiled with women; for they are virgins. These are they which follow the Lamb whithersoever he goeth. These were redeemed from among men, being the firstfruits unto God and to the Lamb.
30932	1181	5	And in their mouth was found no guile: for they are without fault before the throne of God.
30933	1181	6	And I saw another angel fly in the midst of heaven, having the everlasting gospel to preach unto them that dwell on the earth, and to every nation, and kindred, and tongue, and people,
30934	1181	7	Saying with a loud voice, Fear God, and give glory to him; for the hour of his judgment is come: and worship him that made heaven, and earth, and the sea, and the fountains of waters.
30935	1181	8	And there followed another angel, saying, Babylon is fallen, is fallen, that great city, because she made all nations drink of the wine of the wrath of her fornication.
30936	1181	9	And the third angel followed them, saying with a loud voice, If any man worship the beast and his image, and receive his mark in his forehead, or in his hand,
30937	1181	10	The same shall drink of the wine of the wrath of God, which is poured out without mixture into the cup of his indignation; and he shall be tormented with fire and brimstone in the presence of the holy angels, and in the presence of the Lamb:
30938	1181	11	And the smoke of their torment ascendeth up for ever and ever: and they have no rest day nor night, who worship the beast and his image, and whosoever receiveth the mark of his name.
30939	1181	12	Here is the patience of the saints: here are they that keep the commandments of God, and the faith of Jesus.
30940	1181	13	And I heard a voice from heaven saying unto me, Write, Blessed are the dead which die in the Lord from henceforth: Yea, saith the Spirit, that they may rest from their labours; and their works do follow them.
30941	1181	14	And I looked, and behold a white cloud, and upon the cloud one sat like unto the Son of man, having on his head a golden crown, and in his hand a sharp sickle.
30942	1181	15	And another angel came out of the temple, crying with a loud voice to him that sat on the cloud, Thrust in thy sickle, and reap: for the time is come for thee to reap; for the harvest of the earth is ripe.
30943	1181	16	And he that sat on the cloud thrust in his sickle on the earth; and the earth was reaped.
30944	1181	17	And another angel came out of the temple which is in heaven, he also having a sharp sickle.
30945	1181	18	And another angel came out from the altar, which had power over fire; and cried with a loud cry to him that had the sharp sickle, saying, Thrust in thy sharp sickle, and gather the clusters of the vine of the earth; for her grapes are fully ripe.
30946	1181	19	And the angel thrust in his sickle into the earth, and gathered the vine of the earth, and cast it into the great winepress of the wrath of God.
30947	1181	20	And the winepress was trodden without the city, and blood came out of the winepress, even unto the horse bridles, by the space of a thousand and six hundred furlongs.
30948	1182	1	AND I saw another sign in heaven, great and marvellous, seven angels having the seven last plagues; for in them is filled up the wrath of God.
30949	1182	2	And I saw as it were a sea of glass mingled with fire: and them that had gotten the victory over the beast, and over his image, and over his mark, and over the number of his name, stand on the sea of glass, having the harps of God.
30950	1182	3	And they sing the song of Moses the servant of God, and the song of the Lamb, saying, Great and marvellous are thy works, Lord God Almighty; just and true are thy ways, thou King of saints.
30951	1182	4	Who shall not fear thee, O Lord, and glorify thy name? for thou only art holy: for all nations shall come and worship before thee; for thy judgments are made manifest.
30952	1182	5	And after that I looked, and, behold, the temple of the tabernacle of the testimony in heaven was opened:
30953	1182	6	And the seven angels came out of the temple, having the seven plagues, clothed in pure and white linen, and having their breasts girded with golden girdles.
30954	1182	7	And one of the four beasts gave unto the seven angels seven golden vials full of the wrath of God, who liveth for ever and ever.
30955	1182	8	And the temple was filled with smoke from the glory of God, and from his power; and no man was able to enter into the temple, till the seven plagues of the seven angels were fulfilled.
30956	1183	1	AND I heard a great voice out of the temple saying to the seven angels, Go your ways, and pour out the vials of the wrath of God upon the earth.
30957	1183	2	And the first went, and poured out his vial upon the earth; and there fell a noisome and grievous sore upon the men which had the mark of the beast, and upon them which worshipped his image.
30958	1183	3	And the second angel poured out his vial upon the sea; and it became as the blood of a dead man: and every living soul died in the sea.
30959	1183	4	And the third angel poured out his vial upon the rivers and fountains of waters; and they became blood.
30960	1183	5	And I heard the angel of the waters say, Thou art righteous, O Lord, which art, and wast, and shalt be, because thou hast judged thus.
30961	1183	6	For they have shed the blood of saints and prophets, and thou hast given them blood to drink; for they are worthy.
30962	1183	7	And I heard another out of the altar say, Even so, Lord God Almighty, true and righteous are thy judgments.
30963	1183	8	And the fourth angel poured out his vial upon the sun; and power was given unto him to scorch men with fire.
30964	1183	9	And men were scorched with great heat, and blasphemed the name of God, which hath power over these plagues: and they repented not to give him glory.
30965	1183	10	And the fifth angel poured out his vial upon the seat of the beast; and his kingdom was full of darkness; and they gnawed their tongues for pain,
30966	1183	11	And blasphemed the God of heaven because of their pains and their sores, and repented not of their deeds.
30967	1183	12	And the sixth angel poured out his vial upon the great river Euphrates; and the water thereof was dried up, that the way of the kings of the east might be prepared.
30968	1183	13	And I saw three unclean spirits like frogs come out of the mouth of the dragon, and out of the mouth of the beast, and out of the mouth of the false prophet.
30969	1183	14	For they are the spirits of devils, working miracles, which go forth unto the kings of the earth and of the whole world, to gather them to the battle of that great day of God Almighty.
30970	1183	15	Behold, I come as a thief. Blessed is he that watcheth, and keepeth his garments, lest he walk naked, and they see his shame.
30971	1183	16	And he gathered them together into a place called in the Hebrew tongue Armageddon.
30972	1183	17	And the seventh angel poured out his vial into the air; and there came a great voice out of the temple of heaven, from the throne, saying, It is done.
30973	1183	18	And there were voices, and thunders, and lightnings; and there was a great earthquake, such as was not since men were upon the earth, so mighty an earthquake, and so great.
30974	1183	19	And the great city was divided into three parts, and the cities of the nations fell: and great Babylon came in remembrance before God, to give unto her the cup of the wine of the fierceness of his wrath.
30975	1183	20	And every island fled away, and the mountains were not found.
30976	1183	21	And there fell upon men a great hail out of heaven, every stone about the weight of a talent: and men blasphemed God because of the plague of the hail; for the plague thereof was exceeding great.
30977	1184	1	AND there came one of the seven angels which had the seven vials, and talked with me, saying unto me, Come hither; I will shew unto thee the judgment of the great whore that sitteth upon many waters:
30978	1184	2	With whom the kings of the earth have committed fornication, and the inhabitants of the earth have been made drunk with the wine of her fornication.
30979	1184	3	So he carried me away in the spirit into the wilderness: and I saw a woman sit upon a scarlet coloured beast, full of names of blasphemy, having seven heads and ten horns.
30980	1184	4	And the woman was arrayed in purple and scarlet colour, and decked with gold and precious stones and pearls, having a golden cup in her hand full of abominations and filthiness of her fornication:
30981	1184	5	And upon her forehead was a name written, MYSTERY, BABYLON THE GREAT, THE MOTHER OF HARLOTS AND ABOMINATIONS OF THE EARTH.
30982	1184	6	And I saw the woman drunken with the blood of the saints, and with the blood of the martyrs of Jesus: and when I saw her, I wondered with great admiration.
30983	1184	7	And the angel said unto me, Wherefore didst thou marvel? I will tell thee the mystery of the woman, and of the beast that carrieth her, which hath the seven heads and ten horns.
30984	1184	8	The beast that thou sawest was, and is not; and shall ascend out of the bottomless pit, and go into perdition: and they that dwell on the earth shall wonder, whose names were not written in the book of life from the foundation of the world, when they behold the beast that was, and is not, and yet is.
30985	1184	9	And here is the mind which hath wisdom. The seven heads are seven mountains, on which the woman sitteth.
30986	1184	10	And there are seven kings: five are fallen, and one is, and the other is not yet come; and when he cometh, he must continue a short space.
30987	1184	11	And the beast that was, and is not, even he is the eighth, and is of the seven, and goeth into perdition.
30988	1184	12	And the ten horns which thou sawest are ten kings, which have received no kingdom as yet; but receive power as kings one hour with the beast.
30989	1184	13	These have one mind, and shall give their power and strength unto the beast.
30990	1184	14	These shall make war with the Lamb, and the Lamb shall overcome them: for he is Lord of lords, and King of kings: and they that are with him are called, and chosen, and faithful.
30991	1184	15	And he saith unto me, The waters which thou sawest, where the whore sitteth, are peoples, and multitudes, and nations, and tongues.
30992	1184	16	And the ten horns which thou sawest upon the beast, these shall hate the whore, and shall make her desolate and naked, and shall eat her flesh, and burn her with fire.
30993	1184	17	For God hath put in their hearts to fulfil his will, and to agree, and give their kingdom unto the beast, until the words of God shall be fulfilled.
30994	1184	18	And the woman which thou sawest is that great city, which reigneth over the kings of the earth.
30995	1185	1	AND after these things I saw another angel come down from heaven, having great power; and the earth was lightened with his glory.
30996	1185	2	And he cried mightily with a strong voice, saying, Babylon the great is fallen, is fallen, and is become the habitation of devils, and the hold of every foul spirit, and a cage of every unclean and hateful bird.
30997	1185	3	For all nations have drunk of the wine of the wrath of her fornication, and the kings of the earth have committed fornication with her, and the merchants of the earth are waxed rich through the abundance of her delicacies.
30998	1185	4	And I heard another voice from heaven, saying, Come out of her, my people, that ye be not partakers of her sins, and that ye receive not of her plagues.
30999	1185	5	For her sins have reached unto heaven, and God hath remembered her iniquities.
31000	1185	6	Reward her even as she rewarded you, and double unto her double according to her works: in the cup which she hath filled fill to her double.
31001	1185	7	How much she hath glorified herself, and lived deliciously, so much torment and sorrow give her: for she saith in her heart, I sit a queen, and am no widow, and shall see no sorrow.
31002	1185	8	Therefore shall her plagues come in one day, death, and mourning, and famine; and she shall be utterly burned with fire: for strong is the Lord God who judgeth her.
31003	1185	9	And the kings of the earth, who have committed fornication and lived deliciously with her, shall bewail her, and lament for her, when they shall see the smoke of her burning,
31004	1185	10	Standing afar off for the fear of her torment, saying, Alas, alas, that great city Babylon, that mighty city! for in one hour is thy judgment come.
31005	1185	11	And the merchants of the earth shall weep and mourn over her; for no man buyeth their merchandise any more:
31006	1185	12	The merchandise of gold, and silver, and precious stones, and of pearls, and fine linen, and purple, and silk, and scarlet, and all thyine wood, and all manner vessels of ivory, and all manner vessels of most precious wood, and of brass, and iron, and marble,
31007	1185	13	And cinnamon, and odours, and ointments, and frankincense, and wine, and oil, and fine flour, and wheat, and beasts, and sheep, and horses, and chariots, and slaves, and souls of men.
31008	1185	14	And the fruits that thy soul lusted after are departed from thee, and all things which were dainty and goodly are departed from thee, and thou shalt find them no more at all.
31009	1185	15	The merchants of these things, which were made rich by her, shall stand afar off for the fear of her torment, weeping and wailing,
31010	1185	16	And saying, Alas, alas, that great city, that was clothed in fine linen, and purple, and scarlet, and decked with gold, and precious stones, and pearls!
31011	1185	17	For in one hour so great riches is come to nought. And every shipmaster, and all the company in ships, and sailors, and as many as trade by sea, stood afar off,
31012	1185	18	And cried when they saw the smoke of her burning, saying, What city is like unto this great city!
31013	1185	19	And they cast dust on their heads, and cried, weeping and wailing, saying, Alas, alas, that great city, wherein were made rich all that had ships in the sea by reason of her costliness! for in one hour is she made desolate.
31014	1185	20	Rejoice over her, thou heaven, and ye holy apostles and prophets; for God hath avenged you on her.
31015	1185	21	And a mighty angel took up a stone like a great millstone, and cast it into the sea, saying, Thus with violence shall that great city Babylon be thrown down, and shall be found no more at all.
31016	1185	22	And the voice of harpers, and musicians, and of pipers, and trumpeters, shall be heard no more at all in thee; and no craftsman, of whatsoever craft he be, shall be found any more in thee; and the sound of a millstone shall be heard no more at all in thee;
31017	1185	23	And the light of a candle shall shine no more at all in thee; and the voice of the bridegroom and of the bride shall be heard no more at all in thee: for thy merchants were the great men of the earth; for by thy sorceries were all nations deceived.
31018	1185	24	And in her was found the blood of prophets, and of saints, and of all that were slain upon the earth.
31019	1186	1	AND after these things I heard a great voice of much people in heaven, saying, Alleluia; Salvation, and glory, and honour, and power, unto the Lord our God:
31020	1186	2	For true and righteous are his judgments: for he hath judged the great whore, which did corrupt the earth with her fornication, and hath avenged the blood of his servants at her hand.
31021	1186	3	And again they said, Alleluia. And her smoke rose up for ever and ever.
31022	1186	4	And the four and twenty elders and the four beasts fell down and worshipped God that sat on the throne, saying, Amen; Alleluia.
31023	1186	5	And a voice came out of the throne, saying, Praise our God, all ye his servants, and ye that fear him, both small and great.
31024	1186	6	And I heard as it were the voice of a great multitude, and as the voice of many waters, and as the voice of mighty thunderings, saying, Alleluia: for the Lord God omnipotent reigneth.
31025	1186	7	Let us be glad and rejoice, and give honour to him: for the marriage of the Lamb is come, and his wife hath made herself ready.
31026	1186	8	And to her was granted that she should be arrayed in fine linen, clean and white: for the fine linen is the righteousness of saints.
31027	1186	9	And he saith unto me, Write, Blessed are they which are called unto the marriage supper of the Lamb. And he saith unto me, These are the true sayings of God.
31028	1186	10	And I fell at his feet to worship him. And he said unto me, See thou do it not: I am thy fellowservant, and of thy brethren that have the testimony of Jesus: worship God: for the testimony of Jesus is the spirit of prophecy.
31029	1186	11	And I saw heaven opened, and behold a white horse; and he that sat upon him was called Faithful and True, and in righteousness he doth judge and make war.
31030	1186	12	His eyes were as a flame of fire, and on his head were many crowns; and he had a name written, that no man knew, but he himself.
31031	1186	13	And he was clothed with a vesture dipped in blood: and his name is called The Word of God.
31032	1186	14	And the armies which were in heaven followed him upon white horses, clothed in fine linen, white and clean.
31033	1186	15	And out of his mouth goeth a sharp sword, that with it he should smite the nations: and he shall rule them with a rod of iron: and he treadeth the winepress of the fierceness and wrath of Almighty God.
31034	1186	16	And he hath on his vesture and on his thigh a name written, KING OF KINGS, AND LORD OF LORDS.
31035	1186	17	And I saw an angel standing in the sun; and he cried with a loud voice, saying to all the fowls that fly in the midst of heaven, Come and gather yourselves together unto the supper of the great God;
31036	1186	18	That ye may eat the flesh of kings, and the flesh of captains, and the flesh of mighty men, and the flesh of horses, and of them that sit on them, and the flesh of all men, both free and bond, both small and great.
31037	1186	19	And I saw the beast, and the kings of the earth, and their armies, gathered together to make war against him that sat on the horse, and against his army.
31038	1186	20	And the beast was taken, and with him the false prophet that wrought miracles before him, with which he deceived them that had received the mark of the beast, and them that worshipped his image. These both were cast alive into a lake of fire burning with brimstone.
31039	1186	21	And the remnant were slain with the sword of him that sat upon the horse, which sword proceeded out of his mouth: and all the fowls were filled with their flesh.
31040	1187	1	AND I saw an angel come down from heaven, having the key of the bottomless pit and a great chain in his hand.
31041	1187	2	And he laid hold on the dragon, that old serpent, which is the Devil, and Satan, and bound him a thousand years,
31042	1187	3	And cast him into the bottomless pit, and shut him up, and set a seal upon him, that he should deceive the nations no more, till the thousand years should be fulfilled: and after that he must be loosed a little season.
31043	1187	4	And I saw thrones, and they sat upon them, and judgment was given unto them: and I saw the souls of them that were beheaded for the witness of Jesus, and for the word of God, and which had not worshipped the beast, neither his image, neither had received his mark upon their foreheads, or in their hands; and they lived and reigned with Christ a thousand years.
31044	1187	5	But the rest of the dead lived not again until the thousand years were finished. This is the first resurrection.
31045	1187	6	Blessed and holy is he that hath part in the first resurrection: on such the second death hath no power, but they shall be priests of God and of Christ, and shall reign with him a thousand years.
31046	1187	7	And when the thousand years are expired, Satan shall be loosed out of his prison,
31047	1187	8	And shall go out to deceive the nations which are in the four quarters of the earth, Gog and Magog, to gather them together to battle: the number of whom is as the sand of the sea.
31048	1187	9	And they went up on the breadth of the earth, and compassed the camp of the saints about, and the beloved city: and fire came down from God out of heaven, and devoured them.
31049	1187	10	And the devil that deceived them was cast into the lake of fire and brimstone, where the beast and the false prophet are, and shall be tormented day and night for ever and ever.
31050	1187	11	And I saw a great white throne, and him that sat on it, from whose face the earth and the heaven fled away; and there was found no place for them.
31051	1187	12	And I saw the dead, small and great, stand before God; and the books were opened: and another book was opened, which is the book of life: and the dead were judged out of those things which were written in the books, according to their works.
31052	1187	13	And the sea gave up the dead which were in it; and death and hell delivered up the dead which were in them: and they were judged every man according to their works.
31053	1187	14	And death and hell were cast into the lake of fire. This is the second death.
31054	1187	15	And whosoever was not found written in the book of life was cast into the lake of fire.
31055	1188	1	AND I saw a new heaven and a new earth: for the first heaven and the first earth were passed away; and there was no more sea.
31056	1188	2	And I John saw the holy city, new Jerusalem, coming down from God out of heaven, prepared as a bride adorned for her husband.
31057	1188	3	And I heard a great voice out of heaven saying, Behold, the tabernacle of God is with men, and he will dwell with them, and they shall be his people, and God himself shall be with them, and be their God.
31058	1188	4	And God shall wipe away all tears from their eyes; and there shall be no more death, neither sorrow, nor crying, neither shall there be any more pain: for the former things are passed away.
31059	1188	5	And he that sat upon the throne said, Behold, I make all things new. And he said unto me, Write: for these words are true and faithful.
31060	1188	6	And he said unto me, It is done. I am Alpha and Omega, the beginning and the end. I will give unto him that is athirst of the fountain of the water of life freely.
31061	1188	7	He that overcometh shall inherit all things; and I will be his God, and he shall be my son.
31062	1188	8	But the fearful, and unbelieving, and the abominable, and murderers, and whoremongers, and sorcerers, and idolaters, and all liars, shall have their part in the lake which burneth with fire and brimstone: which is the second death.
31063	1188	9	And there came unto me one of the seven angels which had the seven vials full of the seven last plagues, and talked with me, saying, Come hither, I will shew thee the bride, the Lamb's wife.
31064	1188	10	And he carried me away in the spirit to a great and high mountain, and shewed me that great city, the holy Jerusalem, descending out of heaven from God,
31065	1188	11	Having the glory of God: and her light was like unto a stone most precious, even like a jasper stone, clear as crystal;
31066	1188	12	And had a wall great and high, and had twelve gates, and at the gates twelve angels, and names written thereon, which are the names of the twelve tribes of the children of Israel:
31067	1188	13	On the east three gates; on the north three gates; on the south three gates; and on the west three gates.
31068	1188	14	And the wall of the city had twelve foundations, and in them the names of the twelve apostles of the Lamb.
31069	1188	15	And he that talked with me had a golden reed to measure the city, and the gates thereof, and the wall thereof.
31070	1188	16	And the city lieth foursquare, and the length is as large as the breadth: and he measured the city with the reed, twelve thousand furlongs. The length and the breadth and the height of it are equal.
31071	1188	17	And he measured the wall thereof, an hundred and forty and four cubits, according to the measure of a man, that is, of the angel.
31072	1188	18	And the building of the wall of it was of jasper: and the city was pure gold, like unto clear glass.
31073	1188	19	And the foundations of the wall of the city were garnished with all manner of precious stones. The first foundation was jasper; the second, sapphire; the third, a chalcedony; the fourth, an emerald;
31074	1188	20	The fifth, sardonyx; the sixth, sardius; the seventh, chrysolite; the eighth, beryl; the ninth, a topaz; the tenth, a chrysoprasus; the eleventh, a jacinth; the twelfth, an amethyst.
31075	1188	21	And the twelve gates were twelve pearls; every several gate was of one pearl: and the street of the city was pure gold, as it were transparent glass.
31076	1188	22	And I saw no temple therein: for the Lord God Almighty and the Lamb are the temple of it.
31077	1188	23	And the city had no need of the sun, neither of the moon, to shine in it: for the glory of God did lighten it, and the Lamb is the light thereof.
31078	1188	24	And the nations of them which are saved shall walk in the light of it: and the kings of the earth do bring their glory and honour into it.
31079	1188	25	And the gates of it shall not be shut at all by day: for there shall be no night there.
31080	1188	26	And they shall bring the glory and honour of the nations into it.
31081	1188	27	And there shall in no wise enter into it any thing that defileth, neither whatsoever worketh abomination, or maketh a lie: but they which are written in the Lamb's book of life.
31082	1189	1	AND he shewed me a pure river of water of life, clear as crystal, proceeding out of the throne of God and of the Lamb.
31083	1189	2	In the midst of the street of it, and on either side of the river, was there the tree of life, which bare twelve manner of fruits, and yielded her fruit every month: and the leaves of the tree were for the healing of the nations.
31084	1189	3	And there shall be no more curse: but the throne of God and of the Lamb shall be in it; and his servants shall serve him:
31085	1189	4	And they shall see his face; and his name shall be in their foreheads.
31086	1189	5	And there shall be no night there; and they need no candle, neither light of the sun; for the Lord God giveth them light: and they shall reign for ever and ever.
31087	1189	6	And he said unto me, These sayings are faithful and true: and the Lord God of the holy prophets sent his angel to shew unto his servants the things which must shortly be done.
31088	1189	7	Behold, I come quickly: blessed is he that keepeth the sayings of the prophecy of this book.
31089	1189	8	And I John saw these things, and heard them. And when I had heard and seen, I fell down to worship before the feet of the angel which shewed me these things.
31090	1189	9	Then saith he unto me, See thou do it not: for I am thy fellowservant, and of thy brethren the prophets, and of them which keep the sayings of this book: worship God.
31091	1189	10	And he saith unto me, Seal not the sayings of the prophecy of this book: for the time is at hand.
31092	1189	11	He that is unjust, let him be unjust still: and he which is filthy, let him be filthy still: and he that is righteous, let him be righteous still: and he that is holy, let him be holy still.
31093	1189	12	And, behold, I come quickly; and my reward is with me, to give every man according as his work shall be.
31094	1189	13	I am Alpha and Omega, the beginning and the end, the first and the last.
31095	1189	14	Blessed are they that do his commandments, that they may have right to the tree of life, and may enter in through the gates into the city.
31096	1189	15	For without are dogs, and sorcerers, and whoremongers, and murderers, and idolaters, and whosoever loveth and maketh a lie.
31097	1189	16	I Jesus have sent mine angel to testify unto you these things in the churches. I am the root and the offspring of David, and the bright and morning star.
31098	1189	17	And the Spirit and the bride say, Come. And let him that heareth say, Come. And let him that is athirst come. And whosoever will, let him take the water of life freely.
31099	1189	18	For I testify unto every man that heareth the words of the prophecy of this book, If any man shall add unto these things, God shall add unto him the plagues that are written in this book:
31100	1189	19	And if any man shall take away from the words of the book of this prophecy, God shall take away his part out of the book of life, and out of the holy city, and from the things which are written in this book.
31101	1189	20	He which testifieth these things saith, Surely I come quickly. Amen. Even so, come, Lord Jesus.
31102	1189	21	The grace of our Lord Jesus Christ be with you all. Amen.
31103	1190	1	I, Nephi, having been born of goodly parents, therefore I was taught somewhat in all the learning of my father; and having seen many afflictions in the course of my days, nevertheless, having been highly favored of the Lord in all my days; yea, having had a great knowledge of the goodness and the mysteries of God, therefore I make a record of my proceedings in my days.
31104	1190	2	Yea, I make a record in the language of my father, which consists of the learning of the Jews and the language of the Egyptians.
31105	1190	3	And I know that the record which I make is true; and I make it with mine own hand; and I make it according to my knowledge.
31106	1190	4	For it came to pass in the commencement of the first year of the reign of Zedekiah, king of Judah, (my father, Lehi, having dwelt at Jerusalem in all his days); and in that same year there came many prophets, prophesying unto the people that they must repent, or the great city Jerusalem must be destroyed.
31107	1190	5	Wherefore it came to pass that my father, Lehi, as he went forth prayed unto the Lord, yea, even with all his heart, in behalf of his people.
31108	1190	6	And it came to pass as he prayed unto the Lord, there came a pillar of fire and dwelt upon a rock before him; and he saw and heard much; and because of the things which he saw and heard he did quake and tremble exceedingly.
31109	1190	7	And it came to pass that he returned to his own house at Jerusalem; and he cast himself upon his bed, being overcome with the Spirit and the things which he had seen.
31110	1190	8	And being thus overcome with the Spirit, he was carried away in a vision, even that he saw the heavens open, and he thought he saw God sitting upon his throne, surrounded with numberless concourses of angels in the attitude of singing and praising their God.
31111	1190	9	And it came to pass that he saw One descending out of the midst of heaven, and he beheld that his luster was above that of the sun at noon-day.
31112	1190	10	And he also saw twelve others following him, and their brightness did exceed that of the stars in the firmament.
31113	1190	11	And they came down and went forth upon the face of the earth; and the first came and stood before my father, and gave unto him a book, and bade him that he should read.
31114	1190	12	And it came to pass that as he read, he was filled with the Spirit of the Lord.
31115	1190	13	And he read, saying: Wo, wo, unto Jerusalem, for I have seen thine abominations! Yea, and many things did my father read concerning Jerusalem--that it should be destroyed, and the inhabitants thereof; many should perish by the sword, and many should be carried away captive into Babylon.
31116	1190	14	And it came to pass that when my father had read and seen many great and marvelous things, he did exclaim many things unto the Lord; such as: Great and marvelous are thy works, O Lord God Almighty! Thy throne is high in the heavens, and thy power, and goodness, and mercy are over all the inhabitants of the earth; and, because thou art merciful, thou wilt not suffer those who come unto thee that they shall perish!
31117	1190	15	And after this manner was the language of my father in the praising of his God; for his soul did rejoice, and his whole heart was filled, because of the things which he had seen, yea, which the Lord had shown unto him.
31118	1190	16	And now I, Nephi, do not make a full account of the things which my father hath written, for he hath written many things which he saw in visions and in dreams; and he also hath written many things which he prophesied and spake unto his children, of which I shall not make a full account.
31119	1190	17	But I shall make an account of my proceedings in my days. Behold, I make an abridgment of the record of my father, upon plates which I have made with mine own hands; wherefore, after I have abridged the record of my father then will I make an account of mine own life.
31120	1190	18	Therefore, I would that ye should know, that after the Lord had shown so many marvelous things unto my father, Lehi, yea, concerning the destruction of Jerusalem, behold he went forth among the people, and began to prophesy and to declare unto them concerning the things which he had both seen and heard.
31121	1190	19	And it came to pass that the Jews did mock him because of the things which he testified of them; for he truly testified of their wickedness and their abominations; and he testified that the things which he saw and heard, and also the things which he read in the book, manifested plainly of the coming of a Messiah, and also the redemption of the world.
31122	1190	20	And when the Jews heard these things they were angry with him; yea, even as with the prophets of old, whom they had cast out, and stoned, and slain; and they also sought his life, that they might take it away. But behold, I, Nephi, will show unto you that the tender mercies of the Lord are over all those whom he hath chosen, because of their faith, to make them mighty even unto the power of deliverance.
31123	1191	1	For behold, it came to pass that the Lord spake unto my father, yea, even in a dream, and said unto him: Blessed art thou Lehi, because of the things which thou hast done; and because thou hast been faithful and declared unto this people the things which I commanded thee, behold, they seek to take away thy life.
31124	1191	2	And it came to pass that the Lord commanded my father, even in a dream, that he should take his family and depart into the wilderness.
31125	1191	3	And it came to pass that he was obedient unto the word of the Lord, wherefore he did as the Lord commanded him.
31126	1191	4	And it came to pass that he departed into the wilderness. And he left his house, and the land of his inheritance, and his gold, and his silver, and his precious things, and took nothing with him, save it were his family, and provisions, and tents, and departed into the wilderness.
31127	1191	5	And he came down by the borders near the shore of the Red Sea; and he traveled in the wilderness in the borders which are nearer the Red Sea; and he did travel in the wilderness with his family, which consisted of my mother, Sariah, and my elder brothers, who were Laman, Lemuel, and Sam.
31128	1191	6	And it came to pass that when he had traveled three days in the wilderness, he pitched his tent in a valley by the side of a river of water.
31129	1191	7	And it came to pass that he built an altar of stones, and made an offering unto the Lord, and gave thanks unto the Lord our God.
31130	1191	8	And it came to pass that he called the name of the river, Laman, and it emptied into the Red Sea; and the valley was in the borders near the mouth thereof.
31131	1191	9	And when my father saw that the waters of the river emptied into the fountain of the Red Sea, he spake unto Laman, saying: O that thou mightest be like unto this river, continually running into the fountain of all righteousness!
31132	1191	10	And he also spake unto Lemuel: O that thou mightest be like unto this valley, firm and steadfast, and immovable in keeping the commandments of the Lord!
31133	1191	11	Now this he spake because of the stiffneckedness of Laman and Lemuel; for behold they did murmur in many things against their father, because he was a visionary man, and had led them out of the land of Jerusalem, to leave the land of their inheritance, and their gold, and their silver, and their precious things, to perish in the wilderness. And this they said he had done because of the foolish imaginations of his heart.
31134	1191	12	And thus Laman and Lemuel, being the eldest, did murmur against their father. And they did murmur because they knew not the dealings of that God who had created them.
31135	1191	13	Neither did they believe that Jerusalem, that great city, could be destroyed according to the words of the prophets. And they were like unto the Jews who were at Jerusalem, who sought to take away the life of my father.
31136	1191	14	And it came to pass that my father did speak unto them in the valley of Lemuel, with power, being filled with the Spirit, until their frames did shake before him. And he did confound them, that they durst not utter against him; wherefore, they did as he commanded them.
31137	1191	15	And my father dwelt in a tent.
31138	1191	16	And it came to pass that I, Nephi, being exceedingly young, nevertheless being large in stature, and also having great desires to know of the mysteries of God, wherefore, I did cry unto the Lord; and behold he did visit me, and did soften my heart that I did believe all the words which had been spoken by my father; wherefore, I did not rebel against him like unto my brothers.
31139	1191	17	And I spake unto Sam, making known unto him the things which the Lord had manifested unto me by his Holy Spirit. And it came to pass that he believed in my words.
31140	1191	18	But, behold, Laman and Lemuel would not hearken unto my words; and being grieved because of the hardness of their hearts I cried unto the Lord for them.
31141	1191	19	And it came to pass that the Lord spake unto me, saying: Blessed art thou, Nephi, because of thy faith, for thou hast sought me diligently, with lowliness of heart.
31142	1191	20	And inasmuch as ye shall keep my commandments, ye shall prosper, and shall be led to a land of promise; yea, even a land which I have prepared for you; yea, a land which is choice above all other lands.
31143	1191	21	And inasmuch as thy brethren shall rebel against thee, they shall be cut off from the presence of the Lord.
31144	1191	22	And inasmuch as thou shalt keep my commandments, thou shalt be made a ruler and a teacher over thy brethren.
31145	1191	23	For behold, in that day that they shall rebel against me, I will curse them even with a sore curse, and they shall have no power over thy seed except they shall rebel against me also.
31146	1191	24	And if it so be that they rebel against me, they shall be a scourge unto thy seed, to stir them up in the ways of remembrance.
31147	1192	1	And it came to pass that I, Nephi, returned from speaking with the Lord, to the tent of my father.
31148	1192	2	And it came to pass that he spake unto me, saying: Behold I have dreamed a dream, in the which the Lord hath commanded me that thou and thy brethren shall return to Jerusalem.
31149	1192	3	For behold, Laban hath the record of the Jews and also a genealogy of my forefathers, and they are engraven upon plates of brass.
31150	1192	4	Wherefore, the Lord hath commanded me that thou and thy brothers should go unto the house of Laban, and seek the records, and bring them down hither into the wilderness.
31151	1192	5	And now, behold thy brothers murmur, saying it is a hard thing which I have required of them; but behold I have not required it of them, but it is a commandment of the Lord.
31152	1192	6	Therefore go, my son, and thou shalt be favored of the Lord, because thou hast not murmured.
31153	1192	7	And it came to pass that I, Nephi, said unto my father: I will go and do the things which the Lord hath commanded, for I know that the Lord giveth no commandments unto the children of men, save he shall prepare a way for them that they may accomplish the thing which he commandeth them.
31154	1192	8	And it came to pass that when my father had heard these words he was exceedingly glad, for he knew that I had been blessed of the Lord.
31155	1192	9	And I, Nephi, and my brethren took our journey in the wilderness, with our tents, to go up to the land of Jerusalem.
31156	1192	10	And it came to pass that when we had gone up to the land of Jerusalem, I and my brethren did consult one with another.
31157	1192	11	And we cast lots--who of us should go in unto the house of Laban. And it came to pass that the lot fell upon Laman; and Laman went in unto the house of Laban, and he talked with him as he sat in his house.
31158	1192	12	And he desired of Laban the records which were engraven upon the plates of brass, which contained the genealogy of my father.
31159	1192	13	And behold, it came to pass that Laban was angry, and thrust him out from his presence; and he would not that he should have the records. Wherefore, he said unto him: Behold thou art a robber, and I will slay thee.
31160	1192	14	But Laman fled out of his presence, and told the things which Laban had done, unto us. And we began to be exceedingly sorrowful, and my brethren were about to return unto my father in the wilderness.
31161	1192	15	But behold I said unto them that: As the Lord liveth, and as we live, we will not go down unto our father in the wilderness until we have accomplished the thing which the Lord hath commanded us.
31162	1192	16	Wherefore, let us be faithful in keeping the commandments of the Lord; therefore let us go down to the land of our father's inheritance, for behold he left gold and silver, and all manner of riches. And all this he hath done because of the commandments of the Lord.
31163	1192	17	For he knew that Jerusalem must be destroyed, because of the wickedness of the people.
31164	1192	18	For behold, they have rejected the words of the prophets. Wherefore, if my father should dwell in the land after he hath been commanded to flee out of the land, behold, he would also perish. Wherefore, it must needs be that he flee out of the land.
31165	1192	19	And behold, it is wisdom in God that we should obtain these records, that we may preserve unto our children the language of our fathers;
31166	1192	20	And also that we may preserve unto them the words which have been spoken by the mouth of all the holy prophets, which have been delivered unto them by the Spirit and power of God, since the world began, even down unto this present time.
31167	1192	21	And it came to pass that after this manner of language did I persuade my brethren, that they might be faithful in keeping the commandments of God.
31168	1192	22	And it came to pass that we went down to the land of our inheritance, and we did gather together our gold, and our silver, and our precious things.
31169	1192	23	And after we had gathered these things together, we went up again unto the house of Laban.
31170	1192	24	And it came to pass that we went in unto Laban, and desired him that he would give unto us the records which were engraven upon the plates of brass, for which we would give unto him our gold, and our silver, and all our precious things.
31171	1192	25	And it came to pass that when Laban saw our property, and that it was exceedingly great, he did lust after it, insomuch that he thrust us out, and sent his servants to slay us, that he might obtain our property.
31172	1192	26	And it came to pass that we did flee before the servants of Laban, and we were obliged to leave behind our property, and it fell into the hands of Laban.
31173	1192	27	And it came to pass that we fled into the wilderness, and the servants of Laban did not overtake us, and we hid ourselves in the cavity of a rock.
31174	1192	28	And it came to pass that Laman was angry with me, and also with my father; and also was Lemuel, for he hearkened unto the words of Laman. Wherefore Laman and Lemuel did speak many hard words unto us, their younger brothers, and they did smite us even with a rod.
31175	1192	29	And it came to pass as they smote us with a rod, behold, an angel of the Lord came and stood before them, and he spake unto them, saying: Why do ye smite your younger brother with a rod? Know ye not that the Lord hath chosen him to be a ruler over you, and this because of your iniquities? Behold ye shall go up to Jerusalem again, and the Lord will deliver Laban into your hands.
31176	1192	30	And after the angel had spoken unto us, he departed.
31177	1192	31	And after the angel had departed, Laman and Lemuel again began to murmur, saying: How is it possible that the Lord will deliver Laban into our hands? Behold, he is a mighty man, and he can command fifty, yea, even he can slay fifty; then why not us?
31178	1193	1	And it came to pass that I spake unto my brethren, saying: Let us go up again unto Jerusalem, and let us be faithful in keeping the commandments of the Lord; for behold he is mightier than all the earth, then why not mightier than Laban and his fifty, yea, or even than his tens of thousands?
31179	1193	2	Therefore let us go up; let us be strong like unto Moses; for he truly spake unto the waters of the Red Sea and they divided hither and thither, and our fathers came through, out of captivity, on dry ground, and the armies of Pharaoh did follow and were drowned in the waters of the Red Sea.
31180	1193	3	Now behold ye know that this is true; and ye also know that an angel hath spoken unto you; wherefore can ye doubt? Let us go up; the Lord is able to deliver us, even as our fathers, and to destroy Laban, even as the Egyptians.
31181	1193	4	Now when I had spoken these words, they were yet wroth, and did still continue to murmur; nevertheless they did follow me up until we came without the walls of Jerusalem.
31182	1193	5	And it was by night; and I caused that they should hide themselves without the walls. And after they had hid themselves, I, Nephi, crept into the city and went forth towards the house of Laban.
31183	1193	6	And I was led by the Spirit, not knowing beforehand the things which I should do.
31184	1193	7	Nevertheless I went forth, and as I came near unto the house of Laban I beheld a man, and he had fallen to the earth before me, for he was drunken with wine.
31185	1193	8	And when I came to him I found that it was Laban.
31186	1193	9	And I beheld his sword, and I drew it forth from the sheath thereof; and the hilt thereof was of pure gold, and the workmanship thereof was exceedingly fine, and I saw that the blade thereof was of the most precious steel.
31187	1193	10	And it came to pass that I was constrained by the Spirit that I should kill Laban; but I said in my heart: Never at any time have I shed the blood of man. And I shrunk and would that I might not slay him.
31188	1193	11	And the Spirit said unto me again: Behold the Lord hath delivered him into thy hands. Yea, and I also knew that he had sought to take away mine own life; yea, and he would not hearken unto the commandments of the Lord; and he also had taken away our property.
31189	1193	12	And it came to pass that the Spirit said unto me again: Slay him, for the Lord hath delivered him into thy hands;
31190	1193	13	Behold the Lord slayeth the wicked to bring forth his righteous purposes. It is better that one man should perish than that a nation should dwindle and perish in unbelief.
31191	1193	14	And now, when I, Nephi, had heard these words, I remembered the words of the Lord which he spake unto me in the wilderness, saying that: Inasmuch as thy seed shall keep my commandments, they shall prosper in the land of promise.
31192	1193	15	Yea, and I also thought that they could not keep the commandments of the Lord according to the law of Moses, save they should have the law.
31193	1193	16	And I also knew that the law was engraven upon the plates of brass.
31194	1193	17	And again, I knew that the Lord had delivered Laban into my hands for this cause--that I might obtain the records according to his commandments.
31195	1193	18	Therefore I did obey the voice of the Spirit, and took Laban by the hair of the head, and I smote off his head with his own sword.
31196	1193	19	And after I had smitten off his head with his own sword, I took the garments of Laban and put them upon mine own body; yea, even every whit; and I did gird on his armor about my loins.
31197	1193	20	And after I had done this, I went forth unto the treasury of Laban. And as I went forth towards the treasury of Laban, behold, I saw the servant of Laban who had the keys of the treasury. And I commanded him in the voice of Laban, that he should go with me into the treasury.
31198	1193	21	And he supposed me to be his master, Laban, for he beheld the garments and also the sword girded about my loins.
31199	1193	22	And he spake unto me concerning the elders of the Jews, he knowing that his master, Laban, had been out by night among them.
31200	1193	23	And I spake unto him as if it had been Laban.
31201	1193	24	And I also spake unto him that I should carry the engravings, which were upon the plates of brass, to my elder brethren, who were without the walls.
31202	1193	25	And I also bade him that he should follow me.
31203	1193	26	And he, supposing that I spake of the brethren of the church, and that I was truly that Laban whom I had slain, wherefore he did follow me.
31204	1193	27	And he spake unto me many times concerning the elders of the Jews, as I went forth unto my brethren, who were without the walls.
31205	1193	28	And it came to pass that when Laman saw me he was exceedingly frightened, and also Lemuel and Sam. And they fled from before my presence; for they supposed it was Laban, and that he had slain me and had sought to take away their lives also.
31206	1193	29	And it came to pass that I called after them, and they did hear me; wherefore they did cease to flee from my presence.
31207	1193	30	And it came to pass that when the servant of Laban beheld my brethren he began to tremble, and was about to flee from before me and return to the city of Jerusalem.
31208	1193	31	And now I, Nephi, being a man large in stature, and also having received much strength of the Lord, therefore I did seize upon the servant of Laban, and held him, that he should not flee.
31209	1193	32	And it came to pass that I spake with him, that if he would hearken unto my words, as the Lord liveth, and as I live, even so that if he would hearken unto our words, we would spare his life.
31210	1193	33	And I spake unto him, even with an oath, that he need not fear; that he should be a free man like unto us if he would go down in the wilderness with us.
31211	1193	34	And I also spake unto him, saying: Surely the Lord hath commanded us to do this thing; and shall we not be diligent in keeping the commandments of the Lord? Therefore, if thou wilt go down into the wilderness to my father thou shalt have place with us.
31212	1193	35	And it came to pass that Zoram did take courage at the words which I spake. Now Zoram was the name of the servant; and he promised that he would go down into the wilderness unto our father. Yea, and he also made an oath unto us that he would tarry with us from that time forth.
31213	1193	36	Now we were desirous that he should tarry with us for this cause, that the Jews might not know concerning our flight into the wilderness, lest they should pursue us and destroy us.
31214	1193	37	And it came to pass that when Zoram had made an oath unto us, our fears did cease concerning him.
31215	1193	38	And it came to pass that we took the plates of brass and the servant of Laban, and departed into the wilderness, and journeyed unto the tent of our father.
31216	1194	1	And it came to pass that after we had come down into the wilderness unto our father, behold, he was filled with joy, and also my mother, Sariah, was exceedingly glad, for she truly had mourned because of us.
31217	1194	2	For she had supposed that we had perished in the wilderness; and she also had complained against my father, telling him that he was a visionary man; saying: Behold thou hast led us forth from the land of our inheritance, and my sons are no more, and we perish in the wilderness.
31218	1194	3	And after this manner of language had my mother complained against my father.
31219	1194	4	And it had come to pass that my father spake unto her, saying: I know that I am a visionary man; for if I had not seen the things of God in a vision I should not have known the goodness of God, but had tarried at Jerusalem, and had perished with my brethren.
31220	1194	5	But behold, I have obtained a land of promise, in the which things I do rejoice; yea, and I know that the Lord will deliver my sons out of the hands of Laban, and bring them down again unto us in the wilderness.
31221	1194	6	And after this manner of language did my father, Lehi, comfort my mother, Sariah, concerning us, while we journeyed in the wilderness up to the land of Jerusalem, to obtain the record of the Jews.
31222	1194	7	And when we had returned to the tent of my father, behold their joy was full, and my mother was comforted.
31223	1194	8	And she spake, saying: Now I know of a surety that the Lord hath commanded my husband to flee into the wilderness; yea, and I also know of a surety that the Lord hath protected my sons, and delivered them out of the hands of Laban, and given them power whereby they could accomplish the thing which the Lord hath commanded them. And after this manner of language did she speak.
31224	1194	9	And it came to pass that they did rejoice exceedingly, and did offer sacrifice and burnt offerings unto the Lord; and they gave thanks unto the God of Israel.
31225	1194	10	And after they had given thanks unto the God of Israel, my father, Lehi, took the records which were engraven upon the plates of brass, and he did search them from the beginning.
31226	1194	11	And he beheld that they did contain the five books of Moses, which gave an account of the creation of the world, and also of Adam and Eve, who were our first parents;
31227	1194	12	And also a record of the Jews from the beginning, even down to the commencement of the reign of Zedekiah, king of Judah;
31228	1194	13	And also the prophecies of the holy prophets, from the beginning, even down to the commencement of the reign of Zedekiah; and also many prophecies which have been spoken by the mouth of Jeremiah.
31229	1194	14	And it came to pass that my father, Lehi, also found upon the plates of brass a genealogy of his fathers; wherefore he knew that he was a descendant of Joseph; yea, even that Joseph who was the son of Jacob, who was sold into Egypt, and who was preserved by the hand of the Lord, that he might preserve his father, Jacob, and all his household from perishing with famine.
31230	1194	15	And they were also led out of captivity and out of the land of Egypt, by that same God who had preserved them.
31231	1194	16	And thus my father, Lehi, did discover the genealogy of his fathers. And Laban also was a descendant of Joseph, wherefore he and his fathers had kept the records.
31232	1194	17	And now when my father saw all these things, he was filled with the Spirit, and began to prophesy concerning his seed--
31233	1194	18	That these plates of brass should go forth unto all nations, kindreds, tongues, and people who were of his seed.
31234	1194	19	Wherefore, he said that these plates of brass should never perish; neither should they be dimmed any more by time. And he prophesied many things concerning his seed.
31235	1194	20	And it came to pass that thus far I and my father had kept the commandments wherewith the Lord had commanded us.
31236	1194	21	And we had obtained the records which the Lord had commanded us, and searched them and found that they were desirable; yea, even of great worth unto us, insomuch that we could preserve the commandments of the Lord unto our children.
31237	1194	22	Wherefore, it was wisdom in the Lord that we should carry them with us, as we journeyed in the wilderness towards the land of promise.
31238	1195	1	And now I, Nephi, do not give the genealogy of my fathers in this part of my record; neither at any time shall I give it after upon these plates which I am writing; for it is given in the record which has been kept by my father; wherefore, I do not write it in this work.
31239	1195	2	For it sufficeth me to say that we are descendants of Joseph.
31240	1195	3	And it mattereth not to me that I am particular to give a full account of all the things of my father, for they cannot be written upon these plates, for I desire the room that I may write of the things of God.
31241	1195	4	For the fulness of mine intent is that I may persuade men to come unto the God of Abraham, and the God of Isaac, and the God of Jacob, and be saved.
31242	1195	5	Wherefore, the things which are pleasing unto the world I do not write, but the things which are pleasing unto God and unto those who are not of the world.
31243	1195	6	Wherefore, I shall give commandment unto my seed, that they shall not occupy these plates with things which are not of worth unto the children of men.
31244	1196	1	And now I would that ye might know, that after my father, Lehi, had made an end of prophesying concerning his seed, it came to pass that the Lord spake unto him again, saying that it was not meet for him, Lehi, that he should take his family into the wilderness alone; but that his sons should take daughters to wife, that they might raise up seed unto the Lord in the land of promise.
31245	1196	2	And it came to pass that the Lord commanded him that I, Nephi, and my brethren, should again return unto the land of Jerusalem, and bring down Ishmael and his family into the wilderness.
31246	1196	3	And it came to pass that I, Nephi, did again, with my brethren, go forth into the wilderness to go up to Jerusalem.
31247	1196	4	And it came to pass that we went up unto the house of Ishmael, and we did gain favor in the sight of Ishmael, insomuch that we did speak unto him the words of the Lord.
31248	1196	5	And it came to pass that the Lord did soften the heart of Ishmael, and also his household, insomuch that they took their journey with us down into the wilderness to the tent of our father.
31249	1196	6	And it came to pass that as we journeyed in the wilderness, behold Laman and Lemuel, and two of the daughters of Ishmael, and the two sons of Ishmael and their families, did rebel against us; yea, against me, Nephi, and Sam, and their father, Ishmael, and his wife, and his three other daughters.
31250	1196	7	And it came to pass in the which rebellion, they were desirous to return unto the land of Jerusalem.
31251	1196	8	And now I, Nephi, being grieved for the hardness of their hearts, therefore I spake unto them, saying, yea, even unto Laman and unto Lemuel: Behold ye are mine elder brethren, and how is it that ye are so hard in your hearts, and so blind in your minds, that ye have need that I, your younger brother, should speak unto you, yea, and set an example for you?
31252	1196	9	How is it that ye have not hearkened unto the word of the Lord?
31253	1196	10	How is it that ye have forgotten that ye have seen an angel of the Lord?
31254	1196	11	Yea, and how is it that ye have forgotten what great things the Lord hath done for us, in delivering us out of the hands of Laban, and also that we should obtain the record?
31255	1196	12	Yea, and how is it that ye have forgotten that the Lord is able to do all things according to his will, for the children of men, if it so be that they exercise faith in him? Wherefore, let us be faithful to him.
31256	1196	13	And if it so be that we are faithful to him, we shall obtain the land of promise; and ye shall know at some future period that the word of the Lord shall be fulfilled concerning the destruction of Jerusalem; for all things which the Lord hath spoken concerning the destruction of Jerusalem must be fulfilled.
31257	1196	14	For behold, the Spirit of the Lord ceaseth soon to strive with them; for behold, they have rejected the prophets, and Jeremiah have they cast into prison. And they have sought to take away the life of my father, insomuch that they have driven him out of the land.
31258	1196	15	Now behold, I say unto you that if ye will return unto Jerusalem ye shall also perish with them. And now, if ye have choice, go up to the land, and remember the words which I speak unto you, that if ye go ye will also perish; for thus the Spirit of the Lord constraineth me that I should speak.
31259	1196	16	And it came to pass that when I, Nephi, had spoken these words unto my brethren, they were angry with me. And it came to pass that they did lay their hands upon me, for behold, they were exceedingly wroth, and they did bind me with cords, for they sought to take away my life, that they might leave me in the wilderness to be devoured by wild beasts.
31260	1196	17	But it came to pass that I prayed unto the Lord, saying: O Lord, according to my faith which is in thee, wilt thou deliver me from the hands of my brethren; yea, even give me strength that I may burst these bands with which I am bound.
31261	1196	18	And it came to pass that when I had said these words, behold, the bands were loosed from off my hands and feet, and I stood before my brethren, and I spake unto them again.
31262	1196	19	And it came to pass that they were angry with me again, and sought to lay hands upon me; but behold, one of the daughters of Ishmael, yea, and also her mother, and one of the sons of Ishmael, did plead with my brethren, insomuch that they did soften their hearts; and they did cease striving to take away my life.
31263	1196	20	And it came to pass that they were sorrowful, because of their wickedness, insomuch that they did bow down before me, and did plead with me that I would forgive them of the thing that they had done against me.
31264	1196	21	And it came to pass that I did frankly forgive them all that they had done, and I did exhort them that they would pray unto the Lord their God for forgiveness. And it came to pass that they did so. And after they had done praying unto the Lord we did again travel on our journey towards the tent of our father.
31265	1196	22	And it came to pass that we did come down unto the tent of our father. And after I and my brethren and all the house of Ishmael had come down unto the tent of my father, they did give thanks unto the Lord their God; and they did offer sacrifice and burnt offerings unto him.
31266	1197	1	And it came to pass that we had gathered together all manner of seeds of every kind, both of grain of every kind, and also of the seeds of fruit of every kind.
31267	1197	2	And it came to pass that while my father tarried in the wilderness he spake unto us, saying: Behold, I have dreamed a dream; or, in other words, I have seen a vision.
31268	1197	3	And behold, because of the thing which I have seen, I have reason to rejoice in the Lord because of Nephi and also of Sam; for I have reason to suppose that they, and also many of their seed, will be saved.
31269	1197	4	But behold, Laman and Lemuel, I fear exceedingly because of you; for behold, methought I saw in my dream, a dark and dreary wilderness.
31270	1197	5	And it came to pass that I saw a man, and he was dressed in a white robe; and he came and stood before me.
31271	1197	6	And it came to pass that he spake unto me, and bade me follow him.
31272	1197	7	And it came to pass that as I followed him I beheld myself that I was in a dark and dreary waste.
31273	1197	8	And after I had traveled for the space of many hours in darkness, I began to pray unto the Lord that he would have mercy on me, according to the multitude of his tender mercies.
31274	1197	9	And it came to pass after I had prayed unto the Lord I beheld a large and spacious field.
31275	1197	10	And it came to pass that I beheld a tree, whose fruit was desirable to make one happy.
31276	1197	11	And it came to pass that I did go forth and partake of the fruit thereof; and I beheld that it was most sweet, above all that I ever before tasted. Yea, and I beheld that the fruit thereof was white, to exceed all the whiteness that I had ever seen.
31277	1197	12	And as I partook of the fruit thereof it filled my soul with exceedingly great joy; wherefore, I began to be desirous that my family should partake of it also; for I knew that it was desirable above all other fruit.
31278	1197	13	And as I cast my eyes round about, that perhaps I might discover my family also, I beheld a river of water; and it ran along, and it was near the tree of which I was partaking the fruit.
31279	1197	14	And I looked to behold from whence it came; and I saw the head thereof a little way off; and at the head thereof I beheld your mother Sariah, and Sam, and Nephi; and they stood as if they knew not whither they should go.
31280	1197	15	And it came to pass that I beckoned unto them; and I also did say unto them with a loud voice that they should come unto me, and partake of the fruit, which was desirable above all other fruit.
31281	1197	16	And it came to pass that they did come unto me and partake of the fruit also.
31282	1197	17	And it came to pass that I was desirous that Laman and Lemuel should come and partake of the fruit also; wherefore, I cast mine eyes towards the head of the river, that perhaps I might see them.
31283	1197	18	And it came to pass that I saw them, but they would not come unto me and partake of the fruit.
31284	1197	19	And I beheld a rod of iron, and it extended along the bank of the river, and led to the tree by which I stood.
31285	1197	20	And I also beheld a strait and narrow path, which came along by the rod of iron, even to the tree by which I stood; and it also led by the head of the fountain, unto a large and spacious field, as if it had been a world.
31286	1197	21	And I saw numberless concourses of people, many of whom were pressing forward, that they might obtain the path which led unto the tree by which I stood.
31287	1197	22	And it came to pass that they did come forth, and commence in the path which led to the tree.
31288	1197	23	And it came to pass that there arose a mist of darkness; yea, even an exceedingly great mist of darkness, insomuch that they who had commenced in the path did lose their way, that they wandered off and were lost.
31289	1197	24	And it came to pass that I beheld others pressing forward, and they came forth and caught hold of the end of the rod of iron; and they did press forward through the mist of darkness, clinging to the rod of iron, even until they did come forth and partake of the fruit of the tree.
31290	1197	25	And after they had partaken of the fruit of the tree they did cast their eyes about as if they were ashamed.
31291	1197	26	And I also cast my eyes round about, and beheld, on the other side of the river of water, a great and spacious building; and it stood as it were in the air, high above the earth.
31292	1197	27	And it was filled with people, both old and young, both male and female; and their manner of dress was exceedingly fine; and they were in the attitude of mocking and pointing their fingers towards those who had come at and were partaking of the fruit.
31293	1197	28	And after they had tasted of the fruit they were ashamed, because of those that were scoffing at them; and they fell away into forbidden paths and were lost.
31294	1197	29	And now I, Nephi, do not speak all the words of my father.
31295	1197	30	But, to be short in writing, behold, he saw other multitudes pressing forward; and they came and caught hold of the end of the rod of iron; and they did press their way forward, continually holding fast to the rod of iron, until they came forth and fell down and partook of the fruit of the tree.
31296	1197	31	And he also saw other multitudes feeling their way towards that great and spacious building.
31297	1197	32	And it came to pass that many were drowned in the depths of the fountain; and many were lost from his view, wandering in strange roads.
31298	1197	33	And great was the multitude that did enter into that strange building. And after they did enter into that building they did point the finger of scorn at me and those that were partaking of the fruit also; but we heeded them not.
31299	1197	34	These are the words of my father: For as many as heeded them, had fallen away.
31300	1197	35	And Laman and Lemuel partook not of the fruit, said my father.
31301	1197	36	And it came to pass after my father had spoken all the words of his dream or vision, which were many, he said unto us, because of these things which he saw in a vision, he exceedingly feared for Laman and Lemuel; yea, he feared lest they should be cast off from the presence of the Lord.
31302	1197	37	And he did exhort them then with all the feeling of a tender parent, that they would hearken to his words, that perhaps the Lord would be merciful to them, and not cast them off; yea, my father did preach unto them.
31303	1197	38	And after he had preached unto them, and also prophesied unto them of many things, he bade them to keep the commandments of the Lord; and he did cease speaking unto them.
31304	1198	1	And all these things did my father see, and hear, and speak, as he dwelt in a tent, in the valley of Lemuel, and also a great many more things, which cannot be written upon these plates.
31305	1198	2	And now, as I have spoken concerning these plates, behold they are not the plates upon which I make a full account of the history of my people; for the plates upon which I make a full account of my people I have given the name of Nephi; wherefore, they are called the plates of Nephi, after mine own name; and these plates also are called the plates of Nephi.
31306	1198	3	Nevertheless, I have received a commandment of the Lord that I should make these plates, for the special purpose that there should be an account engraven of the ministry of my people.
31307	1198	4	Upon the other plates should be engraven an account of the reign of the kings, and the wars and contentions of my people; wherefore these plates are for the more part of the ministry; and the other plates are for the more part of the reign of the kings and the wars and contentions of my people.
31308	1198	5	Wherefore, the Lord hath commanded me to make these plates for a wise purpose in him, which purpose I know not.
31309	1198	6	But the Lord knoweth all things from the beginning; wherefore, he prepareth a way to accomplish all his works among the children of men; for behold, he hath all power unto the fulfilling of all his words. And thus it is. Amen.
31310	1199	1	And now I, Nephi, proceed to give an account upon these plates of my proceedings, and my reign and ministry; wherefore, to proceed with mine account, I must speak somewhat of the things of my father, and also of my brethren.
31311	1199	2	For behold, it came to pass after my father had made an end of speaking the words of his dream, and also of exhorting them to all diligence, he spake unto them concerning the Jews--
31312	1199	3	That after they should be destroyed, even that great city Jerusalem, and many be carried away captive into Babylon, according to the own due time of the Lord, they should return again, yea, even be brought back out of captivity; and after they should be brought back out of captivity they should possess again the land of their inheritance.
31313	1199	4	Yea, even six hundred years from the time that my father left Jerusalem, a prophet would the Lord God raise up among the Jews--even a Messiah, or, in other words, a Savior of the world.
31314	1199	5	And he also spake concerning the prophets, how great a number had testified of these things, concerning this Messiah, of whom he had spoken, or this Redeemer of the world.
31315	1199	6	Wherefore, all mankind were in a lost and in a fallen state, and ever would be save they should rely on this Redeemer.
31316	1199	7	And he spake also concerning a prophet who should come before the Messiah, to prepare the way of the Lord--
31317	1199	8	Yea, even he should go forth and cry in the wilderness: Prepare ye the way of the Lord, and make his paths straight; for there standeth one among you whom ye know not; and he is mightier than I, whose shoe's latchet I am not worthy to unloose. And much spake my father concerning this thing.
31318	1199	9	And my father said he should baptize in Bethabara, beyond Jordan; and he also said he should baptize with water; even that he should baptize the Messiah with water.
31319	1199	10	And after he had baptized the Messiah with water, he should behold and bear record that he had baptized the Lamb of God, who should take away the sins of the world.
31320	1199	11	And it came to pass after my father had spoken these words he spake unto my brethren concerning the gospel which should be preached among the Jews, and also concerning the dwindling of the Jews in unbelief. And after they had slain the Messiah, who should come, and after he had been slain he should rise from the dead, and should make himself manifest, by the Holy Ghost, unto the Gentiles.
31321	1199	12	Yea, even my father spake much concerning the Gentiles, and also concerning the house of Israel, that they should be compared like unto an olive-tree, whose branches should be broken off and should be scattered upon all the face of the earth.
31322	1199	13	Wherefore, he said it must needs be that we should be led with one accord into the land of promise, unto the fulfilling of the word of the Lord, that we should be scattered upon all the face of the earth.
31323	1199	14	And after the house of Israel should be scattered they should be gathered together again; or, in fine, after the Gentiles had received the fulness of the Gospel, the natural branches of the olive-tree, or the remnants of the house of Israel, should be grafted in, or come to the knowledge of the true Messiah, their Lord and their Redeemer.
31324	1199	15	And after this manner of language did my father prophesy and speak unto my brethren, and also many more things which I do not write in this book; for I have written as many of them as were expedient for me in mine other book.
31325	1199	16	And all these things, of which I have spoken, were done as my father dwelt in a tent, in the valley of Lemuel.
31326	1199	17	And it came to pass after I, Nephi, having heard all the words of my father, concerning the things which he saw in a vision, and also the things which he spake by the power of the Holy Ghost, which power he received by faith on the Son of God--and the Son of God was the Messiah who should come--I, Nephi, was desirous also that I might see, and hear, and know of these things, by the power of the Holy Ghost, which is the gift of God unto all those who diligently seek him, as well in times of old as in the time that he should manifest himself unto the children of men.
31327	1199	18	For he is the same yesterday, to-day, and forever; and the way is prepared for all men from the foundation of the world, if it so be that they repent and come unto him.
31328	1199	19	For he that diligently seeketh shall find; and the mysteries of God shall be unfolded unto them, by the power of the Holy Ghost, as well in these times as in times of old, and as well in times of old as in times to come; wherefore, the course of the Lord is one eternal round.
31329	1199	20	Therefore remember, O man, for all thy doings thou shalt be brought into judgment.
31330	1199	21	Wherefore, if ye have sought to do wickedly in the days of your probation, then ye are found unclean before the judgment-seat of God; and no unclean thing can dwell with God; wherefore, ye must be cast off forever.
31331	1199	22	And the Holy Ghost giveth authority that I should speak these things, and deny them not.
31332	1200	1	For it came to pass after I had desired to know the things that my father had seen, and believing that the Lord was able to make them known unto me, as I sat pondering in mine heart I was caught away in the Spirit of the Lord, yea, into an exceedingly high mountain, which I never had before seen, and upon which I never had before set my foot.
31333	1200	2	And the Spirit said unto me: Behold, what desirest thou?
31334	1200	3	And I said: I desire to behold the things which my father saw.
31335	1200	4	And the Spirit said unto me: Believest thou that thy father saw the tree of which he hath spoken?
31336	1200	5	And I said: Yea, thou knowest that I believe all the words of my father.
31337	1200	6	And when I had spoken these words, the Spirit cried with a loud voice, saying: Hosanna to the Lord, the most high God; for he is God over all the earth, yea, even above all. And blessed art thou, Nephi, because thou believest in the Son of the most high God; wherefore, thou shalt behold the things which thou hast desired.
31338	1200	7	And behold this thing shall be given unto thee for a sign, that after thou hast beheld the tree which bore the fruit which thy father tasted, thou shalt also behold a man descending out of heaven, and him shall ye witness; and after ye have witnessed him ye shall bear record that it is the Son of God.
31339	1200	8	And it came to pass that the Spirit said unto me: Look! And I looked and beheld a tree; and it was like unto the tree which my father had seen; and the beauty thereof was far beyond, yea, exceeding of all beauty; and the whiteness thereof did exceed the whiteness of the driven snow.
31340	1200	9	And it came to pass after I had seen the tree, I said unto the Spirit: I behold thou hast shown unto me the tree which is precious above all.
31341	1200	10	And he said unto me: What desirest thou?
31342	1200	11	And I said unto him: To know the interpretation thereof--for I spake unto him as a man speaketh; for I beheld that he was in the form of a man; yet nevertheless, I knew that it was the Spirit of the Lord; and he spake unto me as a man speaketh with another.
31343	1200	12	And it came to pass that he said unto me: Look! And I looked as if to look upon him, and I saw him not; for he had gone from before my presence.
31344	1200	13	And it came to pass that I looked and beheld the great city of Jerusalem, and also other cities. And I beheld the city of Nazareth; and in the city of Nazareth I beheld a virgin, and she was exceedingly fair and white.
31345	1200	14	And it came to pass that I saw the heavens open; and an angel came down and stood before me; and he said unto me: Nephi, what beholdest thou?
31346	1200	15	And I said unto him: A virgin, most beautiful and fair above all other virgins.
31347	1200	16	And he said unto me: Knowest thou the condescension of God?
31348	1200	17	And I said unto him: I know that he loveth his children; nevertheless, I do not know the meaning of all things.
31349	1200	18	And he said unto me: Behold, the virgin whom thou seest is the mother of the Son of God, after the manner of the flesh.
31350	1200	19	And it came to pass that I beheld that she was carried away in the Spirit; and after she had been carried away in the Spirit for the space of a time the angel spake unto me, saying: Look!
31351	1200	20	And I looked and beheld the virgin again, bearing a child in her arms.
31352	1200	21	And the angel said unto me: Behold the Lamb of God, yea, even the Son of the Eternal Father! Knowest thou the meaning of the tree which thy father saw?
31353	1200	22	And I answered him, saying: Yea, it is the love of God, which sheddeth itself abroad in the hearts of the children of men; wherefore, it is the most desirable above all things.
31354	1200	23	And he spake unto me, saying: Yea, and the most joyous to the soul.
31355	1200	24	And after he had said these words, he said unto me: Look! And I looked, and I beheld the Son of God going forth among the children of men; and I saw many fall down at his feet and worship him.
31356	1200	25	And it came to pass that I beheld that the rod of iron, which my father had seen, was the word of God, which led to the fountain of living waters, or to the tree of life; which waters are a representation of the love of God; and I also beheld that the tree of life was a representation of the love of God.
31357	1200	26	And the angel said unto me again: Look and behold the condescension of God!
31358	1200	27	And I looked and beheld the Redeemer of the world, of whom my father had spoken; and I also beheld the prophet who should prepare the way before him. And the Lamb of God went forth and was baptized of him; and after he was baptized, I beheld the heavens open, and the Holy Ghost come down out of heaven and abide upon him in the form of a dove.
31359	1200	28	And I beheld that he went forth ministering unto the people, in power and great glory; and the multitudes were gathered together to hear him; and I beheld that they cast him out from among them.
31360	1200	29	And I also beheld twelve others following him. And it came to pass that they were carried away in the Spirit from before my face, and I saw them not.
31361	1200	30	And it came to pass that the angel spake unto me again, saying: Look! And I looked, and I beheld the heavens open again, and I saw angels descending upon the children of men; and they did minister unto them.
31362	1200	31	And he spake unto me again, saying: Look! And I looked, and I beheld the Lamb of God going forth among the children of men. And I beheld multitudes of people who were sick, and who were afflicted with all manner of diseases, and with devils and unclean spirits; and the angel spake and showed all these things unto me. And they were healed by the power of the Lamb of God; and the devils and the unclean spirits were cast out.
31363	1200	32	And it came to pass that the angel spake unto me again, saying: Look! And I looked and beheld the Lamb of God, that he was taken by the people; yea, the Son of the everlasting God was judged of the world; and I saw and bear record.
31364	1200	33	And I, Nephi, saw that he was lifted up upon the cross and slain for the sins of the world.
31365	1200	34	And after he was slain I saw the multitudes of the earth, that they were gathered together to fight against the apostles of the Lamb; for thus were the twelve called by the angel of the Lord.
31366	1200	35	And the multitude of the earth was gathered together; and I beheld that they were in a large and spacious building, like unto the building which my father saw. And the angel of the Lord spake unto me again, saying: Behold the world and the wisdom thereof; yea, behold the house of Israel hath gathered together to fight against the twelve apostles of the Lamb.
31367	1200	36	And it came to pass that I saw and bear record, that the great and spacious building was the pride of the world; and it fell, and the fall thereof was exceedingly great. And the angel of the Lord spake unto me again, saying: Thus shall be the destruction of all nations, kindreds, tongues, and people, that shall fight against the twelve apostles of the Lamb.
31368	1201	1	And it came to pass that the angel said unto me: Look, and behold thy seed, and also the seed of thy brethren. And I looked and beheld the land of promise; and I beheld multitudes of people, yea, even as it were in number as many as the sand of the sea.
31369	1201	2	And it came to pass that I beheld multitudes gathered together to battle, one against the other; and I beheld wars, and rumors of wars, and great slaughters with the sword among my people.
31370	1201	3	And it came to pass that I beheld many generations pass away, after the manner of wars and contentions in the land; and I beheld many cities, yea, even that I did not number them.
31371	1201	4	And it came to pass that I saw a mist of darkness on the face of the land of promise; and I saw lightnings, and I heard thunderings, and earthquakes, and all manner of tumultuous noises; and I saw the earth and the rocks, that they rent; and I saw mountains tumbling into pieces; and I saw the plains of the earth, that they were broken up; and I saw many cities that they were sunk; and I saw many that they were burned with fire; and I saw many that did tumble to the earth, because of the quaking thereof.
31372	1201	5	And it came to pass after I saw these things, I saw the vapor of darkness, that it passed from off the face of the earth; and behold, I saw multitudes who had not fallen because of the great and terrible judgments of the Lord.
31373	1201	6	And I saw the heavens open, and the Lamb of God descending out of heaven; and he came down and showed himself unto them.
31374	1201	7	And I also saw and bear record that the Holy Ghost fell upon twelve others; and they were ordained of God, and chosen.
31375	1201	8	And the angel spake unto me, saying: Behold the twelve disciples of the Lamb, who are chosen to minister unto thy seed.
31376	1201	9	And he said unto me: Thou rememberest the twelve apostles of the Lamb? Behold they are they who shall judge the twelve tribes of Israel; wherefore, the twelve ministers of thy seed shall be judged of them; for ye are of the house of Israel.
31377	1201	10	And these twelve ministers whom thou beholdest shall judge thy seed. And, behold, they are righteous forever; for because of their faith in the Lamb of God their garments are made white in his blood.
31378	1201	11	And the angel said unto me: Look! And I looked, and beheld three generations pass away in righteousness; and their garments were white even like unto the Lamb of God. And the angel said unto me: These are made white in the blood of the Lamb, because of their faith in him.
31379	1201	12	And I, Nephi, also saw many of the fourth generation who passed away in righteousness.
31380	1201	13	And it came to pass that I saw the multitudes of the earth gathered together.
31381	1201	14	And the angel said unto me: Behold thy seed, and also the seed of thy brethren.
31382	1201	15	And it came to pass that I looked and beheld the people of my seed gathered together in multitudes against the seed of my brethren; and they were gathered together to battle.
31383	1201	16	And the angel spake unto me, saying: Behold the fountain of filthy water which thy father saw; yea, even the river of which he spake; and the depths thereof are the depths of hell.
31384	1201	17	And the mists of darkness are the temptations of the devil, which blindeth the eyes, and hardeneth the hearts of the children of men, and leadeth them away into broad roads, that they perish and are lost.
31385	1201	18	And the large and spacious building, which thy father saw, is vain imaginations and the pride of the children of men. And a great and a terrible gulf divideth them; yea, even the word of the justice of the Eternal God, and the Messiah who is the Lamb of God, of whom the Holy Ghost beareth record, from the beginning of the world until this time, and from this time henceforth and forever.
31386	1201	19	And while the angel spake these words, I beheld and saw that the seed of my brethren did contend against my seed, according to the word of the angel; and because of the pride of my seed, and the temptations of the devil, I beheld that the seed of my brethren did overpower the people of my seed.
31387	1201	20	And it came to pass that I beheld, and saw the people of the seed of my brethren that they had overcome my seed; and they went forth in multitudes upon the face of the land.
31388	1201	21	And I saw them gathered together in multitudes; and I saw wars and rumors of wars among them; and in wars and rumors of wars I saw many generations pass away.
31389	1201	22	And the angel said unto me: Behold these shall dwindle in unbelief.
31390	1201	23	And it came to pass that I beheld, after they had dwindled in unbelief they became a dark, and loathsome, and a filthy people, full of idleness and all manner of abominations.
31391	1202	1	And it came to pass that the angel spake unto me, saying: Look! And I looked and beheld many nations and kingdoms.
31392	1202	2	And the angel said unto me: What beholdest thou? And I said: I behold many nations and kingdoms.
31393	1202	3	And he said unto me: These are the nations and kingdoms of the Gentiles.
31394	1202	4	And it came to pass that I saw among the nations of the Gentiles the formation of a great church.
31395	1202	5	And the angel said unto me: Behold the formation of a church which is most abominable above all other churches, which slayeth the saints of God, yea, and tortureth them and bindeth them down, and yoketh them with a yoke of iron, and bringeth them down into captivity.
31396	1202	6	And it came to pass that I beheld this great and abominable church; and I saw the devil that he was the founder of it.
31397	1202	7	And I also saw gold, and silver, and silks, and scarlets, and fine-twined linen, and all manner of precious clothing; and I saw many harlots.
31398	1202	8	And the angel spake unto me, saying: Behold the gold, and the silver, and the silks, and the scarlets, and the fine-twined linen, and the precious clothing, and the harlots, are the desires of this great and abominable church.
31399	1202	9	And also for the praise of the world do they destroy the saints of God, and bring them down into captivity.
31400	1202	10	And it came to pass that I looked and beheld many waters; and they divided the Gentiles from the seed of my brethren.
31401	1202	11	And it came to pass that the angel said unto me: Behold the wrath of God is upon the seed of thy brethren.
31402	1202	12	And I looked and beheld a man among the Gentiles, who was separated from the seed of my brethren by the many waters; and I beheld the Spirit of God, that it came down and wrought upon the man; and he went forth upon the many waters, even unto the seed of my brethren, who were in the promised land.
31403	1202	13	And it came to pass that I beheld the Spirit of God, that it wrought upon other Gentiles; and they went forth out of captivity, upon the many waters.
31404	1202	14	And it came to pass that I beheld many multitudes of the Gentiles upon the land of promise; and I beheld the wrath of God, that it was upon the seed of my brethren; and they were scattered before the Gentiles and were smitten.
31405	1202	15	And I beheld the Spirit of the Lord, that it was upon the Gentiles, and they did prosper and obtain the land for their inheritance; and I beheld that they were white, and exceedingly fair and beautiful, like unto my people before they were slain.
31406	1202	16	And it came to pass that I, Nephi, beheld that the Gentiles who had gone forth out of captivity did humble themselves before the Lord; and the power of the Lord was with them.
31407	1202	17	And I beheld that their mother Gentiles were gathered together upon the waters, and upon the land also, to battle against them.
31408	1202	18	And I beheld that the power of God was with them, and also that the wrath of God was upon all those that were gathered together against them to battle.
31409	1202	19	And I, Nephi, beheld that the Gentiles that had gone out of captivity were delivered by the power of God out of the hands of all other nations.
31410	1202	20	And it came to pass that I, Nephi, beheld that they did prosper in the land; and I beheld a book, and it was carried forth among them.
31411	1202	21	And the angel said unto me: Knowest thou the meaning of the book?
31412	1202	22	And I said unto him: I know not.
31413	1202	23	And he said: Behold it proceedeth out of the mouth of a Jew. And I, Nephi, beheld it; and he said unto me: The book that thou beholdest is a record of the Jews, which contains the covenants of the Lord, which he hath made unto the house of Israel; and it also containeth many of the prophecies of the holy prophets; and it is a record like unto the engravings which are upon the plates of brass, save there are not so many; nevertheless, they contain the covenants of the Lord, which he hath made unto the house of Israel; wherefore, they are of great worth unto the Gentiles.
31414	1202	24	And the angel of the Lord said unto me: Thou hast beheld that the book proceeded forth from the mouth of a Jew; and when it proceeded forth from the mouth of a Jew it contained the fulness of the gospel of the Lord, of whom the twelve apostles bear record; and they bear record according to the truth which is in the Lamb of God.
31415	1202	25	Wherefore, these things go forth from the Jews in purity unto the Gentiles, according to the truth which is in God.
31416	1202	26	And after they go forth by the hand of the twelve apostles of the Lamb, from the Jews unto the Gentiles, thou seest the formation of that great and abominable church, which is most abominable above all other churches; for behold, they have taken away from the gospel of the Lamb many parts which are plain and most precious; and also many covenants of the Lord have they taken away.
31417	1202	27	And all this have they done that they might pervert the right ways of the Lord, that they might blind the eyes and harden the hearts of the children of men.
31418	1202	28	Wherefore, thou seest that after the book hath gone forth through the hands of the great and abominable church, that there are many plain and precious things taken away from the book, which is the book of the Lamb of God.
31419	1202	29	And after these plain and precious things were taken away it goeth forth unto all the nations of the Gentiles; and after it goeth forth unto all the nations of the Gentiles, yea, even across the many waters which thou hast seen with the Gentiles which have gone forth out of captivity, thou seest--because of the many plain and precious things which have been taken out of the book, which were plain unto the understanding of the children of men, according to the plainness which is in the Lamb of God--because of these things which are taken away out of the gospel of the Lamb, an exceedingly great many do stumble, yea, insomuch that Satan hath great power over them.
31420	1202	30	Nevertheless, thou beholdest that the Gentiles who have gone forth out of captivity, and have been lifted up by the power of God above all other nations, upon the face of the land which is choice above all other lands, which is the land that the Lord God hath covenanted with thy father that his seed should have for the land of their inheritance; wherefore, thou seest that the Lord God will not suffer that the Gentiles will utterly destroy the mixture of thy seed, which are among thy brethren.
31421	1202	31	Neither will he suffer that the Gentiles shall destroy the seed of thy brethren.
31422	1202	32	Neither will the Lord God suffer that the Gentiles shall forever remain in that awful state of blindness, which thou beholdest they are in, because of the plain and most precious parts of the gospel of the Lamb which have been kept back by that abominable church, whose formation thou hast seen.
31423	1202	33	Wherefore saith the Lamb of God: I will be merciful unto the Gentiles, unto the visiting of the remnant of the house of Israel in great judgment.
31424	1202	34	And it came to pass that the angel of the Lord spake unto me, saying: Behold, saith the Lamb of God, after I have visited the remnant of the house of Israel--and this remnant of whom I speak is the seed of thy father--wherefore, after I have visited them in judgment, and smitten them by the hand of the Gentiles, and after the Gentiles do stumble exceedingly, because of the most plain and precious parts of the gospel of the Lamb which have been kept back by that abominable church, which is the mother of harlots, saith the Lamb--I will be merciful unto the Gentiles in that day, insomuch that I will bring forth unto them, in mine own power, much of my gospel, which shall be plain and precious, saith the Lamb.
31425	1202	35	For, behold, saith the Lamb: I will manifest myself unto thy seed, that they shall write many things which I shall minister unto them, which shall be plain and precious; and after thy seed shall be destroyed, and dwindle in unbelief, and also the seed of thy brethren, behold, these things shall be hid up, to come forth unto the Gentiles, by the gift and power of the Lamb.
31426	1202	36	And in them shall be written my gospel, saith the Lamb, and my rock and my salvation.
31427	1202	37	And blessed are they who shall seek to bring forth my Zion at that day, for they shall have the gift and the power of the Holy Ghost; and if they endure unto the end they shall be lifted up at the last day, and shall be saved in the everlasting kingdom of the Lamb; and whoso shall publish peace, yea, tidings of great joy, how beautiful upon the mountains shall they be.
31428	1202	38	And it came to pass that I beheld the remnant of the seed of my brethren, and also the book of the Lamb of God, which had proceeded forth from the mouth of the Jew, that it came forth from the Gentiles unto the remnant of the seed of my brethren.
31429	1202	39	And after it had come forth unto them I beheld other books, which came forth by the power of the Lamb, from the Gentiles unto them, unto the convincing of the Gentiles and the remnant of the seed of my brethren, and also the Jews who were scattered upon all the face of the earth, that the records of the prophets and of the twelve apostles of the Lamb are true.
31430	1202	40	And the angel spake unto me, saying: These last records, which thou hast seen among the Gentiles, shall establish the truth of the first, which are of the twelve apostles of the Lamb, and shall make known the plain and precious things which have been taken away from them; and shall make known to all kindreds, tongues, and people, that the Lamb of God is the Son of the Eternal Father, and the Savior of the world; and that all men must come unto him, or they cannot be saved.
31431	1202	41	And they must come according to the words which shall be established by the mouth of the Lamb; and the words of the Lamb shall be made known in the records of thy seed, as well as in the records of the twelve apostles of the Lamb; wherefore they both shall be established in one; for there is one God and one Shepherd over all the earth.
31432	1202	42	And the time cometh that he shall manifest himself unto all nations, both unto the Jews and also unto the Gentiles; and after he has manifested himself unto the Jews and also unto the Gentiles, then he shall manifest himself unto the Gentiles and also unto the Jews, and the last shall be first, and the first shall be last.
31433	1203	1	And it shall come to pass, that if the Gentiles shall hearken unto the Lamb of God in that day that he shall manifest himself unto them in word, and also in power, in very deed, unto the taking away of their stumbling blocks--
31434	1203	2	And harden not their hearts against the Lamb of God, they shall be numbered among the seed of thy father; yea, they shall be numbered among the house of Israel; and they shall be a blessed people upon the promised land forever; they shall be no more brought down into captivity; and the house of Israel shall no more be confounded.
31435	1203	3	And that great pit, which hath been digged for them by that great and abominable church, which was founded by the devil and his children, that he might lead away the souls of men down to hell--yea, that great pit which hath been digged for the destruction of men shall be filled by those who digged it, unto their utter destruction, saith the Lamb of God; not the destruction of the soul, save it be the casting of it into that hell which hath no end.
31436	1203	4	For behold, this is according to the captivity of the devil, and also according to the justice of God, upon all those who will work wickedness and abomination before him.
31437	1203	5	And it came to pass that the angel spake unto me, Nephi, saying: Thou hast beheld that if the Gentiles repent it shall be well with them; and thou also knowest concerning the covenants of the Lord unto the house of Israel; and thou also hast heard that whoso repenteth not must perish.
31438	1203	6	Therefore, wo be unto the Gentiles if it so be that they harden their hearts against the Lamb of God.
31439	1203	7	For the time cometh, saith the Lamb of God, that I will work a great and a marvelous work among the children of men; a work which shall be everlasting, either on the one hand or on the other--either to the convincing of them unto peace and life eternal, or unto the deliverance of them to the hardness of their hearts and the blindness of their minds unto their being brought down into captivity, and also into destruction, both temporally and spiritually, according to the captivity of the devil, of which I have spoken.
31440	1203	8	And it came to pass that when the angel had spoken these words, he said unto me: Rememberest thou the covenants of the Father unto the house of Israel? I said unto him, Yea.
31441	1203	9	And it came to pass that he said unto me: Look, and behold that great and abominable church, which is the mother of abominations, whose founder is the devil.
31442	1203	10	And he said unto me: Behold there are save two churches only; the one is the church of the Lamb of God, and the other is the church of the devil; wherefore, whoso belongeth not to the church of the Lamb of God belongeth to that great church, which is the mother of abominations; and she is the whore of all the earth.
31443	1203	11	And it came to pass that I looked and beheld the whore of all the earth, and she sat upon many waters; and she had dominion over all the earth, among all nations, kindreds, tongues, and people.
31444	1203	12	And it came to pass that I beheld the church of the Lamb of God, and its numbers were few, because of the wickedness and abominations of the whore who sat upon many waters; nevertheless, I beheld that the church of the Lamb, who were the saints of God, were also upon all the face of the earth; and their dominions upon the face of the earth were small, because of the wickedness of the great whore whom I saw.
31445	1203	13	And it came to pass that I beheld that the great mother of abominations did gather together multitudes upon the face of all the earth, among all the nations of the Gentiles, to fight against the Lamb of God.
31446	1203	14	And it came to pass that I, Nephi, beheld the power of the Lamb of God, that it descended upon the saints of the church of the Lamb, and upon the covenant people of the Lord, who were scattered upon all the face of the earth; and they were armed with righteousness and with the power of God in great glory.
31447	1203	15	And it came to pass that I beheld that the wrath of God was poured out upon that great and abominable church, insomuch that there were wars and rumors of wars among all the nations and kindreds of the earth.
31448	1203	16	And as there began to be wars and rumors of wars among all the nations which belonged to the mother of abominations, the angel spake unto me, saying: Behold, the wrath of God is upon the mother of harlots; and behold, thou seest all these things--
31449	1203	17	And when the day cometh that the wrath of God is poured out upon the mother of harlots, which is the great and abominable church of all the earth, whose founder is the devil, then, at that day, the work of the Father shall commence, in preparing the way for the fulfilling of his covenants, which he hath made to his people who are of the house of Israel.
31450	1203	18	And it came to pass that the angel spake unto me, saying: Look!
31451	1203	19	And I looked and beheld a man, and he was dressed in a white robe.
31452	1203	20	And the angel said unto me: Behold one of the twelve apostles of the Lamb.
31453	1203	21	Behold, he shall see and write the remainder of these things; yea, and also many things which have been.
31454	1203	22	And he shall also write concerning the end of the world.
31455	1203	23	Wherefore, the things which he shall write are just and true; and behold they are written in the book which thou beheld proceeding out of the mouth of the Jew; and at the time they proceeded out of the mouth of the Jew, or, at the time the book proceeded out of the mouth of the Jew, the things which were written were plain and pure, and most precious and easy to the understanding of all men.
31456	1203	24	And behold, the things which this apostle of the Lamb shall write are many things which thou hast seen; and behold, the remainder shalt thou see.
31457	1203	25	But the things which thou shalt see hereafter thou shalt not write; for the Lord God hath ordained the apostle of the Lamb of God that he should write them.
31458	1203	26	And also others who have been, to them hath he shown all things, and they have written them; and they are sealed up to come forth in their purity, according to the truth which is in the Lamb, in the own due time of the Lord, unto the house of Israel.
31459	1203	27	And I, Nephi, heard and bear record, that the name of the apostle of the Lamb was John, according to the word of the angel.
31460	1203	28	And behold, I, Nephi, am forbidden that I should write the remainder of the things which I saw and heard; wherefore the things which I have written sufficeth me; and I have written but a small part of the things which I saw.
31461	1203	29	And I bear record that I saw the things which my father saw, and the angel of the Lord did make them known unto me.
31462	1203	30	And now I make an end of speaking concerning the things which I saw while I was carried away in the spirit; and if all the things which I saw are not written, the things which I have written are true. And thus it is. Amen.
31463	1204	1	And it came to pass that after I, Nephi, had been carried away in the spirit, and seen all these things, I returned to the tent of my father.
31464	1204	2	And it came to pass that I beheld my brethren, and they were disputing one with another concerning the things which my father had spoken unto them.
31465	1204	3	For he truly spake many great things unto them, which were hard to be understood, save a man should inquire of the Lord; and they being hard in their hearts, therefore they did not look unto the Lord as they ought.
31466	1204	4	And now I, Nephi, was grieved because of the hardness of their hearts, and also, because of the things which I had seen, and knew they must unavoidably come to pass because of the great wickedness of the children of men.
31467	1204	5	And it came to pass that I was overcome because of my afflictions, for I considered that mine afflictions were great above all, because of the destruction of my people, for I had beheld their fall.
31468	1204	6	And it came to pass that after I had received strength I spake unto my brethren, desiring to know of them the cause of their disputations.
31469	1204	7	And they said: Behold, we cannot understand the words which our father hath spoken concerning the natural branches of the olive-tree, and also concerning the Gentiles.
31470	1204	8	And I said unto them: Have ye inquired of the Lord?
31471	1204	9	And they said unto me: We have not; for the Lord maketh no such thing known unto us.
31472	1204	10	Behold, I said unto them: How is it that ye do not keep the commandments of the Lord? How is it that ye will perish, because of the hardness of your hearts?
31473	1204	11	Do ye not remember the things which the Lord hath said?--If ye will not harden your hearts, and ask me in faith, believing that ye shall receive, with diligence in keeping my commandments, surely these things shall be made known unto you.
31474	1204	12	Behold, I say unto you, that the house of Israel was compared unto an olive-tree, by the Spirit of the Lord which was in our father; and behold are we not broken off from the house of Israel, and are we not a branch of the house of Israel?
31475	1204	13	And now, the thing which our father meaneth concerning the grafting in of the natural branches through the fulness of the Gentiles, is, that in the latter days, when our seed shall have dwindled in unbelief, yea, for the space of many years, and many generations after the Messiah shall be manifested in body unto the children of men, then shall the fulness of the gospel of the Messiah come unto the Gentiles, and from the Gentiles unto the remnant of our seed--
31476	1204	14	And at that day shall the remnant of our seed know that they are of the house of Israel, and that they are the covenant people of the Lord; and then shall they know and come to the knowledge of their forefathers, and also to the knowledge of the gospel of their Redeemer, which was ministered unto their fathers by him; wherefore, they shall come to the knowledge of their Redeemer and the very points of his doctrine, that they may know how to come unto him and be saved.
31477	1204	15	And then at that day will they not rejoice and give praise unto their everlasting God, their rock and their salvation? Yea, at that day, will they not receive the strength and nourishment from the true vine? Yea, will they not come unto the true fold of God?
31478	1204	16	Behold, I say unto you, Yea; they shall be remembered again among the house of Israel; they shall be grafted in, being a natural branch of the olive-tree, into the true olive-tree.
31479	1204	17	And this is what our father meaneth; and he meaneth that it will not come to pass until after they are scattered by the Gentiles; and he meaneth that it shall come by way of the Gentiles, that the Lord may show his power unto the Gentiles, for the very cause that he shall be rejected of the Jews, or of the house of Israel.
31480	1204	18	Wherefore, our father hath not spoken of our seed alone, but also of all the house of Israel, pointing to the covenant which should be fulfilled in the latter days; which covenant the Lord made to our father Abraham, saying: In thy seed shall all the kindreds of the earth be blessed.
31481	1204	19	And it came to pass that I, Nephi, spake much unto them concerning these things; yea, I spake unto them concerning the restoration of the Jews in the latter days.
31482	1204	20	And I did rehearse unto them the words of Isaiah, who spake concerning the restoration of the Jews, or of the house of Israel; and after they were restored they should no more be confounded, neither should they be scattered again. And it came to pass that I did speak many words unto my brethren, that they were pacified and did humble themselves before the Lord.
31483	1204	21	And it came to pass that they did speak unto me again, saying: What meaneth this thing which our father saw in a dream? What meaneth the tree which he saw?
31484	1204	22	And I said unto them: It was a representation of the tree of life.
31485	1204	23	And they said unto me: What meaneth the rod of iron which our father saw, that led to the tree?
31486	1204	24	And I said unto them that it was the word of God; and whoso would hearken unto the word of God, and would hold fast unto it, they would never perish; neither could the temptations and the fiery darts of the adversary overpower them unto blindness, to lead them away to destruction.
31487	1204	25	Wherefore, I, Nephi, did exhort them to give heed unto the word of the Lord; yea, I did exhort them with all the energies of my soul, and with all the faculty which I possessed, that they would give heed to the word of God and remember to keep his commandments always in all things.
31488	1204	26	And they said unto me: What meaneth the river of water which our father saw?
31489	1204	27	And I said unto them that the water which my father saw was filthiness; and so much was his mind swallowed up in other things that he beheld not the filthiness of the water.
31490	1204	28	And I said unto them that it was an awful gulf, which separated the wicked from the tree of life, and also from the saints of God.
31491	1204	29	And I said unto them that it was a representation of that awful hell, which the angel said unto me was prepared for the wicked.
31492	1204	30	And I said unto them that our father also saw that the justice of God did also divide the wicked from the righteous; and the brightness thereof was like unto the brightness of a flaming fire, which ascendeth up unto God forever and ever, and hath no end.
31493	1204	31	And they said unto me: Doth this thing mean the torment of the body in the days of probation, or doth it mean the final state of the soul after the death of the temporal body, or doth it speak of the things which are temporal?
31494	1204	32	And it came to pass that I said unto them that it was a representation of things both temporal and spiritual; for the day should come that they must be judged of their works, yea, even the works which were done by the temporal body in their days of probation.
31495	1204	33	Wherefore, if they should die in their wickedness they must be cast off also, as to the things which are spiritual, which are pertaining to righteousness; wherefore, they must be brought to stand before God, to be judged of their works; and if their works have been filthiness they must needs be filthy; and if they be filthy it must needs be that they cannot dwell in the kingdom of God; if so, the kingdom of God must be filthy also.
31496	1204	34	But behold, I say unto you, the kingdom of God is not filthy, and there cannot any unclean thing enter into the kingdom of God; wherefore there must needs be a place of filthiness prepared for that which is filthy.
31497	1204	35	And there is a place prepared, yea, even that awful hell of which I have spoken, and the devil is the preparator of it; wherefore the final state of the souls of men is to dwell in the kingdom of God, or to be cast out because of that justice of which I have spoken.
31498	1204	36	Wherefore, the wicked are rejected from the righteous, and also from that tree of life, whose fruit is most precious and most desirable above all other fruits; yea, and it is the greatest of all the gifts of God. And thus I spake unto my brethren. Amen.
31499	1205	1	And now it came to pass that after I, Nephi, had made an end of speaking to my brethren, behold they said unto me: Thou hast declared unto us hard things, more than we are able to bear.
31500	1205	2	And it came to pass that I said unto them that I knew that I had spoken hard things against the wicked, according to the truth; and the righteous have I justified, and testified that they should be lifted up at the last day; wherefore, the guilty taketh the truth to be hard, for it cutteth them to the very center.
31501	1205	3	And now my brethren, if ye were righteous and were willing to hearken to the truth, and give heed unto it, that ye might walk uprightly before God, then ye would not murmur because of the truth, and say: Thou speakest hard things against us.
31502	1205	4	And it came to pass that I, Nephi, did exhort my brethren, with all diligence, to keep the commandments of the Lord.
31503	1205	5	And it came to pass that they did humble themselves before the Lord; insomuch that I had joy and great hopes of them, that they would walk in the paths of righteousness.
31504	1205	6	Now, all these things were said and done as my father dwelt in a tent in the valley which he called Lemuel.
31505	1205	7	And it came to pass that I, Nephi, took one of the daughters of Ishmael to wife; and also, my brethren took of the daughters of Ishmael to wife; and also Zoram took the eldest daughter of Ishmael to wife.
31506	1205	8	And thus my father had fulfilled all the commandments of the Lord which had been given unto him. And also, I, Nephi, had been blessed of the Lord exceedingly.
31507	1205	9	And it came to pass that the voice of the Lord spake unto my father by night, and commanded him that on the morrow he should take his journey into the wilderness.
31508	1205	10	And it came to pass that as my father arose in the morning, and went forth to the tent door, to his great astonishment he beheld upon the ground a round ball of curious workmanship; and it was of fine brass. And within the ball were two spindles; and the one pointed the way whither we should go into the wilderness.
31509	1205	11	And it came to pass that we did gather together whatsoever things we should carry into the wilderness, and all the remainder of our provisions which the Lord had given unto us; and we did take seed of every kind that we might carry into the wilderness.
31510	1205	12	And it came to pass that we did take our tents and depart into the wilderness, across the river Laman.
31511	1205	13	And it came to pass that we traveled for the space of four days, nearly a south-southeast direction, and we did pitch our tents again; and we did call the name of the place Shazer.
31512	1205	14	And it came to pass that we did take our bows and our arrows, and go forth into the wilderness to slay food for our families; and after we had slain food for our families we did return again to our families in the wilderness, to the place of Shazer. And we did go forth again in the wilderness, following the same direction, keeping in the most fertile parts of the wilderness, which were in the borders near the Red Sea.
31513	1205	15	And it came to pass that we did travel for the space of many days, slaying food by the way, with our bows and our arrows and our stones and our slings.
31514	1205	16	And we did follow the directions of the ball, which led us in the more fertile parts of the wilderness.
31515	1205	17	And after we had traveled for the space of many days, we did pitch our tents for the space of a time, that we might again rest ourselves and obtain food for our families.
31516	1205	18	And it came to pass that as I, Nephi, went forth to slay food, behold, I did break my bow, which was made of fine steel; and after I did break my bow, behold, my brethren were angry with me because of the loss of my bow, for we did obtain no food.
31517	1205	19	And it came to pass that we did return without food to our families, and being much fatigued, because of their journeying, they did suffer much for the want of food.
31518	1205	20	And it came to pass that Laman and Lemuel and the sons of Ishmael did begin to murmur exceedingly, because of their sufferings and afflictions in the wilderness; and also my father began to murmur against the Lord his God; yea, and they were all exceedingly sorrowful, even that they did murmur against the Lord.
31519	1205	21	Now it came to pass that I, Nephi, having been afflicted with my brethren because of the loss of my bow, and their bows having lost their springs, it began to be exceedingly difficult, yea, insomuch that we could obtain no food.
31520	1205	22	And it came to pass that I, Nephi, did speak much unto my brethren, because they had hardened their hearts again, even unto complaining against the Lord their God.
31521	1205	23	And it came to pass that I, Nephi, did make out of wood a bow, and out of a straight stick, an arrow; wherefore, I did arm myself with a bow and an arrow, with a sling and with stones. And I said unto my father: Whither shall I go to obtain food?
31522	1205	24	And it came to pass that he did inquire of the Lord, for they had humbled themselves because of my words; for I did say many things unto them in the energy of my soul.
31523	1205	25	And it came to pass that the voice of the Lord came unto my father; and he was truly chastened because of his murmuring against the Lord, insomuch that he was brought down into the depths of sorrow.
31524	1205	26	And it came to pass that the voice of the Lord said unto him: Look upon the ball, and behold the things which are written.
31525	1205	27	And it came to pass that when my father beheld the things which were written upon the ball, he did fear and tremble exceedingly, and also my brethren and the sons of Ishmael and our wives.
31526	1205	28	And it came to pass that I, Nephi, beheld the pointers which were in the ball, that they did work according to the faith and diligence and heed which we did give unto them.
31527	1205	29	And there was also written upon them a new writing, which was plain to be read, which did give us understanding concerning the ways of the Lord; and it was written and changed from time to time, according to the faith and diligence which we gave unto it. And thus we see that by small means the Lord can bring about great things.
31528	1205	30	And it came to pass that I, Nephi, did go forth up into the top of the mountain, according to the directions which were given upon the ball.
31529	1205	31	And it came to pass that I did slay wild beasts, insomuch that I did obtain food for our families.
31530	1205	32	And it came to pass that I did return to our tents, bearing the beasts which I had slain; and now when they beheld that I had obtained food, how great was their joy! And it came to pass that they did humble themselves before the Lord, and did give thanks unto him.
31531	1205	33	And it came to pass that we did again take our journey, traveling nearly the same course as in the beginning; and after we had traveled for the space of many days we did pitch our tents again, that we might tarry for the space of a time.
31532	1205	34	And it came to pass that Ishmael died, and was buried in the place which was called Nahom.
31533	1205	35	And it came to pass that the daughters of Ishmael did mourn exceedingly, because of the loss of their father, and because of their afflictions in the wilderness; and they did murmur against my father, because he had brought them out of the land of Jerusalem, saying: Our father is dead; yea, and we have wandered much in the wilderness, and we have suffered much affliction, hunger, thirst, and fatigue; and after all these sufferings we must perish in the wilderness with hunger.
31534	1205	36	And thus they did murmur against my father, and also against me; and they were desirous to return again to Jerusalem.
31535	1205	37	And Laman said unto Lemuel and also unto the sons of Ishmael: Behold, let us slay our father, and also our brother Nephi, who has taken it upon him to be our ruler and our teacher, who are his elder brethren.
31536	1205	38	Now, he says that the Lord has talked with him, and also that angels have ministered unto him. But behold, we know that he lies unto us; and he tells us these things, and he worketh many things by his cunning arts, that he may deceive our eyes, thinking, perhaps, that he may lead us away into some strange wilderness; and after he has led us away, he has thought to make himself a king and a ruler over us, that he may do with us according to his will and pleasure. And after this manner did my brother Laman stir up their hearts to anger.
31537	1205	39	And it came to pass that the Lord was with us, yea, even the voice of the Lord came and did speak many words unto them, and did chasten them exceedingly; and after they were chastened by the voice of the Lord they did turn away their anger, and did repent of their sins, insomuch that the Lord did bless us again with food, that we did not perish.
31538	1206	1	And it came to pass that we did again take our journey in the wilderness; and we did travel nearly eastward from that time forth. And we did travel and wade through much affliction in the wilderness; and our women did bear children in the wilderness.
31539	1206	2	And so great were the blessings of the Lord upon us, that while we did live upon raw meat in the wilderness, our women did give plenty of suck for their children, and were strong, yea, even like unto the men; and they began to bear their journeyings without murmurings.
31540	1206	3	And thus we see that the commandments of God must be fulfilled. And if it so be that the children of men keep the commandments of God he doth nourish them, and strengthen them, and provide means whereby they can accomplish the thing which he has commanded them; wherefore, he did provide means for us while we did sojourn in the wilderness.
31541	1206	4	And we did sojourn for the space of many years, yea, even eight years in the wilderness.
31542	1206	5	And we did come to the land which we called Bountiful, because of its much fruit and also wild honey; and all these things were prepared of the Lord that we might not perish. And we beheld the sea, which we called Irreantum, which, being interpreted, is many waters.
31543	1206	6	And it came to pass that we did pitch our tents by the seashore; and notwithstanding we had suffered many afflictions and much difficulty, yea, even so much that we cannot write them all, we were exceedingly rejoiced when we came to the seashore; and we called the place Bountiful, because of its much fruit.
31544	1206	7	And it came to pass that after I, Nephi, had been in the land of Bountiful for the space of many days, the voice of the Lord came unto me, saying: Arise, and get thee into the mountain. And it came to pass that I arose and went up into the mountain, and cried unto the Lord.
31545	1206	8	And it came to pass that the Lord spake unto me, saying: Thou shalt construct a ship, after the manner which I shall show thee, that I may carry thy people across these waters.
31546	1206	9	And I said: Lord, whither shall I go that I may find ore to molten, that I may make tools to construct the ship after the manner which thou hast shown unto me?
31547	1206	10	And it came to pass that the Lord told me whither I should go to find ore, that I might make tools.
31548	1206	11	And it came to pass that I, Nephi, did make a bellows wherewith to blow the fire, of the skins of beasts; and after I had made a bellows, that I might have wherewith to blow the fire, I did smite two stones together that I might make fire.
31549	1206	12	For the Lord had not hitherto suffered that we should make much fire, as we journeyed in the wilderness; for he said: I will make thy food become sweet, that ye cook it not;
31550	1206	13	And I will also be your light in the wilderness; and I will prepare the way before you, if it so be that ye shall keep my commandments; wherefore, inasmuch as ye shall keep my commandments ye shall be led towards the promised land; and ye shall know that it is by me that ye are led.
31551	1206	14	Yea, and the Lord said also that: After ye have arrived in the promised land, ye shall know that I, the Lord, am God; and that I, the Lord, did deliver you from destruction; yea, that I did bring you out of the land of Jerusalem.
31552	1206	15	Wherefore, I, Nephi, did strive to keep the commandments of the Lord, and I did exhort my brethren to faithfulness and diligence.
31553	1206	16	And it came to pass that I did make tools of the ore which I did molten out of the rock.
31554	1206	17	And when my brethren saw that I was about to build a ship, they began to murmur against me, saying: Our brother is a fool, for he thinketh that he can build a ship; yea, and he also thinketh that he can cross these great waters.
31555	1206	18	And thus my brethren did complain against me, and were desirous that they might not labor, for they did not believe that I could build a ship; neither would they believe that I was instructed of the Lord.
31556	1206	19	And now it came to pass that I, Nephi, was exceedingly sorrowful because of the hardness of their hearts; and now when they saw that I began to be sorrowful they were glad in their hearts, insomuch that they did rejoice over me, saying: We knew that ye could not construct a ship, for we knew that ye were lacking in judgment; wherefore, thou canst not accomplish so great a work.
31557	1206	20	And thou art like unto our father, led away by the foolish imaginations of his heart; yea, he hath led us out of the land of Jerusalem, and we have wandered in the wilderness for these many years; and our women have toiled, being big with child; and they have borne children in the wilderness and suffered all things, save it were death; and it would have been better that they had died before they came out of Jerusalem than to have suffered these afflictions.
31558	1206	21	Behold, these many years we have suffered in the wilderness, which time we might have enjoyed our possessions and the land of our inheritance; yea, and we might have been happy.
31559	1206	22	And we know that the people who were in the land of Jerusalem were a righteous people; for they kept the statutes and judgments of the Lord, and all his commandments, according to the law of Moses; wherefore, we know that they are a righteous people; and our father hath judged them, and hath led us away because we would hearken unto his words; yea, and our brother is like unto him. And after this manner of language did my brethren murmur and complain against us.
31560	1206	23	And it came to pass that I, Nephi, spake unto them, saying: Do ye believe that our fathers, who were the children of Israel, would have been led away out of the hands of the Egyptians if they had not hearkened unto the words of the Lord?
31561	1206	24	Yea, do ye suppose that they would have been led out of bondage, if the Lord had not commanded Moses that he should lead them out of bondage?
31562	1206	25	Now ye know that the children of Israel were in bondage; and ye know that they were laden with tasks, which were grievous to be borne; wherefore, ye know that it must needs be a good thing for them, that they should be brought out of bondage.
31563	1206	26	Now ye know that Moses was commanded of the Lord to do that great work; and ye know that by his word the waters of the Red Sea were divided hither and thither, and they passed through on dry ground.
31564	1206	27	But ye know that the Egyptians were drowned in the Red Sea, who were the armies of Pharaoh.
31565	1206	28	And ye also know that they were fed with manna in the wilderness.
31566	1206	29	Yea, and ye also know that Moses, by his word according to the power of God which was in him, smote the rock, and there came forth water, that the children of Israel might quench their thirst.
31567	1206	30	And notwithstanding they being led, the Lord their God, their Redeemer, going before them, leading them by day and giving light unto them by night, and doing all things for them which were expedient for man to receive, they hardened their hearts and blinded their minds, and reviled against Moses and against the true and living God.
31568	1206	31	And it came to pass that according to his word he did destroy them; and according to his word he did lead them; and according to his word he did do all things for them; and there was not any thing done save it were by his word.
31569	1206	32	And after they had crossed the river Jordan he did make them mighty unto the driving out of the children of the land, yea, unto the scattering them to destruction.
31570	1206	33	And now, do ye suppose that the children of this land, who were in the land of promise, who were driven out by our fathers, do ye suppose that they were righteous? Behold, I say unto you, Nay.
31571	1206	34	Do ye suppose that our fathers would have been more choice than they if they had been righteous? I say unto you, Nay.
31572	1206	35	Behold, the Lord esteemeth all flesh in one; he that is righteous is favored of God. But behold, this people had rejected every word of God, and they were ripe in iniquity; and the fulness of the wrath of God was upon them; and the Lord did curse the land against them, and bless it unto our fathers; yea, he did curse it against them unto their destruction, and he did bless it unto our fathers unto their obtaining power over it.
31573	1206	36	Behold, the Lord hath created the earth that it should be inhabited; and he hath created his children that they should possess it.
31574	1206	37	And he raiseth up a righteous nation, and destroyeth the nations of the wicked.
31575	1206	38	And he leadeth away the righteous into precious lands, and the wicked he destroyeth, and curseth the land unto them for their sakes.
31576	1206	39	He ruleth high in the heavens, for it is his throne, and this earth is his footstool.
31577	1206	40	And he loveth those who will have him to be their God. Behold, he loved our fathers, and he covenanted with them, yea, even Abraham, Isaac, and Jacob; and he remembered the covenants which he had made; wherefore, he did bring them out of the land of Egypt.
31578	1206	41	And he did straiten them in the wilderness with his rod; for they hardened their hearts, even as ye have; and the Lord straitened them because of their iniquity. He sent fiery flying serpents among them; and after they were bitten he prepared a way that they might be healed; and the labor which they had to perform was to look; and because of the simpleness of the way, or the easiness of it, there were many who perished.
31579	1206	42	And they did harden their hearts from time to time, and they did revile against Moses, and also against God; nevertheless, ye know that they were led forth by his matchless power into the land of promise.
31580	1206	43	And now, after all these things, the time has come that they have become wicked, yea, nearly unto ripeness; and I know not but they are at this day about to be destroyed; for I know that the day must surely come that they must be destroyed, save a few only, who shall be led away into captivity.
31581	1206	44	Wherefore, the Lord commanded my father that he should depart into the wilderness; and the Jews also sought to take away his life; yea, and ye also have sought to take away his life; wherefore, ye are murderers in your hearts and ye are like unto them.
31582	1206	45	Ye are swift to do iniquity but slow to remember the Lord your God. Ye have seen an angel, and he spake unto you; yea, ye have heard his voice from time to time; and he hath spoken unto you in a still small voice, but ye were past feeling, that ye could not feel his words; wherefore, he has spoken unto you like unto the voice of thunder, which did cause the earth to shake as if it were to divide asunder.
31583	1206	46	And ye also know that by the power of his almighty word he can cause the earth that it shall pass away; yea, and ye know that by his word he can cause the rough places to be made smooth, and smooth places shall be broken up. O, then, why is it, that ye can be so hard in your hearts?
31584	1206	47	Behold, my soul is rent with anguish because of you, and my heart is pained; I fear lest ye shall be cast off forever. Behold, I am full of the Spirit of God, insomuch that my frame has no strength.
31585	1206	48	And now it came to pass that when I had spoken these words they were angry with me, and were desirous to throw me into the depths of the sea; and as they came forth to lay their hands upon me I spake unto them, saying: In the name of the Almighty God, I command you that ye touch me not, for I am filled with the power of God, even unto the consuming of my flesh; and whoso shall lay his hands upon me shall wither even as a dried reed; and he shall be as naught before the power of God, for God shall smite him.
31586	1206	49	And it came to pass that I, Nephi, said unto them that they should murmur no more against their father; neither should they withhold their labor from me, for God had commanded me that I should build a ship.
31587	1206	50	And I said unto them: If God had commanded me to do all things I could do them. If he should command me that I should say unto this water, be thou earth, it should be earth; and if I should say it, it would be done.
31588	1206	51	And now, if the Lord has such great power, and has wrought so many miracles among the children of men, how is it that he cannot instruct me, that I should build a ship?
31589	1206	52	And it came to pass that I, Nephi, said many things unto my brethren, insomuch that they were confounded and could not contend against me; neither durst they lay their hands upon me nor touch me with their fingers, even for the space of many days. Now they durst not do this lest they should wither before me, so powerful was the Spirit of God; and thus it had wrought upon them.
31590	1206	53	And it came to pass that the Lord said unto me: Stretch forth thine hand again unto thy brethren, and they shall not wither before thee, but I will shock them, saith the Lord, and this will I do, that they may know that I am the Lord their God.
31591	1206	54	And it came to pass that I stretched forth my hand unto my brethren, and they did not wither before me; but the Lord did shake them, even according to the word which he had spoken.
31592	1206	55	And now, they said: We know of a surety that the Lord is with thee, for we know that it is the power of the Lord that has shaken us. And they fell down before me, and were about to worship me, but I would not suffer them, saying: I am thy brother, yea, even thy younger brother; wherefore, worship the Lord thy God, and honor thy father and thy mother, that thy days may be long in the land which the Lord thy God shall give thee.
31593	1207	1	And it came to pass that they did worship the Lord, and did go forth with me; and we did work timbers of curious workmanship. And the Lord did show me from time to time after what manner I should work the timbers of the ship.
31594	1207	2	Now I, Nephi, did not work the timbers after the manner which was learned by men, neither did I build the ship after the manner of men; but I did build it after the manner which the Lord had shown unto me; wherefore, it was not after the manner of men.
31595	1207	3	And I, Nephi, did go into the mount oft, and I did pray oft unto the Lord; wherefore the Lord showed unto me great things.
31596	1207	4	And it came to pass that after I had finished the ship, according to the word of the Lord, my brethren beheld that it was good, and that the workmanship thereof was exceedingly fine; wherefore, they did humble themselves again before the Lord.
31597	1207	5	And it came to pass that the voice of the Lord came unto my father, that we should arise and go down into the ship.
31598	1207	6	And it came to pass that on the morrow, after we had prepared all things, much fruits and meat from the wilderness, and honey in abundance, and provisions according to that which the Lord had commanded us, we did go down into the ship, with all our loading and our seeds, and whatsoever thing we had brought with us, every one according to his age; wherefore, we did all go down into the ship, with our wives and our children.
31599	1207	7	And now, my father had begat two sons in the wilderness; the elder was called Jacob and the younger Joseph.
31600	1207	8	And it came to pass after we had all gone down into the ship, and had taken with us our provisions and things which had been commanded us, we did put forth into the sea and were driven forth before the wind towards the promised land.
31601	1207	9	And after we had been driven forth before the wind for the space of many days, behold, my brethren and the sons of Ishmael and also their wives began to make themselves merry, insomuch that they began to dance, and to sing, and to speak with much rudeness, yea, even that they did forget by what power they had been brought thither; yea, they were lifted up unto exceeding rudeness.
31602	1207	10	And I, Nephi, began to fear exceedingly lest the Lord should be angry with us, and smite us because of our iniquity, that we should be swallowed up in the depths of the sea; wherefore, I, Nephi, began to speak to them with much soberness; but behold they were angry with me, saying: We will not that our younger brother shall be a ruler over us.
31603	1207	11	And it came to pass that Laman and Lemuel did take me and bind me with cords, and they did treat me with much harshness; nevertheless, the Lord did suffer it that he might show forth his power, unto the fulfilling of his word which he had spoken concerning the wicked.
31604	1207	12	And it came to pass that after they had bound me insomuch that I could not move, the compass, which had been prepared of the Lord, did cease to work.
31605	1207	13	Wherefore, they knew not whither they should steer the ship, insomuch that there arose a great storm, yea, a great and terrible tempest, and we were driven back upon the waters for the space of three days; and they began to be frightened exceedingly lest they should be drowned in the sea; nevertheless they did not loose me.
31606	1207	14	And on the fourth day, which we had been driven back, the tempest began to be exceedingly sore.
31607	1207	15	And it came to pass that we were about to be swallowed up in the depths of the sea. And after we had been driven back upon the waters for the space of four days, my brethren began to see that the judgments of God were upon them, and that they must perish save that they should repent of their iniquities; wherefore, they came unto me, and loosed the bands which were upon my wrists, and behold they had swollen exceedingly; and also mine ankles were much swollen, and great was the soreness thereof.
31608	1207	16	Nevertheless, I did look unto my God, and I did praise him all the day long; and I did not murmur against the Lord because of mine afflictions.
31609	1207	17	Now my father, Lehi, had said many things unto them, and also unto the sons of Ishmael; but, behold, they did breathe out much threatenings against anyone that should speak for me; and my parents being stricken in years, and having suffered much grief because of their children, they were brought down, yea, even upon their sick-beds.
31610	1207	18	Because of their grief and much sorrow, and the iniquity of my brethren, they were brought near even to be carried out of this time to meet their God; yea, their grey hairs were about to be brought down to lie low in the dust; yea, even they were near to be cast with sorrow into a watery grave.
31611	1207	19	And Jacob and Joseph also, being young, having need of much nourishment, were grieved because of the afflictions of their mother; and also my wife with her tears and prayers, and also my children, did not soften the hearts of my brethren that they would loose me.
31612	1207	20	And there was nothing save it were the power of God, which threatened them with destruction, could soften their hearts; wherefore, when they saw that they were about to be swallowed up in the depths of the sea they repented of the thing which they had done, insomuch that they loosed me.
31613	1207	21	And it came to pass after they had loosed me, behold, I took the compass, and it did work whither I desired it. And it came to pass that I prayed unto the Lord; and after I had prayed the winds did cease, and the storm did cease, and there was a great calm.
31614	1207	22	And it came to pass that I, Nephi, did guide the ship, that we sailed again towards the promised land.
31615	1207	23	And it came to pass that after we had sailed for the space of many days we did arrive at the promised land; and we went forth upon the land, and did pitch our tents; and we did call it the promised land.
31616	1207	24	And it came to pass that we did begin to till the earth, and we began to plant seeds; yea, we did put all our seeds into the earth, which we had brought from the land of Jerusalem. And it came to pass that they did grow exceedingly; wherefore, we were blessed in abundance.
31617	1207	25	And it came to pass that we did find upon the land of promise, as we journeyed in the wilderness, that there were beasts in the forests of every kind, both the cow and the ox, and the ass and the horse, and the goat and the wild goat, and all manner of wild animals, which were for the use of men. And we did find all manner of ore, both of gold, and of silver, and of copper.
31618	1208	1	And it came to pass that the Lord commanded me, wherefore I did make plates of ore that I might engraven upon them the record of my people. And upon the plates which I made I did engraven the record of my father, and also our journeyings in the wilderness, and the prophecies of my father; and also many of mine own prophecies have I engraven upon them.
31619	1208	2	And I knew not at the time when I made them that I should be commanded of the Lord to make these plates; wherefore, the record of my father, and the genealogy of his fathers, and the more part of all our proceedings in the wilderness are engraven upon those first plates of which I have spoken; wherefore, the things which transpired before I made these plates are, of a truth, more particularly made mention upon the first plates.
31620	1208	3	And after I had made these plates by way of commandment, I, Nephi, received a commandment that the ministry and the prophecies, the more plain and precious parts of them, should be written upon these plates; and that the things which were written should be kept for the instruction of my people, who should possess the land, and also for other wise purposes, which purposes are known unto the Lord.
31621	1208	4	Wherefore, I, Nephi, did make a record upon the other plates, which gives an account, or which gives a greater account of the wars and contentions and destructions of my people. And this have I done, and commanded my people what they should do after I was gone; and that these plates should be handed down from one generation to another, or from one prophet to another, until further commandments of the Lord.
31622	1208	5	And an account of my making these plates shall be given hereafter; and then, behold, I proceed according to that which I have spoken; and this I do that the more sacred things may be kept for the knowledge of my people.
31623	1208	6	Nevertheless, I do not write anything upon plates save it be that I think it be sacred. And now, if I do err, even did they err of old; not that I would excuse myself because of other men, but because of the weakness which is in me, according to the flesh, I would excuse myself.
31624	1208	7	For the things which some men esteem to be of great worth, both to the body and soul, others set at naught and trample under their feet. Yea, even the very God of Israel do men trample under their feet; I say, trample under their feet but I would speak in other words--they set him at naught, and hearken not to the voice of his counsels.
31625	1208	8	And behold he cometh, according to the words of the angel, in six hundred years from the time my father left Jerusalem.
31626	1208	9	And the world, because of their iniquity, shall judge him to be a thing of naught; wherefore they scourge him, and he suffereth it; and they smite him, and he suffereth it. Yea, they spit upon him, and he suffereth it, because of his loving kindness and his long-suffering towards the children of men.
31627	1208	10	And the God of our fathers, who were led out of Egypt, out of bondage, and also were preserved in the wilderness by him, yea, the God of Abraham, and of Isaac, and the God of Jacob, yieldeth himself, according to the words of the angel, as a man, into the hands of wicked men, to be lifted up, according to the words of Zenock, and to be crucified, according to the words of Neum, and to be buried in a sepulchre, according to the words of Zenos, which he spake concerning the three days of darkness, which should be a sign given of his death unto those who should inhabit the isles of the sea, more especially given unto those who are of the house of Israel.
31628	1208	11	For thus spake the prophet: The Lord God surely shall visit all the house of Israel at that day, some with his voice, because of their righteousness, unto their great joy and salvation, and others with the thunderings and the lightnings of his power, by tempest, by fire, and by smoke, and vapor of darkness, and by the opening of the earth, and by mountains which shall be carried up.
31629	1208	12	And all these things must surely come, saith the prophet Zenos. And the rocks of the earth must rend; and because of the groanings of the earth, many of the kings of the isles of the sea shall be wrought upon by the Spirit of God, to exclaim: The God of nature suffers.
31630	1208	13	And as for those who are at Jerusalem, saith the prophet, they shall be scourged by all people, because they crucify the God of Israel, and turn their hearts aside, rejecting signs and wonders, and the power and glory of the God of Israel.
31631	1208	14	And because they turn their hearts aside, saith the prophet, and have despised the Holy One of Israel, they shall wander in the flesh, and perish, and become a hiss and a byword, and be hated among all nations.
31632	1208	15	Nevertheless, when that day cometh, saith the prophet, that they no more turn aside their hearts against the Holy One of Israel, then will he remember the covenants which he made to their fathers.
31633	1208	16	Yea, then will he remember the isles of the sea; yea, and all the people who are of the house of Israel, will I gather in, saith the Lord, according to the words of the prophet Zenos, from the four quarters of the earth.
31634	1208	17	Yea, and all the earth shall see the salvation of the Lord, saith the prophet; every nation, kindred, tongue and people shall be blessed.
31635	1208	18	And I, Nephi, have written these things unto my people, that perhaps I might persuade them that they would remember the Lord their Redeemer.
31636	1208	19	Wherefore, I speak unto all the house of Israel, if it so be that they should obtain these things.
31637	1208	20	For behold, I have workings in the spirit, which doth weary me even that all my joints are weak, for those who are at Jerusalem; for had not the Lord been merciful, to show unto me concerning them, even as he had prophets of old, I should have perished also.
31638	1208	21	And he surely did show unto the prophets of old all things concerning them; and also he did show unto many concerning us; wherefore, it must needs be that we know concerning them for they are written upon the plates of brass.
31639	1208	22	Now it came to pass that I, Nephi, did teach my brethren these things; and it came to pass that I did read many things to them, which were engraven upon the plates of brass, that they might know concerning the doings of the Lord in other lands, among people of old.
31640	1208	23	And I did read many things unto them which were written in the books of Moses; but that I might more fully persuade them to believe in the Lord their Redeemer I did read unto them that which was written by the prophet Isaiah; for I did liken all scriptures unto us, that it might be for our profit and learning.
31641	1208	24	Wherefore I spake unto them, saying: Hear ye the words of the prophet, ye who are a remnant of the house of Israel, a branch who have been broken off; hear ye the words of the prophet, which were written unto all the house of Israel, and liken them unto yourselves, that ye may have hope as well as your brethren from whom ye have been broken off; for after this manner has the prophet written.
31642	1209	1	Hearken and hear this, O house of Jacob, who are called by the name of Israel, and are come forth out of the waters of Judah, or out of the waters of baptism, who swear by the name of the Lord, and make mention of the God of Israel, yet they swear not in truth nor in righteousness.
31643	1209	2	Nevertheless, they call themselves of the holy city, but they do not stay themselves upon the God of Israel, who is the Lord of Hosts; yea, the Lord of Hosts is his name.
31644	1209	3	Behold, I have declared the former things from the beginning; and they went forth out of my mouth, and I showed them. I did show them suddenly.
31645	1209	4	And I did it because I knew that thou art obstinate, and thy neck is an iron sinew, and thy brow brass;
31646	1209	5	And I have even from the beginning declared to thee; before it came to pass I showed them thee; and I showed them for fear lest thou shouldst say--Mine idol hath done them, and my graven image, and my molten image hath commanded them.
31647	1209	6	Thou hast seen and heard all this; and will ye not declare them? And that I have showed thee new things from this time, even hidden things, and thou didst not know them.
31648	1209	7	They are created now, and not from the beginning, even before the day when thou heardest them not they were declared unto thee, lest thou shouldst say--Behold I knew them.
31649	1209	8	Yea, and thou heardest not; yea, thou knewest not; yea, from that time thine ear was not opened; for I knew that thou wouldst deal very treacherously, and wast called a transgressor from the womb.
31650	1209	9	Nevertheless, for my name's sake will I defer mine anger, and for my praise will I refrain from thee, that I cut thee not off.
31651	1209	10	For, behold, I have refined thee, I have chosen thee in the furnace of affliction.
31652	1209	11	For mine own sake, yea, for mine own sake will I do this, for I will not suffer my name to be polluted, and I will not give my glory unto another.
31653	1209	12	Hearken unto me, O Jacob, and Israel my called, for I am he; I am the first, and I am also the last.
31654	1209	13	Mine hand hath also laid the foundation of the earth, and my right hand hath spanned the heavens. I call unto them and they stand up together.
31655	1209	14	All ye, assemble yourselves, and hear; who among them hath declared these things unto them? The Lord hath loved him; yea, and he will fulfil his word which he hath declared by them; and he will do his pleasure on Babylon, and his arm shall come upon the Chaldeans.
31656	1209	15	Also, saith the Lord; I the Lord, yea, I have spoken; yea, I have called him to declare, I have brought him, and he shall make his way prosperous.
31657	1209	16	Come ye near unto me; I have not spoken in secret; from the beginning, from the time that it was declared have I spoken; and the Lord God, and his Spirit, hath sent me.
31658	1209	17	And thus saith the Lord, thy Redeemer, the Holy One of Israel; I have sent him, the Lord thy God who teacheth thee to profit, who leadeth thee by the way thou shouldst go, hath done it.
31659	1209	18	O that thou hadst hearkened to my commandments--then had thy peace been as a river, and thy righteousness as the waves of the sea.
31660	1209	19	Thy seed also had been as the sand; the offspring of thy bowels like the gravel thereof; his name should not have been cut off nor destroyed from before me.
31661	1209	20	Go ye forth of Babylon, flee ye from the Chaldeans, with a voice of singing declare ye, tell this, utter to the end of the earth; say ye: The Lord hath redeemed his servant Jacob.
31662	1209	21	And they thirsted not; he led them through the deserts; he caused the waters to flow out of the rock for them; he clave the rock also and the waters gushed out.
31663	1209	22	And notwithstanding he hath done all this, and greater also, there is no peace, saith the Lord, unto the wicked.
31664	1210	1	And again: Hearken, O ye house of Israel, all ye that are broken off and are driven out because of the wickedness of the pastors of my people; yea, all ye that are broken off, that are scattered abroad, who are of my people, O house of Israel. Listen, O isles, unto me, and hearken ye people from far; the Lord hath called me from the womb; from the bowels of my mother hath he made mention of my name.
31665	1210	2	And he hath made my mouth like a sharp sword; in the shadow of his hand hath he hid me, and made me a polished shaft; in his quiver hath he hid me;
31666	1210	3	And said unto me: Thou art my servant, O Israel, in whom I will be glorified.
31667	1210	4	Then I said, I have labored in vain, I have spent my strength for naught and in vain; surely my judgment is with the Lord, and my work with my God.
31668	1210	5	And now, saith the Lord--that formed me from the womb that I should be his servant, to bring Jacob again to him--though Israel be not gathered, yet shall I be glorious in the eyes of the Lord, and my God shall be my strength.
31669	1210	6	And he said: It is a light thing that thou shouldst be my servant to raise up the tribes of Jacob, and to restore the preserved of Israel. I will also give thee for a light to the Gentiles, that thou mayest be my salvation unto the ends of the earth.
31670	1210	7	Thus saith the Lord, the Redeemer of Israel, his Holy One, to him whom man despiseth, to him whom the nations abhorreth, to servant of rulers: Kings shall see and arise, princes also shall worship, because of the Lord that is faithful.
31671	1210	8	Thus saith the Lord: In an acceptable time have I heard thee, O isles of the sea, and in a day of salvation have I helped thee; and I will preserve thee, and give thee my servant for a covenant of the people, to establish the earth, to cause to inherit the desolate heritages;
31672	1210	9	That thou mayest say to the prisoners: Go forth; to them that sit in darkness: Show yourselves. They shall feed in the ways, and their pastures shall be in all high places.
31673	1210	10	They shall not hunger nor thirst, neither shall the heat nor the sun smite them; for he that hath mercy on them shall lead them, even by the springs of water shall he guide them.
31674	1210	11	And I will make all my mountains a way, and my highways shall be exalted.
31675	1210	12	And then, O house of Israel, behold, these shall come from far; and lo, these from the north and from the west; and these from the land of Sinim.
31676	1210	13	Sing, O heavens; and be joyful, O earth; for the feet of those who are in the east shall be established; and break forth into singing, O mountains; for they shall be smitten no more; for the Lord hath comforted his people, and will have mercy upon his afflicted.
31677	1210	14	But, behold, Zion hath said: The Lord hath forsaken me, and my Lord hath forgotten me--but he will show that he hath not.
31678	1210	15	For can a woman forget her sucking child, that she should not have compassion on the son of her womb? Yea, they may forget, yet will I not forget thee, O house of Israel.
31679	1210	16	Behold, I have graven thee upon the palms of my hands; thy walls are continually before me.
31680	1210	17	Thy children shall make haste against thy destroyers; and they that made thee waste shall go forth of thee.
31681	1210	18	Lift up thine eyes round about and behold; all these gather themselves together, and they shall come to thee. And as I live, saith the Lord, thou shalt surely clothe thee with them all, as with an ornament, and bind them on even as a bride.
31682	1210	19	For thy waste and thy desolate places, and the land of thy destruction, shall even now be too narrow by reason of the inhabitants; and they that swallowed thee up shall be far away.
31683	1210	20	The children whom thou shalt have, after thou hast lost the first, shall again in thine ears say: The place is too strait for me; give place to me that I may dwell.
31684	1210	21	Then shalt thou say in thine heart: Who hath begotten me these, seeing I have lost my children, and am desolate, a captive, and removing to and fro? And who hath brought up these? Behold, I was left alone; these, where have they been?
31685	1210	22	Thus saith the Lord God: Behold, I will lift up mine hand to the Gentiles, and set up my standard to the people; and they shall bring thy sons in their arms, and thy daughters shall be carried upon their shoulders.
31686	1210	23	And kings shall be thy nursing fathers, and their queens thy nursing mothers; they shall bow down to thee with their face towards the earth, and lick up the dust of thy feet; and thou shalt know that I am the Lord; for they shall not be ashamed that wait for me.
31687	1210	24	For shall the prey be taken from the mighty, or the lawful captives delivered?
31688	1210	25	But thus saith the Lord, even the captives of the mighty shall be taken away, and the prey of the terrible shall be delivered; for I will contend with him that contendeth with thee, and I will save thy children.
31689	1210	26	And I will feed them that oppress thee with their own flesh; they shall be drunken with their own blood as with sweet wine; and all flesh shall know that I, the Lord, am thy Savior and thy Redeemer, the Mighty One of Jacob.
31690	1211	1	And now it came to pass that after I, Nephi, had read these things which were engraven upon the plates of brass, my brethren came unto me and said unto me: What meaneth these things which ye have read? Behold, are they to be understood according to things which are spiritual, which shall come to pass according to the spirit and not the flesh?
31691	1211	2	And I, Nephi, said unto them: Behold they were manifest unto the prophet by the voice of the Spirit; for by the Spirit are all things made known unto the prophets, which shall come upon the children of men according to the flesh.
31692	1211	3	Wherefore, the things of which I have read are things pertaining to things both temporal and spiritual; for it appears that the house of Israel, sooner or later, will be scattered upon all the face of the earth, and also among all nations.
31693	1211	4	And behold, there are many who are already lost from the knowledge of those who are at Jerusalem. Yea, the more part of all the tribes have been led away; and they are scattered to and fro upon the isles of the sea; and whither they are none of us knoweth, save that we know that they have been led away.
31694	1211	5	And since they have been led away, these things have been prophesied concerning them, and also concerning all those who shall hereafter be scattered and be confounded, because of the Holy One of Israel; for against him will they harden their hearts; wherefore, they shall be scattered among all nations and shall be hated of all men.
31695	1211	6	Nevertheless, after they shall be nursed by the Gentiles, and the Lord has lifted up his hand upon the Gentiles and set them up for a standard, and their children have been carried in their arms, and their daughters have been carried upon their shoulders, behold these things of which are spoken are temporal; for thus are the covenants of the Lord with our fathers; and it meaneth us in the days to come, and also all our brethren who are of the house of Israel.
31696	1211	7	And it meaneth that the time cometh that after all the house of Israel have been scattered and confounded, that the Lord God will raise up a mighty nation among the Gentiles, yea, even upon the face of this land; and by them shall our seed be scattered.
31697	1211	8	And after our seed is scattered the Lord God will proceed to do a marvelous work among the Gentiles, which shall be of great worth unto our seed; wherefore, it is likened unto their being nourished by the Gentiles and being carried in their arms and upon their shoulders.
31698	1211	9	And it shall also be of worth unto the Gentiles; and not only unto the Gentiles but unto all the house of Israel, unto the making known of the covenants of the Father of heaven unto Abraham, saying: In thy seed shall all the kindreds of the earth be blessed.
31699	1211	10	And I would, my brethren, that ye should know that all the kindreds of the earth cannot be blessed unless he shall make bare his arm in the eyes of the nations.
31700	1211	11	Wherefore, the Lord God will proceed to make bare his arm in the eyes of all the nations, in bringing about his covenants and his gospel unto those who are of the house of Israel.
31701	1211	12	Wherefore, he will bring them again out of captivity, and they shall be gathered together to the lands of their inheritance; and they shall be brought out of obscurity and out of darkness; and they shall know that the Lord is their Savior and their Redeemer, the Mighty One of Israel.
31702	1211	13	And the blood of that great and abominable church, which is the whore of all the earth, shall turn upon their own heads; for they shall war among themselves, and the sword of their own hands shall fall upon their own heads, and they shall be drunken with their own blood.
31703	1211	14	And every nation which shall war against thee, O house of Israel, shall be turned one against another, and they shall fall into the pit which they digged to ensnare the people of the Lord. And all that fight against Zion shall be destroyed, and that great whore, who hath perverted the right ways of the Lord, yea, that great and abominable church, shall tumble to the dust and great shall be the fall of it.
31704	1211	15	For behold, saith the prophet, the time cometh speedily that Satan shall have no more power over the hearts of the children of men; for the day soon cometh that all the proud and they who do wickedly shall be as stubble; and the day cometh that they must be burned.
31705	1211	16	For the time soon cometh that the fulness of the wrath of God shall be poured out upon all the children of men; for he will not suffer that the wicked shall destroy the righteous.
31706	1211	17	Wherefore, he will preserve the righteous by his power, even if it so be that the fulness of his wrath must come, and the righteous be preserved, even unto the destruction of their enemies by fire. Wherefore, the righteous need not fear; for thus saith the prophet, they shall be saved, even if it so be as by fire.
31707	1211	18	Behold, my brethren, I say unto you, that these things must shortly come; yea, even blood, and fire, and vapor of smoke must come; and it must needs be upon the face of this earth; and it cometh unto men according to the flesh if it so be that they will harden their hearts against the Holy One of Israel.
31708	1211	19	For behold, the righteous shall not perish; for the time surely must come that all they who fight against Zion shall be cut off.
31709	1211	20	And the Lord will surely prepare a way for his people, unto the fulfilling of the words of Moses, which he spake, saying: A prophet shall the Lord your God raise up unto you, like unto me; him shall ye hear in all things whatsoever he shall say unto you. And it shall come to pass that all those who will not hear that prophet shall be cut off from among the people.
31710	1211	21	And now I, Nephi, declare unto you, that this prophet of whom Moses spake was the Holy One of Israel; wherefore, he shall execute judgment in righteousness.
31711	1211	22	And the righteous need not fear, for they are those who shall not be confounded. But it is the kingdom of the devil, which shall be built up among the children of men, which kingdom is established among them which are in the flesh--
31712	1211	23	For the time speedily shall come that all churches which are built up to get gain, and all those who are built up to get power over the flesh, and those who are built up to become popular in the eyes of the world, and those who seek the lusts of the flesh and the things of the world, and to do all manner of iniquity; yea, in fine, all those who belong to the kingdom of the devil are they who need fear, and tremble, and quake; they are those who must be brought low in the dust; they are those who must be consumed as stubble; and this is according to the words of the prophet.
31713	1211	24	And the time cometh speedily that the righteous must be led up as calves of the stall, and the Holy One of Israel must reign in dominion, and might, and power, and great glory.
31714	1211	25	And he gathereth his children from the four quarters of the earth; and he numbereth his sheep, and they know him; and there shall be one fold and one shepherd; and he shall feed his sheep, and in him they shall find pasture.
31715	1211	26	And because of the righteousness of his people, Satan has no power; wherefore, he cannot be loosed for the space of many years; for he hath no power over the hearts of the people, for they dwell in righteousness, and the Holy One of Israel reigneth.
31716	1211	27	And now behold, I, Nephi, say unto you that all these things must come according to the flesh.
31717	1211	28	But, behold, all nations, kindreds, tongues, and people shall dwell safely in the Holy One of Israel if it so be that they will repent.
31718	1211	29	And now I, Nephi, make an end; for I durst not speak further as yet concerning these things.
31719	1211	30	Wherefore, my brethren, I would that ye should consider that the things which have been written upon the plates of brass are true; and they testify that a man must be obedient to the commandments of God.
31720	1211	31	Wherefore, ye need not suppose that I and my father are the only ones that have testified, and also taught them. Wherefore, if ye shall be obedient to the commandments, and endure to the end, ye shall be saved at the last day. And thus it is. Amen.
31721	1212	1	And now it came to pass that after I, Nephi, had made an end of teaching my brethren, our father, Lehi, also spake many things unto them, and rehearsed unto them, how great things the Lord had done for them in bringing them out of the land of Jerusalem.
31722	1212	2	And he spake unto them concerning their rebellions upon the waters, and the mercies of God in sparing their lives, that they were not swallowed up in the sea.
31723	1212	3	And he also spake unto them concerning the land of promise, which they had obtained--how merciful the Lord had been in warning us that we should flee out of the land of Jerusalem.
31724	1212	4	For, behold, said he, I have seen a vision, in which I know that Jerusalem is destroyed; and had we remained in Jerusalem we should also have perished.
31725	1212	5	But, said he, notwithstanding our afflictions, we have obtained a land of promise, a land which is choice above all other lands; a land which the Lord God hath covenanted with me should be a land for the inheritance of my seed. Yea, the Lord hath covenanted this land unto me, and to my children forever, and also all those who should be led out of other countries by the hand of the Lord.
31726	1212	6	Wherefore, I, Lehi, prophesy according to the workings of the Spirit which is in me, that there shall none come into this land save they shall be brought by the hand of the Lord.
31727	1212	7	Wherefore, this land is consecrated unto him whom he shall bring. And if it so be that they shall serve him according to the commandments which he hath given, it shall be a land of liberty unto them; wherefore, they shall never be brought down into captivity; if so, it shall be because of iniquity; for if iniquity shall abound cursed shall be the land for their sakes, but unto the righteous it shall be blessed forever.
31728	1212	8	And behold, it is wisdom that this land should be kept as yet from the knowledge of other nations; for behold, many nations would overrun the land, that there would be no place for an inheritance.
31729	1212	9	Wherefore, I, Lehi, have obtained a promise, that inasmuch as those whom the Lord God shall bring out of the land of Jerusalem shall keep his commandments, they shall prosper upon the face of this land; and they shall be kept from all other nations, that they may possess this land unto themselves. And if it so be that they shall keep his commandments they shall be blessed upon the face of this land, and there shall be none to molest them, nor to take away the land of their inheritance; and they shall dwell safely forever.
31730	1212	10	But behold, when the time cometh that they shall dwindle in unbelief, after they have received so great blessings from the hand of the Lord--having a knowledge of the creation of the earth, and all men, knowing the great and marvelous works of the Lord from the creation of the world; having power given them to do all things by faith; having all the commandments from the beginning, and having been brought by his infinite goodness into this precious land of promise--behold, I say, if the day shall come that they will reject the Holy One of Israel, the true Messiah, their Redeemer and their God, behold, the judgments of him that is just shall rest upon them.
31731	1212	11	Yea, he will bring other nations unto them, and he will give unto them power, and he will take away from them the lands of their possessions, and he will cause them to be scattered and smitten.
31732	1212	12	Yea, as one generation passeth to another there shall be bloodsheds, and great visitations among them; wherefore, my sons, I would that ye would remember; yea, I would that ye would hearken unto my words.
31733	1212	13	O that ye would awake; awake from a deep sleep, yea, even from the sleep of hell, and shake off the awful chains by which ye are bound, which are the chains which bind the children of men, that they are carried away captive down to the eternal gulf of misery and woe.
31734	1212	14	Awake! and arise from the dust, and hear the words of a trembling parent, whose limbs ye must soon lay down in the cold and silent grave, from whence no traveler can return; a few more days and I go the way of all the earth.
31735	1212	15	But behold, the Lord hath redeemed my soul from hell; I have beheld his glory, and I am encircled about eternally in the arms of his love.
31736	1212	16	And I desire that ye should remember to observe the statutes and the judgments of the Lord; behold, this hath been the anxiety of my soul from the beginning.
31737	1212	17	My heart hath been weighed down with sorrow from time to time, for I have feared, lest for the hardness of your hearts the Lord your God should come out in the fulness of his wrath upon you, that ye be cut off and destroyed forever;
31738	1212	18	Or, that a cursing should come upon you for the space of many generations; and ye are visited by sword, and by famine, and are hated, and are led according to the will and captivity of the devil.
31739	1212	19	O my sons, that these things might not come upon you, but that ye might be a choice and a favored people of the Lord. But behold, his will be done; for his ways are righteousness forever.
31740	1212	20	And he hath said that: Inasmuch as ye shall keep my commandments ye shall prosper in the land; but inasmuch as ye will not keep my commandments ye shall be cut off from my presence.
31741	1212	21	And now that my soul might have joy in you, and that my heart might leave this world with gladness because of you, that I might not be brought down with grief and sorrow to the grave, arise from the dust, my sons, and be men, and be determined in one mind and in one heart, united in all things, that ye may not come down into captivity;
31742	1212	22	That ye may not be cursed with a sore cursing; and also, that ye may not incur the displeasure of a just God upon you, unto the destruction, yea, the eternal destruction of both soul and body.
31743	1212	23	Awake, my sons; put on the armor of righteousness. Shake off the chains with which ye are bound, and come forth out of obscurity, and arise from the dust.
31744	1212	24	Rebel no more against your brother, whose views have been glorious, and who hath kept the commandments from the time that we left Jerusalem; and who hath been an instrument in the hands of God, in bringing us forth into the land of promise; for were it not for him, we must have perished with hunger in the wilderness; nevertheless, ye sought to take away his life; yea, and he hath suffered much sorrow because of you.
31745	1212	25	And I exceedingly fear and tremble because of you, lest he shall suffer again; for behold, ye have accused him that he sought power and authority over you; but I know that he hath not sought for power nor authority over you, but he hath sought the glory of God, and your own eternal welfare.
31746	1212	26	And ye have murmured because he hath been plain unto you. Ye say that he hath used sharpness; ye say that he hath been angry with you; but behold, his sharpness was the sharpness of the power of the word of God, which was in him; and that which ye call anger was the truth, according to that which is in God, which he could not restrain, manifesting boldly concerning your iniquities.
31747	1212	27	And it must needs be that the power of God must be with him, even unto his commanding you that ye must obey. But behold, it was not he, but it was the Spirit of the Lord which was in him, which opened his mouth to utterance that he could not shut it.
31748	1212	28	And now my son, Laman, and also Lemuel and Sam, and also my sons who are the sons of Ishmael, behold, if ye will hearken unto the voice of Nephi ye shall not perish. And if ye will hearken unto him I leave unto you a blessing, yea, even my first blessing.
31749	1212	29	But if ye will not hearken unto him I take away my first blessing, yea, even my blessing, and it shall rest upon him.
31750	1212	30	And now, Zoram, I speak unto you: Behold, thou art the servant of Laban; nevertheless, thou hast been brought out of the land of Jerusalem, and I know that thou art a true friend unto my son, Nephi, forever.
31751	1212	31	Wherefore, because thou hast been faithful thy seed shall be blessed with his seed, that they dwell in prosperity long upon the face of this land; and nothing, save it shall be iniquity among them, shall harm or disturb their prosperity upon the face of this land forever.
31752	1212	32	Wherefore, if ye shall keep the commandments of the Lord, the Lord hath consecrated this land for the security of thy seed with the seed of my son.
31753	1213	1	And now, Jacob, I speak unto you: Thou art my first-born in the days of my tribulation in the wilderness. And behold, in thy childhood thou hast suffered afflictions and much sorrow, because of the rudeness of thy brethren.
31754	1213	2	Nevertheless, Jacob, my first-born in the wilderness, thou knowest the greatness of God; and he shall consecrate thine afflictions for thy gain.
31755	1213	3	Wherefore, thy soul shall be blessed, and thou shalt dwell safely with thy brother, Nephi; and thy days shall be spent in the service of thy God. Wherefore, I know that thou art redeemed, because of the righteousness of thy Redeemer; for thou hast beheld that in the fulness of time he cometh to bring salvation unto men.
31756	1213	4	And thou hast beheld in thy youth his glory; wherefore, thou art blessed even as they unto whom he shall minister in the flesh; for the Spirit is the same, yesterday, today, and forever. And the way is prepared from the fall of man, and salvation is free.
31757	1213	5	And men are instructed sufficiently that they know good from evil. And the law is given unto men. And by the law no flesh is justified; or, by the law men are cut off. Yea, by the temporal law they were cut off; and also, by the spiritual law they perish from that which is good, and become miserable forever.
31758	1213	6	Wherefore, redemption cometh in and through the Holy Messiah; for he is full of grace and truth.
31759	1213	7	Behold, he offereth himself a sacrifice for sin, to answer the ends of the law, unto all those who have a broken heart and a contrite spirit; and unto none else can the ends of the law be answered.
31760	1213	8	Wherefore, how great the importance to make these things known unto the inhabitants of the earth, that they may know that there is no flesh that can dwell in the presence of God, save it be through the merits, and mercy, and grace of the Holy Messiah, who layeth down his life according to the flesh, and taketh it again by the power of the Spirit, that he may bring to pass the resurrection of the dead, being the first that should rise.
31761	1213	9	Wherefore, he is the firstfruits unto God, inasmuch as he shall make intercession for all the children of men; and they that believe in him shall be saved.
31762	1213	10	And because of the intercession for all, all men come unto God; wherefore, they stand in the presence of him, to be judged of him according to the truth and holiness which is in him. Wherefore, the ends of the law which the Holy One hath given, unto the inflicting of the punishment which is affixed, which punishment that is affixed is in opposition to that of the happiness which is affixed, to answer the ends of the atonement--
31763	1213	11	For it must needs be, that there is an opposition in all things. If not so, my first-born in the wilderness, righteousness could not be brought to pass, neither wickedness, neither holiness nor misery, neither good nor bad. Wherefore, all things must needs be a compound in one; wherefore, if it should be one body it must needs remain as dead, having no life neither death, nor corruption nor incorruption, happiness nor misery, neither sense nor insensibility.
31764	1213	12	Wherefore, it must needs have been created for a thing of naught; wherefore there would have been no purpose in the end of its creation. Wherefore, this thing must needs destroy the wisdom of God and his eternal purposes, and also the power, and the mercy, and the justice of God.
31765	1213	13	And if ye shall say there is no law, ye shall also say there is no sin. If ye shall say there is no sin, ye shall also say there is no righteousness. And if there be no righteousness there be no happiness. And if there be no righteousness nor happiness there be no punishment nor misery. And if these things are not there is no God. And if there is no God we are not, neither the earth; for there could have been no creation of things, neither to act nor to be acted upon; wherefore, all things must have vanished away.
31766	1213	14	And now, my sons, I speak unto you these things for your profit and learning; for there is a God, and he hath created all things, both the heavens and the earth, and all things that in them are, both things to act and things to be acted upon.
31767	1213	15	And to bring about his eternal purposes in the end of man, after he had created our first parents, and the beasts of the field and the fowls of the air, and in fine, all things which are created, it must needs be that there was an opposition; even the forbidden fruit in opposition to the tree of life; the one being sweet and the other bitter.
31768	1213	16	Wherefore, the Lord God gave unto man that he should act for himself. Wherefore, man could not act for himself save it should be that he was enticed by the one or the other.
31769	1213	17	And I, Lehi, according to the things which I have read, must needs suppose that an angel of God, according to that which is written, had fallen from heaven; wherefore, he became a devil, having sought that which was evil before God.
31770	1213	18	And because he had fallen from heaven, and had become miserable forever, he sought also the misery of all mankind. Wherefore, he said unto Eve, yea, even that old serpent, who is the devil, who is the father of all lies, wherefore he said: Partake of the forbidden fruit, and ye shall not die, but ye shall be as God, knowing good and evil.
31771	1213	19	And after Adam and Eve had partaken of the forbidden fruit they were driven out of the garden of Eden, to till the earth.
31772	1213	20	And they have brought forth children; yea, even the family of all the earth.
31773	1213	21	And the days of the children of men were prolonged, according to the will of God, that they might repent while in the flesh; wherefore, their state became a state of probation, and their time was lengthened, according to the commandments which the Lord God gave unto the children of men. For he gave commandment that all men must repent; for he showed unto all men that they were lost, because of the transgression of their parents.
31774	1213	22	And now, behold, if Adam had not transgressed he would not have fallen, but he would have remained in the garden of Eden. And all things which were created must have remained in the same state in which they were after they were created; and they must have remained forever, and had no end.
31775	1213	23	And they would have had no children; wherefore they would have remained in a state of innocence, having no joy, for they knew no misery; doing no good, for they knew no sin.
31776	1213	24	But behold, all things have been done in the wisdom of him who knoweth all things.
31777	1213	25	Adam fell that men might be; and men are, that they might have joy.
31778	1213	26	And the Messiah cometh in the fulness of time, that he may redeem the children of men from the fall. And because that they are redeemed from the fall they have become free forever, knowing good from evil; to act for themselves and not to be acted upon, save it be by the punishment of the law at the great and last day, according to the commandments which God hath given.
31779	1213	27	Wherefore, men are free according to the flesh; and all things are given them which are expedient unto man. And they are free to choose liberty and eternal life, through the great Mediator of all men, or to choose captivity and death, according to the captivity and power of the devil; for he seeketh that all men might be miserable like unto himself.
31780	1213	28	And now, my sons, I would that ye should look to the great Mediator, and hearken unto his great commandments; and be faithful unto his words, and choose eternal life, according to the will of his Holy Spirit;
31781	1213	29	And not choose eternal death, according to the will of the flesh and the evil which is therein, which giveth the spirit of the devil power to captivate, to bring you down to hell, that he may reign over you in his own kingdom.
31782	1213	30	I have spoken these few words unto you all, my sons, in the last days of my probation; and I have chosen the good part, according to the words of the prophet. And I have none other object save it be the everlasting welfare of your souls. Amen.
31783	1214	1	And now I speak unto you, Joseph, my last-born. Thou wast born in the wilderness of mine afflictions; yea, in the days of my greatest sorrow did thy mother bear thee.
31784	1214	2	And may the Lord consecrate also unto thee this land, which is a most precious land, for thine inheritance and the inheritance of thy seed with thy brethren, for thy security forever, if it so be that ye shall keep the commandments of the Holy One of Israel.
31785	1214	3	And now, Joseph, my last-born, whom I have brought out of the wilderness of mine afflictions, may the Lord bless thee forever, for thy seed shall not utterly be destroyed.
31786	1214	4	For behold, thou art the fruit of my loins; and I am a descendant of Joseph who was carried captive into Egypt. And great were the covenants of the Lord which he made unto Joseph.
31787	1214	5	Wherefore, Joseph truly saw our day. And he obtained a promise of the Lord, that out of the fruit of his loins the Lord God would raise up a righteous branch unto the house of Israel; not the Messiah, but a branch which was to be broken off, nevertheless, to be remembered in the covenants of the Lord that the Messiah should be made manifest unto them in the latter days, in the spirit of power, unto the bringing of them out of darkness unto light--yea, out of hidden darkness and out of captivity unto freedom.
31788	1214	6	For Joseph truly testified, saying: A seer shall the Lord my God raise up, who shall be a choice seer unto the fruit of my loins.
31789	1214	7	Yea, Joseph truly said: Thus saith the Lord unto me: A choice seer will I raise up out of the fruit of thy loins; and he shall be esteemed highly among the fruit of thy loins. And unto him will I give commandment that he shall do a work for the fruit of thy loins, his brethren, which shall be of great worth unto them, even to the bringing of them to the knowledge of the covenants which I have made with thy fathers.
31790	1214	8	And I will give unto him a commandment that he shall do none other work, save the work which I shall command him. And I will make him great in mine eyes; for he shall do my work.
31791	1214	9	And he shall be great like unto Moses, whom I have said I would raise up unto you, to deliver my people, O house of Israel.
31792	1214	10	And Moses will I raise up, to deliver thy people out of the land of Egypt.
31793	1214	11	But a seer will I raise up out of the fruit of thy loins; and unto him will I give power to bring forth my word unto the seed of thy loins--and not to the bringing forth my word only, saith the Lord, but to the convincing them of my word, which shall have already gone forth among them.
31794	1214	12	Wherefore, the fruit of thy loins shall write; and the fruit of the loins of Judah shall write; and that which shall be written by the fruit of thy loins, and also that which shall be written by the fruit of the loins of Judah, shall grow together, unto the confounding of false doctrines and laying down of contentions, and establishing peace among the fruit of thy loins, and bringing them to the knowledge of their fathers in the latter days, and also to the knowledge of my covenants, saith the Lord.
31795	1214	13	And out of weakness he shall be made strong, in that day when my work shall commence among all my people, unto the restoring thee, O house of Israel, saith the Lord.
31796	1214	14	And thus prophesied Joseph, saying: Behold, that seer will the Lord bless; and they that seek to destroy him shall be confounded; for this promise, which I have obtained of the Lord, of the fruit of my loins, shall be fulfilled. Behold, I am sure of the fulfilling of this promise;
31797	1214	15	And his name shall be called after me; and it shall be after the name of his father. And he shall be like unto me; for the thing, which the Lord shall bring forth by his hand, by the power of the Lord shall bring my people unto salvation.
31798	1214	16	Yea, thus prophesied Joseph: I am sure of this thing, even as I am sure of the promise of Moses; for the Lord hath said unto me, I will preserve thy seed forever.
31799	1214	17	And the Lord hath said: I will raise up a Moses; and I will give power unto him in a rod; and I will give judgment unto him in writing. Yet I will not loose his tongue, that he shall speak much, for I will not make him mighty in speaking. But I will write unto him my law, by the finger of mine own hand; and I will make a spokesman for him.
31800	1214	18	And the Lord said unto me also: I will raise up unto the fruit of thy loins; and I will make for him a spokesman. And I, behold, I will give unto him that he shall write the writing of the fruit of thy loins, unto the fruit of thy loins; and the spokesman of thy loins shall declare it.
31801	1214	19	And the words which he shall write shall be the words which are expedient in my wisdom should go forth unto the fruit of thy loins. And it shall be as if the fruit of thy loins had cried unto them from the dust; for I know their faith.
31802	1214	20	And they shall cry from the dust; yea, even repentance unto their brethren, even after many generations have gone by them. And it shall come to pass that their cry shall go, even according to the simpleness of their words.
31803	1214	21	Because of their faith their words shall proceed forth out of my mouth unto their brethren who are the fruit of thy loins; and the weakness of their words will I make strong in their faith, unto the remembering of my covenant which I made unto thy fathers.
31804	1214	22	And now, behold, my son Joseph, after this manner did my father of old prophesy.
31805	1214	23	Wherefore, because of this covenant thou art blessed; for thy seed shall not be destroyed, for they shall hearken unto the words of the book.
31806	1214	24	And there shall rise up one mighty among them, who shall do much good, both in word and in deed, being an instrument in the hands of God, with exceeding faith, to work mighty wonders, and do that thing which is great in the sight of God, unto the bringing to pass much restoration unto the house of Israel, and unto the seed of thy brethren.
31807	1214	25	And now, blessed art thou, Joseph. Behold, thou art little; wherefore hearken unto the words of thy brother, Nephi, and it shall be done unto thee even according to the words which I have spoken. Remember the words of thy dying father. Amen.
31808	1215	1	And now, I, Nephi, speak concerning the prophecies of which my father hath spoken, concerning Joseph, who was carried into Egypt.
31809	1215	2	For behold, he truly prophesied concerning all his seed. And the prophecies which he wrote, there are not many greater. And he prophesied concerning us, and our future generations; and they are written upon the plates of brass.
31810	1215	3	Wherefore, after my father had made an end of speaking concerning the prophecies of Joseph, he called the children of Laman, his sons, and his daughters, and said unto them: Behold, my sons, and my daughters, who are the sons and the daughters of my first-born, I would that ye should give ear unto my words.
31811	1215	4	For the Lord God hath said that: Inasmuch as ye shall keep my commandments ye shall prosper in the land; and inasmuch as ye will not keep my commandments ye shall be cut off from my presence.
31812	1215	5	But behold, my sons and my daughters, I cannot go down to my grave save I should leave a blessing upon you; for behold, I know that if ye are brought up in the way ye should go ye will not depart from it.
31813	1215	6	Wherefore, if ye are cursed, behold, I leave my blessing upon you, that the cursing may be taken from you and be answered upon the heads of your parents.
31814	1215	7	Wherefore, because of my blessing the Lord God will not suffer that ye shall perish; wherefore, he will be merciful unto you and unto your seed forever.
31815	1215	8	And it came to pass that after my father had made an end of speaking to the sons and daughters of Laman, he caused the sons and daughters of Lemuel to be brought before him.
31816	1215	9	And he spake unto them, saying: Behold, my sons and my daughters, who are the sons and the daughters of my second son; behold I leave unto you the same blessing which I left unto the sons and daughters of Laman; wherefore, thou shalt not utterly be destroyed; but in the end thy seed shall be blessed.
31817	1215	10	And it came to pass that when my father had made an end of speaking unto them, behold, he spake unto the sons of Ishmael, yea, and even all his household.
31818	1215	11	And after he had made an end of speaking unto them, he spake unto Sam, saying: Blessed art thou, and thy seed; for thou shalt inherit the land like unto thy brother Nephi. And thy seed shall be numbered with his seed; and thou shalt be even like unto thy brother, and thy seed like unto his seed; and thou shalt be blessed in all thy days.
31819	1215	12	And it came to pass after my father, Lehi, had spoken unto all his household, according to the feelings of his heart and the Spirit of the Lord which was in him, he waxed old. And it came to pass that he died, and was buried.
31820	1215	13	And it came to pass that not many days after his death, Laman and Lemuel and the sons of Ishmael were angry with me because of the admonitions of the Lord.
31821	1215	14	For I, Nephi, was constrained to speak unto them, according to his word; for I had spoken many things unto them, and also my father, before his death; many of which sayings are written upon mine other plates; for a more history part are written upon mine other plates.
31822	1215	15	And upon these I write the things of my soul, and many of the scriptures which are engraven upon the plates of brass. For my soul delighteth in the scriptures, and my heart pondereth them, and writeth them for the learning and the profit of my children.
31823	1215	16	Behold, my soul delighteth in the things of the Lord; and my heart pondereth continually upon the things which I have seen and heard.
31824	1215	17	Nevertheless, notwithstanding the great goodness of the Lord, in showing me his great and marvelous works, my heart exclaimeth: O wretched man that I am! Yea, my heart sorroweth because of my flesh; my soul grieveth because of mine iniquities.
31825	1215	18	I am encompassed about, because of the temptations and the sins which do so easily beset me.
31826	1215	19	And when I desire to rejoice, my heart groaneth because of my sins; nevertheless, I know in whom I have trusted.
31827	1215	20	My God hath been my support; he hath led me through mine afflictions in the wilderness; and he hath preserved me upon the waters of the great deep.
31828	1215	21	He hath filled me with his love, even unto the consuming of my flesh.
31829	1215	22	He hath confounded mine enemies, unto the causing of them to quake before me.
31830	1215	23	Behold, he hath heard my cry by day, and he hath given me knowledge by visions in the nighttime.
31831	1215	24	And by day have I waxed bold in mighty prayer before him; yea, my voice have I sent up on high; and angels came down and ministered unto me.
31832	1215	25	And upon the wings of his Spirit hath my body been carried away upon exceedingly high mountains. And mine eyes have beheld great things, yea, even too great for man; therefore I was bidden that I should not write them.
31833	1215	26	O then, if I have seen so great things, if the Lord in his condescension unto the children of men hath visited men in so much mercy, why should my heart weep and my soul linger in the valley of sorrow, and my flesh waste away, and my strength slacken, because of mine afflictions?
31834	1215	27	And why should I yield to sin, because of my flesh? Yea, why should I give way to temptations, that the evil one have place in my heart to destroy my peace and afflict my soul? Why am I angry because of mine enemy?
31835	1215	28	Awake, my soul! No longer droop in sin. Rejoice, O my heart, and give place no more for the enemy of my soul.
31836	1215	29	Do not anger again because of mine enemies. Do not slacken my strength because of mine afflictions.
31837	1215	30	Rejoice, O my heart, and cry unto the Lord, and say: O Lord, I will praise thee forever; yea, my soul will rejoice in thee, my God, and the rock of my salvation.
31838	1215	31	O Lord, wilt thou redeem my soul? Wilt thou deliver me out of the hands of mine enemies? Wilt thou make me that I may shake at the appearance of sin?
31839	1215	32	May the gates of hell be shut continually before me, because that my heart is broken and my spirit is contrite! O Lord, wilt thou not shut the gates of thy righteousness before me, that I may walk in the path of the low valley, that I may be strict in the plain road!
31840	1215	33	O Lord, wilt thou encircle me around in the robe of thy righteousness! O Lord, wilt thou make a way for mine escape before mine enemies! Wilt thou make my path straight before me! Wilt thou not place a stumbling block in my way--but that thou wouldst clear my way before me, and hedge not up my way, but the ways of mine enemy.
31841	1215	34	O Lord, I have trusted in thee, and I will trust in thee forever. I will not put my trust in the arm of flesh; for I know that cursed is he that putteth his trust in the arm of flesh. Yea, cursed is he that putteth his trust in man or maketh flesh his arm.
31842	1215	35	Yea, I know that God will give liberally to him that asketh. Yea, my God will give me, if I ask not amiss; therefore I will lift up my voice unto thee; yea, I will cry unto thee, my God, the rock of my righteousness. Behold, my voice shall forever ascend up unto thee, my rock and mine everlasting God. Amen.
31843	1216	1	Behold, it came to pass that I, Nephi, did cry much unto the Lord my God, because of the anger of my brethren.
31844	1216	2	But behold, their anger did increase against me, insomuch that they did seek to take away my life.
31845	1216	3	Yea, they did murmur against me, saying: Our younger brother thinks to rule over us; and we have had much trial because of him; wherefore, now let us slay him, that we may not be afflicted more because of his words. For behold, we will not have him to be our ruler; for it belongs unto us, who are the elder brethren, to rule over this people.
31846	1216	4	Now I do not write upon these plates all the words which they murmured against me. But it sufficeth me to say, that they did seek to take away my life.
31847	1216	5	And it came to pass that the Lord did warn me, that I, Nephi, should depart from them and flee into the wilderness, and all those who would go with me.
31848	1216	6	Wherefore, it came to pass that I, Nephi, did take my family, and also Zoram and his family, and Sam, mine elder brother and his family, and Jacob and Joseph, my younger brethren, and also my sisters, and all those who would go with me. And all those who would go with me were those who believed in the warnings and the revelations of God; wherefore, they did hearken unto my words.
31849	1216	7	And we did take our tents and whatsoever things were possible for us, and did journey in the wilderness for the space of many days. And after we had journeyed for the space of many days we did pitch our tents.
31850	1216	8	And my people would that we should call the name of the place Nephi; wherefore, we did call it Nephi.
31851	1216	9	And all those who were with me did take upon them to call themselves the people of Nephi.
31852	1216	10	And we did observe to keep the judgments, and the statutes, and the commandments of the Lord in all things, according to the law of Moses.
31853	1216	11	And the Lord was with us; and we did prosper exceedingly; for we did sow seed, and we did reap again in abundance. And we began to raise flocks, and herds, and animals of every kind.
31854	1216	12	And I, Nephi, had also brought the records which were engraven upon the plates of brass; and also the ball, or compass, which was prepared for my father by the hand of the Lord, according to that which is written.
31855	1216	13	And it came to pass that we began to prosper exceedingly, and to multiply in the land.
31856	1216	14	And I, Nephi, did take the sword of Laban, and after the manner of it did make many swords, lest by any means the people who were now called Lamanites should come upon us and destroy us; for I knew their hatred towards me and my children and those who were called my people.
31857	1216	15	And I did teach my people to build buildings, and to work in all manner of wood, and of iron, and of copper, and of brass, and of steel, and of gold, and of silver, and of precious ores, which were in great abundance.
31858	1216	16	And I, Nephi, did build a temple; and I did construct it after the manner of the temple of Solomon save it were not built of so many precious things; for they were not to be found upon the land, wherefore, it could not be built like unto Solomon's temple. But the manner of the construction was like unto the temple of Solomon; and the workmanship thereof was exceedingly fine.
31859	1216	17	And it came to pass that I, Nephi, did cause my people to be industrious, and to labor with their hands.
31860	1216	18	And it came to pass that they would that I should be their king. But I, Nephi, was desirous that they should have no king; nevertheless, I did for them according to that which was in my power.
31861	1216	19	And behold, the words of the Lord had been fulfilled unto my brethren, which he spake concerning them, that I should be their ruler and their teacher. Wherefore, I had been their ruler and their teacher, according to the commandments of the Lord, until the time they sought to take away my life.
31862	1216	20	Wherefore, the word of the Lord was fulfilled which he spake unto me, saying that: Inasmuch as they will not hearken unto thy words they shall be cut off from the presence of the Lord. And behold, they were cut off from his presence.
31863	1216	21	And he had caused the cursing to come upon them, yea, even a sore cursing, because of their iniquity. For behold, they had hardened their hearts against him, that they had become like unto a flint; wherefore, as they were white, and exceedingly fair and delightsome, that they might not be enticing unto my people the Lord God did cause a skin of blackness to come upon them.
31864	1216	22	And thus saith the Lord God: I will cause that they shall be loathsome unto thy people, save they shall repent of their iniquities.
31865	1216	23	And cursed shall be the seed of him that mixeth with their seed; for they shall be cursed even with the same cursing. And the Lord spake it, and it was done.
31866	1216	24	And because of their cursing which was upon them they did become an idle people, full of mischief and subtlety, and did seek in the wilderness for beasts of prey.
31867	1216	25	And the Lord God said unto me: They shall be a scourge unto thy seed, to stir them up in remembrance of me; and inasmuch as they will not remember me, and hearken unto my words, they shall scourge them even unto destruction.
31868	1216	26	And it came to pass that I, Nephi, did consecrate Jacob and Joseph, that they should be priests and teachers over the land of my people.
31869	1216	27	And it came to pass that we lived after the manner of happiness.
31870	1216	28	And thirty years had passed away from the time we left Jerusalem.
31871	1216	29	And I, Nephi, had kept the records upon my plates, which I had made, of my people thus far.
31872	1216	30	And it came to pass that the Lord God said unto me: Make other plates; and thou shalt engraven many things upon them which are good in my sight, for the profit of thy people.
31873	1216	31	Wherefore, I, Nephi, to be obedient to the commandments of the Lord, went and made these plates upon which I have engraven these things.
31874	1216	32	And I engraved that which is pleasing unto God. And if my people are pleased with the things of God they will be pleased with mine engravings which are upon these plates.
31875	1216	33	And if my people desire to know the more particular part of the history of my people they must search mine other plates.
31876	1216	34	And it sufficeth me to say that forty years had passed away, and we had already had wars and contentions with our brethren.
31877	1217	1	The words of Jacob, the brother of Nephi, which he spake unto the people of Nephi:
31878	1217	2	Behold, my beloved brethren, I, Jacob, having been called of God, and ordained after the manner of his holy order, and having been consecrated by my brother Nephi, unto whom ye look as a king or a protector, and on whom ye depend for safety, behold ye know that I have spoken unto you exceedingly many things.
31879	1217	3	Nevertheless, I speak unto you again; for I am desirous for the welfare of your souls. Yea, mine anxiety is great for you; and ye yourselves know that it ever has been. For I have exhorted you with all diligence; and I have taught you the words of my father; and I have spoken unto you concerning all things which are written, from the creation of the world.
31880	1217	4	And now, behold, I would speak unto you concerning things which are, and which are to come; wherefore, I will read you the words of Isaiah. And they are the words which my brother has desired that I should speak unto you. And I speak unto you for your sakes, that ye may learn and glorify the name of your God.
31881	1217	5	And now, the words which I shall read are they which Isaiah spake concerning all the house of Israel; wherefore, they may be likened unto you, for ye are of the house of Israel. And there are many things which have been spoken by Isaiah which may be likened unto you, because ye are of the house of Israel.
31882	1217	6	And now, these are the words: Thus saith the Lord God: Behold, I will lift up mine hand to the Gentiles, and set up my standard to the people; and they shall bring thy sons in their arms, and thy daughters shall be carried upon their shoulders.
31883	1217	7	And kings shall be thy nursing fathers, and their queens thy nursing mothers; they shall bow down to thee with their faces towards the earth, and lick up the dust of thy feet; and thou shalt know that I am the Lord; for they shall not be ashamed that wait for me.
31884	1217	8	And now I, Jacob, would speak somewhat concerning these words. For behold, the Lord has shown me that those who were at Jerusalem, from whence we came, have been slain and carried away captive.
31885	1217	9	Nevertheless, the Lord has shown unto me that they should return again. And he also has shown unto me that the Lord God, the Holy One of Israel, should manifest himself unto them in the flesh; and after he should manifest himself they should scourge him and crucify him, according to the words of the angel who spake it unto me.
31886	1217	10	And after they have hardened their hearts and stiffened their necks against the Holy One of Israel, behold, the judgments of the Holy One of Israel shall come upon them. And the day cometh that they shall be smitten and afflicted.
31887	1217	11	Wherefore, after they are driven to and fro, for thus saith the angel, many shall be afflicted in the flesh, and shall not be suffered to perish, because of the prayers of the faithful; they shall be scattered, and smitten, and hated; nevertheless, the Lord will be merciful unto them, that when they shall come to the knowledge of their Redeemer, they shall be gathered together again to the lands of their inheritance.
31888	1217	12	And blessed are the Gentiles, they of whom the prophet has written; for behold, if it so be that they shall repent and fight not against Zion, and do not unite themselves to that great and abominable church, they shall be saved; for the Lord God will fulfil his covenants which he has made unto his children; and for this cause the prophet has written these things.
31889	1217	13	Wherefore, they that fight against Zion and the covenant people of the Lord shall lick up the dust of their feet; and the people of the Lord shall not be ashamed. For the people of the Lord are they who wait for him; for they still wait for the coming of the Messiah.
31890	1217	14	And behold, according to the words of the prophet, the Messiah will set himself again the second time to recover them; wherefore, he will manifest himself unto them in power and great glory, unto the destruction of their enemies, when that day cometh when they shall believe in him; and none will he destroy that believe in him.
31891	1217	15	And they that believe not in him shall be destroyed, both by fire, and by tempest, and by earthquakes, and by bloodsheds, and by pestilence, and by famine. And they shall know that the Lord is God, the Holy One of Israel.
31892	1217	16	For shall the prey be taken from the mighty, or the lawful captive delivered?
31893	1217	17	But thus saith the Lord: Even the captives of the mighty shall be taken away, and the prey of the terrible shall be delivered; for the Mighty God shall deliver his covenant people. For thus saith the Lord: I will contend with them that contendeth with thee--
31894	1217	18	And I will feed them that oppress thee, with their own flesh; and they shall be drunken with their own blood as with sweet wine; and all flesh shall know that I the Lord am thy Savior and thy Redeemer, the Mighty One of Jacob.
31895	1218	1	Yea, for thus saith the Lord: Have I put thee away, or have I cast thee off forever? For thus saith the Lord: Where is the bill of your mother's divorcement? To whom have I put thee away, or to which of my creditors have I sold you? Yea, to whom have I sold you? Behold, for your iniquities have ye sold yourselves, and for your transgressions is your mother put away.
31896	1218	2	Wherefore, when I came, there was no man; when I called, yea, there was none to answer. O house of Israel, is my hand shortened at all that it cannot redeem, or have I no power to deliver? Behold, at my rebuke I dry up the sea, I make their rivers a wilderness and their fish to stink because the waters are dried up, and they die because of thirst.
31897	1218	3	I clothe the heavens with blackness, and I make sackcloth their covering.
31898	1218	4	The Lord God hath given me the tongue of the learned, that I should know how to speak a word in season unto thee, O house of Israel. When ye are weary he waketh morning by morning. He waketh mine ear to hear as the learned.
31899	1218	5	The Lord God hath opened mine ear, and I was not rebellious, neither turned away back.
31900	1218	6	I gave my back to the smiter, and my cheeks to them that plucked off the hair. I hid not my face from shame and spitting.
31901	1218	7	For the Lord God will help me, therefore shall I not be confounded. Therefore have I set my face like a flint, and I know that I shall not be ashamed.
31902	1218	8	And the Lord is near, and he justifieth me. Who will contend with me? Let us stand together. Who is mine adversary? Let him come near me, and I will smite him with the strength of my mouth.
31903	1218	9	For the Lord God will help me. And all they who shall condemn me, behold, all they shall wax old as a garment, and the moth shall eat them up.
31904	1218	10	Who is among you that feareth the Lord, that obeyeth the voice of his servant, that walketh in darkness and hath no light?
31905	1218	11	Behold all ye that kindle fire, that compass yourselves about with sparks, walk in the light of your fire and in the sparks which ye have kindled. This shall ye have of mine hand--ye shall lie down in sorrow.
31906	1219	1	Hearken unto me, ye that follow after righteousness. Look unto the rock from whence ye are hewn, and to the hole of the pit from whence ye are digged.
31907	1219	2	Look unto Abraham, your father, and unto Sarah, she that bare you; for I called him alone, and blessed him.
31908	1219	3	For the Lord shall comfort Zion, he will comfort all her waste places; and he will make her wilderness like Eden, and her desert like the garden of the Lord. Joy and gladness shall be found therein, thanksgiving and the voice of melody.
31909	1219	4	Hearken unto me, my people; and give ear unto me, O my nation; for a law shall proceed from me, and I will make my judgment to rest for a light for the people.
31910	1219	5	My righteousness is near; my salvation is gone forth, and mine arm shall judge the people. The isles shall wait upon me, and on mine arm shall they trust.
31911	1219	6	Lift up your eyes to the heavens, and look upon the earth beneath; for the heavens shall vanish away like smoke, and the earth shall wax old like a garment; and they that dwell therein shall die in like manner. But my salvation shall be forever, and my righteousness shall not be abolished.
31912	1219	7	Hearken unto me, ye that know righteousness, the people in whose heart I have written my law, fear ye not the reproach of men, neither be ye afraid of their revilings.
31913	1219	8	For the moth shall eat them up like a garment, and the worm shall eat them like wool. But my righteousness shall be forever, and my salvation from generation to generation.
31914	1219	9	Awake, awake! Put on strength, O arm of the Lord; awake as in the ancient days. Art thou not he that hath cut Rahab, and wounded the dragon?
31915	1219	10	Art thou not he who hath dried the sea, the waters of the great deep; that hath made the depths of the sea a way for the ransomed to pass over?
31916	1219	11	Therefore, the redeemed of the Lord shall return, and come with singing unto Zion; and everlasting joy and holiness shall be upon their heads; and they shall obtain gladness and joy; sorrow and mourning shall flee away.
31917	1219	12	I am he; yea, I am he that comforteth you. Behold, who art thou, that thou shouldst be afraid of man, who shall die, and of the son of man, who shall be made like unto grass?
31918	1219	13	And forgettest the Lord thy maker, that hath stretched forth the heavens, and laid the foundations of the earth, and hast feared continually every day, because of the fury of the oppressor, as if he were ready to destroy? And where is the fury of the oppressor?
31919	1219	14	The captive exile hasteneth, that he may be loosed, and that he should not die in the pit, nor that his bread should fail.
31920	1219	15	But I am the Lord thy God, whose waves roared; the Lord of Hosts is my name.
31921	1219	16	And I have put my words in thy mouth, and have covered thee in the shadow of mine hand, that I may plant the heavens and lay the foundations of the earth, and say unto Zion: Behold, thou art my people.
31922	1219	17	Awake, awake, stand up, O Jerusalem, which hast drunk at the hand of the Lord the cup of his fury--thou hast drunken the dregs of the cup of trembling wrung out--
31923	1219	18	And none to guide her among all the sons she hath brought forth; neither that taketh her by the hand, of all the sons she hath brought up.
31924	1219	19	These two sons are come unto thee, who shall be sorry for thee--thy desolation and destruction, and the famine and the sword--and by whom shall I comfort thee?
31925	1219	20	Thy sons have fainted, save these two; they lie at the head of all the streets; as a wild bull in a net, they are full of the fury of the Lord, the rebuke of thy God.
31926	1219	21	Therefore hear now this, thou afflicted, and drunken, and not with wine:
31927	1219	22	Thus saith thy Lord, the Lord and thy God pleadeth the cause of his people; behold, I have taken out of thine hand the cup of trembling, the dregs of the cup of my fury; thou shalt no more drink it again.
31928	1219	23	But I will put it into the hand of them that afflict thee; who have said to thy soul: Bow down, that we may go over--and thou hast laid thy body as the ground and as the street to them that went over.
31929	1219	24	Awake, awake, put on thy strength, O Zion; put on thy beautiful garments, O Jerusalem, the holy city; for henceforth there shall no more come into thee the uncircumcised and the unclean.
31930	1219	25	Shake thyself from the dust; arise, sit down, O Jerusalem; loose thyself from the bands of thy neck, O captive daughter of Zion.
31931	1220	1	And now, my beloved brethren, I have read these things that ye might know concerning the covenants of the Lord that he has covenanted with all the house of Israel--
31932	1220	2	That he has spoken unto the Jews, by the mouth of his holy prophets, even from the beginning down, from generation to generation, until the time comes that they shall be restored to the true church and fold of God; when they shall be gathered home to the lands of their inheritance, and shall be established in all their lands of promise.
31933	1220	3	Behold, my beloved brethren, I speak unto you these things that ye may rejoice, and lift up your heads forever, because of the blessings which the Lord God shall bestow upon your children.
31934	1220	4	For I know that ye have searched much, many of you, to know of things to come; wherefore I know that ye know that our flesh must waste away and die; nevertheless, in our bodies we shall see God.
31935	1220	5	Yea, I know that ye know that in the body he shall show himself unto those at Jerusalem, from whence we came; for it is expedient that it should be among them; for it behooveth the great Creator that he suffereth himself to become subject unto man in the flesh, and die for all men, that all men might become subject unto him.
31936	1220	6	For as death hath passed upon all men, to fulfil the merciful plan of the great Creator, there must needs be a power of resurrection, and the resurrection must needs come unto man by reason of the fall; and the fall came by reason of transgression; and because man became fallen they were cut off from the presence of the Lord.
31937	1220	7	Wherefore, it must needs be an infinite atonement--save it should be an infinite atonement this corruption could not put on incorruption. Wherefore, the first judgment which came upon man must needs have remained to an endless duration. And if so, this flesh must have laid down to rot and to crumble to its mother earth, to rise no more.
31938	1220	8	O the wisdom of God, his mercy and grace! For behold, if the flesh should rise no more our spirits must become subject to that angel who fell from before the presence of the Eternal God, and became the devil, to rise no more.
31939	1220	9	And our spirits must have become like unto him, and we become devils, angels to a devil, to be shut out from the presence of our God, and to remain with the father of lies, in misery, like unto himself; yea, to that being who beguiled our first parents, who transformeth himself nigh unto an angel of light, and stirreth up the children of men unto secret combinations of murder and all manner of secret works of darkness.
31940	1220	10	O how great the goodness of our God, who prepareth a way for our escape from the grasp of this awful monster; yea, that monster, death and hell, which I call the death of the body, and also the death of the spirit.
31941	1220	11	And because of the way of deliverance of our God, the Holy One of Israel, this death, of which I have spoken, which is the temporal, shall deliver up its dead; which death is the grave.
31942	1220	12	And this death of which I have spoken, which is the spiritual death, shall deliver up its dead; which spiritual death is hell; wherefore, death and hell must deliver up their dead, and hell must deliver up its captive spirits, and the grave must deliver up its captive bodies, and the bodies and the spirits of men will be restored one to the other; and it is by the power of the resurrection of the Holy One of Israel.
31943	1220	13	O how great the plan of our God! For on the other hand, the paradise of God must deliver up the spirits of the righteous, and the grave deliver up the body of the righteous; and the spirit and the body is restored to itself again, and all men become incorruptible, and immortal, and they are living souls, having a perfect knowledge like unto us in the flesh, save it be that our knowledge shall be perfect.
31944	1220	14	Wherefore, we shall have a perfect knowledge of all our guilt, and our uncleanness, and our nakedness; and the righteous shall have a perfect knowledge of their enjoyment, and their righteousness, being clothed with purity, yea, even with the robe of righteousness.
31945	1220	15	And it shall come to pass that when all men shall have passed from this first death unto life, insomuch as they have become immortal, they must appear before the judgment-seat of the Holy One of Israel; and then cometh the judgment, and then must they be judged according to the holy judgment of God.
31946	1220	16	And assuredly, as the Lord liveth, for the Lord God hath spoken it, and it is his eternal word, which cannot pass away, that they who are righteous shall be righteous still, and they who are filthy shall be filthy still; wherefore, they who are filthy are the devil and his angels; and they shall go away into everlasting fire, prepared for them; and their torment is as a lake of fire and brimstone, whose flame ascendeth up forever and ever and has no end.
31947	1220	17	O the greatness and the justice of our God! For he executeth all his words, and they have gone forth out of his mouth, and his law must be fulfilled.
31948	1220	18	But, behold, the righteous, the saints of the Holy One of Israel, they who have believed in the Holy One of Israel, they who have endured the crosses of the world, and despised the shame of it, they shall inherit the kingdom of God, which was prepared for them from the foundation of the world, and their joy shall be full forever.
31949	1220	19	O the greatness of the mercy of our God, the Holy One of Israel! For he delivereth his saints from that awful monster the devil, and death, and hell, and that lake of fire and brimstone, which is endless torment.
31950	1220	20	O how great the holiness of our God! For he knoweth all things, and there is not anything save he knows it.
31951	1220	21	And he cometh into the world that he may save all men if they will hearken unto his voice; for behold, he suffereth the pains of all men, yea, the pains of every living creature, both men, women, and children, who belong to the family of Adam.
31952	1220	22	And he suffereth this that the resurrection might pass upon all men, that all might stand before him at the great and judgment day.
31953	1220	23	And he commandeth all men that they must repent, and be baptized in his name, having perfect faith in the Holy One of Israel, or they cannot be saved in the kingdom of God.
31954	1220	24	And if they will not repent and believe in his name, and be baptized in his name, and endure to the end, they must be damned; for the Lord God, the Holy One of Israel, has spoken it.
31955	1220	25	Wherefore, he has given a law; and where there is no law given there is no punishment; and where there is no punishment there is no condemnation; and where there is no condemnation the mercies of the Holy One of Israel have claim upon them, because of the atonement; for they are delivered by the power of him.
31956	1220	26	For the atonement satisfieth the demands of his justice upon all those who have not the law given to them, that they are delivered from that awful monster, death and hell, and the devil, and the lake of fire and brimstone, which is endless torment; and they are restored to that God who gave them breath, which is the Holy One of Israel.
31957	1220	27	But wo unto him that has the law given, yea, that has all the commandments of God, like unto us, and that transgresseth them, and that wasteth the days of his probation, for awful is his state!
31958	1220	28	O that cunning plan of the evil one! O the vainness, and the frailties, and the foolishness of men! When they are learned they think they are wise, and they hearken not unto the counsel of God, for they set it aside, supposing they know of themselves, wherefore, their wisdom is foolishness and it profiteth them not. And they shall perish.
31959	1220	29	But to be learned is good if they hearken unto the counsels of God.
31960	1220	30	But wo unto the rich, who are rich as to the things of the world. For because they are rich they despise the poor, and they persecute the meek, and their hearts are upon their treasures; wherefore, their treasure is their god. And behold, their treasure shall perish with them also.
31961	1220	31	And wo unto the deaf that will not hear; for they shall perish.
31962	1220	32	Wo unto the blind that will not see; for they shall perish also.
31963	1220	33	Wo unto the uncircumcised of heart, for a knowledge of their iniquities shall smite them at the last day.
31964	1220	34	Wo unto the liar, for he shall be thrust down to hell.
31965	1220	35	Wo unto the murderer who deliberately killeth, for he shall die.
31966	1220	36	Wo unto them who commit whoredoms, for they shall be thrust down to hell.
31967	1220	37	Yea, wo unto those that worship idols, for the devil of all devils delighteth in them.
31968	1220	38	And, in fine, wo unto all those who die in their sins; for they shall return to God, and behold his face, and remain in their sins.
31969	1220	39	O, my beloved brethren, remember the awfulness in transgressing against that Holy God, and also the awfulness of yielding to the enticings of that cunning one. Remember, to be carnally-minded is death, and to be spiritually-minded is life eternal.
31970	1220	40	O, my beloved brethren, give ear to my words. Remember the greatness of the Holy One of Israel. Do not say that I have spoken hard things against you; for if ye do, ye will revile against the truth; for I have spoken the words of your Maker. I know that the words of truth are hard against all uncleanness; but the righteous fear them not, for they love the truth and are not shaken.
31971	1220	41	O then, my beloved brethren, come unto the Lord, the Holy One. Remember that his paths are righteous. Behold, the way for man is narrow, but it lieth in a straight course before him, and the keeper of the gate is the Holy One of Israel; and he employeth no servant there; and there is none other way save it be by the gate; for he cannot be deceived, for the Lord God is his name.
31972	1220	42	And whoso knocketh, to him will he open; and the wise, and the learned, and they that are rich, who are puffed up because of their learning, and their wisdom, and their riches--yea, they are they whom he despiseth; and save they shall cast these things away, and consider themselves fools before God, and come down in the depths of humility, he will not open unto them.
31973	1220	43	But the things of the wise and the prudent shall be hid from them forever--yea, that happiness which is prepared for the saints.
31974	1220	44	O, my beloved brethren, remember my words. Behold, I take off my garments, and I shake them before you; I pray the God of my salvation that he view me with his all-searching eye; wherefore, ye shall know at the last day, when all men shall be judged of their works, that the God of Israel did witness that I shook your iniquities from my soul, and that I stand with brightness before him, and am rid of your blood.
31975	1220	45	O, my beloved brethren, turn away from your sins; shake off the chains of him that would bind you fast; come unto that God who is the rock of your salvation.
31976	1220	46	Prepare your souls for that glorious day when justice shall be administered unto the righteous, even the day of judgment, that ye may not shrink with awful fear; that ye may not remember your awful guilt in perfectness, and be constrained to exclaim: Holy, holy are thy judgments, O Lord God Almighty--but I know my guilt; I transgressed thy law, and my transgressions are mine; and the devil hath obtained me, that I am a prey to his awful misery.
31977	1220	47	But behold, my brethren, is it expedient that I should awake you to an awful reality of these things? Would I harrow up your souls if your minds were pure? Would I be plain unto you according to the plainness of the truth if ye were freed from sin?
31978	1220	48	Behold, if ye were holy I would speak unto you of holiness; but as ye are not holy, and ye look upon me as a teacher, it must needs be expedient that I teach you the consequences of sin.
31979	1220	49	Behold, my soul abhorreth sin, and my heart delighteth in righteousness; and I will praise the holy name of my God.
31980	1220	50	Come, my brethren, every one that thirsteth, come ye to the waters; and he that hath no money, come buy and eat; yea, come buy wine and milk without money and without price.
31981	1220	51	Wherefore, do not spend money for that which is of no worth, nor your labor for that which cannot satisfy. Hearken diligently unto me, and remember the words which I have spoken; and come unto the Holy One of Israel, and feast upon that which perisheth not, neither can be corrupted, and let your soul delight in fatness.
31982	1220	52	Behold, my beloved brethren, remember the words of your God; pray unto him continually by day, and give thanks unto his holy name by night. Let your hearts rejoice.
31983	1220	53	And behold how great the covenants of the Lord, and how great his condescensions unto the children of men; and because of his greatness, and his grace and mercy, he has promised unto us that our seed shall not utterly be destroyed, according to the flesh, but that he would preserve them; and in future generations they shall become a righteous branch unto the house of Israel.
31984	1220	54	And now, my brethren, I would speak unto you more; but on the morrow I will declare unto you the remainder of my words. Amen.
31985	1221	1	And now I, Jacob, speak unto you again, my beloved brethren, concerning this righteous branch of which I have spoken.
31986	1221	2	For behold, the promises which we have obtained are promises unto us according to the flesh; wherefore, as it has been shown unto me that many of our children shall perish in the flesh because of unbelief, nevertheless, God will be merciful unto many; and our children shall be restored, that they may come to that which will give them the true knowledge of their Redeemer.
31987	1221	3	Wherefore, as I said unto you, it must needs be expedient that Christ--for in the last night the angel spake unto me that this should be his name--should come among the Jews, among those who are the more wicked part of the world; and they shall crucify him--for thus it behooveth our God, and there is none other nation on earth that would crucify their God.
31988	1221	4	For should the mighty miracles be wrought among other nations they would repent, and know that he be their God.
31989	1221	5	But because of priestcrafts and iniquities, they at Jerusalem will stiffen their necks against him, that he be crucified.
31990	1221	6	Wherefore, because of their iniquities, destructions, famines, pestilences, and bloodshed shall come upon them; and they who shall not be destroyed shall be scattered among all nations.
31991	1221	7	But behold, thus saith the Lord God: When the day cometh that they shall believe in me, that I am Christ, then have I covenanted with their fathers that they shall be restored in the flesh, upon the earth, unto the lands of their inheritance.
31992	1221	8	And it shall come to pass that they shall be gathered in from their long dispersion, from the isles of the sea, and from the four parts of the earth; and the nations of the Gentiles shall be great in the eyes of me, saith God, in carrying them forth to the lands of their inheritance.
31993	1221	9	Yea, the kings of the Gentiles shall be nursing fathers unto them, and their queens shall become nursing mothers; wherefore, the promises of the Lord are great unto the Gentiles, for he hath spoken it, and who can dispute?
31994	1221	10	But behold, this land, said God, shall be a land of thine inheritance, and the Gentiles shall be blessed upon the land.
31995	1221	11	And this land shall be a land of liberty unto the Gentiles, and there shall be no kings upon the land, who shall raise up unto the Gentiles.
31996	1221	12	And I will fortify this land against all other nations.
31997	1221	13	And he that fighteth against Zion shall perish, saith God.
31998	1221	14	For he that raiseth up a king against me shall perish, for I, the Lord, the king of heaven, will be their king, and I will be a light unto them forever, that hear my words.
31999	1221	15	Wherefore, for this cause, that my covenants may be fulfilled which I have made unto the children of men, that I will do unto them while they are in the flesh, I must needs destroy the secret works of darkness, and of murders, and of abominations.
32000	1221	16	Wherefore, he that fighteth against Zion, both Jew and Gentile, both bond and free, both male and female, shall perish; for they are they who are the whore of all the earth; for they who are not for me are against me, saith our God.
32001	1221	17	For I will fulfil my promises which I have made unto the children of men, that I will do unto them while they are in the flesh--
32002	1221	18	Wherefore, my beloved brethren, thus saith our God: I will afflict thy seed by the hand of the Gentiles; nevertheless, I will soften the hearts of the Gentiles, that they shall be like unto a father to them; wherefore, the Gentiles shall be blessed and numbered among the house of Israel.
32003	1221	19	Wherefore, I will consecrate this land unto thy seed, and them who shall be numbered among thy seed, forever, for the land of their inheritance; for it is a choice land, saith God unto me, above all other lands, wherefore I will have all men that dwell thereon that they shall worship me, saith God.
32004	1221	20	And now, my beloved brethren, seeing that our merciful God has given us so great knowledge concerning these things, let us remember him, and lay aside our sins, and not hang down our heads, for we are not cast off; nevertheless, we have been driven out of the land of our inheritance; but we have been led to a better land, for the Lord has made the sea our path, and we are upon an isle of the sea.
32005	1221	21	But great are the promises of the Lord unto them who are upon the isles of the sea; wherefore as it says isles, there must needs be more than this, and they are inhabited also by our brethren.
32006	1221	22	For behold, the Lord God has led away from time to time from the house of Israel, according to his will and pleasure. And now behold, the Lord remembereth all them who have been broken off, wherefore he remembereth us also.
32007	1221	23	Therefore, cheer up your hearts, and remember that ye are free to act for yourselves--to choose the way of everlasting death or the way of eternal life.
32008	1221	24	Wherefore, my beloved brethren, reconcile yourselves to the will of God, and not to the will of the devil and the flesh; and remember, after ye are reconciled unto God, that it is only in and through the grace of God that ye are saved.
32009	1221	25	Wherefore, may God raise you from death by the power of the resurrection, and also from everlasting death by the power of the atonement, that ye may be received into the eternal kingdom of God, that ye may praise him through grace divine. Amen.
32010	1222	1	And now, Jacob spake many more things to my people at that time; nevertheless only these things have I caused to be written, for the things which I have written sufficeth me.
32011	1222	2	And now I, Nephi, write more of the words of Isaiah, for my soul delighteth in his words. For I will liken his words unto my people, and I will send them forth unto all my children, for he verily saw my Redeemer, even as I have seen him.
32012	1222	3	And my brother, Jacob, also has seen him as I have seen him; wherefore, I will send their words forth unto my children to prove unto them that my words are true. Wherefore, by the words of three, God hath said, I will establish my word. Nevertheless, God sendeth more witnesses, and he proveth all his words.
32013	1222	4	Behold, my soul delighteth in proving unto my people the truth of the coming of Christ; for, for this end hath the law of Moses been given; and all things which have been given of God from the beginning of the world, unto man, are the typifying of him.
32014	1222	5	And also my soul delighteth in the covenants of the Lord which he hath made to our fathers; yea, my soul delighteth in his grace, and in his justice, and power, and mercy in the great and eternal plan of deliverance from death.
32015	1222	6	And my soul delighteth in proving unto my people that save Christ should come all men must perish.
32016	1222	7	For if there be no Christ there be no God; and if there be no God we are not, for there could have been no creation. But there is a God, and he is Christ, and he cometh in the fulness of his own time.
32017	1222	8	And now I write some of the words of Isaiah, that whoso of my people shall see these words may lift up their hearts and rejoice for all men. Now these are the words, and ye may liken them unto you and unto all men.
32018	1223	1	The word that Isaiah, the son of Amoz, saw concerning Judah and Jerusalem:
32019	1223	2	And it shall come to pass in the last days, when the mountain of the Lord's house shall be established in the top of the mountains, and shall be exalted above the hills, and all nations shall flow unto it.
32020	1223	3	And many people shall go and say, Come ye, and let us go up to the mountain of the Lord, to the house of the God of Jacob; and he will teach us of his ways, and we will walk in his paths; for out of Zion shall go forth the law, and the word of the Lord from Jerusalem.
32021	1223	4	And he shall judge among the nations, and shall rebuke many people: and they shall beat their swords into plow-shares, and their spears into pruning-hooks--nation shall not lift up sword against nation, neither shall they learn war any more.
32022	1223	5	O house of Jacob, come ye and let us walk in the light of the Lord; yea, come, for ye have all gone astray, every one to his wicked ways.
32023	1223	6	Therefore, O Lord, thou hast forsaken thy people, the house of Jacob, because they be replenished from the east, and hearken unto soothsayers like the Philistines, and they please themselves in the children of strangers.
32024	1223	7	Their land also is full of silver and gold, neither is there any end of their treasures; their land is also full of horses, neither is there any end of their chariots.
32025	1223	8	Their land is also full of idols; they worship the work of their own hands, that which their own fingers have made.
32026	1223	9	And the mean man boweth not down, and the great man humbleth himself not, therefore, forgive him not.
32027	1223	10	O ye wicked ones, enter into the rock, and hide thee in the dust, for the fear of the Lord and the glory of his majesty shall smite thee.
32028	1223	11	And it shall come to pass that the lofty looks of man shall be humbled, and the haughtiness of men shall be bowed down, and the Lord alone shall be exalted in that day.
32029	1223	12	For the day of the Lord of Hosts soon cometh upon all nations, yea, upon every one; yea, upon the proud and lofty, and upon every one who is lifted up, and he shall be brought low.
32030	1223	13	Yea, and the day of the Lord shall come upon all the cedars of Lebanon, for they are high and lifted up; and upon all the oaks of Bashan;
32031	1223	14	And upon all the high mountains, and upon all the hills, and upon all the nations which are lifted up, and upon every people;
32032	1223	15	And upon every high tower, and upon every fenced wall;
32033	1223	16	And upon all the ships of the sea, and upon all the ships of Tarshish, and upon all pleasant pictures.
32034	1223	17	And the loftiness of man shall be bowed down, and the haughtiness of men shall be made low; and the Lord alone shall be exalted in that day.
32035	1223	18	And the idols he shall utterly abolish.
32036	1223	19	And they shall go into the holes of the rocks, and into the caves of the earth, for the fear of the Lord shall come upon them and the glory of his majesty shall smite them, when he ariseth to shake terribly the earth.
32037	1223	20	In that day a man shall cast his idols of silver, and his idols of gold, which he hath made for himself to worship, to the moles and to the bats;
32038	1223	21	To go into the clefts of the rocks, and into the tops of the ragged rocks, for the fear of the Lord shall come upon them and the majesty of his glory shall smite them, when he ariseth to shake terribly the earth.
32039	1223	22	Cease ye from man, whose breath is in his nostrils; for wherein is he to be accounted of?
32040	1224	1	For behold, the Lord, the Lord of Hosts, doth take away from Jerusalem, and from Judah, the stay and the staff, the whole staff of bread, and the whole stay of water--
32041	1224	2	The mighty man, and the man of war, the judge, and the prophet, and the prudent, and the ancient;
32042	1224	3	The captain of fifty, and the honorable man, and the counselor, and the cunning artificer, and the eloquent orator.
32043	1224	4	And I will give children unto them to be their princes, and babes shall rule over them.
32044	1224	5	And the people shall be oppressed, every one by another, and every one by his neighbor; the child shall behave himself proudly against the ancient, and the base against the honorable.
32045	1224	6	When a man shall take hold of his brother of the house of his father, and shall say: Thou hast clothing, be thou our ruler, and let not this ruin come under thy hand--
32046	1224	7	In that day shall he swear, saying: I will not be a healer; for in my house there is neither bread nor clothing; make me not a ruler of the people.
32047	1224	8	For Jerusalem is ruined, and Judah is fallen, because their tongues and their doings have been against the Lord, to provoke the eyes of his glory.
32048	1224	9	The show of their countenance doth witness against them, and doth declare their sin to be even as Sodom, and they cannot hide it. Wo unto their souls, for they have rewarded evil unto themselves!
32049	1224	10	Say unto the righteous that it is well with them; for they shall eat the fruit of their doings.
32050	1224	11	Wo unto the wicked, for they shall perish; for the reward of their hands shall be upon them!
32051	1224	12	And my people, children are their oppressors, and women rule over them. O my people, they who lead thee cause thee to err and destroy the way of thy paths.
32052	1224	13	The Lord standeth up to plead, and standeth to judge the people.
32053	1224	14	The Lord will enter into judgment with the ancients of his people and the princes thereof; for ye have eaten up the vineyard and the spoil of the poor in your houses.
32054	1224	15	What mean ye? Ye beat my people to pieces, and grind the faces of the poor, saith the Lord God of Hosts.
32055	1224	16	Moreover, the Lord saith: Because the daughters of Zion are haughty, and walk with stretched-forth necks and wanton eyes, walking and mincing as they go, and making a tinkling with their feet--
32056	1224	17	Therefore the Lord will smite with a scab the crown of the head of the daughters of Zion, and the Lord will discover their secret parts.
32057	1224	18	In that day the Lord will take away the bravery of their tinkling ornaments, and cauls, and round tires like the moon;
32058	1224	19	The chains and the bracelets, and the mufflers;
32059	1224	20	The bonnets, and the ornaments of the legs, and the headbands, and the tablets, and the ear-rings;
32060	1224	21	The rings, and nose jewels;
32061	1224	22	The changeable suits of apparel, and the mantles, and the wimples, and the crisping-pins;
32062	1224	23	The glasses, and the fine linen, and hoods, and the veils.
32063	1224	24	And it shall come to pass, instead of sweet smell there shall be stink; and instead of a girdle, a rent; and instead of well set hair, baldness; and instead of a stomacher, a girding of sackcloth; burning instead of beauty.
32064	1224	25	Thy men shall fall by the sword and thy mighty in the war.
32065	1224	26	And her gates shall lament and mourn; and she shall be desolate, and shall sit upon the ground.
32066	1225	1	And in that day, seven women shall take hold of one man, saying: We will eat our own bread, and wear our own apparel; only let us be called by thy name to take away our reproach.
32067	1225	2	In that day shall the branch of the Lord be beautiful and glorious; the fruit of the earth excellent and comely to them that are escaped of Israel.
32068	1225	3	And it shall come to pass, they that are left in Zion and remain in Jerusalem shall be called holy, every one that is written among the living in Jerusalem--
32069	1225	4	When the Lord shall have washed away the filth of the daughters of Zion, and shall have purged the blood of Jerusalem from the midst thereof by the spirit of judgment and by the spirit of burning.
32070	1225	5	And the Lord will create upon every dwelling-place of mount Zion, and upon her assemblies, a cloud and smoke by day and the shining of a flaming fire by night; for upon all the glory of Zion shall be a defence.
32071	1225	6	And there shall be a tabernacle for a shadow in the daytime from the heat, and for a place of refuge, and a covert from storm and from rain.
32072	1226	1	And then will I sing to my well-beloved a song of my beloved, touching his vineyard. My well-beloved hath a vineyard in a very fruitful hill.
32073	1226	2	And he fenced it, and gathered out the stones thereof, and planted it with the choicest vine, and built a tower in the midst of it, and also made a wine-press therein; and he looked that it should bring forth grapes, and it brought forth wild grapes.
32074	1226	3	And now, O inhabitants of Jerusalem, and men of Judah, judge, I pray you, betwixt me and my vineyard.
32075	1226	4	What could have been done more to my vineyard that I have not done in it? Wherefore, when I looked that it should bring forth grapes it brought forth wild grapes.
32076	1226	5	And now go to; I will tell you what I will do to my vineyard--I will take away the hedge thereof, and it shall be eaten up; and I will break down the wall thereof, and it shall be trodden down;
32077	1226	6	And I will lay it waste; it shall not be pruned nor digged; but there shall come up briers and thorns; I will also command the clouds that they rain no rain upon it.
32078	1226	7	For the vineyard of the Lord of Hosts is the house of Israel, and the men of Judah his pleasant plant; and he looked for judgment, and behold, oppression; for righteousness, but behold, a cry.
32079	1226	8	Wo unto them that join house to house, till there can be no place, that they may be placed alone in the midst of the earth!
32080	1226	9	In mine ears, said the Lord of Hosts, of a truth many houses shall be desolate, and great and fair cities without inhabitant.
32081	1226	10	Yea, ten acres of vineyard shall yield one bath, and the seed of a homer shall yield an ephah.
32082	1226	11	Wo unto them that rise up early in the morning, that they may follow strong drink, that continue until night, and wine inflame them!
32083	1226	12	And the harp, and the viol, the tabret, and pipe, and wine are in their feasts; but they regard not the work of the Lord, neither consider the operation of his hands.
32084	1226	13	Therefore, my people are gone into captivity, because they have no knowledge; and their honorable men are famished, and their multitude dried up with thirst.
32085	1226	14	Therefore, hell hath enlarged herself, and opened her mouth without measure; and their glory, and their multitude, and their pomp, and he that rejoiceth, shall descend into it.
32086	1226	15	And the mean man shall be brought down, and the mighty man shall be humbled, and the eyes of the lofty shall be humbled.
32087	1226	16	But the Lord of Hosts shall be exalted in judgment, and God that is holy shall be sanctified in righteousness.
32088	1226	17	Then shall the lambs feed after their manner, and the waste places of the fat ones shall strangers eat.
32089	1226	18	Wo unto them that draw iniquity with cords of vanity, and sin as it were with a cart rope;
32090	1226	19	That say: Let him make speed, hasten his work, that we may see it; and let the counsel of the Holy One of Israel draw nigh and come, that we may know it.
32091	1226	20	Wo unto them that call evil good, and good evil, that put darkness for light, and light for darkness, that put bitter for sweet, and sweet for bitter!
32092	1226	21	Wo unto the wise in their own eyes and prudent in their own sight!
32093	1226	22	Wo unto the mighty to drink wine, and men of strength to mingle strong drink;
32094	1226	23	Who justify the wicked for reward, and take away the righteousness of the righteous from him!
32095	1226	24	Therefore, as the fire devoureth the stubble, and the flame consumeth the chaff, their root shall be rottenness, and their blossoms shall go up as dust; because they have cast away the law of the Lord of Hosts, and despised the word of the Holy One of Israel.
32096	1226	25	Therefore, is the anger of the Lord kindled against his people, and he hath stretched forth his hand against them, and hath smitten them; and the hills did tremble, and their carcasses were torn in the midst of the streets. For all this his anger is not turned away, but his hand is stretched out still.
32097	1226	26	And he will lift up an ensign to the nations from far, and will hiss unto them from the end of the earth; and behold, they shall come with speed swiftly; none shall be weary nor stumble among them.
32098	1226	27	None shall slumber nor sleep; neither shall the girdle of their loins be loosed, nor the latchet of their shoes be broken;
32099	1226	28	Whose arrows shall be sharp, and all their bows bent, and their horses' hoofs shall be counted like flint, and their wheels like a whirlwind, their roaring like a lion.
32100	1226	29	They shall roar like young lions; yea, they shall roar, and lay hold of the prey, and shall carry away safe, and none shall deliver.
32101	1226	30	And in that day they shall roar against them like the roaring of the sea; and if they look unto the land, behold, darkness and sorrow, and the light is darkened in the heavens thereof.
32102	1227	1	In the year that king Uzziah died, I saw also the Lord sitting upon a throne, high and lifted up, and his train filled the temple.
32103	1227	2	Above it stood the seraphim; each one had six wings; with twain he covered his face, and with twain he covered his feet, and with twain he did fly.
32104	1227	3	And one cried unto another, and said: Holy, holy, holy, is the Lord of Hosts; the whole earth is full of his glory.
32105	1227	4	And the posts of the door moved at the voice of him that cried, and the house was filled with smoke.
32106	1227	5	Then said I: Wo is unto me! for I am undone; because I am a man of unclean lips; and I dwell in the midst of a people of unclean lips; for mine eyes have seen the King, the Lord of Hosts.
32107	1227	6	Then flew one of the seraphim unto me, having a live coal in his hand, which he had taken with the tongs from off the altar;
32108	1227	7	And he laid it upon my mouth, and said: Lo, this has touched thy lips; and thine iniquity is taken away, and thy sin purged.
32109	1227	8	Also I heard the voice of the Lord, saying: Whom shall I send, and who will go for us? Then I said: Here am I; send me.
32110	1227	9	And he said: Go and tell this people--Hear ye indeed, but they understood not; and see ye indeed, but they perceived not.
32111	1227	10	Make the heart of this people fat, and make their ears heavy, and shut their eyes--lest they see with their eyes, and hear with their ears, and understand with their heart, and be converted and be healed.
32112	1227	11	Then said I: Lord, how long? And he said: Until the cities be wasted without inhabitant, and the houses without man, and the land be utterly desolate;
32113	1227	12	And the Lord have removed men far away, for there shall be a great forsaking in the midst of the land.
32114	1227	13	But yet there shall be a tenth, and they shall return, and shall be eaten, as a teil-tree, and as an oak whose substance is in them when they cast their leaves; so the holy seed shall be the substance thereof.
32115	1228	1	And it came to pass in the days of Ahaz the son of Jotham, the son of Uzziah, king of Judah, that Rezin, king of Syria, and Pekah the son of Remaliah, king of Israel, went up toward Jerusalem to war against it, but could not prevail against it.
32116	1228	2	And it was told the house of David, saying: Syria is confederate with Ephraim. And his heart was moved, and the heart of his people, as the trees of the wood are moved with the wind.
32117	1228	3	Then said the Lord unto Isaiah: Go forth now to meet Ahaz, thou and Shearjashub thy son, at the end of the conduit of the upper pool in the highway of the fuller's field;
32118	1228	4	And say unto him: Take heed, and be quiet; fear not, neither be faint-hearted for the two tails of these smoking firebrands, for the fierce anger of Rezin with Syria, and of the son of Remaliah.
32119	1228	5	Because Syria, Ephraim, and the son of Remaliah, have taken evil counsel against thee, saying:
32120	1228	6	Let us go up against Judah and vex it, and let us make a breach therein for us, and set a king in the midst of it, yea, the son of Tabeal.
32121	1228	7	Thus saith the Lord God: It shall not stand, neither shall it come to pass.
32122	1228	8	For the head of Syria is Damascus, and the head of Damascus, Rezin; and within three score and five years shall Ephraim be broken that it be not a people.
32123	1228	9	And the head of Ephraim is Samaria, and the head of Samaria is Remaliah's son. If ye will not believe surely ye shall not be established.
32124	1228	10	Moreover, the Lord spake again unto Ahaz, saying:
32125	1228	11	Ask thee a sign of the Lord thy God; ask it either in the depths, or in the heights above.
32126	1228	12	But Ahaz said: I will not ask, neither will I tempt the Lord.
32127	1228	13	And he said: Hear ye now, O house of David; is it a small thing for you to weary men, but will ye weary my God also?
32128	1228	14	Therefore, the Lord himself shall give you a sign--Behold, a virgin shall conceive, and shall bear a son, and shall call his name Immanuel.
32129	1228	15	Butter and honey shall he eat, that he may know to refuse the evil and to choose the good.
32130	1228	16	For before the child shall know to refuse the evil and choose the good, the land that thou abhorrest shall be forsaken of both her kings.
32131	1228	17	The Lord shall bring upon thee, and upon thy people, and upon thy father's house, days that have not come from the day that Ephraim departed from Judah, the king of Assyria.
32132	1228	18	And it shall come to pass in that day that the Lord shall hiss for the fly that is in the uttermost part of Egypt, and for the bee that is in the land of Assyria.
32133	1228	19	And they shall come, and shall rest all of them in the desolate valleys, and in the holes of the rocks, and upon all thorns, and upon all bushes.
32134	1228	20	In the same day shall the Lord shave with a razor that is hired, by them beyond the river, by the king of Assyria, the head, and the hair of the feet; and it shall also consume the beard.
32135	1228	21	And it shall come to pass in that day, a man shall nourish a young cow and two sheep;
32136	1228	22	And it shall come to pass, for the abundance of milk they shall give he shall eat butter; for butter and honey shall every one eat that is left in the land.
32137	1228	23	And it shall come to pass in that day, every place shall be, where there were a thousand vines at a thousand silverlings, which shall be for briers and thorns.
32138	1228	24	With arrows and with bows shall men come thither, because all the land shall become briers and thorns.
32139	1228	25	And all hills that shall be digged with the mattock, there shall not come thither the fear of briers and thorns; but it shall be for the sending forth of oxen, and the treading of lesser cattle.
32140	1229	1	Moreover, the word of the Lord said unto me: Take thee a great roll, and write in it with a man's pen, concerning Maher-shalal-hash-baz.
32141	1229	2	And I took unto me faithful witnesses to record, Uriah the priest, and Zechariah the son of Jeberechiah.
32142	1229	3	And I went unto the prophetess; and she conceived and bare a son. Then said the Lord to me: Call his name, Maher-shalal-hash-baz.
32143	1229	4	For behold, the child shall not have knowledge to cry, My father, and my mother, before the riches of Damascus and the spoil of Samaria shall be taken away before the king of Assyria.
32144	1229	5	The Lord spake also unto me again, saying:
32145	1229	6	Forasmuch as this people refuseth the waters of Shiloah that go softly, and rejoice in Rezin and Remaliah's son;
32146	1229	7	Now therefore, behold, the Lord bringeth up upon them the waters of the river, strong and many, even the king of Assyria and all his glory; and he shall come up over all his channels, and go over all his banks.
32147	1229	8	And he shall pass through Judah; he shall overflow and go over, he shall reach even to the neck; and the stretching out of his wings shall fill the breadth of thy land, O Immanuel.
32148	1229	9	Associate yourselves, O ye people, and ye shall be broken in pieces; and give ear all ye of far countries; gird yourselves, and ye shall be broken in pieces; gird yourselves, and ye shall be broken in pieces.
32149	1229	10	Take counsel together, and it shall come to naught; speak the word, and it shall not stand; for God is with us.
32150	1229	11	For the Lord spake thus to me with a strong hand, and instructed me that I should not walk in the way of this people, saying:
32151	1229	12	Say ye not, A confederacy, to all to whom this people shall say, A confederacy; neither fear ye their fear, nor be afraid.
32152	1229	13	Sanctify the Lord of Hosts himself, and let him be your fear, and let him be your dread.
32153	1229	14	And he shall be for a sanctuary; but for a stone of stumbling, and for a rock of offense to both the houses of Israel, for a gin and a snare to the inhabitants of Jerusalem.
32154	1229	15	And many among them shall stumble and fall, and be broken, and be snared, and be taken.
32155	1229	16	Bind up the testimony, seal the law among my disciples.
32156	1229	17	And I will wait upon the Lord, that hideth his face from the house of Jacob, and I will look for him.
32157	1229	18	Behold, I and the children whom the Lord hath given me are for signs and for wonders in Israel from the Lord of Hosts, which dwelleth in Mount Zion.
32158	1229	19	And when they shall say unto you: Seek unto them that have familiar spirits, and unto wizards that peep and mutter--should not a people seek unto their God for the living to hear from the dead?
32159	1229	20	To the law and to the testimony; and if they speak not according to this word, it is because there is no light in them.
32160	1229	21	And they shall pass through it hardly bestead and hungry; and it shall come to pass that when they shall be hungry, they shall fret themselves, and curse their king and their God, and look upward.
32161	1229	22	And they shall look unto the earth and behold trouble, and darkness, dimness of anguish, and shall be driven to darkness.
32162	1230	1	Nevertheless, the dimness shall not be such as was in her vexation, when at first he lightly afflicted the land of Zebulun, and the land of Naphtali, and afterwards did more grievously afflict by the way of the Red Sea beyond Jordan in Galilee of the nations.
32163	1230	2	The people that walked in darkness have seen a great light; they that dwell in the land of the shadow of death, upon them hath the light shined.
32164	1230	3	Thou hast multiplied the nation, and increased the joy--they joy before thee according to the joy in harvest, and as men rejoice when they divide the spoil.
32165	1230	4	For thou hast broken the yoke of his burden, and the staff of his shoulder, the rod of his oppressor.
32166	1230	5	For every battle of the warrior is with confused noise, and garments rolled in blood; but this shall be with burning and fuel of fire.
32167	1230	6	For unto us a child is born, unto us a son is given; and the government shall be upon his shoulder; and his name shall be called, Wonderful, Counselor, The Mighty God, The Everlasting Father, The Prince of Peace.
32168	1230	7	Of the increase of government and peace there is no end, upon the throne of David, and upon his kingdom to order it, and to establish it with judgment and with justice from henceforth, even forever. The zeal of the Lord of Hosts will perform this.
32169	1230	8	The Lord sent his word unto Jacob and it hath lighted upon Israel.
32170	1230	9	And all the people shall know, even Ephraim and the inhabitants of Samaria, that say in the pride and stoutness of heart:
32171	1230	10	The bricks are fallen down, but we will build with hewn stones; the sycamores are cut down, but we will change them into cedars.
32172	1230	11	Therefore the Lord shall set up the adversaries of Rezin against him, and join his enemies together;
32173	1230	12	The Syrians before and the Philistines behind; and they shall devour Israel with open mouth. For all this his anger is not turned away, but his hand is stretched out still.
32174	1230	13	For the people turneth not unto him that smiteth them, neither do they seek the Lord of Hosts.
32175	1230	14	Therefore will the Lord cut off from Israel head and tail, branch and rush in one day.
32176	1230	15	The ancient, he is the head; and the prophet that teacheth lies, he is the tail.
32177	1230	16	For the leaders of this people cause them to err; and they that are led of them are destroyed.
32178	1230	17	Therefore the Lord shall have no joy in their young men, neither shall have mercy on their fatherless and widows; for every one of them is a hypocrite and an evildoer, and every mouth speaketh folly. For all this his anger is not turned away, but his hand is stretched out still.
32179	1230	18	For wickedness burneth as the fire; it shall devour the briers and thorns, and shall kindle in the thickets of the forests, and they shall mount up like the lifting up of smoke.
32180	1230	19	Through the wrath of the Lord of Hosts is the land darkened, and the people shall be as the fuel of the fire; no man shall spare his brother.
32181	1230	20	And he shall snatch on the right hand and be hungry; and he shall eat on the left hand and they shall not be satisfied; they shall eat every man the flesh of his own arm--
32182	1230	21	Manasseh, Ephraim; and Ephraim, Manasseh; they together shall be against Judah. For all this his anger is not turned away, but his hand is stretched out still.
32183	1231	1	Wo unto them that decree unrighteous decrees, and that write grievousness which they have prescribed;
32184	1231	2	To turn away the needy from judgment, and to take away the right from the poor of my people, that widows may be their prey, and that they may rob the fatherless!
32185	1231	3	And what will ye do in the day of visitation, and in the desolation which shall come from far? to whom will ye flee for help? and where will ye leave your glory?
32186	1231	4	Without me they shall bow down under the prisoners, and they shall fall under the slain. For all this his anger is not turned away, but his hand is stretched out still.
32187	1231	5	O Assyrian, the rod of mine anger, and the staff in their hand is their indignation.
32188	1231	6	I will send him against a hypocritical nation, and against the people of my wrath will I give him a charge to take the spoil, and to take the prey, and to tread them down like the mire of the streets.
32189	1231	7	Howbeit he meaneth not so, neither doth his heart think so; but in his heart it is to destroy and cut off nations not a few.
32190	1231	8	For he saith: Are not my princes altogether kings?
32191	1231	9	Is not Calno as Carchemish? Is not Hamath as Arpad? Is not Samaria as Damascus?
32192	1231	10	As my hand hath founded the kingdoms of the idols, and whose graven images did excel them of Jerusalem and of Samaria;
32193	1231	11	Shall I not, as I have done unto Samaria and her idols, so do to Jerusalem and to her idols?
32194	1231	12	Wherefore it shall come to pass that when the Lord hath performed his whole work upon Mount Zion and upon Jerusalem, I will punish the fruit of the stout heart of the king of Assyria, and the glory of his high looks.
32195	1231	13	For he saith: By the strength of my hand and by my wisdom I have done these things; for I am prudent; and I have moved the borders of the people, and have robbed their treasures, and I have put down the inhabitants like a valiant man;
32196	1231	14	And my hand hath found as a nest the riches of the people; and as one gathereth eggs that are left have I gathered all the earth; and there was none that moved the wing, or opened the mouth, or peeped.
32197	1231	15	Shall the ax boast itself against him that heweth therewith? Shall the saw magnify itself against him that shaketh it? As if the rod should shake itself against them that lift it up, or as if the staff should lift up itself as if it were no wood!
32198	1231	16	Therefore shall the Lord, the Lord of Hosts, send among his fat ones, leanness; and under his glory he shall kindle a burning like the burning of a fire.
32199	1231	17	And the light of Israel shall be for a fire, and his Holy One for a flame, and shall burn and shall devour his thorns and his briers in one day;
32200	1231	18	And shall consume the glory of his forest, and of his fruitful field, both soul and body; and they shall be as when a standard-bearer fainteth.
32201	1231	19	And the rest of the trees of his forest shall be few, that a child may write them.
32202	1231	20	And it shall come to pass in that day, that the remnant of Israel, and such as are escaped of the house of Jacob, shall no more again stay upon him that smote them, but shall stay upon the Lord, the Holy One of Israel, in truth.
32203	1231	21	The remnant shall return, yea, even the remnant of Jacob, unto the mighty God.
32204	1231	22	For though thy people Israel be as the sand of the sea, yet a remnant of them shall return; the consumption decreed shall overflow with righteousness.
32205	1231	23	For the Lord God of Hosts shall make a consumption, even determined in all the land.
32206	1231	24	Therefore, thus saith the Lord God of Hosts: O my people that dwellest in Zion, be not afraid of the Assyrian; he shall smite thee with a rod, and shall lift up his staff against thee, after the manner of Egypt.
32207	1231	25	For yet a very little while, and the indignation shall cease, and mine anger in their destruction.
32208	1231	26	And the Lord of Hosts shall stir up a scourge for him according to the slaughter of Midian at the rock of Oreb; and as his rod was upon the sea so shall he lift it up after the manner of Egypt.
32209	1231	27	And it shall come to pass in that day that his burden shall be taken away from off thy shoulder, and his yoke from off thy neck, and the yoke shall be destroyed because of the anointing.
32210	1231	28	He is come to Aiath, he is passed to Migron; at Michmash he hath laid up his carriages.
32211	1231	29	They are gone over the passage; they have taken up their lodging at Geba; Ramath is afraid; Gibeah of Saul is fled.
32212	1231	30	Lift up the voice, O daughter of Gallim; cause it to be heard unto Laish, O poor Anathoth.
32213	1231	31	Madmenah is removed; the inhabitants of Gebim gather themselves to flee.
32214	1231	32	As yet shall he remain at Nob that day; he shall shake his hand against the mount of the daughter of Zion, the hill of Jerusalem.
32215	1231	33	Behold, the Lord, the Lord of Hosts shall lop the bough with terror; and the high ones of stature shall be hewn down; and the haughty shall be humbled.
32216	1231	34	And he shall cut down the thickets of the forests with iron, and Lebanon shall fall by a mighty one.
32217	1232	1	And there shall come forth a rod out of the stem of Jesse, and a branch shall grow out of his roots.
32218	1232	2	And the Spirit of the Lord shall rest upon him, the spirit of wisdom and understanding, the spirit of counsel and might, the spirit of knowledge and of the fear of the Lord;
32219	1232	3	And shall make him of quick understanding in the fear of the Lord; and he shall not judge after the sight of his eyes, neither reprove after the hearing of his ears.
32220	1232	4	But with righteousness shall he judge the poor, and reprove with equity for the meek of the earth; and he shall smite the earth with the rod of his mouth, and with the breath of his lips shall he slay the wicked.
32221	1232	5	And righteousness shall be the girdle of his loins, and faithfulness the girdle of his reins.
32222	1232	6	The wolf also shall dwell with the lamb, and the leopard shall lie down with the kid, and the calf and the young lion and fatling together; and a little child shall lead them.
32223	1232	7	And the cow and the bear shall feed; their young ones shall lie down together; and the lion shall eat straw like the ox.
32224	1232	8	And the sucking child shall play on the hole of the asp, and the weaned child shall put his hand on the cockatrice's den.
32225	1232	9	They shall not hurt nor destroy in all my holy mountain, for the earth shall be full of the knowledge of the Lord, as the waters cover the sea.
32226	1232	10	And in that day there shall be a root of Jesse, which shall stand for an ensign of the people; to it shall the Gentiles seek; and his rest shall be glorious.
32227	1232	11	And it shall come to pass in that day that the Lord shall set his hand again the second time to recover the remnant of his people which shall be left, from Assyria, and from Egypt, and from Pathros, and from Cush, and from Elam, and from Shinar, and from Hamath, and from the islands of the sea.
32228	1232	12	And he shall set up an ensign for the nations, and shall assemble the outcasts of Israel, and gather together the dispersed of Judah from the four corners of the earth.
32229	1232	13	The envy of Ephraim also shall depart, and the adversaries of Judah shall be cut off; Ephraim shall not envy Judah, and Judah shall not vex Ephraim.
32230	1232	14	But they shall fly upon the shoulders of the Philistines towards the west; they shall spoil them of the east together; they shall lay their hand upon Edom and Moab; and the children of Ammon shall obey them.
32231	1232	15	And the Lord shall utterly destroy the tongue of the Egyptian sea; and with his mighty wind he shall shake his hand over the river, and shall smite it in the seven streams, and make men go over dry shod.
32232	1232	16	And there shall be a highway for the remnant of his people which shall be left, from Assyria, like as it was to Israel in the day that he came up out of the land of Egypt.
32233	1233	1	And in that day thou shalt say: O Lord, I will praise thee; though thou wast angry with me thine anger is turned away, and thou comfortedest me.
32234	1233	2	Behold, God is my salvation; I will trust, and not be afraid; for the Lord JEHOVAH is my strength and my song; he also has become my salvation.
32235	1233	3	Therefore, with joy shall ye draw water out of the wells of salvation.
32236	1233	4	And in that day shall ye say: Praise the Lord, call upon his name, declare his doings among the people, make mention that his name is exalted.
32237	1233	5	Sing unto the Lord; for he hath done excellent things; this is known in all the earth.
32238	1233	6	Cry out and shout, thou inhabitant of Zion; for great is the Holy One of Israel in the midst of thee.
32239	1234	1	The burden of Babylon, which Isaiah the son of Amoz did see.
32240	1234	2	Lift ye up a banner upon the high mountain, exalt the voice unto them, shake the hand, that they may go into the gates of the nobles.
32241	1234	3	I have commanded my sanctified ones, I have also called my mighty ones, for mine anger is not upon them that rejoice in my highness.
32242	1234	4	The noise of the multitude in the mountains like as of a great people, a tumultuous noise of the kingdoms of nations gathered together, the Lord of Hosts mustereth the hosts of the battle.
32243	1234	5	They come from a far country, from the end of heaven, yea, the Lord, and the weapons of his indignation, to destroy the whole land.
32244	1234	6	Howl ye, for the day of the Lord is at hand; it shall come as a destruction from the Almighty.
32245	1234	7	Therefore shall all hands be faint, every man's heart shall melt;
32246	1234	8	And they shall be afraid; pangs and sorrows shall take hold of them; they shall be amazed one at another; their faces shall be as flames.
32247	1234	9	Behold, the day of the Lord cometh, cruel both with wrath and fierce anger, to lay the land desolate; and he shall destroy the sinners thereof out of it.
32248	1234	10	For the stars of heaven and the constellations thereof shall not give their light; the sun shall be darkened in his going forth, and the moon shall not cause her light to shine.
32249	1234	11	And I will punish the world for evil, and the wicked for their iniquity; I will cause the arrogancy of the proud to cease, and will lay down the haughtiness of the terrible.
32250	1234	12	I will make a man more precious than fine gold; even a man than the golden wedge of Ophir.
32251	1234	13	Therefore, I will shake the heavens, and the earth shall remove out of her place, in the wrath of the Lord of Hosts, and in the day of his fierce anger.
32252	1234	14	And it shall be as the chased roe, and as a sheep that no man taketh up; and they shall every man turn to his own people, and flee every one into his own land.
32253	1234	15	Every one that is proud shall be thrust through; yea, and every one that is joined to the wicked shall fall by the sword.
32254	1234	16	Their children also shall be dashed to pieces before their eyes; their houses shall be spoiled and their wives ravished.
32255	1234	17	Behold, I will stir up the Medes against them, which shall not regard silver and gold, nor shall they delight in it.
32256	1234	18	Their bows shall also dash the young men to pieces; and they shall have no pity on the fruit of the womb; their eyes shall not spare children.
32257	1234	19	And Babylon, the glory of kingdoms, the beauty of the Chaldees' excellency, shall be as when God overthrew Sodom and Gomorrah.
32258	1234	20	It shall never be inhabited, neither shall it be dwelt in from generation to generation: neither shall the Arabian pitch tent there; neither shall the shepherds make their fold there.
32259	1234	21	But wild beasts of the desert shall lie there; and their houses shall be full of doleful creatures; and owls shall dwell there, and satyrs shall dance there.
32260	1234	22	And the wild beasts of the islands shall cry in their desolate houses, and dragons in their pleasant palaces; and her time is near to come, and her day shall not be prolonged. For I will destroy her speedily; yea, for I will be merciful unto my people, but the wicked shall perish.
32261	1235	1	For the Lord will have mercy on Jacob, and will yet choose Israel, and set them in their own land; and the strangers shall be joined with them, and they shall cleave to the house of Jacob.
32262	1235	2	And the people shall take them and bring them to their place; yea, from far unto the ends of the earth; and they shall return to their lands of promise. And the house of Israel shall possess them, and the land of the Lord shall be for servants and handmaids; and they shall take them captives unto whom they were captives; and they shall rule over their oppressors.
32263	1235	3	And it shall come to pass in that day that the Lord shall give thee rest, from thy sorrow, and from thy fear, and from the hard bondage wherein thou wast made to serve.
32264	1235	4	And it shall come to pass in that day, that thou shalt take up this proverb against the king of Babylon, and say: How hath the oppressor ceased, the golden city ceased!
32265	1235	5	The Lord hath broken the staff of the wicked, the scepters of the rulers.
32266	1235	6	He who smote the people in wrath with a continual stroke, he that ruled the nations in anger, is persecuted, and none hindereth.
32267	1235	7	The whole earth is at rest, and is quiet; they break forth into singing.
32268	1235	8	Yea, the fir-trees rejoice at thee, and also the cedars of Lebanon, saying: Since thou art laid down no feller is come up against us.
32269	1235	9	Hell from beneath is moved for thee to meet thee at thy coming; it stirreth up the dead for thee, even all the chief ones of the earth; it hath raised up from their thrones all the kings of the nations.
32270	1235	10	All they shall speak and say unto thee: Art thou also become weak as we? Art thou become like unto us?
32271	1235	11	Thy pomp is brought down to the grave; the noise of thy viols is not heard; the worm is spread under thee, and the worms cover thee.
32272	1235	12	How art thou fallen from heaven, O Lucifer, son of the morning! Art thou cut down to the ground, which did weaken the nations!
32273	1235	13	For thou hast said in thy heart: I will ascend into heaven, I will exalt my throne above the stars of God; I will sit also upon the mount of the congregation, in the sides of the north;
32274	1235	14	I will ascend above the heights of the clouds; I will be like the Most High.
32275	1235	15	Yet thou shalt be brought down to hell, to the sides of the pit.
32276	1235	16	They that see thee shall narrowly look upon thee, and shall consider thee, and shall say: Is this the man that made the earth to tremble, that did shake kingdoms?
32277	1235	17	And made the world as a wilderness, and destroyed the cities thereof, and opened not the house of his prisoners?
32278	1235	18	All the kings of the nations, yea, all of them, lie in glory, every one of them in his own house.
32279	1235	19	But thou art cast out of thy grave like an abominable branch, and the remnant of those that are slain, thrust through with a sword, that go down to the stones of the pit; as a carcass trodden under feet.
32280	1235	20	Thou shalt not be joined with them in burial, because thou hast destroyed thy land and slain thy people; the seed of evil-doers shall never be renowned.
32281	1235	21	Prepare slaughter for his children for the iniquities of their fathers, that they do not rise, nor possess the land, nor fill the face of the world with cities.
32282	1235	22	For I will rise up against them, saith the Lord of Hosts, and cut off from Babylon the name, and remnant, and son, and nephew, saith the Lord.
32283	1235	23	I will also make it a possession for the bittern, and pools of water; and I will sweep it with the besom of destruction, saith the Lord of Hosts.
32284	1235	24	The Lord of Hosts hath sworn, saying: Surely as I have thought, so shall it come to pass; and as I have purposed, so shall it stand--
32285	1235	25	That I will bring the Assyrian in my land, and upon my mountains tread him under foot; then shall his yoke depart from off them, and his burden depart from off their shoulders.
32286	1235	26	This is the purpose that is purposed upon the whole earth; and this is the hand that is stretched out upon all nations.
32287	1235	27	For the Lord of Hosts hath purposed, and who shall disannul? And his hand is stretched out, and who shall turn it back?
32288	1235	28	In the year that king Ahaz died was this burden.
32289	1235	29	Rejoice not thou, whole Palestina, because the rod of him that smote thee is broken; for out of the serpent's root shall come forth a cockatrice, and his fruit shall be a fiery flying serpent.
32290	1235	30	And the first-born of the poor shall feed, and the needy shall lie down in safety; and I will kill thy root with famine, and he shall slay thy remnant.
32291	1235	31	Howl, O gate; cry, O city; thou, whole Palestina, art dissolved; for there shall come from the north a smoke, and none shall be alone in his appointed times.
32292	1235	32	What shall then answer the messengers of the nations? That the Lord hath founded Zion, and the poor of his people shall trust in it.
32293	1236	1	Now I, Nephi, do speak somewhat concerning the words which I have written, which have been spoken by the mouth of Isaiah. For behold, Isaiah spake many things which were hard for many of my people to understand; for they know not concerning the manner of prophesying among the Jews.
32294	1236	2	For I, Nephi, have not taught them many things concerning the manner of the Jews; for their works were works of darkness, and their doings were doings of abominations.
32295	1236	3	Wherefore, I write unto my people, unto all those that shall receive hereafter these things which I write, that they may know the judgments of God, that they come upon all nations, according to the word which he hath spoken.
32296	1236	4	Wherefore, hearken, O my people, which are of the house of Israel, and give ear unto my words; for because the words of Isaiah are not plain unto you, nevertheless they are plain unto all those that are filled with the spirit of prophecy. But I give unto you a prophecy, according to the spirit which is in me; wherefore I shall prophesy according to the plainness which hath been with me from the time that I came out from Jerusalem with my father; for behold, my soul delighteth in plainness unto my people, that they may learn.
32297	1236	5	Yea, and my soul delighteth in the words of Isaiah, for I came out from Jerusalem, and mine eyes hath beheld the things of the Jews, and I know that the Jews do understand the things of the prophets, and there is none other people that understand the things which were spoken unto the Jews like unto them, save it be that they are taught after the manner of the things of the Jews.
32298	1236	6	But behold, I, Nephi, have not taught my children after the manner of the Jews; but behold, I, of myself, have dwelt at Jerusalem, wherefore I know concerning the regions round about; and I have made mention unto my children concerning the judgments of God, which hath come to pass among the Jews, unto my children, according to all that which Isaiah hath spoken, and I do not write them.
32299	1236	7	But behold, I proceed with mine own prophecy, according to my plainness; in the which I know that no man can err; nevertheless, in the days that the prophecies of Isaiah shall be fulfilled men shall know of a surety, at the times when they shall come to pass.
32300	1236	8	Wherefore, they are of worth unto the children of men, and he that supposeth that they are not, unto them will I speak particularly, and confine the words unto mine own people; for I know that they shall be of great worth unto them in the last days; for in that day shall they understand them; wherefore, for their good have I written them.
32301	1236	9	And as one generation hath been destroyed among the Jews because of iniquity, even so have they been destroyed from generation to generation according to their iniquities; and never hath any of them been destroyed save it were foretold them by the prophets of the Lord.
32302	1236	10	Wherefore, it hath been told them concerning the destruction which should come upon them, immediately after my father left Jerusalem; nevertheless, they hardened their hearts; and according to my prophecy they have been destroyed, save it be those which are carried away captive into Babylon.
32303	1236	11	And now this I speak because of the spirit which is in me. And notwithstanding they have been carried away they shall return again, and possess the land of Jerusalem; wherefore, they shall be restored again to the land of their inheritance.
32304	1236	12	But, behold, they shall have wars, and rumors of wars; and when the day cometh that the Only Begotten of the Father, yea, even the Father of heaven and of earth, shall manifest himself unto them in the flesh, behold, they will reject him, because of their iniquities, and the hardness of their hearts, and the stiffness of their necks.
32305	1236	13	Behold, they will crucify him; and after he is laid in a sepulchre for the space of three days he shall rise from the dead, with healing in his wings; and all those who shall believe on his name shall be saved in the kingdom of God. Wherefore, my soul delighteth to prophesy concerning him, for I have seen his day, and my heart doth magnify his holy name.
32306	1236	14	And behold it shall come to pass that after the Messiah hath risen from the dead, and hath manifested himself unto his people, unto as many as will believe on his name, behold, Jerusalem shall be destroyed again; for wo unto them that fight against God and the people of his church.
32307	1236	15	Wherefore, the Jews shall be scattered among all nations; yea, and also Babylon shall be destroyed; wherefore, the Jews shall be scattered by other nations.
32308	1236	16	And after they have been scattered, and the Lord God hath scourged them by other nations for the space of many generations, yea, even down from generation to generation until they shall be persuaded to believe in Christ, the Son of God, and the atonement, which is infinite for all mankind--and when that day shall come that they shall believe in Christ, and worship the Father in his name, with pure hearts and clean hands, and look not forward any more for another Messiah, then, at that time, the day will come that it must needs be expedient that they should believe these things.
32309	1236	17	And the Lord will set his hand again the second time to restore his people from their lost and fallen state. Wherefore, he will proceed to do a marvelous work and a wonder among the children of men.
32310	1236	18	Wherefore, he shall bring forth his words unto them, which words shall judge them at the last day, for they shall be given them for the purpose of convincing them of the true Messiah, who was rejected by them; and unto the convincing of them that they need not look forward any more for a Messiah to come, for there should not any come, save it should be a false Messiah which should deceive the people; for there is save one Messiah spoken of by the prophets, and that Messiah is he who should be rejected of the Jews.
32311	1236	19	For according to the words of the prophets, the Messiah cometh in six hundred years from the time that my father left Jerusalem; and according to the words of the prophets, and also the word of the angel of God, his name shall be Jesus Christ, the Son of God.
32312	1236	20	And now, my brethren, I have spoken plainly that ye cannot err. And as the Lord God liveth that brought Israel up out of the land of Egypt, and gave unto Moses power that he should heal the nations after they had been bitten by the poisonous serpents, if they would cast their eyes unto the serpent which he did raise up before them, and also gave him power that he should smite the rock and the water should come forth; yea, behold I say unto you, that as these things are true, and as the Lord God liveth, there is none other name given under heaven save it be this Jesus Christ, of which I have spoken, whereby man can be saved.
32313	1236	21	Wherefore, for this cause hath the Lord God promised unto me that these things which I write shall be kept and preserved, and handed down unto my seed, from generation to generation, that the promise may be fulfilled unto Joseph, that his seed should never perish as long as the earth should stand.
32314	1236	22	Wherefore, these things shall go from generation to generation as long as the earth shall stand; and they shall go according to the will and pleasure of God; and the nations who shall possess them shall be judged of them according to the words which are written.
32315	1236	23	For we labor diligently to write, to persuade our children, and also our brethren, to believe in Christ, and to be reconciled to God; for we know that it is by grace that we are saved, after all we can do.
32316	1236	24	And, notwithstanding we believe in Christ, we keep the law of Moses, and look forward with steadfastness unto Christ, until the law shall be fulfilled.
32317	1236	25	For, for this end was the law given; wherefore the law hath become dead unto us, and we are made alive in Christ because of our faith; yet we keep the law because of the commandments.
32318	1236	26	And we talk of Christ, we rejoice in Christ, we preach of Christ, we prophesy of Christ, and we write according to our prophecies, that our children may know to what source they may look for a remission of their sins.
32319	1236	27	Wherefore, we speak concerning the law that our children may know the deadness of the law; and they, by knowing the deadness of the law, may look forward unto that life which is in Christ, and know for what end the law was given. And after the law is fulfilled in Christ, that they need not harden their hearts against him when the law ought to be done away.
32320	1236	28	And now behold, my people, ye are a stiffnecked people; wherefore, I have spoken plainly unto you, that ye cannot misunderstand. And the words which I have spoken shall stand as a testimony against you; for they are sufficient to teach any man the right way; for the right way is to believe in Christ and deny him not; for by denying him ye also deny the prophets and the law.
32321	1236	29	And now behold, I say unto you that the right way is to believe in Christ, and deny him not; and Christ is the Holy One of Israel; wherefore ye must bow down before him, and worship him with all your might, mind, and strength, and your whole soul; and if ye do this ye shall in nowise be cast out.
32322	1236	30	And, inasmuch as it shall be expedient, ye must keep the performances and ordinances of God until the law shall be fulfilled which was given unto Moses.
32323	1237	1	And after Christ shall have risen from the dead he shall show himself unto you, my children, and my beloved brethren; and the words which he shall speak unto you shall be the law which ye shall do.
32324	1237	2	For behold, I say unto you that I have beheld that many generations shall pass away, and there shall be great wars and contentions among my people.
32325	1237	3	And after the Messiah shall come there shall be signs given unto my people of his birth, and also of his death and resurrection; and great and terrible shall that day be unto the wicked, for they shall perish; and they perish because they cast out the prophets, and the saints, and stone them, and slay them; wherefore the cry of the blood of the saints shall ascend up to God from the ground against them.
32326	1237	4	Wherefore, all those who are proud, and that do wickedly, the day that cometh shall burn them up, saith the Lord of Hosts, for they shall be as stubble.
32327	1237	5	And they that kill the prophets, and the saints, the depths of the earth shall swallow them up, saith the Lord of Hosts; and mountains shall cover them, and whirlwinds shall carry them away, and buildings shall fall upon them and crush them to pieces and grind them to powder.
32328	1237	6	And they shall be visited with thunderings, and lightnings, and earthquakes, and all manner of destructions, for the fire of the anger of the Lord shall be kindled against them, and they shall be as stubble, and the day that cometh shall consume them, saith the Lord of Hosts.
32329	1237	7	O the pain, and the anguish of my soul for the loss of the slain of my people! For I, Nephi, have seen it, and it well nigh consumeth me before the presence of the Lord; but I must cry unto my God: Thy ways are just.
32330	1237	8	But behold, the righteous that hearken unto the words of the prophets, and destroy them not, but look forward unto Christ with steadfastness for the signs which are given, notwithstanding all persecution--behold, they are they which shall not perish.
32331	1237	9	But the Son of righteousness shall appear unto them; and he shall heal them, and they shall have peace with him, until three generations shall have passed away, and many of the fourth generation shall have passed away in righteousness.
32332	1237	10	And when these things have passed away a speedy destruction cometh unto my people; for, notwithstanding the pains of my soul, I have seen it; wherefore, I know that it shall come to pass; and they sell themselves for naught; for, for the reward of their pride and their foolishness they shall reap destruction; for because they yield unto the devil and choose works of darkness rather than light, therefore they must go down to hell.
32333	1237	11	For the Spirit of the Lord will not always strive with man. And when the Spirit ceaseth to strive with man then cometh speedy destruction, and this grieveth my soul.
32334	1237	12	And as I spake concerning the convincing of the Jews, that Jesus is the very Christ, it must needs be that the Gentiles be convinced also that Jesus is the Christ, the Eternal God;
32335	1237	13	And that he manifesteth himself unto all those who believe in him, by the power of the Holy Ghost; yea, unto every nation, kindred, tongue, and people, working mighty miracles, signs, and wonders, among the children of men according to their faith.
32336	1237	14	But behold, I prophesy unto you concerning the last days; concerning the days when the Lord God shall bring these things forth unto the children of men.
32337	1237	15	After my seed and the seed of my brethren shall have dwindled in unbelief, and shall have been smitten by the Gentiles; yea, after the Lord God shall have camped against them round about, and shall have laid siege against them with a mount, and raised forts against them; and after they shall have been brought down low in the dust, even that they are not, yet the words of the righteous shall be written, and the prayers of the faithful shall be heard, and all those who have dwindled in unbelief shall not be forgotten.
32338	1237	16	For those who shall be destroyed shall speak unto them out of the ground, and their speech shall be low out of the dust, and their voice shall be as one that hath a familiar spirit; for the Lord God will give unto him power, that he may whisper concerning them, even as it were out of the ground; and their speech shall whisper out of the dust.
32339	1237	17	For thus saith the Lord God: They shall write the things which shall be done among them, and they shall be written and sealed up in a book, and those who have dwindled in unbelief shall not have them, for they seek to destroy the things of God.
32340	1237	18	Wherefore, as those who have been destroyed have been destroyed speedily; and the multitude of their terrible ones shall be as chaff that passeth away--yea, thus saith the Lord God: It shall be at an instant, suddenly--
32341	1237	19	And it shall come to pass, that those who have dwindled in unbelief shall be smitten by the hand of the Gentiles.
32342	1237	20	And the Gentiles are lifted up in the pride of their eyes, and have stumbled, because of the greatness of their stumbling block, that they have built up many churches; nevertheless, they put down the power and miracles of God, and preach up unto themselves their own wisdom and their own learning, that they may get gain and grind upon the face of the poor.
32343	1237	21	And there are many churches built up which cause envyings, and strifes, and malice.
32344	1237	22	And there are also secret combinations, even as in times of old, according to the combinations of the devil, for he is the founder of all these things; yea, the founder of murder, and works of darkness; yea, and he leadeth them by the neck with a flaxen cord, until he bindeth them with his strong cords forever.
32345	1237	23	For behold, my beloved brethren, I say unto you that the Lord God worketh not in darkness.
32346	1237	24	He doeth not anything save it be for the benefit of the world; for he loveth the world, even that he layeth down his own life that he may draw all men unto him. Wherefore, he commandeth none that they shall not partake of his salvation.
32347	1237	25	Behold, doth he cry unto any, saying: Depart from me? Behold, I say unto you, Nay; but he saith: Come unto me all ye ends of the earth, buy milk and honey, without money and without price.
32348	1237	26	Behold, hath he commanded any that they should depart out of the synagogues, or out of the houses of worship? Behold, I say unto you, Nay.
32349	1237	27	Hath he commanded any that they should not partake of his salvation? Behold I say unto you, Nay; but he hath given it free for all men; and he hath commanded his people that they should persuade all men to repentance.
32350	1237	28	Behold, hath the Lord commanded any that they should not partake of his goodness? Behold I say unto you, Nay; but all men are privileged the one like unto the other, and none are forbidden.
32351	1237	29	He commandeth that there shall be no priestcrafts; for, behold, priestcrafts are that men preach and set themselves up for a light unto the world, that they may get gain and praise of the world; but they seek not the welfare of Zion.
32352	1237	30	Behold, the Lord hath forbidden this thing; wherefore, the Lord God hath given a commandment that all men should have charity, which charity is love. And except they should have charity they were nothing. Wherefore, if they should have charity they would not suffer the laborer in Zion to perish.
32353	1237	31	But the laborer in Zion shall labor for Zion; for if they labor for money they shall perish.
32354	1237	32	And again, the Lord God hath commanded that men should not murder; that they should not lie; that they should not steal; that they should not take the name of the Lord their God in vain; that they should not envy; that they should not have malice; that they should not contend one with another; that they should not commit whoredoms; and that they should do none of these things; for whoso doeth them shall perish.
32355	1237	33	For none of these iniquities come of the Lord; for he doeth that which is good among the children of men; and he doeth nothing save it be plain unto the children of men; and he inviteth them all to come unto him and partake of his goodness; and he denieth none that come unto him, black and white, bond and free, male and female; and he remembereth the heathen; and all are alike unto God, both Jew and Gentile.
32356	1238	1	But, behold, in the last days, or in the days of the Gentiles--yea, behold all the nations of the Gentiles and also the Jews, both those who shall come upon this land and those who shall be upon other lands, yea, even upon all the lands of the earth, behold, they will be drunken with iniquity and all manner of abominations--
32357	1238	2	And when that day shall come they shall be visited of the Lord of Hosts, with thunder and with earthquake, and with a great noise, and with storm, and with tempest, and with the flame of devouring fire.
32358	1238	3	And all the nations that fight against Zion, and that distress her, shall be as a dream of a night vision; yea, it shall be unto them, even as unto a hungry man which dreameth, and behold he eateth but he awaketh and his soul is empty; or like unto a thirsty man which dreameth, and behold he drinketh but he awaketh and behold he is faint, and his soul hath appetite; yea, even so shall the multitude of all the nations be that fight against Mount Zion.
32359	1238	4	For behold, all ye that doeth iniquity, stay yourselves and wonder, for ye shall cry out, and cry; yea, ye shall be drunken but not with wine, ye shall stagger but not with strong drink.
32360	1238	5	For behold, the Lord hath poured out upon you the spirit of deep sleep. For behold, ye have closed your eyes, and ye have rejected the prophets; and your rulers, and the seers hath he covered because of your iniquity.
32361	1238	6	And it shall come to pass that the Lord God shall bring forth unto you the words of a book, and they shall be the words of them which have slumbered.
32362	1238	7	And behold the book shall be sealed; and in the book shall be a revelation from God, from the beginning of the world to the ending thereof.
32363	1238	8	Wherefore, because of the things which are sealed up, the things which are sealed shall not be delivered in the day of the wickedness and abominations of the people. Wherefore the book shall be kept from them.
32364	1238	9	But the book shall be delivered unto a man, and he shall deliver the words of the book, which are the words of those who have slumbered in the dust, and he shall deliver these words unto another;
32365	1238	10	But the words which are sealed he shall not deliver, neither shall he deliver the book. For the book shall be sealed by the power of God, and the revelation which was sealed shall be kept in the book until the own due time of the Lord, that they may come forth; for behold, they reveal all things from the foundation of the world unto the end thereof.
32366	1238	11	And the day cometh that the words of the book which were sealed shall be read upon the house tops; and they shall be read by the power of Christ; and all things shall be revealed unto the children of men which ever have been among the children of men, and which ever will be even unto the end of the earth.
32367	1238	12	Wherefore, at that day when the book shall be delivered unto the man of whom I have spoken, the book shall be hid from the eyes of the world, that the eyes of none shall behold it save it be that three witnesses shall behold it, by the power of God, besides him to whom the book shall be delivered; and they shall testify to the truth of the book and the things therein.
32368	1238	13	And there is none other which shall view it, save it be a few according to the will of God, to bear testimony of his word unto the children of men; for the Lord God hath said that the words of the faithful should speak as if it were from the dead.
32369	1238	14	Wherefore, the Lord God will proceed to bring forth the words of the book; and in the mouth of as many witnesses as seemeth him good will he establish his word; and wo be unto him that rejecteth the word of God!
32370	1238	15	But behold, it shall come to pass that the Lord God shall say unto him to whom he shall deliver the book: Take these words which are not sealed and deliver them to another, that he may show them unto the learned, saying: Read this, I pray thee. And the learned shall say: Bring hither the book, and I will read them.
32371	1238	16	And now, because of the glory of the world and to get gain will they say this, and not for the glory of God.
32372	1238	17	And the man shall say: I cannot bring the book, for it is sealed.
32373	1238	18	Then shall the learned say: I cannot read it.
32374	1238	19	Wherefore it shall come to pass, that the Lord God will deliver again the book and the words thereof to him that is not learned; and the man that is not learned shall say: I am not learned.
32375	1238	20	Then shall the Lord God say unto him: The learned shall not read them, for they have rejected them, and I am able to do mine own work; wherefore thou shalt read the words which I shall give unto thee.
32376	1238	21	Touch not the things which are sealed, for I will bring them forth in mine own due time; for I will show unto the children of men that I am able to do mine own work.
32377	1238	22	Wherefore, when thou hast read the words which I have commanded thee, and obtained the witnesses which I have promised unto thee, then shalt thou seal up the book again, and hide it up unto me, that I may preserve the words which thou hast not read, until I shall see fit in mine own wisdom to reveal all things unto the children of men.
32378	1238	23	For behold, I am God; and I am a God of miracles; and I will show unto the world that I am the same yesterday, today, and forever; and I work not among the children of men save it be according to their faith.
32379	1238	24	And again it shall come to pass that the Lord shall say unto him that shall read the words that shall be delivered him:
32380	1238	25	Forasmuch as this people draw near unto me with their mouth, and with their lips do honor me, but have removed their hearts far from me, and their fear towards me is taught by the precepts of men--
32381	1238	26	Therefore, I will proceed to do a marvelous work among this people, yea, a marvelous work and a wonder, for the wisdom of their wise and learned shall perish, and the understanding of their prudent shall be hid.
32382	1238	27	And wo unto them that seek deep to hide their counsel from the Lord! And their works are in the dark; and they say: Who seeth us, and who knoweth us? And they also say: Surely, your turning of things upside down shall be esteemed as the potter's clay. But behold, I will show unto them, saith the Lord of Hosts, that I know all their works. For shall the work say of him that made it, he made me not? Or shall the thing framed say of him that framed it, he had no understanding?
32383	1238	28	But behold, saith the Lord of Hosts: I will show unto the children of men that it is yet a very little while and Lebanon shall be turned into a fruitful field; and the fruitful field shall be esteemed as a forest.
32384	1238	29	And in that day shall the deaf hear the words of the book, and the eyes of the blind shall see out of obscurity and out of darkness.
32385	1238	30	And the meek also shall increase, and their joy shall be in the Lord, and the poor among men shall rejoice in the Holy One of Israel.
32386	1238	31	For assuredly as the Lord liveth they shall see that the terrible one is brought to naught, and the scorner is consumed, and all that watch for iniquity are cut off;
32387	1238	32	And they that make a man an offender for a word, and lay a snare for him that reproveth in the gate, and turn aside the just for a thing of naught.
32388	1238	33	Therefore, thus saith the Lord, who redeemed Abraham, concerning the house of Jacob: Jacob shall not now be ashamed, neither shall his face now wax pale.
32389	1238	34	But when he seeth his children, the work of my hands, in the midst of him, they shall sanctify my name, and sanctify the Holy One of Jacob, and shall fear the God of Israel.
32390	1238	35	They also that erred in spirit shall come to understanding, and they that murmured shall learn doctrine.
32391	1239	1	And now, behold, my brethren, I have spoken unto you, according as the Spirit hath constrained me; wherefore, I know that they must surely come to pass.
32392	1239	2	And the things which shall be written out of the book shall be of great worth unto the children of men, and especially unto our seed, which is a remnant of the house of Israel.
32393	1239	3	For it shall come to pass in that day that the churches which are built up, and not unto the Lord, when the one shall say unto the other: Behold, I, I am the Lord's; and the others shall say: I, I am the Lord's; and thus shall every one say that hath built up churches, and not unto the Lord--
32394	1239	4	And they shall contend one with another; and their priests shall contend one with another, and they shall teach with their learning, and deny the Holy Ghost, which giveth utterance.
32395	1239	5	And they deny the power of God, the Holy One of Israel; and they say unto the people: Hearken unto us, and hear ye our precept; for behold there is no God today, for the Lord and the Redeemer hath done his work, and he hath given his power unto men;
32396	1239	6	Behold, hearken ye unto my precept; if they shall say there is a miracle wrought by the hand of the Lord, believe it not; for this day he is not a God of miracles; he hath done his work.
32397	1239	7	Yea, and there shall be many which shall say: Eat, drink, and be merry, for tomorrow we die; and it shall be well with us.
32398	1239	8	And there shall also be many which shall say: Eat, drink, and be merry; nevertheless, fear God--he will justify in committing a little sin; yea, lie a little, take the advantage of one because of his words, dig a pit for thy neighbor; there is no harm in this; and do all these things, for tomorrow we die; and if it so be that we are guilty, God will beat us with a few stripes, and at last we shall be saved in the kingdom of God.
32399	1239	9	Yea, and there shall be many which shall teach after this manner, false and vain and foolish doctrines, and shall be puffed up in their hearts, and shall seek deep to hide their counsels from the Lord; and their works shall be in the dark.
32400	1239	10	And the blood of the saints shall cry from the ground against them.
32401	1239	11	Yea, they have all gone out of the way; they have become corrupted.
32402	1239	12	Because of pride, and because of false teachers, and false doctrine, their churches have become corrupted, and their churches are lifted up; because of pride they are puffed up.
32403	1239	13	They rob the poor because of their fine sanctuaries; they rob the poor because of their fine clothing; and they persecute the meek and the poor in heart, because in their pride they are puffed up.
32404	1239	14	They wear stiff necks and high heads; yea, and because of pride, and wickedness, and abominations, and whoredoms, they have all gone astray save it be a few, who are the humble followers of Christ; nevertheless, they are led, that in many instances they do err because they are taught by the precepts of men.
32405	1239	15	O the wise, and the learned, and the rich, that are puffed up in the pride of their hearts, and all those who preach false doctrines, and all those who commit whoredoms, and pervert the right way of the Lord, wo, wo, wo be unto them, saith the Lord God Almighty, for they shall be thrust down to hell!
32406	1239	16	Wo unto them that turn aside the just for a thing of naught and revile against that which is good, and say that it is of no worth! For the day shall come that the Lord God will speedily visit the inhabitants of the earth; and in that day that they are fully ripe in iniquity they shall perish.
32407	1239	17	But behold, if the inhabitants of the earth shall repent of their wickedness and abominations they shall not be destroyed, saith the Lord of Hosts.
32408	1239	18	But behold, that great and abominable church, the whore of all the earth, must tumble to the earth, and great must be the fall thereof.
32409	1239	19	For the kingdom of the devil must shake, and they which belong to it must needs be stirred up unto repentance, or the devil will grasp them with his everlasting chains, and they be stirred up to anger, and perish;
32410	1239	20	For behold, at that day shall he rage in the hearts of the children of men, and stir them up to anger against that which is good.
32411	1239	21	And others will he pacify, and lull them away into carnal security, that they will say: All is well in Zion; yea, Zion prospereth, all is well--and thus the devil cheateth their souls, and leadeth them away carefully down to hell.
32412	1239	22	And behold, others he flattereth away, and telleth them there is no hell; and he saith unto them: I am no devil, for there is none--and thus he whispereth in their ears, until he grasps them with his awful chains, from whence there is no deliverance.
32413	1239	23	Yea, they are grasped with death, and hell; and death, and hell, and the devil, and all that have been seized therewith must stand before the throne of God, and be judged according to their works, from whence they must go into the place prepared for them, even a lake of fire and brimstone, which is endless torment.
32414	1239	24	Therefore, wo be unto him that is at ease in Zion!
32415	1239	25	Wo be unto him that crieth: All is well!
32416	1239	26	Yea, wo be unto him that hearkeneth unto the precepts of men, and denieth the power of God, and the gift of the Holy Ghost!
32417	1239	27	Yea, wo be unto him that saith: We have received, and we need no more!
32418	1239	28	And in fine, wo unto all those who tremble, and are angry because of the truth of God! For behold, he that is built upon the rock receiveth it with gladness; and he that is built upon a sandy foundation trembleth lest he shall fall.
32419	1239	29	Wo be unto him that shall say: We have received the word of God, and we need no more of the word of God, for we have enough!
32420	1239	30	For behold, thus saith the Lord God: I will give unto the children of men line upon line, precept upon precept, here a little and there a little; and blessed are those who hearken unto my precepts, and lend an ear unto my counsel, for they shall learn wisdom; for unto him that receiveth I will give more; and from them that shall say, We have enough, from them shall be taken away even that which they have.
32421	1239	31	Cursed is he that putteth his trust in man, or maketh flesh his arm, or shall hearken unto the precepts of men, save their precepts shall be given by the power of the Holy Ghost.
32422	1239	32	Wo be unto the Gentiles, saith the Lord God of Hosts! For notwithstanding I shall lengthen out mine arm unto them from day to day, they will deny me; nevertheless, I will be merciful unto them, saith the Lord God, if they will repent and come unto me; for mine arm is lengthened out all the day long, saith the Lord God of Hosts.
32423	1240	1	But behold, there shall be many--at that day when I shall proceed to do a marvelous work among them, that I may remember my covenants which I have made unto the children of men, that I may set my hand again the second time to recover my people, which are of the house of Israel;
32424	1240	2	And also, that I may remember the promises which I have made unto thee, Nephi, and also unto thy father, that I would remember your seed; and that the words of your seed should proceed forth out of my mouth unto your seed; and my words shall hiss forth unto the ends of the earth, for a standard unto my people, which are of the house of Israel;
32425	1240	3	And because my words shall hiss forth--many of the Gentiles shall say: A Bible! A Bible! We have got a Bible, and there cannot be any more Bible.
32426	1240	4	But thus saith the Lord God: O fools, they shall have a Bible; and it shall proceed forth from the Jews, mine ancient covenant people. And what thank they the Jews for the Bible which they receive from them? Yea, what do the Gentiles mean? Do they remember the travails, and the labors, and the pains of the Jews, and their diligence unto me, in bringing forth salvation unto the Gentiles?
32427	1240	5	O ye Gentiles, have ye remembered the Jews, mine ancient covenant people? Nay; but ye have cursed them, and have hated them, and have not sought to recover them. But behold, I will return all these things upon your own heads; for I the Lord have not forgotten my people.
32428	1240	6	Thou fool, that shall say: A Bible, we have got a Bible, and we need no more Bible. Have ye obtained a Bible save it were by the Jews?
32429	1240	7	Know ye not that there are more nations than one? Know ye not that I, the Lord your God, have created all men, and that I remember those who are upon the isles of the sea; and that I rule in the heavens above and in the earth beneath; and I bring forth my word unto the children of men, yea, even upon all the nations of the earth?
32430	1240	8	Wherefore murmur ye, because that ye shall receive more of my word? Know ye not that the testimony of two nations is a witness unto you that I am God, that I remember one nation like unto another? Wherefore, I speak the same words unto one nation like unto another. And when the two nations shall run together the testimony of the two nations shall run together also.
32431	1240	9	And I do this that I may prove unto many that I am the same yesterday, today, and forever; and that I speak forth my words according to mine own pleasure. And because that I have spoken one word ye need not suppose that I cannot speak another; for my work is not yet finished; neither shall it be until the end of man, neither from that time henceforth and forever.
32432	1240	10	Wherefore, because that ye have a Bible ye need not suppose that it contains all my words; neither need ye suppose that I have not caused more to be written.
32433	1240	11	For I command all men, both in the east and in the west, and in the north, and in the south, and in the islands of the sea, that they shall write the words which I speak unto them; for out of the books which shall be written I will judge the world, every man according to their works, according to that which is written.
32434	1240	12	For behold, I shall speak unto the Jews and they shall write it; and I shall also speak unto the Nephites and they shall write it; and I shall also speak unto the other tribes of the house of Israel, which I have led away, and they shall write it; and I shall also speak unto all nations of the earth and they shall write it.
32435	1240	13	And it shall come to pass that the Jews shall have the words of the Nephites, and the Nephites shall have the words of the Jews; and the Nephites and the Jews shall have the words of the lost tribes of Israel; and the lost tribes of Israel shall have the words of the Nephites and the Jews.
32436	1240	14	And it shall come to pass that my people, which are of the house of Israel, shall be gathered home unto the lands of their possessions; and my word also shall be gathered in one. And I will show unto them that fight against my word and against my people, who are of the house of Israel, that I am God, and that I covenanted with Abraham that I would remember his seed forever.
32437	1241	1	And now behold, my beloved brethren, I would speak unto you; for I, Nephi, would not suffer that ye should suppose that ye are more righteous than the Gentiles shall be. For behold, except ye shall keep the commandments of God ye shall all likewise perish; and because of the words which have been spoken ye need not suppose that the Gentiles are utterly destroyed.
32438	1241	2	For behold, I say unto you that as many of the Gentiles as will repent are the covenant people of the Lord; and as many of the Jews as will not repent shall be cast off; for the Lord covenanteth with none save it be with them that repent and believe in his Son, who is the Holy One of Israel.
32439	1241	3	And now, I would prophesy somewhat more concerning the Jews and the Gentiles. For after the book of which I have spoken shall come forth, and be written unto the Gentiles, and sealed up again unto the Lord, there shall be many which shall believe the words which are written; and they shall carry them forth unto the remnant of our seed.
32440	1241	4	And then shall the remnant of our seed know concerning us, how that we came out from Jerusalem, and that they are descendants of the Jews.
32441	1241	5	And the gospel of Jesus Christ shall be declared among them; wherefore, they shall be restored unto the knowledge of their fathers, and also to the knowledge of Jesus Christ, which was had among their fathers.
32442	1241	6	And then shall they rejoice; for they shall know that it is a blessing unto them from the hand of God; and their scales of darkness shall begin to fall from their eyes; and many generations shall not pass away among them, save they shall be a pure and a delightsome people.
32443	1241	7	And it shall come to pass that the Jews which are scattered also shall begin to believe in Christ; and they shall begin to gather in upon the face of the land; and as many as shall believe in Christ shall also become a delightsome people.
32444	1241	8	And it shall come to pass that the Lord God shall commence his work among all nations, kindreds, tongues, and people, to bring about the restoration of his people upon the earth.
32445	1241	9	And with righteousness shall the Lord God judge the poor, and reprove with equity for the meek of the earth. And he shall smite the earth with the rod of his mouth; and with the breath of his lips shall he slay the wicked.
32446	1241	10	For the time speedily cometh that the Lord God shall cause a great division among the people, and the wicked will he destroy; and he will spare his people, yea, even if it so be that he must destroy the wicked by fire.
32447	1241	11	And righteousness shall be the girdle of his loins, and faithfulness the girdle of his reins.
32448	1241	12	And then shall the wolf dwell with the lamb; and the leopard shall lie down with the kid, and the calf, and the young lion, and the fatling, together; and a little child shall lead them.
32449	1241	13	And the cow and the bear shall feed; their young ones shall lie down together; and the lion shall eat straw like the ox.
32450	1241	14	And the sucking child shall play on the hole of the asp, and the weaned child shall put his hand on the cockatrice's den.
32451	1241	15	They shall not hurt nor destroy in all my holy mountain; for the earth shall be full of the knowledge of the Lord as the waters cover the sea.
32452	1241	16	Wherefore, the things of all nations shall be made known; yea, all things shall be made known unto the children of men.
32453	1241	17	There is nothing which is secret save it shall be revealed; there is no work of darkness save it shall be made manifest in the light; and there is nothing which is sealed upon the earth save it shall be loosed.
32454	1241	18	Wherefore, all things which have been revealed unto the children of men shall at that day be revealed; and Satan shall have power over the hearts of the children of men no more, for a long time. And now, my beloved brethren, I make an end of my sayings.
32455	1242	1	And now I, Nephi, make an end of my prophesying unto you, my beloved brethren. And I cannot write but a few things, which I know must surely come to pass; neither can I write but a few of the words of my brother Jacob.
32456	1242	2	Wherefore, the things which I have written sufficeth me, save it be a few words which I must speak concerning the doctrine of Christ; wherefore, I shall speak unto you plainly, according to the plainness of my prophesying.
32457	1242	3	For my soul delighteth in plainness; for after this manner doth the Lord God work among the children of men. For the Lord God giveth light unto the understanding; for he speaketh unto men according to their language, unto their understanding.
32458	1242	4	Wherefore, I would that ye should remember that I have spoken unto you concerning that prophet which the Lord showed unto me, that should baptize the Lamb of God, which should take away the sins of the world.
32459	1242	5	And now, if the Lamb of God, he being holy, should have need to be baptized by water, to fulfil all righteousness, O then, how much more need have we, being unholy, to be baptized, yea, even by water!
32460	1242	6	And now, I would ask of you, my beloved brethren, wherein the Lamb of God did fulfil all righteousness in being baptized by water?
32461	1242	7	Know ye not that he was holy? But notwithstanding he being holy, he showeth unto the children of men that, according to the flesh he humbleth himself before the Father, and witnesseth unto the Father that he would be obedient unto him in keeping his commandments.
32462	1242	8	Wherefore, after he was baptized with water the Holy Ghost descended upon him in the form of a dove.
32463	1242	9	And again, it showeth unto the children of men the straitness of the path, and the narrowness of the gate, by which they should enter, he having set the example before them.
32464	1242	10	And he said unto the children of men: Follow thou me. Wherefore, my beloved brethren, can we follow Jesus save we shall be willing to keep the commandments of the Father?
32465	1242	11	And the Father said: Repent ye, repent ye, and be baptized in the name of my Beloved Son.
32466	1242	12	And also, the voice of the Son came unto me, saying: He that is baptized in my name, to him will the Father give the Holy Ghost, like unto me; wherefore, follow me, and do the things which ye have seen me do.
32467	1242	13	Wherefore, my beloved brethren, I know that if ye shall follow the Son, with full purpose of heart, acting no hypocrisy and no deception before God, but with real intent, repenting of your sins, witnessing unto the Father that ye are willing to take upon you the name of Christ, by baptism--yea, by following your Lord and your Savior down into the water, according to his word, behold, then shall ye receive the Holy Ghost; yea, then cometh the baptism of fire and of the Holy Ghost; and then can ye speak with the tongue of angels, and shout praises unto the Holy One of Israel.
32468	1242	14	But, behold, my beloved brethren, thus came the voice of the Son unto me, saying: After ye have repented of your sins, and witnessed unto the Father that ye are willing to keep my commandments, by the baptism of water, and have received the baptism of fire and of the Holy Ghost, and can speak with a new tongue, yea, even with the tongue of angels, and after this should deny me, it would have been better for you that ye had not known me.
32469	1242	15	And I heard a voice from the Father, saying: Yea, the words of my Beloved are true and faithful. He that endureth to the end, the same shall be saved.
32470	1242	16	And now, my beloved brethren, I know by this that unless a man shall endure to the end, in following the example of the Son of the living God, he cannot be saved.
32471	1242	17	Wherefore, do the things which I have told you I have seen that your Lord and your Redeemer should do; for, for this cause have they been shown unto me, that ye might know the gate by which ye should enter. For the gate by which ye should enter is repentance and baptism by water; and then cometh a remission of your sins by fire and by the Holy Ghost.
32472	1242	18	And then are ye in this strait and narrow path which leads to eternal life; yea, ye have entered in by the gate; ye have done according to the commandments of the Father and the Son; and ye have received the Holy Ghost, which witnesses of the Father and the Son, unto the fulfilling of the promise which he hath made, that if ye entered in by the way ye should receive.
32473	1242	19	And now, my beloved brethren, after ye have gotten into this strait and narrow path, I would ask if all is done? Behold, I say unto you, Nay; for ye have not come thus far save it were by the word of Christ with unshaken faith in him, relying wholly upon the merits of him who is mighty to save.
32474	1242	20	Wherefore, ye must press forward with a steadfastness in Christ, having a perfect brightness of hope, and a love of God and of all men. Wherefore, if ye shall press forward, feasting upon the word of Christ, and endure to the end, behold, thus saith the Father: Ye shall have eternal life.
32475	1242	21	And now, behold, my beloved brethren, this is the way; and there is none other way nor name given under heaven whereby man can be saved in the kingdom of God. And now, behold, this is the doctrine of Christ, and the only and true doctrine of the Father, and of the Son, and of the Holy Ghost, which is one God, without end. Amen.
32476	1243	1	And now, behold, my beloved brethren, I suppose that ye ponder somewhat in your hearts concerning that which ye should do after ye have entered in by the way. But, behold, why do ye ponder these things in your hearts?
32477	1243	2	Do ye not remember that I said unto you that after ye had received the Holy Ghost ye could speak with the tongue of angels? And now, how could ye speak with the tongue of angels save it were by the Holy Ghost?
32478	1243	3	Angels speak by the power of the Holy Ghost; wherefore, they speak the words of Christ. Wherefore, I said unto you, feast upon the words of Christ; for behold, the words of Christ will tell you all things what ye should do.
32479	1243	4	Wherefore, now after I have spoken these words, if ye cannot understand them it will be because ye ask not, neither do ye knock; wherefore, ye are not brought into the light, but must perish in the dark.
32480	1243	5	For behold, again I say unto you that if ye will enter in by the way, and receive the Holy Ghost, it will show unto you all things what ye should do.
32481	1243	6	Behold, this is the doctrine of Christ, and there will be no more doctrine given until after he shall manifest himself unto you in the flesh. And when he shall manifest himself unto you in the flesh, the things which he shall say unto you shall ye observe to do.
32482	1243	7	And now I, Nephi, cannot say more; the Spirit stoppeth mine utterance, and I am left to mourn because of the unbelief, and the wickedness, and the ignorance, and the stiffneckedness of men; for they will not search knowledge, nor understand great knowledge, when it is given unto them in plainness, even as plain as word can be.
32483	1243	8	And now, my beloved brethren, I perceive that ye ponder still in your hearts; and it grieveth me that I must speak concerning this thing. For if ye would hearken unto the Spirit which teacheth a man to pray ye would know that ye must pray; for the evil spirit teacheth not a man to pray, but teacheth him that he must not pray.
32484	1243	9	But behold, I say unto you that ye must pray always, and not faint; that ye must not perform any thing unto the Lord save in the first place ye shall pray unto the Father in the name of Christ, that he will consecrate thy performance unto thee, that thy performance may be for the welfare of thy soul.
32485	1244	1	And now I, Nephi, cannot write all the things which were taught among my people; neither am I mighty in writing, like unto speaking; for when a man speaketh by the power of the Holy Ghost the power of the Holy Ghost carrieth it unto the hearts of the children of men.
32486	1244	2	But behold, there are many that harden their hearts against the Holy Spirit, that it hath no place in them; wherefore, they cast many things away which are written and esteem them as things of naught.
32487	1244	3	But I, Nephi, have written what I have written, and I esteem it as of great worth, and especially unto my people. For I pray continually for them by day, and mine eyes water my pillow by night, because of them; and I cry unto my God in faith, and I know that he will hear my cry.
32488	1244	4	And I know that the Lord God will consecrate my prayers for the gain of my people. And the words which I have written in weakness will be made strong unto them; for it persuadeth them to do good; it maketh known unto them of their fathers; and it speaketh of Jesus, and persuadeth them to believe in him, and to endure to the end, which is life eternal.
32489	1244	5	And it speaketh harshly against sin, according to the plainness of the truth; wherefore, no man will be angry at the words which I have written save he shall be of the spirit of the devil.
32490	1244	6	I glory in plainness; I glory in truth; I glory in my Jesus, for he hath redeemed my soul from hell.
32491	1244	7	I have charity for my people, and great faith in Christ that I shall meet many souls spotless at his judgment-seat.
32492	1244	8	I have charity for the Jew--I say Jew, because I mean them from whence I came.
32493	1244	9	I also have charity for the Gentiles. But behold, for none of these can I hope except they shall be reconciled unto Christ, and enter into the narrow gate, and walk in the strait path which leads to life, and continue in the path until the end of the day of probation.
32494	1244	10	And now, my beloved brethren, and also Jew, and all ye ends of the earth, hearken unto these words and believe in Christ; and if ye believe not in these words believe in Christ. And if ye shall believe in Christ ye will believe in these words, for they are the words of Christ, and he hath given them unto me; and they teach all men that they should do good.
32495	1244	11	And if they are not the words of Christ, judge ye--for Christ will show unto you, with power and great glory, that they are his words, at the last day; and you and I shall stand face to face before his bar; and ye shall know that I have been commanded of him to write these things, notwithstanding my weakness.
32496	1244	12	And I pray the Father in the name of Christ that many of us, if not all, may be saved in his kingdom at that great and last day.
32497	1244	13	And now, my beloved brethren, all those who are of the house of Israel, and all ye ends of the earth, I speak unto you as the voice of one crying from the dust: Farewell until that great day shall come.
32498	1244	14	And you that will not partake of the goodness of God, and respect the words of the Jews, and also my words, and the words which shall proceed forth out of the mouth of the Lamb of God, behold, I bid you an everlasting farewell, for these words shall condemn you at the last day.
32499	1244	15	For what I seal on earth, shall be brought against you at the judgment bar; for thus hath the Lord commanded me, and I must obey. Amen.
32500	1245	1	For behold, it came to pass that fifty and five years had passed away from the time that Lehi left Jerusalem; wherefore, Nephi gave me, Jacob, a commandment concerning the small plates, upon which these things are engraven.
32501	1245	2	And he gave me, Jacob, a commandment that I should write upon these plates a few of the things which I considered to be most precious; that I should not touch, save it were lightly, concerning the history of this people which are called the people of Nephi.
32502	1245	3	For he said that the history of his people should be engraven upon his other plates, and that I should preserve these plates and hand them down unto my seed, from generation to generation.
32503	1245	4	And if there were preaching which was sacred, or revelation which was great, or prophesying, that I should engraven the heads of them upon these plates, and touch upon them as much as it were possible, for Christ's sake, and for the sake of our people.
32504	1245	5	For because of faith and great anxiety, it truly had been made manifest unto us concerning our people, what things should happen unto them.
32505	1245	6	And we also had many revelations, and the spirit of much prophecy; wherefore, we knew of Christ and his kingdom, which should come.
32506	1245	7	Wherefore we labored diligently among our people, that we might persuade them to come unto Christ, and partake of the goodness of God, that they might enter into his rest, lest by any means he should swear in his wrath they should not enter in, as in the provocation in the days of temptation while the children of Israel were in the wilderness.
32507	1245	8	Wherefore, we would to God that we could persuade all men not to rebel against God, to provoke him to anger, but that all men would believe in Christ, and view his death, and suffer his cross and bear the shame of the world; wherefore, I, Jacob, take it upon me to fulfil the commandment of my brother Nephi.
32508	1245	9	Now Nephi began to be old, and he saw that he must soon die; wherefore, he anointed a man to be a king and a ruler over his people now, according to the reigns of the kings.
32509	1245	10	The people having loved Nephi exceedingly, he having been a great protector for them, having wielded the sword of Laban in their defence, and having labored in all his days for their welfare--
32510	1245	11	Wherefore, the people were desirous to retain in remembrance his name. And whoso should reign in his stead were called by the people, second Nephi, third Nephi, and so forth, according to the reigns of the kings; and thus they were called by the people, let them be of whatever name they would.
32511	1245	12	And it came to pass that Nephi died.
32512	1245	13	Now the people which were not Lamanites were Nephites; nevertheless, they were called Nephites, Jacobites, Josephites, Zoramites, Lamanites, Lemuelites, and Ishmaelites.
32513	1245	14	But I, Jacob, shall not hereafter distinguish them by these names, but I shall call them Lamanites that seek to destroy the people of Nephi, and those who are friendly to Nephi I shall call Nephites, or the people of Nephi, according to the reigns of the kings.
32514	1245	15	And now it came to pass that the people of Nephi, under the reign of the second king, began to grow hard in their hearts, and indulge themselves somewhat in wicked practices, such as like unto David of old desiring many wives and concubines, and also Solomon, his son.
32515	1245	16	Yea, and they also began to search much gold and silver, and began to be lifted up somewhat in pride.
32516	1245	17	Wherefore I, Jacob, gave unto them these words as I taught them in the temple, having first obtained mine errand from the Lord.
32517	1245	18	For I, Jacob, and my brother Joseph had been consecrated priests and teachers of this people, by the hand of Nephi.
32518	1245	19	And we did magnify our office unto the Lord, taking upon us the responsibility, answering the sins of the people upon our own heads if we did not teach them the word of God with all diligence; wherefore, by laboring with our might their blood might not come upon our garments; otherwise their blood would come upon our garments, and we would not be found spotless at the last day.
32519	1246	1	The words which Jacob, the brother of Nephi, spake unto the people of Nephi, after the death of Nephi:
32520	1246	2	Now, my beloved brethren, I, Jacob, according to the responsibility which I am under to God, to magnify mine office with soberness, and that I might rid my garments of your sins, I come up into the temple this day that I might declare unto you the word of God.
32521	1246	3	And ye yourselves know that I have hitherto been diligent in the office of my calling; but I this day am weighed down with much more desire and anxiety for the welfare of your souls than I have hitherto been.
32522	1246	4	For behold, as yet, ye have been obedient unto the word of the Lord, which I have given unto you.
32523	1246	5	But behold, hearken ye unto me, and know that by the help of the all-powerful Creator of heaven and earth I can tell you concerning your thoughts, how that ye are beginning to labor in sin, which sin appeareth very abominable unto me, yea, and abominable unto God.
32524	1246	6	Yea, it grieveth my soul and causeth me to shrink with shame before the presence of my Maker, that I must testify unto you concerning the wickedness of your hearts.
32525	1246	7	And also it grieveth me that I must use so much boldness of speech concerning you, before your wives and your children, many of whose feelings are exceedingly tender and chaste and delicate before God, which thing is pleasing unto God;
32526	1246	8	And it supposeth me that they have come up hither to hear the pleasing word of God, yea, the word which healeth the wounded soul.
32527	1246	9	Wherefore, it burdeneth my soul that I should be constrained, because of the strict commandment which I have received from God, to admonish you according to your crimes, to enlarge the wounds of those who are already wounded, instead of consoling and healing their wounds; and those who have not been wounded, instead of feasting upon the pleasing word of God have daggers placed to pierce their souls and wound their delicate minds.
32528	1246	10	But, notwithstanding the greatness of the task, I must do according to the strict commands of God, and tell you concerning your wickedness and abominations, in the presence of the pure in heart, and the broken heart, and under the glance of the piercing eye of the Almighty God.
32529	1246	11	Wherefore, I must tell you the truth according to the plainness of the word of God. For behold, as I inquired of the Lord, thus came the word unto me, saying: Jacob, get thou up into the temple on the morrow, and declare the word which I shall give thee unto this people.
32530	1246	12	And now behold, my brethren, this is the word which I declare unto you, that many of you have begun to search for gold, and for silver, and for all manner of precious ores, in the which this land, which is a land of promise unto you and to your seed, doth abound most plentifully.
32531	1246	13	And the hand of providence hath smiled upon you most pleasingly, that you have obtained many riches; and because some of you have obtained more abundantly than that of your brethren ye are lifted up in the pride of your hearts, and wear stiff necks and high heads because of the costliness of your apparel, and persecute your brethren because ye suppose that ye are better than they.
32532	1246	14	And now, my brethren, do ye suppose that God justifieth you in this thing? Behold, I say unto you, Nay. But he condemneth you, and if ye persist in these things his judgments must speedily come unto you.
32533	1246	15	O that he would show you that he can pierce you, and with one glance of his eye he can smite you to the dust!
32534	1246	16	O that he would rid you from this iniquity and abomination. And, O that ye would listen unto the word of his commands, and let not this pride of your hearts destroy your souls!
32535	1246	17	Think of your brethren like unto yourselves, and be familiar with all and free with your substance, that they may be rich like unto you.
32536	1246	18	But before ye seek for riches, seek ye for the kingdom of God.
32537	1246	19	And after ye have obtained a hope in Christ ye shall obtain riches, if ye seek them; and ye will seek them for the intent to do good--to clothe the naked, and to feed the hungry, and to liberate the captive, and administer relief to the sick and the afflicted.
32538	1246	20	And now, my brethren, I have spoken unto you concerning pride; and those of you which have afflicted your neighbor, and persecuted him because ye were proud in your hearts, of the things which God hath given you, what say ye of it?
32539	1246	21	Do ye not suppose that such things are abominable unto him who created all flesh? And the one being is as precious in his sight as the other. And all flesh is of the dust; and for the selfsame end hath he created them, that they should keep his commandments and glorify him forever.
32540	1246	22	And now I make an end of speaking unto you concerning this pride. And were it not that I must speak unto you concerning a grosser crime, my heart would rejoice exceedingly because of you.
32541	1246	23	But the word of God burdens me because of your grosser crimes. For behold, thus saith the Lord: This people begin to wax in iniquity; they understand not the scriptures, for they seek to excuse themselves in committing whoredoms, because of the things which were written concerning David, and Solomon his son.
32542	1246	24	Behold, David and Solomon truly had many wives and concubines, which thing was abominable before me, saith the Lord.
32543	1246	25	Wherefore, thus saith the Lord, I have led this people forth out of the land of Jerusalem, by the power of mine arm, that I might raise up unto me a righteous branch from the fruit of the loins of Joseph.
32544	1246	26	Wherefore, I the Lord God will not suffer that this people shall do like unto them of old.
32545	1246	27	Wherefore, my brethren, hear me, and hearken to the word of the Lord: For there shall not any man among you have save it be one wife; and concubines he shall have none;
32546	1246	28	For I, the Lord God, delight in the chastity of women. And whoredoms are an abomination before me; thus saith the Lord of Hosts.
32547	1246	29	Wherefore, this people shall keep my commandments, saith the Lord of Hosts, or cursed be the land for their sakes.
32548	1246	30	For if I will, saith the Lord of Hosts, raise up seed unto me, I will command my people; otherwise they shall hearken unto these things.
32549	1246	31	For behold, I, the Lord, have seen the sorrow, and heard the mourning of the daughters of my people in the land of Jerusalem, yea, and in all the lands of my people, because of the wickedness and abominations of their husbands.
32550	1246	32	And I will not suffer, saith the Lord of Hosts, that the cries of the fair daughters of this people, which I have led out of the land of Jerusalem, shall come up unto me against the men of my people, saith the Lord of Hosts.
32551	1246	33	For they shall not lead away captive the daughters of my people because of their tenderness, save I shall visit them with a sore curse, even unto destruction; for they shall not commit whoredoms, like unto them of old, saith the Lord of Hosts.
32552	1246	34	And now behold, my brethren, ye know that these commandments were given to our father, Lehi; wherefore, ye have known them before; and ye have come unto great condemnation; for ye have done these things which ye ought not to have done.
32553	1246	35	Behold, ye have done greater iniquities than the Lamanites, our brethren. Ye have broken the hearts of your tender wives, and lost the confidence of your children, because of your bad examples before them; and the sobbings of their hearts ascend up to God against you. And because of the strictness of the word of God, which cometh down against you, many hearts died, pierced with deep wounds.
32554	1247	1	But behold, I, Jacob, would speak unto you that are pure in heart. Look unto God with firmness of mind, and pray unto him with exceeding faith, and he will console you in your afflictions, and he will plead your cause, and send down justice upon those who seek your destruction.
32555	1247	2	O all ye that are pure in heart, lift up your heads and receive the pleasing word of God, and feast upon his love; for ye may, if your minds are firm, forever.
32556	1247	3	But, wo, wo, unto you that are not pure in heart, that are filthy this day before God; for except ye repent the land is cursed for your sakes; and the Lamanites, which are not filthy like unto you, nevertheless they are cursed with a sore cursing, shall scourge you even unto destruction.
32557	1247	4	And the time speedily cometh, that except ye repent they shall possess the land of your inheritance, and the Lord God will lead away the righteous out from among you.
32558	1247	5	Behold, the Lamanites your brethren, whom ye hate because of their filthiness and the cursing which hath come upon their skins, are more righteous than you; for they have not forgotten the commandment of the Lord, which was given unto our father--that they should have save it were one wife, and concubines they should have none, and there should not be whoredoms committed among them.
32559	1247	6	And now, this commandment they observe to keep; wherefore, because of this observance, in keeping this commandment, the Lord God will not destroy them, but will be merciful unto them; and one day they shall become a blessed people.
32560	1247	7	Behold, their husbands love their wives, and their wives love their husbands; and their husbands and their wives love their children; and their unbelief and their hatred towards you is because of the iniquity of their fathers; wherefore, how much better are you than they, in the sight of your great Creator?
32561	1247	8	O my brethren, I fear that unless ye shall repent of your sins that their skins will be whiter than yours, when ye shall be brought with them before the throne of God.
32562	1247	9	Wherefore, a commandment I give unto you, which is the word of God, that ye revile no more against them because of the darkness of their skins; neither shall ye revile against them because of their filthiness; but ye shall remember your own filthiness, and remember that their filthiness came because of their fathers.
32563	1247	10	Wherefore, ye shall remember your children, how that ye have grieved their hearts because of the example that ye have set before them; and also, remember that ye may, because of your filthiness, bring your children unto destruction, and their sins be heaped upon your heads at the last day.
32564	1247	11	O my brethren, hearken unto my words; arouse the faculties of your souls; shake yourselves that ye may awake from the slumber of death; and loose yourselves from the pains of hell that ye may not become angels to the devil, to be cast into that lake of fire and brimstone which is the second death.
32565	1247	12	And now I, Jacob, spake many more things unto the people of Nephi, warning them against fornication and lasciviousness, and every kind of sin, telling them the awful consequences of them.
32566	1247	13	And a hundredth part of the proceedings of this people, which now began to be numerous, cannot be written upon these plates; but many of their proceedings are written upon the larger plates, and their wars, and their contentions, and the reigns of their kings.
32567	1247	14	These plates are called the plates of Jacob, and they were made by the hand of Nephi. And I make an end of speaking these words.
32568	1248	1	Now behold, it came to pass that I, Jacob, having ministered much unto my people in word, (and I cannot write but a little of my words, because of the difficulty of engraving our words upon plates) and we know that the things which we write upon plates must remain;
32569	1248	2	But whatsoever things we write upon anything save it be upon plates must perish and vanish away; but we can write a few words upon plates, which will give our children, and also our beloved brethren, a small degree of knowledge concerning us, or concerning their fathers--
32570	1248	3	Now in this thing we do rejoice; and we labor diligently to engraven these words upon plates, hoping that our beloved brethren and our children will receive them with thankful hearts, and look upon them that they may learn with joy and not with sorrow, neither with contempt, concerning their first parents.
32571	1248	4	For, for this intent have we written these things, that they may know that we knew of Christ, and we had a hope of his glory many hundred years before his coming; and not only we ourselves had a hope of his glory, but also all the holy prophets which were before us.
32572	1248	5	Behold, they believed in Christ and worshiped the Father in his name, and also we worship the Father in his name. And for this intent we keep the law of Moses, it pointing our souls to him; and for this cause it is sanctified unto us for righteousness, even as it was accounted unto Abraham in the wilderness to be obedient unto the commands of God in offering up his son Isaac, which is a similitude of God and his Only Begotten Son.
32573	1248	6	Wherefore, we search the prophets, and we have many revelations and the spirit of prophecy; and having all these witnesses we obtain a hope, and our faith becometh unshaken, insomuch that we truly can command in the name of Jesus and the very trees obey us, or the mountains, or the waves of the sea.
32574	1248	7	Nevertheless, the Lord God showeth us our weakness that we may know that it is by his grace, and his great condescensions unto the children of men, that we have power to do these things.
32575	1248	8	Behold, great and marvelous are the works of the Lord. How unsearchable are the depths of the mysteries of him; and it is impossible that man should find out all his ways. And no man knoweth of his ways save it be revealed unto him; wherefore, brethren, despise not the revelations of God.
32576	1248	9	For behold, by the power of his word man came upon the face of the earth, which earth was created by the power of his word. Wherefore, if God being able to speak and the world was, and to speak and man was created, O then, why not able to command the earth, or the workmanship of his hands upon the face of it, according to his will and pleasure?
32577	1248	10	Wherefore, brethren, seek not to counsel the Lord, but to take counsel from his hand. For behold, ye yourselves know that he counseleth in wisdom, and in justice, and in great mercy, over all his works.
32578	1248	11	Wherefore, beloved brethren, be reconciled unto him through the atonement of Christ, his Only Begotten Son, and ye may obtain a resurrection, according to the power of the resurrection which is in Christ, and be presented as the first-fruits of Christ unto God, having faith, and obtained a good hope of glory in him before he manifesteth himself in the flesh.
32579	1248	12	And now, beloved, marvel not that I tell you these things; for why not speak of the atonement of Christ, and attain to a perfect knowledge of him, as to attain to the knowledge of a resurrection and the world to come?
32580	1248	13	Behold, my brethren, he that prophesieth, let him prophesy to the understanding of men; for the Spirit speaketh the truth and lieth not. Wherefore, it speaketh of things as they really are, and of things as they really will be; wherefore, these things are manifested unto us plainly, for the salvation of our souls. But behold, we are not witnesses alone in these things; for God also spake them unto prophets of old.
32581	1248	14	But behold, the Jews were a stiffnecked people; and they despised the words of plainness, and killed the prophets, and sought for things that they could not understand. Wherefore, because of their blindness, which blindness came by looking beyond the mark, they must needs fall; for God hath taken away his plainness from them, and delivered unto them many things which they cannot understand, because they desired it. And because they desired it God hath done it, that they may stumble.
32582	1248	15	And now I, Jacob, am led on by the Spirit unto prophesying; for I perceive by the workings of the Spirit which is in me, that by the stumbling of the Jews they will reject the stone upon which they might build and have safe foundation.
32583	1248	16	But behold, according to the scriptures, this stone shall become the great, and the last, and the only sure foundation, upon which the Jews can build.
32584	1248	17	And now, my beloved, how is it possible that these, after having rejected the sure foundation, can ever build upon it, that it may become the head of their corner?
32585	1248	18	Behold, my beloved brethren, I will unfold this mystery unto you; if I do not, by any means, get shaken from my firmness in the Spirit, and stumble because of my over anxiety for you.
32586	1249	1	Behold, my brethren, do ye not remember to have read the words of the prophet Zenos, which he spake unto the house of Israel, saying:
32587	1249	2	Hearken, O ye house of Israel, and hear the words of me, a prophet of the Lord.
32588	1249	3	For behold, thus saith the Lord, I will liken thee, O house of Israel, like unto a tame olive-tree, which a man took and nourished in his vineyard; and it grew, and waxed old, and began to decay.
32589	1249	4	And it came to pass that the master of the vineyard went forth, and he saw that his olive-tree began to decay; and he said: I will prune it, and dig about it, and nourish it, that perhaps it may shoot forth young and tender branches, and it perish not.
32590	1249	5	And it came to pass that he pruned it, and digged about it, and nourished it according to his word.
32591	1249	6	And it came to pass that after many days it began to put forth somewhat a little, young and tender branches; but behold, the main top thereof began to perish.
32592	1249	7	And it came to pass that the master of the vineyard saw it, and he said unto his servant: It grieveth me that I should lose this tree; wherefore, go and pluck the branches from a wild olive-tree, and bring them hither unto me; and we will pluck off those main branches which are beginning to wither away, and we will cast them into the fire that they may be burned.
32593	1249	8	And behold, saith the Lord of the vineyard, I take away many of these young and tender branches, and I will graft them whithersoever I will; and it mattereth not that if it so be that the root of this tree will perish, I may preserve the fruit thereof unto myself; wherefore, I will take these young and tender branches, and I will graft them whithersoever I will.
32594	1249	9	Take thou the branches of the wild olive-tree, and graft them in, in the stead thereof; and these which I have plucked off I will cast into the fire and burn them, that they may not cumber the ground of my vineyard.
32595	1249	10	And it came to pass that the servant of the Lord of the vineyard did according to the word of the Lord of the vineyard, and grafted in the branches of the wild olive-tree.
32596	1249	11	And the Lord of the vineyard caused that it should be digged about, and pruned, and nourished, saying unto his servant: It grieveth me that I should lose this tree; wherefore, that perhaps I might preserve the roots thereof that they perish not, that I might preserve them unto myself, I have done this thing.
32597	1249	12	Wherefore, go thy way; watch the tree, and nourish it, according to my words.
32598	1249	13	And these will I place in the nethermost part of my vineyard, whithersoever I will, it mattereth not unto thee; and I do it that I may preserve unto myself the natural branches of the tree; and also, that I may lay up fruit thereof against the season, unto myself; for it grieveth me that I should lose this tree and the fruit thereof.
32599	1249	14	And it came to pass that the Lord of the vineyard went his way, and hid the natural branches of the tame olive-tree in the nethermost parts of the vineyard, some in one and some in another, according to his will and pleasure.
32600	1249	15	And it came to pass that a long time passed away, and the Lord of the vineyard said unto his servant: Come, let us go down into the vineyard, that we may labor in the vineyard.
32601	1249	16	And it came to pass that the Lord of the vineyard, and also the servant, went down into the vineyard to labor. And it came to pass that the servant said unto his master: Behold, look here; behold the tree.
32602	1249	17	And it came to pass that the Lord of the vineyard looked and beheld the tree in the which the wild olive branches had been grafted; and it had sprung forth and begun to bear fruit. And he beheld that it was good; and the fruit thereof was like unto the natural fruit.
32603	1249	18	And he said unto the servant: Behold, the branches of the wild tree have taken hold of the moisture of the root thereof, that the root thereof hath brought forth much strength; and because of the much strength of the root thereof the wild branches have brought forth tame fruit. Now, if we had not grafted in these branches, the tree thereof would have perished. And now, behold, I shall lay up much fruit, which the tree thereof hath brought forth; and the fruit thereof I shall lay up against the season, unto mine own self.
32604	1249	19	And it came to pass that the Lord of the vineyard said unto the servant: Come, let us go to the nethermost part of the vineyard, and behold if the natural branches of the tree have not brought forth much fruit also, that I may lay up of the fruit thereof against the season, unto mine own self.
32605	1249	20	And it came to pass that they went forth whither the master had hid the natural branches of the tree, and he said unto the servant: Behold these; and he beheld the first that it had brought forth much fruit; and he beheld also that it was good. And he said unto the servant: Take of the fruit thereof, and lay it up against the season, that I may preserve it unto mine own self; for behold, said he, this long time have I nourished it, and it hath brought forth much fruit.
32606	1249	21	And it came to pass that the servant said unto his master: How comest thou hither to plant this tree, or this branch of the tree? For behold, it was the poorest spot in all the land of thy vineyard.
32607	1249	22	And the Lord of the vineyard said unto him: Counsel me not; I knew that it was a poor spot of ground; wherefore, I said unto thee, I have nourished it this long time, and thou beholdest that it hath brought forth much fruit.
32608	1249	23	And it came to pass that the Lord of the vineyard said unto his servant: Look hither; behold I have planted another branch of the tree also; and thou knowest that this spot of ground was poorer than the first. But, behold the tree. I have nourished it this long time, and it hath brought forth much fruit; therefore, gather it, and lay it up against the season, that I may preserve it unto mine own self.
32609	1249	24	And it came to pass that the Lord of the vineyard said again unto his servant: Look hither, and behold another branch also, which I have planted; behold that I have nourished it also, and it hath brought forth fruit.
32610	1249	25	And he said unto the servant: Look hither and behold the last. Behold, this have I planted in a good spot of ground; and I have nourished it this long time, and only a part of the tree hath brought forth tame fruit, and the other part of the tree hath brought forth wild fruit; behold, I have nourished this tree like unto the others.
32611	1249	26	And it came to pass that the Lord of the vineyard said unto the servant: Pluck off the branches that have not brought forth good fruit, and cast them into the fire.
32612	1249	27	But behold, the servant said unto him: Let us prune it, and dig about it, and nourish it a little longer, that perhaps it may bring forth good fruit unto thee, that thou canst lay it up against the season.
32613	1249	28	And it came to pass that the Lord of the vineyard and the servant of the Lord of the vineyard did nourish all the fruit of the vineyard.
32614	1249	29	And it came to pass that a long time had passed away, and the Lord of the vineyard said unto his servant: Come, let us go down into the vineyard, that we may labor again in the vineyard. For behold, the time draweth near, and the end soon cometh; wherefore, I must lay up fruit against the season, unto mine own self.
32615	1249	30	And it came to pass that the Lord of the vineyard and the servant went down into the vineyard; and they came to the tree whose natural branches had been broken off, and the wild branches had been grafted in; and behold all sorts of fruit did cumber the tree.
32616	1249	31	And it came to pass that the Lord of the vineyard did taste of the fruit, every sort according to its number. And the Lord of the vineyard said: Behold, this long time have we nourished this tree, and I have laid up unto myself against the season much fruit.
32617	1249	32	But behold, this time it hath brought forth much fruit, and there is none of it which is good. And behold, there are all kinds of bad fruit; and it profiteth me nothing, notwithstanding all our labor; and now it grieveth me that I should lose this tree.
32618	1249	33	And the Lord of the vineyard said unto the servant: What shall we do unto the tree, that I may preserve again good fruit thereof unto mine own self?
32619	1249	34	And the servant said unto his master: Behold, because thou didst graft in the branches of the wild olive-tree they have nourished the roots, that they are alive and they have not perished; wherefore thou beholdest that they are yet good.
32620	1249	35	And it came to pass that the Lord of the vineyard said unto his servant: The tree profiteth me nothing, and the roots thereof profit me nothing so long as it shall bring forth evil fruit.
32621	1249	36	Nevertheless, I know that the roots are good, and for mine own purpose I have preserved them; and because of their much strength they have hitherto brought forth, from the wild branches, good fruit.
32622	1249	37	But behold, the wild branches have grown and have overrun the roots thereof; and because that the wild branches have overcome the roots thereof it hath brought forth much evil fruit; and because that it hath brought forth so much evil fruit thou beholdest that it beginneth to perish; and it will soon become ripened, that it may be cast into the fire, except we should do something for it to preserve it.
32623	1249	38	And it came to pass that the Lord of the vineyard said unto his servant: Let us go down into the nethermost parts of the vineyard, and behold if the natural branches have also brought forth evil fruit.
32624	1249	39	And it came to pass that they went down into the nethermost parts of the vineyard. And it came to pass that they beheld that the fruit of the natural branches had become corrupt also; yea, the first and the second and also the last; and they had all become corrupt.
32625	1249	40	And the wild fruit of the last had overcome that part of the tree which brought forth good fruit, even that the branch had withered away and died.
32626	1249	41	And it came to pass that the Lord of the vineyard wept, and said unto the servant: What could I have done more for my vineyard?
32627	1249	42	Behold, I knew that all the fruit of the vineyard, save it were these, had become corrupted. And now these which have once brought forth good fruit have also become corrupted; and now all the trees of my vineyard are good for nothing save it be to be hewn down and cast into the fire.
32628	1249	43	And behold this last, whose branch hath withered away, I did plant in a good spot of ground; yea, even that which was choice unto me above all other parts of the land of my vineyard.
32629	1249	44	And thou beheldest that I also cut down that which cumbered this spot of ground, that I might plant this tree in the stead thereof.
32630	1249	45	And thou beheldest that a part thereof brought forth good fruit, and a part thereof brought forth wild fruit; and because I plucked not the branches thereof and cast them into the fire, behold, they have overcome the good branch that it hath withered away.
32631	1249	46	And now, behold, notwithstanding all the care which we have taken of my vineyard, the trees thereof have become corrupted, that they bring forth no good fruit; and these I had hoped to preserve, to have laid up fruit thereof against the season, unto mine own self. But, behold, they have become like unto the wild olive-tree, and they are of no worth but to be hewn down and cast into the fire; and it grieveth me that I should lose them.
32632	1249	47	But what could I have done more in my vineyard? Have I slackened mine hand, that I have not nourished it? Nay, I have nourished it, and I have digged about it, and I have pruned it, and I have dunged it; and I have stretched forth mine hand almost all the day long, and the end draweth nigh. And it grieveth me that I should hew down all the trees of my vineyard, and cast them into the fire that they should be burned. Who is it that has corrupted my vineyard?
32633	1249	48	And it came to pass that the servant said unto his master: Is it not the loftiness of thy vineyard--have not the branches thereof overcome the roots which are good? And because the branches have overcome the roots thereof, behold they grew faster than the strength of the roots, taking strength unto themselves. Behold, I say, is not this the cause that the trees of thy vineyard have become corrupted?
32634	1249	49	And it came to pass that the Lord of the vineyard said unto the servant: Let us go to and hew down the trees of the vineyard and cast them into the fire, that they shall not cumber the ground of my vineyard, for I have done all. What could I have done more for my vineyard?
32635	1249	50	But, behold, the servant said unto the Lord of the vineyard: Spare it a little longer.
32636	1249	51	And the Lord said: Yea, I will spare it a little longer, for it grieveth me that I should lose the trees of my vineyard.
32637	1249	52	Wherefore, let us take of the branches of these which I have planted in the nethermost parts of my vineyard, and let us graft them into the tree from whence they came; and let us pluck from the tree those branches whose fruit is most bitter, and graft in the natural branches of the tree in the stead thereof.
32638	1249	53	And this will I do that the tree may not perish, that, perhaps, I may preserve unto myself the roots thereof for mine own purpose.
32639	1249	54	And, behold, the roots of the natural branches of the tree which I planted whithersoever I would are yet alive; wherefore, that I may preserve them also for mine own purpose, I will take of the branches of this tree, and I will graft them in unto them. Yea, I will graft in unto them the branches of their mother tree, that I may preserve the roots also unto mine own self, that when they shall be sufficiently strong perhaps they may bring forth good fruit unto me, and I may yet have glory in the fruit of my vineyard.
32640	1249	55	And it came to pass that they took from the natural tree which had become wild, and grafted in unto the natural trees, which also had become wild.
32641	1249	56	And they also took of the natural trees which had become wild, and grafted into their mother tree.
32642	1249	57	And the Lord of the vineyard said unto the servant: Pluck not the wild branches from the trees, save it be those which are most bitter; and in them ye shall graft according to that which I have said.
32643	1249	58	And we will nourish again the trees of the vineyard, and we will trim up the branches thereof; and we will pluck from the trees those branches which are ripened, that must perish, and cast them into the fire.
32644	1249	59	And this I do that, perhaps, the roots thereof may take strength because of their goodness; and because of the change of the branches, that the good may overcome the evil.
32645	1249	60	And because that I have preserved the natural branches and the roots thereof, and that I have grafted in the natural branches again into their mother tree, and have preserved the roots of their mother tree, that, perhaps, the trees of my vineyard may bring forth again good fruit; and that I may have joy again in the fruit of my vineyard, and, perhaps, that I may rejoice exceedingly that I have preserved the roots and the branches of the first fruit--
32646	1249	61	Wherefore, go to, and call servants, that we may labor diligently with our might in the vineyard, that we may prepare the way, that I may bring forth again the natural fruit, which natural fruit is good and the most precious above all other fruit.
32647	1249	62	Wherefore, let us go to and labor with our might this last time, for behold the end draweth nigh, and this is for the last time that I shall prune my vineyard.
32648	1249	63	Graft in the branches; begin at the last that they may be first, and that the first may be last, and dig about the trees, both old and young, the first and the last; and the last and the first, that all may be nourished once again for the last time.
32649	1249	64	Wherefore, dig about them, and prune them, and dung them once more, for the last time, for the end draweth nigh. And if it be so that these last grafts shall grow, and bring forth the natural fruit, then shall ye prepare the way for them, that they may grow.
32650	1249	65	And as they begin to grow ye shall clear away the branches which bring forth bitter fruit, according to the strength of the good and the size thereof; and ye shall not clear away the bad thereof all at once, lest the roots thereof should be too strong for the graft, and the graft thereof shall perish, and I lose the trees of my vineyard.
32651	1249	66	For it grieveth me that I should lose the trees of my vineyard; wherefore ye shall clear away the bad according as the good shall grow, that the root and the top may be equal in strength, until the good shall overcome the bad, and the bad be hewn down and cast into the fire, that they cumber not the ground of my vineyard; and thus will I sweep away the bad out of my vineyard.
32652	1249	67	And the branches of the natural tree will I graft in again into the natural tree;
32653	1249	68	And the branches of the natural tree will I graft into the natural branches of the tree; and thus will I bring them together again, that they shall bring forth the natural fruit, and they shall be one.
32654	1249	69	And the bad shall be cast away, yea, even out of all the land of my vineyard; for behold, only this once will I prune my vineyard.
32655	1249	70	And it came to pass that the Lord of the vineyard sent his servant; and the servant went and did as the Lord had commanded him, and brought other servants; and they were few.
32656	1249	71	And the Lord of the vineyard said unto them: Go to, and labor in the vineyard, with your might. For behold, this is the last time that I shall nourish my vineyard; for the end is nigh at hand, and the season speedily cometh; and if ye labor with your might with me ye shall have joy in the fruit which I shall lay up unto myself against the time which will soon come.
32657	1249	72	And it came to pass that the servants did go and labor with their mights; and the Lord of the vineyard labored also with them; and they did obey the commandments of the Lord of the vineyard in all things.
32658	1249	73	And there began to be the natural fruit again in the vineyard; and the natural branches began to grow and thrive exceedingly; and the wild branches began to be plucked off and to be cast away; and they did keep the root and the top thereof equal, according to the strength thereof.
32659	1249	74	And thus they labored, with all diligence, according to the commandments of the Lord of the vineyard, even until the bad had been cast away out of the vineyard, and the Lord had preserved unto himself that the trees had become again the natural fruit; and they became like unto one body; and the fruits were equal; and the Lord of the vineyard had preserved unto himself the natural fruit, which was most precious unto him from the beginning.
32660	1249	75	And it came to pass that when the Lord of the vineyard saw that his fruit was good, and that his vineyard was no more corrupt, he called up his servants, and said unto them: Behold, for this last time have we nourished my vineyard; and thou beholdest that I have done according to my will; and I have preserved the natural fruit, that it is good, even like as it was in the beginning. And blessed art thou; for because ye have been diligent in laboring with me in my vineyard, and have kept my commandments, and have brought unto me again the natural fruit, that my vineyard is no more corrupted, and the bad is cast away, behold ye shall have joy with me because of the fruit of my vineyard.
32661	1249	76	For behold, for a long time will I lay up of the fruit of my vineyard unto mine own self against the season, which speedily cometh; and for the last time have I nourished my vineyard, and pruned it, and dug about it, and dunged it; wherefore I will lay up unto mine own self of the fruit, for a long time, according to that which I have spoken.
32662	1249	77	And when the time cometh that evil fruit shall again come into my vineyard, then will I cause the good and the bad to be gathered; and the good will I preserve unto myself, and the bad will I cast away into its own place. And then cometh the season and the end; and my vineyard will I cause to be burned with fire.
32663	1250	1	And now, behold, my brethren, as I said unto you that I would prophesy, behold, this is my prophecy--that the things which this prophet Zenos spake, concerning the house of Israel, in the which he likened them unto a tame olive-tree, must surely come to pass.
32664	1250	2	And the day that he shall set his hand again the second time to recover his people, is the day, yea, even the last time, that the servants of the Lord shall go forth in his power, to nourish and prune his vineyard; and after that the end soon cometh.
32665	1250	3	And how blessed are they who have labored diligently in his vineyard; and how cursed are they who shall be cast out into their own place! And the world shall be burned with fire.
32666	1250	4	And how merciful is our God unto us, for he remembereth the house of Israel, both roots and branches; and he stretches forth his hands unto them all the day long; and they are a stiffnecked and a gainsaying people; but as many as will not harden their hearts shall be saved in the kingdom of God.
32667	1250	5	Wherefore, my beloved brethren, I beseech of you in words of soberness that ye would repent, and come with full purpose of heart, and cleave unto God as he cleaveth unto you. And while his arm of mercy is extended towards you in the light of the day, harden not your hearts.
32668	1250	6	Yea, today, if ye will hear his voice, harden not your hearts; for why will ye die?
32669	1250	7	For behold, after ye have been nourished by the good word of God all the day long, will ye bring forth evil fruit, that ye must be hewn down and cast into the fire?
32670	1250	8	Behold, will ye reject these words? Will ye reject the words of the prophets; and will ye reject all the words which have been spoken concerning Christ, after so many have spoken concerning him; and deny the good word of Christ, and the power of God, and the gift of the Holy Ghost, and quench the Holy Spirit, and make a mock of the great plan of redemption, which hath been laid for you?
32671	1250	9	Know ye not that if ye will do these things, that the power of the redemption and the resurrection, which is in Christ, will bring you to stand with shame and awful guilt before the bar of God?
32672	1250	10	And according to the power of justice, for justice cannot be denied, ye must go away into that lake of fire and brimstone, whose flames are unquenchable, and whose smoke ascendeth up forever and ever, which lake of fire and brimstone is endless torment.
32673	1250	11	O then, my beloved brethren, repent ye, and enter in at the strait gate, and continue in the way which is narrow, until ye shall obtain eternal life.
32674	1250	12	O be wise; what can I say more?
32675	1250	13	Finally, I bid you farewell, until I shall meet you before the pleasing bar of God, which bar striketh the wicked with awful dread and fear. Amen.
32676	1251	1	And now it came to pass after some years had passed away, there came a man among the people of Nephi, whose name was Sherem.
32677	1251	2	And it came to pass that he began to preach among the people, and to declare unto them that there should be no Christ. And he preached many things which were flattering unto the people; and this he did that he might overthrow the doctrine of Christ.
32678	1251	3	And he labored diligently that he might lead away the hearts of the people, insomuch that he did lead away many hearts; and he knowing that I, Jacob, had faith in Christ who should come, he sought much opportunity that he might come unto me.
32679	1251	4	And he was learned, that he had a perfect knowledge of the language of the people; wherefore, he could use much flattery, and much power of speech, according to the power of the devil.
32680	1251	5	And he had hope to shake me from the faith, notwithstanding the many revelations and the many things which I had seen concerning these things; for I truly had seen angels, and they had ministered unto me. And also, I had heard the voice of the Lord speaking unto me in very word, from time to time; wherefore, I could not be shaken.
32681	1251	6	And it came to pass that he came unto me, and on this wise did he speak unto me, saying: Brother Jacob, I have sought much opportunity that I might speak unto you; for I have heard and also know that thou goest about much, preaching that which ye call the gospel, or the doctrine of Christ.
32682	1251	7	And ye have led away much of this people that they pervert the right way of God, and keep not the law of Moses which is the right way; and convert the law of Moses into the worship of a being which ye say shall come many hundred years hence. And now behold, I, Sherem, declare unto you that this is blasphemy; for no man knoweth of such things; for he cannot tell of things to come. And after this manner did Sherem contend against me.
32683	1251	8	But behold, the Lord God poured in his Spirit into my soul, insomuch that I did confound him in all his words.
32684	1251	9	And I said unto him: Deniest thou the Christ who shall come? And he said: If there should be a Christ, I would not deny him; but I know that there is no Christ, neither has been, nor ever will be.
32685	1251	10	And I said unto him: Believest thou the scriptures? And he said, Yea.
32686	1251	11	And I said unto him: Then ye do not understand them; for they truly testify of Christ. Behold, I say unto you that none of the prophets have written, nor prophesied, save they have spoken concerning this Christ.
32687	1251	12	And this is not all--it has been made manifest unto me, for I have heard and seen; and it also has been made manifest unto me by the power of the Holy Ghost; wherefore, I know if there should be no atonement made all mankind must be lost.
32688	1251	13	And it came to pass that he said unto me: Show me a sign by this power of the Holy Ghost, in the which ye know so much.
32689	1251	14	And I said unto him: What am I that I should tempt God to show unto thee a sign in the thing which thou knowest to be true? Yet thou wilt deny it, because thou art of the devil. Nevertheless, not my will be done; but if God shall smite thee, let that be a sign unto thee that he has power, both in heaven and in earth; and also, that Christ shall come. And thy will, O Lord, be done, and not mine.
32690	1251	15	And it came to pass that when I, Jacob, had spoken these words, the power of the Lord came upon him, insomuch that he fell to the earth. And it came to pass that he was nourished for the space of many days.
32691	1251	16	And it came to pass that he said unto the people: Gather together on the morrow, for I shall die; wherefore, I desire to speak unto the people before I shall die.
32692	1251	17	And it came to pass that on the morrow the multitude were gathered together; and he spake plainly unto them and denied the things which he had taught them, and confessed the Christ, and the power of the Holy Ghost, and the ministering of angels.
32693	1251	18	And he spake plainly unto them, that he had been deceived by the power of the devil. And he spake of hell, and of eternity, and of eternal punishment.
32694	1251	19	And he said: I fear lest I have committed the unpardonable sin, for I have lied unto God; for I denied the Christ, and said that I believed the scriptures; and they truly testify of him. And because I have thus lied unto God I greatly fear lest my case shall be awful; but I confess unto God.
32695	1251	20	And it came to pass that when he had said these words he could say no more, and he gave up the ghost.
32696	1251	21	And when the multitude had witnessed that he spake these things as he was about to give up the ghost, they were astonished exceedingly; insomuch that the power of God came down upon them, and they were overcome that they fell to the earth.
32697	1251	22	Now, this thing was pleasing unto me, Jacob, for I had requested it of my Father who was in heaven; for he had heard my cry and answered my prayer.
32698	1251	23	And it came to pass that peace and the love of God was restored again among the people; and they searched the scriptures, and hearkened no more to the words of this wicked man.
32699	1251	24	And it came to pass that many means were devised to reclaim and restore the Lamanites to the knowledge of the truth; but it all was vain, for they delighted in wars and bloodshed, and they had an eternal hatred against us, their brethren. And they sought by the power of their arms to destroy us continually.
32700	1251	25	Wherefore, the people of Nephi did fortify against them with their arms, and with all their might, trusting in the God and rock of their salvation; wherefore, they became as yet, conquerors of their enemies.
32701	1251	26	And it came to pass that I, Jacob, began to be old; and the record of this people being kept on the other plates of Nephi, wherefore, I conclude this record, declaring that I have written according to the best of my knowledge, by saying that the time passed away with us, and also our lives passed away like as it were unto us a dream, we being a lonesome and a solemn people, wanderers, cast out from Jerusalem, born in tribulation, in a wilderness, and hated of our brethren, which caused wars and contentions; wherefore, we did mourn out our days.
32702	1251	27	And I, Jacob, saw that I must soon go down to my grave; wherefore, I said unto my son Enos: Take these plates. And I told him the things which my brother Nephi had commanded me, and he promised obedience unto the commands. And I make an end of my writing upon these plates, which writing has been small; and to the reader I bid farewell, hoping that many of my brethren may read my words. Brethren, adieu.
32703	1252	1	Behold, it came to pass that I, Enos, knowing my father that he was a just man--for he taught me in his language, and also in the nurture and admonition of the Lord--and blessed be the name of my God for it--
32704	1252	2	And I will tell you of the wrestle which I had before God, before I received a remission of my sins.
32705	1252	3	Behold, I went to hunt beasts in the forests; and the words which I had often heard my father speak concerning eternal life, and the joy of the saints, sunk deep into my heart.
32706	1252	4	And my soul hungered; and I kneeled down before my Maker, and I cried unto him in mighty prayer and supplication for mine own soul; and all the day long did I cry unto him; yea, and when the night came I did still raise my voice high that it reached the heavens.
32707	1252	5	And there came a voice unto me, saying: Enos, thy sins are forgiven thee, and thou shalt be blessed.
32708	1252	6	And I, Enos, knew that God could not lie; wherefore, my guilt was swept away.
32709	1252	7	And I said: Lord, how is it done?
32710	1252	8	And he said unto me: Because of thy faith in Christ, whom thou hast never before heard nor seen. And many years pass away before he shall manifest himself in the flesh; wherefore, go to, thy faith hath made thee whole.
32711	1252	9	Now, it came to pass that when I had heard these words I began to feel a desire for the welfare of my brethren, the Nephites; wherefore, I did pour out my whole soul unto God for them.
32712	1252	10	And while I was thus struggling in the spirit, behold, the voice of the Lord came into my mind again, saying: I will visit thy brethren according to their diligence in keeping my commandments. I have given unto them this land, and it is a holy land; and I curse it not save it be for the cause of iniquity; wherefore, I will visit thy brethren according as I have said; and their transgressions will I bring down with sorrow upon their own heads.
32713	1252	11	And after I, Enos, had heard these words, my faith began to be unshaken in the Lord; and I prayed unto him with many long strugglings for my brethren, the Lamanites.
32714	1252	12	And it came to pass that after I had prayed and labored with all diligence, the Lord said unto me: I will grant unto thee according to thy desires, because of thy faith.
32715	1252	13	And now behold, this was the desire which I desired of him--that if it should so be, that my people, the Nephites, should fall into transgression, and by any means be destroyed, and the Lamanites should not be destroyed, that the Lord God would preserve a record of my people, the Nephites; even if it so be by the power of his holy arm, that it might be brought forth at some future day unto the Lamanites, that, perhaps, they might be brought unto salvation--
32716	1252	14	For at the present our strugglings were vain in restoring them to the true faith. And they swore in their wrath that, if it were possible, they would destroy our records and us, and also all the traditions of our fathers.
32717	1252	15	Wherefore, I knowing that the Lord God was able to preserve our records, I cried unto him continually, for he had said unto me: Whatsoever thing ye shall ask in faith, believing that ye shall receive in the name of Christ, ye shall receive it.
32718	1252	16	And I had faith, and I did cry unto God that he would preserve the records; and he covenanted with me that he would bring them forth unto the Lamanites in his own due time.
32719	1252	17	And I, Enos, knew it would be according to the covenant which he had made; wherefore my soul did rest.
32720	1252	18	And the Lord said unto me: Thy fathers have also required of me this thing; and it shall be done unto them according to their faith; for their faith was like unto thine.
32721	1252	19	And now it came to pass that I, Enos, went about among the people of Nephi, prophesying of things to come, and testifying of the things which I had heard and seen.
32722	1252	20	And I bear record that the people of Nephi did seek diligently to restore the Lamanites unto the true faith in God. But our labors were vain; their hatred was fixed, and they were led by their evil nature that they became wild, and ferocious, and a blood-thirsty people, full of idolatry and filthiness; feeding upon beasts of prey; dwelling in tents, and wandering about in the wilderness with a short skin girdle about their loins and their heads shaven; and their skill was in the bow, and in the cimeter, and the ax. And many of them did eat nothing save it was raw meat; and they were continually seeking to destroy us.
32723	1252	21	And it came to pass that the people of Nephi did till the land, and raise all manner of grain, and of fruit, and flocks of herds, and flocks of all manner of cattle of every kind, and goats, and wild goats, and also many horses.
32724	1252	22	And there were exceedingly many prophets among us. And the people were a stiffnecked people, hard to understand.
32725	1252	23	And there was nothing save it was exceeding harshness, preaching and prophesying of wars, and contentions, and destructions, and continually reminding them of death, and the duration of eternity, and the judgments and the power of God, and all these things--stirring them up continually to keep them in the fear of the Lord. I say there was nothing short of these things, and exceedingly great plainness of speech, would keep them from going down speedily to destruction. And after this manner do I write concerning them.
32726	1252	24	And I saw wars between the Nephites and Lamanites in the course of my days.
32727	1252	25	And it came to pass that I began to be old, and an hundred and seventy and nine years had passed away from the time that our father Lehi left Jerusalem.
32728	1252	26	And I saw that I must soon go down to my grave, having been wrought upon by the power of God that I must preach and prophesy unto this people, and declare the word according to the truth which is in Christ. And I have declared it in all my days, and have rejoiced in it above that of the world.
32729	1252	27	And I soon go to the place of my rest, which is with my Redeemer; for I know that in him I shall rest. And I rejoice in the day when my mortal shall put on immortality, and shall stand before him; then shall I see his face with pleasure, and he will say unto me: Come unto me, ye blessed, there is a place prepared for you in the mansions of my Father. Amen.
32730	1253	1	Now behold, I, Jarom, write a few words according to the commandment of my father, Enos, that our genealogy may be kept.
32731	1253	2	And as these plates are small, and as these things are written for the intent of the benefit of our brethren the Lamanites, wherefore, it must needs be that I write a little; but I shall not write the things of my prophesying, nor of my revelations. For what could I write more than my fathers have written? For have not they revealed the plan of salvation? I say unto you, Yea; and this sufficeth me.
32732	1253	3	Behold, it is expedient that much should be done among this people, because of the hardness of their hearts, and the deafness of their ears, and the blindness of their minds, and the stiffness of their necks; nevertheless, God is exceedingly merciful unto them, and has not as yet swept them off from the face of the land.
32733	1253	4	And there are many among us who have many revelations, for they are not all stiffnecked. And as many as are not stiffnecked and have faith, have communion with the Holy Spirit, which maketh manifest unto the children of men, according to their faith.
32734	1253	5	And now, behold, two hundred years had passed away, and the people of Nephi had waxed strong in the land. They observed to keep the law of Moses and the sabbath day holy unto the Lord. And they profaned not; neither did they blaspheme. And the laws of the land were exceedingly strict.
32735	1253	6	And they were scattered upon much of the face of the land, and the Lamanites also. And they were exceedingly more numerous than were they of the Nephites; and they loved murder and would drink the blood of beasts.
32736	1253	7	And it came to pass that they came many times against us, the Nephites, to battle. But our kings and our leaders were mighty men in the faith of the Lord; and they taught the people the ways of the Lord; wherefore, we withstood the Lamanites and swept them away out of our lands, and began to fortify our cities, or whatsoever place of our inheritance.
32737	1253	8	And we multiplied exceedingly, and spread upon the face of the land, and became exceedingly rich in gold, and in silver, and in precious things, and in fine workmanship of wood, in buildings, and in machinery, and also in iron and copper, and brass and steel, making all manner of tools of every kind to till the ground, and weapons of war--yea, the sharp pointed arrow, and the quiver, and the dart, and the javelin, and all preparations for war.
32738	1253	9	And thus being prepared to meet the Lamanites, they did not prosper against us. But the word of the Lord was verified, which he spake unto our fathers, saying that: Inasmuch as ye will keep my commandments ye shall prosper in the land.
32739	1253	10	And it came to pass that the prophets of the Lord did threaten the people of Nephi, according to the word of God, that if they did not keep the commandments, but should fall into transgression, they should be destroyed from off the face of the land.
32740	1253	11	Wherefore, the prophets, and the priests, and the teachers, did labor diligently, exhorting with all long-suffering the people to diligence; teaching the law of Moses, and the intent for which it was given; persuading them to look forward unto the Messiah, and believe in him to come as though he already was. And after this manner did they teach them.
32741	1253	12	And it came to pass that by so doing they kept them from being destroyed upon the face of the land; for they did prick their hearts with the word, continually stirring them up unto repentance.
32742	1253	13	And it came to pass that two hundred and thirty and eight years had passed away--after the manner of wars, and contentions, and dissensions, for the space of much of the time.
32743	1253	14	And I, Jarom, do not write more, for the plates are small. But behold, my brethren, ye can go to the other plates of Nephi; for behold, upon them the records of our wars are engraven, according to the writings of the kings, or those which they caused to be written.
32744	1253	15	And I deliver these plates into the hands of my son Omni, that they may be kept according to the commandments of my fathers.
32745	1254	1	Behold, it came to pass that I, Omni, being commanded by my father, Jarom, that I should write somewhat upon these plates, to preserve our genealogy--
32746	1254	2	Wherefore, in my days, I would that ye should know that I fought much with the sword to preserve my people, the Nephites, from falling into the hands of their enemies, the Lamanites. But behold, I of myself am a wicked man, and I have not kept the statutes and the commandments of the Lord as I ought to have done.
32747	1254	3	And it came to pass that two hundred and seventy and six years had passed away, and we had many seasons of peace; and we had many seasons of serious war and bloodshed. Yea, and in fine, two hundred and eighty and two years had passed away, and I had kept these plates according to the commandments of my fathers; and I conferred them upon my son Amaron. And I make an end.
32748	1254	4	And now I, Amaron, write the things whatsoever I write, which are few, in the book of my father.
32749	1254	5	Behold, it came to pass that three hundred and twenty years had passed away, and the more wicked part of the Nephites were destroyed.
32750	1254	6	For the Lord would not suffer, after he had led them out of the land of Jerusalem and kept and preserved them from falling into the hands of their enemies, yea, he would not suffer that the words should not be verified, which he spake unto our fathers, saying that: Inasmuch as ye will not keep my commandments ye shall not prosper in the land.
32751	1254	7	Wherefore, the Lord did visit them in great judgment; nevertheless, he did spare the righteous that they should not perish, but did deliver them out of the hands of their enemies.
32752	1254	8	And it came to pass that I did deliver the plates unto my brother Chemish.
32753	1254	9	Now I, Chemish, write what few things I write, in the same book with my brother; for behold, I saw the last which he wrote, that he wrote it with his own hand; and he wrote it in the day that he delivered them unto me. And after this manner we keep the records, for it is according to the commandments of our fathers. And I make an end.
32754	1254	10	Behold, I, Abinadom, am the son of Chemish. Behold, it came to pass that I saw much war and contention between my people, the Nephites, and the Lamanites; and I, with my own sword, have taken the lives of many of the Lamanites in the defence of my brethren.
32755	1254	11	And behold, the record of this people is engraven upon plates which is had by the kings, according to the generations; and I know of no revelation save that which has been written, neither prophecy; wherefore, that which is sufficient is written. And I make an end.
32756	1254	12	Behold, I am Amaleki, the son of Abinadom. Behold, I will speak unto you somewhat concerning Mosiah, who was made king over the land of Zarahemla; for behold, he being warned of the Lord that he should flee out of the land of Nephi, and as many as would hearken unto the voice of the Lord should also depart out of the land with him, into the wilderness--
32757	1254	13	And it came to pass that he did according as the Lord had commanded him. And they departed out of the land into the wilderness, as many as would hearken unto the voice of the Lord; and they were led by many preachings and prophesyings. And they were admonished continually by the word of God; and they were led by the power of his arm, through the wilderness until they came down into the land which is called the land of Zarahemla.
32758	1254	14	And they discovered a people, who were called the people of Zarahemla. Now, there was great rejoicing among the people of Zarahemla; and also Zarahemla did rejoice exceedingly, because the Lord had sent the people of Mosiah with the plates of brass which contained the record of the Jews.
32759	1254	15	Behold, it came to pass that Mosiah discovered that the people of Zarahemla came out from Jerusalem at the time that Zedekiah, king of Judah, was carried away captive into Babylon.
32760	1254	16	And they journeyed in the wilderness, and were brought by the hand of the Lord across the great waters, into the land where Mosiah discovered them; and they had dwelt there from that time forth.
32761	1254	17	And at the time that Mosiah discovered them, they had become exceedingly numerous. Nevertheless, they had had many wars and serious contentions, and had fallen by the sword from time to time; and their language had become corrupted; and they had brought no records with them; and they denied the being of their Creator; and Mosiah, nor the people of Mosiah, could understand them.
32762	1254	18	But it came to pass that Mosiah caused that they should be taught in his language. And it came to pass that after they were taught in the language of Mosiah, Zarahemla gave a genealogy of his fathers, according to his memory; and they are written, but not in these plates.
32763	1254	19	And it came to pass that the people of Zarahemla, and of Mosiah, did unite together; and Mosiah was appointed to be their king.
32764	1254	20	And it came to pass in the days of Mosiah, there was a large stone brought unto him with engravings on it; and he did interpret the engravings by the gift and power of God.
32765	1254	21	And they gave an account of one Coriantumr, and the slain of his people. And Coriantumr was discovered by the people of Zarahemla; and he dwelt with them for the space of nine moons.
32766	1254	22	It also spake a few words concerning his fathers. And his first parents came out from the tower, at the time the Lord confounded the language of the people; and the severity of the Lord fell upon them according to his judgments, which are just; and their bones lay scattered in the land northward.
32767	1254	23	Behold, I, Amaleki, was born in the days of Mosiah; and I have lived to see his death; and Benjamin, his son, reigneth in his stead.
32768	1254	24	And behold, I have seen, in the days of king Benjamin, a serious war and much bloodshed between the Nephites and the Lamanites. But behold, the Nephites did obtain much advantage over them; yea, insomuch that king Benjamin did drive them out of the land of Zarahemla.
32769	1254	25	And it came to pass that I began to be old; and, having no seed, and knowing king Benjamin to be a just man before the Lord, wherefore, I shall deliver up these plates unto him, exhorting all men to come unto God, the Holy One of Israel, and believe in prophesying, and in revelations, and in the ministering of angels, and in the gift of speaking with tongues, and in the gift of interpreting languages, and in all things which are good; for there is nothing which is good save it comes from the Lord; and that which is evil cometh from the devil.
32770	1254	26	And now, my beloved brethren, I would that ye should come unto Christ, who is the Holy One of Israel, and partake of his salvation, and the power of his redemption. Yea, come unto him, and offer your whole souls as an offering unto him, and continue in fasting and praying, and endure to the end; and as the Lord liveth ye will be saved.
32771	1254	27	And now I would speak somewhat concerning a certain number who went up into the wilderness to return to the land of Nephi; for there was a large number who were desirous to possess the land of their inheritance.
32772	1254	28	Wherefore, they went up into the wilderness. And their leader being a strong and mighty man, and a stiffnecked man, wherefore he caused a contention among them; and they were all slain, save fifty, in the wilderness, and they returned again to the land of Zarahemla.
32773	1254	29	And it came to pass that they also took others to a considerable number, and took their journey again into the wilderness.
32774	1254	30	And I, Amaleki, had a brother, who also went with them; and I have not since known concerning them. And I am about to lie down in my grave; and these plates are full. And I make an end of my speaking.
32775	1255	1	And now I, Mormon, being about to deliver up the record which I have been making into the hands of my son Moroni, behold I have witnessed almost all the destruction of my people, the Nephites.
32776	1255	2	And it is many hundred years after the coming of Christ that I deliver these records into the hands of my son; and it supposeth me that he will witness the entire destruction of my people. But may God grant that he may survive them, that he may write somewhat concerning them, and somewhat concerning Christ, that perhaps some day it may profit them.
32777	1255	3	And now, I speak somewhat concerning that which I have written; for after I had made an abridgment from the plates of Nephi, down to the reign of this king Benjamin, of whom Amaleki spake, I searched among the records which had been delivered into my hands, and I found these plates, which contained this small account of the prophets, from Jacob down to the reign of this king Benjamin, and also many of the words of Nephi.
32778	1255	4	And the things which are upon these plates pleasing me, because of the prophecies of the coming of Christ; and my fathers knowing that many of them have been fulfilled; yea, and I also know that as many things as have been prophesied concerning us down to this day have been fulfilled, and as many as go beyond this day must surely come to pass--
32779	1255	5	Wherefore, I chose these things, to finish my record upon them, which remainder of my record I shall take from the plates of Nephi; and I cannot write the hundredth part of the things of my people.
32780	1255	6	But behold, I shall take these plates, which contain these prophesyings and revelations, and put them with the remainder of my record, for they are choice unto me; and I know they will be choice unto my brethren.
32781	1255	7	And I do this for a wise purpose; for thus it whispereth me, according to the workings of the Spirit of the Lord which is in me. And now, I do not know all things; but the Lord knoweth all things which are to come; wherefore, he worketh in me to do according to his will.
32782	1255	8	And my prayer to God is concerning my brethren, that they may once again come to the knowledge of God, yea, the redemption of Christ; that they may once again be a delightsome people.
32783	1255	9	And now I, Mormon, proceed to finish out my record, which I take from the plates of Nephi; and I make it according to the knowledge and the understanding which God has given me.
32784	1255	10	Wherefore, it came to pass that after Amaleki had delivered up these plates into the hands of king Benjamin, he took them and put them with the other plates, which contained records which had been handed down by the kings, from generation to generation until the days of king Benjamin.
32785	1255	11	And they were handed down from king Benjamin, from generation to generation until they have fallen into my hands. And I, Mormon, pray to God that they may be preserved from this time henceforth. And I know that they will be preserved; for there are great things written upon them, out of which my people and their brethren shall be judged at the great and last day, according to the word of God which is written.
32786	1255	12	And now, concerning this king Benjamin--he had somewhat of contentions among his own people.
32787	1255	13	And it came to pass also that the armies of the Lamanites came down out of the land of Nephi, to battle against his people. But behold, king Benjamin gathered together his armies, and he did stand against them; and he did fight with the strength of his own arm, with the sword of Laban.
32788	1255	14	And in the strength of the Lord they did contend against their enemies, until they had slain many thousands of the Lamanites. And it came to pass that they did contend against the Lamanites until they had driven them out of all the lands of their inheritance.
32789	1255	15	And it came to pass that after there had been false Christs, and their mouths had been shut, and they punished according to their crimes;
32790	1255	16	And after there had been false prophets, and false preachers and teachers among the people, and all these having been punished according to their crimes; and after there having been much contention and many dissensions away unto the Lamanites, behold, it came to pass that king Benjamin, with the assistance of the holy prophets who were among his people--
32791	1255	17	For behold, king Benjamin was a holy man, and he did reign over his people in righteousness; and there were many holy men in the land, and they did speak the word of God with power and with authority; and they did use much sharpness because of the stiffneckedness of the people--
32792	1255	18	Wherefore, with the help of these, king Benjamin, by laboring with all the might of his body and the faculty of his whole soul, and also the prophets, did once more establish peace in the land.
32793	1256	1	And now there was no more contention in all the land of Zarahemla, among all the people who belonged to king Benjamin, so that king Benjamin had continual peace all the remainder of his days.
32794	1256	2	And it came to pass that he had three sons; and he called their names Mosiah, and Helorum, and Helaman. And he caused that they should be taught in all the language of his fathers, that thereby they might become men of understanding; and that they might know concerning the prophecies which had been spoken by the mouths of their fathers, which were delivered them by the hand of the Lord.
32795	1256	3	And he also taught them concerning the records which were engraven on the plates of brass, saying: My sons, I would that ye should remember that were it not for these plates, which contain these records and these commandments, we must have suffered in ignorance, even at this present time, not knowing the mysteries of God.
32796	1256	4	For it were not possible that our father, Lehi, could have remembered all these things, to have taught them to his children, except it were for the help of these plates; for he having been taught in the language of the Egyptians therefore he could read these engravings, and teach them to his children, that thereby they could teach them to their children, and so fulfilling the commandments of God, even down to this present time.
32797	1256	5	I say unto you, my sons, were it not for these things, which have been kept and preserved by the hand of God, that we might read and understand of his mysteries, and have his commandments always before our eyes, that even our fathers would have dwindled in unbelief, and we should have been like unto our brethren, the Lamanites, who know nothing concerning these things, or even do not believe them when they are taught them, because of the traditions of their fathers, which are not correct.
32798	1256	6	O my sons, I would that ye should remember that these sayings are true, and also that these records are true. And behold, also the plates of Nephi, which contain the records and the sayings of our fathers from the time they left Jerusalem until now, and they are true; and we can know of their surety because we have them before our eyes.
32799	1256	7	And now, my sons, I would that ye should remember to search them diligently, that ye may profit thereby; and I would that ye should keep the commandments of God, that ye may prosper in the land according to the promises which the Lord made unto our fathers.
32800	1256	8	And many more things did king Benjamin teach his sons, which are not written in this book.
32801	1256	9	And it came to pass that after king Benjamin had made an end of teaching his sons, that he waxed old, and he saw that he must very soon go the way of all the earth; therefore, he thought it expedient that he should confer the kingdom upon one of his sons.
32802	1256	10	Therefore, he had Mosiah brought before him; and these are the words which he spake unto him, saying: My son, I would that ye should make a proclamation throughout all this land among all this people, or the people of Zarahemla, and the people of Mosiah who dwell in the land, that thereby they may be gathered together; for on the morrow I shall proclaim unto this my people out of mine own mouth that thou art a king and a ruler over this people, whom the Lord our God hath given us.
32803	1256	11	And moreover, I shall give this people a name, that thereby they may be distinguished above all the people which the Lord God hath brought out of the land of Jerusalem; and this I do because they have been a diligent people in keeping the commandments of the Lord.
32804	1256	12	And I give unto them a name that never shall be blotted out, except it be through transgression.
32805	1256	13	Yea, and moreover I say unto you, that if this highly favored people of the Lord should fall into transgression, and become a wicked and an adulterous people, that the Lord will deliver them up, that thereby they become weak like unto their brethren; and he will no more preserve them by his matchless and marvelous power, as he has hitherto preserved our fathers.
32806	1256	14	For I say unto you, that if he had not extended his arm in the preservation of our fathers they must have fallen into the hands of the Lamanites, and become victims to their hatred.
32807	1256	15	And it came to pass that after king Benjamin had made an end of these sayings to his son, that he gave him charge concerning all the affairs of the kingdom.
32808	1256	16	And moreover, he also gave him charge concerning the records which were engraven on the plates of brass; and also the plates of Nephi; and also, the sword of Laban, and the ball or director, which led our fathers through the wilderness, which was prepared by the hand of the Lord that thereby they might be led, every one according to the heed and diligence which they gave unto him.
32809	1256	17	Therefore, as they were unfaithful they did not prosper nor progress in their journey, but were driven back, and incurred the displeasure of God upon them; and therefore they were smitten with famine and sore afflictions, to stir them up in remembrance of their duty.
32810	1256	18	And now, it came to pass that Mosiah went and did as his father had commanded him, and proclaimed unto all the people who were in the land of Zarahemla that thereby they might gather themselves together, to go up to the temple to hear the words which his father should speak unto them.
32811	1257	1	And it came to pass that after Mosiah had done as his father had commanded him, and had made a proclamation throughout all the land, that the people gathered themselves together throughout all the land, that they might go up to the temple to hear the words which king Benjamin should speak unto them.
32812	1257	2	And there were a great number, even so many that they did not number them; for they had multiplied exceedingly and waxed great in the land.
32813	1257	3	And they also took of the firstlings of their flocks, that they might offer sacrifice and burnt offerings according to the law of Moses;
32814	1257	4	And also that they might give thanks to the Lord their God, who had brought them out of the land of Jerusalem, and who had delivered them out of the hands of their enemies, and had appointed just men to be their teachers, and also a just man to be their king, who had established peace in the land of Zarahemla, and who had taught them to keep the commandments of God, that they might rejoice and be filled with love towards God and all men.
32815	1257	5	And it came to pass that when they came up to the temple, they pitched their tents round about, every man according to his family, consisting of his wife, and his sons, and his daughters, and their sons, and their daughters, from the eldest down to the youngest, every family being separate one from another.
32816	1257	6	And they pitched their tents round about the temple, every man having his tent with the door thereof towards the temple, that thereby they might remain in their tents and hear the words which king Benjamin should speak unto them;
32817	1257	7	For the multitude being so great that king Benjamin could not teach them all within the walls of the temple, therefore he caused a tower to be erected, that thereby his people might hear the words which he should speak unto them.
32818	1257	8	And it came to pass that he began to speak to his people from the tower; and they could not all hear his words because of the greatness of the multitude; therefore he caused that the words which he spake should be written and sent forth among those that were not under the sound of his voice, that they might also receive his words.
32819	1257	9	And these are the words which he spake and caused to be written, saying: My brethren, all ye that have assembled yourselves together, you that can hear my words which I shall speak unto you this day; for I have not commanded you to come up hither to trifle with the words which I shall speak, but that you should hearken unto me, and open your ears that ye may hear, and your hearts that ye may understand, and your minds that the mysteries of God may be unfolded to your view.
32820	1257	10	I have not commanded you to come up hither that ye should fear me, or that ye should think that I of myself am more than a mortal man.
32821	1257	11	But I am like as yourselves, subject to all manner of infirmities in body and mind; yet I have been chosen by this people, and consecrated by my father, and was suffered by the hand of the Lord that I should be a ruler and a king over this people; and have been kept and preserved by his matchless power, to serve you with all the might, mind and strength which the Lord hath granted unto me.
32822	1257	12	I say unto you that as I have been suffered to spend my days in your service, even up to this time, and have not sought gold nor silver nor any manner of riches of you;
32823	1257	13	Neither have I suffered that ye should be confined in dungeons, nor that ye should make slaves one of another, nor that ye should murder, or plunder, or steal, or commit adultery; nor even have I suffered that ye should commit any manner of wickedness, and have taught you that ye should keep the commandments of the Lord, in all things which he hath commanded you--
32824	1257	14	And even I, myself, have labored with mine own hands that I might serve you, and that ye should not be laden with taxes, and that there should nothing come upon you which was grievous to be borne--and of all these things which I have spoken, ye yourselves are witnesses this day.
32825	1257	15	Yet, my brethren, I have not done these things that I might boast, neither do I tell these things that thereby I might accuse you; but I tell you these things that ye may know that I can answer a clear conscience before God this day.
32826	1257	16	Behold, I say unto you that because I said unto you that I had spent my days in your service, I do not desire to boast, for I have only been in the service of God.
32827	1257	17	And behold, I tell you these things that ye may learn wisdom; that ye may learn that when ye are in the service of your fellow beings ye are only in the service of your God.
32828	1257	18	Behold, ye have called me your king; and if I, whom ye call your king, do labor to serve you, then ought not ye to labor to serve one another?
32829	1257	19	And behold also, if I, whom ye call your king, who has spent his days in your service, and yet has been in the service of God, do merit any thanks from you, O how you ought to thank your heavenly King!
32830	1257	20	I say unto you, my brethren, that if you should render all the thanks and praise which your whole soul has power to possess, to that God who has created you, and has kept and preserved you, and has caused that ye should rejoice, and has granted that ye should live in peace one with another--
32831	1257	21	I say unto you that if ye should serve him who has created you from the beginning, and is preserving you from day to day, by lending you breath, that ye may live and move and do according to your own will, and even supporting you from one moment to another--I say, if ye should serve him with all your whole souls yet ye would be unprofitable servants.
32832	1257	22	And behold, all that he requires of you is to keep his commandments; and he has promised you that if ye would keep his commandments ye should prosper in the land; and he never doth vary from that which he hath said; therefore, if ye do keep his commandments he doth bless you and prosper you.
32833	1257	23	And now, in the first place, he hath created you, and granted unto you your lives, for which ye are indebted unto him.
32834	1257	24	And secondly, he doth require that ye should do as he hath commanded you; for which if ye do, he doth immediately bless you; and therefore he hath paid you. And ye are still indebted unto him, and are, and will be, forever and ever; therefore, of what have ye to boast?
32835	1257	25	And now I ask, can ye say aught of yourselves? I answer you, Nay. Ye cannot say that ye are even as much as the dust of the earth; yet ye were created of the dust of the earth; but behold, it belongeth to him who created you.
32836	1257	26	And I, even I, whom ye call your king, am no better than ye yourselves are; for I am also of the dust. And ye behold that I am old, and am about to yield up this mortal frame to its mother earth.
32837	1257	27	Therefore, as I said unto you that I had served you, walking with a clear conscience before God, even so I at this time have caused that ye should assemble yourselves together, that I might be found blameless, and that your blood should not come upon me, when I shall stand to be judged of God of the things whereof he hath commanded me concerning you.
32838	1257	28	I say unto you that I have caused that ye should assemble yourselves together that I might rid my garments of your blood, at this period of time when I am about to go down to my grave, that I might go down in peace, and my immortal spirit may join the choirs above in singing the praises of a just God.
32839	1257	29	And moreover, I say unto you that I have caused that ye should assemble yourselves together, that I might declare unto you that I can no longer be your teacher, nor your king;
32840	1257	30	For even at this time, my whole frame doth tremble exceedingly while attempting to speak unto you; but the Lord God doth support me, and hath suffered me that I should speak unto you, and hath commanded me that I should declare unto you this day, that my son Mosiah is a king and a ruler over you.
32841	1257	31	And now, my brethren, I would that ye should do as ye have hitherto done. As ye have kept my commandments, and also the commandments of my father, and have prospered, and have been kept from falling into the hands of your enemies, even so if ye shall keep the commandments of my son, or the commandments of God which shall be delivered unto you by him, ye shall prosper in the land, and your enemies shall have no power over you.
32842	1257	32	But, O my people, beware lest there shall arise contentions among you, and ye list to obey the evil spirit, which was spoken of by my father Mosiah.
32843	1257	33	For behold, there is a wo pronounced upon him who listeth to obey that spirit; for if he listeth to obey him, and remaineth and dieth in his sins, the same drinketh damnation to his own soul; for he receiveth for his wages an everlasting punishment, having transgressed the law of God contrary to his own knowledge.
32844	1257	34	I say unto you, that there are not any among you, except it be your little children that have not been taught concerning these things, but what knoweth that ye are eternally indebted to your heavenly Father, to render to him all that you have and are; and also have been taught concerning the records which contain the prophecies which have been spoken by the holy prophets, even down to the time our father, Lehi, left Jerusalem;
32845	1257	35	And also, all that has been spoken by our fathers until now. And behold, also, they spake that which was commanded them of the Lord; therefore, they are just and true.
32846	1257	36	And now, I say unto you, my brethren, that after ye have known and have been taught all these things, if ye should transgress and go contrary to that which has been spoken, that ye do withdraw yourselves from the Spirit of the Lord, that it may have no place in you to guide you in wisdom's paths that ye may be blessed, prospered, and preserved--
32847	1257	37	I say unto you, that the man that doeth this, the same cometh out in open rebellion against God; therefore he listeth to obey the evil spirit, and becometh an enemy to all righteousness; therefore, the Lord has no place in him, for he dwelleth not in unholy temples.
32848	1257	38	Therefore if that man repenteth not, and remaineth and dieth an enemy to God, the demands of divine justice do awaken his immortal soul to a lively sense of his own guilt, which doth cause him to shrink from the presence of the Lord, and doth fill his breast with guilt, and pain, and anguish, which is like an unquenchable fire, whose flame ascendeth up forever and ever.
32849	1257	39	And now I say unto you, that mercy hath no claim on that man; therefore his final doom is to endure a never-ending torment.
32850	1257	40	O, all ye old men, and also ye young men, and you little children who can understand my words, for I have spoken plainly unto you that ye might understand, I pray that ye should awake to a remembrance of the awful situation of those that have fallen into transgression.
32851	1257	41	And moreover, I would desire that ye should consider on the blessed and happy state of those that keep the commandments of God. For behold, they are blessed in all things, both temporal and spiritual; and if they hold out faithful to the end they are received into heaven, that thereby they may dwell with God in a state of never-ending happiness. O remember, remember that these things are true; for the Lord God hath spoken it.
32852	1258	1	And again my brethren, I would call your attention, for I have somewhat more to speak unto you; for behold, I have things to tell you concerning that which is to come.
32853	1258	2	And the things which I shall tell you are made known unto me by an angel from God. And he said unto me: Awake; and I awoke, and behold he stood before me.
32854	1258	3	And he said unto me: Awake, and hear the words which I shall tell thee; for behold, I am come to declare unto you the glad tidings of great joy.
32855	1258	4	For the Lord hath heard thy prayers, and hath judged of thy righteousness, and hath sent me to declare unto thee that thou mayest rejoice; and that thou mayest declare unto thy people, that they may also be filled with joy.
32856	1258	5	For behold, the time cometh, and is not far distant, that with power, the Lord Omnipotent who reigneth, who was, and is from all eternity to all eternity, shall come down from heaven among the children of men, and shall dwell in a tabernacle of clay, and shall go forth amongst men, working mighty miracles, such as healing the sick, raising the dead, causing the lame to walk, the blind to receive their sight, and the deaf to hear, and curing all manner of diseases.
32857	1258	6	And he shall cast out devils, or the evil spirits which dwell in the hearts of the children of men.
32858	1258	7	And lo, he shall suffer temptations, and pain of body, hunger, thirst, and fatigue, even more than man can suffer, except it be unto death; for behold, blood cometh from every pore, so great shall be his anguish for the wickedness and the abominations of his people.
32859	1258	8	And he shall be called Jesus Christ, the Son of God, the Father of heaven and earth, the Creator of all things from the beginning; and his mother shall be called Mary.
32860	1258	9	And lo, he cometh unto his own, that salvation might come unto the children of men even through faith on his name; and even after all this they shall consider him a man, and say that he hath a devil, and shall scourge him, and shall crucify him.
32861	1258	10	And he shall rise the third day from the dead; and behold, he standeth to judge the world; and behold, all these things are done that a righteous judgment might come upon the children of men.
32862	1258	11	For behold, and also his blood atoneth for the sins of those who have fallen by the transgression of Adam, who have died not knowing the will of God concerning them, or who have ignorantly sinned.
32863	1258	12	But wo, wo unto him who knoweth that he rebelleth against God! For salvation cometh to none such except it be through repentance and faith on the Lord Jesus Christ.
32864	1258	13	And the Lord God hath sent his holy prophets among all the children of men, to declare these things to every kindred, nation, and tongue, that thereby whosoever should believe that Christ should come, the same might receive remission of their sins, and rejoice with exceedingly great joy, even as though he had already come among them.
32865	1258	14	Yet the Lord God saw that his people were a stiffnecked people, and he appointed unto them a law, even the law of Moses.
32866	1258	15	And many signs, and wonders, and types, and shadows showed he unto them, concerning his coming; and also holy prophets spake unto them concerning his coming; and yet they hardened their hearts, and understood not that the law of Moses availeth nothing except it were through the atonement of his blood.
32867	1258	16	And even if it were possible that little children could sin they could not be saved; but I say unto you they are blessed; for behold, as in Adam, or by nature, they fall, even so the blood of Christ atoneth for their sins.
32868	1258	17	And moreover, I say unto you, that there shall be no other name given nor any other way nor means whereby salvation can come unto the children of men, only in and through the name of Christ, the Lord Omnipotent.
32869	1258	18	For behold he judgeth, and his judgment is just; and the infant perisheth not that dieth in his infancy; but men drink damnation to their own souls except they humble themselves and become as little children, and believe that salvation was, and is, and is to come, in and through the atoning blood of Christ, the Lord Omnipotent.
32870	1258	19	For the natural man is an enemy to God, and has been from the fall of Adam, and will be, forever and ever, unless he yields to the enticings of the Holy Spirit, and putteth off the natural man and becometh a saint through the atonement of Christ the Lord, and becometh as a child, submissive, meek, humble, patient, full of love, willing to submit to all things which the Lord seeth fit to inflict upon him, even as a child doth submit to his father.
32871	1258	20	And moreover, I say unto you, that the time shall come when the knowledge of a Savior shall spread throughout every nation, kindred, tongue, and people.
32872	1258	21	And behold, when that time cometh, none shall be found blameless before God, except it be little children, only through repentance and faith on the name of the Lord God Omnipotent.
32873	1258	22	And even at this time, when thou shalt have taught thy people the things which the Lord thy God hath commanded thee, even then are they found no more blameless in the sight of God, only according to the words which I have spoken unto thee.
32874	1258	23	And now I have spoken the words which the Lord God hath commanded me.
32875	1258	24	And thus saith the Lord: They shall stand as a bright testimony against this people, at the judgment day; whereof they shall be judged, every man according to his works, whether they be good, or whether they be evil.
32876	1258	25	And if they be evil they are consigned to an awful view of their own guilt and abominations, which doth cause them to shrink from the presence of the Lord into a state of misery and endless torment, from whence they can no more return; therefore they have drunk damnation to their own souls.
32877	1258	26	Therefore, they have drunk out of the cup of the wrath of God, which justice could no more deny unto them than it could deny that Adam should fall because of his partaking of the forbidden fruit; therefore, mercy could have claim on them no more forever.
32878	1258	27	And their torment is as a lake of fire and brimstone, whose flames are unquenchable, and whose smoke ascendeth up forever and ever. Thus hath the Lord commanded me. Amen.
32879	1259	1	And now, it came to pass that when king Benjamin had made an end of speaking the words which had been delivered unto him by the angel of the Lord, that he cast his eyes round about on the multitude, and behold they had fallen to the earth, for the fear of the Lord had come upon them.
32880	1259	2	And they had viewed themselves in their own carnal state, even less than the dust of the earth. And they all cried aloud with one voice, saying: O have mercy, and apply the atoning blood of Christ that we may receive forgiveness of our sins, and our hearts may be purified; for we believe in Jesus Christ, the Son of God, who created heaven and earth, and all things; who shall come down among the children of men.
32881	1259	3	And it came to pass that after they had spoken these words the Spirit of the Lord came upon them, and they were filled with joy, having received a remission of their sins, and having peace of conscience, because of the exceeding faith which they had in Jesus Christ who should come, according to the words which king Benjamin had spoken unto them.
32882	1259	4	And king Benjamin again opened his mouth and began to speak unto them, saying: My friends and my brethren, my kindred and my people, I would again call your attention, that ye may hear and understand the remainder of my words which I shall speak unto you.
32883	1259	5	For behold, if the knowledge of the goodness of God at this time has awakened you to a sense of your nothingness, and your worthless and fallen state--
32884	1259	6	I say unto you, if ye have come to a knowledge of the goodness of God, and his matchless power, and his wisdom, and his patience, and his long-suffering towards the children of men; and also, the atonement which has been prepared from the foundation of the world, that thereby salvation might come to him that should put his trust in the Lord, and should be diligent in keeping his commandments, and continue in the faith even unto the end of his life, I mean the life of the mortal body--
32885	1259	7	I say, that this is the man who receiveth salvation, through the atonement which was prepared from the foundation of the world for all mankind, which ever were since the fall of Adam, or who are, or who ever shall be, even unto the end of the world.
32886	1259	8	And this is the means whereby salvation cometh. And there is none other salvation save this which hath been spoken of; neither are there any conditions whereby man can be saved except the conditions which I have told you.
32887	1259	9	Believe in God; believe that he is, and that he created all things, both in heaven and in earth; believe that he has all wisdom, and all power, both in heaven and in earth; believe that man doth not comprehend all the things which the Lord can comprehend.
32888	1259	10	And again, believe that ye must repent of your sins and forsake them, and humble yourselves before God; and ask in sincerity of heart that he would forgive you; and now, if you believe all these things see that ye do them.
32889	1259	11	And again I say unto you as I have said before, that as ye have come to the knowledge of the glory of God, or if ye have known of his goodness and have tasted of his love, and have received a remission of your sins, which causeth such exceedingly great joy in your souls, even so I would that ye should remember, and always retain in remembrance, the greatness of God, and your own nothingness, and his goodness and long-suffering towards you, unworthy creatures, and humble yourselves even in the depths of humility, calling on the name of the Lord daily, and standing steadfastly in the faith of that which is to come, which was spoken by the mouth of the angel.
32890	1259	12	And behold, I say unto you that if ye do this ye shall always rejoice, and be filled with the love of God, and always retain a remission of your sins; and ye shall grow in the knowledge of the glory of him that created you, or in the knowledge of that which is just and true.
32891	1259	13	And ye will not have a mind to injure one another, but to live peaceably, and to render to every man according to that which is his due.
32892	1259	14	And ye will not suffer your children that they go hungry, or naked; neither will ye suffer that they transgress the laws of God, and fight and quarrel one with another, and serve the devil, who is the master of sin, or who is the evil spirit which hath been spoken of by our fathers, he being an enemy to all righteousness.
32893	1259	15	But ye will teach them to walk in the ways of truth and soberness; ye will teach them to love one another, and to serve one another.
32894	1259	16	And also, ye yourselves will succor those that stand in need of your succor; ye will administer of your substance unto him that standeth in need; and ye will not suffer that the beggar putteth up his petition to you in vain, and turn him out to perish.
32895	1259	17	Perhaps thou shalt say: The man has brought upon himself his misery; therefore I will stay my hand, and will not give unto him of my food, nor impart unto him of my substance that he may not suffer, for his punishments are just--
32896	1259	18	But I say unto you, O man, whosoever doeth this the same hath great cause to repent; and except he repenteth of that which he hath done he perisheth forever, and hath no interest in the kingdom of God.
32897	1259	19	For behold, are we not all beggars? Do we not all depend upon the same Being, even God, for all the substance which we have, for both food and raiment, and for gold, and for silver, and for all the riches which we have of every kind?
32898	1259	20	And behold, even at this time, ye have been calling on his name, and begging for a remission of your sins. And has he suffered that ye have begged in vain? Nay; he has poured out his Spirit upon you, and has caused that your hearts should be filled with joy, and has caused that your mouths should be stopped that ye could not find utterance, so exceedingly great was your joy.
32899	1259	21	And now, if God, who has created you, on whom you are dependent for your lives and for all that ye have and are, doth grant unto you whatsoever ye ask that is right, in faith, believing that ye shall receive, O then, how ye ought to impart of the substance that ye have one to another.
32900	1259	22	And if ye judge the man who putteth up his petition to you for your substance that he perish not, and condemn him, how much more just will be your condemnation for withholding your substance, which doth not belong to you but to God, to whom also your life belongeth; and yet ye put up no petition, nor repent of the thing which thou hast done.
32901	1259	23	I say unto you, wo be unto that man, for his substance shall perish with him; and now, I say these things unto those who are rich as pertaining to the things of this world.
32902	1259	24	And again, I say unto the poor, ye who have not and yet have sufficient, that ye remain from day to day; I mean all you who deny the beggar, because ye have not; I would that ye say in your hearts that: I give not because I have not, but if I had I would give.
32903	1259	25	And now, if ye say this in your hearts ye remain guiltless, otherwise ye are condemned; and your condemnation is just for ye covet that which ye have not received.
32904	1259	26	And now, for the sake of these things which I have spoken unto you--that is, for the sake of retaining a remission of your sins from day to day, that ye may walk guiltless before God--I would that ye should impart of your substance to the poor, every man according to that which he hath, such as feeding the hungry, clothing the naked, visiting the sick and administering to their relief, both spiritually and temporally, according to their wants.
32905	1259	27	And see that all these things are done in wisdom and order; for it is not requisite that a man should run faster than he has strength. And again, it is expedient that he should be diligent, that thereby he might win the prize; therefore, all things must be done in order.
32906	1259	28	And I would that ye should remember, that whosoever among you borroweth of his neighbor should return the thing that he borroweth, according as he doth agree, or else thou shalt commit sin; and perhaps thou shalt cause thy neighbor to commit sin also.
32907	1259	29	And finally, I cannot tell you all the things whereby ye may commit sin; for there are divers ways and means, even so many that I cannot number them.
32908	1259	30	But this much I can tell you, that if ye do not watch yourselves, and your thoughts, and your words, and your deeds, and observe the commandments of God, and continue in the faith of what ye have heard concerning the coming of our Lord, even unto the end of your lives, ye must perish. And now, O man, remember, and perish not.
32909	1260	1	And now, it came to pass that when king Benjamin had thus spoken to his people, he sent among them, desiring to know of his people if they believed the words which he had spoken unto them.
32910	1260	2	And they all cried with one voice, saying: Yea, we believe all the words which thou hast spoken unto us; and also, we know of their surety and truth, because of the Spirit of the Lord Omnipotent, which has wrought a mighty change in us, or in our hearts, that we have no more disposition to do evil, but to do good continually.
32911	1260	3	And we, ourselves, also, through the infinite goodness of God, and the manifestations of his Spirit, have great views of that which is to come; and were it expedient, we could prophesy of all things.
32912	1260	4	And it is the faith which we have had on the things which our king has spoken unto us that has brought us to this great knowledge, whereby we do rejoice with such exceedingly great joy.
32913	1260	5	And we are willing to enter into a covenant with our God to do his will, and to be obedient to his commandments in all things that he shall command us, all the remainder of our days, that we may not bring upon ourselves a never-ending torment, as has been spoken by the angel, that we may not drink out of the cup of the wrath of God.
32914	1260	6	And now, these are the words which king Benjamin desired of them; and therefore he said unto them: Ye have spoken the words that I desired; and the covenant which ye have made is a righteous covenant.
32915	1260	7	And now, because of the covenant which ye have made ye shall be called the children of Christ, his sons, and his daughters; for behold, this day he hath spiritually begotten you; for ye say that your hearts are changed through faith on his name; therefore, ye are born of him and have become his sons and his daughters.
32916	1260	8	And under this head ye are made free, and there is no other head whereby ye can be made free. There is no other name given whereby salvation cometh; therefore, I would that ye should take upon you the name of Christ, all you that have entered into the covenant with God that ye should be obedient unto the end of your lives.
32917	1260	9	And it shall come to pass that whosoever doeth this shall be found at the right hand of God, for he shall know the name by which he is called; for he shall be called by the name of Christ.
32918	1260	10	And now it shall come to pass, that whosoever shall not take upon him the name of Christ must be called by some other name; therefore, he findeth himself on the left hand of God.
32919	1260	11	And I would that ye should remember also, that this is the name that I said I should give unto you that never should be blotted out, except it be through transgression; therefore, take heed that ye do not transgress, that the name be not blotted out of your hearts.
32920	1260	12	I say unto you, I would that ye should remember to retain the name written always in your hearts, that ye are not found on the left hand of God, but that ye hear and know the voice by which ye shall be called, and also, the name by which he shall call you.
32921	1260	13	For how knoweth a man the master whom he has not served, and who is a stranger unto him, and is far from the thoughts and intents of his heart?
32922	1260	14	And again, doth a man take an ass which belongeth to his neighbor, and keep him? I say unto you, Nay; he will not even suffer that he shall feed among his flocks, but will drive him away, and cast him out. I say unto you, that even so shall it be among you if ye know not the name by which ye are called.
32923	1260	15	Therefore, I would that ye should be steadfast and immovable, always abounding in good works, that Christ, the Lord God Omnipotent, may seal you his, that you may be brought to heaven, that ye may have everlasting salvation and eternal life, through the wisdom, and power, and justice, and mercy of him who created all things, in heaven and in earth, who is God above all. Amen.
32924	1261	1	And now, king Benjamin thought it was expedient, after having finished speaking to the people, that he should take the names of all those who had entered into a covenant with God to keep his commandments.
32925	1261	2	And it came to pass that there was not one soul, except it were little children, but who had entered into the covenant and had taken upon them the name of Christ.
32926	1261	3	And again, it came to pass that when king Benjamin had made an end of all these things, and had consecrated his son Mosiah to be a ruler and a king over his people, and had given him all the charges concerning the kingdom, and also had appointed priests to teach the people, that thereby they might hear and know the commandments of God, and to stir them up in remembrance of the oath which they had made, he dismissed the multitude, and they returned, every one, according to their families, to their own houses.
32927	1261	4	And Mosiah began to reign in his father's stead. And he began to reign in the thirtieth year of his age, making in the whole, about four hundred and seventy-six years from the time that Lehi left Jerusalem.
32928	1261	5	And king Benjamin lived three years and he died.
32929	1261	6	And it came to pass that king Mosiah did walk in the ways of the Lord, and did observe his judgments and his statutes, and did keep his commandments in all things whatsoever he commanded him.
32930	1261	7	And king Mosiah did cause his people that they should till the earth. And he also, himself, did till the earth, that thereby he might not become burdensome to his people, that he might do according to that which his father had done in all things. And there was no contention among all his people for the space of three years.
32931	1262	1	And now, it came to pass that after king Mosiah had had continual peace for the space of three years, he was desirous to know concerning the people who went up to dwell in the land of Lehi-Nephi, or in the city of Lehi-Nephi; for his people had heard nothing from them from the time they left the land of Zarahemla; therefore, they wearied him with their teasings.
32932	1262	2	And it came to pass that king Mosiah granted that sixteen of their strong men might go up to the land of Lehi-Nephi, to inquire concerning their brethren.
32933	1262	3	And it came to pass that on the morrow they started to go up, having with them one Ammon, he being a strong and mighty man, and a descendant of Zarahemla; and he was also their leader.
32934	1262	4	And now, they knew not the course they should travel in the wilderness to go up to the land of Lehi-Nephi; therefore they wandered many days in the wilderness, even forty days did they wander.
32935	1262	5	And when they had wandered forty days they came to a hill, which is north of the land of Shilom, and there they pitched their tents.
32936	1262	6	And Ammon took three of his brethren, and their names were Amaleki, Helem, and Hem, and they went down into the land of Nephi.
32937	1262	7	And behold, they met the king of the people who were in the land of Nephi, and in the land of Shilom; and they were surrounded by the king's guard, and were taken, and were bound, and were committed to prison.
32938	1262	8	And it came to pass when they had been in prison two days they were again brought before the king, and their bands were loosed; and they stood before the king, and were permitted, or rather commanded, that they should answer the questions which he should ask them.
32939	1262	9	And he said unto them: Behold, I am Limhi, the son of Noah, who was the son of Zeniff, who came up out of the land of Zarahemla to inherit this land, which was the land of their fathers, who was made a king by the voice of the people.
32940	1262	10	And now, I desire to know the cause whereby ye were so bold as to come near the walls of the city, when I, myself, was with my guards without the gate?
32941	1262	11	And now, for this cause have I suffered that ye should be preserved, that I might inquire of you, or else I should have caused that my guards should have put you to death. Ye are permitted to speak.
32942	1262	12	And now, when Ammon saw that he was permitted to speak, he went forth and bowed himself before the king; and rising again he said: O king, I am very thankful before God this day that I am yet alive, and am permitted to speak; and I will endeavor to speak with boldness;
32943	1262	13	For I am assured that if ye had known me ye would not have suffered that I should have worn these bands. For I am Ammon, and am a descendant of Zarahemla, and have come up out of the land of Zarahemla to inquire concerning our brethren, whom Zeniff brought up out of that land.
32944	1262	14	And now, it came to pass that after Limhi had heard the words of Ammon, he was exceedingly glad, and said: Now, I know of a surety that my brethren who were in the land of Zarahemla are yet alive. And now, I will rejoice; and on the morrow I will cause that my people shall rejoice also.
32945	1262	15	For behold, we are in bondage to the Lamanites, and are taxed with a tax which is grievous to be borne. And now, behold, our brethren will deliver us out of our bondage, or out of the hands of the Lamanites, and we will be their slaves; for it is better that we be slaves to the Nephites than to pay tribute to the king of the Lamanites.
32946	1262	16	And now, king Limhi commanded his guards that they should no more bind Ammon nor his brethren, but caused that they should go to the hill which was north of Shilom, and bring their brethren into the city, that thereby they might eat, and drink, and rest themselves from the labors of their journey; for they had suffered many things; they had suffered hunger, thirst, and fatigue.
32947	1262	17	And now, it came to pass on the morrow that king Limhi sent a proclamation among all his people, that thereby they might gather themselves together to the temple, to hear the words which he should speak unto them.
32948	1262	18	And it came to pass that when they had gathered themselves together that he spake unto them in this wise, saying: O ye, my people, lift up your heads and be comforted; for behold, the time is at hand, or is not far distant, when we shall no longer be in subjection to our enemies, notwithstanding our many strugglings, which have been in vain; yet I trust there remaineth an effectual struggle to be made.
32949	1262	19	Therefore, lift up your heads, and rejoice, and put your trust in God, in that God who was the God of Abraham, and Isaac, and Jacob; and also, that God who brought the children of Israel out of the land of Egypt, and caused that they should walk through the Red Sea on dry ground, and fed them with manna that they might not perish in the wilderness; and many more things did he do for them.
32950	1262	20	And again, that same God has brought our fathers out of the land of Jerusalem, and has kept and preserved his people even until now; and behold, it is because of our iniquities and abominations that he has brought us into bondage.
32951	1262	21	And ye all are witnesses this day, that Zeniff, who was made king over this people, he being over-zealous to inherit the land of his fathers, therefore being deceived by the cunning and craftiness of king Laman, who having entered into a treaty with king Zeniff, and having yielded up into his hands the possessions of a part of the land, or even the city of Lehi-Nephi, and the city of Shilom; and the land round about--
32952	1262	22	And all this he did, for the sole purpose of bringing this people into subjection or into bondage. And behold, we at this time do pay tribute to the king of the Lamanites, to the amount of one half of our corn, and our barley, and even all our grain of every kind, and one half of the increase of our flocks and our herds; and even one half of all we have or possess the king of the Lamanites doth exact of us, or our lives.
32953	1262	23	And now, is not this grievous to be borne? And is not this, our affliction, great? Now behold, how great reason we have to mourn.
32954	1262	24	Yea, I say unto you, great are the reasons which we have to mourn; for behold how many of our brethren have been slain, and their blood has been spilt in vain, and all because of iniquity.
32955	1262	25	For if this people had not fallen into transgression the Lord would not have suffered that this great evil should come upon them. But behold, they would not hearken unto his words; but there arose contentions among them, even so much that they did shed blood among themselves.
32956	1262	26	And a prophet of the Lord have they slain; yea, a chosen man of God, who told them of their wickedness and abominations, and prophesied of many things which are to come, yea, even the coming of Christ.
32957	1262	27	And because he said unto them that Christ was the God, the Father of all things, and said that he should take upon him the image of man, and it should be the image after which man was created in the beginning; or in other words, he said that man was created after the image of God, and that God should come down among the children of men, and take upon him flesh and blood, and go forth upon the face of the earth--
32958	1262	28	And now, because he said this, they did put him to death; and many more things did they do which brought down the wrath of God upon them. Therefore, who wondereth that they are in bondage, and that they are smitten with sore afflictions?
32959	1262	29	For behold, the Lord hath said: I will not succor my people in the day of their transgression; but I will hedge up their ways that they prosper not; and their doings shall be as a stumbling block before them.
32960	1262	30	And again, he saith: If my people shall sow filthiness they shall reap the chaff thereof in the whirlwind; and the effect thereof is poison.
32961	1262	31	And again he saith: If my people shall sow filthiness they shall reap the east wind, which bringeth immediate destruction.
32962	1262	32	And now, behold, the promise of the Lord is fulfilled, and ye are smitten and afflicted.
32963	1262	33	But if ye will turn to the Lord with full purpose of heart, and put your trust in him, and serve him with all diligence of mind, if ye do this, he will, according to his own will and pleasure, deliver you out of bondage.
32964	1263	1	And it came to pass that after king Limhi had made an end of speaking to his people, for he spake many things unto them and only a few of them have I written in this book, he told his people all the things concerning their brethren who were in the land of Zarahemla.
32965	1263	2	And he caused that Ammon should stand up before the multitude, and rehearse unto them all that had happened unto their brethren from the time that Zeniff went up out of the land even until the time that he himself came up out of the land.
32966	1263	3	And he also rehearsed unto them the last words which king Benjamin had taught them, and explained them to the people of king Limhi, so that they might understand all the words which he spake.
32967	1263	4	And it came to pass that after he had done all this, that king Limhi dismissed the multitude, and caused that they should return every one unto his own house.
32968	1263	5	And it came to pass that he caused that the plates which contained the record of his people from the time that they left the land of Zarahemla, should be brought before Ammon, that he might read them.
32969	1263	6	Now, as soon as Ammon had read the record, the king inquired of him to know if he could interpret languages, and Ammon told him that he could not.
32970	1263	7	And the king said unto him: Being grieved for the afflictions of my people, I caused that forty and three of my people should take a journey into the wilderness, that thereby they might find the land of Zarahemla, that we might appeal unto our brethren to deliver us out of bondage.
32971	1263	8	And they were lost in the wilderness for the space of many days, yet they were diligent, and found not the land of Zarahemla but returned to this land, having traveled in a land among many waters, having discovered a land which was covered with bones of men, and of beasts, and was also covered with ruins of buildings of every kind, having discovered a land which had been peopled with a people who were as numerous as the hosts of Israel.
32972	1263	9	And for a testimony that the things that they had said are true they have brought twenty-four plates which are filled with engravings, and they are of pure gold.
32973	1263	10	And behold, also, they have brought breastplates, which are large, and they are of brass and of copper, and are perfectly sound.
32974	1263	11	And again, they have brought swords, the hilts thereof have perished, and the blades thereof were cankered with rust; and there is no one in the land that is able to interpret the language or the engravings that are on the plates. Therefore I said unto thee: Canst thou translate?
32975	1263	12	And I say unto thee again: Knowest thou of any one that can translate? For I am desirous that these records should be translated into our language; for, perhaps, they will give us a knowledge of a remnant of the people who have been destroyed, from whence these records came; or, perhaps, they will give us a knowledge of this very people who have been destroyed; and I am desirous to know the cause of their destruction.
32976	1263	13	Now Ammon said unto him: I can assuredly tell thee, O king, of a man that can translate the records; for he has wherewith that he can look, and translate all records that are of ancient date; and it is a gift from God. And the things are called interpreters, and no man can look in them except he be commanded, lest he should look for that he ought not and he should perish. And whosoever is commanded to look in them, the same is called seer.
32977	1263	14	And behold, the king of the people who are in the land of Zarahemla is the man that is commanded to do these things, and who has this high gift from God.
32978	1263	15	And the king said that a seer is greater than a prophet.
32979	1263	16	And Ammon said that a seer is a revelator and a prophet also; and a gift which is greater can no man have, except he should possess the power of God, which no man can; yet a man may have great power given him from God.
32980	1263	17	But a seer can know of things which are past, and also of things which are to come, and by them shall all things be revealed, or, rather, shall secret things be made manifest, and hidden things shall come to light, and things which are not known shall be made known by them, and also things shall be made known by them which otherwise could not be known.
32981	1263	18	Thus God has provided a means that man, through faith, might work mighty miracles; therefore he becometh a great benefit to his fellow beings.
32982	1263	19	And now, when Ammon had made an end of speaking these words the king rejoiced exceedingly, and gave thanks to God, saying: Doubtless a great mystery is contained within these plates, and these interpreters were doubtless prepared for the purpose of unfolding all such mysteries to the children of men.
32983	1263	20	O how marvelous are the works of the Lord, and how long doth he suffer with his people; yea, and how blind and impenetrable are the understandings of the children of men; for they will not seek wisdom, neither do they desire that she should rule over them!
32984	1263	21	Yea, they are as a wild flock which fleeth from the shepherd, and scattereth, and are driven, and are devoured by the beasts of the forest.
32985	1264	1	I, Zeniff, having been taught in all the language of the Nephites, and having had a knowledge of the land of Nephi, or of the land of our fathers' first inheritance, and having been sent as a spy among the Lamanites that I might spy out their forces, that our army might come upon them and destroy them--but when I saw that which was good among them I was desirous that they should not be destroyed.
32986	1264	2	Therefore, I contended with my brethren in the wilderness, for I would that our ruler should make a treaty with them; but he being an austere and a blood-thirsty man commanded that I should be slain; but I was rescued by the shedding of much blood; for father fought against father, and brother against brother, until the greater number of our army was destroyed in the wilderness; and we returned, those of us that were spared, to the land of Zarahemla, to relate that tale to their wives and their children.
32987	1264	3	And yet, I being over-zealous to inherit the land of our fathers, collected as many as were desirous to go up to possess the land, and started again on our journey into the wilderness to go up to the land; but we were smitten with famine and sore afflictions; for we were slow to remember the Lord our God.
32988	1264	4	Nevertheless, after many days' wandering in the wilderness we pitched our tents in the place where our brethren were slain, which was near to the land of our fathers.
32989	1264	5	And it came to pass that I went again with four of my men into the city, in unto the king, that I might know of the disposition of the king, and that I might know if I might go in with my people and possess the land in peace.
32990	1264	6	And I went in unto the king, and he covenanted with me that I might possess the land of Lehi-Nephi, and the land of Shilom.
32991	1264	7	And he also commanded that his people should depart out of the land, and I and my people went into the land that we might possess it.
32992	1264	8	And we began to build buildings, and to repair the walls of the city, yea, even the walls of the city of Lehi-Nephi, and the city of Shilom.
32993	1264	9	And we began to till the ground, yea, even with all manner of seeds, with seeds of corn, and of wheat, and of barley, and with neas, and with sheum, and with seeds of all manner of fruits; and we did begin to multiply and prosper in the land.
32994	1264	10	Now it was the cunning and the craftiness of king Laman, to bring my people into bondage, that he yielded up the land that we might possess it.
32995	1264	11	Therefore it came to pass, that after we had dwelt in the land for the space of twelve years that king Laman began to grow uneasy, lest by any means my people should wax strong in the land, and that they could not overpower them and bring them into bondage.
32996	1264	12	Now they were a lazy and an idolatrous people; therefore they were desirous to bring us into bondage, that they might glut themselves with the labors of our hands; yea, that they might feast themselves upon the flocks of our fields.
32997	1264	13	Therefore it came to pass that king Laman began to stir up his people that they should contend with my people; therefore there began to be wars and contentions in the land.
32998	1264	14	For, in the thirteenth year of my reign in the land of Nephi, away on the south of the land of Shilom, when my people were watering and feeding their flocks, and tilling their lands, a numerous host of Lamanites came upon them and began to slay them, and to take off their flocks, and the corn of their fields.
32999	1264	15	Yea, and it came to pass that they fled, all that were not overtaken, even into the city of Nephi, and did call upon me for protection.
33000	1264	16	And it came to pass that I did arm them with bows, and with arrows, with swords, and with cimeters, and with clubs, and with slings, and with all manner of weapons which we could invent, and I and my people did go forth against the Lamanites to battle.
33001	1264	17	Yea, in the strength of the Lord did we go forth to battle against the Lamanites; for I and my people did cry mightily to the Lord that he would deliver us out of the hands of our enemies, for we were awakened to a remembrance of the deliverance of our fathers.
33002	1264	18	And God did hear our cries and did answer our prayers; and we did go forth in his might; yea, we did go forth against the Lamanites, and in one day and a night we did slay three thousand and forty-three; we did slay them even until we had driven them out of our land.
33003	1264	19	And I, myself, with mine own hands, did help to bury their dead. And behold, to our great sorrow and lamentation, two hundred and seventy-nine of our brethren were slain.
33004	1265	1	And it came to pass that we again began to establish the kingdom and we again began to possess the land in peace. And I caused that there should be weapons of war made of every kind, that thereby I might have weapons for my people against the time the Lamanites should come up again to war against my people.
33005	1265	2	And I set guards round about the land, that the Lamanites might not come upon us again unawares and destroy us; and thus I did guard my people and my flocks, and keep them from falling into the hands of our enemies.
33006	1265	3	And it came to pass that we did inherit the land of our fathers for many years, yea, for the space of twenty and two years.
33007	1265	4	And I did cause that the men should till the ground, and raise all manner of grain and all manner of fruit of every kind.
33008	1265	5	And I did cause that the women should spin, and toil, and work, and work all manner of fine linen, yea, and cloth of every kind, that we might clothe our nakedness; and thus we did prosper in the land--thus we did have continual peace in the land for the space of twenty and two years.
33009	1265	6	And it came to pass that king Laman died, and his son began to reign in his stead. And he began to stir his people up in rebellion against my people; therefore they began to prepare for war, and to come up to battle against my people.
33010	1265	7	But I had sent my spies out round about the land of Shemlon, that I might discover their preparations, that I might guard against them, that they might not come upon my people and destroy them.
33011	1265	8	And it came to pass that they came up upon the north of the land of Shilom, with their numerous hosts, men armed with bows, and with arrows, and with swords, and with cimeters, and with stones, and with slings; and they had their heads shaved that they were naked; and they were girded with a leathern girdle about their loins.
33012	1265	9	And it came to pass that I caused that the women and children of my people should be hid in the wilderness; and I also caused that all my old men that could bear arms, and also all my young men that were able to bear arms, should gather themselves together to go to battle against the Lamanites; and I did place them in their ranks, every man according to his age.
33013	1265	10	And it came to pass that we did go up to battle against the Lamanites; and I, even I, in my old age, did go up to battle against the Lamanites. And it came to pass that we did go up in the strength of the Lord to battle.
33014	1265	11	Now, the Lamanites knew nothing concerning the Lord, nor the strength of the Lord, therefore they depended upon their own strength. Yet they were a strong people, as to the strength of men.
33015	1265	12	They were a wild, and ferocious, and a blood-thirsty people, believing in the tradition of their fathers, which is this--Believing that they were driven out of the land of Jerusalem because of the iniquities of their fathers, and that they were wronged in the wilderness by their brethren, and they were also wronged while crossing the sea;
33016	1265	13	And again, that they were wronged while in the land of their first inheritance, after they had crossed the sea, and all this because that Nephi was more faithful in keeping the commandments of the Lord--therefore he was favored of the Lord, for the Lord heard his prayers and answered them, and he took the lead of their journey in the wilderness.
33017	1265	14	And his brethren were wroth with him because they understood not the dealings of the Lord; they were also wroth with him upon the waters because they hardened their hearts against the Lord.
33018	1265	15	And again, they were wroth with him when they had arrived in the promised land, because they said that he had taken the ruling of the people out of their hands; and they sought to kill him.
33019	1265	16	And again, they were wroth with him because he departed into the wilderness as the Lord had commanded him, and took the records which were engraven on the plates of brass, for they said that he robbed them.
33020	1265	17	And thus they have taught their children that they should hate them, and that they should murder them, and that they should rob and plunder them, and do all they could to destroy them; therefore they have an eternal hatred towards the children of Nephi.
33021	1265	18	For this very cause has king Laman, by his cunning, and lying craftiness, and his fair promises, deceived me, that I have brought this my people up into this land, that they may destroy them; yea, and we have suffered these many years in the land.
33022	1265	19	And now I, Zeniff, after having told all these things unto my people concerning the Lamanites, I did stimulate them to go to battle with their might, putting their trust in the Lord; therefore, we did contend with them, face to face.
33023	1265	20	And it came to pass that we did drive them again out of our land; and we slew them with a great slaughter, even so many that we did not number them.
33024	1265	21	And it came to pass that we returned again to our own land, and my people again began to tend their flocks, and to till their ground.
33025	1265	22	And now I, being old, did confer the kingdom upon one of my sons; therefore, I say no more. And may the Lord bless my people. Amen.
33026	1266	1	And now it came to pass that Zeniff conferred the kingdom upon Noah, one of his sons; therefore Noah began to reign in his stead; and he did not walk in the ways of his father.
33027	1266	2	For behold, he did not keep the commandments of God, but he did walk after the desires of his own heart. And he had many wives and concubines. And he did cause his people to commit sin, and do that which was abominable in the sight of the Lord. Yea, and they did commit whoredoms and all manner of wickedness.
33028	1266	3	And he laid a tax of one fifth part of all they possessed, a fifth part of their gold and of their silver, and a fifth part of their ziff, and of their copper, and of their brass and their iron; and a fifth part of their fatlings; and also a fifth part of all their grain.
33029	1266	4	And all this did he take to support himself, and his wives and his concubines; and also his priests, and their wives and their concubines; thus he had changed the affairs of the kingdom.
33030	1266	5	For he put down all the priests that had been consecrated by his father, and consecrated new ones in their stead, such as were lifted up in the pride of their hearts.
33031	1266	6	Yea, and thus they were supported in their laziness, and in their idolatry, and in their whoredoms, by the taxes which king Noah had put upon his people; thus did the people labor exceedingly to support iniquity.
33032	1266	7	Yea, and they also became idolatrous, because they were deceived by the vain and flattering words of the king and priests; for they did speak flattering things unto them.
33033	1266	8	And it came to pass that king Noah built many elegant and spacious buildings; and he ornamented them with fine work of wood, and of all manner of precious things, of gold, and of silver, and of iron, and of brass, and of ziff, and of copper;
33034	1266	9	And he also built him a spacious palace, and a throne in the midst thereof, all of which was of fine wood and was ornamented with gold and silver and with precious things.
33035	1266	10	And he also caused that his workmen should work all manner of fine work within the walls of the temple, of fine wood, and of copper, and of brass.
33036	1266	11	And the seats which were set apart for the high priests, which were above all the other seats, he did ornament with pure gold; and he caused a breastwork to be built before them, that they might rest their bodies and their arms upon while they should speak lying and vain words to his people.
33037	1266	12	And it came to pass that he built a tower near the temple; yea, a very high tower, even so high that he could stand upon the top thereof and overlook the land of Shilom, and also the land of Shemlon, which was possessed by the Lamanites; and he could even look over all the land round about.
33038	1266	13	And it came to pass that he caused many buildings to be built in the land Shilom; and he caused a great tower to be built on the hill north of the land Shilom, which had been a resort for the children of Nephi at the time they fled out of the land; and thus he did do with the riches which he obtained by the taxation of his people.
33039	1266	14	And it came to pass that he placed his heart upon his riches, and he spent his time in riotous living with his wives and his concubines; and so did also his priests spend their time with harlots.
33040	1266	15	And it came to pass that he planted vineyards round about in the land; and he built wine-presses, and made wine in abundance; and therefore he became a wine-bibber, and also his people.
33041	1266	16	And it came to pass that the Lamanites began to come in upon his people, upon small numbers, and to slay them in their fields, and while they were tending their flocks.
33042	1266	17	And king Noah sent guards round about the land to keep them off; but he did not send a sufficient number, and the Lamanites came upon them and killed them, and drove many of their flocks out of the land; thus the Lamanites began to destroy them, and to exercise their hatred upon them.
33043	1266	18	And it came to pass that king Noah sent his armies against them, and they were driven back, or they drove them back for a time; therefore, they returned rejoicing in their spoil.
33044	1266	19	And now, because of this great victory they were lifted up in the pride of their hearts; they did boast in their own strength, saying that their fifty could stand against thousands of the Lamanites; and thus they did boast, and did delight in blood, and the shedding of the blood of their brethren, and this because of the wickedness of their king and priests.
33045	1266	20	And it came to pass that there was a man among them whose name was Abinadi; and he went forth among them, and began to prophesy, saying: Behold, thus saith the Lord, and thus hath he commanded me, saying, Go forth, and say unto this people, thus saith the Lord--Wo be unto this people, for I have seen their abominations, and their wickedness, and their whoredoms; and except they repent I will visit them in mine anger.
33046	1266	21	And except they repent and turn to the Lord their God, behold, I will deliver them into the hands of their enemies; yea, and they shall be brought into bondage; and they shall be afflicted by the hand of their enemies.
33047	1266	22	And it shall come to pass that they shall know that I am the Lord their God, and am a jealous God, visiting the iniquities of my people.
33048	1266	23	And it shall come to pass that except this people repent and turn unto the Lord their God, they shall be brought into bondage; and none shall deliver them, except it be the Lord the Almighty God.
33049	1266	24	Yea, and it shall come to pass that when they shall cry unto me I will be slow to hear their cries; yea, and I will suffer them that they be smitten by their enemies.
33050	1266	25	And except they repent in sackcloth and ashes, and cry mightily to the Lord their God, I will not hear their prayers, neither will I deliver them out of their afflictions; and thus saith the Lord, and thus hath he commanded me.
33051	1266	26	Now it came to pass that when Abinadi had spoken these words unto them they were wroth with him, and sought to take away his life; but the Lord delivered him out of their hands.
33052	1266	27	Now when king Noah had heard of the words which Abinadi had spoken unto the people, he was also wroth; and he said: Who is Abinadi, that I and my people should be judged of him, or who is the Lord, that shall bring upon my people such great affliction?
33053	1266	28	I command you to bring Abinadi hither, that I may slay him, for he has said these things that he might stir up my people to anger one with another, and to raise contentions among my people; therefore I will slay him.
33054	1266	29	Now the eyes of the people were blinded; therefore they hardened their hearts against the words of Abinadi, and they sought from that time forward to take him. And king Noah hardened his heart against the word of the Lord, and he did not repent of his evil doings.
33055	1267	1	And it came to pass that after the space of two years that Abinadi came among them in disguise, that they knew him not, and began to prophesy among them, saying: Thus has the Lord commanded me, saying--Abinadi, go and prophesy unto this my people, for they have hardened their hearts against my words; they have repented not of their evil doings; therefore, I will visit them in my anger, yea, in my fierce anger will I visit them in their iniquities and abominations.
33056	1267	2	Yea, wo be unto this generation! And the Lord said unto me: Stretch forth thy hand and prophesy, saying: Thus saith the Lord, it shall come to pass that this generation, because of their iniquities, shall be brought into bondage, and shall be smitten on the cheek; yea, and shall be driven by men, and shall be slain; and the vultures of the air, and the dogs, yea, and the wild beasts, shall devour their flesh.
33057	1267	3	And it shall come to pass that the life of king Noah shall be valued even as a garment in a hot furnace; for he shall know that I am the Lord.
33058	1267	4	And it shall come to pass that I will smite this my people with sore afflictions, yea, with famine and with pestilence; and I will cause that they shall howl all the day long.
33059	1267	5	Yea, and I will cause that they shall have burdens lashed upon their backs; and they shall be driven before like a dumb ass.
33060	1267	6	And it shall come to pass that I will send forth hail among them, and it shall smite them; and they shall also be smitten with the east wind; and insects shall pester their land also, and devour their grain.
33061	1267	7	And they shall be smitten with a great pestilence--and all this will I do because of their iniquities and abominations.
33062	1267	8	And it shall come to pass that except they repent I will utterly destroy them from off the face of the earth; yet they shall leave a record behind them, and I will preserve them for other nations which shall possess the land; yea, even this will I do that I may discover the abominations of this people to other nations. And many things did Abinadi prophesy against this people.
33063	1267	9	And it came to pass that they were angry with him; and they took him and carried him bound before the king, and said unto the king: Behold, we have brought a man before thee who has prophesied evil concerning thy people, and saith that God will destroy them.
33064	1267	10	And he also prophesieth evil concerning thy life, and saith that thy life shall be as a garment in a furnace of fire.
33065	1267	11	And again, he saith that thou shalt be as a stalk, even as a dry stalk of the field, which is run over by the beasts and trodden under foot.
33066	1267	12	And again, he saith thou shalt be as the blossoms of a thistle, which, when it is fully ripe, if the wind bloweth, it is driven forth upon the face of the land. And he pretendeth the Lord hath spoken it. And he saith all this shall come upon thee except thou repent, and this because of thine iniquities.
33067	1267	13	And now, O king, what great evil hast thou done, or what great sins have thy people committed, that we should be condemned of God or judged of this man?
33068	1267	14	And now, O king, behold, we are guiltless, and thou, O king, hast not sinned; therefore, this man has lied concerning you, and he has prophesied in vain.
33069	1267	15	And behold, we are strong, we shall not come into bondage, or be taken captive by our enemies; yea, and thou hast prospered in the land, and thou shalt also prosper.
33070	1267	16	Behold, here is the man, we deliver him into thy hands; thou mayest do with him as seemeth thee good.
33071	1267	17	And it came to pass that king Noah caused that Abinadi should be cast into prison; and he commanded that the priests should gather themselves together that he might hold a council with them what he should do with him.
33072	1267	18	And it came to pass that they said unto the king: Bring him hither that we may question him; and the king commanded that he should be brought before them.
33073	1267	19	And they began to question him, that they might cross him, that thereby they might have wherewith to accuse him; but he answered them boldly, and withstood all their questions, yea, to their astonishment; for he did withstand them in all their questions, and did confound them in all their words.
33074	1267	20	And it came to pass that one of them said unto him: What meaneth the words which are written, and which have been taught by our fathers, saying:
33075	1267	21	How beautiful upon the mountains are the feet of him that bringeth good tidings; that publisheth peace; that bringeth good tidings of good; that publisheth salvation; that saith unto Zion, Thy God reigneth;
33076	1267	22	Thy watchmen shall lift up the voice; with the voice together shall they sing; for they shall see eye to eye when the Lord shall bring again Zion;
33077	1267	23	Break forth into joy; sing together ye waste places of Jerusalem; for the Lord hath comforted his people, he hath redeemed Jerusalem;
33078	1267	24	The Lord hath made bare his holy arm in the eyes of all the nations, and all the ends of the earth shall see the salvation of our God?
33079	1267	25	And now Abinadi said unto them: Are you priests, and pretend to teach this people, and to understand the spirit of prophesying, and yet desire to know of me what these things mean?
33080	1267	26	I say unto you, wo be unto you for perverting the ways of the Lord! For if ye understand these things ye have not taught them; therefore, ye have perverted the ways of the Lord.
33081	1267	27	Ye have not applied your hearts to understanding; therefore, ye have not been wise. Therefore, what teach ye this people?
33082	1267	28	And they said: We teach the law of Moses.
33083	1267	29	And again he said unto them: If ye teach the law of Moses why do ye not keep it? Why do ye set your hearts upon riches? Why do ye commit whoredoms and spend your strength with harlots, yea, and cause this people to commit sin, that the Lord has cause to send me to prophesy against this people, yea, even a great evil against this people?
33084	1267	30	Know ye not that I speak the truth? Yea, ye know that I speak the truth; and you ought to tremble before God.
33085	1267	31	And it shall come to pass that ye shall be smitten for your iniquities, for ye have said that ye teach the law of Moses. And what know ye concerning the law of Moses? Doth salvation come by the law of Moses? What say ye?
33086	1267	32	And they answered and said that salvation did come by the law of Moses.
33087	1267	33	But now Abinadi said unto them: I know if ye keep the commandments of God ye shall be saved; yea, if ye keep the commandments which the Lord delivered unto Moses in the mount of Sinai, saying:
33088	1267	34	I am the Lord thy God, who hath brought thee out of the land of Egypt, out of the house of bondage.
33089	1267	35	Thou shalt have no other God before me.
33090	1267	36	Thou shalt not make unto thee any graven image, or any likeness of any thing in heaven above, or things which are in the earth beneath.
33091	1267	37	Now Abinadi said unto them, Have ye done all this? I say unto you, Nay, ye have not. And have ye taught this people that they should do all these things? I say unto you, Nay, ye have not.
33092	1268	1	And now when the king had heard these words, he said unto his priests: Away with this fellow, and slay him; for what have we to do with him, for he is mad.
33093	1268	2	And they stood forth and attempted to lay their hands on him; but he withstood them, and said unto them:
33094	1268	3	Touch me not, for God shall smite you if ye lay your hands upon me, for I have not delivered the message which the Lord sent me to deliver; neither have I told you that which ye requested that I should tell; therefore, God will not suffer that I shall be destroyed at this time.
33095	1268	4	But I must fulfil the commandments wherewith God has commanded me; and because I have told you the truth ye are angry with me. And again, because I have spoken the word of God ye have judged me that I am mad.
33096	1268	5	Now it came to pass after Abinadi had spoken these words that the people of king Noah durst not lay their hands on him, for the Spirit of the Lord was upon him; and his face shone with exceeding luster, even as Moses' did while in the mount of Sinai, while speaking with the Lord.
33097	1268	6	And he spake with power and authority from God; and he continued his words, saying:
33098	1268	7	Ye see that ye have not power to slay me, therefore I finish my message. Yea, and I perceive that it cuts you to your hearts because I tell you the truth concerning your iniquities.
33099	1268	8	Yea, and my words fill you with wonder and amazement, and with anger.
33100	1268	9	But I finish my message; and then it matters not whither I go, if it so be that I am saved.
33101	1268	10	But this much I tell you, what you do with me, after this, shall be as a type and a shadow of things which are to come.
33102	1268	11	And now I read unto you the remainder of the commandments of God, for I perceive that they are not written in your hearts; I perceive that ye have studied and taught iniquity the most part of your lives.
33103	1268	12	And now, ye remember that I said unto you: Thou shall not make unto thee any graven image, or any likeness of things which are in heaven above, or which are in the earth beneath, or which are in the water under the earth.
33104	1268	13	And again: Thou shalt not bow down thyself unto them, nor serve them; for I the Lord thy God am a jealous God, visiting the iniquities of the fathers upon the children, unto the third and fourth generations of them that hate me;
33105	1268	14	And showing mercy unto thousands of them that love me and keep my commandments.
33106	1268	15	Thou shalt not take the name of the Lord thy God in vain; for the Lord will not hold him guiltless that taketh his name in vain.
33107	1268	16	Remember the sabbath day, to keep it holy.
33108	1268	17	Six days shalt thou labor, and do all thy work;
33109	1268	18	But the seventh day, the sabbath of the Lord thy God, thou shalt not do any work, thou, nor thy son, nor thy daughter, thy man-servant, nor thy maid-servant, nor thy cattle, nor thy stranger that is within thy gates;
33110	1268	19	For in six days the Lord made heaven and earth, and the sea, and all that in them is; wherefore the Lord blessed the sabbath day, and hallowed it.
33111	1268	20	Honor thy father and thy mother, that thy days may be long upon the land which the Lord thy God giveth thee.
33112	1268	21	Thou shalt not kill.
33113	1268	22	Thou shalt not commit adultery. Thou shalt not steal.
33114	1268	23	Thou shalt not bear false witness against thy neighbor.
33115	1268	24	Thou shalt not covet thy neighbor's house, thou shalt not covet thy neighbor's wife, nor his man-servant, nor his maid-servant, nor his ox, nor his ass, nor anything that is thy neighbor's.
33116	1268	25	And it came to pass that after Abinadi had made an end of these sayings that he said unto them: Have ye taught this people that they should observe to do all these things for to keep these commandments?
33117	1268	26	I say unto you, Nay; for if ye had, the Lord would not have caused me to come forth and to prophesy evil concerning this people.
33118	1268	27	And now ye have said that salvation cometh by the law of Moses. I say unto you that it is expedient that ye should keep the law of Moses as yet; but I say unto you, that the time shall come when it shall no more be expedient to keep the law of Moses.
33119	1268	28	And moreover, I say unto you, that salvation doth not come by the law alone; and were it not for the atonement, which God himself shall make for the sins and iniquities of his people, that they must unavoidably perish, notwithstanding the law of Moses.
33120	1268	29	And now I say unto you that it was expedient that there should be a law given to the children of Israel, yea, even a very strict law; for they were a stiffnecked people, quick to do iniquity, and slow to remember the Lord their God;
33121	1268	30	Therefore there was a law given them, yea, a law of performances and of ordinances, a law which they were to observe strictly from day to day, to keep them in remembrance of God and their duty towards him.
33122	1268	31	But behold, I say unto you, that all these things were types of things to come.
33123	1268	32	And now, did they understand the law? I say unto you, Nay, they did not all understand the law; and this because of the hardness of their hearts; for they understood not that there could not any man be saved except it were through the redemption of God.
33124	1268	33	For behold, did not Moses prophesy unto them concerning the coming of the Messiah, and that God should redeem his people? Yea, and even all the prophets who have prophesied ever since the world began--have they not spoken more or less concerning these things?
33125	1268	34	Have they not said that God himself should come down among the children of men, and take upon him the form of man, and go forth in mighty power upon the face of the earth?
33126	1268	35	Yea, and have they not said also that he should bring to pass the resurrection of the dead, and that he, himself, should be oppressed and afflicted?
33127	1269	1	Yea, even doth not Isaiah say: Who hath believed our report, and to whom is the arm of the Lord revealed?
33128	1269	2	For he shall grow up before him as a tender plant, and as a root out of dry ground; he hath no form nor comeliness; and when we shall see him there is no beauty that we should desire him.
33129	1269	3	He is despised and rejected of men; a man of sorrows, and acquainted with grief; and we hid as it were our faces from him; he was despised, and we esteemed him not.
33130	1269	4	Surely he has borne our griefs, and carried our sorrows; yet we did esteem him stricken, smitten of God, and afflicted.
33131	1269	5	But he was wounded for our transgressions, he was bruised for our iniquities; the chastisement of our peace was upon him; and with his stripes we are healed.
33132	1269	6	All we, like sheep, have gone astray; we have turned every one to his own way; and the Lord hath laid on him the iniquities of us all.
33133	1269	7	He was oppressed, and he was afflicted, yet he opened not his mouth; he is brought as a lamb to the slaughter, and as a sheep before her shearers is dumb so he opened not his mouth.
33134	1269	8	He was taken from prison and from judgment; and who shall declare his generation? For he was cut off out of the land of the living; for the transgressions of my people was he stricken.
33135	1269	9	And he made his grave with the wicked, and with the rich in his death; because he had done no evil, neither was any deceit in his mouth.
33136	1269	10	Yet it pleased the Lord to bruise him; he hath put him to grief; when thou shalt make his soul an offering for sin he shall see his seed, he shall prolong his days, and the pleasure of the Lord shall prosper in his hand.
33137	1269	11	He shall see the travail of his soul, and shall be satisfied; by his knowledge shall my righteous servant justify many; for he shall bear their iniquities.
33138	1269	12	Therefore will I divide him a portion with the great, and he shall divide the spoil with the strong; because he hath poured out his soul unto death; and he was numbered with the transgressors; and he bore the sins of many, and made intercession for the transgressors.
33139	1270	1	And now Abinadi said unto them: I would that ye should understand that God himself shall come down among the children of men, and shall redeem his people.
33140	1270	2	And because he dwelleth in flesh he shall be called the Son of God, and having subjected the flesh to the will of the Father, being the Father and the Son--
33141	1270	3	The Father, because he was conceived by the power of God; and the Son, because of the flesh; thus becoming the Father and Son--
33142	1270	4	And they are one God, yea, the very Eternal Father of heaven and of earth.
33143	1270	5	And thus the flesh becoming subject to the Spirit, or the Son to the Father, being one God, suffereth temptation, and yieldeth not to the temptation, but suffereth himself to be mocked, and scourged, and cast out, and disowned by his people.
33144	1270	6	And after all this, after working many mighty miracles among the children of men, he shall be led, yea, even as Isaiah said, as a sheep before the shearer is dumb, so he opened not his mouth.
33145	1270	7	Yea, even so he shall be led, crucified, and slain, the flesh becoming subject even unto death, the will of the Son being swallowed up in the will of the Father.
33146	1270	8	And thus God breaketh the bands of death, having gained the victory over death; giving the Son power to make intercession for the children of men--
33147	1270	9	Having ascended into heaven, having the bowels of mercy; being filled with compassion towards the children of men; standing betwixt them and justice; having broken the bands of death, taken upon himself their iniquity and their transgressions, having redeemed them, and satisfied the demands of justice.
33148	1270	10	And now I say unto you, who shall declare his generation? Behold, I say unto you, that when his soul has been made an offering for sin he shall see his seed. And now what say ye? And who shall be his seed?
33149	1270	11	Behold I say unto you, that whosoever has heard the words of the prophets, yea, all the holy prophets who have prophesied concerning the coming of the Lord--I say unto you, that all those who have hearkened unto their words, and believed that the Lord would redeem his people, and have looked forward to that day for a remission of their sins, I say unto you, that these are his seed, or they are the heirs of the kingdom of God.
33150	1270	12	For these are they whose sins he has borne; these are they for whom he has died, to redeem them from their transgressions. And now, are they not his seed?
33151	1270	13	Yea, and are not the prophets, every one that has opened his mouth to prophesy, that has not fallen into transgression, I mean all the holy prophets ever since the world began? I say unto you that they are his seed.
33152	1270	14	And these are they who have published peace, who have brought good tidings of good, who have published salvation; and said unto Zion: Thy God reigneth!
33153	1270	15	And O how beautiful upon the mountains were their feet!
33154	1270	16	And again, how beautiful upon the mountains are the feet of those that are still publishing peace!
33155	1270	17	And again, how beautiful upon the mountains are the feet of those who shall hereafter publish peace, yea, from this time henceforth and forever!
33156	1270	18	And behold, I say unto you, this is not all. For O how beautiful upon the mountains are the feet of him that bringeth good tidings, that is the founder of peace, yea, even the Lord, who has redeemed his people; yea, him who has granted salvation unto his people;
33157	1270	19	For were it not for the redemption which he hath made for his people, which was prepared from the foundation of the world, I say unto you, were it not for this, all mankind must have perished.
33158	1270	20	But behold, the bands of death shall be broken, and the Son reigneth, and hath power over the dead; therefore, he bringeth to pass the resurrection of the dead.
33159	1270	21	And there cometh a resurrection, even a first resurrection; yea, even a resurrection of those that have been, and who are, and who shall be, even until the resurrection of Christ--for so shall he be called.
33160	1270	22	And now, the resurrection of all the prophets, and all those that have believed in their words, or all those that have kept the commandments of God, shall come forth in the first resurrection; therefore, they are the first resurrection.
33161	1270	23	They are raised to dwell with God who has redeemed them; thus they have eternal life through Christ, who has broken the bands of death.
33162	1270	24	And these are those who have part in the first resurrection; and these are they that have died before Christ came, in their ignorance, not having salvation declared unto them. And thus the Lord bringeth about the restoration of these; and they have a part in the first resurrection, or have eternal life, being redeemed by the Lord.
33163	1270	25	And little children also have eternal life.
33164	1270	26	But behold, and fear, and tremble before God, for ye ought to tremble; for the Lord redeemeth none such that rebel against him and die in their sins; yea, even all those that have perished in their sins ever since the world began, that have wilfully rebelled against God, that have known the commandments of God, and would not keep them; these are they that have no part in the first resurrection.
33165	1270	27	Therefore ought ye not to tremble? For salvation cometh to none such; for the Lord hath redeemed none such; yea, neither can the Lord redeem such; for he cannot deny himself; for he cannot deny justice when it has its claim.
33166	1270	28	And now I say unto you that the time shall come that the salvation of the Lord shall be declared to every nation, kindred, tongue, and people.
33167	1270	29	Yea, Lord, thy watchmen shall lift up their voice; with the voice together shall they sing; for they shall see eye to eye, when the Lord shall bring again Zion.
33168	1270	30	Break forth into joy, sing together, ye waste places of Jerusalem; for the Lord hath comforted his people, he hath redeemed Jerusalem.
33169	1270	31	The Lord hath made bare his holy arm in the eyes of all the nations; and all the ends of the earth shall see the salvation of our God.
33170	1271	1	And now, it came to pass that after Abinadi had spoken these words he stretched forth his hand and said: The time shall come when all shall see the salvation of the Lord; when every nation, kindred, tongue, and people shall see eye to eye and shall confess before God that his judgments are just.
33171	1271	2	And then shall the wicked be cast out, and they shall have cause to howl, and weep, and wail, and gnash their teeth; and this because they would not hearken unto the voice of the Lord; therefore the Lord redeemeth them not.
33172	1271	3	For they are carnal and devilish, and the devil has power over them; yea, even that old serpent that did beguile our first parents, which was the cause of their fall; which was the cause of all mankind becoming carnal, sensual, devilish, knowing evil from good, subjecting themselves to the devil.
33173	1271	4	Thus all mankind were lost; and behold, they would have been endlessly lost were it not that God redeemed his people from their lost and fallen state.
33174	1271	5	But remember that he that persists in his own carnal nature, and goes on in the ways of sin and rebellion against God, remaineth in his fallen state and the devil hath all power over him. Therefore, he is as though there was no redemption made, being an enemy to God; and also is the devil an enemy to God.
33175	1271	6	And now if Christ had not come into the world, speaking of things to come as though they had already come, there could have been no redemption.
33176	1271	7	And if Christ had not risen from the dead, or have broken the bands of death that the grave should have no victory, and that death should have no sting, there could have been no resurrection.
33177	1271	8	But there is a resurrection, therefore the grave hath no victory, and the sting of death is swallowed up in Christ.
33178	1271	9	He is the light and the life of the world; yea, a light that is endless, that can never be darkened; yea, and also a life which is endless, that there can be no more death.
33179	1271	10	Even this mortal shall put on immortality, and this corruption shall put on incorruption, and shall be brought to stand before the bar of God, to be judged of him according to their works whether they be good or whether they be evil--
33180	1271	11	If they be good, to the resurrection of endless life and happiness; and if they be evil, to the resurrection of endless damnation, being delivered up to the devil, who hath subjected them, which is damnation--
33181	1271	12	Having gone according to their own carnal wills and desires; having never called upon the Lord while the arms of mercy were extended towards them; for the arms of mercy were extended towards them, and they would not; they being warned of their iniquities and yet they would not depart from them; and they were commanded to repent and yet they would not repent.
33182	1271	13	And now, ought ye not to tremble and repent of your sins, and remember that only in and through Christ ye can be saved?
33183	1271	14	Therefore, if ye teach the law of Moses, also teach that it is a shadow of those things which are to come--
33184	1271	15	Teach them that redemption cometh through Christ the Lord, who is the very Eternal Father. Amen.
33185	1272	1	And now it came to pass that when Abinadi had finished these sayings, that the king commanded that the priests should take him and cause that he should be put to death.
33186	1272	2	But there was one among them whose name was Alma, he also being a descendant of Nephi. And he was a young man, and he believed the words which Abinadi had spoken, for he knew concerning the iniquity which Abinadi had testified against them; therefore he began to plead with the king that he would not be angry with Abinadi, but suffer that he might depart in peace.
33187	1272	3	But the king was more wroth, and caused that Alma should be cast out from among them, and sent his servants after him that they might slay him.
33188	1272	4	But he fled from before them and hid himself that they found him not. And he being concealed for many days did write all the words which Abinadi had spoken.
33189	1272	5	And it came to pass that the king caused that his guards should surround Abinadi and take him; and they bound him and cast him into prison.
33190	1272	6	And after three days, having counseled with his priests, he caused that he should again be brought before him.
33191	1272	7	And he said unto him: Abinadi, we have found an accusation against thee, and thou art worthy of death.
33192	1272	8	For thou hast said that God himself should come down among the children of men; and now, for this cause thou shalt be put to death unless thou wilt recall all the words which thou hast spoken evil concerning me and my people.
33193	1272	9	Now Abinadi said unto him: I say unto you, I will not recall the words which I have spoken unto you concerning this people, for they are true; and that ye may know of their surety I have suffered myself that I have fallen into your hands.
33194	1272	10	Yea, and I will suffer even until death, and I will not recall my words, and they shall stand as a testimony against you. And if ye slay me ye will shed innocent blood, and this shall also stand as a testimony against you at the last day.
33195	1272	11	And now king Noah was about to release him, for he feared his word; for he feared that the judgments of God would come upon him.
33196	1272	12	But the priests lifted up their voices against him, and began to accuse him, saying: He has reviled the king. Therefore the king was stirred up in anger against him, and he delivered him up that he might be slain.
33197	1272	13	And it came to pass that they took him and bound him, and scourged his skin with faggots, yea, even unto death.
33198	1272	14	And now when the flames began to scorch him, he cried unto them, saying:
33199	1272	15	Behold, even as ye have done unto me, so shall it come to pass that thy seed shall cause that many shall suffer the pains that I do suffer, even the pains of death by fire; and this because they believe in the salvation of the Lord their God.
33200	1272	16	And it will come to pass that ye shall be afflicted with all manner of diseases because of your iniquities.
33201	1272	17	Yea, and ye shall be smitten on every hand, and shall be driven and scattered to and fro, even as a wild flock is driven by wild and ferocious beasts.
33202	1272	18	And in that day ye shall be hunted, and ye shall be taken by the hand of your enemies, and then ye shall suffer, as I suffer, the pains of death by fire.
33203	1272	19	Thus God executeth vengeance upon those that destroy his people. O God, receive my soul.
33204	1272	20	And now, when Abinadi had said these words, he fell, having suffered death by fire; yea, having been put to death because he would not deny the commandments of God, having sealed the truth of his words by his death.
33205	1273	1	And now, it came to pass that Alma, who had fled from the servants of king Noah, repented of his sins and iniquities, and went about privately among the people, and began to teach the words of Abinadi--
33206	1273	2	Yea, concerning that which was to come, and also concerning the resurrection of the dead, and the redemption of the people, which was to be brought to pass through the power, and sufferings, and death of Christ, and his resurrection and ascension into heaven.
33207	1273	3	And as many as would hear his word he did teach. And he taught them privately, that it might not come to the knowledge of the king. And many did believe his words.
33208	1273	4	And it came to pass that as many as did believe him did go forth to a place which was called Mormon, having received its name from the king, being in the borders of the land having been infested, by times or at seasons, by wild beasts.
33209	1273	5	Now, there was in Mormon a fountain of pure water, and Alma resorted thither, there being near the water a thicket of small trees, where he did hide himself in the daytime from the searches of the king.
33210	1273	6	And it came to pass that as many as believed him went thither to hear his words.
33211	1273	7	And it came to pass after many days there were a goodly number gathered together at the place of Mormon, to hear the words of Alma. Yea, all were gathered together that believed on his word, to hear him. And he did teach them, and did preach unto them repentance, and redemption, and faith on the Lord.
33212	1273	8	And it came to pass that he said unto them: Behold, here are the waters of Mormon (for thus were they called) and now, as ye are desirous to come into the fold of God, and to be called his people, and are willing to bear one another's burdens, that they may be light;
33213	1273	9	Yea, and are willing to mourn with those that mourn; yea, and comfort those that stand in need of comfort, and to stand as witnesses of God at all times and in all things, and in all places that ye may be in, even until death, that ye may be redeemed of God, and be numbered with those of the first resurrection, that ye may have eternal life--
33214	1273	10	Now I say unto you, if this be the desire of your hearts, what have you against being baptized in the name of the Lord, as a witness before him that ye have entered into a covenant with him, that ye will serve him and keep his commandments, that he may pour out his Spirit more abundantly upon you?
33215	1273	11	And now when the people had heard these words, they clapped their hands for joy, and exclaimed: This is the desire of our hearts.
33216	1273	12	And now it came to pass that Alma took Helam, he being one of the first, and went and stood forth in the water, and cried, saying: O Lord, pour out thy Spirit upon thy servant, that he may do this work with holiness of heart.
33217	1273	13	And when he had said these words, the Spirit of the Lord was upon him, and he said: Helam, I baptize thee, having authority from the Almighty God, as a testimony that ye have entered into a covenant to serve him until you are dead as to the mortal body; and may the Spirit of the Lord be poured out upon you; and may he grant unto you eternal life, through the redemption of Christ, whom he has prepared from the foundation of the world.
33218	1273	14	And after Alma had said these words, both Alma and Helam were buried in the water; and they arose and came forth out of the water rejoicing, being filled with the Spirit.
33219	1273	15	And again, Alma took another, and went forth a second time into the water, and baptized him according to the first, only he did not bury himself again in the water.
33220	1273	16	And after this manner he did baptize every one that went forth to the place of Mormon; and they were in number about two hundred and four souls; yea, and they were baptized in the waters of Mormon, and were filled with the grace of God.
33221	1273	17	And they were called the church of God, or the church of Christ, from that time forward. And it came to pass that whosoever was baptized by the power and authority of God was added to his church.
33222	1273	18	And it came to pass that Alma, having authority from God, ordained priests; even one priest to every fifty of their number did he ordain to preach unto them, and to teach them concerning the things pertaining to the kingdom of God.
33223	1273	19	And he commanded them that they should teach nothing save it were the things which he had taught, and which had been spoken by the mouth of the holy prophets.
33224	1273	20	Yea, even he commanded them that they should preach nothing save it were repentance and faith on the Lord, who had redeemed his people.
33225	1273	21	And he commanded them that there should be no contention one with another, but that they should look forward with one eye, having one faith and one baptism, having their hearts knit together in unity and in love one towards another.
33226	1273	22	And thus he commanded them to preach. And thus they became the children of God.
33227	1273	23	And he commanded them that they should observe the sabbath day, and keep it holy, and also every day they should give thanks to the Lord their God.
33228	1273	24	And he also commanded them that the priests whom he had ordained should labor with their own hands for their support.
33229	1273	25	And there was one day in every week that was set apart that they should gather themselves together to teach the people, and to worship the Lord their God, and also, as often as it was in their power, to assemble themselves together.
33230	1273	26	And the priests were not to depend upon the people for their support; but for their labor they were to receive the grace of God, that they might wax strong in the Spirit, having the knowledge of God, that they might teach with power and authority from God.
33231	1273	27	And again Alma commanded that the people of the church should impart of their substance, every one according to that which he had; if he have more abundantly he should impart more abundantly; and of him that had but little, but little should be required; and to him that had not should be given.
33232	1273	28	And thus they should impart of their substance of their own free will and good desires towards God, and to those priests that stood in need, yea, and to every needy, naked soul.
33233	1273	29	And this he said unto them, having been commanded of God; and they did walk uprightly before God, imparting to one another both temporally and spiritually according to their needs and their wants.
33234	1273	30	And now it came to pass that all this was done in Mormon, yea, by the waters of Mormon, in the forest that was near the waters of Mormon; yea, the place of Mormon, the waters of Mormon, the forest of Mormon, how beautiful are they to the eyes of them who there came to the knowledge of their Redeemer; yea, and how blessed are they, for they shall sing to his praise forever.
33235	1273	31	And these things were done in the borders of the land, that they might not come to the knowledge of the king.
33236	1273	32	But behold, it came to pass that the king, having discovered a movement among the people, sent his servants to watch them. Therefore on the day that they were assembling themselves together to hear the word of the Lord they were discovered unto the king.
33237	1273	33	And now the king said that Alma was stirring up the people to rebellion against him; therefore he sent his army to destroy them.
33238	1273	34	And it came to pass that Alma and the people of the Lord were apprised of the coming of the king's army; therefore they took their tents and their families and departed into the wilderness.
33239	1273	35	And they were in number about four hundred and fifty souls.
33240	1274	1	And it came to pass that the army of the king returned, having searched in vain for the people of the Lord.
33241	1274	2	And now behold, the forces of the king were small, having been reduced, and there began to be a division among the remainder of the people.
33242	1274	3	And the lesser part began to breathe out threatenings against the king, and there began to be a great contention among them.
33243	1274	4	And now there was a man among them whose name was Gideon, and he being a strong man and an enemy to the king, therefore he drew his sword, and swore in his wrath that he would slay the king.
33244	1274	5	And it came to pass that he fought with the king; and when the king saw that he was about to overpower him, he fled and ran and got upon the tower which was near the temple.
33245	1274	6	And Gideon pursued after him and was about to get upon the tower to slay the king, and the king cast his eyes round about towards the land of Shemlon, and behold, the army of the Lamanites were within the borders of the land.
33246	1274	7	And now the king cried out in the anguish of his soul, saying: Gideon, spare me, for the Lamanites are upon us, and they will destroy us; yea, they will destroy my people.
33247	1274	8	And now the king was not so much concerned about his people as he was about his own life; nevertheless, Gideon did spare his life.
33248	1274	9	And the king commanded the people that they should flee before the Lamanites, and he himself did go before them, and they did flee into the wilderness, with their women and their children.
33249	1274	10	And it came to pass that the Lamanites did pursue them, and did overtake them, and began to slay them.
33250	1274	11	Now it came to pass that the king commanded them that all the men should leave their wives and their children, and flee before the Lamanites.
33251	1274	12	Now there were many that would not leave them, but had rather stay and perish with them. And the rest left their wives and their children and fled.
33252	1274	13	And it came to pass that those who tarried with their wives and their children caused that their fair daughters should stand forth and plead with the Lamanites that they would not slay them.
33253	1274	14	And it came to pass that the Lamanites had compassion on them, for they were charmed with the beauty of their women.
33254	1274	15	Therefore the Lamanites did spare their lives, and took them captives and carried them back to the land of Nephi, and granted unto them that they might possess the land, under the conditions that they would deliver up king Noah into the hands of the Lamanites, and deliver up their property, even one half of all they possessed, one half of their gold, and their silver, and all their precious things, and thus they should pay tribute to the king of the Lamanites from year to year.
33255	1274	16	And now there was one of the sons of the king among those that were taken captive, whose name was Limhi.
33256	1274	17	And now Limhi was desirous that his father should not be destroyed; nevertheless, Limhi was not ignorant of the iniquities of his father, he himself being a just man.
33257	1274	18	And it came to pass that Gideon sent men into the wilderness secretly, to search for the king and those that were with him. And it came to pass that they met the people in the wilderness, all save the king and his priests.
33258	1274	19	Now they had sworn in their hearts that they would return to the land of Nephi, and if their wives and their children were slain, and also those that had tarried with them, that they would seek revenge, and also perish with them.
33259	1274	20	And the king commanded them that they should not return; and they were angry with the king, and caused that he should suffer, even unto death by fire.
33260	1274	21	And they were about to take the priests also and put them to death, and they fled before them.
33261	1274	22	And it came to pass that they were about to return to the land of Nephi, and they met the men of Gideon. And the men of Gideon told them of all that had happened to their wives and their children; and that the Lamanites had granted unto them that they might possess the land by paying a tribute to the Lamanites of one half of all they possessed.
33262	1274	23	And the people told the men of Gideon that they had slain the king, and his priests had fled from them farther into the wilderness.
33263	1274	24	And it came to pass that after they had ended the ceremony, that they returned to the land of Nephi, rejoicing, because their wives and their children were not slain; and they told Gideon what they had done to the king.
33264	1274	25	And it came to pass that the king of the Lamanites made an oath unto them, that his people should not slay them.
33265	1274	26	And also Limhi, being the son of the king, having the kingdom conferred upon him by the people, made oath unto the king of the Lamanites that his people should pay tribute unto him, even one half of all they possessed.
33266	1274	27	And it came to pass that Limhi began to establish the kingdom and to establish peace among his people.
33267	1274	28	And the king of the Lamanites set guards round about the land, that he might keep the people of Limhi in the land, that they might not depart into the wilderness; and he did support his guards out of the tribute which he did receive from the Nephites.
33268	1274	29	And now king Limhi did have continual peace in his kingdom for the space of two years, that the Lamanites did not molest them nor seek to destroy them.
33269	1275	1	Now there was a place in Shemlon where the daughters of the Lamanites did gather themselves together to sing, and to dance, and to make themselves merry.
33270	1275	2	And it came to pass that there was one day a small number of them gathered together to sing and to dance.
33271	1275	3	And now the priests of king Noah, being ashamed to return to the city of Nephi, yea, and also fearing that the people would slay them, therefore they durst not return to their wives and their children.
33272	1275	4	And having tarried in the wilderness, and having discovered the daughters of the Lamanites, they laid and watched them;
33273	1275	5	And when there were but few of them gathered together to dance, they came forth out of their secret places and took them and carried them into the wilderness; yea, twenty and four of the daughters of the Lamanites they carried into the wilderness.
33274	1275	6	And it came to pass that when the Lamanites found that their daughters had been missing, they were angry with the people of Limhi, for they thought it was the people of Limhi.
33275	1275	7	Therefore they sent their armies forth; yea, even the king himself went before his people; and they went up to the land of Nephi to destroy the people of Limhi.
33276	1275	8	And now Limhi had discovered them from the tower, even all their preparations for war did he discover; therefore he gathered his people together, and laid wait for them in the fields and in the forests.
33277	1275	9	And it came to pass that when the Lamanites had come up, that the people of Limhi began to fall upon them from their waiting places, and began to slay them.
33278	1275	10	And it came to pass that the battle became exceedingly sore, for they fought like lions for their prey.
33279	1275	11	And it came to pass that the people of Limhi began to drive the Lamanites before them; yet they were not half so numerous as the Lamanites. But they fought for their lives, and for their wives, and for their children; therefore they exerted themselves and like dragons did they fight.
33280	1275	12	And it came to pass that they found the king of the Lamanites among the number of their dead; yet he was not dead, having been wounded and left upon the ground, so speedy was the flight of his people.
33281	1275	13	And they took him and bound up his wounds, and brought him before Limhi, and said: Behold, here is the king of the Lamanites; he having received a wound has fallen among their dead, and they have left him; and behold, we have brought him before you; and now let us slay him.
33282	1275	14	But Limhi said unto them: Ye shall not slay him, but bring him hither that I may see him. And they brought him. And Limhi said unto him: What cause have ye to come up to war against my people? Behold, my people have not broken the oath that I made unto you; therefore, why should ye break the oath which ye made unto my people?
33283	1275	15	And now the king said: I have broken the oath because thy people did carry away the daughters of my people; therefore, in my anger I did cause my people to come up to war against thy people.
33284	1275	16	And now Limhi had heard nothing concerning this matter; therefore he said: I will search among my people and whosoever has done this thing shall perish. Therefore he caused a search to be made among his people.
33285	1275	17	Now when Gideon had heard these things, he being the king's captain, he went forth and said unto the king: I pray thee forbear, and do not search this people, and lay not this thing to their charge.
33286	1275	18	For do ye not remember the priests of thy father, whom this people sought to destroy? And are they not in the wilderness? And are not they the ones who have stolen the daughters of the Lamanites?
33287	1275	19	And now, behold, and tell the king of these things, that he may tell his people that they may be pacified towards us; for behold they are already preparing to come against us; and behold also there are but few of us.
33288	1275	20	And behold, they come with their numerous hosts; and except the king doth pacify them towards us we must perish.
33289	1275	21	For are not the words of Abinadi fulfilled, which he prophesied against us--and all this because we would not hearken unto the words of the Lord, and turn from our iniquities?
33290	1275	22	And now let us pacify the king, and we fulfil the oath which we have made unto him; for it is better that we should be in bondage than that we should lose our lives; therefore, let us put a stop to the shedding of so much blood.
33291	1275	23	And now Limhi told the king all the things concerning his father, and the priests that had fled into the wilderness, and attributed the carrying away of their daughters to them.
33292	1275	24	And it came to pass that the king was pacified towards his people; and he said unto them: Let us go forth to meet my people, without arms; and I swear unto you with an oath that my people shall not slay thy people.
33293	1275	25	And it came to pass that they followed the king, and went forth without arms to meet the Lamanites. And it came to pass that they did meet the Lamanites; and the king of the Lamanites did bow himself down before them, and did plead in behalf of the people of Limhi.
33294	1275	26	And when the Lamanites saw the people of Limhi, that they were without arms, they had compassion on them and were pacified towards them, and returned with their king in peace to their own land.
33295	1276	1	And it came to pass that Limhi and his people returned to the city of Nephi, and began to dwell in the land again in peace.
33296	1276	2	And it came to pass that after many days the Lamanites began again to be stirred up in anger against the Nephites, and they began to come into the borders of the land round about.
33297	1276	3	Now they durst not slay them, because of the oath which their king had made unto Limhi; but they would smite them on their cheeks, and exercise authority over them; and began to put heavy burdens upon their backs, and drive them as they would a dumb ass--
33298	1276	4	Yea, all this was done that the word of the Lord might be fulfilled.
33299	1276	5	And now the afflictions of the Nephites were great, and there was no way that they could deliver themselves out of their hands, for the Lamanites had surrounded them on every side.
33300	1276	6	And it came to pass that the people began to murmur with the king because of their afflictions; and they began to be desirous to go against them to battle. And they did afflict the king sorely with their complaints; therefore he granted unto them that they should do according to their desires.
33301	1276	7	And they gathered themselves together again, and put on their armor, and went forth against the Lamanites to drive them out of their land.
33302	1276	8	And it came to pass that the Lamanites did beat them, and drove them back, and slew many of them.
33303	1276	9	And now there was a great mourning and lamentation among the people of Limhi, the widow mourning for her husband, the son and the daughter mourning for their father, and the brothers for their brethren.
33304	1276	10	Now there were a great many widows in the land, and they did cry mightily from day to day, for a great fear of the Lamanites had come upon them.
33305	1276	11	And it came to pass that their continual cries did stir up the remainder of the people of Limhi to anger against the Lamanites; and they went again to battle, but they were driven back again, suffering much loss.
33306	1276	12	Yea, they went again even the third time, and suffered in the like manner; and those that were not slain returned again to the city of Nephi.
33307	1276	13	And they did humble themselves even to the dust, subjecting themselves to the yoke of bondage, submitting themselves to be smitten, and to be driven to and fro, and burdened, according to the desires of their enemies.
33308	1276	14	And they did humble themselves even in the depths of humility; and they did cry mightily to God; yea, even all the day long did they cry unto their God that he would deliver them out of their afflictions.
33309	1276	15	And now the Lord was slow to hear their cry because of their iniquities; nevertheless the Lord did hear their cries, and began to soften the hearts of the Lamanites that they began to ease their burdens; yet the Lord did not see fit to deliver them out of bondage.
33310	1276	16	And it came to pass that they began to prosper by degrees in the land, and began to raise grain more abundantly, and flocks, and herds, that they did not suffer with hunger.
33311	1276	17	Now there was a great number of women, more than there was of men; therefore king Limhi commanded that every man should impart to the support of the widows and their children, that they might not perish with hunger; and this they did because of the greatness of their number that had been slain.
33312	1276	18	Now the people of Limhi kept together in a body as much as it was possible, and secured their grain and their flocks;
33313	1276	19	And the king himself did not trust his person without the walls of the city, unless he took his guards with him, fearing that he might by some means fall into the hands of the Lamanites.
33314	1276	20	And he caused that his people should watch the land round about, that by some means they might take those priests that fled into the wilderness, who had stolen the daughters of the Lamanites, and that had caused such a great destruction to come upon them.
33315	1276	21	For they were desirous to take them that they might punish them; for they had come into the land of Nephi by night, and carried off their grain and many of their precious things; therefore they laid wait for them.
33316	1276	22	And it came to pass that there was no more disturbance between the Lamanites and the people of Limhi, even until the time that Ammon and his brethren came into the land.
33317	1276	23	And the king having been without the gates of the city with his guard, discovered Ammon and his brethren; and supposing them to be priests of Noah therefore he caused that they should be taken, and bound, and cast into prison. And had they been the priests of Noah he would have caused that they should be put to death.
33318	1276	24	But when he found that they were not, but that they were his brethren, and had come from the land of Zarahemla, he was filled with exceedingly great joy.
33319	1276	25	Now king Limhi had sent, previous to the coming of Ammon, a small number of men to search for the land of Zarahemla; but they could not find it, and they were lost in the wilderness.
33320	1276	26	Nevertheless, they did find a land which had been peopled; yea, a land which was covered with dry bones; yea, a land which had been peopled and which had been destroyed; and they, having supposed it to be the land of Zarahemla, returned to the land of Nephi, having arrived in the borders of the land not many days before the coming of Ammon.
33321	1276	27	And they brought a record with them, even a record of the people whose bones they had found; and it was engraven on plates of ore.
33322	1276	28	And now Limhi was again filled with joy on learning from the mouth of Ammon that king Mosiah had a gift from God, whereby he could interpret such engravings; yea, and Ammon also did rejoice.
33323	1276	29	Yet Ammon and his brethren were filled with sorrow because so many of their brethren had been slain;
33324	1276	30	And also that king Noah and his priests had caused the people to commit so many sins and iniquities against God; and they also did mourn for the death of Abinadi; and also for the departure of Alma and the people that went with him, who had formed a church of God through the strength and power of God, and faith on the words which had been spoken by Abinadi.
33325	1276	31	Yea, they did mourn for their departure, for they knew not whither they had fled. Now they would have gladly joined with them, for they themselves had entered into a covenant with God to serve him and keep his commandments.
33326	1276	32	And now since the coming of Ammon, king Limhi had also entered into a covenant with God, and also many of his people, to serve him and keep his commandments.
33327	1276	33	And it came to pass that king Limhi and many of his people were desirous to be baptized; but there was none in the land that had authority from God. And Ammon declined doing this thing, considering himself an unworthy servant.
33328	1276	34	Therefore they did not at that time form themselves into a church, waiting upon the Spirit of the Lord. Now they were desirous to become even as Alma and his brethren, who had fled into the wilderness.
33329	1276	35	They were desirous to be baptized as a witness and a testimony that they were willing to serve God with all their hearts; nevertheless they did prolong the time; and an account of their baptism shall be given hereafter.
33330	1276	36	And now all the study of Ammon and his people, and king Limhi and his people, was to deliver themselves out of the hands of the Lamanites and from bondage.
33331	1277	1	And now it came to pass that Ammon and king Limhi began to consult with the people how they should deliver themselves out of bondage; and even they did cause that all the people should gather themselves together; and this they did that they might have the voice of the people concerning the matter.
33332	1277	2	And it came to pass that they could find no way to deliver themselves out of bondage, except it were to take their women and children, and their flocks, and their herds, and their tents, and depart into the wilderness; for the Lamanites being so numerous, it was impossible for the people of Limhi to contend with them, thinking to deliver themselves out of bondage by the sword.
33333	1277	3	Now it came to pass that Gideon went forth and stood before the king, and said unto him: Now O king, thou hast hitherto hearkened unto my words many times when we have been contending with our brethren, the Lamanites.
33334	1277	4	And now O king, if thou hast not found me to be an unprofitable servant, or if thou hast hitherto listened to my words in any degree, and they have been of service to thee, even so I desire that thou wouldst listen to my words at this time, and I will be thy servant and deliver this people out of bondage.
33335	1277	5	And the king granted unto him that he might speak. And Gideon said unto him:
33336	1277	6	Behold the back pass, through the back wall, on the back side of the city. The Lamanites, or the guards of the Lamanites, by night are drunken; therefore let us send a proclamation among all this people that they gather together their flocks and herds, that they may drive them into the wilderness by night.
33337	1277	7	And I will go according to thy command and pay the last tribute of wine to the Lamanites, and they will be drunken; and we will pass through the secret pass on the left of their camp when they are drunken and asleep.
33338	1277	8	Thus we will depart with our women and our children, our flocks, and our herds into the wilderness; and we will travel around the land of Shilom.
33339	1277	9	And it came to pass that the king hearkened unto the words of Gideon.
33340	1277	10	And king Limhi caused that his people should gather their flocks together; and he sent the tribute of wine to the Lamanites; and he also sent more wine, as a present unto them; and they did drink freely of the wine which king Limhi did send unto them.
33341	1277	11	And it came to pass that the people of king Limhi did depart by night into the wilderness with their flocks and their herds, and they went round about the land of Shilom in the wilderness, and bent their course towards the land of Zarahemla, being led by Ammon and his brethren.
33342	1277	12	And they had taken all their gold, and silver, and their precious things, which they could carry, and also their provisions with them, into the wilderness; and they pursued their journey.
33343	1277	13	And after being many days in the wilderness they arrived in the land of Zarahemla, and joined Mosiah's people, and became his subjects.
33344	1277	14	And it came to pass that Mosiah received them with joy; and he also received their records, and also the records which had been found by the people of Limhi.
33345	1277	15	And now it came to pass when the Lamanites had found that the people of Limhi had departed out of the land by night, that they sent an army into the wilderness to pursue them;
33346	1277	16	And after they had pursued them two days, they could no longer follow their tracks; therefore they were lost in the wilderness.
33347	1278	1	Now Alma, having been warned of the Lord that the armies of king Noah would come upon them, and having made it known to his people, therefore they gathered together their flocks, and took of their grain, and departed into the wilderness before the armies of king Noah.
33348	1278	2	And the Lord did strengthen them, that the people of king Noah could not overtake them to destroy them.
33349	1278	3	And they fled eight days' journey into the wilderness.
33350	1278	4	And they came to a land, yea, even a very beautiful and pleasant land, a land of pure water.
33351	1278	5	And they pitched their tents, and began to till the ground, and began to build buildings; yea, they were industrious, and did labor exceedingly.
33352	1278	6	And the people were desirous that Alma should be their king, for he was beloved by his people.
33353	1278	7	But he said unto them: Behold, it is not expedient that we should have a king; for thus saith the Lord: Ye shall not esteem one flesh above another, or one man shall not think himself above another; therefore I say unto you it is not expedient that ye should have a king.
33354	1278	8	Nevertheless, if it were possible that ye could always have just men to be your kings it would be well for you to have a king.
33355	1278	9	But remember the iniquity of king Noah and his priests; and I myself was caught in a snare, and did many things which were abominable in the sight of the Lord, which caused me sore repentance;
33356	1278	10	Nevertheless, after much tribulation, the Lord did hear my cries, and did answer my prayers, and has made me an instrument in his hands in bringing so many of you to a knowledge of his truth.
33357	1278	11	Nevertheless, in this I do not glory, for I am unworthy to glory of myself.
33358	1278	12	And now I say unto you, ye have been oppressed by king Noah, and have been in bondage to him and his priests, and have been brought into iniquity by them; therefore ye were bound with the bands of iniquity.
33359	1278	13	And now as ye have been delivered by the power of God out of these bonds; yea, even out of the hands of king Noah and his people, and also from the bonds of iniquity, even so I desire that ye should stand fast in this liberty wherewith ye have been made free, and that ye trust no man to be a king over you.
33360	1278	14	And also trust no one to be your teacher nor your minister, except he be a man of God, walking in his ways and keeping his commandments.
33361	1278	15	Thus did Alma teach his people, that every man should love his neighbor as himself, that there should be no contention among them.
33362	1278	16	And now, Alma was their high priest, he being the founder of their church.
33363	1278	17	And it came to pass that none received authority to preach or to teach except it were by him from God. Therefore he consecrated all their priests and all their teachers; and none were consecrated except they were just men.
33364	1278	18	Therefore they did watch over their people, and did nourish them with things pertaining to righteousness.
33365	1278	19	And it came to pass that they began to prosper exceedingly in the land; and they called the land Helam.
33366	1278	20	And it came to pass that they did multiply and prosper exceedingly in the land of Helam; and they built a city, which they called the city of Helam.
33367	1278	21	Nevertheless the Lord seeth fit to chasten his people; yea, he trieth their patience and their faith.
33368	1278	22	Nevertheless--whosoever putteth his trust in him the same shall be lifted up at the last day. Yea, and thus it was with this people.
33369	1278	23	For behold, I will show unto you that they were brought into bondage, and none could deliver them but the Lord their God, yea, even the God of Abraham and Isaac and of Jacob.
33370	1278	24	And it came to pass that he did deliver them, and he did show forth his mighty power unto them, and great were their rejoicings.
33371	1278	25	For behold, it came to pass that while they were in the land of Helam, yea, in the city of Helam, while tilling the land round about, behold an army of the Lamanites was in the borders of the land.
33372	1278	26	Now it came to pass that the brethren of Alma fled from their fields, and gathered themselves together in the city of Helam; and they were much frightened because of the appearance of the Lamanites.
33373	1278	27	But Alma went forth and stood among them, and exhorted them that they should not be frightened, but that they should remember the Lord their God and he would deliver them.
33374	1278	28	Therefore they hushed their fears, and began to cry unto the Lord that he would soften the hearts of the Lamanites, that they would spare them, and their wives, and their children.
33375	1278	29	And it came to pass the the Lord did soften the hearts of the Lamanites. And Alma and his brethren went forth and delivered themselves up into their hands; and the Lamanites took possession of the land of Helam.
33376	1278	30	Now the armies of the Lamanites, which had followed after the people of king Limhi, had been lost in the wilderness for many days.
33377	1278	31	And behold, they had found those priests of king Noah, in a place which they called Amulon; and they had begun to possess the land of Amulon and had begun to till the ground.
33378	1278	32	Now the name of the leader of those priests was Amulon.
33379	1278	33	And it came to pass that Amulon did plead with the Lamanites; and he also sent forth their wives, who were the daughters of the Lamanites, to plead with their brethren, that they should not destroy their husbands.
33380	1278	34	And the Lamanites had compassion on Amulon and his brethren, and did not destroy them, because of their wives.
33381	1278	35	And Amulon and his brethren did join the Lamanites, and they were traveling in the wilderness in search of the land of Nephi when they discovered the land of Helam, which was possessed by Alma and his brethren.
33382	1278	36	And it came to pass that the Lamanites promised unto Alma and his brethren, that if they would show them the way which led to the land of Nephi that they would grant unto them their lives and their liberty.
33383	1278	37	But after Alma had shown them the way that led to the land of Nephi the Lamanites would not keep their promise; but they set guards round about the land of Helam, over Alma and his brethren.
33384	1278	38	And the remainder of them went to the land of Nephi; and a part of them returned to the land of Helam, and also brought with them the wives and the children of the guards who had been left in the land.
33385	1278	39	And the king of the Lamanites had granted unto Amulon that he should be a king and a ruler over his people, who were in the land of Helam; nevertheless he should have no power to do anything contrary to the will of the king of the Lamanites.
33386	1279	1	And it came to pass that Amulon did gain favor in the eyes of the king of the Lamanites; therefore, the king of the Lamanites granted unto him and his brethren that they should be appointed teachers over his people, yea, even over the people who were in the land of Shemlon, and in the land of Shilom, and in the land of Amulon.
33387	1279	2	For the Lamanites had taken possession of all these lands; therefore, the king of the Lamanites had appointed kings over all these lands.
33388	1279	3	And now the name of the king of the Lamanites was Laman, being called after the name of his father; and therefore he was called king Laman. And he was king over a numerous people.
33389	1279	4	And he appointed teachers of the brethren of Amulon in every land which was possessed by his people; and thus the language of Nephi began to be taught among all the people of the Lamanites.
33390	1279	5	And they were a people friendly one with another; nevertheless they knew not God; neither did the brethren of Amulon teach them anything concerning the Lord their God, neither the law of Moses; nor did they teach them the words of Abinadi;
33391	1279	6	But they taught them that they should keep their record, and that they might write one to another.
33392	1279	7	And thus the Lamanites began to increase in riches, and began to trade one with another and wax great, and began to be a cunning and a wise people, as to the wisdom of the world, yea, a very cunning people, delighting in all manner of wickedness and plunder, except it were among their own brethren.
33393	1279	8	And now it came to pass that Amulon began to exercise authority over Alma and his brethren, and began to persecute him, and cause that his children should persecute their children.
33394	1279	9	For Amulon knew Alma, that he had been one of the king's priests, and that it was he that believed the words of Abinadi and was driven out before the king, and therefore he was wroth with him; for he was subject to king Laman, yet he exercised authority over them, and put tasks upon them, and put task-masters over them.
33395	1279	10	And it came to pass that so great were their afflictions that they began to cry mightily to God.
33396	1279	11	And Amulon commanded them that they should stop their cries; and he put guards over them to watch them, that whosoever should be found calling upon God should be put to death.
33397	1279	12	And Alma and his people did not raise their voices to the Lord their God, but did pour out their hearts to him; and he did know the thoughts of their hearts.
33398	1279	13	And it came to pass that the voice of the Lord came to them in their afflictions, saying: Lift up your heads and be of good comfort, for I know of the covenant which ye have made unto me; and I will covenant with my people and deliver them out of bondage.
33399	1279	14	And I will also ease the burdens which are put upon your shoulders, that even you cannot feel them upon your backs, even while you are in bondage; and this will I do that ye may stand as witnesses for me hereafter, and that ye may know of a surety that I, the Lord God, do visit my people in their afflictions.
33400	1279	15	And now it came to pass that the burdens which were laid upon Alma and his brethren were made light; yea, the Lord did strengthen them that they could bear up their burdens with ease, and they did submit cheerfully and with patience to all the will of the Lord.
33401	1279	16	And it came to pass that so great was their faith and their patience that the voice of the Lord came unto them again, saying: Be of good comfort, for on the morrow I will deliver you out of bondage.
33402	1279	17	And he said unto Alma: Thou shalt go before this people, and I will go with thee and deliver this people out of bondage.
33403	1279	18	Now it came to pass that Alma and his people in the night-time gathered their flocks together, and also of their grain; yea, even all the night-time were they gathering the flocks together.
33404	1279	19	And in the morning the Lord caused a deep sleep to come upon the Lamanites, yea, and all their task-masters were in a profound sleep.
33405	1279	20	And Alma and his people departed into the wilderness; and when they had traveled all day they pitched their tents in a valley, and they called the valley Alma, because he led their way in the wilderness.
33406	1279	21	Yea, and in the valley of Alma they poured out their thanks to God because he had been merciful unto them, and eased their burdens, and had delivered them out of bondage; for they were in bondage, and none could deliver them except it were the Lord their God.
33407	1279	22	And they gave thanks to God, yea, all their men and all their women and all their children that could speak lifted their voices in the praises of their God.
33408	1279	23	And now the Lord said unto Alma: Haste thee and get thou and this people out of this land, for the Lamanites have awakened and do pursue thee; therefore get thee out of this land, and I will stop the Lamanites in this valley that they come no further in pursuit of this people.
33409	1279	24	And it came to pass that they departed out of the valley, and took their journey into the wilderness.
33410	1279	25	And after they had been in the wilderness twelve days they arrived in the land of Zarahemla; and king Mosiah did also receive them with joy.
33411	1280	1	And now king Mosiah caused that all the people should be gathered together.
33412	1280	2	Now there were not so many of the children of Nephi, or so many of those who were descendants of Nephi, as there were of the people of Zarahemla, who was a descendant of Mulek, and those who came with him into the wilderness.
33413	1280	3	And there were not so many of the people of Nephi and of the people of Zarahemla as there were of the Lamanites; yea, they were not half so numerous.
33414	1280	4	And now all the people of Nephi were assembled together, and also all the people of Zarahemla, and they were gathered together in two bodies.
33415	1280	5	And it came to pass that Mosiah did read, and caused to be read, the records of Zeniff to his people; yea, he read the records of the people of Zeniff, from the time they left the land of Zarahemla until they returned again.
33416	1280	6	And he also read the account of Alma and his brethren, and all their afflictions, from the time they left the land of Zarahemla until the time they returned again.
33417	1280	7	And now, when Mosiah had made an end of reading the records, his people who tarried in the land were struck with wonder and amazement.
33418	1280	8	For they knew not what to think; for when they beheld those that had been delivered out of bondage they were filled with exceedingly great joy.
33419	1280	9	And again, when they thought of their brethren who had been slain by the Lamanites they were filled with sorrow, and even shed many tears of sorrow.
33420	1280	10	And again, when they thought of the immediate goodness of God, and his power in delivering Alma and his brethren out of the hands of the Lamanites and of bondage, they did raise their voices and give thanks to God.
33421	1280	11	And again, when they thought upon the Lamanites, who were their brethren, of their sinful and polluted state, they were filled with pain and anguish for the welfare of their souls.
33422	1280	12	And it came to pass that those who were the children of Amulon and his brethren, who had taken to wife the daughters of the Lamanites, were displeased with the conduct of their fathers, and they would no longer be called by the names of their fathers, therefore they took upon themselves the name of Nephi, that they might be called the children of Nephi and be numbered among those who were called Nephites.
33423	1280	13	And now all the people of Zarahemla were numbered with the Nephites, and this because the kingdom had been conferred upon none but those who were descendants of Nephi.
33424	1280	14	And now it came to pass that when Mosiah had made an end of speaking and reading to the people, he desired that Alma should also speak to the people.
33425	1280	15	And Alma did speak unto them, when they were assembled together in large bodies, and he went from one body to another, preaching unto the people repentance and faith on the Lord.
33426	1280	16	And he did exhort the people of Limhi and his brethren, all those that had been delivered out of bondage, that they should remember that it was the Lord that did deliver them.
33427	1280	17	And it came to pass that after Alma had taught the people many things, and had made an end of speaking to them, that king Limhi was desirous that he might be baptized; and all his people were desirous that they might be baptized also.
33428	1280	18	Therefore, Alma did go forth into the water and did baptize them; yea, he did baptize them after the manner he did his brethren in the waters of Mormon; yea, and as many as he did baptize did belong to the church of God; and this because of their belief on the words of Alma.
33429	1280	19	And it came to pass that king Mosiah granted unto Alma that he might establish churches throughout all the land of Zarahemla; and gave him power to ordain priests and teachers over every church.
33430	1280	20	Now this was done because there were so many people that they could not all be governed by one teacher; neither could they all hear the word of God in one assembly;
33431	1280	21	Therefore they did assemble themselves together in different bodies, being called churches; every church having their priests and their teachers, and every priest preaching the word according as it was delivered to him by the mouth of Alma.
33432	1280	22	And thus, notwithstanding there being many churches they were all one church, yea, even the church of God; for there was nothing preached in all the churches except it were repentance and faith in God.
33433	1280	23	And now there were seven churches in the land of Zarahemla. And it came to pass that whosoever were desirous to take upon them the name of Christ, or of God, they did join the churches of God;
33434	1280	24	And they were called the people of God. And the Lord did pour out his Spirit upon them, and they were blessed, and prospered in the land.
33435	1281	1	Now it came to pass that there were many of the rising generation that could not understand the words of king Benjamin, being little children at the time he spake unto his people; and they did not believe the tradition of their fathers.
33436	1281	2	They did not believe what had been said concerning the resurrection of the dead, neither did they believe concerning the coming of Christ.
33437	1281	3	And now because of their unbelief they could not understand the word of God; and their hearts were hardened.
33438	1281	4	And they would not be baptized; neither would they join the church. And they were a separate people as to their faith, and remained so ever after, even in their carnal and sinful state; for they would not call upon the Lord their God.
33439	1281	5	And now in the reign of Mosiah they were not half so numerous as the people of God; but because of the dissensions among the brethren they became more numerous.
33440	1281	6	For it came to pass that they did deceive many with their flattering words, who were in the church, and did cause them to commit many sins; therefore it became expedient that those who committed sin, that were in the church, should be admonished by the church.
33441	1281	7	And it came to pass that they were brought before the priests, and delivered up unto the priests by the teachers; and the priests brought them before Alma, who was the high priest.
33442	1281	8	Now king Mosiah had given Alma the authority over the church.
33443	1281	9	And it came to pass that Alma did not know concerning them; but there were many witnesses against them; yea, the people stood and testified of their iniquity in abundance.
33444	1281	10	Now there had not any such thing happened before in the church; therefore Alma was troubled in his spirit, and he caused that they should be brought before the king.
33445	1281	11	And he said unto the king: Behold, here are many whom we have brought before thee, who are accused of their brethren; yea, and they have been taken in divers iniquities. And they do not repent of their iniquities; therefore we have brought them before thee, that thou mayest judge them according to their crimes.
33446	1281	12	But king Mosiah said unto Alma: Behold, I judge them not; therefore I deliver them into thy hands to be judged.
33447	1281	13	And now the spirit of Alma was again troubled; and he went and inquired of the Lord what he should do concerning this matter, for he feared that he should do wrong in the sight of God.
33448	1281	14	And it came to pass that after he had poured out his whole soul to God, the voice of the Lord came to him, saying:
33449	1281	15	Blessed art thou, Alma, and blessed are they who were baptized in the waters of Mormon. Thou art blessed because of thy exceeding faith in the words alone of my servant Abinadi.
33450	1281	16	And blessed are they because of their exceeding faith in the words alone which thou hast spoken unto them.
33451	1281	17	And blessed art thou because thou hast established a church among this people; and they shall be established, and they shall be my people.
33452	1281	18	Yea, blessed is this people who are willing to bear my name; for in my name shall they be called; and they are mine.
33453	1281	19	And because thou hast inquired of me concerning the transgressor, thou art blessed.
33454	1281	20	Thou art my servant; and I covenant with thee that thou shalt have eternal life; and thou shalt serve me and go forth in my name, and shalt gather together my sheep.
33455	1281	21	And he that will hear my voice shall be my sheep; and him shall ye receive into the church, and him will I also receive.
33456	1281	22	For behold, this is my church; whosoever is baptized shall be baptized unto repentance. And whomsoever ye receive shall believe in my name; and him will I freely forgive.
33457	1281	23	For it is I that taketh upon me the sins of the world; for it is I that hath created them; and it is I that granteth unto him that believeth unto the end a place at my right hand.
33458	1281	24	For behold, in my name are they called; and if they know me they shall come forth, and shall have a place eternally at my right hand.
33459	1281	25	And it shall come to pass that when the second trump shall sound then shall they that never knew me come forth and shall stand before me.
33460	1281	26	And then shall they know that I am the Lord their God, that I am their Redeemer; but they would not be redeemed.
33461	1281	27	And then I will confess unto them that I never knew them; and they shall depart into everlasting fire prepared for the devil and his angels.
33462	1281	28	Therefore I say unto you, that he that will not hear my voice, the same shall ye not receive into my church, for him I will not receive at the last day.
33463	1281	29	Therefore I say unto you, Go; and whosoever transgresseth against me, him shall ye judge according to the sins which he has committed; and if he confess his sins before thee and me, and repenteth in the sincerity of his heart, him shall ye forgive, and I will forgive him also.
33464	1281	30	Yea, and as often as my people repent will I forgive them their trespasses against me.
33465	1281	31	And ye shall also forgive one another your trespasses; for verily I say unto you, he that forgiveth not his neighbor's trespasses when he says that he repents, the same hath brought himself under condemnation.
33466	1281	32	Now I say unto you, Go; and whosoever will not repent of his sins the same shall not be numbered among my people; and this shall be observed from this time forward.
33467	1281	33	And it came to pass when Alma had heard these words he wrote them down that he might have them, and that he might judge the people of that church according to the commandments of God.
33468	1281	34	And it came to pass that Alma went and judged those that had been taken in iniquity, according to the word of the Lord.
33469	1281	35	And whosoever repented of their sins and did confess them, them he did number among the people of the church;
33470	1281	36	And those that would not confess their sins and repent of their iniquity, the same were not numbered among the people of the church, and their names were blotted out.
33471	1281	37	And it came to pass that Alma did regulate all the affairs of the church; and they began again to have peace and to prosper exceedingly in the affairs of the church, walking circumspectly before God, receiving many, and baptizing many.
33472	1281	38	And now all these things did Alma and his fellow laborers do who were over the church, walking in all diligence, teaching the word of God in all things, suffering all manner of afflictions, being persecuted by all those who did not belong to the church of God.
33473	1281	39	And they did admonish their brethren; and they were also admonished, every one by the word of God, according to his sins, or to the sins which he had committed, being commanded of God to pray without ceasing, and to give thanks in all things.
33474	1282	1	And now it came to pass that the persecutions which were inflicted on the church by the unbelievers became so great that the church began to murmur, and complain to their leaders concerning the matter; and they did complain to Alma. And Alma laid the case before their king, Mosiah. And Mosiah consulted with his priests.
33475	1282	2	And it came to pass that king Mosiah sent a proclamation throughout the land round about that there should not any unbeliever persecute any of those who belonged to the church of God.
33476	1282	3	And there was a strict command throughout all the churches that there should be no persecutions among them, that there should be an equality among all men;
33477	1282	4	That they should let no pride nor haughtiness disturb their peace; that every man should esteem his neighbor as himself, laboring with their own hands for their support.
33478	1282	5	Yea, and all their priests and teachers should labor with their own hands for their support, in all cases save it were in sickness, or in much want; and doing these things, they did abound in the grace of God.
33479	1282	6	And there began to be much peace again in the land; and the people began to be very numerous, and began to scatter abroad upon the face of the earth, yea, on the north and on the south, on the east and on the west, building large cities and villages in all quarters of the land.
33480	1282	7	And the Lord did visit them and prosper them, and they became a large and wealthy people.
33481	1282	8	Now the sons of Mosiah were numbered among the unbelievers; and also one of the sons of Alma was numbered among them, he being called Alma, after his father; nevertheless, he became a very wicked and an idolatrous man. And he was a man of many words, and did speak much flattery to the people; therefore he led many of the people to do after the manner of his iniquities.
33482	1282	9	And he became a great hinderment to the prosperity of the church of God; stealing away the hearts of the people; causing much dissension among the people; giving a chance for the enemy of God to exercise his power over them.
33483	1282	10	And now it came to pass that while he was going about to destroy the church of God, for he did go about secretly with the sons of Mosiah seeking to destroy the church, and to lead astray the people of the Lord, contrary to the commandments of God, or even the king--
33484	1282	11	And as I said unto you, as they were going about rebelling against God, behold, the angel of the Lord appeared unto them; and he descended as it were in a cloud; and he spake as it were with a voice of thunder, which caused the earth to shake upon which they stood;
33485	1282	12	And so great was their astonishment, that they fell to the earth, and understood not the words which he spake unto them.
33486	1282	13	Nevertheless he cried again, saying: Alma, arise and stand forth, for why persecutest thou the church of God? For the Lord hath said: This is my church, and I will establish it; and nothing shall overthrow it, save it is the transgression of my people.
33487	1282	14	And again, the angel said: Behold, the Lord hath heard the prayers of his people, and also the prayers of his servant, Alma, who is thy father; for he has prayed with much faith concerning thee that thou mightest be brought to the knowledge of the truth; therefore, for this purpose have I come to convince thee of the power and authority of God, that the prayers of his servants might be answered according to their faith.
33488	1282	15	And now behold, can ye dispute the power of God? For behold, doth not my voice shake the earth? And can ye not also behold me before you? And I am sent from God.
33489	1282	16	Now I say unto thee: Go, and remember the captivity of thy fathers in the land of Helam, and in the land of Nephi; and remember how great things he has done for them; for they were in bondage, and he has delivered them. And now I say unto thee, Alma, go thy way, and seek to destroy the church no more, that their prayers may be answered, and this even if thou wilt of thyself be cast off.
33490	1282	17	And now it came to pass that these were the last words which the angel spake unto Alma, and he departed.
33491	1282	18	And now Alma and those that were with him fell again to the earth, for great was their astonishment; for with their own eyes they had beheld an angel of the Lord; and his voice was as thunder, which shook the earth; and they knew that there was nothing save the power of God that could shake the earth and cause it to tremble as though it would part asunder.
33492	1282	19	And now the astonishment of Alma was so great that he became dumb, that he could not open his mouth; yea, and he became weak, even that he could not move his hands; therefore he was taken by those that were with him, and carried helpless, even until he was laid before his father.
33493	1282	20	And they rehearsed unto his father all that had happened unto them; and his father rejoiced, for he knew that it was the power of God.
33494	1282	21	And he caused that a multitude should be gathered together that they might witness what the Lord had done for his son, and also for those that were with him.
33495	1282	22	And he caused that the priests should assemble themselves together; and they began to fast, and to pray to the Lord their God that he would open the mouth of Alma, that he might speak, and also that his limbs might receive their strength--that the eyes of the people might be opened to see and know of the goodness and glory of God.
33496	1282	23	And it came to pass after they had fasted and prayed for the space of two days and two nights, the limbs of Alma received their strength, and he stood up and began to speak unto them, bidding them to be of good comfort:
33497	1282	24	For, said he, I have repented of my sins, and have been redeemed of the Lord; behold I am born of the Spirit.
33498	1282	25	And the Lord said unto me: Marvel not that all mankind, yea, men and women, all nations, kindreds, tongues and people, must be born again; yea, born of God, changed from their carnal and fallen state, to a state of righteousness, being redeemed of God, becoming his sons and daughters;
33499	1282	26	And thus they become new creatures; and unless they do this, they can in nowise inherit the kingdom of God.
33500	1282	27	I say unto you, unless this be the case, they must be cast off; and this I know, because I was like to be cast off.
33501	1282	28	Nevertheless, after wading through much tribulation, repenting nigh unto death, the Lord in mercy hath seen fit to snatch me out of an everlasting burning, and I am born of God.
33502	1282	29	My soul hath been redeemed from the gall of bitterness and bonds of iniquity. I was in the darkest abyss; but now I behold the marvelous light of God. My soul was racked with eternal torment; but I am snatched, and my soul is pained no more.
33503	1282	30	I rejected my Redeemer, and denied that which had been spoken of by our fathers; but now that they may foresee that he will come, and that he remembereth every creature of his creating, he will make himself manifest unto all.
33504	1282	31	Yea, every knee shall bow, and every tongue confess before him. Yea, even at the last day, when all men shall stand to be judged of him, then shall they confess that he is God; then shall they confess, who live without God in the world, that the judgment of an everlasting punishment is just upon them; and they shall quake, and tremble, and shrink beneath the glance of his all-searching eye.
33505	1282	32	And now it came to pass that Alma began from this time forward to teach the people, and those who were with Alma at the time the angel appeared unto them, traveling round about through all the land, publishing to all the people the things which they had heard and seen, and preaching the word of God in much tribulation, being greatly persecuted by those who were unbelievers, being smitten by many of them.
33506	1282	33	But notwithstanding all this, they did impart much consolation to the church, confirming their faith, and exhorting them with long-suffering and much travail to keep the commandments of God.
33507	1282	34	And four of them were the sons of Mosiah; and their names were Ammon, and Aaron, and Omner, and Himni; these were the names of the sons of Mosiah.
33508	1282	35	And they traveled throughout all the land of Zarahemla, and among all the people who were under the reign of king Mosiah, zealously striving to repair all the injuries which they had done to the church, confessing all their sins, and publishing all the things which they had seen, and explaining the prophecies and the scriptures to all who desired to hear them.
33509	1282	36	And thus they were instruments in the hands of God in bringing many to the knowledge of the truth, yea, to the knowledge of their Redeemer.
33510	1282	37	And how blessed are they! For they did publish peace; they did publish good tidings of good; and they did declare unto the people that the Lord reigneth.
33511	1283	1	Now it came to pass that after the sons of Mosiah had done all these things, they took a small number with them and returned to their father, the king, and desired of him that he would grant unto them that they might, with these whom they had selected, go up to the land of Nephi that they might preach the things which they had heard, and that they might impart the word of God to their brethren, the Lamanites--
33512	1283	2	That perhaps they might bring them to the knowledge of the Lord their God, and convince them of the iniquity of their fathers; and that perhaps they might cure them of their hatred towards the Nephites, that they might also be brought to rejoice in the Lord their God, that they might become friendly to one another, and that there should be no more contentions in all the land which the Lord their God had given them.
33513	1283	3	Now they were desirous that salvation should be declared to every creature, for they could not bear that any human soul should perish; yea, even the very thoughts that any soul should endure endless torment did cause them to quake and tremble.
33514	1283	4	And thus did the Spirit of the Lord work upon them, for they were the very vilest of sinners. And the Lord saw fit in his infinite mercy to spare them; nevertheless they suffered much anguish of soul because of their iniquities, suffering much and fearing that they should be cast off forever.
33515	1283	5	And it came to pass that they did plead with their father many days that they might go up to the land of Nephi.
33516	1283	6	And king Mosiah went and inquired of the Lord if he should let his sons go up among the Lamanites to preach the word.
33517	1283	7	And the Lord said unto Mosiah: Let them go up, for many shall believe on their words, and they shall have eternal life; and I will deliver thy sons out of the hands of the Lamanites.
33518	1283	8	And it came to pass that Mosiah granted that they might go and do according to their request.
33519	1283	9	And they took their journey into the wilderness to go up to preach the word among the Lamanites; and I shall give an account of their proceedings hereafter.
33520	1283	10	Now king Mosiah had no one to confer the kingdom upon, for there was not any of his sons who would accept of the kingdom.
33521	1283	11	Therefore he took the records which were engraven on the plates of brass, and also the plates of Nephi, and all the things which he had kept and preserved according to the commandments of God, after having translated and caused to be written the records which were on the plates of gold which had been found by the people of Limhi, which were delivered to him by the hand of Limhi;
33522	1283	12	And this he did because of the great anxiety of his people; for they were desirous beyond measure to know concerning those people who had been destroyed.
33523	1283	13	And now he translated them by the means of those two stones which were fastened into the two rims of a bow.
33524	1283	14	Now these things were prepared from the beginning, and were handed down from generation to generation, for the purpose of interpreting languages;
33525	1283	15	And they have been kept and preserved by the hand of the Lord, that he should discover to every creature who should possess the land the iniquities and abominations of his people;
33526	1283	16	And whosoever has these things is called seer, after the manner of old times.
33527	1283	17	Now after Mosiah had finished translating these records, behold, it gave an account of the people who were destroyed, from the time that they were destroyed back to the building of the great tower, at the time the Lord confounded the language of the people and they were scattered abroad upon the face of all the earth, yea, and even from that time back until the creation of Adam.
33528	1283	18	Now this account did cause the people of Mosiah to mourn exceedingly, yea, they were filled with sorrow; nevertheless it gave them much knowledge, in the which they did rejoice.
33529	1283	19	And this account shall be written hereafter; for behold, it is expedient that all people should know the things which are written in this account.
33530	1283	20	And now, as I said unto you, that after king Mosiah had done these things, he took the plates of brass, and all the things which he had kept, and conferred them upon Alma, who was the son of Alma; yea, all the records, and also the interpreters, and conferred them upon him, and commanded him that he should keep and preserve them, and also keep a record of the people, handing them down from one generation to another, even as they had been handed down from the time that Lehi left Jerusalem.
33531	1284	1	Now when Mosiah had done this he sent out throughout all the land, among all the people, desiring to know their will concerning who should be their king.
33532	1284	2	And it came to pass that the voice of the people came, saying: We are desirous that Aaron thy son should be our king and our ruler.
33533	1284	3	Now Aaron had gone up to the land of Nephi, therefore the king could not confer the kingdom upon him; neither would Aaron take upon him the kingdom; neither were any of the sons of Mosiah willing to take upon them the kingdom.
33534	1284	4	Therefore king Mosiah sent again among the people; yea, even a written word sent he among the people. And these were the words that were written, saying:
33535	1284	5	Behold, O ye my people, or my brethren, for I esteem you as such, I desire that ye should consider the cause which ye are called to consider--for ye are desirous to have a king.
33536	1284	6	Now I declare unto you that he to whom the kingdom doth rightly belong has declined, and will not take upon him the kingdom.
33537	1284	7	And now if there should be another appointed in his stead, behold I fear there would rise contentions among you. And who knoweth but what my son, to whom the kingdom doth belong, should turn to be angry and draw away a part of this people after him, which would cause wars and contentions among you, which would be the cause of shedding much blood and perverting the way of the Lord, yea, and destroy the souls of many people.
33538	1284	8	Now I say unto you let us be wise and consider these things, for we have no right to destroy my son, neither should we have any right to destroy another if he should be appointed in his stead.
33539	1284	9	And if my son should turn again to his pride and vain things he would recall the things which he had said, and claim his right to the kingdom, which would cause him and also this people to commit much sin.
33540	1284	10	And now let us be wise and look forward to these things, and do that which will make for the peace of this people.
33541	1284	11	Therefore I will be your king the remainder of my days; nevertheless, let us appoint judges, to judge this people according to our law; and we will newly arrange the affairs of this people, for we will appoint wise men to be judges, that will judge this people according to the commandments of God.
33542	1284	12	Now it is better that a man should be judged of God than of man, for the judgments of God are always just, but the judgments of man are not always just.
33543	1284	13	Therefore, if it were possible that you could have just men to be your kings, who would establish the laws of God, and judge this people according to his commandments, yea, if ye could have men for your kings who would do even as my father Benjamin did for this people--I say unto you, if this could always be the case then it would be expedient that ye should always have kings to rule over you.
33544	1284	14	And even I myself have labored with all the power and faculties which I have possessed, to teach you the commandments of God, and to establish peace throughout the land, that there should be no wars nor contentions, no stealing, nor plundering, nor murdering, nor any manner of iniquity;
33545	1284	15	And whosoever has committed iniquity, him have I punished according to the crime which he has committed, according to the law which has been given to us by our fathers.
33546	1284	16	Now I say unto you, that because all men are not just it is not expedient that ye should have a king or kings to rule over you.
33547	1284	17	For behold, how much iniquity doth one wicked king cause to be committed, yea, and what great destruction!
33548	1284	18	Yea, remember king Noah, his wickedness and his abominations, and also the wickedness and abominations of his people. Behold what great destruction did come upon them; and also because of their iniquities they were brought into bondage.
33549	1284	19	And were it not for the interposition of their all-wise Creator, and this because of their sincere repentance, they must unavoidably remain in bondage until now.
33550	1284	20	But behold, he did deliver them because they did humble themselves before him; and because they cried mightily unto him he did deliver them out of bondage; and thus doth the Lord work with his power in all cases among the children of men, extending the arm of mercy towards them that put their trust in him.
33551	1284	21	And behold, now I say unto you, ye cannot dethrone an iniquitous king save it be through much contention, and the shedding of much blood.
33552	1284	22	For behold, he has his friends in iniquity, and he keepeth his guards about him; and he teareth up the laws of those who have reigned in righteousness before him; and he trampleth under his feet the commandments of God;
33553	1284	23	And he enacteth laws, and sendeth them forth among his people, yea, laws after the manner of his own wickedness; and whosoever doth not obey his laws he causeth to be destroyed; and whosoever doth rebel against him he will send his armies against them to war, and if he can he will destroy them; and thus an unrighteous king doth pervert the ways of all righteousness.
33554	1284	24	And now behold I say unto you, it is not expedient that such abominations should come upon you.
33555	1284	25	Therefore, choose you by the voice of this people, judges, that ye may be judged according to the laws which have been given you by our fathers, which are correct, and which were given them by the hand of the Lord.
33556	1284	26	Now it is not common that the voice of the people desireth anything contrary to that which is right; but it is common for the lesser part of the people to desire that which is not right; therefore this shall ye observe and make it your law--to do your business by the voice of the people.
33557	1284	27	And if the time comes that the voice of the people doth choose iniquity, then is the time that the judgments of God will come upon you; yea, then is the time he will visit you with great destruction even as he has hitherto visited this land.
33558	1284	28	And now if ye have judges, and they do not judge you according to the law which has been given, ye can cause that they may be judged of a higher judge.
33559	1284	29	If your higher judges do not judge righteous judgments, ye shall cause that a small number of your lower judges should be gathered together, and they shall judge your higher judges, according to the voice of the people.
33560	1284	30	And I command you to do these things in the fear of the Lord; and I command you to do these things, and that ye have no king; that if these people commit sins and iniquities they shall be answered upon their own heads.
33561	1284	31	For behold I say unto you, the sins of many people have been caused by the iniquities of their kings; therefore their iniquities are answered upon the heads of their kings.
33562	1284	32	And now I desire that this inequality should be no more in this land, especially among this my people; but I desire that this land be a land of liberty, and every man may enjoy his rights and privileges alike, so long as the Lord sees fit that we may live and inherit the land, yea, even as long as any of our posterity remains upon the face of the land.
33563	1284	33	And many more things did king Mosiah write unto them, unfolding unto them all the trials and troubles of a righteous king, yea, all the travails of soul for their people, and also all the murmurings of the people to their king; and he explained it all unto them.
33564	1284	34	And he told them that these things ought not to be; but that the burden should come upon all the people, that every man might bear his part.
33565	1284	35	And he also unfolded unto them all the disadvantages they labored under, by having an unrighteous king to rule over them;
33566	1284	36	Yea, all his iniquities and abominations, and all the wars, and contentions, and bloodshed, and the stealing, and the plundering, and the committing of whoredoms, and all manner of iniquities which cannot be enumerated--telling them that these things ought not to be, that they were expressly repugnant to the commandments of God.
33567	1284	37	And now it came to pass, after king Mosiah had sent these things forth among the people they were convinced of the truth of his words.
33568	1284	38	Therefore they relinquished their desires for a king, and became exceedingly anxious that every man should have an equal chance throughout all the land; yea, and every man expressed a willingness to answer for his own sins.
33569	1284	39	Therefore, it came to pass that they assembled themselves together in bodies throughout the land, to cast in their voices concerning who should be their judges, to judge them according to the law which had been given them; and they were exceedingly rejoiced because of the liberty which had been granted unto them.
33570	1284	40	And they did wax strong in love towards Mosiah; yea, they did esteem him more than any other man; for they did not look upon him as a tyrant who was seeking for gain, yea, for that lucre which doth corrupt the soul; for he had not exacted riches of them, neither had he delighted in the shedding of blood; but he had established peace in the land, and he had granted unto his people that they should be delivered from all manner of bondage; therefore they did esteem him, yea, exceedingly, beyond measure.
33571	1284	41	And it came to pass that they did appoint judges to rule over them, or to judge them according to the law; and this they did throughout all the land.
33572	1284	42	And it came to pass that Alma was appointed to be the first chief judge, he being also the high priest, his father having conferred the office upon him, and having given him the charge concerning all the affairs of the church.
33573	1284	43	And now it came to pass that Alma did walk in the ways of the Lord, and he did keep his commandments, and he did judge righteous judgments; and there was continual peace through the land.
33574	1284	44	And thus commenced the reign of the judges throughout all the land of Zarahemla, among all the people who were called the Nephites; and Alma was the first and chief judge.
33575	1284	45	And now it came to pass that his father died, being eighty and two years old, having lived to fulfil the commandments of God.
33576	1284	46	And it came to pass that Mosiah died also, in the thirty and third year of his reign, being sixty and three years old; making in the whole, five hundred and nine years from the time Lehi left Jerusalem.
33577	1284	47	And thus ended the reign of the kings over the people of Nephi; and thus ended the days of Alma, who was the founder of their church.
33578	1285	1	Now it came to pass that in the first year of the reign of the judges over the people of Nephi, from this time forward, king Mosiah having gone the way of all the earth, having warred a good warfare, walking uprightly before God, leaving none to reign in his stead; nevertheless he had established laws, and they were acknowledged by the people; therefore they were obliged to abide by the laws which he had made.
33579	1285	2	And it came to pass that in the first year of the reign of Alma in the judgment-seat, there was a man brought before him to be judged, a man who was large, and was noted for his much strength.
33580	1285	3	And he had gone about among the people, preaching to them that which he termed to be the word of God, bearing down against the church; declaring unto the people that every priest and teacher ought to become popular; and they ought not to labor with their hands, but that they ought to be supported by the people.
33581	1285	4	And he also testified unto the people that all mankind should be saved at the last day, and that they need not fear nor tremble, but that they might lift up their heads and rejoice; for the Lord had created all men, and had also redeemed all men; and, in the end, all men should have eternal life.
33582	1285	5	And it came to pass that he did teach these things so much that many did believe on his words, even so many that they began to support him and give him money.
33583	1285	6	And he began to be lifted up in the pride of his heart, and to wear very costly apparel, yea, and even began to establish a church after the manner of his preaching.
33584	1285	7	And it came to pass as he was going, to preach to those who believed on his word, he met a man who belonged to the church of God, yea, even one of their teachers; and he began to contend with him sharply, that he might lead away the people of the church; but the man withstood him, admonishing him with the words of God.
33585	1285	8	Now the name of the man was Gideon; and it was he who was an instrument in the hands of God in delivering the people of Limhi out of bondage.
33586	1285	9	Now, because Gideon withstood him with the words of God he was wroth with Gideon, and drew his sword and began to smite him. Now Gideon being stricken with many years, therefore he was not able to withstand his blows, therefore he was slain by the sword.
33587	1285	10	And the man who slew him was taken by the people of the church, and was brought before Alma, to be judged according to the crimes which he had committed.
33588	1285	11	And it came to pass that he stood before Alma and pleaded for himself with much boldness.
33589	1285	12	But Alma said unto him: Behold, this is the first time that priestcraft has been introduced among this people. And behold, thou art not only guilty of priestcraft, but hast endeavored to enforce it by the sword; and were priestcraft to be enforced among this people it would prove their entire destruction.
33590	1285	13	And thou hast shed the blood of a righteous man, yea, a man who has done much good among this people; and were we to spare thee his blood would come upon us for vengeance.
33591	1285	14	Therefore thou art condemned to die, according to the law which has been given us by Mosiah, our last king; and it has been acknowledged by this people; therefore this people must abide by the law.
33592	1285	15	And it came to pass that they took him; and his name was Nehor; and they carried him upon the top of the hill Manti, and there he was caused, or rather did acknowledge, between the heavens and the earth, that what he had taught to the people was contrary to the word of God; and there he suffered an ignominious death.
33593	1285	16	Nevertheless, this did not put an end to the spreading of priestcraft through the land; for there were many who loved the vain things of the world, and they went forth preaching false doctrines; and this they did for the sake of riches and honor.
33594	1285	17	Nevertheless, they durst not lie, if it were known, for fear of the law, for liars were punished; therefore they pretended to preach according to their belief; and now the law could have no power on any man for his belief.
33595	1285	18	And they durst not steal, for fear of the law, for such were punished; neither durst they rob, nor murder, for he that murdered was punished unto death.
33596	1285	19	But it came to pass that whosoever did not belong to the church of God began to persecute those that did belong to the church of God, and had taken upon them the name of Christ.
33597	1285	20	Yea, they did persecute them, and afflict them with all manner of words, and this because of their humility; because they were not proud in their own eyes, and because they did impart the word of God, one with another, without money and without price.
33598	1285	21	Now there was a strict law among the people of the church, that there should not any man, belonging to the church, arise and persecute those that did not belong to the church, and that there should be no persecution among themselves.
33599	1285	22	Nevertheless, there were many among them who began to be proud, and began to contend warmly with their adversaries, even unto blows; yea, they would smite one another with their fists.
33600	1285	23	Now this was in the second year of the reign of Alma, and it was a cause of much affliction to the church; yea, it was the cause of much trial with the church.
33601	1285	24	For the hearts of many were hardened, and their names were blotted out, that they were remembered no more among the people of God. And also many withdrew themselves from among them.
33602	1285	25	Now this was a great trial to those that did stand fast in the faith; nevertheless, they were steadfast and immovable in keeping the commandments of God, and they bore with patience the persecution which was heaped upon them.
33603	1285	26	And when the priests left their labor to impart the word of God unto the people, the people also left their labors to hear the word of God. And when the priest had imparted unto them the word of God they all returned again diligently unto their labors; and the priest, not esteeming himself above his hearers, for the preacher was no better than the hearer, neither was the teacher any better than the learner; and thus they were all equal, and they did all labor, every man according to his strength.
33604	1285	27	And they did impart of their substance, every man according to that which he had, to the poor, and the needy, and the sick, and the afflicted; and they did not wear costly apparel, yet they were neat and comely.
33605	1285	28	And thus they did establish the affairs of the church; and thus they began to have continual peace again, notwithstanding all their persecutions.
33606	1285	29	And now, because of the steadiness of the church they began to be exceedingly rich, having abundance of all things whatsoever they stood in need--an abundance of flocks and herds, and fatlings of every kind, and also abundance of grain, and of gold, and of silver, and of precious things, and abundance of silk and fine-twined linen, and all manner of good homely cloth.
33607	1285	30	And thus, in their prosperous circumstances, they did not send away any who were naked, or that were hungry, or that were athirst, or that were sick, or that had not been nourished; and they did not set their hearts upon riches; therefore they were liberal to all, both old and young, both bond and free, both male and female, whether out of the church or in the church, having no respect to persons as to those who stood in need.
33608	1285	31	And thus they did prosper and become far more wealthy than those who did not belong to their church.
33609	1285	32	For those who did not belong to their church did indulge themselves in sorceries, and in idolatry or idleness, and in babblings, and in envyings and strife; wearing costly apparel; being lifted up in the pride of their own eyes; persecuting, lying, thieving, robbing, committing whoredoms, and murdering, and all manner of wickedness; nevertheless, the law was put in force upon all those who did transgress it, inasmuch as it was possible.
33610	1285	33	And it came to pass that by thus exercising the law upon them, every man suffering according to that which he had done, they became more still, and durst not commit any wickedness if it were known; therefore, there was much peace among the people of Nephi until the fifth year of the reign of the judges.
33611	1286	1	And it came to pass in the commencement of the fifth year of their reign there began to be a contention among the people; for a certain man, being called Amlici, he being a very cunning man, yea, a wise man as to the wisdom of the world, he being after the order of the man that slew Gideon by the sword, who was executed according to the law--
33612	1286	2	Now this Amlici had, by his cunning, drawn away much people after him; even so much that they began to be very powerful; and they began to endeavor to establish Amlici to be a king over the people.
33613	1286	3	Now this was alarming to the people of the church, and also to all those who had not been drawn away after the persuasions of Amlici; for they knew that according to their law that such things must be established by the voice of the people.
33614	1286	4	Therefore, if it were possible that Amlici should gain the voice of the people, he, being a wicked man, would deprive them of their rights and privileges of the church; for it was his intent to destroy the church of God.
33615	1286	5	And it came to pass that the people assembled themselves together throughout all the land, every man according to his mind, whether it were for or against Amlici, in separate bodies, having much dispute and wonderful contentions one with another.
33616	1286	6	And thus they did assemble themselves together to cast in their voices concerning the matter; and they were laid before the judges.
33617	1286	7	And it came to pass that the voice of the people came against Amlici, that he was not made king over the people.
33618	1286	8	Now this did cause much joy in the hearts of those who were against him; but Amlici did stir up those who were in his favor to anger against those who were not in his favor.
33619	1286	9	And it came to pass that they gathered themselves together, and did consecrate Amlici to be their king.
33620	1286	10	Now when Amlici was made king over them he commanded them that they should take up arms against their brethren; and this he did that he might subject them to him.
33621	1286	11	Now the people of Amlici were distinguished by the name of Amlici, being called Amlicites; and the remainder were called Nephites, or the people of God.
33622	1286	12	Therefore the people of the Nephites were aware of the intent of the Amlicites, and therefore they did prepare to meet them; yea, they did arm themselves with swords, and with cimeters, and with bows, and with arrows, and with stones, and with slings, and with all manner of weapons of war, of every kind.
33623	1286	13	And thus they were prepared to meet the Amlicites at the time of their coming. And there were appointed captains, and higher captains, and chief captains, according to their numbers.
33624	1286	14	And it came to pass that Amlici did arm his men with all manner of weapons of war of every kind; and he also appointed rulers and leaders over his people, to lead them to war against their brethren.
33625	1286	15	And it came to pass that the Amlicites came upon the hill Amnihu, which was east of the river Sidon, which ran by the land of Zarahemla, and there they began to make war with the Nephites.
33626	1286	16	Now Alma, being the chief judge and the governor of the people of Nephi, therefore he went up with his people, yea, with his captains, and chief captains, yea, at the head of his armies, against the Amlicites to battle.
33627	1286	17	And they began to slay the Amlicites upon the hill east of Sidon. And the Amlicites did contend with the Nephites with great strength, insomuch that many of the Nephites did fall before the Amlicites.
33628	1286	18	Nevertheless the Lord did strengthen the hand of the Nephites, that they slew the Amlicites with great slaughter, that they began to flee before them.
33629	1286	19	And it came to pass that the Nephites did pursue the Amlicites all that day, and did slay them with much slaughter, insomuch that there were slain of the Amlicites twelve thousand five hundred thirty and two souls; and there were slain of the Nephites six thousand five hundred sixty and two souls.
33630	1286	20	And it came to pass that when Alma could pursue the Amlicites no longer he caused that his people should pitch their tents in the valley of Gideon, the valley being called after that Gideon who was slain by the hand of Nehor with the sword; and in this valley the Nephites did pitch their tents for the night.
33631	1286	21	And Alma sent spies to follow the remnant of the Amlicites, that he might know of their plans and their plots, whereby he might guard himself against them, that he might preserve his people from being destroyed.
33632	1286	22	Now those whom he had sent out to watch the camp of the Amlicites were called Zeram, and Amnor, and Manti, and Limher; these were they who went out with their men to watch the camp of the Amlicites.
33633	1286	23	And it came to pass that on the morrow they returned into the camp of the Nephites in great haste, being greatly astonished, and struck with much fear, saying:
33634	1286	24	Behold, we followed the camp of the Amlicites, and to our great astonishment, in the land of Minon, above the land of Zarahemla, in the course of the land of Nephi, we saw a numerous host of the Lamanites; and behold, the Amlicites have joined them;
33635	1286	25	And they are upon our brethren in that land; and they are fleeing before them with their flocks, and their wives, and their children, towards our city; and except we make haste they obtain possession of our city, and our fathers, and our wives, and our children be slain.
33636	1286	26	And it came to pass that the people of Nephi took their tents, and departed out of the valley of Gideon towards their city, which was the city of Zarahemla.
33637	1286	27	And behold, as they were crossing the river Sidon, the Lamanites and the Amlicites, being as numerous almost, as it were, as the sands of the sea, came upon them to destroy them.
33638	1286	28	Nevertheless, the Nephites being strengthened by the hand of the Lord, having prayed mightily to him that he would deliver them out of the hands of their enemies, therefore the Lord did hear their cries, and did strengthen them, and the Lamanites and the Amlicites did fall before them.
33639	1286	29	And it came to pass that Alma fought with Amlici with the sword, face to face; and they did contend mightily, one with another.
33640	1286	30	And it came to pass that Alma, being a man of God, being exercised with much faith, cried, saying: O Lord, have mercy and spare my life, that I may be an instrument in thy hands to save and preserve this people.
33641	1286	31	Now when Alma had said these words he contended again with Amlici; and he was strengthened, insomuch that he slew Amlici with the sword.
33642	1286	32	And he also contended with the king of the Lamanites; but the king of the Lamanites fled back from before Alma and sent his guards to contend with Alma.
33643	1286	33	But Alma, with his guards, contended with the guards of the king of the Lamanites until he slew and drove them back.
33644	1286	34	And thus he cleared the ground, or rather the bank, which was on the west of the river Sidon, throwing the bodies of the Lamanites who had been slain into the waters of Sidon, that thereby his people might have room to cross and contend with the Lamanites and the Amlicites on the west side of the river Sidon.
33645	1286	35	And it came to pass that when they had all crossed the river Sidon that the Lamanites and the Amlicites began to flee before them, notwithstanding they were so numerous that they could not be numbered.
33646	1286	36	And they fled before the Nephites towards the wilderness which was west and north, away beyond the borders of the land; and the Nephites did pursue them with their might, and did slay them.
33647	1286	37	Yea, they were met on every hand, and slain and driven, until they were scattered on the west, and on the north, until they had reached the wilderness, which was called Hermounts; and it was that part of the wilderness which was infested by wild and ravenous beasts.
33648	1286	38	And it came to pass that many died in the wilderness of their wounds, and were devoured by those beasts and also the vultures of the air; and their bones have been found, and have been heaped up on the earth.
33649	1287	1	And it came to pass that the Nephites who were not slain by the weapons of war, after having buried those who had been slain--now the number of the slain were not numbered, because of the greatness of their number--after they had finished burying their dead they all returned to their lands, and to their houses, and their wives, and their children.
33650	1287	2	Now many women and children had been slain with the sword, and also many of their flocks and their herds; and also many of their fields of grain were destroyed, for they were trodden down by the hosts of men.
33651	1287	3	And now as many of the Lamanites and the Amlicites who had been slain upon the bank of the river Sidon were cast into the waters of Sidon; and behold their bones are in the depths of the sea, and they are many.
33652	1287	4	And the Amlicites were distinguished from the Nephites, for they had marked themselves with red in their foreheads after the manner of the Lamanites; nevertheless they had not shorn their heads like unto the Lamanites.
33653	1287	5	Now the heads of the Lamanites were shorn; and they were naked, save it were skin which was girded about their loins, and also their armor, which was girded about them, and their bows, and their arrows, and their stones, and their slings, and so forth.
33654	1287	6	And the skins of the Lamanites were dark, according to the mark which was set upon their fathers, which was a curse upon them because of their transgression and their rebellion against their brethren, who consisted of Nephi, Jacob, and Joseph, and Sam, who were just and holy men.
33655	1287	7	And their brethren sought to destroy them, therefore they were cursed; and the Lord God set a mark upon them, yea, upon Laman and Lemuel, and also the sons of Ishmael, and Ishmaelitish women.
33656	1287	8	And this was done that their seed might be distinguished from the seed of their brethren, that thereby the Lord God might preserve his people, that they might not mix and believe in incorrect traditions which would prove their destruction.
33657	1287	9	And it came to pass that whosoever did mingle his seed with that of the Lamanites did bring the same curse upon his seed.
33658	1287	10	Therefore, whosoever suffered himself to be led away by the Lamanites was called under that head, and there was a mark set upon him.
33659	1287	11	And it came to pass that whosoever would not believe in the tradition of the Lamanites, but believed those records which were brought out of the land of Jerusalem, and also in the tradition of their fathers, which were correct, who believed in the commandments of God and kept them, were called the Nephites, or the people of Nephi, from that time forth--
33660	1287	12	And it is they who have kept the records which are true of their people, and also of the people of the Lamanites.
33661	1287	13	Now we will return again to the Amlicites, for they also had a mark set upon them; yea, they set the mark upon themselves, yea, even a mark of red upon their foreheads.
33662	1287	14	Thus the word of God is fulfilled, for these are the words which he said to Nephi: Behold, the Lamanites have I cursed, and I will set a mark on them that they and their seed may be separated from thee and thy seed, from this time henceforth and forever, except they repent of their wickedness and turn to me that I may have mercy upon them.
33663	1287	15	And again: I will set a mark upon him that mingleth his seed with thy brethren, that they may be cursed also.
33664	1287	16	And again: I will set a mark upon him that fighteth against thee and thy seed.
33665	1287	17	And again, I say he that departeth from thee shall no more be called thy seed; and I will bless thee, and whomsoever shall be called thy seed, henceforth and forever; and these were the promises of the Lord unto Nephi and to his seed.
33666	1287	18	Now the Amlicites knew not that they were fulfilling the words of God when they began to mark themselves in their foreheads; nevertheless they had come out in open rebellion against God; therefore it was expedient that the curse should fall upon them.
33667	1287	19	Now I would that ye should see that they brought upon themselves the curse; and even so doth every man that is cursed bring upon himself his own condemnation.
33668	1287	20	Now it came to pass that not many days after the battle which was fought in the land of Zarahemla, by the Lamanites and the Amlicites, that there was another army of the Lamanites came in upon the people of Nephi, in the same place where the first army met the Amlicites.
33669	1287	21	And it came to pass that there was an army sent to drive them out of their land.
33670	1287	22	Now Alma himself being afflicted with a wound did not go up to battle at this time against the Lamanites;
33671	1287	23	But he sent up a numerous army against them; and they went up and slew many of the Lamanites, and drove the remainder of them out of the borders of their land.
33672	1287	24	And then they returned again and began to establish peace in the land, being troubled no more for a time with their enemies.
33673	1287	25	Now all these things were done, yea, all these wars and contentions were commenced and ended in the fifth year of the reign of the judges.
33674	1287	26	And in one year were thousands and tens of thousands of souls sent to the eternal world, that they might reap their rewards according to their works, whether they were good or whether they were bad, to reap eternal happiness or eternal misery, according to the spirit which they listed to obey, whether it be a good spirit or a bad one.
33675	1287	27	For every man receiveth wages of him whom he listeth to obey, and this according to the words of the spirit of prophecy; therefore let it be according to the truth. And thus endeth the fifth year of the reign of the judges.
33676	1288	1	Now it came to pass in the sixth year of the reign of the judges over the people of Nephi, there were no contentions nor wars in the land of Zarahemla;
33677	1288	2	But the people were afflicted, yea, greatly afflicted for the loss of their brethren, and also for the loss of their flocks and herds, and also for the loss of their fields of grain, which were trodden under foot and destroyed by the Lamanites.
33678	1288	3	And so great were their afflictions that every soul had cause to mourn; and they believed that it was the judgments of God sent upon them because of their wickedness and their abominations; therefore they were awakened to a remembrance of their duty.
33679	1288	4	And they began to establish the church more fully; yea, and many were baptized in the waters of Sidon and were joined to the church of God; yea, they were baptized by the hand of Alma, who had been consecrated the high priest over the people of the church, by the hand of his father Alma.
33680	1288	5	And it came to pass in the seventh year of the reign of the judges there were about three thousand five hundred souls that united themselves to the church of God and were baptized. And thus ended the seventh year of the reign of the judges over the people of Nephi; and there was continual peace in all that time.
33681	1288	6	And it came to pass in the eighth year of the reign of the judges, that the people of the church began to wax proud, because of their exceeding riches, and their fine silks, and their fine-twined linen, and because of their many flocks and herds, and their gold and their silver, and all manner of precious things, which they had obtained by their industry; and in all these things were they lifted up in the pride of their eyes, for they began to wear very costly apparel.
33682	1288	7	Now this was the cause of much affliction to Alma, yea, and to many of the people whom Alma had consecrated to be teachers, and priests, and elders over the church; yea, many of them were sorely grieved for the wickedness which they saw had begun to be among their people.
33683	1288	8	For they saw and beheld with great sorrow that the people of the church began to be lifted up in the pride of their eyes, and to set their hearts upon riches and upon the vain things of the world, that they began to be scornful, one towards another, and they began to persecute those that did not believe according to their own will and pleasure.
33684	1288	9	And thus, in this eighth year of the reign of the judges, there began to be great contentions among the people of the church; yea, there were envyings, and strife, and malice, and persecutions, and pride, even to exceed the pride of those who did not belong to the church of God.
33685	1288	10	And thus ended the eighth year of the reign of the judges; and the wickedness of the church was a great stumbling-block to those who did not belong to the church; and thus the church began to fail in its progress.
33686	1288	11	And it came to pass in the commencement of the ninth year, Alma saw the wickedness of the church, and he saw also that the example of the church began to lead those who were unbelievers on from one piece of iniquity to another, thus bringing on the destruction of the people.
33687	1288	12	Yea, he saw great inequality among the people, some lifting themselves up with their pride, despising others, turning their backs upon the needy and the naked and those who were hungry, and those who were athirst, and those who were sick and afflicted.
33688	1288	13	Now this was a great cause for lamentations among the people, while others were abasing themselves, succoring those who stood in need of their succor, such as imparting their substance to the poor and the needy, feeding the hungry, and suffering all manner of afflictions, for Christ's sake, who should come according to the spirit of prophecy;
33689	1288	14	Looking forward to that day, thus retaining a remission of their sins; being filled with great joy because of the resurrection of the dead, according to the will and power and deliverance of Jesus Christ from the bands of death.
33690	1288	15	And now it came to pass that Alma, having seen the afflictions of the humble followers of God, and the persecutions which were heaped upon them by the remainder of his people, and seeing all their inequality, began to be very sorrowful; nevertheless the Spirit of the Lord did not fail him.
33691	1288	16	And he selected a wise man who was among the elders of the church, and gave him power according to the voice of the people, that he might have power to enact laws according to the laws which had been given, and to put them in force according to the wickedness and the crimes of the people.
33692	1288	17	Now this man's name was Nephihah, and he was appointed chief judge; and he sat in the judgment-seat to judge and to govern the people.
33693	1288	18	Now Alma did not grant unto him the office of being high priest over the church, but he retained the office of high priest unto himself; but he delivered the judgment-seat unto Nephihah.
33694	1288	19	And this he did that he himself might go forth among his people, or among the people of Nephi, that he might preach the word of God unto them, to stir them up in remembrance of their duty, and that he might pull down, by the word of God, all the pride and craftiness and all the contentions which were among his people, seeing no way that he might reclaim them save it were in bearing down in pure testimony against them.
33695	1288	20	And thus in the commencement of the ninth year of the reign of the judges over the people of Nephi, Alma delivered up the judgment-seat to Nephihah, and confined himself wholly to the high priesthood of the holy order of God, to the testimony of the word, according to the spirit of revelation and prophecy.
33696	1289	1	Now it came to pass that Alma began to deliver the word of God unto the people, first in the land of Zarahemla, and from thence throughout all the land.
33697	1289	2	And these are the words which he spake to the people in the church which was established in the city of Zarahemla, according to his own record, saying:
33698	1289	3	I, Alma, having been consecrated by my father, Alma, to be a high priest over the church of God, he having power and authority from God to do these things, behold, I say unto you that he began to establish a church in the land which was in the borders of Nephi; yea, the land which was called the land of Mormon; yea, and he did baptize his brethren in the waters of Mormon.
33699	1289	4	And behold, I say unto you, they were delivered out of the hands of the people of king Noah, by the mercy and power of God.
33700	1289	5	And behold, after that, they were brought into bondage by the hands of the Lamanites in the wilderness; yea, I say unto you, they were in captivity, and again the Lord did deliver them out of bondage by the power of his word; and we were brought into this land, and here we began to establish the church of God throughout this land also.
33701	1289	6	And now behold, I say unto you, my brethren, you that belong to this church, have you sufficiently retained in remembrance the captivity of your fathers? Yea, and have you sufficiently retained in remembrance his mercy and long-suffering towards them? And moreover, have ye sufficiently retained in remembrance that he has delivered their souls from hell?
33702	1289	7	Behold, he changed their hearts; yea, he awakened them out of a deep sleep, and they awoke unto God. Behold, they were in the midst of darkness; nevertheless, their souls were illuminated by the light of the everlasting word; yea, they were encircled about by the bands of death, and the chains of hell, and an everlasting destruction did await them.
33703	1289	8	And now I ask of you, my brethren, were they destroyed? Behold, I say unto you, Nay, they were not.
33704	1289	9	And again I ask, were the bands of death broken, and the chains of hell which encircled them about, were they loosed? I say unto you, Yea, they were loosed, and their souls did expand, and they did sing redeeming love. And I say unto you that they are saved.
33705	1289	10	And now I ask of you on what conditions are they saved? Yea, what grounds had they to hope for salvation? What is the cause of their being loosed from the bands of death, yea, and also the chains of hell?
33706	1289	11	Behold, I can tell you--did not my father Alma believe in the words which were delivered by the mouth of Abinadi? And was he not a holy prophet? Did he not speak the words of God, and my father Alma believe them?
33707	1289	12	And according to his faith there was a mighty change wrought in his heart. Behold I say unto you that this is all true.
33708	1289	13	And behold, he preached the word unto your fathers, and a mighty change was also wrought in their hearts, and they humbled themselves and put their trust in the true and living God. And behold, they were faithful until the end; therefore they were saved.
33709	1289	14	And now behold, I ask of you, my brethren of the church, have ye spiritually been born of God? Have ye received his image in your countenances? Have ye experienced this mighty change in your hearts?
33710	1289	15	Do ye exercise faith in the redemption of him who created you? Do you look forward with an eye of faith, and view this mortal body raised in immortality, and this corruption raised in incorruption, to stand before God to be judged according to the deeds which have been done in the mortal body?
33711	1289	16	I say unto you, can you imagine to yourselves that ye hear the voice of the Lord, saying unto you, in that day: Come unto me ye blessed, for behold, your works have been the works of righteousness upon the face of the earth?
33712	1289	17	Or do ye imagine to yourselves that ye can lie unto the Lord in that day, and say--Lord, our works have been righteous works upon the face of the earth--and that he will save you?
33713	1289	18	Or otherwise, can ye imagine yourselves brought before the tribunal of God with your souls filled with guilt and remorse, having a remembrance of all your guilt, yea, a perfect remembrance of all your wickedness, yea, a remembrance that ye have set at defiance the commandments of God?
33714	1289	19	I say unto you, can ye look up to God at that day with a pure heart and clean hands? I say unto you, can you look up, having the image of God engraven upon your countenances?
33715	1289	20	I say unto you, can ye think of being saved when you have yielded yourselves to become subjects to the devil?
33716	1289	21	I say unto you, ye will know at that day that ye cannot be saved; for there can no man be saved except his garments are washed white; yea, his garments must be purified until they are cleansed from all stain, through the blood of him of whom it has been spoken by our fathers, who should come to redeem his people from their sins.
33717	1289	22	And now I ask of you, my brethren, how will any of you feel, if ye shall stand before the bar of God, having your garments stained with blood and all manner of filthiness? Behold, what will these things testify against you?
33718	1289	23	Behold will they not testify that ye are murderers, yea, and also that ye are guilty of all manner of wickedness?
33719	1289	24	Behold, my brethren, do ye suppose that such an one can have a place to sit down in the kingdom of God, with Abraham, with Isaac, and with Jacob, and also all the holy prophets, whose garments are cleansed and are spotless, pure and white?
33720	1289	25	I say unto you, Nay; except ye make our Creator a liar from the beginning, or suppose that he is a liar from the beginning, ye cannot suppose that such can have place in the kingdom of heaven; but they shall be cast out for they are the children of the kingdom of the devil.
33721	1289	26	And now behold, I say unto you, my brethren, if ye have experienced a change of heart, and if ye have felt to sing the song of redeeming love, I would ask, can ye feel so now?
33722	1289	27	Have ye walked, keeping yourselves blameless before God? Could ye say, if ye were called to die at this time, within yourselves, that ye have been sufficiently humble? That your garments have been cleansed and made white through the blood of Christ, who will come to redeem his people from their sins?
33723	1289	28	Behold, are ye stripped of pride? I say unto you, if ye are not ye are not prepared to meet God. Behold ye must prepare quickly; for the kingdom of heaven is soon at hand, and such an one hath not eternal life.
33724	1289	29	Behold, I say, is there one among you who is not stripped of envy? I say unto you that such an one is not prepared; and I would that he should prepare quickly, for the hour is close at hand, and he knoweth not when the time shall come; for such an one is not found guiltless.
33725	1289	30	And again I say unto you, is there one among you that doth make a mock of his brother, or that heapeth upon him persecutions?
33726	1289	31	Wo unto such an one, for he is not prepared, and the time is at hand that he must repent or he cannot be saved!
33727	1289	32	Yea, even wo unto all ye workers of iniquity; repent, repent, for the Lord God hath spoken it!
33728	1289	33	Behold, he sendeth an invitation unto all men, for the arms of mercy are extended towards them, and he saith: Repent, and I will receive you.
33729	1289	34	Yea, he saith: Come unto me and ye shall partake of the fruit of the tree of life; yea, ye shall eat and drink of the bread and the waters of life freely;
33730	1289	35	Yea, come unto me and bring forth works of righteousness, and ye shall not be hewn down and cast into the fire--
33731	1289	36	For behold, the time is at hand that whosoever bringeth forth not good fruit, or whosoever doeth not the works of righteousness, the same have cause to wail and mourn.
33732	1289	37	O ye workers of iniquity; ye that are puffed up in the vain things of the world, ye that have professed to have known the ways of righteousness nevertheless have gone astray, as sheep having no shepherd, notwithstanding a shepherd hath called after you and is still calling after you, but ye will not hearken unto his voice!
33733	1289	38	Behold, I say unto you, that the good shepherd doth call you; yea, and in his own name he doth call you, which is the name of Christ; and if ye will not hearken unto the voice of the good shepherd, to the name by which ye are called, behold, ye are not the sheep of the good shepherd.
33734	1289	39	And now if ye are not the sheep of the good shepherd, of what fold are ye? Behold, I say unto you, that the devil is your shepherd, and ye are of his fold; and now, who can deny this? Behold, I say unto you, whosoever denieth this is a liar and a child of the devil.
33735	1289	40	For I say unto you that whatsoever is good cometh from God, and whatsoever is evil cometh from the devil.
33736	1289	41	Therefore, if a man bringeth forth good works he hearkeneth unto the voice of the good shepherd, and he doth follow him; but whosoever bringeth forth evil works, the same becometh a child of the devil, for he hearkeneth unto his voice, and doth follow him.
33737	1289	42	And whosoever doeth this must receive his wages of him; therefore, for his wages he receiveth death, as to things pertaining unto righteousness, being dead unto all good works.
33738	1289	43	And now, my brethren, I would that ye should hear me, for I speak in the energy of my soul; for behold, I have spoken unto you plainly that ye cannot err, or have spoken according to the commandments of God.
33739	1289	44	For I am called to speak after this manner, according to the holy order of God, which is in Christ Jesus; yea, I am commanded to stand and testify unto this people the things which have been spoken by our fathers concerning the things which are to come.
33740	1289	45	And this is not all. Do ye not suppose that I know of these things myself? Behold, I testify unto you that I do know that these things whereof I have spoken are true. And how do ye suppose that I know of their surety?
33741	1289	46	Behold, I say unto you they are made known unto me by the Holy Spirit of God. Behold, I have fasted and prayed many days that I might know these things of myself. And now I do know of myself that they are true; for the Lord God hath made them manifest unto me by his Holy Spirit; and this is the spirit of revelation which is in me.
33742	1289	47	And moreover, I say unto you that it has thus been revealed unto me, that the words which have been spoken by our fathers are true, even so according to the spirit of prophecy which is in me, which is also by the manifestation of the Spirit of God.
33743	1289	48	I say unto you, that I know of myself that whatsoever I shall say unto you, concerning that which is to come, is true; and I say unto you, that I know that Jesus Christ shall come, yea, the Son, the Only Begotten of the Father, full of grace, and mercy, and truth. And behold, it is he that cometh to take away the sins of the world, yea, the sins of every man who steadfastly believeth on his name.
33744	1289	49	And now I say unto you that this is the order after which I am called, yea, to preach unto my beloved brethren, yea, and every one that dwelleth in the land; yea, to preach unto all, both old and young, both bond and free; yea, I say unto you the aged, and also the middle aged, and the rising generation; yea, to cry unto them that they must repent and be born again.
33745	1289	50	Yea, thus saith the Spirit: Repent, all ye ends of the earth, for the kingdom of heaven is soon at hand; yea, the Son of God cometh in his glory, in his might, majesty, power, and dominion. Yea, my beloved brethren, I say unto you, that the Spirit saith: Behold the glory of the King of all the earth; and also the King of heaven shall very soon shine forth among all the children of men.
33746	1289	51	And also the Spirit saith unto me, yea, crieth unto me with a mighty voice, saying: Go forth and say unto this people--Repent, for except ye repent ye can in nowise inherit the kingdom of heaven.
33747	1289	52	And again I say unto you, the Spirit saith: Behold, the ax is laid at the root of the tree; therefore every tree that bringeth not forth good fruit shall be hewn down and cast into the fire, yea, a fire which cannot be consumed, even an unquenchable fire. Behold, and remember, the Holy One hath spoken it.
33748	1289	53	And now my beloved brethren, I say unto you, can ye withstand these sayings; yea, can ye lay aside these things, and trample the Holy One under your feet; yea, can ye be puffed up in the pride of your hearts; yea, will ye still persist in the wearing of costly apparel and setting your hearts upon the vain things of the world, upon your riches?
33749	1289	54	Yea, will ye persist in supposing that ye are better one than another; yea, will ye persist in the persecution of your brethren, who humble themselves and do walk after the holy order of God, wherewith they have been brought into this church, having been sanctified by the Holy Spirit, and they do bring forth works which are meet for repentance--
33750	1289	55	Yea, and will you persist in turning your backs upon the poor, and the needy, and in withholding your substance from them?
33751	1289	56	And finally, all ye that will persist in your wickedness, I say unto you that these are they who shall be hewn down and cast into the fire except they speedily repent.
33752	1289	57	And now I say unto you, all you that are desirous to follow the voice of the good shepherd, come ye out from the wicked, and be ye separate, and touch not their unclean things; and behold, their names shall be blotted out, that the names of the wicked shall not be numbered among the names of the righteous, that the word of God may be fulfilled, which saith: The names of the wicked shall not be mingled with the names of my people;
33753	1289	58	For the names of the righteous shall be written in the book of life, and unto them will I grant an inheritance at my right hand. And now, my brethren, what have ye to say against this? I say unto you, if ye speak against it, it matters not, for the word of God must be fulfilled.
33754	1289	59	For what shepherd is there among you having many sheep doth not watch over them, that the wolves enter not and devour his flock? And behold, if a wolf enter his flock doth he not drive him out? Yea, and at the last, if he can, he will destroy him.
33755	1289	60	And now I say unto you that the good shepherd doth call after you; and if you will hearken unto his voice he will bring you into his fold, and ye are his sheep; and he commandeth you that ye suffer no ravenous wolf to enter among you, that ye may not be destroyed.
33756	1289	61	And now I, Alma, do command you in the language of him who hath commanded me, that ye observe to do the words which I have spoken unto you.
33757	1289	62	I speak by way of command unto you that belong to the church; and unto those who do not belong to the church I speak by way of invitation, saying: Come and be baptized unto repentance, that ye also may be partakers of the fruit of the tree of life.
33758	1290	1	And now it came to pass that after Alma had made an end of speaking unto the people of the church, which was established in the city of Zarahemla, he ordained priests and elders, by laying on his hands according to the order of God, to preside and watch over the church.
33759	1290	2	And it came to pass that whosoever did not belong to the church who repented of their sins were baptized unto repentance, and were received into the church.
33760	1290	3	And it also came to pass that whosoever did belong to the church that did not repent of their wickedness and humble themselves before God--I mean those who were lifted up in the pride of their hearts--the same were rejected, and their names were blotted out, that their names were not numbered among those of the righteous.
33761	1290	4	And thus they began to establish the order of the church in the city of Zarahemla.
33762	1290	5	Now I would that ye should understand that the word of God was liberal unto all, that none were deprived of the privilege of assembling themselves together to hear the word of God.
33763	1290	6	Nevertheless the children of God were commanded that they should gather themselves together oft, and join in fasting and mighty prayer in behalf of the welfare of the souls of those who knew not God.
33764	1290	7	And now it came to pass that when Alma had made these regulations he departed from them, yea, from the church which was in the city of Zarahemla, and went over upon the east of the river Sidon, into the valley of Gideon, there having been a city built, which was called the city of Gideon, which was in the valley that was called Gideon, being called after the man who was slain by the hand of Nehor with the sword.
33765	1290	8	And Alma went and began to declare the word of God unto the church which was established in the valley of Gideon, according to the revelation of the truth of the word which had been spoken by his fathers, and according to the spirit of prophecy which was in him, according to the testimony of Jesus Christ, the Son of God, who should come to redeem his people from their sins, and the holy order by which he was called. And thus it is written. Amen.
33766	1291	1	Behold my beloved brethren, seeing that I have been permitted to come unto you, therefore I attempt to address you in my language; yea, by my own mouth, seeing that it is the first time that I have spoken unto you by the words of my mouth, I having been wholly confined to the judgment-seat, having had much business that I could not come unto you.
33767	1291	2	And even I could not have come now at this time were it not that the judgment-seat hath been given to another, to reign in my stead; and the Lord in much mercy hath granted that I should come unto you.
33768	1291	3	And behold, I have come having great hopes and much desire that I should find that ye had humbled yourselves before God, and that ye had continued in the supplicating of his grace, that I should find that ye were blameless before him, that I should find that ye were not in the awful dilemma that our brethren were in at Zarahemla.
33769	1291	4	But blessed be the name of God, that he hath given me to know, yea, hath given unto me the exceedingly great joy of knowing that they are established again in the way of his righteousness.
33770	1291	5	And I trust, according to the Spirit of God which is in me, that I shall also have joy over you; nevertheless I do not desire that my joy over you should come by the cause of so much afflictions and sorrow which I have had for the brethren at Zarahemla, for behold, my joy cometh over them after wading through much affliction and sorrow.
33771	1291	6	But behold, I trust that ye are not in a state of so much unbelief as were your brethren; I trust that ye are not lifted up in the pride of your hearts; yea, I trust that ye have not set your hearts upon riches and the vain things of the world; yea, I trust that you do not worship idols, but that ye do worship the true and the living God, and that ye look forward for the remission of your sins, with an everlasting faith, which is to come.
33772	1291	7	For behold, I say unto you there be many things to come; and behold, there is one thing which is of more importance than they all--for behold, the time is not far distant that the Redeemer liveth and cometh among his people.
33773	1291	8	Behold, I do not say that he will come among us at the time of his dwelling in his mortal tabernacle; for behold, the Spirit hath not said unto me that this should be the case. Now as to this thing I do not know; but this much I do know, that the Lord God hath power to do all things which are according to his word.
33774	1291	9	But behold, the Spirit hath said this much unto me, saying: Cry unto this people, saying--Repent ye, and prepare the way of the Lord, and walk in his paths, which are straight; for behold, the kingdom of heaven is at hand, and the Son of God cometh upon the face of the earth.
33775	1291	10	And behold, he shall be born of Mary, at Jerusalem which is the land of our forefathers, she being a virgin, a precious and chosen vessel, who shall be overshadowed and conceive by the power of the Holy Ghost, and bring forth a son, yea, even the Son of God.
33776	1291	11	And he shall go forth, suffering pains and afflictions and temptations of every kind; and this that the word might be fulfilled which saith he will take upon him the pains and the sicknesses of his people.
33777	1291	12	And he will take upon him death, that he may loose the bands of death which bind his people; and he will take upon him their infirmities, that his bowels may be filled with mercy, according to the flesh, that he may know according to the flesh how to succor his people according to their infirmities.
33778	1291	13	Now the Spirit knoweth all things; nevertheless the Son of God suffereth according to the flesh that he might take upon him the sins of his people, that he might blot out their transgressions according to the power of his deliverance; and now behold, this is the testimony which is in me.
33779	1291	14	Now I say unto you that ye must repent, and be born again; for the Spirit saith if ye are not born again ye cannot inherit the kingdom of heaven; therefore come and be baptized unto repentance, that ye may be washed from your sins, that ye may have faith on the Lamb of God, who taketh away the sins of the world, who is mighty to save and to cleanse from all unrighteousness.
33780	1291	15	Yea, I say unto you come and fear not, and lay aside every sin, which easily doth beset you, which doth bind you down to destruction, yea, come and go forth, and show unto your God that ye are willing to repent of your sins and enter into a covenant with him to keep his commandments, and witness it unto him this day by going into the waters of baptism.
33781	1291	16	And whosoever doeth this, and keepeth the commandments of God from thenceforth, the same will remember that I say unto him, yea, he will remember that I have said unto him, he shall have eternal life, according to the testimony of the Holy Spirit, which testifieth in me.
33782	1291	17	And now my beloved brethren, do you believe these things? Behold, I say unto you, yea, I know that ye believe them; and the way that I know that ye believe them is by the manifestation of the Spirit which is in me. And now because your faith is strong concerning that, yea, concerning the things which I have spoken, great is my joy.
33783	1291	18	For as I said unto you from the beginning, that I had much desire that ye were not in the state of dilemma like your brethren, even so I have found that my desires have been gratified.
33784	1291	19	For I perceive that ye are in the paths of righteousness; I perceive that ye are in the path which leads to the kingdom of God; yea, I perceive that ye are making his paths straight.
33785	1291	20	I perceive that it has been made known unto you, by the testimony of his word, that he cannot walk in crooked paths; neither doth he vary from that which he hath said; neither hath he a shadow of turning from the right to the left, or from that which is right to that which is wrong; therefore, his course is one eternal round.
33786	1291	21	And he doth not dwell in unholy temples; neither can filthiness or anything which is unclean be received into the kingdom of God; therefore I say unto you the time shall come, yea, and it shall be at the last day, that he who is filthy shall remain in his filthiness.
33787	1291	22	And now my beloved brethren, I have said these things unto you that I might awaken you to a sense of your duty to God, that ye may walk blameless before him, that ye may walk after the holy order of God, after which ye have been received.
33788	1291	23	And now I would that ye should be humble, and be submissive and gentle; easy to be entreated; full of patience and long-suffering; being temperate in all things; being diligent in keeping the commandments of God at all times; asking for whatsoever things ye stand in need, both spiritual and temporal; always returning thanks unto God for whatsoever things ye do receive.
33789	1291	24	And see that ye have faith, hope, and charity, and then ye will always abound in good works.
33790	1291	25	And may the Lord bless you, and keep your garments spotless, that ye may at last be brought to sit down with Abraham, Isaac, and Jacob, and the holy prophets who have been ever since the world began, having your garments spotless even as their garments are spotless, in the kingdom of heaven to go no more out.
33791	1291	26	And now my beloved brethren, I have spoken these words unto you according to the Spirit which testifieth in me; and my soul doth exceedingly rejoice, because of the exceeding diligence and heed which ye have given unto my word.
33792	1291	27	And now, may the peace of God rest upon you, and upon your houses and lands, and upon your flocks and herds, and all that you possess, your women and your children, according to your faith and good works, from this time forth and forever. And thus I have spoken. Amen.
33793	1292	1	And now it came to pass that Alma returned from the land of Gideon, after having taught the people of Gideon many things which cannot be written, having established the order of the church, according as he had before done in the land of Zarahemla, yea, he returned to his own house at Zarahemla to rest himself from the labors which he had performed.
33794	1292	2	And thus ended the ninth year of the reign of the judges over the people of Nephi.
33795	1292	3	And it came to pass in the commencement of the tenth year of the reign of the judges over the people of Nephi, that Alma departed from thence and took his journey over into the land of Melek, on the west of the river Sidon, on the west by the borders of the wilderness.
33796	1292	4	And he began to teach the people in the land of Melek according to the holy order of God, by which he had been called; and he began to teach the people throughout all the land of Melek.
33797	1292	5	And it came to pass that the people came to him throughout all the borders of the land which was by the wilderness side. And they were baptized throughout all the land;
33798	1292	6	So that when he had finished his work at Melek he departed thence, and traveled three days' journey on the north of the land of Melek; and he came to a city which was called Ammonihah.
33799	1292	7	Now it was the custom of the people of Nephi to call their lands, and their cities, and their villages, yea, even all their small villages, after the name of him who first possessed them; and thus it was with the land of Ammonihah.
33800	1292	8	And it came to pass that when Alma had come to the city of Ammonihah he began to preach the word of God unto them.
33801	1292	9	Now Satan had gotten great hold upon the hearts of the people of the city of Ammonihah; therefore they would not hearken unto the words of Alma.
33802	1292	10	Nevertheless Alma labored much in the spirit, wrestling with God in mighty prayer, that he would pour out his Spirit upon the people who were in the city; that he would also grant that he might baptize them unto repentance.
33803	1292	11	Nevertheless, they hardened their hearts, saying unto him: Behold, we know that thou art Alma; and we know that thou art high priest over the church which thou hast established in many parts of the land, according to your tradition; and we are not of thy church, and we do not believe in such foolish traditions.
33804	1292	12	And now we know that because we are not of thy church we know that thou hast no power over us; and thou hast delivered up the judgment-seat unto Nephihah; therefore thou art not the chief judge over us.
33805	1292	13	Now when the people had said this, and withstood all his words, and reviled him, and spit upon him, and caused that he should be cast out of their city, he departed thence and took his journey towards the city which was called Aaron.
33806	1292	14	And it came to pass that while he was journeying thither, being weighed down with sorrow, wading through much tribulation and anguish of soul, because of the wickedness of the people who were in the city of Ammonihah, it came to pass while Alma was thus weighed down with sorrow, behold an angel of the Lord appeared unto him, saying:
33807	1292	15	Blessed art thou, Alma; therefore, lift up thy head and rejoice, for thou hast great cause to rejoice; for thou hast been faithful in keeping the commandments of God from the time which thou receivedst thy first message from him. Behold, I am he that delivered it unto you.
33808	1292	16	And behold, I am sent to command thee that thou return to the city of Ammonihah, and preach again unto the people of the city; yea, preach unto them. Yea, say unto them, except they repent the Lord God will destroy them.
33809	1292	17	For behold, they do study at this time that they may destroy the liberty of thy people, (for thus saith the Lord) which is contrary to the statutes, and judgments, and commandments which he has given unto his people.
33810	1292	18	Now it came to pass that after Alma had received his message from the angel of the Lord he returned speedily to the land of Ammonihah. And he entered the city by another way, yea, by the way which is on the south of the city of Ammonihah.
33811	1292	19	And as he entered the city he was an hungered, and he said to a man: Will ye give to an humble servant of God something to eat?
33812	1292	20	And the man said unto him: I am a Nephite, and I know that thou art a holy prophet of God, for thou art the man whom an angel said in a vision: Thou shalt receive. Therefore, go with me into my house and I will impart unto thee of my food; and I know that thou wilt be a blessing unto me and my house.
33813	1292	21	And it came to pass that the man received him into his house; and the man was called Amulek; and he brought forth bread and meat and set before Alma.
33814	1292	22	And it came to pass that Alma ate bread and was filled; and he blessed Amulek and his house, and he gave thanks unto God.
33815	1292	23	And after he had eaten and was filled he said unto Amulek: I am Alma, and am the high priest over the church of God throughout the land.
33816	1292	24	And behold, I have been called to preach the word of God among all this people, according to the spirit of revelation and prophecy; and I was in this land and they would not receive me, but they cast me out and I was about to set my back towards this land forever.
33817	1292	25	But behold, I have been commanded that I should turn again and prophesy unto this people, yea, and to testify against them concerning their iniquities.
33818	1292	26	And now, Amulek, because thou hast fed me and taken me in, thou art blessed; for I was an hungered, for I had fasted many days.
33819	1292	27	And Alma tarried many days with Amulek before he began to preach unto the people.
33820	1292	28	And it came to pass that the people did wax more gross in their iniquities.
33821	1292	29	And the word came to Alma, saying: Go; and also say unto my servant Amulek, go forth and prophesy unto this people, saying--Repent ye, for thus saith the Lord, except ye repent I will visit this people in mine anger; yea, and I will not turn my fierce anger away.
33822	1292	30	And Alma went forth, and also Amulek, among the people, to declare the words of God unto them; and they were filled with the Holy Ghost.
33823	1292	31	And they had power given unto them, insomuch that they could not be confined in dungeons; neither was it possible that any man could slay them; nevertheless they did not exercise their power until they were bound in bands and cast into prison. Now, this was done that the Lord might show forth his power in them.
33824	1292	32	And it came to pass that they went forth and began to preach and to prophesy unto the people, according to the spirit and power which the Lord had given them.
33825	1293	1	And again, I, Alma, having been commanded of God that I should take Amulek and go forth and preach again unto this people, or the people who were in the city of Ammonihah, it came to pass as I began to preach unto them, they began to contend with me, saying:
33826	1293	2	Who art thou? Suppose ye that we shall believe the testimony of one man, although he should preach unto us that the earth should pass away?
33827	1293	3	Now they understood not the words which they spake; for they knew not that the earth should pass away.
33828	1293	4	And they said also: We will not believe thy words if thou shouldst prophesy that this great city should be destroyed in one day.
33829	1293	5	Now they knew not that God could do such marvelous works, for they were a hard-hearted and a stiffnecked people.
33830	1293	6	And they said: Who is God, that sendeth no more authority than one man among this people, to declare unto them the truth of such great and marvelous things?
33831	1293	7	And they stood forth to lay their hands on me; but behold, they did not. And I stood with boldness to declare unto them, yea, I did boldly testify unto them, saying:
33832	1293	8	Behold, O ye wicked and perverse generation, how have ye forgotten the tradition of your fathers; yea, how soon ye have forgotten the commandments of God.
33833	1293	9	Do ye not remember that our father, Lehi, was brought out of Jerusalem by the hand of God? Do ye not remember that they were all led by him through the wilderness?
33834	1293	10	And have ye forgotten so soon how many times he delivered our fathers out of the hands of their enemies, and preserved them from being destroyed, even by the hands of their own brethren?
33835	1293	11	Yea, and if it had not been for his matchless power, and his mercy, and his long-suffering towards us, we should unavoidably have been cut off from the face of the earth long before this period of time, and perhaps been consigned to a state of endless misery and woe.
33836	1293	12	Behold, now I say unto you that he commandeth you to repent; and except ye repent, ye can in nowise inherit the kingdom of God. But behold, this is not all--he has commanded you to repent, or he will utterly destroy you from off the face of the earth; yea, he will visit you in his anger, and in his fierce anger he will not turn away.
33837	1293	13	Behold, do ye not remember the words which he spake unto Lehi, saying that: Inasmuch as ye shall keep my commandments, ye shall prosper in the land? And again it is said that: Inasmuch as ye will not keep my commandments ye shall be cut off from the presence of the Lord.
33838	1293	14	Now I would that ye should remember, that inasmuch as the Lamanites have not kept the commandments of God, they have been cut off from the presence of the Lord. Now we see that the word of the Lord has been verified in this thing, and the Lamanites have been cut off from his presence, from the beginning of their transgressions in the land.
33839	1293	15	Nevertheless I say unto you, that it shall be more tolerable for them in the day of judgment than for you, if ye remain in your sins, yea, and even more tolerable for them in this life than for you, except ye repent.
33840	1293	16	For there are many promises which are extended to the Lamanites; for it is because of the traditions of their fathers that caused them to remain in their state of ignorance; therefore the Lord will be merciful unto them and prolong their existence in the land.
33841	1293	17	And at some period of time they will be brought to believe in his word, and to know of the incorrectness of the traditions of their fathers; and many of them will be saved, for the Lord will be merciful unto all who call on his name.
33842	1293	18	But behold, I say unto you that if ye persist in your wickedness that your days shall not be prolonged in the land, for the Lamanites shall be sent upon you; and if ye repent not they shall come in a time when you know not, and ye shall be visited with utter destruction; and it shall be according to the fierce anger of the Lord.
33843	1293	19	For he will not suffer you that ye shall live in your iniquities, to destroy his people. I say unto you, Nay; he would rather suffer that the Lamanites might destroy all his people who are called the people of Nephi, if it were possible that they could fall into sins and transgressions, after having had so much light and so much knowledge given unto them of the Lord their God;
33844	1293	20	Yea, after having been such a highly favored people of the Lord; yea, after having been favored above every other nation, kindred, tongue, or people; after having had all things made known unto them, according to their desires, and their faith, and prayers, of that which has been, and which is, and which is to come;
33845	1293	21	Having been visited by the Spirit of God; having conversed with angels, and having been spoken unto by the voice of the Lord; and having the spirit of prophecy, and the spirit of revelation, and also many gifts, the gift of speaking with tongues, and the gift of preaching, and the gift of the Holy Ghost, and the gift of translation;
33846	1293	22	Yea, and after having been delivered of God out of the land of Jerusalem, by the hand of the Lord; having been saved from famine, and from sickness, and all manner of diseases of every kind; and they having waxed strong in battle, that they might not be destroyed; having been brought out of bondage time after time, and having been kept and preserved until now; and they have been prospered until they are rich in all manner of things--
33847	1293	23	And now behold I say unto you, that if this people, who have received so many blessings from the hand of the Lord, should transgress contrary to the light and knowledge which they do have, I say unto you that if this be the case, that if they should fall into transgression, it would be far more tolerable for the Lamanites than for them.
33848	1293	24	For behold, the promises of the Lord are extended to the Lamanites, but they are not unto you if ye transgress; for has not the Lord expressly promised and firmly decreed, that if ye will rebel against him that ye shall utterly be destroyed from off the face of the earth?
33849	1293	25	And now for this cause, that ye may not be destroyed, the Lord has sent his angel to visit many of his people, declaring unto them that they must go forth and cry mightily unto this people, saying: Repent ye, for the kingdom of heaven is nigh at hand;
33850	1293	26	And not many days hence the Son of God shall come in his glory; and his glory shall be the glory of the Only Begotten of the Father, full of grace, equity, and truth, full of patience, mercy, and long-suffering, quick to hear the cries of his people and to answer their prayers.
33851	1293	27	And behold, he cometh to redeem those who will be baptized unto repentance, through faith on his name.
33852	1293	28	Therefore, prepare ye the way of the Lord, for the time is at hand that all men shall reap a reward of their works, according to that which they have been--if they have been righteous they shall reap the salvation of their souls, according to the power and deliverance of Jesus Christ; and if they have been evil they shall reap the damnation of their souls, according to the power and captivation of the devil.
33853	1293	29	Now behold, this is the voice of the angel, crying unto the people.
33854	1293	30	And now, my beloved brethren, for ye are my brethren, and ye ought to be beloved, and ye ought to bring forth works which are meet for repentance, seeing that your hearts have been grossly hardened against the word of God, and seeing that ye are a lost and a fallen people.
33855	1293	31	Now it came to pass that when I, Alma, had spoken these words, behold, the people were wroth with me because I said unto them that they were a hard-hearted and a stiffnecked people.
33856	1293	32	And also because I said unto them that they were a lost and a fallen people they were angry with me, and sought to lay their hands upon me, that they might cast me into prison.
33857	1293	33	But it came to pass that the Lord did not suffer them that they should take me at that time and cast me into prison.
33858	1293	34	And it came to pass that Amulek went and stood forth, and began to preach unto them also. And now the words of Amulek are not all written, nevertheless a part of his words are written in this book.
33859	1294	1	Now these are the words which Amulek preached unto the people who were in the land of Ammonihah, saying:
33860	1294	2	I am Amulek; I am the son of Giddonah, who was the son of Ishmael, who was a descendant of Aminadi; and it was the same Aminadi who interpreted the writing which was upon the wall of the temple, which was written by the finger of God.
33861	1294	3	And Aminadi was a descendant of Nephi, who was the son of Lehi, who came out of the land of Jerusalem, who was a descendant of Manasseh, who was the son of Joseph who was sold into Egypt by the hands of his brethren.
33862	1294	4	And behold, I am also a man of no small reputation among all those who know me; yea, and behold, I have many kindreds and friends, and I have also acquired much riches by the hand of my industry.
33863	1294	5	Nevertheless, after all this, I never have known much of the ways of the Lord, and his mysteries and marvelous power. I said I never had known much of these things; but behold, I mistake, for I have seen much of his mysteries and his marvelous power; yea, even in the preservation of the lives of this people.
33864	1294	6	Nevertheless, I did harden my heart, for I was called many times and I would not hear; therefore I knew concerning these things, yet I would not know; therefore I went on rebelling against God, in the wickedness of my heart, even until the fourth day of this seventh month, which is in the tenth year of the reign of the judges.
33865	1294	7	As I was journeying to see a very near kindred, behold an angel of the Lord appeared unto me and said: Amulek, return to thine own house, for thou shalt feed a prophet of the Lord; yea, a holy man, who is a chosen man of God; for he has fasted many days because of the sins of this people, and he is an hungered, and thou shalt receive him into thy house and feed him, and he shall bless thee and thy house; and the blessing of the Lord shall rest upon thee and thy house.
33866	1294	8	And it came to pass that I obeyed the voice of the angel, and returned towards my house. And as I was going thither I found the man whom the angel said unto me: Thou shalt receive into thy house--and behold it was this same man who has been speaking unto you concerning the things of God.
33867	1294	9	And the angel said unto me he is a holy man; wherefore I know he is a holy man because it was said by an angel of God.
33868	1294	10	And again, I know that the things whereof he hath testified are true; for behold I say unto you, that as the Lord liveth, even so has he sent his angel to make these things manifest unto me; and this he has done while this Alma hath dwelt at my house.
33869	1294	11	For behold, he hath blessed mine house, he hath blessed me, and my women, and my children, and my father and my kinsfolk; yea, even all my kindred hath he blessed, and the blessing of the Lord hath rested upon us according to the words which he spake.
33870	1294	12	And now, when Amulek had spoken these words the people began to be astonished, seeing there was more than one witness who testified of the things whereof they were accused, and also of the things which were to come, according to the spirit of prophecy which was in them.
33871	1294	13	Nevertheless, there were some among them who thought to question them, that by their cunning devices they might catch them in their words, that they might find witness against them, that they might deliver them to their judges that they might be judged according to the law, and that they might be slain or cast into prison, according to the crime which they could make appear or witness against them.
33872	1294	14	Now it was those men who sought to destroy them, who were lawyers, who were hired or appointed by the people to administer the law at their times of trials, or at the trials of the crimes of the people before the judges.
33873	1294	15	Now these lawyers were learned in all the arts and cunning of the people; and this was to enable them that they might be skilful in their profession.
33874	1294	16	And it came to pass that they began to question Amulek, that thereby they might make him cross his words, or contradict the words which he should speak.
33875	1294	17	Now they knew not that Amulek could know of their designs. But it came to pass as they began to question him, he perceived their thoughts, and he said unto them: O ye wicked and perverse generation, ye lawyers and hypocrites, for ye are laying the foundations of the devil; for ye are laying traps and snares to catch the holy ones of God.
33876	1294	18	Ye are laying plans to pervert the ways of the righteous, and to bring down the wrath of God upon your heads, even to the utter destruction of this people.
33877	1294	19	Yea, well did Mosiah say, who was our last king, when he was about to deliver up the kingdom, having no one to confer it upon, causing that this people should be governed by their own voices--yea, well did he say that if the time should come that the voice of this people should choose iniquity, that is, if the time should come that this people should fall into transgression, they would be ripe for destruction.
33878	1294	20	And now I say unto you that well doth the Lord judge of your iniquities; well doth he cry unto this people, by the voice of his angels: Repent ye, repent, for the kingdom of heaven is at hand.
33879	1294	21	Yea, well doth he cry, by the voice of his angels that: I will come down among my people, with equity and justice in my hands.
33880	1294	22	Yea, and I say unto you that if it were not for the prayers of the righteous, who are now in the land, that ye would even now be visited with utter destruction; yet it would not be by flood, as were the people in the days of Noah, but it would be by famine, and by pestilence, and the sword.
33881	1294	23	But it is by the prayers of the righteous that ye are spared; now therefore, if ye will cast out the righteous from among you then will not the Lord stay his hand; but in his fierce anger he will come out against you; then ye shall be smitten by famine, and by pestilence, and by the sword; and the time is soon at hand except ye repent.
33882	1294	24	And now it came to pass that the people were more angry with Amulek, and they cried out, saying: This man doth revile against our laws which are just, and our wise lawyers whom we have selected.
33883	1294	25	But Amulek stretched forth his hand, and cried the mightier unto them, saying: O ye wicked and perverse generation, why hath Satan got such great hold upon your hearts? Why will ye yield yourselves unto him that he may have power over you, to blind your eyes, that ye will not understand the words which are spoken, according to their truth?
33884	1294	26	For behold, have I testified against your law? Ye do not understand; ye say that I have spoken against your law; but I have not, but I have spoken in favor of your law, to your condemnation.
33885	1294	27	And now behold, I say unto you, that the foundation of the destruction of this people is beginning to be laid by the unrighteousness of your lawyers and your judges.
33886	1294	28	And now it came to pass that when Amulek had spoken these words the people cried out against him, saying: Now we know that this man is a child of the devil, for he hath lied unto us; for he hath spoken against our law. And now he says that he has not spoken against it.
33887	1294	29	And again, he has reviled against our lawyers, and our judges.
33888	1294	30	And it came to pass that the lawyers put it into their hearts that they should remember these things against him.
33889	1294	31	And there was one among them whose name was Zeezrom. Now he was the foremost to accuse Amulek and Alma, he being one of the most expert among them, having much business to do among the people.
33890	1294	32	Now the object of these lawyers was to get gain; and they got gain according to their employ.
33891	1295	1	Now it was in the law of Mosiah that every man who was a judge of the law, or those who were appointed to be judges, should receive wages according to the time which they labored to judge those who were brought before them to be judged.
33892	1295	2	Now if a man owed another, and he would not pay that which he did owe, he was complained of to the judge; and the judge executed authority, and sent forth officers that the man should be brought before him; and he judged the man according to the law and the evidences which were brought against him, and thus the man was compelled to pay that which he owed, or be stripped, or be cast out from among the people as a thief and a robber.
33893	1295	3	And the judge received for his wages according to his time--a senine of gold for a day, or a senum of silver, which is equal to a senine of gold; and this is according to the law which was given.
33894	1295	4	Now these are the names of the different pieces of their gold, and of their silver, according to their value. And the names are given by the Nephites, for they did not reckon after the manner of the Jews who were at Jerusalem; neither did they measure after the manner of the Jews; but they altered their reckoning and their measure, according to the minds and the circumstances of the people, in every generation, until the reign of the judges, they having been established by king Mosiah.
33895	1295	5	Now the reckoning is thus--a senine of gold, a seon of gold, a shum of gold, and a limnah of gold.
33896	1295	6	A senum of silver, an amnor of silver, an ezrom of silver, and an onti of silver.
33897	1295	7	A senum of silver was equal to a senine of gold, and either for a measure of barley, and also for a measure of every kind of grain.
33898	1295	8	Now the amount of a seon of gold was twice the value of a senine.
33899	1295	9	And a shum of gold was twice the value of a seon.
33900	1295	10	And a limnah of gold was the value of them all.
33901	1295	11	And an amnor of silver was as great as two senums.
33902	1295	12	And an ezrom of silver was as great as four senums.
33903	1295	13	And an onti was as great as them all.
33904	1295	14	Now this is the value of the lesser numbers of their reckoning--
33905	1295	15	A shiblon is half of a senum; therefore, a shiblon for half a measure of barley.
33906	1295	16	And a shiblum is a half of a shiblon.
33907	1295	17	And a leah is the half of a shiblum.
33908	1295	18	Now this is their number, according to their reckoning.
33909	1295	19	Now an antion of gold is equal to three shiblons.
33910	1295	20	Now, it was for the sole purpose to get gain, because they received their wages according to their employ, therefore, they did stir up the people to riotings, and all manner of disturbances and wickedness, that they might have more employ, that they might get money according to the suits which were brought before them; therefore they did stir up the people against Alma and Amulek.
33911	1295	21	And this Zeezrom began to question Amulek, saying: Will ye answer me a few questions which I shall ask you? Now Zeezrom was a man who was expert in the devices of the devil, that he might destroy that which was good; therefore, he said unto Amulek: Will ye answer the questions which I shall put unto you?
33912	1295	22	And Amulek said unto him: Yea, if it be according to the Spirit of the Lord, which is in me; for I shall say nothing which is contrary to the Spirit of the Lord. And Zeezrom said unto him: Behold, here are six onties of silver, and all these will I give thee if thou wilt deny the existence of a Supreme Being.
33913	1295	23	Now Amulek said: O thou child of hell, why tempt ye me? Knowest thou that the righteous yieldeth to no such temptations?
33914	1295	24	Believest thou that there is no God? I say unto you, Nay, thou knowest that there is a God, but thou lovest that lucre more than him.
33915	1295	25	And now thou hast lied before God unto me. Thou saidst unto me--Behold these six onties, which are of great worth, I will give unto thee--when thou hadst it in thy heart to retain them from me; and it was only thy desire that I should deny the true and living God, that thou mightest have cause to destroy me. And now behold, for this great evil thou shalt have thy reward.
33916	1295	26	And Zeezrom said unto him: Thou sayest there is a true and living God?
33917	1295	27	And Amulek said: Yea, there is a true and living God.
33918	1295	28	Now Zeezrom said: Is there more than one God?
33919	1295	29	And he answered, No.
33920	1295	30	Now Zeezrom said unto him again: How knowest thou these things?
33921	1295	31	And he said: An angel hath made them known unto me.
33922	1295	32	And Zeezrom said again: Who is he that shall come? Is it the Son of God?
33923	1295	33	And he said unto him, Yea.
33924	1295	34	And Zeezrom said again: Shall he save his people in their sins? And Amulek answered and said unto him: I say unto you he shall not, for it is impossible for him to deny his word.
33925	1295	35	Now Zeezrom said unto the people: See that ye remember these things; for he said there is but one God; yet he saith that the Son of God shall come, but he shall not save his people--as though he had authority to command God.
33926	1295	36	Now Amulek saith again unto him: Behold thou hast lied, for thou sayest that I spake as though I had authority to command God because I said he shall not save his people in their sins.
33927	1295	37	And I say unto you again that he cannot save them in their sins; for I cannot deny his word, and he hath said that no unclean thing can inherit the kingdom of heaven; therefore, how can ye be saved, except ye inherit the kingdom of heaven? Therefore, ye cannot be saved in your sins.
33928	1295	38	Now Zeezrom saith again unto him: Is the Son of God the very Eternal Father?
33929	1295	39	And Amulek said unto him: Yea, he is the very Eternal Father of heaven and of earth, and all things which in them are; he is the beginning and the end, the first and the last;
33930	1295	40	And he shall come into the world to redeem his people; and he shall take upon him the transgressions of those who believe on his name; and these are they that shall have eternal life, and salvation cometh to none else.
33931	1295	41	Therefore the wicked remain as though there had been no redemption made, except it be the loosing of the bands of death; for behold, the day cometh that all shall rise from the dead and stand before God, and be judged according to their works.
33932	1295	42	Now, there is a death which is called a temporal death; and the death of Christ shall loose the bands of this temporal death, that all shall be raised from this temporal death.
33933	1295	43	The spirit and the body shall be reunited again in its perfect form; both limb and joint shall be restored to its proper frame, even as we now are at this time; and we shall be brought to stand before God, knowing even as we know now, and have a bright recollection of all our guilt.
33934	1295	44	Now, this restoration shall come to all, both old and young, both bond and free, both male and female, both the wicked and the righteous; and even there shall not so much as a hair of their heads be lost; but every thing shall be restored to its perfect frame, as it is now, or in the body, and shall be brought and be arraigned before the bar of Christ the Son, and God the Father, and the Holy Spirit, which is one Eternal God, to be judged according to their works, whether they be good or whether they be evil.
33935	1295	45	Now, behold, I have spoken unto you concerning the death of the mortal body, and also concerning the resurrection of the mortal body. I say unto you that this mortal body is raised to an immortal body, that is from death, even from the first death unto life, that they can die no more; their spirits uniting with their bodies, never to be divided; thus the whole becoming spiritual and immortal, that they can no more see corruption.
33936	1295	46	Now, when Amulek had finished these words the people began again to be astonished, and also Zeezrom began to tremble. And thus ended the words of Amulek, or this is all that I have written.
33937	1296	1	Now Alma, seeing that the words of Amulek had silenced Zeezrom, for he beheld that Amulek had caught him in his lying and deceiving to destroy him, and seeing that he began to tremble under a consciousness of his guilt, he opened his mouth and began to speak unto him, and to establish the words of Amulek, and to explain things beyond, or to unfold the scriptures beyond that which Amulek had done.
33938	1296	2	Now the words that Alma spake unto Zeezrom were heard by the people round about; for the multitude was great, and he spake on this wise:
33939	1296	3	Now Zeezrom, seeing that thou hast been taken in thy lying and craftiness, for thou hast not lied unto men only but thou hast lied unto God; for behold, he knows all thy thoughts, and thou seest that thy thoughts are made known unto us by his Spirit;
33940	1296	4	And thou seest that we know that thy plan was a very subtle plan, as to the subtlety of the devil, for to lie and to deceive this people that thou mightest set them against us, to revile us and to cast us out--
33941	1296	5	Now this was a plan of thine adversary, and he hath exercised his power in thee. Now I would that ye should remember that what I say unto thee I say unto all.
33942	1296	6	And behold I say unto you all that this was a snare of the adversary, which he has laid to catch this people, that he might bring you into subjection unto him, that he might encircle you about with his chains, that he might chain you down to everlasting destruction, according to the power of his captivity.
33943	1296	7	Now when Alma had spoken these words, Zeezrom began to tremble more exceedingly, for he was convinced more and more of the power of God; and he was also convinced that Alma and Amulek had a knowledge of him, for he was convinced that they knew the thoughts and intents of his heart; for power was given unto them that they might know of these things according to the spirit of prophecy.
33944	1296	8	And Zeezrom began to inquire of them diligently, that he might know more concerning the kingdom of God. And he said unto Alma: What does this mean which Amulek hath spoken concerning the resurrection of the dead, that all shall rise from the dead, both the just and the unjust, and are brought to stand before God to be judged according to their works?
33945	1296	9	And now Alma began to expound these things unto him, saying: It is given unto many to know the mysteries of God; nevertheless they are laid under a strict command that they shall not impart only according to the portion of his word which he doth grant unto the children of men, according to the heed and diligence which they give unto him.
33946	1296	10	And therefore, he that will harden his heart, the same receiveth the lesser portion of the word; and he that will not harden his heart, to him is given the greater portion of the word, until it is given unto him to know the mysteries of God until he know them in full.
33947	1296	11	And they that will harden their hearts, to them is given the lesser portion of the word until they know nothing concerning his mysteries; and then they are taken captive by the devil, and led by his will down to destruction. Now this is what is meant by the chains of hell.
33948	1296	12	And Amulek hath spoken plainly concerning death, and being raised from this mortality to a state of immortality, and being brought before the bar of God, to be judged according to our works.
33949	1296	13	Then if our hearts have been hardened, yea, if we have hardened our hearts against the word, insomuch that it has not been found in us, then will our state be awful, for then we shall be condemned.
33950	1296	14	For our words will condemn us, yea, all our works will condemn us; we shall not be found spotless; and our thoughts will also condemn us; and in this awful state we shall not dare to look up to our God; and we would fain be glad if we could command the rocks and the mountains to fall upon us to hide us from his presence.
33951	1296	15	But this cannot be; we must come forth and stand before him in his glory, and in his power, and in his might, majesty, and dominion, and acknowledge to our everlasting shame that all his judgments are just; that he is just in all his works, and that he is merciful unto the children of men, and that he has all power to save every man that believeth on his name and bringeth forth fruit meet for repentance.
33952	1296	16	And now behold, I say unto you then cometh a death, even a second death, which is a spiritual death; then is a time that whosoever dieth in his sins, as to a temporal death, shall also die a spiritual death; yea, he shall die as to things pertaining unto righteousness.
33953	1296	17	Then is the time when their torments shall be as a lake of fire and brimstone, whose flame ascendeth up forever and ever; and then is the time that they shall be chained down to an everlasting destruction, according to the power and captivity of Satan, he having subjected them according to his will.
33954	1296	18	Then, I say unto you, they shall be as though there had been no redemption made; for they cannot be redeemed according to God's justice; and they cannot die, seeing there is no more corruption.
33955	1296	19	Now it came to pass that when Alma had made an end of speaking these words, the people began to be more astonished;
33956	1296	20	But there was one Antionah, who was a chief ruler among them, came forth and said unto him: What is this that thou hast said, that man should rise from the dead and be changed from this mortal to an immortal state that the soul can never die?
33957	1296	21	What does the scripture mean, which saith that God placed cherubim and a flaming sword on the east of the garden of Eden, lest our first parents should enter and partake of the fruit of the tree of life, and live forever? And thus we see that there was no possible chance that they should live forever.
33958	1296	22	Now Alma said unto him: This is the thing which I was about to explain. Now we see that Adam did fall by the partaking of the forbidden fruit, according to the word of God; and thus we see, that by his fall, all mankind became a lost and fallen people.
33959	1296	23	And now behold, I say unto you that if it had been possible for Adam to have partaken of the fruit of the tree of life at that time, there would have been no death, and the word would have been void, making God a liar, for he said: If thou eat thou shalt surely die.
33960	1296	24	And we see that death comes upon mankind, yea, the death which has been spoken of by Amulek, which is the temporal death; nevertheless there was a space granted unto man in which he might repent; therefore this life became a probationary state; a time to prepare to meet God; a time to prepare for that endless state which has been spoken of by us, which is after the resurrection of the dead.
33961	1296	25	Now, if it had not been for the plan of redemption, which was laid from the foundation of the world, there could have been no resurrection of the dead; but there was a plan of redemption laid, which shall bring to pass the resurrection of the dead, of which has been spoken.
33962	1296	26	And now behold, if it were possible that our first parents could have gone forth and partaken of the tree of life they would have been forever miserable, having no preparatory state; and thus the plan of redemption would have been frustrated, and the word of God would have been void, taking none effect.
33963	1296	27	But behold, it was not so; but it was appointed unto men that they must die; and after death, they must come to judgment, even that same judgment of which we have spoken, which is the end.
33964	1296	28	And after God had appointed that these things should come unto man, behold, then he saw that it was expedient that man should know concerning the things whereof he had appointed unto them;
33965	1296	29	Therefore he sent angels to converse with them, who caused men to behold of his glory.
33966	1296	30	And they began from that time forth to call on his name; therefore God conversed with men, and made known unto them the plan of redemption, which had been prepared from the foundation of the world; and this he made known unto them according to their faith and repentance and their holy works.
33967	1296	31	Wherefore, he gave commandments unto men, they having first transgressed the first commandments as to things which were temporal, and becoming as Gods, knowing good from evil, placing themselves in a state to act, or being placed in a state to act according to their wills and pleasures, whether to do evil or to do good--
33968	1296	32	Therefore God gave unto them commandments, after having made known unto them the plan of redemption, that they should not do evil, the penalty thereof being a second death, which was an everlasting death as to things pertaining unto righteousness; for on such the plan of redemption could have no power, for the works of justice could not be destroyed, according to the supreme goodness of God.
33969	1296	33	But God did call on men, in the name of his Son, (this being the plan of redemption which was laid) saying: If ye will repent and harden not your hearts, then will I have mercy upon you, through mine Only Begotten Son;
33970	1296	34	Therefore, whosoever repenteth, and hardeneth not his heart, he shall have claim on mercy through mine Only Begotten Son, unto a remission of his sins; and these shall enter into my rest.
33971	1296	35	And whosoever will harden his heart and will do iniquity, behold, I swear in my wrath that he shall not enter into my rest.
33972	1296	36	And now, my brethren, behold I say unto you, that if ye will harden your hearts ye shall not enter into the rest of the Lord; therefore your iniquity provoketh him that he sendeth down his wrath upon you as in the first provocation, yea, according to his word in the last provocation as well as the first, to the everlasting destruction of your souls; therefore, according to his word, unto the last death, as well as the first.
33973	1296	37	And now, my brethren, seeing we know these things, and they are true, let us repent, and harden not our hearts, that we provoke not the Lord our God to pull down his wrath upon us in these his second commandments which he has given unto us; but let us enter into the rest of God, which is prepared according to his word.
33974	1297	1	And again, my brethren, I would cite your minds forward to the time when the Lord God gave these commandments unto his children; and I would that ye should remember that the Lord God ordained priests, after his holy order, which was after the order of his Son, to teach these things unto the people.
33975	1297	2	And those priests were ordained after the order of his Son, in a manner that thereby the people might know in what manner to look forward to his Son for redemption.
33976	1297	3	And this is the manner after which they were ordained--being called and prepared from the foundation of the world according to the foreknowledge of God, on account of their exceeding faith and good works; in the first place being left to choose good or evil; therefore they having chosen good, and exercising exceedingly great faith, are called with a holy calling, yea, with that holy calling which was prepared with, and according to, a preparatory redemption for such.
33977	1297	4	And thus they have been called to this holy calling on account of their faith, while others would reject the Spirit of God on account of the hardness of their hearts and blindness of their minds, while, if it had not been for this they might have had as great privilege as their brethren.
33978	1297	5	Or in fine, in the first place they were on the same standing with their brethren; thus this holy calling being prepared from the foundation of the world for such as would not harden their hearts, being in and through the atonement of the Only Begotten Son, who was prepared--
33979	1297	6	And thus being called by this holy calling, and ordained unto the high priesthood of the holy order of God, to teach his commandments unto the children of men, that they also might enter into his rest--
33980	1297	7	This high priesthood being after the order of his Son, which order was from the foundation of the world; or in other words, being without beginning of days or end of years, being prepared from eternity to all eternity, according to his foreknowledge of all things--
33981	1297	8	Now they were ordained after this manner--being called with a holy calling, and ordained with a holy ordinance, and taking upon them the high priesthood of the holy order, which calling, and ordinance, and high priesthood, is without beginning or end--
33982	1297	9	Thus they become high priests forever, after the order of the Son, the Only Begotten of the Father, who is without beginning of days or end of years, who is full of grace, equity, and truth. And thus it is. Amen.
33983	1297	10	Now, as I said concerning the holy order, or this high priesthood, there were many who were ordained and became high priests of God; and it was on account of their exceeding faith and repentance, and their righteousness before God, they choosing to repent and work righteousness rather than to perish;
33984	1297	11	Therefore they were called after this holy order, and were sanctified, and their garments were washed white through the blood of the Lamb.
33985	1297	12	Now they, after being sanctified by the Holy Ghost, having their garments made white, being pure and spotless before God, could not look upon sin save it were with abhorrence; and there were many, exceedingly great many, who were made pure and entered into the rest of the Lord their God.
33986	1297	13	And now, my brethren, I would that ye should humble yourselves before God, and bring forth fruit meet for repentance, that ye may also enter into that rest.
33987	1297	14	Yea, humble yourselves even as the people in the days of Melchizedek, who was also a high priest after this same order which I have spoken, who also took upon him the high priesthood forever.
33988	1297	15	And it was this same Melchizedek to whom Abraham paid tithes; yea, even our father Abraham paid tithes of one-tenth part of all he possessed.
33989	1297	16	Now these ordinances were given after this manner, that thereby the people might look forward on the Son of God, it being a type of his order, or it being his order, and this that they might look forward to him for a remission of their sins, that they might enter into the rest of the Lord.
33990	1297	17	Now this Melchizedek was a king over the land of Salem; and his people had waxed strong in iniquity and abomination; yea, they had all gone astray; they were full of all manner of wickedness;
33991	1297	18	But Melchizedek having exercised mighty faith, and received the office of the high priesthood according to the holy order of God, did preach repentance unto his people. And behold, they did repent; and Melchizedek did establish peace in the land in his days; therefore he was called the prince of peace, for he was the king of Salem; and he did reign under his father.
33992	1297	19	Now, there were many before him, and also there were many afterwards, but none were greater; therefore, of him they have more particularly made mention.
33993	1297	20	Now I need not rehearse the matter; what I have said may suffice. Behold, the scriptures are before you; if ye will wrest them it shall be to your own destruction.
33994	1297	21	And now it came to pass that when Alma had said these words unto them, he stretched forth his hand unto them and cried with a mighty voice, saying: Now is the time to repent, for the day of salvation draweth nigh;
33995	1297	22	Yea, and the voice of the Lord, by the mouth of angels, doth declare it unto all nations; yea, doth declare it, that they may have glad tidings of great joy; yea, and he doth sound these glad tidings among all his people, yea, even to them that are scattered abroad upon the face of the earth; wherefore they have come unto us.
33996	1297	23	And they are made known unto us in plain terms, that we may understand, that we cannot err; and this because of our being wanderers in a strange land; therefore, we are thus highly favored, for we have these glad tidings declared unto us in all parts of our vineyard.
33997	1297	24	For behold, angels are declaring it unto many at this time in our land; and this is for the purpose of preparing the hearts of the children of men to receive his word at the time of his coming in his glory.
33998	1297	25	And now we only wait to hear the joyful news declared unto us by the mouth of angels, of his coming; for the time cometh, we know not how soon. Would to God that it might be in my day; but let it be sooner or later, in it I will rejoice.
33999	1297	26	And it shall be made known unto just and holy men, by the mouth of angels, at the time of his coming, that the words of our fathers may be fulfilled, according to that which they have spoken concerning him, which was according to the spirit of prophecy which was in them.
34000	1297	27	And now, my brethren, I wish from the inmost part of my heart, yea, with great anxiety even unto pain, that ye would hearken unto my words, and cast off your sins, and not procrastinate the day of your repentance;
34001	1297	28	But that ye would humble yourselves before the Lord, and call on his holy name, and watch and pray continually, that ye may not be tempted above that which ye can bear, and thus be led by the Holy Spirit, becoming humble, meek, submissive, patient, full of love and all long-suffering;
34002	1297	29	Having faith on the Lord; having a hope that ye shall receive eternal life; having the love of God always in your hearts, that ye may be lifted up at the last day and enter into his rest.
34003	1297	30	And may the Lord grant unto you repentance, that ye may not bring down his wrath upon you, that ye may not be bound down by the chains of hell, that ye may not suffer the second death.
34004	1297	31	And Alma spake many more words unto the people, which are not written in this book.
34005	1298	1	And it came to pass after he had made an end of speaking unto the people many of them did believe on his words, and began to repent, and to search the scriptures.
34006	1298	2	But the more part of them were desirous that they might destroy Alma and Amulek; for they were angry with Alma, because of the plainness of his words unto Zeezrom; and they also said that Amulek had lied unto them, and had reviled against their law and also against their lawyers and judges.
34007	1298	3	And they were also angry with Alma and Amulek; and because they had testified so plainly against their wickedness, they sought to put them away privily.
34008	1298	4	But it came to pass that they did not; but they took them and bound them with strong cords, and took them before the chief judge of the land.
34009	1298	5	And the people went forth and witnessed against them--testifying that they had reviled against the law, and their lawyers and judges of the land, and also of all the people that were in the land; and also testified that there was but one God, and that he should send his Son among the people, but he should not save them; and many such things did the people testify against Alma and Amulek. Now this was done before the chief judge of the land.
34010	1298	6	And it came to pass that Zeezrom was astonished at the words which had been spoken; and he also knew concerning the blindness of the minds, which he had caused among the people by his lying words; and his soul began to be harrowed up under a consciousness of his own guilt; yea, he began to be encircled about by the pains of hell.
34011	1298	7	And it came to pass that he began to cry unto the people, saying: Behold, I am guilty, and these men are spotless before God. And he began to plead for them from that time forth; but they reviled him, saying: Art thou also possessed with the devil? And they spit upon him, and cast him out from among them, and also all those who believed in the words which had been spoken by Alma and Amulek; and they cast them out, and sent men to cast stones at them.
34012	1298	8	And they brought their wives and children together, and whosoever believed or had been taught to believe in the word of God they caused that they should be cast into the fire; and they also brought forth their records which contained the holy scriptures, and cast them into the fire also, that they might be burned and destroyed by fire.
34013	1298	9	And it came to pass that they took Alma and Amulek, and carried them forth to the place of martyrdom, that they might witness the destruction of those who were consumed by fire.
34014	1298	10	And when Amulek saw the pains of the women and children who were consuming in the fire, he also was pained; and he said unto Alma: How can we witness this awful scene? Therefore let us stretch forth our hands, and exercise the power of God which is in us, and save them from the flames.
34015	1298	11	But Alma said unto him: The Spirit constraineth me that I must not stretch forth mine hand; for behold the Lord receiveth them up unto himself, in glory; and he doth suffer that they may do this thing, or that the people may do this thing unto them, according to the hardness of their hearts, that the judgments which he shall exercise upon them in his wrath may be just; and the blood of the innocent shall stand as a witness against them, yea, and cry mightily against them at the last day.
34016	1298	12	Now Amulek said unto Alma: Behold, perhaps they will burn us also.
34017	1298	13	And Alma said: Be it according to the will of the Lord. But, behold, our work is not finished; therefore they burn us not.
34018	1298	14	Now it came to pass that when the bodies of those who had been cast into the fire were consumed, and also the records which were cast in with them, the chief judge of the land came and stood before Alma and Amulek, as they were bound; and he smote them with his hand upon their cheeks, and said unto them: After what ye have seen, will ye preach again unto this people, that they shall be cast into a lake of fire and brimstone?
34019	1298	15	Behold, ye see that ye had not power to save those who had been cast into the fire; neither has God saved them because they were of thy faith. And the judge smote them again upon their cheeks, and asked: What say ye for yourselves?
34020	1298	16	Now this judge was after the order and faith of Nehor, who slew Gideon.
34021	1298	17	And it came to pass that Alma and Amulek answered him nothing; and he smote them again, and delivered them to the officers to be cast into prison.
34022	1298	18	And when they had been cast into prison three days, there came many lawyers, and judges, and priests, and teachers, who were of the profession of Nehor; and they came in unto the prison to see them, and they questioned them about many words; but they answered them nothing.
34023	1298	19	And it came to pass that the judge stood before them, and said: Why do ye not answer the words of this people? Know ye not that I have power to deliver you up unto the flames? And he commanded them to speak; but they answered nothing.
34024	1298	20	And it came to pass that they departed and went their ways, but came again on the morrow; and the judge also smote them again on their cheeks. And many came forth also, and smote them, saying: Will ye stand again and judge this people, and condemn our law? If ye have such great power why do ye not deliver yourselves?
34025	1298	21	And many such things did they say unto them, gnashing their teeth upon them, and spitting upon them, and saying: How shall we look when we are damned?
34026	1298	22	And many such things, yea, all manner of such things did they say unto them; and thus they did mock them for many days. And they did withhold food from them that they might hunger, and water that they might thirst; and they also did take from them their clothes that they were naked; and thus they were bound with strong cords, and confined in prison.
34027	1298	23	And it came to pass after they had thus suffered for many days, (and it was on the twelfth day, in the tenth month, in the tenth year of the reign of the judges over the people of Nephi) that the chief judge over the land of Ammonihah and many of their teachers and their lawyers went in unto the prison where Alma and Amulek were bound with cords.
34028	1298	24	And the chief judge stood before them, and smote them again, and said unto them: If ye have the power of God deliver yourselves from these bands, and then we will believe that the Lord will destroy this people according to your words.
34029	1298	25	And it came to pass that they all went forth and smote them, saying the same words, even until the last; and when the last had spoken unto them the power of God was upon Alma and Amulek, and they rose and stood upon their feet.
34030	1298	26	And Alma cried, saying: How long shall we suffer these great afflictions, O Lord? O Lord, give us strength according to our faith which is in Christ, even unto deliverance. And they broke the cords with which they were bound; and when the people saw this, they began to flee, for the fear of destruction had come upon them.
34031	1298	27	And it came to pass that so great was their fear that they fell to the earth, and did not obtain the outer door of the prison; and the earth shook mightily, and the walls of the prison were rent in twain, so that they fell to the earth; and the chief judge, and the lawyers, and priests, and teachers, who smote upon Alma and Amulek, were slain by the fall thereof.
34032	1298	28	And Alma and Amulek came forth out of the prison, and they were not hurt; for the Lord had granted unto them power, according to their faith which was in Christ. And they straightway came forth out of the prison; and they were loosed from their bands; and the prison had fallen to the earth, and every soul within the walls thereof, save it were Alma and Amulek, was slain; and they straightway came forth into the city.
34033	1298	29	Now the people having heard a great noise came running together by multitudes to know the cause of it; and when they saw Alma and Amulek coming forth out of the prison, and the walls thereof had fallen to the earth, they were struck with great fear, and fled from the presence of Alma and Amulek even as a goat fleeth with her young from two lions; and thus they did flee from the presence of Alma and Amulek.
34034	1299	1	And it came to pass that Alma and Amulek were commanded to depart out of that city; and they departed, and came out even into the land of Sidom; and behold, there they found all the people who had departed out of the land of Ammonihah, who had been cast out and stoned, because they believed in the words of Alma.
34035	1299	2	And they related unto them all that had happened unto their wives and children, and also concerning themselves, and of their power of deliverance.
34036	1299	3	And also Zeezrom lay sick at Sidom, with a burning fever, which was caused by the great tribulations of his mind on account of his wickedness, for he supposed that Alma and Amulek were no more; and he supposed that they had been slain because of his iniquity. And this great sin, and his many other sins, did harrow up his mind until it did become exceedingly sore, having no deliverance; therefore he began to be scorched with a burning heat.
34037	1299	4	Now, when he heard that Alma and Amulek were in the land of Sidom, his heart began to take courage; and he sent a message immediately unto them, desiring them to come unto him.
34038	1299	5	And it came to pass that they went immediately, obeying the message which he had sent unto them; and they went in unto the house unto Zeezrom; and they found him upon his bed, sick, being very low with a burning fever; and his mind also was exceedingly sore because of his iniquities; and when he saw them he stretched forth his hand, and besought them that they would heal him.
34039	1299	6	And it came to pass that Alma said unto him, taking him by the hand: Believest thou in the power of Christ unto salvation?
34040	1299	7	And he answered and said: Yea, I believe all the words that thou hast taught.
34041	1299	8	And Alma said: If thou believest in the redemption of Christ thou canst be healed.
34042	1299	9	And he said: Yea, I believe according to thy words.
34043	1299	10	And then Alma cried unto the Lord, saying: O Lord our God, have mercy on this man, and heal him according to his faith which is in Christ.
34044	1299	11	And when Alma had said these words, Zeezrom leaped upon his feet, and began to walk; and this was done to the great astonishment of all the people; and the knowledge of this went forth throughout all the land of Sidom.
34045	1299	12	And Alma baptized Zeezrom unto the Lord; and he began from that time forth to preach unto the people.
34046	1299	13	And Alma established a church in the land of Sidom, and consecrated priests and teachers in the land, to baptize unto the Lord whosoever were desirous to be baptized.
34047	1299	14	And it came to pass that they were many; for they did flock in from all the region round about Sidom, and were baptized.
34048	1299	15	But as to the people that were in the land of Ammonihah, they yet remained a hard-hearted and a stiffnecked people; and they repented not of their sins, ascribing all the power of Alma and Amulek to the devil; for they were of the profession of Nehor, and did not believe in the repentance of their sins.
34049	1299	16	And it came to pass that Alma and Amulek, Amulek having forsaken all his gold, and silver, and his precious things, which were in the land of Ammonihah, for the word of God, he being rejected by those who were once his friends and also by his father and his kindred;
34050	1299	17	Therefore, after Alma having established the church at Sidom, seeing a great check, yea, seeing that the people were checked as to the pride of their hearts, and began to humble themselves before God, and began to assemble themselves together at their sanctuaries to worship God before the altar, watching and praying continually, that they might be delivered from Satan, and from death, and from destruction--
34051	1299	18	Now as I said, Alma having seen all these things, therefore he took Amulek and came over to the land of Zarahemla, and took him to his own house, and did administer unto him in his tribulations, and strengthened him in the Lord.
34052	1299	19	And thus ended the tenth year of the reign of the judges over the people of Nephi.
34053	1300	1	And it came to pass in the eleventh year of the reign of the judges over the people of Nephi, on the fifth day of the second month, there having been much peace in the land of Zarahemla, there having been no wars nor contentions for a certain number of years, even until the fifth day of the second month in the eleventh year, there was a cry of war heard throughout the land.
34054	1300	2	For behold, the armies of the Lamanites had come in upon the wilderness side, into the borders of the land, even into the city of Ammonihah, and began to slay the people and destroy the city.
34055	1300	3	And now it came to pass, before the Nephites could raise a sufficient army to drive them out of the land, they had destroyed the people who were in the city of Ammonihah, and also some around the borders of Noah, and taken others captive into the wilderness.
34056	1300	4	Now it came to pass that the Nephites were desirous to obtain those who had been carried away captive into the wilderness.
34057	1300	5	Therefore, he that had been appointed chief captain over the armies of the Nephites, (and his name was Zoram, and he had two sons, Lehi and Aha)--now Zoram and his two sons, knowing that Alma was high priest over the church, and having heard that he had the spirit of prophecy, therefore they went unto him and desired of him to know whither the Lord would that they should go into the wilderness in search of their brethren, who had been taken captive by the Lamanites.
34058	1300	6	And it came to pass that Alma inquired of the Lord concerning the matter. And Alma returned and said unto them: Behold, the Lamanites will cross the river Sidon in the south wilderness, away up beyond the borders of the land of Manti. And behold there shall ye meet them, on the east of the river Sidon, and there the Lord will deliver unto thee thy brethren who have been taken captive by the Lamanites.
34059	1300	7	And it came to pass that Zoram and his sons crossed over the river Sidon, with their armies, and marched away beyond the borders of Manti into the south wilderness, which was on the east side of the river Sidon.
34060	1300	8	And they came upon the armies of the Lamanites, and the Lamanites were scattered and driven into the wilderness; and they took their brethren who had been taken captive by the Lamanites, and there was not one soul of them had been lost that were taken captive. And they were brought by their brethren to possess their own lands.
34061	1300	9	And thus ended the eleventh year of the judges, the Lamanites having been driven out of the land, and the people of Ammonihah were destroyed; yea, every living soul of the Ammonihahites was destroyed, and also their great city, which they said God could not destroy, because of its greatness.
34062	1300	10	But behold, in one day it was left desolate; and the carcasses were mangled by dogs and wild beasts of the wilderness.
34063	1300	11	Nevertheless, after many days their dead bodies were heaped up upon the face of the earth, and they were covered with a shallow covering. And now so great was the scent thereof that the people did not go in to possess the land of Ammonihah for many years. And it was called Desolation of Nehors; for they were of the profession of Nehor, who were slain; and their lands remained desolate.
34064	1300	12	And the Lamanites did not come again to war against the Nephites until the fourteenth year of the reign of the judges over the people of Nephi. And thus for three years did the people of Nephi have continual peace in all the land.
34065	1300	13	And Alma and Amulek went forth preaching repentance to the people in their temples, and in their sanctuaries, and also in their synagogues, which were built after the manner of the Jews.
34066	1300	14	And as many as would hear their words, unto them they did impart the word of God, without any respect of persons, continually.
34067	1300	15	And thus did Alma and Amulek go forth, and also many more who had been chosen for the work, to preach the word throughout all the land. And the establishment of the church became general throughout the land, in all the region round about, among all the people of the Nephites.
34068	1300	16	And there was no inequality among them; the Lord did pour out his Spirit on all the face of the land to prepare the minds of the children of men, or to prepare their hearts to receive the word which should be taught among them at the time of his coming--
34069	1300	17	That they might not be hardened against the word, that they might not be unbelieving, and go on to destruction, but that they might receive the word with joy, and as a branch be grafted into the true vine, that they might enter into the rest of the Lord their God.
34070	1300	18	Now those priests who did go forth among the people did preach against all lyings, and deceivings, and envyings, and strifes, and malice, and revilings, and stealing, robbing, plundering, murdering, committing adultery, and all manner of lasciviousness, crying that these things ought not so to be--
34071	1300	19	Holding forth things which must shortly come; yea, holding forth the coming of the Son of God, his sufferings and death, and also the resurrection of the dead.
34072	1300	20	And many of the people did inquire concerning the place where the Son of God should come; and they were taught that he would appear unto them after his resurrection; and this the people did hear with great joy and gladness.
34073	1300	21	And now after the church had been established throughout all the land--having got the victory over the devil, and the word of God being preached in its purity in all the land, and the Lord pouring out his blessings upon the people--thus ended the fourteenth year of the reign of the judges over the people of Nephi.
34074	1301	1	And now it came to pass that as Alma was journeying from the land of Gideon southward, away to the land of Manti, behold, to his astonishment, he met with the sons of Mosiah journeying towards the land of Zarahemla.
34075	1301	2	Now these sons of Mosiah were with Alma at the time the angel first appeared unto him; therefore Alma did rejoice exceedingly to see his brethren; and what added more to his joy, they were still his brethren in the Lord; yea, and they had waxed strong in the knowledge of the truth; for they were men of a sound understanding and they had searched the scriptures diligently, that they might know the word of God.
34076	1301	3	But this is not all; they had given themselves to much prayer, and fasting; therefore they had the spirit of prophecy, and the spirit of revelation, and when they taught, they taught with power and authority of God.
34077	1301	4	And they had been teaching the word of God for the space of fourteen years among the Lamanites, having had much success in bringing many to the knowledge of the truth; yea, by the power of their words many were brought before the altar of God, to call on his name and confess their sins before him.
34078	1301	5	Now these are the circumstances which attended them in their journeyings, for they had many afflictions; they did suffer much, both in body and in mind, such as hunger, thirst and fatigue, and also much labor in the spirit.
34079	1301	6	Now these were their journeyings: Having taken leave of their father, Mosiah, in the first year of the judges; having refused the kingdom which their father was desirous to confer upon them, and also this was the minds of the people;
34080	1301	7	Nevertheless they departed out of the land of Zarahemla, and took their swords, and their spears, and their bows, and their arrows, and their slings; and this they did that they might provide food for themselves while in the wilderness.
34081	1301	8	And thus they departed into the wilderness with their numbers which they had selected, to go up to the land of Nephi, to preach the word of God unto the Lamanites.
34082	1301	9	And it came to pass that they journeyed many days in the wilderness, and they fasted much and prayed much that the Lord would grant unto them a portion of his Spirit to go with them, and abide with them, that they might be an instrument in the hands of God to bring, if it were possible, their brethren, the Lamanites, to the knowledge of the truth, to the knowledge of the baseness of the traditions of their fathers, which were not correct.
34083	1301	10	And it came to pass that the Lord did visit them with his Spirit, and said unto them: Be comforted. And they were comforted.
34084	1301	11	And the Lord said unto them also: Go forth among the Lamanites, thy brethren, and establish my word; yet ye shall be patient in long-suffering and afflictions, that ye may show forth good examples unto them in me, and I will make an instrument of thee in my hands unto the salvation of many souls.
34085	1301	12	And it came to pass that the hearts of the sons of Mosiah, and also those who were with them, took courage to go forth unto the Lamanites to declare unto them the word of God.
34086	1301	13	And it came to pass when they had arrived in the borders of the land of the Lamanites, that they separated themselves and departed one from another, trusting in the Lord that they should meet again at the close of their harvest; for they supposed that great was the work which they had undertaken.
34087	1301	14	And assuredly it was great, for they had undertaken to preach the word of God to a wild and a hardened and a ferocious people; a people who delighted in murdering the Nephites, and robbing and plundering them; and their hearts were set upon riches, or upon gold and silver, and precious stones; yet they sought to obtain these things by murdering and plundering, that they might not labor for them with their own hands.
34088	1301	15	Thus they were a very indolent people, many of whom did worship idols, and the curse of God had fallen upon them because of the traditions of their fathers; notwithstanding the promises of the Lord were extended unto them on the conditions of repentance.
34089	1301	16	Therefore, this was the cause for which the sons of Mosiah had undertaken the work, that perhaps they might bring them unto repentance; that perhaps they might bring them to know of the plan of redemption.
34090	1301	17	Therefore they separated themselves one from another, and went forth among them, every man alone, according to the word and power of God which was given unto him.
34091	1301	18	Now Ammon being the chief among them, or rather he did administer unto them, and he departed from them, after having blessed them according to their several stations, having imparted the word of God unto them, or administered unto them before his departure; and thus they took their several journeys throughout the land.
34092	1301	19	And Ammon went to the land of Ishmael, the land being called after the sons of Ishmael, who also became Lamanites.
34093	1301	20	And as Ammon entered the land of Ishmael, the Lamanites took him and bound him, as was their custom to bind all the Nephites who fell into their hands, and carry them before the king; and thus it was left to the pleasure of the king to slay them, or to retain them in captivity, or to cast them into prison, or to cast them out of his land, according to his will and pleasure.
34094	1301	21	And thus Ammon was carried before the king who was over the land of Ishmael; and his name was Lamoni; and he was a descendant of Ishmael.
34095	1301	22	And the king inquired of Ammon if it were his desire to dwell in the land among the Lamanites, or among his people.
34096	1301	23	And Ammon said unto him: Yea, I desire to dwell among this people for a time; yea, and perhaps until the day I die.
34097	1301	24	And it came to pass that king Lamoni was much pleased with Ammon, and caused that his bands should be loosed; and he would that Ammon should take one of his daughters to wife.
34098	1301	25	But Ammon said unto him: Nay, but I will be thy servant. Therefore Ammon became a servant to king Lamoni. And it came to pass that he was set among other servants to watch the flocks of Lamoni, according to the custom of the Lamanites.
34099	1301	26	And after he had been in the service of the king three days, as he was with the Lamanitish servants going forth with their flocks to the place of water, which was called the water of Sebus, and all the Lamanites drive their flocks hither, that they may have water--
34100	1301	27	Therefore, as Ammon and the servants of the king were driving forth their flocks to this place of water, behold, a certain number of the Lamanites, who had been with their flocks to water, stood and scattered the flocks of Ammon and the servants of the king, and they scattered them insomuch that they fled many ways.
34101	1301	28	Now the servants of the king began to murmur, saying: Now the king will slay us, as he has our brethren because their flocks were scattered by the wickedness of these men. And they began to weep exceedingly, saying: Behold, our flocks are scattered already.
34102	1301	29	Now they wept because of the fear of being slain. Now when Ammon saw this his heart was swollen within him with joy; for, said he, I will show forth my power unto these my fellow-servants, or the power which is in me, in restoring these flocks unto the king, that I may win the hearts of these my fellow-servants, that I may lead them to believe in my words.
34103	1301	30	And now, these were the thoughts of Ammon, when he saw the afflictions of those whom he termed to be his brethren.
34104	1301	31	And it came to pass that he flattered them by his words, saying: My brethren, be of good cheer and let us go in search of the flocks, and we will gather them together and bring them back unto the place of water; and thus we will preserve the flocks unto the king and he will not slay us.
34105	1301	32	And it came to pass that they went in search of the flocks, and they did follow Ammon, and they rushed forth with much swiftness and did head the flocks of the king, and did gather them together again to the place of water.
34106	1301	33	And those men again stood to scatter their flocks; but Ammon said unto his brethren: Encircle the flocks round about that they flee not; and I go and contend with these men who do scatter our flocks.
34107	1301	34	Therefore, they did as Ammon commanded them, and he went forth and stood to contend with those who stood by the waters of Sebus; and they were in number not a few.
34108	1301	35	Therefore they did not fear Ammon, for they supposed that one of their men could slay him according to their pleasure, for they knew not that the Lord had promised Mosiah that he would deliver his sons out of their hands; neither did they know anything concerning the Lord; therefore they delighted in the destruction of their brethren; and for this cause they stood to scatter the flocks of the king.
34109	1301	36	But Ammon stood forth and began to cast stones at them with his sling; yea, with mighty power he did sling stones amongst them; and thus he slew a certain number of them insomuch that they began to be astonished at his power; nevertheless they were angry because of the slain of their brethren, and they were determined that he should fall; therefore, seeing that they could not hit him with their stones, they came forth with clubs to slay him.
34110	1301	37	But behold, every man that lifted his club to smite Ammon, he smote off their arms with his sword; for he did withstand their blows by smiting their arms with the edge of his sword, insomuch that they began to be astonished, and began to flee before him; yea, and they were not few in number; and he caused them to flee by the strength of his arm.
34111	1301	38	Now six of them had fallen by the sling, but he slew none save it were their leader with his sword; and he smote off as many of their arms as were lifted against him, and they were not a few.
34112	1301	39	And when he had driven them afar off, he returned and they watered their flocks and returned them to the pasture of the king, and then went in unto the king, bearing the arms which had been smitten off by the sword of Ammon, of those who sought to slay him; and they were carried in unto the king for a testimony of the things which they had done.
34113	1302	1	And it came to pass that king Lamoni caused that his servants should stand forth and testify to all the things which they had seen concerning the matter.
34114	1302	2	And when they had all testified to the things which they had seen, and he had learned of the faithfulness of Ammon in preserving his flocks, and also of his great power in contending against those who sought to slay him, he was astonished exceedingly, and said: Surely, this is more than a man. Behold, is not this the Great Spirit who doth send such great punishments upon this people, because of their murders?
34115	1302	3	And they answered the king, and said: Whether he be the Great Spirit or a man, we know not; but this much we do know, that he cannot be slain by the enemies of the king; neither can they scatter the king's flocks when he is with us, because of his expertness and great strength; therefore, we know that he is a friend to the king. And now, O king, we do not believe that a man has such great power, for we know he cannot be slain.
34116	1302	4	And now, when the king heard these words, he said unto them: Now I know that it is the Great Spirit; and he has come down at this time to preserve your lives, that I might not slay you as I did your brethren. Now this is the Great Spirit of whom our fathers have spoken.
34117	1302	5	Now this was the tradition of Lamoni, which he had received from his father, that there was a Great Spirit. Notwithstanding they believed in a Great Spirit they supposed that whatsoever they did was right; nevertheless, Lamoni began to fear exceedingly, with fear lest he had done wrong in slaying his servants;
34118	1302	6	For he had slain many of them because their brethren had scattered their flocks at the place of water; and thus, because they had had their flocks scattered they were slain.
34119	1302	7	Now it was the practice of these Lamanites to stand by the waters of Sebus to scatter the flocks of the people, that thereby they might drive away many that were scattered unto their own land, it being a practice of plunder among them.
34120	1302	8	And it came to pass that king Lamoni inquired of his servants, saying: Where is this man that has such great power?
34121	1302	9	And they said unto him: Behold, he is feeding thy horses. Now the king had commanded his servants, previous to the time of the watering of their flocks, that they should prepare his horses and chariots, and conduct him forth to the land of Nephi; for there had been a great feast appointed at the land of Nephi, by the father of Lamoni, who was king over all the land.
34122	1302	10	Now when king Lamoni heard that Ammon was preparing his horses and his chariots he was more astonished, because of the faithfulness of Ammon, saying: Surely there has not been any servant among all my servants that has been so faithful as this man; for even he doth remember all my commandments to execute them.
34123	1302	11	Now I surely know that this is the Great Spirit, and I would desire him that he come in unto me, but I durst not.
34124	1302	12	And it came to pass that when Ammon had made ready the horses and the chariots for the king and his servants, he went in unto the king, and he saw that the countenance of the king was changed; therefore he was about to return out of his presence.
34125	1302	13	And one of the king's servants said unto him, Rabbanah, which is, being interpreted, powerful or great king, considering their kings to be powerful; and thus he said unto him: Rabbanah, the king desireth thee to stay.
34126	1302	14	Therefore Ammon turned himself unto the king, and said unto him: What wilt thou that I should do for thee, O king? And the king answered him not for the space of an hour, according to their time, for he knew not what he should say unto him.
34127	1302	15	And it came to pass that Ammon said unto him again: What desirest thou of me? But the king answered him not.
34128	1302	16	And it came to pass that Ammon, being filled with the Spirit of God, therefore he perceived the thoughts of the king. And he said unto him: Is it because thou hast heard that I defended thy servants and thy flocks, and slew seven of their brethren with the sling and with the sword, and smote off the arms of others, in order to defend thy flocks and thy servants; behold, is it this that causeth thy marvelings?
34129	1302	17	I say unto you, what is it, that thy marvelings are so great? Behold, I am a man, and am thy servant; therefore, whatsoever thou desirest which is right, that will I do.
34130	1302	18	Now when the king had heard these words, he marveled again, for he beheld that Ammon could discern his thoughts; but notwithstanding this, king Lamoni did open his mouth, and said unto him: Who art thou? Art thou that Great Spirit, who knows all things?
34131	1302	19	Ammon answered and said unto him: I am not.
34132	1302	20	And the king said: How knowest thou the thoughts of my heart? Thou mayest speak boldly, and tell me concerning these things; and also tell me by what power ye slew and smote off the arms of my brethren that scattered my flocks--
34133	1302	21	And now, if thou wilt tell me concerning these things, whatsoever thou desirest I will give unto thee; and if it were needed, I would guard thee with my armies; but I know that thou art more powerful than all they; nevertheless, whatsoever thou desirest of me I will grant it unto thee.
34134	1302	22	Now Ammon being wise, yet harmless, he said unto Lamoni: Wilt thou hearken unto my words, if I tell thee by what power I do these things? And this is the thing that I desire of thee.
34135	1302	23	And the king answered him, and said: Yea, I will believe all thy words. And thus he was caught with guile.
34136	1302	24	And Ammon began to speak unto him with boldness, and said unto him: Believest thou that there is a God?
34137	1302	25	And he answered, and said unto him: I do not know what that meaneth.
34138	1302	26	And then Ammon said: Believest thou that there is a Great Spirit?
34139	1302	27	And he said, Yea.
34140	1302	28	And Ammon said: This is God. And Ammon said unto him again: Believest thou that this Great Spirit, who is God, created all things which are in heaven and in the earth?
34141	1302	29	And he said: Yea, I believe that he created all things which are in the earth; but I do not know the heavens.
34142	1302	30	And Ammon said unto him: The heavens is a place where God dwells and all his holy angels.
34143	1302	31	And king Lamoni said: Is it above the earth?
34144	1302	32	And Ammon said: Yea, and he looketh down upon all the children of men; and he knows all the thoughts and intents of the heart; for by his hand were they all created from the beginning.
34145	1302	33	And king Lamoni said: I believe all these things which thou hast spoken. Art thou sent from God?
34146	1302	34	Ammon said unto him: I am a man; and man in the beginning was created after the image of God, and I am called by his Holy Spirit to teach these things unto this people, that they may be brought to a knowledge of that which is just and true;
34147	1302	35	And a portion of that Spirit dwelleth in me, which giveth me knowledge, and also power according to my faith and desires which are in God.
34148	1302	36	Now when Ammon had said these words, he began at the creation of the world, and also the creation of Adam, and told him all the things concerning the fall of man, and rehearsed and laid before him the records and the holy scriptures of the people, which had been spoken by the prophets, even down to the time that their father, Lehi, left Jerusalem.
34149	1302	37	And he also rehearsed unto them (for it was unto the king and to his servants) all the journeyings of their fathers in the wilderness, and all their sufferings with hunger and thirst, and their travail, and so forth.
34150	1302	38	And he also rehearsed unto them concerning the rebellions of Laman and Lemuel, and the sons of Ishmael, yea, all their rebellions did he relate unto them; and he expounded unto them all the records and scriptures from the time that Lehi left Jerusalem down to the present time.
34151	1302	39	But this is not all; for he expounded unto them the plan of redemption, which was prepared from the foundation of the world; and he also made known unto them concerning the coming of Christ, and all the works of the Lord did he make known unto them.
34152	1302	40	And it came to pass that after he had said all these things, and expounded them to the king, that the king believed all his words.
34153	1302	41	And he began to cry unto the Lord, saying: O Lord, have mercy; according to thy abundant mercy which thou hast had upon the people of Nephi, have upon me, and my people.
34154	1302	42	And now, when he had said this, he fell unto the earth, as if he were dead.
34155	1302	43	And it came to pass that his servants took him and carried him in unto his wife, and laid him upon a bed; and he lay as if he were dead for the space of two days and two nights; and his wife, and his sons, and his daughters mourned over him, after the manner of the Lamanites, greatly lamenting his loss.
34156	1303	1	And it came to pass that after two days and two nights they were about to take his body and lay it in a sepulchre, which they had made for the purpose of burying their dead.
34157	1303	2	Now the queen having heard of the fame of Ammon, therefore she sent and desired that he should come in unto her.
34158	1303	3	And it came to pass that Ammon did as he was commanded, and went in unto the queen, and desired to know what she would that he should do.
34159	1303	4	And she said unto him: The servants of my husband have made it known unto me that thou art a prophet of a holy God, and that thou hast power to do many mighty works in his name;
34160	1303	5	Therefore, if this is the case, I would that ye should go in and see my husband, for he has been laid upon his bed for the space of two days and two nights; and some say that he is not dead, but others say that he is dead and that he stinketh, and that he ought to be placed in the sepulchre; but as for myself, to me he doth not stink.
34161	1303	6	Now, this was what Ammon desired, for he knew that king Lamoni was under the power of God; he knew that the dark veil of unbelief was being cast away from his mind, and the light which did light up his mind, which was the light of the glory of God, which was a marvelous light of his goodness--yea, this light had infused such joy into his soul, the cloud of darkness having been dispelled, and that the light of everlasting life was lit up in his soul, yea, he knew that this had overcome his natural frame, and he was carried away in God--
34162	1303	7	Therefore, what the queen desired of him was his only desire. Therefore, he went in to see the king according as the queen had desired him; and he saw the king, and he knew that he was not dead.
34163	1303	8	And he said unto the queen: He is not dead, but he sleepeth in God, and on the morrow he shall rise again; therefore bury him not.
34164	1303	9	And Ammon said unto her: Believest thou this? And she said unto him: I have had no witness save thy word, and the word of our servants; nevertheless I believe that it shall be according as thou hast said.
34165	1303	10	And Ammon said unto her: Blessed art thou because of thy exceeding faith; I say unto thee, woman, there has not been such great faith among all the people of the Nephites.
34166	1303	11	And it came to pass that she watched over the bed of her husband, from that time even until that time on the morrow which Ammon had appointed that he should rise.
34167	1303	12	And it came to pass that he arose, according to the words of Ammon; and as he arose, he stretched forth his hand unto the woman, and said: Blessed be the name of God, and blessed art thou.
34168	1303	13	For as sure as thou livest, behold, I have seen my Redeemer; and he shall come forth, and be born of a woman, and he shall redeem all mankind who believe on his name. Now, when he had said these words, his heart was swollen within him, and he sunk again with joy; and the queen also sunk down, being overpowered by the Spirit.
34169	1303	14	Now Ammon seeing the Spirit of the Lord poured out according to his prayers upon the Lamanites, his brethren, who had been the cause of so much mourning among the Nephites, or among all the people of God because of their iniquities and their traditions, he fell upon his knees, and began to pour out his soul in prayer and thanksgiving to God for what he had done for his brethren; and he was also overpowered with joy; and thus they all three had sunk to the earth.
34170	1303	15	Now, when the servants of the king had seen that they had fallen, they also began to cry unto God, for the fear of the Lord had come upon them also, for it was they who had stood before the king and testified unto him concerning the great power of Ammon.
34171	1303	16	And it came to pass that they did call on the name of the Lord, in their might, even until they had all fallen to the earth, save it were one of the Lamanitish women, whose name was Abish, she having been converted unto the Lord for many years, on account of a remarkable vision of her father--
34172	1303	17	Thus, having been converted to the Lord, and never having made it known, therefore, when she saw that all the servants of Lamoni had fallen to the earth, and also her mistress, the queen, and the king, and Ammon lay prostrate upon the earth, she knew that it was the power of God; and supposing that this opportunity, by making known unto the people what had happened among them, that by beholding this scene it would cause them to believe in the power of God, therefore she ran forth from house to house, making it known unto the people.
34173	1303	18	And they began to assemble themselves together unto the house of the king. And there came a multitude, and to their astonishment they beheld the king, and the queen, and their servants prostrate upon the earth, and they all lay there as though they were dead; and they also saw Ammon, and behold, he was a Nephite.
34174	1303	19	And now the people began to murmur among themselves; some saying that it was a great evil that had come upon them, or upon the king and his house, because he had suffered that the Nephite should remain in the land.
34175	1303	20	But others rebuked them, saying: The king hath brought this evil upon his house, because he slew his servants who had had their flocks scattered at the waters of Sebus.
34176	1303	21	And they were also rebuked by those men who had stood at the waters of Sebus and scattered the flocks which belonged to the king, for they were angry with Ammon because of the number which he had slain of their brethren at the waters of Sebus, while defending the flocks of the king.
34177	1303	22	Now, one of them, whose brother had been slain with the sword of Ammon, being exceedingly angry with Ammon, drew his sword and went forth that he might let it fall upon Ammon, to slay him; and as he lifted the sword to smite him, behold, he fell dead.
34178	1303	23	Now we see that Ammon could not be slain, for the Lord had said unto Mosiah, his father: I will spare him, and it shall be unto him according to thy faith--therefore, Mosiah trusted him unto the Lord.
34179	1303	24	And it came to pass that when the multitude beheld that the man had fallen dead, who lifted the sword to slay Ammon, fear came upon them all, and they durst not put forth their hands to touch him or any of those who had fallen; and they began to marvel again among themselves what could be the cause of this great power, or what all these things could mean.
34180	1303	25	And it came to pass that there were many among them who said that Ammon was the Great Spirit, and others said he was sent by the Great Spirit;
34181	1303	26	But others rebuked them all, saying that he was a monster, who had been sent from the Nephites to torment them.
34182	1303	27	And there were some who said that Ammon was sent by the Great Spirit to afflict them because of their iniquities; and that it was the Great Spirit that had always attended the Nephites, who had ever delivered them out of their hands; and they said that it was this Great Spirit who had destroyed so many of their brethren, the Lamanites.
34183	1303	28	And thus the contention began to be exceedingly sharp among them. And while they were thus contending, the woman servant who had caused the multitude to be gathered together came, and when she saw the contention which was among the multitude she was exceedingly sorrowful, even unto tears.
34184	1303	29	And it came to pass that she went and took the queen by the hand, that perhaps she might raise her from the ground; and as soon as she touched her hand she arose and stood upon her feet, and cried with a loud voice, saying: O blessed Jesus, who has saved me from an awful hell! O blessed God, have mercy on this people!
34185	1303	30	And when she had said this, she clasped her hands, being filled with joy, speaking many words which were not understood; and when she had done this, she took the king, Lamoni, by the hand, and behold he arose and stood upon his feet.
34186	1303	31	And he, immediately, seeing the contention among his people, went forth and began to rebuke them, and to teach them the words which he had heard from the mouth of Ammon; and as many as heard his words believed, and were converted unto the Lord.
34187	1303	32	But there were many among them who would not hear his words; therefore they went their way.
34188	1303	33	And it came to pass that when Ammon arose he also administered unto them, and also did all the servants of Lamoni; and they did all declare unto the people the selfsame thing--that their hearts had been changed; that they had no more desire to do evil.
34189	1303	34	And behold, many did declare unto the people that they had seen angels and had conversed with them; and thus they had told them things of God, and of his righteousness.
34190	1303	35	And it came to pass that there were many that did believe in their words; and as many as did believe were baptized; and they became a righteous people, and they did establish a church among them.
34191	1303	36	And thus the work of the Lord did commence among the Lamanites; thus the Lord did begin to pour out his Spirit upon them; and we see that his arm is extended to all people who will repent and believe on his name.
34192	1304	1	And it came to pass that when they had established a church in that land, that king Lamoni desired that Ammon should go with him to the land of Nephi, that he might show him unto his father.
34193	1304	2	And the voice of the Lord came to Ammon, saying: Thou shalt not go up to the land of Nephi, for behold, the king will seek thy life; but thou shalt go to the land of Middoni; for behold, thy brother Aaron, and also Muloki and Ammah are in prison.
34194	1304	3	Now it came to pass that when Ammon had heard this, he said unto Lamoni: Behold, my brother and brethren are in prison at Middoni, and I go that I may deliver them.
34195	1304	4	Now Lamoni said unto Ammon: I know, in the strength of the Lord thou canst do all things. But behold, I will go with thee to the land of Middoni; for the king of the land of Middoni, whose name is Antiomno, is a friend unto me; therefore I go to the land of Middoni, that I may flatter the king of the land, and he will cast thy brethren out of prison. Now Lamoni said unto him: Who told thee that thy brethren were in prison?
34196	1304	5	And Ammon said unto him: No one hath told me, save it be God; and he said unto me--Go and deliver thy brethren, for they are in prison in the land of Middoni.
34197	1304	6	Now when Lamoni had heard this he caused that his servants should make ready his horses and his chariots.
34198	1304	7	And he said unto Ammon: Come, I will go with thee down to the land of Middoni, and there I will plead with the king that he will cast thy brethren out of prison.
34199	1304	8	And it came to pass that as Ammon and Lamoni were journeying thither, they met the father of Lamoni, who was king over all the land.
34200	1304	9	And behold, the father of Lamoni said unto him: Why did ye not come to the feast on that great day when I made a feast unto my sons, and unto my people?
34201	1304	10	And he also said: Whither art thou going with this Nephite, who is one of the children of a liar?
34202	1304	11	And it came to pass that Lamoni rehearsed unto him whither he was going, for he feared to offend him.
34203	1304	12	And he also told him all the cause of his tarrying in his own kingdom, that he did not go unto his father to the feast which he had prepared.
34204	1304	13	And now when Lamoni had rehearsed unto him all these things, behold, to his astonishment, his father was angry with him, and said: Lamoni, thou art going to deliver these Nephites, who are sons of a liar. Behold, he robbed our fathers; and now his children are also come amongst us that they may, by their cunning and their lyings, deceive us, that they again may rob us of our property.
34205	1304	14	Now the father of Lamoni commanded him that he should slay Ammon with the sword. And he also commanded him that he should not go to the land of Middoni, but that he should return with him to the land of Ishmael.
34206	1304	15	But Lamoni said unto him: I will not slay Ammon, neither will I return to the land of Ishmael, but I go to the land of Middoni that I may release the brethren of Ammon, for I know that they are just men and holy prophets of the true God.
34207	1304	16	Now when his father had heard these words, he was angry with him, and he drew his sword that he might smite him to the earth.
34208	1304	17	But Ammon stood forth and said unto him: Behold, thou shalt not slay thy son; nevertheless, it were better that he should fall than thee, for behold, he has repented of his sins; but if thou shouldst fall at this time, in thine anger, thy soul could not be saved.
34209	1304	18	And again, it is expedient that thou shouldst forbear; for if thou shouldst slay thy son, he being an innocent man, his blood would cry from the ground to the Lord his God, for vengeance to come upon thee; and perhaps thou wouldst lose thy soul.
34210	1304	19	Now when Ammon had said these words unto him, he answered him, saying: I know that if I should slay my son, that I should shed innocent blood; for it is thou that hast sought to destroy him.
34211	1304	20	And he stretched forth his hand to slay Ammon. But Ammon withstood his blows, and also smote his arm that he could not use it.
34212	1304	21	Now when the king saw that Ammon could slay him, he began to plead with Ammon that he would spare his life.
34213	1304	22	But Ammon raised his sword, and said unto him: Behold, I will smite thee except thou wilt grant unto me that my brethren may be cast out of prison.
34214	1304	23	Now the king, fearing he should lose his life, said: If thou wilt spare me I will grant unto thee whatsoever thou wilt ask, even to half of the kingdom.
34215	1304	24	Now when Ammon saw that he had wrought upon the old king according to his desire, he said unto him: If thou wilt grant that my brethren may be cast out of prison, and also that Lamoni may retain his kingdom, and that ye be not displeased with him, but grant that he may do according to his own desires in whatsoever thing he thinketh, then will I spare thee; otherwise I will smite thee to the earth.
34216	1304	25	Now when Ammon had said these words, the king began to rejoice because of his life.
34217	1304	26	And when he saw that Ammon had no desire to destroy him, and when he also saw the great love he had for his son Lamoni, he was astonished exceedingly, and said: Because this is all that thou hast desired, that I would release thy brethren, and suffer that my son Lamoni should retain his kingdom, behold, I will grant unto you that my son may retain his kingdom from this time and forever; and I will govern him no more--
34218	1304	27	And I will also grant unto thee that thy brethren may be cast out of prison, and thou and thy brethren may come unto me, in my kingdom; for I shall greatly desire to see thee. For the king was greatly astonished at the words which he had spoken, and also at the words which had been spoken by his son Lamoni, therefore he was desirous to learn them.
34219	1304	28	And it came to pass that Ammon and Lamoni proceeded on their journey towards the land of Middoni. And Lamoni found favor in the eyes of the king of the land; therefore the brethren of Ammon were brought forth out of prison.
34220	1304	29	And when Ammon did meet them he was exceedingly sorrowful, for behold they were naked, and their skins were worn exceedingly because of being bound with strong cords. And they also had suffered hunger, thirst, and all kinds of afflictions; nevertheless they were patient in all their sufferings.
34221	1304	30	And, as it happened, it was their lot to have fallen into the hands of a more hardened and a more stiffnecked people; therefore they would not hearken unto their words, and they had cast them out, and had smitten them, and had driven them from house to house, and from place to place, even until they had arrived in the land of Middoni; and there they were taken and cast into prison, and bound with strong cords, and kept in prison for many days, and were delivered by Lamoni and Ammon.
34222	1305	1	Now when Ammon and his brethren separated themselves in the borders of the land of the Lamanites, behold Aaron took his journey towards the land which was called by the Lamanites, Jerusalem, calling it after the land of their fathers' nativity; and it was away joining the borders of Mormon.
34223	1305	2	Now the Lamanites and the Amalekites and the people of Amulon had built a great city, which was called Jerusalem.
34224	1305	3	Now the Lamanites of themselves were sufficiently hardened, but the Amalekites and the Amulonites were still harder; therefore they did cause the Lamanites that they should harden their hearts, that they should wax strong in wickedness and their abominations.
34225	1305	4	And it came to pass that Aaron came to the city of Jerusalem, and first began to preach to the Amalekites. And he began to preach to them in their synagogues, for they had built synagogues after the order of the Nehors; for many of the Amalekites and the Amulonites were after the order of the Nehors.
34226	1305	5	Therefore, as Aaron entered into one of their synagogues to preach unto the people, and as he was speaking unto them, behold there arose an Amalekite and began to contend with him, saying: What is that thou hast testified? Hast thou seen an angel? Why do not angels appear unto us? Behold are not this people as good as thy people?
34227	1305	6	Thou also sayest, except we repent we shall perish. How knowest thou the thought and intent of our hearts? How knowest thou that we have cause to repent? How knowest thou that we are not a righteous people? Behold, we have built sanctuaries, and we do assemble ourselves together to worship God. We do believe that God will save all men.
34228	1305	7	Now Aaron said unto him: Believest thou that the Son of God shall come to redeem mankind from their sins?
34229	1305	8	And the man said unto him: We do not believe that thou knowest any such thing. We do not believe in these foolish traditions. We do not believe that thou knowest of things to come, neither do we believe that thy fathers and also that our fathers did know concerning the things which they spake, of that which is to come.
34230	1305	9	Now Aaron began to open the scriptures unto them concerning the coming of Christ, and also concerning the resurrection of the dead, and that there could be no redemption for mankind save it were through the death and sufferings of Christ, and the atonement of his blood.
34231	1305	10	And it came to pass as he began to expound these things unto them they were angry with him, and began to mock him; and they would not hear the words which he spake.
34232	1305	11	Therefore, when he saw that they would not hear his words, he departed out of their synagogue, and came over to a village which was called Ani-Anti, and there he found Muloki preaching the word unto them; and also Ammah and his brethren. And they contended with many about the word.
34233	1305	12	And it came to pass that they saw that the people would harden their hearts, therefore they departed and came over into the land of Middoni. And they did preach the word unto many, and few believed on the words which they taught.
34234	1305	13	Nevertheless, Aaron and a certain number of his brethren were taken and cast into prison, and the remainder of them fled out of the land of Middoni unto the regions round about.
34235	1305	14	And those who were cast into prison suffered many things, and they were delivered by the hand of Lamoni and Ammon, and they were fed and clothed.
34236	1305	15	And they went forth again to declare the word, and thus they were delivered for the first time out of prison; and thus they had suffered.
34237	1305	16	And they went forth whithersoever they were led by the Spirit of the Lord, preaching the word of God in every synagogue of the Amalekites, or in every assembly of the Lamanites where they could be admitted.
34238	1305	17	And it came to pass that the Lord began to bless them, insomuch that they brought many to the knowledge of the truth; yea, they did convince many of their sins, and of the traditions of their fathers, which were not correct.
34239	1305	18	And it came to pass that Ammon and Lamoni returned from the land of Middoni to the land of Ishmael, which was the land of their inheritance.
34240	1305	19	And king Lamoni would not suffer that Ammon should serve him, or be his servant.
34241	1305	20	But he caused that there should be synagogues built in the land of Ishmael; and he caused that his people, or the people who were under his reign, should assemble themselves together.
34242	1305	21	And he did rejoice over them, and he did teach them many things. And he did also declare unto them that they were a people who were under him, and that they were a free people, that they were free from the oppressions of the king, his father; for that his father had granted unto him that he might reign over the people who were in the land of Ishmael, and in all the land round about.
34243	1305	22	And he also declared unto them that they might have the liberty of worshiping the Lord their God according to their desires, in whatsoever place they were in, if it were in the land which was under the reign of king Lamoni.
34244	1305	23	And Ammon did preach unto the people of king Lamoni; and it came to pass that he did teach them all things concerning things pertaining to righteousness. And he did exhort them daily, with all diligence; and they gave heed unto his word, and they were zealous for keeping the commandments of God.
34245	1306	1	Now, as Ammon was thus teaching the people of Lamoni continually, we will return to the account of Aaron and his brethren; for after he departed from the land of Middoni he was led by the Spirit to the land of Nephi, even to the house of the king which was over all the land save it were the land of Ishmael; and he was the father of Lamoni.
34246	1306	2	And it came to pass that he went in unto him into the king's palace, with his brethren, and bowed himself before the king, and said unto him: Behold, O king, we are the brethren of Ammon, whom thou hast delivered out of prison.
34247	1306	3	And now, O king, if thou wilt spare our lives, we will be thy servants. And the king said unto them: Arise, for I will grant unto you your lives, and I will not suffer that ye shall be my servants; but I will insist that ye shall administer unto me; for I have been somewhat troubled in mind because of the generosity and the greatness of the words of thy brother Ammon; and I desire to know the cause why he has not come up out of Middoni with thee.
34248	1306	4	And Aaron said unto the king: Behold, the Spirit of the Lord has called him another way; he has gone to the land of Ishmael, to teach the people of Lamoni.
34249	1306	5	Now the king said unto them: What is this that ye have said concerning the Spirit of the Lord? Behold, this is the thing which doth trouble me.
34250	1306	6	And also, what is this that Ammon said--If ye will repent ye shall be saved, and if ye will not repent, ye shall be cast off at the last day?
34251	1306	7	And Aaron answered him and said unto him: Believest thou that there is a God? And the king said: I know that the Amalekites say that there is a God, and I have granted unto them that they should build sanctuaries, that they may assemble themselves together to worship him. And if now thou sayest there is a God, behold I will believe.
34252	1306	8	And now when Aaron heard this, his heart began to rejoice, and he said: Behold, assuredly as thou livest, O king, there is a God.
34253	1306	9	And the king said: Is God that Great Spirit that brought our fathers out of the land of Jerusalem?
34254	1306	10	And Aaron said unto him: Yea, he is that Great Spirit, and he created all things both in heaven and in earth. Believest thou this?
34255	1306	11	And he said: Yea, I believe that the Great Spirit created all things, and I desire that ye should tell me concerning all these things, and I will believe thy words.
34256	1306	12	And it came to pass that when Aaron saw that the king would believe his words, he began from the creation of Adam, reading the scriptures unto the king--how God created man after his own image, and that God gave him commandments, and that because of transgression, man had fallen.
34257	1306	13	And Aaron did expound unto him the scriptures from the creation of Adam, laying the fall of man before him, and their carnal state and also the plan of redemption, which was prepared from the foundation of the world, through Christ, for all whosoever would believe on his name.
34258	1306	14	And since man had fallen he could not merit anything of himself; but the sufferings and death of Christ atone for their sins, through faith and repentance, and so forth; and that he breaketh the bands of death, that the grave shall have no victory, and that the sting of death should be swallowed up in the hopes of glory; and Aaron did expound all these things unto the king.
34259	1306	15	And it came to pass that after Aaron had expounded these things unto him, the king said: What shall I do that I may have this eternal life of which thou hast spoken? Yea, what shall I do that I may be born of God, having this wicked spirit rooted out of my breast, and receive his Spirit, that I may be filled with joy, that I may not be cast off at the last day? Behold, said he, I will give up all that I possess, yea, I will forsake my kingdom, that I may receive this great joy.
34260	1306	16	But Aaron said unto him: If thou desirest this thing, if thou wilt bow down before God, yea, if thou wilt repent of all thy sins, and will bow down before God, and call on his name in faith, believing that ye shall receive, then shalt thou receive the hope which thou desirest.
34261	1306	17	And it came to pass that when Aaron had said these words, the king did bow down before the Lord, upon his knees; yea, even he did prostrate himself upon the earth, and cried mightily, saying:
34262	1306	18	O God, Aaron hath told me that there is a God; and if there is a God, and if thou art God, wilt thou make thyself known unto me, and I will give away all my sins to know thee, and that I may be raised from the dead, and be saved at the last day. And now when the king had said these words, he was struck as if he were dead.
34263	1306	19	And it came to pass that his servants ran and told the queen all that had happened unto the king. And she came in unto the king; and when she saw him lay as if he were dead, and also Aaron and his brethren standing as though they had been the cause of his fall, she was angry with them, and commanded that her servants, or the servants of the king, should take them and slay them.
34264	1306	20	Now the servants had seen the cause of the king's fall, therefore they durst not lay their hands on Aaron and his brethren; and they pled with the queen saying: Why commandest thou that we should slay these men, when behold one of them is mightier than us all? Therefore we shall fall before them.
34265	1306	21	Now when the queen saw the fear of the servants she also began to fear exceedingly, lest there should some evil come upon her. And she commanded her servants that they should go and call the people, that they might slay Aaron and his brethren.
34266	1306	22	Now when Aaron saw the determination of the queen, he, also knowing the hardness of the hearts of the people, feared lest that a multitude should assemble themselves together, and there should be a great contention and a disturbance among them; therefore he put forth his hand and raised the king from the earth, and said unto him: Stand. And he stood upon his feet, receiving his strength.
34267	1306	23	Now this was done in the presence of the queen and many of the servants. And when they saw it they greatly marveled, and began to fear. And the king stood forth, and began to minister unto them. And he did minister unto them, insomuch that his whole household were converted unto the Lord.
34268	1306	24	Now there was a multitude gathered together because of the commandment of the queen, and there began to be great murmurings among them because of Aaron and his brethren.
34269	1306	25	But the king stood forth among them and administered unto them. And they were pacified towards Aaron and those who were with him.
34270	1306	26	And it came to pass that when the king saw that the people were pacified, he caused that Aaron and his brethren should stand forth in the midst of the multitude, and that they should preach the word unto them.
34271	1306	27	And it came to pass that the king sent a proclamation throughout all the land, amongst all his people who were in all his land, who were in all the regions round about, which was bordering even to the sea, on the east and on the west, and which was divided from the land of Zarahemla by a narrow strip of wilderness, which ran from the sea east even to the sea west, and round about on the borders of the seashore, and the borders of the wilderness which was on the north by the land of Zarahemla, through the borders of Manti, by the head of the river Sidon, running from the east towards the west--and thus were the Lamanites and the Nephites divided.
34272	1306	28	Now, the more idle part of the Lamanites lived in the wilderness, and dwelt in tents; and they were spread through the wilderness on the west, in the land of Nephi; yea, and also on the west of the land of Zarahemla, in the borders by the seashore, and on the west in the land of Nephi, in the place of their fathers' first inheritance, and thus bordering along by the seashore.
34273	1306	29	And also there were many Lamanites on the east by the seashore, whither the Nephites had driven them. And thus the Nephites were nearly surrounded by the Lamanites; nevertheless the Nephites had taken possession of all the northern parts of the land bordering on the wilderness, at the head of the river Sidon, from the east to the west, round about on the wilderness side; on the north, even until they came to the land which they called Bountiful.
34274	1306	30	And it bordered upon the land which they called Desolation, it being so far northward that it came into the land which had been peopled and been destroyed, of whose bones we have spoken, which was discovered by the people of Zarahemla, it being the place of their first landing.
34275	1306	31	And they came from there up into the south wilderness. Thus the land on the northward was called Desolation, and the land on the southward was called Bountiful, it being the wilderness which is filled with all manner of wild animals of every kind, a part of which had come from the land northward for food.
34276	1306	32	And now, it was only the distance of a day and a half's journey for a Nephite, on the line Bountiful and the land Desolation, from the east to the west sea; and thus the land of Nephi and the land of Zarahemla were nearly surrounded by water, there being a small neck of land between the land northward and the land southward.
34277	1306	33	And it came to pass that the Nephites had inhabited the land Bountiful, even from the east unto the west sea, and thus the Nephites in their wisdom, with their guards and their armies, had hemmed in the Lamanites on the south, that thereby they should have no more possession on the north, that they might not overrun the land northward.
34278	1306	34	Therefore the Lamanites could have no more possessions only in the land of Nephi, and the wilderness round about. Now this was wisdom in the Nephites--as the Lamanites were an enemy to them, they would not suffer their afflictions on every hand, and also that they might have a country whither they might flee, according to their desires.
34279	1306	35	And now I, after having said this, return again to the account of Ammon and Aaron, Omner and Himni, and their brethren.
34280	1307	1	Behold, now it came to pass that the king of the Lamanites sent a proclamation among all his people, that they should not lay their hands on Ammon, or Aaron, or Omner, or Himni, nor either of their brethren who should go forth preaching the word of God, in whatsoever place they should be, in any part of their land.
34281	1307	2	Yea, he sent a decree among them, that they should not lay their hands on them to bind them, or to cast them into prison; neither should they spit upon them, nor smite them, nor cast them out of their synagogues, nor scourge them; neither should they cast stones at them, but that they should have free access to their houses, and also their temples, and their sanctuaries.
34282	1307	3	And thus they might go forth and preach the word according to their desires, for the king had been converted unto the Lord, and all his household; therefore he sent his proclamation throughout the land unto his people, that the word of God might have no obstruction, but that it might go forth throughout all the land, that his people might be convinced concerning the wicked traditions of their fathers, and that they might be convinced that they were all brethren, and that they ought not to murder, nor to plunder, nor to steal, nor to commit adultery, nor to commit any manner of wickedness.
34283	1307	4	And now it came to pass that when the king had sent forth this proclamation, that Aaron and his brethren went forth from city to city, and from one house of worship to another, establishing churches, and consecrating priests and teachers throughout the land among the Lamanites, to preach and to teach the word of God among them; and thus they began to have great success.
34284	1307	5	And thousands were brought to the knowledge of the Lord, yea, thousands were brought to believe in the traditions of the Nephites; and they were taught the records and prophecies which were handed down even to the present time.
34285	1307	6	And as sure as the Lord liveth, so sure as many as believed, or as many as were brought to the knowledge of the truth, through the preaching of Ammon and his brethren, according to the spirit of revelation and of prophecy, and the power of God working miracles in them--yea, I say unto you, as the Lord liveth, as many of the Lamanites as believed in their preaching, and were converted unto the Lord, never did fall away.
34286	1307	7	For they became a righteous people; they did lay down the weapons of their rebellion, that they did not fight against God any more, neither against any of their brethren.
34287	1307	8	Now, these are they who were converted unto the Lord:
34288	1307	9	The people of the Lamanites who were in the land of Ishmael;
34289	1307	10	And also of the people of the Lamanites who were in the land of Middoni;
34290	1307	11	And also of the people of the Lamanites who were in the city of Nephi;
34291	1307	12	And also of the people of the Lamanites who were in the land of Shilom, and who were in the land of Shemlon, and in the city of Lemuel, and in the city of Shimnilom.
34292	1307	13	And these are the names of the cities of the Lamanites which were converted unto the Lord; and these are they that laid down the weapons of their rebellion, yea, all their weapons of war; and they were all Lamanites.
34293	1307	14	And the Amalekites were not converted, save only one; neither were any of the Amulonites; but they did harden their hearts, and also the hearts of the Lamanites in that part of the land wheresoever they dwelt, yea, and all their villages and all their cities.
34294	1307	15	Therefore, we have named all the cities of the Lamanites in which they did repent and come to the knowledge of the truth, and were converted.
34295	1307	16	And now it came to pass that the king and those who were converted were desirous that they might have a name, that thereby they might be distinguished from their brethren; therefore the king consulted with Aaron and many of their priests, concerning the name that they should take upon them, that they might be distinguished.
34296	1307	17	And it came to pass that they called their names Anti-Nephi-Lehies; and they were called by this name and were no more called Lamanites.
34297	1307	18	And they began to be a very industrious people; yea, and they were friendly with the Nephites; therefore, they did open a correspondence with them, and the curse of God did no more follow them.
34298	1308	1	And it came to pass that the Amalekites and the Amulonites and the Lamanites who were in the land of Amulon, and also in the land of Helam, and who were in the land of Jerusalem, and in fine, in all the land round about, who had not been converted and had not taken upon them the name of Anti-Nephi-Lehi, were stirred up by the Amalekites and by the Amulonites to anger against their brethren.
34299	1308	2	And their hatred became exceedingly sore against them, even insomuch that they began to rebel against their king, insomuch that they would not that he should be their king; therefore, they took up arms against the people of Anti-Nephi-Lehi.
34300	1308	3	Now the king conferred the kingdom upon his son, and he called his name Anti-Nephi-Lehi.
34301	1308	4	And the king died in that selfsame year that the Lamanites began to make preparations for war against the people of God.
34302	1308	5	Now when Ammon and his brethren and all those who had come up with him saw the preparations of the Lamanites to destroy their brethren, they came forth to the land of Midian, and there Ammon met all his brethren; and from thence they came to the land of Ishmael that they might hold a council with Lamoni and also with his brother Anti-Nephi-Lehi, what they should do to defend themselves against the Lamanites.
34303	1308	6	Now there was not one soul among all the people who had been converted unto the Lord that would take up arms against their brethren; nay, they would not even make any preparations for war; yea, and also their king commanded them that they should not.
34304	1308	7	Now, these are the words which he said unto the people concerning the matter: I thank my God, my beloved people, that our great God has in goodness sent these our brethren, the Nephites, unto us to preach unto us, and to convince us of the traditions of our wicked fathers.
34305	1308	8	And behold, I thank my great God that he has given us a portion of his Spirit to soften our hearts, that we have opened a correspondence with these brethren, the Nephites.
34306	1308	9	And behold, I also thank my God, that by opening this correspondence we have been convinced of our sins, and of the many murders which we have committed.
34307	1308	10	And I also thank my God, yea, my great God, that he hath granted unto us that we might repent of these things, and also that he hath forgiven us of those our many sins and murders which we have committed, and taken away the guilt from our hearts, through the merits of his Son.
34308	1308	11	And now behold, my brethren, since it has been all that we could do, (as we were the most lost of all mankind) to repent of all our sins and the many murders which we have committed, and to get God to take them away from our hearts, for it was all we could do to repent sufficiently before God that he would take away our stain--
34309	1308	12	Now, my best beloved brethren, since God hath taken away our stains, and our swords have become bright, then let us stain our swords no more with the blood of our brethren.
34310	1308	13	Behold, I say unto you, Nay, let us retain our swords that they be not stained with the blood of our brethren; for perhaps, if we should stain our swords again they can no more be washed bright through the blood of the Son of our great God, which shall be shed for the atonement of our sins.
34311	1308	14	And the great God has had mercy on us, and made these things known unto us that we might not perish; yea, and he has made these things known unto us beforehand, because he loveth our souls as well as he loveth our children; therefore, in his mercy he doth visit us by his angels, that the plan of salvation might be made known unto us as well as unto future generations.
34312	1308	15	Oh, how merciful is our God! And now behold, since it has been as much as we could do to get our stains taken away from us, and our swords are made bright, let us hide them away that they may be kept bright, as a testimony to our God at the last day, or at the day that we shall be brought to stand before him to be judged, that we have not stained our swords in the blood of our brethren since he imparted his word unto us and has made us clean thereby.
34313	1308	16	And now, my brethren, if our brethren seek to destroy us, behold, we will hide away our swords, yea, even we will bury them deep in the earth, that they may be kept bright, as a testimony that we have never used them, at the last day; and if our brethren destroy us, behold, we shall go to our God and shall be saved.
34314	1308	17	And now it came to pass that when the king had made an end of these sayings, and all the people were assembled together, they took their swords, and all the weapons which were used for the shedding of man's blood, and they did bury them up deep in the earth.
34315	1308	18	And this they did, it being in their view a testimony to God, and also to men, that they never would use weapons again for the shedding of man's blood; and this they did, vouching and covenanting with God, that rather than shed the blood of their brethren they would give up their own lives; and rather than take away from a brother they would give unto him; and rather than spend their days in idleness they would labor abundantly with their hands.
34316	1308	19	And thus we see that, when these Lamanites were brought to believe and to know the truth, they were firm, and would suffer even unto death rather than commit sin; and thus we see that they buried their weapons of peace, or they buried the weapons of war, for peace.
34317	1308	20	And it came to pass that their brethren, the Lamanites, made preparations for war, and came up to the land of Nephi for the purpose of destroying the king, and to place another in his stead, and also of destroying the people of Anti-Nephi-Lehi out of the land.
34318	1308	21	Now when the people saw that they were coming against them they went out to meet them, and prostrated themselves before them to the earth, and began to call on the name of the Lord; and thus they were in this attitude when the Lamanites began to fall upon them, and began to slay them with the sword.
34319	1308	22	And thus without meeting any resistance, they did slay a thousand and five of them; and we know that they are blessed, for they have gone to dwell with their God.
34320	1308	23	Now when the Lamanites saw that their brethren would not flee from the sword, neither would they turn aside to the right hand or to the left, but that they would lie down and perish, and praised God even in the very act of perishing under the sword--
34321	1308	24	Now when the Lamanites saw this they did forbear from slaying them; and there were many whose hearts had swollen in them for those of their brethren who had fallen under the sword, for they repented of the things which they had done.
34322	1308	25	And it came to pass that they threw down their weapons of war, and they would not take them again, for they were stung for the murders which they had committed; and they came down even as their brethren, relying upon the mercies of those whose arms were lifted to slay them.
34323	1308	26	And it came to pass that the people of God were joined that day by more than the number who had been slain; and those who had been slain were righteous people, therefore we have no reason to doubt but what they were saved.
34324	1308	27	And there was not a wicked man slain among them; but there were more than a thousand brought to the knowledge of the truth; thus we see that the Lord worketh in many ways to the salvation of his people.
34325	1308	28	Now the greatest number of those of the Lamanites who slew so many of their brethren were Amalekites and Amulonites, the greatest number of whom were after the order of the Nehors.
34326	1308	29	Now, among those who joined the people of the Lord, there were none who were Amalekites or Amulonites, or who were of the order of Nehor, but they were actual descendants of Laman and Lemuel.
34327	1308	30	And thus we can plainly discern, that after a people have been once enlightened by the Spirit of God, and have had great knowledge of things pertaining to righteousness, and then have fallen away into sin and transgression, they become more hardened, and thus their state becomes worse than though they had never known these things.
34328	1309	1	And behold, now it came to pass that those Lamanites were more angry because they had slain their brethren; therefore they swore vengeance upon the Nephites; and they did no more attempt to slay the people of Anti-Nephi-Lehi at that time.
34329	1309	2	But they took their armies and went over into the borders of the land of Zarahemla, and fell upon the people who were in the land of Ammonihah and destroyed them.
34330	1309	3	And after that, they had many battles with the Nephites, in the which they were driven and slain.
34331	1309	4	And among the Lamanites who were slain were almost all the seed of Amulon and his brethren, who were the priests of Noah, and they were slain by the hands of the Nephites;
34332	1309	5	And the remainder, having fled into the east wilderness, and having usurped the power and authority over the Lamanites, caused that many of the Lamanites should perish by fire because of their belief--
34333	1309	6	For many of them, after having suffered much loss and so many afflictions, began to be stirred up in remembrance of the words which Aaron and his brethren had preached to them in their land; therefore they began to disbelieve the traditions of their fathers, and to believe in the Lord, and that he gave great power unto the Nephites; and thus there were many of them converted in the wilderness.
34334	1309	7	And it came to pass that those rulers who were the remnant of the children of Amulon caused that they should be put to death, yea, all those that believed in these things.
34335	1309	8	Now this martyrdom caused that many of their brethren should be stirred up to anger; and there began to be contention in the wilderness; and the Lamanites began to hunt the seed of Amulon and his brethren and began to slay them; and they fled into the east wilderness.
34336	1309	9	And behold they are hunted at this day by the Lamanites. Thus the words of Abinadi were brought to pass, which he said concerning the seed of the priests who caused that he should suffer death by fire.
34337	1309	10	For he said unto them: What ye shall do unto me shall be a type of things to come.
34338	1309	11	And now Abinadi was the first that suffered death by fire because of his belief in God; now this is what he meant, that many should suffer death by fire, according as he had suffered.
34339	1309	12	And he said unto the priests of Noah that their seed should cause many to be put to death, in the like manner as he was, and that they should be scattered abroad and slain, even as a sheep having no shepherd is driven and slain by wild beasts; and now behold, these words were verified, for they were driven by the Lamanites, and they were hunted, and they were smitten.
34340	1309	13	And it came to pass that when the Lamanites saw that they could not overpower the Nephites they returned again to their own land; and many of them came over to dwell in the land of Ishmael and the land of Nephi, and did join themselves to the people of God, who were the people of Anti-Nephi-Lehi.
34341	1309	14	And they did also bury their weapons of war, according as their brethren had, and they began to be a righteous people; and they did walk in the ways of the Lord, and did observe to keep his commandments and his statutes.
34342	1309	15	Yea, and they did keep the law of Moses; for it was expedient that they should keep the law of Moses as yet, for it was not all fulfilled. But notwithstanding the law of Moses, they did look forward to the coming of Christ, considering that the law of Moses was a type of his coming, and believing that they must keep those outward performances until the time that he should be revealed unto them.
34343	1309	16	Now they did not suppose that salvation came by the law of Moses; but the law of Moses did serve to strengthen their faith in Christ; and thus they did retain a hope through faith, unto eternal salvation, relying upon the spirit of prophecy, which spake of those things to come.
34344	1309	17	And now behold, Ammon, and Aaron, and Omner, and Himni, and their brethren did rejoice exceedingly, for the success which they had had among the Lamanites, seeing that the Lord had granted unto them according to their prayers, and that he had also verified his word unto them in every particular.
34345	1310	1	And now, these are the words of Ammon to his brethren, which say thus: My brothers and my brethren, behold I say unto you, how great reason have we to rejoice; for could we have supposed when we started from the land of Zarahemla that God would have granted unto us such great blessings?
34346	1310	2	And now, I ask, what great blessings has he bestowed upon us? Can ye tell?
34347	1310	3	Behold, I answer for you; for our brethren, the Lamanites, were in darkness, yea, even in the darkest abyss, but behold, how many of them are brought to behold the marvelous light of God! And this is the blessing which hath been bestowed upon us, that we have been made instruments in the hands of God to bring about this great work.
34348	1310	4	Behold, thousands of them do rejoice, and have been brought into the fold of God.
34349	1310	5	Behold, the field was ripe, and blessed are ye, for ye did thrust in the sickle, and did reap with your might, yea, all the day long did ye labor; and behold the number of your sheaves! And they shall be gathered into the garners, that they are not wasted.
34350	1310	6	Yea, they shall not be beaten down by the storm at the last day; yea, neither shall they be harrowed up by the whirlwinds; but when the storm cometh they shall be gathered together in their place, that the storm cannot penetrate to them; yea, neither shall they be driven with fierce winds whithersoever the enemy listeth to carry them.
34351	1310	7	But behold, they are in the hands of the Lord of the harvest, and they are his; and he will raise them up at the last day.
34352	1310	8	Blessed be the name of our God; let us sing to his praise, yea, let us give thanks to his holy name, for he doth work righteousness forever.
34353	1310	9	For if we had not come up out of the land of Zarahemla, these our dearly beloved brethren, who have so dearly beloved us, would still have been racked with hatred against us, yea, and they would also have been strangers to God.
34354	1310	10	And it came to pass that when Ammon had said these words, his brother Aaron rebuked him, saying: Ammon, I fear that thy joy doth carry thee away unto boasting.
34355	1310	11	But Ammon said unto him: I do not boast in my own strength, nor in my own wisdom; but behold, my joy is full, yea, my heart is brim with joy, and I will rejoice in my God.
34356	1310	12	Yea, I know that I am nothing; as to my strength I am weak; therefore I will not boast of myself, but I will boast of my God, for in his strength I can do all things; yea, behold, many mighty miracles we have wrought in this land, for which we will praise his name forever.
34357	1310	13	Behold, how many thousands of our brethren has he loosed from the pains of hell; and they are brought to sing redeeming love, and this because of the power of his word which is in us, therefore have we not great reason to rejoice?
34358	1310	14	Yea, we have reason to praise him forever, for he is the Most High God, and has loosed our brethren from the chains of hell.
34359	1310	15	Yea, they were encircled about with everlasting darkness and destruction; but behold, he has brought them into his everlasting light, yea, into everlasting salvation; and they are encircled about with the matchless bounty of his love; yea, and we have been instruments in his hands of doing this great and marvelous work.
34360	1310	16	Therefore, let us glory, yea, we will glory in the Lord; yea, we will rejoice, for our joy is full; yea, we will praise our God forever. Behold, who can glory too much in the Lord? Yea, who can say too much of his great power, and of his mercy, and of his long-suffering towards the children of men? Behold, I say unto you, I cannot say the smallest part which I feel.
34361	1310	17	Who could have supposed that our God would have been so merciful as to have snatched us from our awful, sinful, and polluted state?
34362	1310	18	Behold, we went forth even in wrath, with mighty threatenings to destroy his church.
34363	1310	19	Oh then, why did he not consign us to an awful destruction, yea, why did he not let the sword of his justice fall upon us, and doom us to eternal despair?
34364	1310	20	Oh, my soul, almost as it were, fleeth at the thought. Behold, he did not exercise his justice upon us, but in his great mercy hath brought us over that everlasting gulf of death and misery, even to the salvation of our souls.
34365	1310	21	And now behold, my brethren, what natural man is there that knoweth these things? I say unto you, there is none that knoweth these things, save it be the penitent.
34366	1310	22	Yea, he that repenteth and exerciseth faith, and bringeth forth good works, and prayeth continually without ceasing--unto such it is given to know the mysteries of God; yea, unto such it shall be given to reveal things which never have been revealed; yea, and it shall be given unto such to bring thousands of souls to repentance, even as it has been given unto us to bring these our brethren to repentance.
34367	1310	23	Now do ye remember, my brethren, that we said unto our brethren in the land of Zarahemla, we go up to the land of Nephi, to preach unto our brethren, the Lamanites, and they laughed us to scorn?
34368	1310	24	For they said unto us: Do ye suppose that ye can bring the Lamanites to the knowledge of the truth? Do ye suppose that ye can convince the Lamanites of the incorrectness of the traditions of their fathers, as stiffnecked a people as they are; whose hearts delight in the shedding of blood; whose days have been spent in the grossest iniquity; whose ways have been the ways of a transgressor from the beginning? Now my brethren, ye remember that this was their language.
34369	1310	25	And moreover they did say: Let us take up arms against them, that we destroy them and their iniquity out of the land, lest they overrun us and destroy us.
34370	1310	26	But behold, my beloved brethren, we came into the wilderness not with the intent to destroy our brethren, but with the intent that perhaps we might save some few of their souls.
34371	1310	27	Now when our hearts were depressed, and we were about to turn back, behold, the Lord comforted us, and said: Go amongst thy brethren, the Lamanites, and bear with patience thine afflictions, and I will give unto you success.
34372	1310	28	And now behold, we have come, and been forth amongst them; and we have been patient in our sufferings, and we have suffered every privation; yea, we have traveled from house to house, relying upon the mercies of the world--not upon the mercies of the world alone but upon the mercies of God.
34373	1310	29	And we have entered into their houses and taught them, and we have taught them in their streets; yea, and we have taught them upon their hills; and we have also entered into their temples and their synagogues and taught them; and we have been cast out, and mocked, and spit upon, and smote upon our cheeks; and we have been stoned, and taken and bound with strong cords, and cast into prison; and through the power and wisdom of God we have been delivered again.
34374	1310	30	And we have suffered all manner of afflictions, and all this, that perhaps we might be the means of saving some soul; and we supposed that our joy would be full if perhaps we could be the means of saving some.
34375	1310	31	Now behold, we can look forth and see the fruits of our labors; and are they few? I say unto you, Nay, they are many; yea, and we can witness of their sincerity, because of their love towards their brethren and also towards us.
34376	1310	32	For behold, they had rather sacrifice their lives than even to take the life of their enemy; and they have buried their weapons of war deep in the earth, because of their love towards their brethren.
34377	1310	33	And now behold I say unto you, has there been so great love in all the land? Behold, I say unto you, Nay, there has not, even among the Nephites.
34378	1310	34	For behold, they would take up arms against their brethren; they would not suffer themselves to be slain. But behold how many of these have laid down their lives; and we know that they have gone to their God, because of their love and of their hatred to sin.
34379	1310	35	Now have we not reason to rejoice? Yea, I say unto you, there never were men that had so great reason to rejoice as we, since the world began; yea, and my joy is carried away, even unto boasting in my God; for he has all power, all wisdom, and all understanding; he comprehendeth all things, and he is a merciful Being, even unto salvation, to those who will repent and believe on his name.
34380	1310	36	Now if this is boasting, even so will I boast; for this is my life and my light, my joy and my salvation, and my redemption from everlasting wo. Yea, blessed is the name of my God, who has been mindful of this people, who are a branch of the tree of Israel, and has been lost from its body in a strange land; yea, I say, blessed be the name of my God, who has been mindful of us, wanderers in a strange land.
34381	1310	37	Now my brethren, we see that God is mindful of every people, whatsoever land they may be in; yea, he numbereth his people, and his bowels of mercy are over all the earth. Now this is my joy, and my great thanksgiving; yea, and I will give thanks unto my God forever. Amen.
34382	1311	1	Now it came to pass that when those Lamanites who had gone to war against the Nephites had found, after their many struggles to destroy them, that it was in vain to seek their destruction, they returned again to the land of Nephi.
34383	1311	2	And it came to pass that the Amalekites, because of their loss, were exceedingly angry. And when they saw that they could not seek revenge from the Nephites, they began to stir up the people in anger against their brethren, the people of Anti-Nephi-Lehi; therefore they began again to destroy them.
34384	1311	3	Now this people again refused to take their arms, and they suffered themselves to be slain according to the desires of their enemies.
34385	1311	4	Now when Ammon and his brethren saw this work of destruction among those whom they so dearly beloved, and among those who had so dearly beloved them--for they were treated as though they were angels sent from God to save them from everlasting destruction--therefore, when Ammon and his brethren saw this great work of destruction, they were moved with compassion, and they said unto the king:
34386	1311	5	Let us gather together this people of the Lord, and let us go down to the land of Zarahemla to our brethren the Nephites, and flee out of the hands of our enemies, that we be not destroyed.
34387	1311	6	But the king said unto them: Behold, the Nephites will destroy us, because of the many murders and sins we have committed against them.
34388	1311	7	And Ammon said: I will go and inquire of the Lord, and if he say unto us, go down unto our brethren, will ye go?
34389	1311	8	And the king said unto him: Yea, if the Lord saith unto us go, we will go down unto our brethren, and we will be their slaves until we repair unto them the many murders and sins which we have committed against them.
34390	1311	9	But Ammon said unto him: It is against the law of our brethren, which was established by my father, that there should be any slaves among them; therefore let us go down and rely upon the mercies of our brethren.
34391	1311	10	But the king said unto him: Inquire of the Lord, and if he saith unto us go, we will go; otherwise we will perish in the land.
34392	1311	11	And it came to pass that Ammon went and inquired of the Lord, and the Lord said unto him:
34393	1311	12	Get this people out of this land, that they perish not; for Satan has great hold on the hearts of the Amalekites, who do stir up the Lamanites to anger against their brethren to slay them; therefore get thee out of this land; and blessed are this people in this generation, for I will preserve them.
34394	1311	13	And now it came to pass that Ammon went and told the king all the words which the Lord had said unto him.
34395	1311	14	And they gathered together all their people, yea, all the people of the Lord, and did gather together all their flocks and herds, and departed out of the land, and came into the wilderness which divided the land of Nephi from the land of Zarahemla, and came over near the borders of the land.
34396	1311	15	And it came to pass that Ammon said unto them: Behold, I and my brethren will go forth into the land of Zarahemla, and ye shall remain here until we return; and we will try the hearts of our brethren, whether they will that ye shall come into their land.
34397	1311	16	And it came to pass that as Ammon was going forth into the land, that he and his brethren met Alma, over in the place of which has been spoken; and behold, this was a joyful meeting.
34398	1311	17	Now the joy of Ammon was so great even that he was full; yea, he was swallowed up in the joy of his God, even to the exhausting of his strength; and he fell again to the earth.
34399	1311	18	Now was not this exceeding joy? Behold, this is joy which none receiveth save it be the truly penitent and humble seeker of happiness.
34400	1311	19	Now the joy of Alma in meeting his brethren was truly great, and also the joy of Aaron, of Omner, and Himni; but behold their joy was not that to exceed their strength.
34401	1311	20	And now it came to pass that Alma conducted his brethren back to the land of Zarahemla; even to his own house. And they went and told the chief judge all the things that had happened unto them in the land of Nephi, among their brethren, the Lamanites.
34402	1311	21	And it came to pass that the chief judge sent a proclamation throughout all the land, desiring the voice of the people concerning the admitting their brethren, who were the people of Anti-Nephi-Lehi.
34403	1311	22	And it came to pass that the voice of the people came, saying: Behold, we will give up the land of Jershon, which is on the east by the sea, which joins the land Bountiful, which is on the south of the land Bountiful; and this land Jershon is the land which we will give unto our brethren for an inheritance.
34404	1311	23	And behold, we will set our armies between the land Jershon and the land Nephi, that we may protect our brethren in the land Jershon; and this we do for our brethren, on account of their fear to take up arms against their brethren lest they should commit sin; and this their great fear came because of their sore repentance which they had, on account of their many murders and their awful wickedness.
34405	1311	24	And now behold, this will we do unto our brethren, that they may inherit the land Jershon; and we will guard them from their enemies with our armies, on condition that they will give us a portion of their substance to assist us that we may maintain our armies.
34406	1311	25	Now, it came to pass that when Ammon had heard this, he returned to the people of Anti-Nephi-Lehi, and also Alma with him, into the wilderness, where they had pitched their tents, and made known unto them all these things. And Alma also related unto them his conversion, with Ammon and Aaron, and his brethren.
34407	1311	26	And it came to pass that it did cause great joy among them. And they went down into the land of Jershon, and took possession of the land of Jershon; and they were called by the Nephites the people of Ammon; therefore they were distinguished by that name ever after.
34408	1311	27	And they were among the people of Nephi, and also numbered among the people who were of the church of God. And they were also distinguished for their zeal towards God, and also towards men; for they were perfectly honest and upright in all things; and they were firm in the faith of Christ, even unto the end.
34409	1311	28	And they did look upon shedding the blood of their brethren with the greatest abhorrence; and they never could be prevailed upon to take up arms against their brethren; and they never did look upon death with any degree of terror, for their hope and views of Christ and the resurrection; therefore, death was swallowed up to them by the victory of Christ over it.
34410	1311	29	Therefore, they would suffer death in the most aggravating and distressing manner which could be inflicted by their brethren, before they would take the sword or cimeter to smite them.
34411	1311	30	And thus they were a zealous and beloved people, a highly favored people of the Lord.
34412	1312	1	And now it came to pass that after the people of Ammon were established in the land of Jershon, and a church also established in the land of Jershon, and the armies of the Nephites were set round about the land of Jershon, yea, in all the borders round about the land of Zarahemla; behold the armies of the Lamanites had followed their brethren into the wilderness.
34413	1312	2	And thus there was a tremendous battle; yea, even such an one as never had been known among all the people in the land from the time Lehi left Jerusalem; yea, and tens of thousands of the Lamanites were slain and scattered abroad.
34414	1312	3	Yea, and also there was a tremendous slaughter among the people of Nephi; nevertheless, the Lamanites were driven and scattered, and the people of Nephi returned again to their land.
34415	1312	4	And now this was a time that there was a great mourning and lamentation heard throughout all the land, among all the people of Nephi--
34416	1312	5	Yea, the cry of widows mourning for their husbands, and also of fathers mourning for their sons, and the daughter for the brother, yea, the brother for the father; and thus the cry of mourning was heard among all of them, mourning for their kindred who had been slain.
34417	1312	6	And now surely this was a sorrowful day; yea, a time of solemnity, and a time of much fasting and prayer.
34418	1312	7	And thus endeth the fifteenth year of the reign of the judges over the people of Nephi;
34419	1312	8	And this is the account of Ammon and his brethren, their journeyings in the land of Nephi, their sufferings in the land, their sorrows, and their afflictions, and their incomprehensible joy, and the reception and safety of the brethren in the land of Jershon. And now may the Lord, the Redeemer of all men, bless their souls forever.
34420	1312	9	And this is the account of the wars and contentions among the Nephites, and also the wars between the Nephites and the Lamanites; and the fifteenth year of the reign of the judges is ended.
34421	1312	10	And from the first year to the fifteenth has brought to pass the destruction of many thousand lives; yea, it has brought to pass an awful scene of bloodshed.
34422	1312	11	And the bodies of many thousands are laid low in the earth, while the bodies of many thousands are moldering in heaps upon the face of the earth; yea, and many thousands are mourning for the loss of their kindred, because they have reason to fear, according to the promises of the Lord, that they are consigned to a state of endless wo.
34423	1312	12	While many thousands of others truly mourn for the loss of their kindred, yet they rejoice and exult in the hope, and even know, according to the promises of the Lord, that they are raised to dwell at the right hand of God, in a state of never-ending happiness.
34424	1312	13	And thus we see how great the inequality of man is because of sin and transgression, and the power of the devil, which comes by the cunning plans which he hath devised to ensnare the hearts of men.
34425	1312	14	And thus we see the great call of diligence of men to labor in the vineyards of the Lord; and thus we see the great reason of sorrow, and also of rejoicing--sorrow because of death and destruction among men, and joy because of the light of Christ unto life.
34426	1313	1	O that I were an angel, and could have the wish of mine heart, that I might go forth and speak with the trump of God, with a voice to shake the earth, and cry repentance unto every people!
34427	1313	2	Yea, I would declare unto every soul, as with the voice of thunder, repentance and the plan of redemption, that they should repent and come unto our God, that there might not be more sorrow upon all the face of the earth.
34428	1313	3	But behold, I am a man, and do sin in my wish; for I ought to be content with the things which the Lord hath allotted unto me.
34429	1313	4	I ought not to harrow up in my desires, the firm decree of a just God, for I know that he granteth unto men according to their desire, whether it be unto death or unto life; yea, I know that he allotteth unto men, yea, decreeth unto them decrees which are unalterable, according to their wills, whether they be unto salvation or unto destruction.
34430	1313	5	Yea, and I know that good and evil have come before all men; he that knoweth not good from evil is blameless; but he that knoweth good and evil, to him it is given according to his desires, whether he desireth good or evil, life or death, joy or remorse of conscience.
34431	1313	6	Now, seeing that I know these things, why should I desire more than to perform the work to which I have been called?
34432	1313	7	Why should I desire that I were an angel, that I could speak unto all the ends of the earth?
34433	1313	8	For behold, the Lord doth grant unto all nations, of their own nation and tongue, to teach his word, yea, in wisdom, all that he seeth fit that they should have; therefore we see that the Lord doth counsel in wisdom, according to that which is just and true.
34434	1313	9	I know that which the Lord hath commanded me, and I glory in it. I do not glory of myself, but I glory in that which the Lord hath commanded me; yea, and this is my glory, that perhaps I may be an instrument in the hands of God to bring some soul to repentance; and this is my joy.
34435	1313	10	And behold, when I see many of my brethren truly penitent, and coming to the Lord their God, then is my soul filled with joy; then do I remember what the Lord has done for me, yea, even that he hath heard my prayer; yea, then do I remember his merciful arm which he extended towards me.
34436	1313	11	Yea, and I also remember the captivity of my fathers; for I surely do know that the Lord did deliver them out of bondage, and by this did establish his church; yea, the Lord God, the God of Abraham, the God of Isaac, and the God of Jacob, did deliver them out of bondage.
34437	1313	12	Yea, I have always remembered the captivity of my fathers; and that same God who delivered them out of the hands of the Egyptians did deliver them out of bondage.
34438	1313	13	Yea, and that same God did establish his church among them; yea, and that same God hath called me by a holy calling, to preach the word unto this people, and hath given me much success, in the which my joy is full.
34439	1313	14	But I do not joy in my own success alone, but my joy is more full because of the success of my brethren, who have been up to the land of Nephi.
34440	1313	15	Behold, they have labored exceedingly, and have brought forth much fruit; and how great shall be their reward!
34441	1313	16	Now, when I think of the success of these my brethren my soul is carried away, even to the separation of it from the body, as it were, so great is my joy.
34442	1313	17	And now may God grant unto these, my brethren, that they may sit down in the kingdom of God; yea, and also all those who are the fruit of their labors that they may go no more out, but that they may praise him forever. And may God grant that it may be done according to my words, even as I have spoken. Amen.
34443	1314	1	Behold, now it came to pass that after the people of Ammon were established in the land of Jershon, yea, and also after the Lamanites were driven out of the land, and their dead were buried by the people of the land--
34444	1314	2	Now their dead were not numbered because of the greatness of their numbers; neither were the dead of the Nephites numbered--but it came to pass after they had buried their dead, and also after the days of fasting, and mourning, and prayer, (and it was in the sixteenth year of the reign of the judges over the people of Nephi) there began to be continual peace throughout all the land.
34445	1314	3	Yea, and the people did observe to keep the commandments of the Lord; and they were strict in observing the ordinances of God, according to the law of Moses; for they were taught to keep the law of Moses until it should be fulfilled.
34446	1314	4	And thus the people did have no disturbance in all the sixteenth year of the reign of the judges over the people of Nephi.
34447	1314	5	And it came to pass that in the commencement of the seventeenth year of the reign of the judges, there was continual peace.
34448	1314	6	But it came to pass in the latter end of the seventeenth year, there came a man into the land of Zarahemla, and he was Anti-Christ, for he began to preach unto the people against the prophecies which had been spoken by the prophets, concerning the coming of Christ.
34449	1314	7	Now there was no law against a man's belief; for it was strictly contrary to the commands of God that there should be a law which should bring men on to unequal grounds.
34450	1314	8	For thus saith the scripture: Choose ye this day, whom ye will serve.
34451	1314	9	Now if a man desired to serve God, it was his privilege; or rather, if he believed in God it was his privilege to serve him; but if he did not believe in him there was no law to punish him.
34452	1314	10	But if he murdered he was punished unto death; and if he robbed he was also punished; and if he stole he was also punished; and if he committed adultery he was also punished; yea, for all this wickedness they were punished.
34453	1314	11	For there was a law that men should be judged according to their crimes. Nevertheless, there was no law against a man's belief; therefore, a man was punished only for the crimes which he had done; therefore all men were on equal grounds.
34454	1314	12	And this Anti-Christ, whose name was Korihor, (and the law could have no hold upon him) began to preach unto the people that there should be no Christ. And after this manner did he preach, saying:
34455	1314	13	O ye that are bound down under a foolish and a vain hope, why do ye yoke yourselves with such foolish things? Why do ye look for a Christ? For no man can know of anything which is to come.
34456	1314	14	Behold, these things which ye call prophecies, which ye say are handed down by holy prophets, behold, they are foolish traditions of your fathers.
34457	1314	15	How do ye know of their surety? Behold, ye cannot know of things which ye do not see; therefore ye cannot know that there shall be a Christ.
34458	1314	16	Ye look forward and say that ye see a remission of your sins. But behold, it is the effect of a frenzied mind; and this derangement of your minds comes because of the traditions of your fathers, which lead you away into a belief of things which are not so.
34459	1314	17	And many more such things did he say unto them, telling them that there could be no atonement made for the sins of men, but every man fared in this life according to the management of the creature; therefore every man prospered according to his genius, and that every man conquered according to his strength; and whatsoever a man did was no crime.
34460	1314	18	And thus he did preach unto them, leading away the hearts of many, causing them to lift up their heads in their wickedness, yea, leading away many women, and also men, to commit whoredoms--telling them that when a man was dead, that was the end thereof.
34461	1314	19	Now this man went over to the land of Jershon also, to preach these things among the people of Ammon, who were once the people of the Lamanites.
34462	1314	20	But behold they were more wise than many of the Nephites; for they took him, and bound him, and carried him before Ammon, who was a high priest over that people.
34463	1314	21	And it came to pass that he caused that he should be carried out of the land. And he came over into the land of Gideon, and began to preach unto them also; and here he did not have much success, for he was taken and bound and carried before the high priest, and also the chief judge over the land.
34464	1314	22	And it came to pass that the high priest said unto him: Why do ye go about perverting the ways of the Lord? Why do ye teach this people that there shall be no Christ, to interrupt their rejoicings? Why do ye speak against all the prophecies of the holy prophets?
34465	1314	23	Now the high priest's name was Giddonah. And Korihor said unto him: Because I do not teach the foolish traditions of your fathers, and because I do not teach this people to bind themselves down under the foolish ordinances and performances which are laid down by ancient priests, to usurp power and authority over them, to keep them in ignorance, that they may not lift up their heads, but be brought down according to thy words.
34466	1314	24	Ye say that this people is a free people. Behold, I say they are in bondage. Ye say that those ancient prophecies are true. Behold, I say that ye do not know that they are true.
34467	1314	25	Ye say that this people is a guilty and a fallen people, because of the transgression of a parent. Behold, I say that a child is not guilty because of its parents.
34468	1314	26	And ye also say that Christ shall come. But behold, I say that ye do not know that there shall be a Christ. And ye say also that he shall be slain for the sins of the world--
34469	1314	27	And thus ye lead away this people after the foolish traditions of your fathers, and according to your own desires; and ye keep them down, even as it were in bondage, that ye may glut yourselves with the labors of their hands, that they durst not look up with boldness, and that they durst not enjoy their rights and privileges.
34470	1314	28	Yea, they durst not make use of that which is their own lest they should offend their priests, who do yoke them according to their desires, and have brought them to believe, by their traditions and their dreams and their whims and their visions and their pretended mysteries, that they should, if they did not do according to their words, offend some unknown being, who they say is God--a being who never has been seen or known, who never was nor ever will be.
34471	1314	29	Now when the high priest and the chief judge saw the hardness of his heart, yea, when they saw that he would revile even against God, they would not make any reply to his words; but they caused that he should be bound; and they delivered him up into the hands of the officers, and sent him to the land of Zarahemla, that he might be brought before Alma, and the chief judge who was governor over all the land.
34472	1314	30	And it came to pass that when he was brought before Alma and the chief judge, he did go on in the same manner as he did in the land of Gideon; yea, he went on to blaspheme.
34473	1314	31	And he did rise up in great swelling words before Alma, and did revile against the priests and teachers, accusing them of leading away the people after the silly traditions of their fathers, for the sake of glutting on the labors of the people.
34474	1314	32	Now Alma said unto him: Thou knowest that we do not glut ourselves upon the labors of this people; for behold I have labored even from the commencement of the reign of the judges until now, with mine own hands for my support, notwithstanding my many travels round about the land to declare the word of God unto my people.
34475	1314	33	And notwithstanding the many labors which I have performed in the church, I have never received so much as even one senine for my labor; neither has any of my brethren, save it were in the judgment-seat; and then we have received only according to law for our time.
34476	1314	34	And now, if we do not receive anything for our labors in the church, what doth it profit us to labor in the church save it were to declare the truth, that we may have rejoicings in the joy of our brethren?
34477	1314	35	Then why sayest thou that we preach unto this people to get gain, when thou, of thyself, knowest that we receive no gain? And now, believest thou that we deceive this people, that causes such joy in their hearts?
34478	1314	36	And Korihor answered him, Yea.
34479	1314	37	And then Alma said unto him: Believest thou that there is a God?
34480	1314	38	And he answered, Nay.
34481	1314	39	Now Alma said unto him: Will ye deny again that there is a God, and also deny the Christ? For behold, I say unto you, I know there is a God, and also that Christ shall come.
34482	1314	40	And now what evidence have ye that there is no God, or that Christ cometh not? I say unto you that ye have none, save it be your word only.
34483	1314	41	But, behold, I have all things as a testimony that these things are true; and ye also have all things as a testimony unto you that they are true; and will ye deny them? Believest thou that these things are true?
34484	1314	42	Behold, I know that thou believest, but thou art possessed with a lying spirit, and ye have put off the Spirit of God that it may have no place in you; but the devil has power over you, and he doth carry you about, working devices that he may destroy the children of God.
34485	1314	43	And now Korihor said unto Alma: If thou wilt show me a sign, that I may be convinced that there is a God, yea, show unto me that he hath power, and then will I be convinced of the truth of thy words.
34486	1314	44	But Alma said unto him: Thou hast had signs enough; will ye tempt your God? Will ye say, Show unto me a sign, when ye have the testimony of all these thy brethren, and also all the holy prophets? The scriptures are laid before thee, yea, and all things denote there is a God; yea, even the earth, and all things that are upon the face of it, yea, and its motion, yea, and also all the planets which move in their regular form do witness that there is a Supreme Creator.
34487	1314	45	And yet do ye go about, leading away the hearts of this people, testifying unto them there is no God? And yet will ye deny against all these witnesses? And he said: Yea, I will deny, except ye shall show me a sign.
34488	1314	46	And now it came to pass that Alma said unto him: Behold, I am grieved because of the hardness of your heart, yea, that ye will still resist the spirit of the truth, that thy soul may be destroyed.
34489	1314	47	But behold, it is better that thy soul should be lost than that thou shouldst be the means of bringing many souls down to destruction, by thy lying and by thy flattering words; therefore if thou shalt deny again, behold God shall smite thee, that thou shalt become dumb, that thou shalt never open thy mouth any more, that thou shalt not deceive this people any more.
34490	1314	48	Now Korihor said unto him: I do not deny the existence of a God, but I do not believe that there is a God; and I say also, that ye do not know that there is a God; and except ye show me a sign, I will not believe.
34491	1314	49	Now Alma said unto him: This will I give unto thee for a sign, that thou shalt be struck dumb, according to my words; and I say, that in the name of God, ye shall be struck dumb, that ye shall no more have utterance.
34492	1314	50	Now when Alma had said these words, Korihor was struck dumb, that he could not have utterance, according to the words of Alma.
34493	1314	51	And now when the chief judge saw this, he put forth his hand and wrote unto Korihor, saying: Art thou convinced of the power of God? In whom did ye desire that Alma should show forth his sign? Would ye that he should afflict others, to show unto thee a sign? Behold, he has showed unto you a sign; and now will ye dispute more?
34494	1314	52	And Korihor put forth his hand and wrote, saying: I know that I am dumb, for I cannot speak; and I know that nothing save it were the power of God could bring this upon me; yea, and I always knew that there was a God.
34495	1314	53	But behold, the devil hath deceived me; for he appeared unto me in the form of an angel, and said unto me: Go and reclaim this people, for they have all gone astray after an unknown God. And he said unto me: There is no God; yea, and he taught me that which I should say. And I have taught his words; and I taught them because they were pleasing unto the carnal mind; and I taught them, even until I had much success, insomuch that I verily believed that they were true; and for this cause I withstood the truth, even until I have brought this great curse upon me.
34496	1314	54	Now when he had said this, he besought that Alma should pray unto God, that the curse might be taken from him.
34497	1314	55	But Alma said unto him: If this curse should be taken from thee thou wouldst again lead away the hearts of this people; therefore, it shall be unto thee even as the Lord will.
34498	1314	56	And it came to pass that the curse was not taken off of Korihor; but he was cast out, and went about from house to house begging for his food.
34499	1314	57	Now the knowledge of what had happened unto Korihor was immediately published throughout all the land; yea, the proclamation was sent forth by the chief judge to all the people in the land, declaring unto those who had believed in the words of Korihor that they must speedily repent, lest the same judgments would come unto them.
34500	1314	58	And it came to pass that they were all convinced of the wickedness of Korihor; therefore they were all converted again unto the Lord; and this put an end to the iniquity after the manner of Korihor. And Korihor did go about from house to house, begging food for his support.
34501	1314	59	And it came to pass that as he went forth among the people, yea, among a people who had separated themselves from the Nephites and called themselves Zoramites, being led by a man whose name was Zoram--and as he went forth amongst them, behold, he was run upon and trodden down, even until he was dead.
34502	1314	60	And thus we see the end of him who perverteth the ways of the Lord; and thus we see that the devil will not support his children at the last day, but doth speedily drag them down to hell.
34503	1315	1	Now it came to pass that after the end of Korihor, Alma having received tidings that the Zoramites were perverting the ways of the Lord, and that Zoram, who was their leader, was leading the hearts of the people to bow down to dumb idols, his heart again began to sicken because of the iniquity of the people.
34504	1315	2	For it was the cause of great sorrow to Alma to know of iniquity among his people; therefore his heart was exceedingly sorrowful because of the separation of the Zoramites from the Nephites.
34505	1315	3	Now the Zoramites had gathered themselves together in a land which they called Antionum, which was east of the land of Zarahemla, which lay nearly bordering upon the seashore, which was south of the land of Jershon, which also bordered upon the wilderness south, which wilderness was full of the Lamanites.
34506	1315	4	Now the Nephites greatly feared that the Zoramites would enter into a correspondence with the Lamanites, and that it would be the means of great loss on the part of the Nephites.
34507	1315	5	And now, as the preaching of the word had a great tendency to lead the people to do that which was just--yea, it had had more powerful effect upon the minds of the people than the sword, or anything else, which had happened unto them--therefore Alma thought it was expedient that they should try the virtue of the word of God.
34508	1315	6	Therefore he took Ammon, and Aaron, and Omner; and Himni he did leave in the church in Zarahemla; but the former three he took with him, and also Amulek and Zeezrom, who were at Melek; and he also took two of his sons.
34509	1315	7	Now the eldest of his sons he took not with him, and his name was Helaman; but the names of those whom he took with him were Shiblon and Corianton; and these are the names of those who went with him among the Zoramites, to preach unto them the word.
34510	1315	8	Now the Zoramites were dissenters from the Nephites; therefore they had had the word of God preached unto them.
34511	1315	9	But they had fallen into great errors, for they would not observe to keep the commandments of God, and his statutes, according to the law of Moses.
34512	1315	10	Neither would they observe the performances of the church, to continue in prayer and supplication to God daily, that they might not enter into temptation.
34513	1315	11	Yea, in fine, they did pervert the ways of the Lord in very many instances; therefore, for this cause, Alma and his brethren went into the land to preach the word unto them.
34514	1315	12	Now, when they had come into the land, behold, to their astonishment they found that the Zoramites had built synagogues, and that they did gather themselves together on one day of the week, which day they did call the day of the Lord; and they did worship after a manner which Alma and his brethren had never beheld;
34515	1315	13	For they had a place built up in the center of their synagogue, a place for standing, which was high above the head; and the top thereof would only admit one person.
34516	1315	14	Therefore, whosoever desired to worship must go forth and stand upon the top thereof, and stretch forth his hands towards heaven, and cry with a loud voice, saying:
34517	1315	15	Holy, holy God; we believe that thou art God, and we believe that thou art holy, and that thou wast a spirit, and that thou art a spirit, and that thou wilt be a spirit forever.
34518	1315	16	Holy God, we believe that thou hast separated us from our brethren; and we do not believe in the tradition of our brethren, which was handed down to them by the childishness of their fathers; but we believe that thou hast elected us to be thy holy children; and also thou hast made it known unto us that there shall be no Christ.
34519	1315	17	But thou art the same yesterday, today, and forever; and thou hast elected us that we shall be saved, whilst all around us are elected to be cast by thy wrath down to hell; for the which holiness, O God, we thank thee; and we also thank thee that thou hast elected us, that we may not be led away after the foolish traditions of our brethren, which doth bind them down to a belief of Christ, which doth lead their hearts to wander far from thee, our God.
34520	1315	18	And again we thank thee, O God, that we are a chosen and a holy people. Amen.
34521	1315	19	Now it came to pass that after Alma and his brethren and his sons had heard these prayers, they were astonished beyond all measure.
34522	1315	20	For behold, every man did go forth and offer up these same prayers.
34523	1315	21	Now the place was called by them Rameumptom, which, being interpreted, is the holy stand.
34524	1315	22	Now, from this stand they did offer up, every man, the selfsame prayer unto God, thanking their God that they were chosen of him, and that he did not lead them away after the tradition of their brethren, and that their hearts were not stolen away to believe in things to come, which they knew nothing about.
34525	1315	23	Now, after the people had all offered up thanks after this manner, they returned to their homes, never speaking of their God again until they had assembled themselves together again to the holy stand, to offer up thanks after their manner.
34526	1315	24	Now when Alma saw this his heart was grieved; for he saw that they were a wicked and a perverse people; yea, he saw that their hearts were set upon gold, and upon silver, and upon all manner of fine goods.
34527	1315	25	Yea, and he also saw that their hearts were lifted up unto great boasting, in their pride.
34528	1315	26	And he lifted up his voice to heaven, and cried, saying: O, how long, O Lord, wilt thou suffer that thy servants shall dwell here below in the flesh, to behold such gross wickedness among the children of men?
34529	1315	27	Behold, O God, they cry unto thee, and yet their hearts are swallowed up in their pride. Behold, O God, they cry unto thee with their mouths, while they are puffed up, even to greatness, with the vain things of the world.
34530	1315	28	Behold, O my God, their costly apparel, and their ringlets, and their bracelets, and their ornaments of gold, and all their precious things which they are ornamented with; and behold, their hearts are set upon them, and yet they cry unto thee and say--We thank thee, O God, for we are a chosen people unto thee, while others shall perish.
34531	1315	29	Yea, and they say that thou hast made it known unto them that there shall be no Christ.
34532	1315	30	O Lord God, how long wilt thou suffer that such wickedness and infidelity shall be among this people? O Lord, wilt thou give me strength, that I may bear with mine infirmities. For I am infirm, and such wickedness among this people doth pain my soul.
34533	1315	31	O Lord, my heart is exceedingly sorrowful; wilt thou comfort my soul in Christ. O Lord, wilt thou grant unto me that I may have strength, that I may suffer with patience these afflictions which shall come upon me, because of the iniquity of this people.
34534	1315	32	O Lord, wilt thou comfort my soul, and give unto me success, and also my fellow laborers who are with me--yea, Ammon, and Aaron, and Omner, and also Amulek and Zeezrom and also my two sons--yea, even all these wilt thou comfort, O Lord. Yea, wilt thou comfort their souls in Christ.
34535	1315	33	Wilt thou grant unto them that they may have strength, that they may bear their afflictions which shall come upon them because of the iniquities of this people.
34536	1315	34	O Lord, wilt thou grant unto us that we may have success in bringing them again unto thee in Christ.
34537	1315	35	Behold, O Lord, their souls are precious, and many of them are our brethren; therefore, give unto us, O Lord, power and wisdom that we may bring these, our brethren, again unto thee.
34538	1315	36	Now it came to pass that when Alma had said these words, that he clapped his hands upon all them who were with him. And behold, as he clapped his hands upon them, they were filled with the Holy Spirit.
34539	1315	37	And after that they did separate themselves one from another, taking no thought for themselves what they should eat, or what they should drink, or what they should put on.
34540	1315	38	And the Lord provided for them that they should hunger not, neither should they thirst; yea, and he also gave them strength, that they should suffer no manner of afflictions, save it were swallowed up in the joy of Christ. Now this was according to the prayer of Alma; and this because he prayed in faith.
34541	1316	1	And it came to pass that they did go forth, and began to preach the word of God unto the people, entering into their synagogues, and into their houses; yea, and even they did preach the word in their streets.
34542	1316	2	And it came to pass that after much labor among them, they began to have success among the poor class of people; for behold, they were cast out of the synagogues because of the coarseness of their apparel--
34543	1316	3	Therefore they were not permitted to enter into their synagogues to worship God, being esteemed as filthiness; therefore they were poor; yea, they were esteemed by their brethren as dross; therefore they were poor as to things of the world; and also they were poor in heart.
34544	1316	4	Now, as Alma was teaching and speaking unto the people upon the hill Onidah, there came a great multitude unto him, who were those of whom we have been speaking, of whom were poor in heart, because of their poverty as to the things of the world.
34545	1316	5	And they came unto Alma; and the one who was the foremost among them said unto him: Behold, what shall these my brethren do, for they are despised of all men because of their poverty, yea, and more especially by our priests; for they have cast us out of our synagogues which we have labored abundantly to build with our own hands; and they have cast us out because of our exceeding poverty; and we have no place to worship our God; and behold, what shall we do?
34546	1316	6	And now when Alma heard this, he turned him about, his face immediately towards him, and he beheld with great joy; for he beheld that their afflictions had truly humbled them, and that they were in a preparation to hear the word.
34547	1316	7	Therefore he did say no more to the other multitude; but he stretched forth his hand, and cried unto those whom he beheld, who were truly penitent, and said unto them:
34548	1316	8	I behold that ye are lowly in heart; and if so, blessed are ye.
34549	1316	9	Behold thy brother hath said, What shall we do?--for we are cast out of our synagogues, that we cannot worship our God.
34550	1316	10	Behold I say unto you, do ye suppose that ye cannot worship God save it be in your synagogues only?
34551	1316	11	And moreover, I would ask, do ye suppose that ye must not worship God only once in a week?
34552	1316	12	I say unto you, it is well that ye are cast out of your synagogues, that ye may be humble, and that ye may learn wisdom; for it is necessary that ye should learn wisdom; for it is because that ye are cast out, that ye are despised of your brethren because of your exceeding poverty, that ye are brought to a lowliness of heart; for ye are necessarily brought to be humble.
34553	1316	13	And now, because ye are compelled to be humble blessed are ye; for a man sometimes, if he is compelled to be humble, seeketh repentance; and now surely, whosoever repenteth shall find mercy; and he that findeth mercy and endureth to the end the same shall be saved.
34554	1316	14	And now, as I said unto you, that because ye were compelled to be humble ye were blessed, do ye not suppose that they are more blessed who truly humble themselves because of the word?
34555	1316	15	Yea, he that truly humbleth himself, and repenteth of his sins, and endureth to the end, the same shall be blessed--yea, much more blessed than they who are compelled to be humble because of their exceeding poverty.
34556	1316	16	Therefore, blessed are they who humble themselves without being compelled to be humble; or rather, in other words, blessed is he that believeth in the word of God, and is baptized without stubbornness of heart, yea, without being brought to know the word, or even compelled to know, before they will believe.
34557	1316	17	Yea, there are many who do say: If thou wilt show unto us a sign from heaven, then we shall know of a surety; then we shall believe.
34558	1316	18	Now I ask, is this faith? Behold, I say unto you, Nay; for if a man knoweth a thing he hath no cause to believe, for he knoweth it.
34559	1316	19	And now, how much more cursed is he that knoweth the will of God and doeth it not, than he that only believeth, or only hath cause to believe, and falleth into transgression?
34560	1316	20	Now of this thing ye must judge. Behold, I say unto you, that it is on the one hand even as it is on the other; and it shall be unto every man according to his work.
34561	1316	21	And now as I said concerning faith--faith is not to have a perfect knowledge of things; therefore if ye have faith ye hope for things which are not seen, which are true.
34562	1316	22	And now, behold, I say unto you, and I would that ye should remember, that God is merciful unto all who believe on his name; therefore he desireth, in the first place, that ye should believe, yea, even on his word.
34563	1316	23	And now, he imparteth his word by angels unto men, yea, not only men but women also. Now this is not all; little children do have words given unto them many times, which confound the wise and the learned.
34564	1316	24	And now, my beloved brethren, as ye have desired to know of me what ye shall do because ye are afflicted and cast out--now I do not desire that ye should suppose that I mean to judge you only according to that which is true--
34565	1316	25	For I do not mean that ye all of you have been compelled to humble yourselves; for I verily believe that there are some among you who would humble themselves, let them be in whatsoever circumstances they might.
34566	1316	26	Now, as I said concerning faith--that it was not a perfect knowledge--even so it is with my words. Ye cannot know of their surety at first, unto perfection, any more than faith is a perfect knowledge.
34567	1316	27	But behold, if ye will awake and arouse your faculties, even to an experiment upon my words, and exercise a particle of faith, yea, even if ye can no more than desire to believe, let this desire work in you, even until ye believe in a manner that ye can give place for a portion of my words.
34568	1316	28	Now, we will compare the word unto a seed. Now, if ye give place, that a seed may be planted in your heart, behold, if it be a true seed, or a good seed, if ye do not cast it out by your unbelief, that ye will resist the Spirit of the Lord, behold, it will begin to swell within your breasts; and when you feel these swelling motions, ye will begin to say within yourselves--It must needs be that this is a good seed, or that the word is good, for it beginneth to enlarge my soul; yea, it beginneth to enlighten my understanding, yea, it beginneth to be delicious to me.
34569	1316	29	Now behold, would not this increase your faith? I say unto you, Yea; nevertheless it hath not grown up to a perfect knowledge.
34570	1316	30	But behold, as the seed swelleth, and sprouteth, and beginneth to grow, then you must needs say that the seed is good; for behold it swelleth, and sprouteth, and beginneth to grow. And now, behold, will not this strengthen your faith? Yea, it will strengthen your faith: for ye will say I know that this is a good seed; for behold it sprouteth and beginneth to grow.
34571	1316	31	And now, behold, are ye sure that this is a good seed? I say unto you, Yea; for every seed bringeth forth unto its own likeness.
34572	1316	32	Therefore, if a seed groweth it is good, but if it groweth not, behold it is not good, therefore it is cast away.
34573	1316	33	And now, behold, because ye have tried the experiment, and planted the seed, and it swelleth and sprouteth, and beginneth to grow, ye must needs know that the seed is good.
34574	1316	34	And now, behold, is your knowledge perfect? Yea, your knowledge is perfect in that thing, and your faith is dormant; and this because you know, for ye know that the word hath swelled your souls, and ye also know that it hath sprouted up, that your understanding doth begin to be enlightened, and your mind doth begin to expand.
34575	1316	35	O then, is not this real? I say unto you, Yea, because it is light; and whatsoever is light, is good, because it is discernible, therefore ye must know that it is good; and now behold, after ye have tasted this light is your knowledge perfect?
34576	1316	36	Behold I say unto you, Nay; neither must ye lay aside your faith, for ye have only exercised your faith to plant the seed that ye might try the experiment to know if the seed was good.
34577	1316	37	And behold, as the tree beginneth to grow, ye will say: Let us nourish it with great care, that it may get root, that it may grow up, and bring forth fruit unto us. And now behold, if ye nourish it with much care it will get root, and grow up, and bring forth fruit.
34578	1316	38	But if ye neglect the tree, and take no thought for its nourishment, behold it will not get any root; and when the heat of the sun cometh and scorcheth it, because it hath no root it withers away, and ye pluck it up and cast it out.
34579	1316	39	Now, this is not because the seed was not good, neither is it because the fruit thereof would not be desirable; but it is because your ground is barren, and ye will not nourish the tree, therefore ye cannot have the fruit thereof.
34580	1316	40	And thus, if ye will not nourish the word, looking forward with an eye of faith to the fruit thereof, ye can never pluck of the fruit of the tree of life.
34581	1316	41	But if ye will nourish the word, yea, nourish the tree as it beginneth to grow, by your faith with great diligence, and with patience, looking forward to the fruit thereof, it shall take root; and behold it shall be a tree springing up unto everlasting life.
34582	1316	42	And because of your diligence and your faith and your patience with the word in nourishing it, that it may take root in you, behold, by and by ye shall pluck the fruit thereof, which is most precious, which is sweet above all that is sweet, and which is white above all that is white, yea, and pure above all that is pure; and ye shall feast upon this fruit even until ye are filled, that ye hunger not, neither shall ye thirst.
34583	1316	43	Then, my brethren, ye shall reap the rewards of your faith, and your diligence, and patience, and long-suffering, waiting for the tree to bring forth fruit unto you.
34584	1317	1	Now after Alma had spoken these words, they sent forth unto him desiring to know whether they should believe in one God, that they might obtain this fruit of which he had spoken, or how they should plant the seed, or the word of which he had spoken, which he said must be planted in their hearts; or in what manner they should begin to exercise their faith.
34585	1317	2	And Alma said unto them: Behold, ye have said that ye could not worship your God because ye are cast out of your synagogues. But behold, I say unto you, if ye suppose that ye cannot worship God, ye do greatly err, and ye ought to search the scriptures; if ye suppose that they have taught you this, ye do not understand them.
34586	1317	3	Do ye remember to have read what Zenos, the prophet of old, has said concerning prayer or worship?
34587	1317	4	For he said: Thou art merciful, O God, for thou hast heard my prayer, even when I was in the wilderness; yea, thou wast merciful when I prayed concerning those who were mine enemies, and thou didst turn them to me.
34588	1317	5	Yea, O God, and thou wast merciful unto me when I did cry unto thee in my field; when I did cry unto thee in my prayer, and thou didst hear me.
34589	1317	6	And again, O God, when I did turn to my house thou didst hear me in my prayer.
34590	1317	7	And when I did turn unto my closet, O Lord, and prayed unto thee, thou didst hear me.
34591	1317	8	Yea, thou art merciful unto thy children when they cry unto thee, to be heard of thee and not of men, and thou wilt hear them.
34592	1317	9	Yea, O God, thou hast been merciful unto me, and heard my cries in the midst of thy congregations.
34593	1317	10	Yea, and thou hast also heard me when I have been cast out and have been despised by mine enemies; yea, thou didst hear my cries, and wast angry with mine enemies, and thou didst visit them in thine anger with speedy destruction.
34594	1317	11	And thou didst hear me because of mine afflictions and my sincerity; and it is because of thy Son that thou hast been thus merciful unto me, therefore I will cry unto thee in all mine afflictions, for in thee is my joy; for thou hast turned thy judgments away from me, because of thy Son.
34595	1317	12	And now Alma said unto them: Do ye believe those scriptures which have been written by them of old?
34596	1317	13	Behold, if ye do, ye must believe what Zenos said; for, behold he said: Thou hast turned away thy judgments because of thy Son.
34597	1317	14	Now behold, my brethren, I would ask if ye have read the scriptures? If ye have, how can ye disbelieve on the Son of God?
34598	1317	15	For it is not written that Zenos alone spake of these things, but Zenock also spake of these things--
34599	1317	16	For behold, he said: Thou art angry, O Lord, with this people, because they will not understand thy mercies which thou hast bestowed upon them because of thy Son.
34600	1317	17	And now, my brethren, ye see that a second prophet of old has testified of the Son of God, and because the people would not understand his words they stoned him to death.
34601	1317	18	But behold, this is not all; these are not the only ones who have spoken concerning the Son of God.
34602	1317	19	Behold, he was spoken of by Moses; yea, and behold a type was raised up in the wilderness, that whosoever would look upon it might live. And many did look and live.
34603	1317	20	But few understood the meaning of those things, and this because of the hardness of their hearts. But there were many who were so hardened that they would not look, therefore they perished. Now the reason they would not look is because they did not believe that it would heal them.
34604	1317	21	O my brethren, if ye could be healed by merely casting about your eyes that ye might be healed, would ye not behold quickly, or would ye rather harden your hearts in unbelief, and be slothful, that ye would not cast about your eyes, that ye might perish?
34605	1317	22	If so, wo shall come upon you; but if not so, then cast about your eyes and begin to believe in the Son of God, that he will come to redeem his people, and that he shall suffer and die to atone for their sins; and that he shall rise again from the dead, which shall bring to pass the resurrection, that all men shall stand before him, to be judged at the last and judgment day, according to their works.
34606	1317	23	And now, my brethren, I desire that ye shall plant this word in your hearts, and as it beginneth to swell even so nourish it by your faith. And behold, it will become a tree, springing up in you unto everlasting life. And then may God grant unto you that your burdens may be light, through the joy of his Son. And even all this can ye do if ye will. Amen.
34607	1318	1	And now it came to pass that after Alma had spoken these words unto them he sat down upon the ground, and Amulek arose and began to teach them, saying:
34608	1318	2	My brethren, I think that it is impossible that ye should be ignorant of the things which have been spoken concerning the coming of Christ, who is taught by us to be the Son of God; yea, I know that these things were taught unto you bountifully before your dissension from among us.
34609	1318	3	And as ye have desired of my beloved brother that he should make known unto you what ye should do, because of your afflictions; and he hath spoken somewhat unto you to prepare your minds; yea, and he hath exhorted you unto faith and to patience--
34610	1318	4	Yea, even that ye would have so much faith as even to plant the word in your hearts, that ye may try the experiment of its goodness.
34611	1318	5	And we have beheld that the great question which is in your minds is whether the word be in the Son of God, or whether there shall be no Christ.
34612	1318	6	And ye also beheld that my brother has proved unto you, in many instances, that the word is in Christ unto salvation.
34613	1318	7	My brother has called upon the words of Zenos, that redemption cometh through the Son of God, and also upon the words of Zenock; and also he has appealed unto Moses, to prove that these things are true.
34614	1318	8	And now, behold, I will testify unto you of myself that these things are true. Behold, I say unto you, that I do know that Christ shall come among the children of men, to take upon him the transgressions of his people, and that he shall atone for the sins of the world; for the Lord God hath spoken it.
34615	1318	9	For it is expedient that an atonement should be made; for according to the great plan of the Eternal God there must be an atonement made, or else all mankind must unavoidably perish; yea, all are hardened; yea, all are fallen and are lost, and must perish except it be through the atonement which it is expedient should be made.
34616	1318	10	For it is expedient that there should be a great and last sacrifice; yea, not a sacrifice of man, neither of beast, neither of any manner of fowl; for it shall not be a human sacrifice; but it must be an infinite and eternal sacrifice.
34617	1318	11	Now there is not any man that can sacrifice his own blood which will atone for the sins of another. Now, if a man murdereth, behold will our law, which is just, take the life of his brother? I say unto you, Nay.
34618	1318	12	But the law requireth the life of him who hath murdered; therefore there can be nothing which is short of an infinite atonement which will suffice for the sins of the world.
34619	1318	13	Therefore, it is expedient that there should be a great and last sacrifice, and then shall there be, or it is expedient there should be, a stop to the shedding of blood; then shall the law of Moses be fulfilled; yea, it shall be all fulfilled, every jot and tittle, and none shall have passed away.
34620	1318	14	And behold, this is the whole meaning of the law, every whit pointing to that great and last sacrifice; and that great and last sacrifice will be the Son of God, yea, infinite and eternal.
34621	1318	15	And thus he shall bring salvation to all those who shall believe on his name; this being the intent of this last sacrifice, to bring about the bowels of mercy, which overpowereth justice, and bringeth about means unto men that they may have faith unto repentance.
34622	1318	16	And thus mercy can satisfy the demands of justice, and encircles them in the arms of safety, while he that exercises no faith unto repentance is exposed to the whole law of the demands of justice; therefore only unto him that has faith unto repentance is brought about the great and eternal plan of redemption.
34623	1318	17	Therefore may God grant unto you, my brethren, that ye may begin to exercise your faith unto repentance, that ye begin to call upon his holy name, that he would have mercy upon you;
34624	1318	18	Yea, cry unto him for mercy; for he is mighty to save.
34625	1318	19	Yea, humble yourselves, and continue in prayer unto him.
34626	1318	20	Cry unto him when ye are in your fields, yea, over all your flocks.
34627	1318	21	Cry unto him in your houses, yea, over all your household, both morning, mid-day, and evening.
34628	1318	22	Yea, cry unto him against the power of your enemies.
34629	1318	23	Yea, cry unto him against the devil, who is an enemy to all righteousness.
34630	1318	24	Cry unto him over the crops of your fields, that ye may prosper in them.
34631	1318	25	Cry over the flocks of your fields, that they may increase.
34632	1318	26	But this is not all; ye must pour out your souls in your closets, and your secret places, and in your wilderness.
34633	1318	27	Yea, and when you do not cry unto the Lord, let your hearts be full, drawn out in prayer unto him continually for your welfare, and also for the welfare of those who are around you.
34634	1318	28	And now behold, my beloved brethren, I say unto you, do not suppose that this is all; for after ye have done all these things, if ye turn away the needy, and the naked, and visit not the sick and afflicted, and impart of your substance, if ye have, to those who stand in need--I say unto you, if ye do not any of these things, behold, your prayer is vain, and availeth you nothing, and ye are as hypocrites who do deny the faith.
34635	1318	29	Therefore, if ye do not remember to be charitable, ye are as dross, which the refiners do cast out, (it being of no worth) and is trodden under foot of men.
34636	1318	30	And now, my brethren, I would that, after ye have received so many witnesses, seeing that the holy scriptures testify of these things, ye come forth and bring fruit unto repentance.
34637	1318	31	Yea, I would that ye would come forth and harden not your hearts any longer; for behold, now is the time and the day of your salvation; and therefore, if ye will repent and harden not your hearts, immediately shall the great plan of redemption be brought about unto you.
34638	1318	32	For behold, this life is the time for men to prepare to meet God; yea, behold the day of this life is the day for men to perform their labors.
34639	1318	33	And now, as I said unto you before, as ye have had so many witnesses, therefore, I beseech of you that ye do not procrastinate the day of your repentance until the end; for after this day of life, which is given us to prepare for eternity, behold, if we do not improve our time while in this life, then cometh the night of darkness wherein there can be no labor performed.
34640	1318	34	Ye cannot say, when ye are brought to that awful crisis, that I will repent, that I will return to my God. Nay, ye cannot say this; for that same spirit which doth possess your bodies at the time that ye go out of this life, that same spirit will have power to possess your body in that eternal world.
34641	1318	35	For behold, if ye have procrastinated the day of your repentance even until death, behold, ye have become subjected to the spirit of the devil, and he doth seal you his; therefore, the Spirit of the Lord hath withdrawn from you, and hath no place in you, and the devil hath all power over you; and this is the final state of the wicked.
34642	1318	36	And this I know, because the Lord hath said he dwelleth not in unholy temples, but in the hearts of the righteous doth he dwell; yea, and he has also said that the righteous shall sit down in his kingdom, to go no more out; but their garments should be made white through the blood of the Lamb.
34643	1318	37	And now, my beloved brethren, I desire that ye should remember these things, and that ye should work out your salvation with fear before God, and that ye should no more deny the coming of Christ;
34644	1318	38	That ye contend no more against the Holy Ghost, but that ye receive it, and take upon you the name of Christ; that ye humble yourselves even to the dust, and worship God, in whatsoever place ye may be in, in spirit and in truth; and that ye live in thanksgiving daily, for the many mercies and blessings which he doth bestow upon you.
34645	1318	39	Yea, and I also exhort you, my brethren, that ye be watchful unto prayer continually, that ye may not be led away by the temptations of the devil, that he may not overpower you, that ye may not become his subjects at the last day; for behold, he rewardeth you no good thing.
34646	1318	40	And now my beloved brethren, I would exhort you to have patience, and that ye bear with all manner of afflictions; that ye do not revile against those who do cast you out because of your exceeding poverty, lest ye become sinners like unto them;
34647	1318	41	But that ye have patience, and bear with those afflictions, with a firm hope that ye shall one day rest from all your afflictions.
34648	1319	1	Now it came to pass that after Amulek had made an end of these words, they withdrew themselves from the multitude and came over into the land of Jershon.
34649	1319	2	Yea, and the rest of the brethren, after they had preached the word unto the Zoramites, also came over into the land of Jershon.
34650	1319	3	And it came to pass that after the more popular part of the Zoramites had consulted together concerning the words which had been preached unto them, they were angry because of the word, for it did destroy their craft; therefore they would not hearken unto the words.
34651	1319	4	And they sent and gathered together throughout all the land all the people, and consulted with them concerning the words which had been spoken.
34652	1319	5	Now their rulers and their priests and their teachers did not let the people know concerning their desires; therefore they found out privily the minds of all the people.
34653	1319	6	And it came to pass that after they had found out the minds of all the people, those who were in favor of the words which had been spoken by Alma and his brethren were cast out of the land; and they were many; and they came over also into the land of Jershon.
34654	1319	7	And it came to pass that Alma and his brethren did minister unto them.
34655	1319	8	Now the people of the Zoramites were angry with the people of Ammon who were in Jershon, and the chief ruler of the Zoramites, being a very wicked man, sent over unto the people of Ammon desiring them that they should cast out of their land all those who came over from them into their land.
34656	1319	9	And he breathed out many threatenings against them. And now the people of Ammon did not fear their words; therefore they did not cast them out, but they did receive all the poor of the Zoramites that came over unto them; and they did nourish them, and did clothe them, and did give unto them lands for their inheritance; and they did administer unto them according to their wants.
34657	1319	10	Now this did stir up the Zoramites to anger against the people of Ammon, and they began to mix with the Lamanites and to stir them up also to anger against them.
34658	1319	11	And thus the Zoramites and the Lamanites began to make preparations for war against the people of Ammon, and also against the Nephites.
34659	1319	12	And thus ended the seventeenth year of the reign of the judges over the people of Nephi.
34660	1319	13	And the people of Ammon departed out of the land of Jershon, and came over into the land of Melek, and gave place in the land of Jershon for the armies of the Nephites, that they might contend with the armies of the Lamanites and the armies of the Zoramites; and thus commenced a war betwixt the Lamanites and the Nephites, in the eighteenth year of the reign of the judges; and an account shall be given of their wars hereafter.
34661	1319	14	And Alma, and Ammon, and their brethren, and also the two sons of Alma returned to the land of Zarahemla, after having been instruments in the hands of God of bringing many of the Zoramites to repentance; and as many as were brought to repentance were driven out of their land; but they have lands for their inheritance in the land of Jershon, and they have taken up arms to defend themselves, and their wives, and children, and their lands.
34662	1319	15	Now Alma, being grieved for the iniquity of his people, yea for the wars, and the bloodsheds, and the contentions which were among them; and having been to declare the word, or sent to declare the word, among all the people in every city; and seeing that the hearts of the people began to wax hard, and that they began to be offended because of the strictness of the word, his heart was exceedingly sorrowful.
34663	1319	16	Therefore, he caused that his sons should be gathered together, that he might give unto them every one his charge, separately, concerning the things pertaining unto righteousness. And we have an account of his commandments, which he gave unto them according to his own record.
34664	1320	1	My son, give ear to my words; for I swear unto you, that inasmuch as ye shall keep the commandments of God ye shall prosper in the land.
34665	1320	2	I would that ye should do as I have done, in remembering the captivity of our fathers; for they were in bondage, and none could deliver them except it was the God of Abraham, and the God of Isaac, and the God of Jacob; and he surely did deliver them in their afflictions.
34666	1320	3	And now, O my son Helaman, behold, thou art in thy youth, and therefore, I beseech of thee that thou wilt hear my words and learn of me; for I do know that whosoever shall put their trust in God shall be supported in their trials, and their troubles, and their afflictions, and shall be lifted up at the last day.
34667	1320	4	And I would not that ye think that I know of myself--not of the temporal but of the spiritual, not of the carnal mind but of God.
34668	1320	5	Now, behold, I say unto you, if I had not been born of God I should not have known these things; but God has, by the mouth of his holy angel, made these things known unto me, not of any worthiness of myself;
34669	1320	6	For I went about with the sons of Mosiah, seeking to destroy the church of God; but behold, God sent his holy angel to stop us by the way.
34670	1320	7	And behold, he spake unto us, as it were the voice of thunder, and the whole earth did tremble beneath our feet; and we all fell to the earth, for the fear of the Lord came upon us.
34671	1320	8	But behold, the voice said unto me: Arise. And I arose and stood up, and beheld the angel.
34672	1320	9	And he said unto me: If thou wilt of thyself be destroyed, seek no more to destroy the church of God.
34673	1320	10	And it came to pass that I fell to the earth; and it was for the space of three days and three nights that I could not open my mouth, neither had I the use of my limbs.
34674	1320	11	And the angel spake more things unto me, which were heard by my brethren, but I did not hear them; for when I heard the words--If thou wilt be destroyed of thyself, seek no more to destroy the church of God--I was struck with such great fear and amazement lest perhaps I should be destroyed, that I fell to the earth and I did hear no more.
34675	1320	12	But I was racked with eternal torment, for my soul was harrowed up to the greatest degree and racked with all my sins.
34676	1320	13	Yea, I did remember all my sins and iniquities, for which I was tormented with the pains of hell; yea, I saw that I had rebelled against my God, and that I had not kept his holy commandments.
34677	1320	14	Yea, and I had murdered many of his children, or rather led them away unto destruction; yea, and in fine so great had been my iniquities, that the very thought of coming into the presence of my God did rack my soul with inexpressible horror.
34678	1320	15	Oh, thought I, that I could be banished and become extinct both soul and body, that I might not be brought to stand in the presence of my God, to be judged of my deeds.
34679	1320	16	And now, for three days and for three nights was I racked, even with the pains of a damned soul.
34680	1320	17	And it came to pass that as I was thus racked with torment, while I was harrowed up by the memory of my many sins, behold, I remembered also to have heard my father prophesy unto the people concerning the coming of one Jesus Christ, a Son of God, to atone for the sins of the world.
34681	1320	18	Now, as my mind caught hold upon this thought, I cried within my heart: O Jesus, thou Son of God, have mercy on me, who am in the gall of bitterness, and am encircled about by the everlasting chains of death.
34682	1320	19	And now, behold, when I thought this, I could remember my pains no more; yea, I was harrowed up by the memory of my sins no more.
34683	1320	20	And oh, what joy, and what marvelous light I did behold; yea, my soul was filled with joy as exceeding as was my pain!
34684	1320	21	Yea, I say unto you, my son, that there could be nothing so exquisite and so bitter as were my pains. Yea, and again I say unto you, my son, that on the other hand, there can be nothing so exquisite and sweet as was my joy.
34685	1320	22	Yea, methought I saw, even as our father Lehi saw, God sitting upon his throne, surrounded with numberless concourses of angels, in the attitude of singing and praising their God; yea, and my soul did long to be there.
34686	1320	23	But behold, my limbs did receive their strength again, and I stood upon my feet, and did manifest unto the people that I had been born of God.
34687	1320	24	Yea, and from that time even until now, I have labored without ceasing, that I might bring souls unto repentance; that I might bring them to taste of the exceeding joy of which I did taste; that they might also be born of God, and be filled with the Holy Ghost.
34688	1320	25	Yea, and now behold, O my son, the Lord doth give me exceedingly great joy in the fruit of my labors;
34689	1320	26	For because of the word which he has imparted unto me, behold, many have been born of God, and have tasted as I have tasted, and have seen eye to eye as I have seen; therefore they do know of these things of which I have spoken, as I do know; and the knowledge which I have is of God.
34690	1320	27	And I have been supported under trials and troubles of every kind, yea, and in all manner of afflictions; yea, God has delivered me from prison, and from bonds, and from death; yea, and I do put my trust in him, and he will still deliver me.
34691	1320	28	And I know that he will raise me up at the last day, to dwell with him in glory; yea, and I will praise him forever, for he has brought our fathers out of Egypt, and he has swallowed up the Egyptians in the Red Sea; and he led them by his power into the promised land; yea, and he has delivered them out of bondage and captivity from time to time.
34692	1320	29	Yea, and he has also brought our fathers out of the land of Jerusalem; and he has also, by his everlasting power, delivered them out of bondage and captivity, from time to time even down to the present day; and I have always retained in remembrance their captivity; yea, and ye also ought to retain in remembrance, as I have done, their captivity.
34693	1320	30	But behold, my son, this is not all; for ye ought to know as I do know, that inasmuch as ye shall keep the commandments of God ye shall prosper in the land; and ye ought to know also, that inasmuch as ye will not keep the commandments of God ye shall be cut off from his presence. Now this is according to his word.
34694	1321	1	And now, my son Helaman, I command you that ye take the records which have been entrusted with me;
34695	1321	2	And I also command you that ye keep a record of this people, according as I have done, upon the plates of Nephi, and keep all these things sacred which I have kept, even as I have kept them; for it is for a wise purpose that they are kept.
34696	1321	3	And these plates of brass, which contain these engravings, which have the records of the holy scriptures upon them, which have the genealogy of our forefathers, even from the beginning--
34697	1321	4	Behold, it has been prophesied by our fathers, that they should be kept and handed down from one generation to another, and be kept and preserved by the hand of the Lord until they should go forth unto every nation, kindred, tongue, and people, that they shall know of the mysteries contained thereon.
34698	1321	5	And now behold, if they are kept they must retain their brightness; yea, and they will retain their brightness; yea, and also shall all the plates which do contain that which is holy writ.
34699	1321	6	Now ye may suppose that this is foolishness in me; but behold I say unto you, that by small and simple things are great things brought to pass; and small means in many instances doth confound the wise.
34700	1321	7	And the Lord God doth work by means to bring about his great and eternal purposes; and by very small means the Lord doth confound the wise and bringeth about the salvation of many souls.
34701	1321	8	And now, it has hitherto been wisdom in God that these things should be preserved; for behold, they have enlarged the memory of this people, yea, and convinced many of the error of their ways, and brought them to the knowledge of their God unto the salvation of their souls.
34702	1321	9	Yea, I say unto you, were it not for these things that these records do contain, which are on these plates, Ammon and his brethren could not have convinced so many thousands of the Lamanites of the incorrect tradition of their fathers; yea, these records and their words brought them unto repentance; that is, they brought them to the knowledge of the Lord their God, and to rejoice in Jesus Christ their Redeemer.
34703	1321	10	And who knoweth but what they will be the means of bringing many thousands of them, yea, and also many thousands of our stiffnecked brethren, the Nephites, who are now hardening their hearts in sin and iniquities, to the knowledge of their Redeemer?
34704	1321	11	Now these mysteries are not yet fully made known unto me; therefore I shall forbear.
34705	1321	12	And it may suffice if I only say they are preserved for a wise purpose, which purpose is known unto God; for he doth counsel in wisdom over all his works, and his paths are straight, and his course is one eternal round.
34706	1321	13	O remember, remember, my son Helaman, how strict are the commandments of God. And he said: If ye will keep my commandments ye shall prosper in the land--but if ye keep not his commandments ye shall be cut off from his presence.
34707	1321	14	And now remember, my son, that God has entrusted you with these things, which are sacred, which he has kept sacred, and also which he will keep and preserve for a wise purpose in him, that he may show forth his power unto future generations.
34708	1321	15	And now behold, I tell you by the spirit of prophecy, that if ye transgress the commandments of God, behold, these things which are sacred shall be taken away from you by the power of God, and ye shall be delivered up unto Satan, that he may sift you as chaff before the wind.
34709	1321	16	But if ye keep the commandments of God, and do with these things which are sacred according to that which the Lord doth command you, (for you must appeal unto the Lord for all things whatsoever ye must do with them) behold, no power of earth or hell can take them from you, for God is powerful to the fulfilling of all his words.
34710	1321	17	For he will fulfil all his promises which he shall make unto you, for he has fulfilled his promises which he has made unto our fathers.
34711	1321	18	For he promised unto them that he would preserve these things for a wise purpose in him, that he might show forth his power unto future generations.
34712	1321	19	And now behold, one purpose hath he fulfilled, even to the restoration of many thousands of the Lamanites to the knowledge of the truth; and he hath shown forth his power in them, and he will also still show forth his power in them unto future generations; therefore they shall be preserved.
34713	1321	20	Therefore I command you, my son Helaman, that ye be diligent in fulfilling all my words, and that ye be diligent in keeping the commandments of God as they are written.
34714	1321	21	And now, I will speak unto you concerning those twenty-four plates, that ye keep them, that the mysteries and the works of darkness, and their secret works, or the secret works of those people who have been destroyed, may be made manifest unto this people; yea, all their murders, and robbings, and their plunderings, and all their wickedness and abominations, may be made manifest unto this people; yea, and that ye preserve these interpreters.
34715	1321	22	For behold, the Lord saw that his people began to work in darkness, yea, work secret murders and abominations; therefore the Lord said, if they did not repent they should be destroyed from off the face of the earth.
34716	1321	23	And the Lord said: I will prepare unto my servant Gazelem, a stone, which shall shine forth in darkness unto light, that I may discover unto my people who serve me, that I may discover unto them the works of their brethren, yea, their secret works, their works of darkness, and their wickedness and abominations.
34717	1321	24	And now, my son, these interpreters were prepared that the word of God might be fulfilled, which he spake, saying:
34718	1321	25	I will bring forth out of darkness unto light all their secret works and their abominations; and except they repent I will destroy them from off the face of the earth; and I will bring to light all their secrets and abominations, unto every nation that shall hereafter possess the land.
34719	1321	26	And now, my son, we see that they did not repent; therefore they have been destroyed, and thus far the word of God has been fulfilled; yea, their secret abominations have been brought out of darkness and made known unto us.
34720	1321	27	And now, my son, I command you that ye retain all their oaths, and their covenants, and their agreements in their secret abominations; yea, and all their signs and their wonders ye shall keep from this people, that they know them not, lest peradventure they should fall into darkness also and be destroyed.
34721	1321	28	For behold, there is a curse upon all this land, that destruction shall come upon all those workers of darkness, according to the power of God, when they are fully ripe; therefore I desire that this people might not be destroyed.
34722	1321	29	Therefore ye shall keep these secret plans of their oaths and their covenants from this people, and only their wickedness and their murders and their abominations shall ye make known unto them; and ye shall teach them to abhor such wickedness and abominations and murders; and ye shall also teach them that these people were destroyed on account of their wickedness and abominations and their murders.
34723	1321	30	For behold, they murdered all the prophets of the Lord who came among them to declare unto them concerning their iniquities; and the blood of those whom they murdered did cry unto the Lord their God for vengeance upon those who were their murderers; and thus the judgments of God did come upon these workers of darkness and secret combinations.
34724	1321	31	Yea, and cursed be the land forever and ever unto those workers of darkness and secret combinations, even unto destruction, except they repent before they are fully ripe.
34725	1321	32	And now, my son, remember the words which I have spoken unto you; trust not those secret plans unto this people, but teach them an everlasting hatred against sin and iniquity.
34726	1321	33	Preach unto them repentance, and faith on the Lord Jesus Christ; teach them to humble themselves and to be meek and lowly in heart; teach them to withstand every temptation of the devil, with their faith on the Lord Jesus Christ.
34727	1321	34	Teach them to never be weary of good works, but to be meek and lowly in heart; for such shall find rest to their souls.
34728	1321	35	O, remember, my son, and learn wisdom in thy youth; yea, learn in thy youth to keep the commandments of God.
34729	1321	36	Yea, and cry unto God for all thy support; yea, let all thy doings be unto the Lord, and whithersoever thou goest let it be in the Lord; yea, let all thy thoughts be directed unto the Lord; yea, let the affections of thy heart be placed upon the Lord forever.
34730	1321	37	Counsel with the Lord in all thy doings, and he will direct thee for good; yea, when thou liest down at night lie down unto the Lord, that he may watch over you in your sleep; and when thou risest in the morning let thy heart be full of thanks unto God; and if ye do these things, ye shall be lifted up at the last day.
34731	1321	38	And now, my son, I have somewhat to say concerning the thing which our fathers call a ball, or director--or our fathers called it Liahona, which is, being interpreted, a compass; and the Lord prepared it.
34732	1321	39	And behold, there cannot any man work after the manner of so curious a workmanship. And behold, it was prepared to show unto our fathers the course which they should travel in the wilderness.
34733	1321	40	And it did work for them according to their faith in God; therefore, if they had faith to believe that God could cause that those spindles should point the way they should go, behold, it was done; therefore they had this miracle, and also many other miracles wrought by the power of God, day by day.
34734	1321	41	Nevertheless, because those miracles were worked by small means it did show unto them marvelous works. They were slothful, and forgot to exercise their faith and diligence and then those marvelous works ceased, and they did not progress in their journey;
34735	1321	42	Therefore, they tarried in the wilderness, or did not travel a direct course, and were afflicted with hunger and thirst, because of their transgressions.
34736	1321	43	And now, my son, I would that ye should understand that these things are not without a shadow; for as our fathers were slothful to give heed to this compass (now these things were temporal) they did not prosper; even so it is with things which are spiritual.
34737	1321	44	For behold, it is as easy to give heed to the word of Christ, which will point to you a straight course to eternal bliss, as it was for our fathers to give heed to this compass, which would point unto them a straight course to the promised land.
34738	1321	45	And now I say, is there not a type in this thing? For just as surely as this director did bring our fathers, by following its course, to the promised land, shall the words of Christ, if we follow their course, carry us beyond this vale of sorrow into a far better land of promise.
34739	1321	46	O my son, do not let us be slothful because of the easiness of the way; for so was it with our fathers; for so was it prepared for them, that if they would look they might live; even so it is with us. The way is prepared, and if we will look we may live forever.
34740	1321	47	And now, my son, see that ye take care of these sacred things, yea, see that ye look to God and live. Go unto this people and declare the word, and be sober. My son, farewell.
34741	1322	1	My son, give ear to my words, for I say unto you, even as I said unto Helaman, that inasmuch as ye shall keep the commandments of God ye shall prosper in the land; and inasmuch as ye will not keep the commandments of God ye shall be cut off from his presence.
34742	1322	2	And now, my son, I trust that I shall have great joy in you, because of your steadiness and your faithfulness unto God; for as you have commenced in your youth to look to the Lord your God, even so I hope that you will continue in keeping his commandments; for blessed is he that endureth to the end.
34743	1322	3	I say unto you, my son, that I have had great joy in thee already, because of thy faithfulness and thy diligence, and thy patience and thy long-suffering among the people of the Zoramites.
34744	1322	4	For I know that thou wast in bonds; yea, and I also know that thou wast stoned for the word's sake; and thou didst bear all these things with patience because the Lord was with thee; and now thou knowest that the Lord did deliver thee.
34745	1322	5	And now my son, Shiblon, I would that ye should remember, that as much as ye shall put your trust in God even so much ye shall be delivered out of your trials, and your troubles, and your afflictions, and ye shall be lifted up at the last day.
34746	1322	6	Now, my son, I would not that ye should think that I know these things of myself, but it is the Spirit of God which is in me which maketh these things known unto me; for if I had not been born of God I should not have known these things.
34747	1322	7	But behold, the Lord in his great mercy sent his angel to declare unto me that I must stop the work of destruction among his people; yea, and I have seen an angel face to face, and he spake with me, and his voice was as thunder, and it shook the whole earth.
34748	1322	8	And it came to pass that I was three days and three nights in the most bitter pain and anguish of soul; and never, until I did cry out unto the Lord Jesus Christ for mercy, did I receive a remission of my sins. But behold, I did cry unto him and I did find peace to my soul.
34749	1322	9	And now, my son, I have told you this that ye may learn wisdom, that ye may learn of me that there is no other way or means whereby man can be saved, only in and through Christ. Behold, he is the life and the light of the world. Behold, he is the word of truth and righteousness.
34750	1322	10	And now, as ye have begun to teach the word even so I would that ye should continue to teach; and I would that ye would be diligent and temperate in all things.
34751	1322	11	See that ye are not lifted up unto pride; yea, see that ye do not boast in your own wisdom, nor of your much strength.
34752	1322	12	Use boldness, but not overbearance; and also see that ye bridle all your passions, that ye may be filled with love; see that ye refrain from idleness.
34753	1322	13	Do not pray as the Zoramites do, for ye have seen that they pray to be heard of men, and to be praised for their wisdom.
34754	1322	14	Do not say: O God, I thank thee that we are better than our brethren; but rather say: O Lord, forgive my unworthiness, and remember my brethren in mercy--yea, acknowledge your unworthiness before God at all times.
34755	1322	15	And may the Lord bless your soul, and receive you at the last day into his kingdom, to sit down in peace. Now go, my son, and teach the word unto this people. Be sober. My son, farewell.
34756	1323	1	And now, my son, I have somewhat more to say unto thee than what I said unto thy brother; for behold, have ye not observed the steadiness of thy brother, his faithfulness, and his diligence in keeping the commandments of God? Behold, has he not set a good example for thee?
34757	1323	2	For thou didst not give so much heed unto my words as did thy brother, among the people of the Zoramites. Now this is what I have against thee; thou didst go on unto boasting in thy strength and thy wisdom.
34758	1323	3	And this is not all, my son. Thou didst do that which was grievous unto me; for thou didst forsake the ministry, and did go over into the land of Siron among the borders of the Lamanites, after the harlot Isabel.
34759	1323	4	Yea, she did steal away the hearts of many; but this was no excuse for thee, my son. Thou shouldst have tended to the ministry wherewith thou wast entrusted.
34760	1323	5	Know ye not, my son, that these things are an abomination in the sight of the Lord; yea, most abominable above all sins save it be the shedding of innocent blood or denying the Holy Ghost?
34761	1323	6	For behold, if ye deny the Holy Ghost when it once has had place in you, and ye know that ye deny it, behold, this is a sin which is unpardonable; yea, and whosoever murdereth against the light and knowledge of God, it is not easy for him to obtain forgiveness; yea, I say unto you, my son, that it is not easy for him to obtain a forgiveness.
34762	1323	7	And now, my son, I would to God that ye had not been guilty of so great a crime. I would not dwell upon your crimes, to harrow up your soul, if it were not for your good.
34763	1323	8	But behold, ye cannot hide your crimes from God; and except ye repent they will stand as a testimony against you at the last day.
34764	1323	9	Now my son, I would that ye should repent and forsake your sins, and go no more after the lusts of your eyes, but cross yourself in all these things; for except ye do this ye can in nowise inherit the kingdom of God. Oh, remember, and take it upon you, and cross yourself in these things.
34765	1323	10	And I command you to take it upon you to counsel with your elder brothers in your undertakings; for behold, thou art in thy youth, and ye stand in need to be nourished by your brothers. And give heed to their counsel.
34766	1323	11	Suffer not yourself to be led away by any vain or foolish thing; suffer not the devil to lead away your heart again after those wicked harlots. Behold, O my son, how great iniquity ye brought upon the Zoramites; for when they saw your conduct they would not believe in my words.
34767	1323	12	And now the Spirit of the Lord doth say unto me: Command thy children to do good, lest they lead away the hearts of many people to destruction; therefore I command you, my son, in the fear of God, that ye refrain from your iniquities;
34768	1323	13	That ye turn to the Lord with all your mind, might, and strength; that ye lead away the hearts of no more to do wickedly; but rather return unto them, and acknowledge your faults and that wrong which ye have done.
34769	1323	14	Seek not after riches nor the vain things of this world; for behold, you cannot carry them with you.
34770	1323	15	And now, my son, I would say somewhat unto you concerning the coming of Christ. Behold, I say unto you, that it is he that surely shall come to take away the sins of the world; yea, he cometh to declare glad tidings of salvation unto his people.
34771	1323	16	And now, my son, this was the ministry unto which ye were called, to declare these glad tidings unto this people, to prepare their minds; or rather that salvation might come unto them, that they may prepare the minds of their children to hear the word at the time of his coming.
34772	1323	17	And now I will ease your mind somewhat on this subject. Behold, you marvel why these things should be known so long beforehand. Behold, I say unto you, is not a soul at this time as precious unto God as a soul will be at the time of his coming?
34773	1323	18	Is it not as necessary that the plan of redemption should be made known unto this people as well as unto their children?
34774	1323	19	Is it not as easy at this time for the Lord to send his angel to declare these glad tidings unto us as unto our children, or as after the time of his coming?
34775	1324	1	Now my son, here is somewhat more I would say unto thee; for I perceive that thy mind is worried concerning the resurrection of the dead.
34776	1324	2	Behold, I say unto you, that there is no resurrection--or, I would say, in other words, that this mortal does not put on immortality, this corruption does not put on incorruption--until after the coming of Christ.
34777	1324	3	Behold, he bringeth to pass the resurrection of the dead. But behold, my son, the resurrection is not yet. Now, I unfold unto you a mystery; nevertheless, there are many mysteries which are kept, that no one knoweth them save God himself. But I show unto you one thing which I have inquired diligently of God that I might know--that is concerning the resurrection.
34778	1324	4	Behold, there is a time appointed that all shall come forth from the dead. Now when this time cometh no one knows; but God knoweth the time which is appointed.
34779	1324	5	Now, whether there shall be one time, or a second time, or a third time, that men shall come forth from the dead, it mattereth not; for God knoweth all these things; and it sufficeth me to know that this is the case--that there is a time appointed that all shall rise from the dead.
34780	1324	6	Now there must needs be a space betwixt the time of death and the time of the resurrection.
34781	1324	7	And now I would inquire what becometh of the souls of men from this time of death to the time appointed for the resurrection?
34782	1324	8	Now whether there is more than one time appointed for men to rise it mattereth not; for all do not die at once, and this mattereth not; all is as one day with God, and time only is measured unto men.
34783	1324	9	Therefore, there is a time appointed unto men that they shall rise from the dead; and there is a space between the time of death and the resurrection. And now, concerning this space of time, what becometh of the souls of men is the thing which I have inquired diligently of the Lord to know; and this is the thing of which I do know.
34784	1324	10	And when the time cometh when all shall rise, then shall they know that God knoweth all the times which are appointed unto man.
34785	1324	11	Now, concerning the state of the soul between death and the resurrection--Behold, it has been made known unto me by an angel, that the spirits of all men, as soon as they are departed from this mortal body, yea, the spirits of all men, whether they be good or evil, are taken home to that God who gave them life.
34786	1324	12	And then shall it come to pass, that the spirits of those who are righteous are received into a state of happiness, which is called paradise, a state of rest, a state of peace, where they shall rest from all their troubles and from all care, and sorrow.
34787	1324	13	And then shall it come to pass, that the spirits of the wicked, yea, who are evil--for behold, they have no part nor portion of the Spirit of the Lord; for behold, they chose evil works rather than good; therefore the spirit of the devil did enter into them, and take possession of their house--and these shall be cast out into outer darkness; there shall be weeping, and wailing, and gnashing of teeth, and this because of their own iniquity, being led captive by the will of the devil.
34788	1324	14	Now this is the state of the souls of the wicked, yea, in darkness, and a state of awful, fearful looking for the fiery indignation of the wrath of God upon them; thus they remain in this state, as well as the righteous in paradise, until the time of their resurrection.
34789	1324	15	Now, there are some that have understood that this state of happiness and this state of misery of the soul, before the resurrection, was a first resurrection. Yea, I admit it may be termed a resurrection, the raising of the spirit or the soul and their consignation to happiness or misery, according to the words which have been spoken.
34790	1324	16	And behold, again it hath been spoken, that there is a first resurrection, a resurrection of all those who have been, or who are, or who shall be, down to the resurrection of Christ from the dead.
34791	1324	17	Now, we do not suppose that this first resurrection, which is spoken of in this manner, can be the resurrection of the souls and their consignation to happiness or misery. Ye cannot suppose that this is what it meaneth.
34792	1324	18	Behold, I say unto you, Nay; but it meaneth the reuniting of the soul with the body, of those from the days of Adam down to the resurrection of Christ.
34793	1324	19	Now, whether the souls and the bodies of those of whom has been spoken shall all be reunited at once, the wicked as well as the righteous, I do not say; let it suffice, that I say that they all come forth; or in other words, their resurrection cometh to pass before the resurrection of those who die after the resurrection of Christ.
34794	1324	20	Now, my son, I do not say that their resurrection cometh at the resurrection of Christ; but behold, I give it as my opinion, that the souls and the bodies are reunited, of the righteous, at the resurrection of Christ, and his ascension into heaven.
34795	1324	21	But whether it be at his resurrection or after, I do not say; but this much I say, that there is a space between death and the resurrection of the body, and a state of the soul in happiness or in misery until the time which is appointed of God that the dead shall come forth, and be reunited, both soul and body, and be brought to stand before God, and be judged according to their works.
34796	1324	22	Yea, this bringeth about the restoration of those things of which has been spoken by the mouths of the prophets.
34797	1324	23	The soul shall be restored to the body, and the body to the soul; yea, and every limb and joint shall be restored to its body; yea, even a hair of the head shall not be lost; but all things shall be restored to their proper and perfect frame.
34798	1324	24	And now, my son, this is the restoration of which has been spoken by the mouths of the prophets--
34799	1324	25	And then shall the righteous shine forth in the kingdom of God.
34800	1324	26	But behold, an awful death cometh upon the wicked; for they die as to things pertaining to things of righteousness; for they are unclean, and no unclean thing can inherit the kingdom of God; but they are cast out, and consigned to partake of the fruits of their labors or their works, which have been evil; and they drink the dregs of a bitter cup.
34801	1325	1	And now, my son, I have somewhat to say concerning the restoration of which has been spoken; for behold, some have wrested the scriptures, and have gone far astray because of this thing. And I perceive that thy mind has been worried also concerning this thing. But behold, I will explain it unto thee.
34802	1325	2	I say unto thee, my son, that the plan of restoration is requisite with the justice of God; for it is requisite that all things should be restored to their proper order. Behold, it is requisite and just, according to the power and resurrection of Christ, that the soul of man should be restored to its body, and that every part of the body should be restored to itself.
34803	1325	3	And it is requisite with the justice of God that men should be judged according to their works; and if their works were good in this life, and the desires of their hearts were good, that they should also, at the last day, be restored unto that which is good.
34804	1325	4	And if their works are evil they shall be restored unto them for evil. Therefore, all things shall be restored to their proper order, every thing to its natural frame--mortality raised to immortality, corruption to incorruption--raised to endless happiness to inherit the kingdom of God, or to endless misery to inherit the kingdom of the devil, the one on one hand, the other on the other--
34805	1325	5	The one raised to happiness according to his desires of happiness, or good according to his desires of good; and the other to evil according to his desires of evil; for as he has desired to do evil all the day long even so shall he have his reward of evil when the night cometh.
34806	1325	6	And so it is on the other hand. If he hath repented of his sins, and desired righteousness until the end of his days, even so he shall be rewarded unto righteousness.
34807	1325	7	These are they that are redeemed of the Lord; yea, these are they that are taken out, that are delivered from that endless night of darkness; and thus they stand or fall; for behold, they are their own judges, whether to do good or do evil.
34808	1325	8	Now, the decrees of God are unalterable; therefore, the way is prepared that whosoever will may walk therein and be saved.
34809	1325	9	And now behold, my son, do not risk one more offense against your God upon those points of doctrine, which ye have hitherto risked to commit sin.
34810	1325	10	Do not suppose, because it has been spoken concerning restoration, that ye shall be restored from sin to happiness. Behold, I say unto you, wickedness never was happiness.
34811	1325	11	And now, my son, all men that are in a state of nature, or I would say, in a carnal state, are in the gall of bitterness and in the bonds of iniquity; they are without God in the world, and they have gone contrary to the nature of God; therefore, they are in a state contrary to the nature of happiness.
34812	1325	12	And now behold, is the meaning of the word restoration to take a thing of a natural state and place it in an unnatural state, or to place it in a state opposite to its nature?
34813	1325	13	O, my son, this is not the case; but the meaning of the word restoration is to bring back again evil for evil, or carnal for carnal, or devilish for devilish--good for that which is good; righteous for that which is righteous; just for that which is just; merciful for that which is merciful.
34814	1325	14	Therefore, my son, see that you are merciful unto your brethren; deal justly, judge righteously, and do good continually; and if ye do all these things then shall ye receive your reward; yea, ye shall have mercy restored unto you again; ye shall have justice restored unto you again; ye shall have a righteous judgment restored unto you again; and ye shall have good rewarded unto you again.
34815	1325	15	For that which ye do send out shall return unto you again, and be restored; therefore, the word restoration more fully condemneth the sinner, and justifieth him not at all.
34816	1326	1	And now, my son, I perceive there is somewhat more which doth worry your mind, which ye cannot understand--which is concerning the justice of God in the punishment of the sinner; for ye do try to suppose that it is injustice that the sinner should be consigned to a state of misery.
34817	1326	2	Now behold, my son, I will explain this thing unto thee. For behold, after the Lord God sent our first parents forth from the garden of Eden, to till the ground, from whence they were taken--yea, he drew out the man, and he placed at the east end of the garden of Eden, cherubim, and a flaming sword which turned every way, to keep the tree of life--
34818	1326	3	Now, we see that the man had become as God, knowing good and evil; and lest he should put forth his hand, and take also of the tree of life, and eat and live forever, the Lord God placed cherubim and the flaming sword, that he should not partake of the fruit--
34819	1326	4	And thus we see, that there was a time granted unto man to repent, yea, a probationary time, a time to repent and serve God.
34820	1326	5	For behold, if Adam had put forth his hand immediately, and partaken of the tree of life, he would have lived forever, according to the word of God, having no space for repentance; yea, and also the word of God would have been void, and the great plan of salvation would have been frustrated.
34821	1326	6	But behold, it was appointed unto man to die--therefore, as they were cut off from the tree of life they should be cut off from the face of the earth--and man became lost forever, yea, they became fallen man.
34822	1326	7	And now, ye see by this that our first parents were cut off both temporally and spiritually from the presence of the Lord; and thus we see they became subjects to follow after their own will.
34823	1326	8	Now behold, it was not expedient that man should be reclaimed from this temporal death, for that would destroy the great plan of happiness.
34824	1326	9	Therefore, as the soul could never die, and the fall had brought upon all mankind a spiritual death as well as a temporal, that is, they were cut off from the presence of the Lord, it was expedient that mankind should be reclaimed from this spiritual death.
34825	1326	10	Therefore, as they had become carnal, sensual, and devilish, by nature, this probationary state became a state for them to prepare; it became a preparatory state.
34826	1326	11	And now remember, my son, if it were not for the plan of redemption, (laying it aside) as soon as they were dead their souls were miserable, being cut off from the presence of the Lord.
34827	1326	12	And now, there was no means to reclaim men from this fallen state, which man had brought upon himself because of his own disobedience;
34828	1326	13	Therefore, according to justice, the plan of redemption could not be brought about, only on conditions of repentance of men in this probationary state, yea, this preparatory state; for except it were for these conditions, mercy could not take effect except it should destroy the work of justice. Now the work of justice could not be destroyed; if so, God would cease to be God.
34829	1326	14	And thus we see that all mankind were fallen, and they were in the grasp of justice; yea, the justice of God, which consigned them forever to be cut off from his presence.
34830	1326	15	And now, the plan of mercy could not be brought about except an atonement should be made; therefore God himself atoneth for the sins of the world, to bring about the plan of mercy, to appease the demands of justice, that God might be a perfect, just God, and a merciful God also.
34831	1326	16	Now, repentance could not come unto men except there were a punishment, which also was eternal as the life of the soul should be, affixed opposite to the plan of happiness, which was as eternal also as the life of the soul.
34832	1326	17	Now, how could a man repent except he should sin? How could he sin if there was no law? How could there be a law save there was a punishment?
34833	1326	18	Now, there was a punishment affixed, and a just law given, which brought remorse of conscience unto man.
34834	1326	19	Now, if there was no law given--if a man murdered he should die--would he be afraid he would die if he should murder?
34835	1326	20	And also, if there was no law given against sin men would not be afraid to sin.
34836	1326	21	And if there was no law given, if men sinned what could justice do, or mercy either, for they would have no claim upon the creature?
34837	1326	22	But there is a law given, and a punishment affixed, and a repentance granted; which repentance, mercy claimeth; otherwise, justice claimeth the creature and executeth the law, and the law inflicteth the punishment; if not so, the works of justice would be destroyed, and God would cease to be God.
34838	1326	23	But God ceaseth not to be God, and mercy claimeth the penitent, and mercy cometh because of the atonement; and the atonement bringeth to pass the resurrection of the dead; and the resurrection of the dead bringeth back men into the presence of God; and thus they are restored into his presence, to be judged according to their works, according to the law and justice.
34839	1326	24	For behold, justice exerciseth all his demands, and also mercy claimeth all which is her own; and thus, none but the truly penitent are saved.
34840	1326	25	What, do ye suppose that mercy can rob justice? I say unto you, Nay; not one whit. If so, God would cease to be God.
34841	1326	26	And thus God bringeth about his great and eternal purposes, which were prepared from the foundation of the world. And thus cometh about the salvation and the redemption of men, and also their destruction and misery.
34842	1326	27	Therefore, O my son, whosoever will come may come and partake of the waters of life freely; and whosoever will not come the same is not compelled to come; but in the last day it shall be restored unto him according to his deeds.
34843	1326	28	If he has desired to do evil, and has not repented in his days, behold, evil shall be done unto him, according to the restoration of God.
34844	1326	29	And now, my son, I desire that ye should let these things trouble you no more, and only let your sins trouble you, with that trouble which shall bring you down unto repentance.
34845	1326	30	O my son, I desire that ye should deny the justice of God no more. Do not endeavor to excuse yourself in the least point because of your sins, by denying the justice of God; but do you let the justice of God, and his mercy, and his long-suffering have full sway in your heart; and let it bring you down to the dust in humility.
34846	1326	31	And now, O my son, ye are called of God to preach the word unto this people. And now, my son, go thy way, declare the word with truth and soberness, that thou mayest bring souls unto repentance, that the great plan of mercy may have claim upon them. And may God grant unto you even according to my words. Amen.
34847	1327	1	And now it came to pass that the sons of Alma did go forth among the people, to declare the word unto them. And Alma, also, himself, could not rest, and he also went forth.
34848	1327	2	Now we shall say no more concerning their preaching, except that they preached the word, and the truth, according to the spirit of prophecy and revelation; and they preached after the holy order of God by which they were called.
34849	1327	3	And now I return to an account of the wars between the Nephites and the Lamanites, in the eighteenth year of the reign of the judges.
34850	1327	4	For behold, it came to pass that the Zoramites became Lamanites; therefore, in the commencement of the eighteenth year the people of the Nephites saw that the Lamanites were coming upon them; therefore they made preparations for war; yea, they gathered together their armies in the land of Jershon.
34851	1327	5	And it came to pass that the Lamanites came with their thousands; and they came into the land of Antionum, which is the land of the Zoramites; and a man by the name of Zerahemnah was their leader.
34852	1327	6	And now, as the Amalekites were of a more wicked and murderous disposition than the Lamanites were, in and of themselves, therefore, Zerahemnah appointed chief captains over the Lamanites, and they were all Amalekites and Zoramites.
34853	1327	7	Now this he did that he might preserve their hatred towards the Nephites, that he might bring them into subjection to the accomplishment of his designs.
34854	1327	8	For behold, his designs were to stir up the Lamanites to anger against the Nephites; this he did that he might usurp great power over them, and also that he might gain power over the Nephites by bringing them into bondage.
34855	1327	9	And now the design of the Nephites was to support their lands, and their houses, and their wives, and their children, that they might preserve them from the hands of their enemies; and also that they might preserve their rights and their privileges, yea, and also their liberty, that they might worship God according to their desires.
34856	1327	10	For they knew that if they should fall into the hands of the Lamanites, that whosoever should worship God in spirit and in truth, the true and the living God, the Lamanites would destroy.
34857	1327	11	Yea, and they also knew the extreme hatred of the Lamanites towards their brethren, who were the people of Anti-Nephi-Lehi, who were called the people of Ammon--and they would not take up arms, yea, they had entered into a covenant and they would not break it--therefore, if they should fall into the hands of the Lamanites they would be destroyed.
34858	1327	12	And the Nephites would not suffer that they should be destroyed; therefore they gave them lands for their inheritance.
34859	1327	13	And the people of Ammon did give unto the Nephites a large portion of their substance to support their armies; and thus the Nephites were compelled, alone, to withstand against the Lamanites, who were a compound of Laman and Lemuel, and the sons of Ishmael, and all those who had dissented from the Nephites, who were Amalekites and Zoramites, and the descendants of the priests of Noah.
34860	1327	14	Now those descendants were as numerous, nearly, as were the Nephites; and thus the Nephites were obliged to contend with their brethren, even unto bloodshed.
34861	1327	15	And it came to pass as the armies of the Lamanites had gathered together in the land of Antionum, behold, the armies of the Nephites were prepared to meet them in the land of Jershon.
34862	1327	16	Now, the leader of the Nephites, or the man who had been appointed to be the chief captain over the Nephites--now the chief captain took the command of all the armies of the Nephites--and his name was Moroni;
34863	1327	17	And Moroni took all the command, and the government of their wars. And he was only twenty and five years old when he was appointed chief captain over the armies of the Nephites.
34864	1327	18	And it came to pass that he met the Lamanites in the borders of Jershon, and his people were armed with swords, and with cimeters, and all manner of weapons of war.
34865	1327	19	And when the armies of the Lamanites saw that the people of Nephi, or that Moroni, had prepared his people with breastplates and with arm-shields, yea, and also shields to defend their heads, and also they were dressed with thick clothing--
34866	1327	20	Now the army of Zerahemnah was not prepared with any such thing; they had only their swords and their cimeters, their bows and their arrows, their stones and their slings; and they were naked, save it were a skin which was girded about their loins; yea, all were naked, save it were the Zoramites and the Amalekites;
34867	1327	21	But they were not armed with breastplates, nor shields--therefore, they were exceedingly afraid of the armies of the Nephites because of their armor, notwithstanding their number being so much greater than the Nephites.
34868	1327	22	Behold, now it came to pass that they durst not come against the Nephites in the borders of Jershon; therefore they departed out of the land of Antionum into the wilderness, and took their journey round about in the wilderness, away by the head of the river Sidon, that they might come into the land of Manti and take possession of the land; for they did not suppose that the armies of Moroni would know whither they had gone.
34869	1327	23	But it came to pass, as soon as they had departed into the wilderness Moroni sent spies into the wilderness to watch their camp; and Moroni, also, knowing of the prophecies of Alma, sent certain men unto him, desiring him that he should inquire of the Lord whither the armies of the Nephites should go to defend themselves against the Lamanites.
34870	1327	24	And it came to pass that the word of the Lord came unto Alma, and Alma informed the messengers of Moroni, that the armies of the Lamanites were marching round about in the wilderness, that they might come over into the land of Manti, that they might commence an attack upon the weaker part of the people. And those messengers went and delivered the message unto Moroni.
34871	1327	25	Now Moroni, leaving a part of his army in the land of Jershon, lest by any means a part of the Lamanites should come into that land and take possession of the city, took the remaining part of his army and marched over into the land of Manti.
34872	1327	26	And he caused that all the people in that quarter of the land should gather themselves together to battle against the Lamanites, to defend their lands and their country, their rights and their liberties; therefore they were prepared against the time of the coming of the Lamanites.
34873	1327	27	And it came to pass that Moroni caused that his army should be secreted in the valley which was near the bank of the river Sidon, which was on the west of the river Sidon in the wilderness.
34874	1327	28	And Moroni placed spies round about, that he might know when the camp of the Lamanites should come.
34875	1327	29	And now, as Moroni knew the intention of the Lamanites, that it was their intention to destroy their brethren, or to subject them and bring them into bondage that they might establish a kingdom unto themselves over all the land;
34876	1327	30	And he also knowing that it was the only desire of the Nephites to preserve their lands, and their liberty, and their church, therefore he thought it no sin that he should defend them by stratagem; therefore, he found by his spies which course the Lamanites were to take.
34877	1327	31	Therefore, he divided his army and brought a part over into the valley, and concealed them on the east, and on the south of the hill Riplah;
34878	1327	32	And the remainder he concealed in the west valley, on the west of the river Sidon, and so down into the borders of the land Manti.
34879	1327	33	And thus having placed his army according to his desire, he was prepared to meet them.
34880	1327	34	And it came to pass that the Lamanites came up on the north of the hill, where a part of the army of Moroni was concealed.
34881	1327	35	And as the Lamanites had passed the hill Riplah, and came into the valley, and began to cross the river Sidon, the army which was concealed on the south of the hill, which was led by a man whose name was Lehi, and he led his army forth and encircled the Lamanites about on the east in their rear.
34882	1327	36	And it came to pass that the Lamanites, when they saw the Nephites coming upon them in their rear, turned them about and began to contend with the army of Lehi.
34883	1327	37	And the work of death commenced on both sides, but it was more dreadful on the part of the Lamanites, for their nakedness was exposed to the heavy blows of the Nephites with their swords and their cimeters, which brought death almost at every stroke.
34884	1327	38	While on the other hand, there was now and then a man fell among the Nephites, by their swords and the loss of blood, they being shielded from the more vital parts of the body, or the more vital parts of the body being shielded from the strokes of the Lamanites, by their breastplates, and their armshields, and their head-plates; and thus the Nephites did carry on the work of death among the Lamanites.
34885	1327	39	And it came to pass that the Lamanites became frightened, because of the great destruction among them, even until they began to flee towards the river Sidon.
34886	1327	40	And they were pursued by Lehi and his men; and they were driven by Lehi into the waters of Sidon, and they crossed the waters of Sidon. And Lehi retained his armies upon the bank of the river Sidon that they should not cross.
34887	1327	41	And it came to pass that Moroni and his army met the Lamanites in the valley, on the other side of the river Sidon, and began to fall upon them and to slay them.
34888	1327	42	And the Lamanites did flee again before them, towards the land of Manti; and they were met again by the armies of Moroni.
34889	1327	43	Now in this case the Lamanites did fight exceedingly; yea, never had the Lamanites been known to fight with such exceedingly great strength and courage, no, not even from the beginning.
34890	1327	44	And they were inspired by the Zoramites and the Amalekites, who were their chief captains and leaders, and by Zerahemnah, who was their chief captain, or their chief leader and commander; yea, they did fight like dragons, and many of the Nephites were slain by their hands, yea, for they did smite in two many of their head-plates, and they did pierce many of their breastplates, and they did smite off many of their arms; and thus the Lamanites did smite in their fierce anger.
34891	1327	45	Nevertheless, the Nephites were inspired by a better cause, for they were not fighting for monarchy nor power but they were fighting for their homes and their liberties, their wives and their children, and their all, yea, for their rites of worship and their church.
34892	1327	46	And they were doing that which they felt was the duty which they owed to their God; for the Lord had said unto them, and also unto their fathers, that: Inasmuch as ye are not guilty of the first offense, neither the second, ye shall not suffer yourselves to be slain by the hands of your enemies.
34893	1327	47	And again, the Lord has said that: Ye shall defend your families even unto bloodshed. Therefore for this cause were the Nephites contending with the Lamanites, to defend themselves, and their families, and their lands, their country, and their rights, and their religion.
34894	1327	48	And it came to pass that when the men of Moroni saw the fierceness and the anger of the Lamanites, they were about to shrink and flee from them. And Moroni, perceiving their intent, sent forth and inspired their hearts with these thoughts--yea, the thoughts of their lands, their liberty, yea, their freedom from bondage.
34895	1327	49	And it came to pass that they turned upon the Lamanites, and they cried with one voice unto the Lord their God, for their liberty and their freedom from bondage.
34896	1327	50	And they began to stand against the Lamanites with power; and in that selfsame hour that they cried unto the Lord for their freedom, the Lamanites began to flee before them; and they fled even to the waters of Sidon.
34897	1327	51	Now, the Lamanites were more numerous, yea, by more than double the number of the Nephites; nevertheless, they were driven insomuch that they were gathered together in one body in the valley, upon the bank by the river Sidon.
34898	1327	52	Therefore the armies of Moroni encircled them about, yea, even on both sides of the river, for behold, on the east were the men of Lehi.
34899	1327	53	Therefore when Zerahemnah saw the men of Lehi on the east of the river Sidon, and the armies of Moroni on the west of the river Sidon, that they were encircled about by the Nephites, they were struck with terror.
34900	1327	54	Now Moroni, when he saw their terror, commanded his men that they should stop shedding their blood.
34901	1328	1	And it came to pass that they did stop and withdrew a pace from them. And Moroni said unto Zerahemnah: Behold, Zerahemnah, that we do not desire to be men of blood. Ye know that ye are in our hands, yet we do not desire to slay you.
34902	1328	2	Behold, we have not come out to battle against you that we might shed your blood for power; neither do we desire to bring any one to the yoke of bondage. But this is the very cause for which ye have come against us; yea, and ye are angry with us because of our religion.
34903	1328	3	But now, ye behold that the Lord is with us; and ye behold that he has delivered you into our hands. And now I would that ye should understand that this is done unto us because of our religion and our faith in Christ. And now ye see that ye cannot destroy this our faith.
34904	1328	4	Now ye see that this is the true faith of God; yea, ye see that God will support, and keep, and preserve us, so long as we are faithful unto him, and unto our faith, and our religion; and never will the Lord suffer that we shall be destroyed except we should fall into transgression and deny our faith.
34905	1328	5	And now, Zerahemnah, I command you, in the name of that all-powerful God, who has strengthened our arms that we have gained power over you, by our faith, by our religion, and by our rites of worship, and by our church, and by the sacred support which we owe to our wives and our children, by that liberty which binds us to our lands and our country; yea, and also by the maintenance of the sacred word of God, to which we owe all our happiness; and by all that is most dear unto us--
34906	1328	6	Yea, and this is not all; I command you by all the desires which ye have for life, that ye deliver up your weapons of war unto us, and we will seek not your blood, but we will spare your lives, if ye will go your way and come not again to war against us.
34907	1328	7	And now, if ye do not this, behold, ye are in our hands, and I will command my men that they shall fall upon you, and inflict the wounds of death in your bodies, that ye may become extinct; and then we will see who shall have power over this people; yea, we will see who shall be brought into bondage.
34908	1328	8	And now it came to pass that when Zerahemnah had heard these sayings he came forth and delivered up his sword and his cimeter, and his bow into the hands of Moroni, and said unto him: Behold, here are our weapons of war; we will deliver them up unto you, but we will not suffer ourselves to take an oath unto you, which we know that we shall break, and also our children; but take our weapons of war, and suffer that we may depart into the wilderness; otherwise we will retain our swords, and we will perish or conquer.
34909	1328	9	Behold, we are not of your faith; we do not believe that it is God that has delivered us into your hands; but we believe that it is your cunning that has preserved you from our swords. Behold, it is your breastplates and your shields that have preserved you.
34910	1328	10	And now when Zerahemnah had made an end of speaking these words, Moroni returned the sword and the weapons of war, which he had received, unto Zerahemnah, saying: Behold, we will end the conflict.
34911	1328	11	Now I cannot recall the words which I have spoken, therefore as the Lord liveth, ye shall not depart except ye depart with an oath that ye will not return again against us to war. Now as ye are in our hands we will spill your blood upon the ground, or ye shall submit to the conditions which I have proposed.
34912	1328	12	And now when Moroni had said these words, Zerahemnah retained his sword, and he was angry with Moroni, and he rushed forward that he might slay Moroni; but as he raised his sword, behold, one of Moroni's soldiers smote it even to the earth, and it broke by the hilt; and he also smote Zerahemnah that he took off his scalp and it fell to the earth. And Zerahemnah withdrew from before them into the midst of his soldiers.
34913	1328	13	And it came to pass that the soldier who stood by, who smote off the scalp of Zerahemnah, took up the scalp from off the ground by the hair, and laid it upon the point of his sword, and stretched it forth unto them, saying unto them with a loud voice:
34914	1328	14	Even as this scalp has fallen to the earth, which is the scalp of your chief, so shall ye fall to the earth except ye will deliver up your weapons of war and depart with a covenant of peace.
34915	1328	15	Now there were many, when they heard these words and saw the scalp which was upon the sword, that were struck with fear; and many came forth and threw down their weapons of war at the feet of Moroni, and entered into a covenant of peace. And as many as entered into a covenant they suffered to depart into the wilderness.
34916	1328	16	Now it came to pass that Zerahemnah was exceedingly wroth, and he did stir up the remainder of his soldiers to anger, to contend more powerfully against the Nephites.
34917	1328	17	And now Moroni was angry, because of the stubbornness of the Lamanites; therefore he commanded his people that they should fall upon them and slay them. And it came to pass that they began to slay them; yea, and the Lamanites did contend with their swords and their might.
34918	1328	18	But behold, their naked skins and their bare heads were exposed to the sharp swords of the Nephites; yea, behold they were pierced and smitten, yea, and did fall exceedingly fast before the swords of the Nephites; and they began to be swept down, even as the soldier of Moroni had prophesied.
34919	1328	19	Now Zerahemnah, when he saw that they were all about to be destroyed, cried mightily unto Moroni, promising that he would covenant and also his people with them, if they would spare the remainder of their lives, that they never would come to war again against them.
34920	1328	20	And it came to pass that Moroni caused that the work of death should cease again among the people. And he took the weapons of war from the Lamanites; and after they had entered into a covenant with him of peace they were suffered to depart into the wilderness.
34921	1328	21	Now the number of their dead was not numbered because of the greatness of the number; yea, the number of their dead was exceedingly great, both on the Nephites and on the Lamanites.
34922	1328	22	And it came to pass that they did cast their dead into the waters of Sidon, and they have gone forth and are buried in the depths of the sea.
34923	1328	23	And the armies of the Nephites, or of Moroni, returned and came to their houses and their lands.
34924	1328	24	And thus ended the eighteenth year of the reign of the judges over the people of Nephi. And thus ended the record of Alma, which was written upon the plates of Nephi.
34925	1329	1	Behold, now it came to pass that the people of Nephi were exceedingly rejoiced, because the Lord had again delivered them out of the hands of their enemies; therefore they gave thanks unto the Lord their God; yea, and they did fast much and pray much, and they did worship God with exceedingly great joy.
34926	1329	2	And it came to pass in the nineteenth year of the reign of the judges over the people of Nephi, that Alma came unto his son Helaman and said unto him: Believest thou the words which I spake unto thee concerning those records which have been kept?
34927	1329	3	And Helaman said unto him: Yea, I believe.
34928	1329	4	And Alma said again: Believest thou in Jesus Christ, who shall come?
34929	1329	5	And he said: Yea, I believe all the words which thou hast spoken.
34930	1329	6	And Alma said unto him again: Will ye keep my commandments?
34931	1329	7	And he said: Yea, I will keep thy commandments with all my heart.
34932	1329	8	Then Alma said unto him: Blessed art thou; and the Lord shall prosper thee in this land.
34933	1329	9	But behold, I have somewhat to prophesy unto thee; but what I prophesy unto thee ye shall not make known; yea, what I prophesy unto thee shall not be made known, even until the prophecy is fulfilled; therefore write the words which I shall say.
34934	1329	10	And these are the words: Behold, I perceive that this very people, the Nephites, according to the spirit of revelation which is in me, in four hundred years from the time that Jesus Christ shall manifest himself unto them, shall dwindle in unbelief.
34935	1329	11	Yea, and then shall they see wars and pestilences, yea, famines and bloodshed, even until the people of Nephi shall become extinct--
34936	1329	12	Yea, and this because they shall dwindle in unbelief and fall into the works of darkness, and lasciviousness, and all manner of iniquities; yea, I say unto you, that because they shall sin against so great light and knowledge, yea, I say unto you, that from that day, even the fourth generation shall not all pass away before this great iniquity shall come.
34937	1329	13	And when that great day cometh, behold, the time very soon cometh that those who are now, or the seed of those who are now numbered among the people of Nephi, shall no more be numbered among the people of Nephi.
34938	1329	14	But whosoever remaineth, and is not destroyed in that great and dreadful day, shall be numbered among the Lamanites, and shall become like unto them, all, save it be a few who shall be called the disciples of the Lord; and them shall the Lamanites pursue even until they shall become extinct. And now, because of iniquity, this prophecy shall be fulfilled.
34939	1329	15	And now it came to pass that after Alma had said these things to Helaman, he blessed him, and also his other sons; and he also blessed the earth for the righteous' sake.
34940	1329	16	And he said: Thus saith the Lord God--Cursed shall be the land, yea, this land, unto every nation, kindred, tongue, and people, unto destruction, which do wickedly, when they are fully ripe; and as I have said so shall it be; for this is the cursing and the blessing of God upon the land, for the Lord cannot look upon sin with the least degree of allowance.
34941	1329	17	And now, when Alma had said these words he blessed the church, yea, all those who should stand fast in the faith from that time henceforth.
34942	1329	18	And when Alma had done this he departed out of the land of Zarahemla, as if to go into the land of Melek. And it came to pass that he was never heard of more; as to his death or burial we know not of.
34943	1329	19	Behold, this we know, that he was a righteous man; and the saying went abroad in the church that he was taken up by the Spirit, or buried by the hand of the Lord, even as Moses. But behold, the scriptures saith the Lord took Moses unto himself; and we suppose that he has also received Alma in the spirit, unto himself; therefore, for this cause we know nothing concerning his death and burial.
34944	1329	20	And now it came to pass in the commencement of the nineteenth year of the reign of the judges over the people of Nephi, that Helaman went forth among the people to declare the word unto them.
34945	1329	21	For behold, because of their wars with the Lamanites and the many little dissensions and disturbances which had been among the people, it became expedient that the word of God should be declared among them, yea, and that a regulation should be made throughout the church.
34946	1329	22	Therefore, Helaman and his brethren went forth to establish the church again in all the land, yea, in every city throughout all the land which was possessed by the people of Nephi. And it came to pass that they did appoint priests and teachers throughout all the land, over all the churches.
34947	1329	23	And now it came to pass that after Helaman and his brethren had appointed priests and teachers over the churches that there arose a dissension among them, and they would not give heed to the words of Helaman and his brethren;
34948	1329	24	But they grew proud, being lifted up in their hearts, because of their exceedingly great riches; therefore they grew rich in their own eyes, and would not give heed to their words, to walk uprightly before God.
34949	1330	1	And it came to pass that as many as would not hearken to the words of Helaman and his brethren were gathered together against their brethren.
34950	1330	2	And now behold, they were exceedingly wroth, insomuch that they were determined to slay them.
34951	1330	3	Now the leader of those who were wroth against their brethren was a large and a strong man; and his name was Amalickiah.
34952	1330	4	And Amalickiah was desirous to be a king; and those people who were wroth were also desirous that he should be their king; and they were the greater part of them the lower judges of the land, and they were seeking for power.
34953	1330	5	And they had been led by the flatteries of Amalickiah, that if they would support him and establish him to be their king that he would make them rulers over the people.
34954	1330	6	Thus they were led away by Amalickiah to dissensions, notwithstanding the preaching of Helaman and his brethren, yea, notwithstanding their exceedingly great care over the church, for they were high priests over the church.
34955	1330	7	And there were many in the church who believed in the flattering words of Amalickiah, therefore they dissented even from the church; and thus were the affairs of the people of Nephi exceedingly precarious and dangerous, notwithstanding their great victory which they had had over the Lamanites, and their great rejoicings which they had had because of their deliverance by the hand of the Lord.
34956	1330	8	Thus we see how quick the children of men do forget the Lord their God, yea, how quick to do iniquity, and to be led away by the evil one.
34957	1330	9	Yea, and we also see the great wickedness one very wicked man can cause to take place among the children of men.
34958	1330	10	Yea, we see that Amalickiah, because he was a man of cunning device and a man of many flattering words, that he led away the hearts of many people to do wickedly; yea, and to seek to destroy the church of God, and to destroy the foundation of liberty which God had granted unto them, or which blessing God had sent upon the face of the land for the righteous' sake.
34959	1330	11	And now it came to pass that when Moroni, who was the chief commander of the armies of the Nephites, had heard of these dissensions, he was angry with Amalickiah.
34960	1330	12	And it came to pass that he rent his coat; and he took a piece thereof, and wrote upon it--In memory of our God, our religion, and freedom, and our peace, our wives, and our children--and he fastened it upon the end of a pole.
34961	1330	13	And he fastened on his head-plate, and his breastplate, and his shields, and girded on his armor about his loins; and he took the pole, which had on the end thereof his rent coat, (and he called it the title of liberty) and he bowed himself to the earth, and he prayed mightily unto his God for the blessings of liberty to rest upon his brethren, so long as there should a band of Christians remain to possess the land--
34962	1330	14	For thus were all the true believers of Christ, who belonged to the church of God, called by those who did not belong to the church.
34963	1330	15	And those who did belong to the church were faithful; yea, all those who were true believers in Christ took upon them, gladly, the name of Christ, or Christians as they were called, because of their belief in Christ who should come.
34964	1330	16	And therefore, at this time, Moroni prayed that the cause of the Christians, and the freedom of the land might be favored.
34965	1330	17	And it came to pass that when he had poured out his soul to God, he named all the land which was south of the land Desolation, yea, and in fine, all the land, both on the north and on the south--A chosen land, and the land of liberty.
34966	1330	18	And he said: Surely God shall not suffer that we, who are despised because we take upon us the name of Christ, shall be trodden down and destroyed, until we bring it upon us by our own transgressions.
34967	1330	19	And when Moroni had said these words, he went forth among the people, waving the rent part of his garment in the air, that all might see the writing which he had written upon the rent part, and crying with a loud voice, saying:
34968	1330	20	Behold, whosoever will maintain this title upon the land, let them come forth in the strength of the Lord, and enter into a covenant that they will maintain their rights, and their religion, that the Lord God may bless them.
34969	1330	21	And it came to pass that when Moroni had proclaimed these words, behold, the people came running together with their armor girded about their loins, rending their garments in token, or as a covenant, that they would not forsake the Lord their God; or, in other words, if they should transgress the commandments of God, or fall into transgression, and be ashamed to take upon them the name of Christ, the Lord should rend them even as they had rent their garments.
34970	1330	22	Now this was the covenant which they made, and they cast their garments at the feet of Moroni, saying: We covenant with our God, that we shall be destroyed, even as our brethren in the land northward, if we shall fall into transgression; yea, he may cast us at the feet of our enemies, even as we have cast our garments at thy feet to be trodden under foot, if we shall fall into transgression.
34971	1330	23	Moroni said unto them: Behold, we are a remnant of the seed of Jacob; yea, we are a remnant of the seed of Joseph, whose coat was rent by his brethren into many pieces; yea, and now behold, let us remember to keep the commandments of God, or our garments shall be rent by our brethren, and we be cast into prison, or be sold, or be slain.
34972	1330	24	Yea, let us preserve our liberty as a remnant of Joseph; yea, let us remember the words of Jacob, before his death, for behold, he saw that a part of the remnant of the coat of Joseph was preserved and had not decayed. And he said--Even as this remnant of garment of my son hath been preserved, so shall a remnant of the seed of my son be preserved by the hand of God, and be taken unto himself, while the remainder of the seed of Joseph shall perish, even as the remnant of his garment.
34973	1330	25	Now behold, this giveth my soul sorrow; nevertheless, my soul hath joy in my son, because of that part of his seed which shall be taken unto God.
34974	1330	26	Now behold, this was the language of Jacob.
34975	1330	27	And now who knoweth but what the remnant of the seed of Joseph, which shall perish as his garment, are those who have dissented from us? Yea, and even it shall be ourselves if we do not stand fast in the faith of Christ.
34976	1330	28	And now it came to pass that when Moroni had said these words he went forth, and also sent forth in all the parts of the land where there were dissensions, and gathered together all the people who were desirous to maintain their liberty, to stand against Amalickiah and those who had dissented, who were called Amalickiahites.
34977	1330	29	And it came to pass that when Amalickiah saw that the people of Moroni were more numerous than the Amalickiahites--and he also saw that his people were doubtful concerning the justice of the cause in which they had undertaken--therefore, fearing that he should not gain the point, he took those of his people who would and departed into the land of Nephi.
34978	1330	30	Now Moroni thought it was not expedient that the Lamanites should have any more strength; therefore he thought to cut off the people of Amalickiah, or to take them and bring them back, and put Amalickiah to death; yea, for he knew that he would stir up the Lamanites to anger against them, and cause them to come to battle against them; and this he knew that Amalickiah would do that he might obtain his purposes.
34979	1330	31	Therefore Moroni thought it was expedient that he should take his armies, who had gathered themselves together, and armed themselves, and entered into a covenant to keep the peace--and it came to pass that he took his army and marched out with his tents into the wilderness, to cut off the course of Amalickiah in the wilderness.
34980	1330	32	And it came to pass that he did according to his desires, and marched forth into the wilderness, and headed the armies of Amalickiah.
34981	1330	33	And it came to pass that Amalickiah fled with a small number of his men, and the remainder were delivered up into the hands of Moroni and were taken back into the land of Zarahemla.
34982	1330	34	Now, Moroni being a man who was appointed by the chief judges and the voice of the people, therefore he had power according to his will with the armies of the Nephites, to establish and to exercise authority over them.
34983	1330	35	And it came to pass that whomsoever of the Amalickiahites that would not enter into a covenant to support the cause of freedom, that they might maintain a free government, he caused to be put to death; and there were but few who denied the covenant of freedom.
34984	1330	36	And it came to pass also, that he caused the title of liberty to be hoisted upon every tower which was in all the land, which was possessed by the Nephites; and thus Moroni planted the standard of liberty among the Nephites.
34985	1330	37	And they began to have peace again in the land; and thus they did maintain peace in the land until nearly the end of the nineteenth year of the reign of the judges.
34986	1330	38	And Helaman and the high priests did also maintain order in the church; yea, even for the space of four years did they have much peace and rejoicing in the church.
34987	1330	39	And it came to pass that there were many who died, firmly believing that their souls were redeemed by the Lord Jesus Christ; thus they went out of the world rejoicing.
34988	1330	40	And there were some who died with fevers, which at some seasons of the year were very frequent in the land--but not so much so with fevers, because of the excellent qualities of the many plants and roots which God had prepared to remove the cause of diseases, to which men were subject by the nature of the climate--
34989	1330	41	But there were many who died with old age; and those who died in the faith of Christ are happy in him, as we must needs suppose.
34990	1331	1	Now we will return in our record to Amalickiah and those who had fled with him into the wilderness; for, behold, he had taken those who went with him, and went up in the land of Nephi among the Lamanites, and did stir up the Lamanites to anger against the people of Nephi, insomuch that the king of the Lamanites sent a proclamation throughout all his land, among all his people, that they should gather themselves together again to go to battle against the Nephites.
34991	1331	2	And it came to pass that when the proclamation had gone forth among them they were exceedingly afraid; yea, they feared to displease the king, and they also feared to go to battle against the Nephites lest they should lose their lives. And it came to pass that they would not, or the more part of them would not, obey the commandments of the king.
34992	1331	3	And now it came to pass that the king was wroth because of their disobedience; therefore he gave Amalickiah the command of that part of his army which was obedient unto his commands, and commanded him that he should go forth and compel them to arms.
34993	1331	4	Now behold, this was the desire of Amalickiah; for he being a very subtle man to do evil therefore he laid the plan in his heart to dethrone the king of the Lamanites.
34994	1331	5	And now he had got the command of those parts of the Lamanites who were in favor of the king; and he sought to gain favor of those who were not obedient; therefore he went forward to the place which was called Onidah, for thither had all the Lamanites fled; for they discovered the army coming, and, supposing that they were coming to destroy them, therefore they fled to Onidah, to the place of arms.
34995	1331	6	And they had appointed a man to be a king and a leader over them, being fixed in their minds with a determined resolution that they would not be subjected to go against the Nephites.
34996	1331	7	And it came to pass that they had gathered themselves together upon the top of the mount which was called Antipas, in preparation to battle.
34997	1331	8	Now it was not Amalickiah's intention to give them battle according to the commandments of the king; but behold, it was his intention to gain favor with the armies of the Lamanites, that he might place himself at their head and dethrone the king and take possession of the kingdom.
34998	1331	9	And behold, it came to pass that he caused his army to pitch their tents in the valley which was near the mount Antipas.
34999	1331	10	And it came to pass that when it was night he sent a secret embassy into the mount Antipas, desiring that the leader of those who were upon the mount, whose name was Lehonti, that he should come down to the foot of the mount, for he desired to speak with him.
35000	1331	11	And it came to pass that when Lehonti received the message he durst not go down to the foot of the mount. And it came to pass that Amalickiah sent again the second time, desiring him to come down. And it came to pass that Lehonti would not; and he sent again the third time.
35001	1331	12	And it came to pass that when Amalickiah found that he could not get Lehonti to come down off from the mount, he went up into the mount, nearly to Lehonti's camp; and he sent again the fourth time his message unto Lehonti, desiring that he would come down, and that he would bring his guards with him.
35002	1331	13	And it came to pass that when Lehonti had come down with his guards to Amalickiah, that Amalickiah desired him to come down with his army in the night-time, and surround those men in their camps over whom the king had given him command, and that he would deliver them up into Lehonti's hands, if he would make him (Amalickiah) a second leader over the whole army.
35003	1331	14	And it came to pass that Lehonti came down with his men and surrounded the men of Amalickiah, so that before they awoke at the dawn of day they were surrounded by the armies of Lehonti.
35004	1331	15	And it came to pass that when they saw that they were surrounded, they plead with Amalickiah that he would suffer them to fall in with their brethren, that they might not be destroyed. Now this was the very thing which Amalickiah desired.
35005	1331	16	And it came to pass that he delivered his men, contrary to the commands of the king. Now this was the thing that Amalickiah desired, that he might accomplish his designs in dethroning the king.
35006	1331	17	Now it was the custom among the Lamanites, if their chief leader was killed, to appoint the second leader to be their chief leader.
35007	1331	18	And it came to pass that Amalickiah caused that one of his servants should administer poison by degrees to Lehonti, that he died.
35008	1331	19	Now, when Lehonti was dead, the Lamanites appointed Amalickiah to be their leader and their chief commander.
35009	1331	20	And it came to pass that Amalickiah marched with his armies (for he had gained his desires) to the land of Nephi, to the city of Nephi, which was the chief city.
35010	1331	21	And the king came out to meet him with his guards, for he supposed that Amalickiah had fulfilled his commands, and that Amalickiah had gathered together so great an army to go against the Nephites to battle.
35011	1331	22	But behold, as the king came out to meet him Amalickiah caused that his servants should go forth to meet the king. And they went and bowed themselves before the king, as if to reverence him because of his greatness.
35012	1331	23	And it came to pass that the king put forth his hand to raise them, as was the custom with the Lamanites, as a token of peace, which custom they had taken from the Nephites.
35013	1331	24	And it came to pass that when he had raised the first from the ground, behold he stabbed the king to the heart; and he fell to the earth.
35014	1331	25	Now the servants of the king fled; and the servants of Amalickiah raised a cry, saying:
35015	1331	26	Behold, the servants of the king have stabbed him to the heart, and he has fallen and they have fled; behold, come and see.
35016	1331	27	And it came to pass that Amalickiah commanded that his armies should march forth and see what had happened to the king; and when they had come to the spot, and found the king lying in his gore, Amalickiah pretended to be wroth, and said: Whosoever loved the king, let him go forth, and pursue his servants that they may be slain.
35017	1331	28	And it came to pass that all they who loved the king, when they heard these words, came forth and pursued after the servants of the king.
35018	1331	29	Now when the servants of the king saw an army pursuing after them, they were frightened again, and fled into the wilderness, and came over into the land of Zarahemla and joined the people of Ammon.
35019	1331	30	And the army which pursued after them returned, having pursued after them in vain; and thus Amalickiah, by his fraud, gained the hearts of the people.
35020	1331	31	And it came to pass on the morrow he entered the city Nephi with his armies, and took possession of the city.
35021	1331	32	And now it came to pass that the queen, when she had heard that the king was slain--for Amalickiah had sent an embassy to the queen informing her that the king had been slain by his servants, that he had pursued them with his army, but it was in vain, and they had made their escape--
35022	1331	33	Therefore, when the queen had received this message she sent unto Amalickiah, desiring him that he would spare the people of the city; and she also desired him that he should come in unto her; and she also desired him that he should bring witnesses with him to testify concerning the death of the king.
35023	1331	34	And it came to pass that Amalickiah took the same servant that slew the king, and all them who were with him, and went in unto the queen, unto the place where she sat; and they all testified unto her that the king was slain by his own servants; and they said also: They have fled; does not this testify against them? And thus they satisfied the queen concerning the death of the king.
35024	1331	35	And it came to pass that Amalickiah sought the favor of the queen, and took her unto him to wife; and thus by his fraud, and by the assistance of his cunning servants, he obtained the kingdom; yea, he was acknowledged king throughout all the land, among all the people of the Lamanites, who were composed of the Lamanites and the Lemuelites and the Ishmaelites, and all the dissenters of the Nephites, from the reign of Nephi down to the present time.
35025	1331	36	Now these dissenters, having the same instruction and the same information of the Nephites, yea, having been instructed in the same knowledge of the Lord, nevertheless, it is strange to relate, not long after their dissensions they became more hardened and impenitent, and more wild, wicked and ferocious than the Lamanites--drinking in with the traditions of the Lamanites; giving way to indolence, and all manner of lasciviousness; yea, entirely forgetting the Lord their God.
35026	1332	1	And now it came to pass that, as soon as Amalickiah had obtained the kingdom he began to inspire the hearts of the Lamanites against the people of Nephi; yea, he did appoint men to speak unto the Lamanites from their towers, against the Nephites.
35027	1332	2	And thus he did inspire their hearts against the Nephites, insomuch that in the latter end of the nineteenth year of the reign of the judges, he having accomplished his designs thus far, yea, having been made king over the Lamanites, he sought also to reign over all the land, yea, and all the people who were in the land, the Nephites as well as the Lamanites.
35028	1332	3	Therefore he had accomplished his design, for he had hardened the hearts of the Lamanites and blinded their minds, and stirred them up to anger, insomuch that he had gathered together a numerous host to go to battle against the Nephites.
35029	1332	4	For he was determined, because of the greatness of the number of his people, to overpower the Nephites and to bring them into bondage.
35030	1332	5	And thus he did appoint chief captains of the Zoramites, they being the most acquainted with the strength of the Nephites, and their places of resort, and the weakest parts of their cities; therefore he appointed them to be chief captains over his armies.
35031	1332	6	And it came to pass that they took their camp, and moved forth toward the land of Zarahemla in the wilderness.
35032	1332	7	Now it came to pass that while Amalickiah had thus been obtaining power by fraud and deceit, Moroni, on the other hand, had been preparing the minds of the people to be faithful unto the Lord their God.
35033	1332	8	Yea, he had been strengthening the armies of the Nephites, and erecting small forts, or places of resort; throwing up banks of earth round about to enclose his armies, and also building walls of stone to encircle them about, round about their cities and the borders of their lands; yea, all round about the land.
35034	1332	9	And in their weakest fortifications he did place the greater number of men; and thus he did fortify and strengthen the land which was possessed by the Nephites.
35035	1332	10	And thus he was preparing to support their liberty, their lands, their wives, and their children, and their peace, and that they might live unto the Lord their God, and that they might maintain that which was called by their enemies the cause of Christians.
35036	1332	11	And Moroni was a strong and a mighty man; he was a man of a perfect understanding; yea, a man that did not delight in bloodshed; a man whose soul did joy in the liberty and the freedom of his country, and his brethren from bondage and slavery;
35037	1332	12	Yea, a man whose heart did swell with thanksgiving to his God, for the many privileges and blessings which he bestowed upon his people; a man who did labor exceedingly for the welfare and safety of his people.
35038	1332	13	Yea, and he was a man who was firm in the faith of Christ, and he had sworn with an oath to defend his people, his rights, and his country, and his religion, even to the loss of his blood.
35039	1332	14	Now the Nephites were taught to defend themselves against their enemies, even to the shedding of blood if it were necessary; yea, and they were also taught never to give an offense, yea, and never to raise the sword except it were against an enemy, except it were to preserve their lives.
35040	1332	15	And this was their faith, that by so doing God would prosper them in the land, or in other words, if they were faithful in keeping the commandments of God that he would prosper them in the land; yea, warn them to flee, or to prepare for war, according to their danger;
35041	1332	16	And also, that God would make it known unto them whither they should go to defend themselves against their enemies, and by so doing, the Lord would deliver them; and this was the faith of Moroni, and his heart did glory in it; not in the shedding of blood but in doing good, in preserving his people, yea, in keeping the commandments of God, yea, and resisting iniquity.
35042	1332	17	Yea, verily, verily I say unto you, if all men had been, and were, and ever would be, like unto Moroni, behold, the very powers of hell would have been shaken forever; yea, the devil would never have power over the hearts of the children of men.
35043	1332	18	Behold, he was a man like unto Ammon, the son of Mosiah, yea, and even the other sons of Mosiah, yea, and also Alma and his sons, for they were all men of God.
35044	1332	19	Now behold, Helaman and his brethren were no less serviceable unto the people than was Moroni; for they did preach the word of God, and they did baptize unto repentance all men whosoever would hearken unto their words.
35045	1332	20	And thus they went forth, and the people did humble themselves because of their words, insomuch that they were highly favored of the Lord, and thus they were free from wars and contentions among themselves, yea, even for the space of four years.
35046	1332	21	But, as I have said, in the latter end of the nineteenth year, yea, notwithstanding their peace amongst themselves, they were compelled reluctantly to contend with their brethren, the Lamanites.
35047	1332	22	Yea, and in fine, their wars never did cease for the space of many years with the Lamanites, notwithstanding their much reluctance.
35048	1332	23	Now, they were sorry to take up arms against the Lamanites, because they did not delight in the shedding of blood; yea, and this was not all--they were sorry to be the means of sending so many of their brethren out of this world into an eternal world, unprepared to meet their God.
35049	1332	24	Nevertheless, they could not suffer to lay down their lives, that their wives and their children should be massacred by the barbarous cruelty of those who were once their brethren, yea, and had dissented from their church, and had left them and had gone to destroy them by joining the Lamanites.
35050	1332	25	Yea, they could not bear that their brethren should rejoice over the blood of the Nephites, so long as there were any who should keep the commandments of God, for the promise of the Lord was, if they should keep his commandments they should prosper in the land.
35051	1333	1	And now it came to pass in the eleventh month of the nineteenth year, on the tenth day of the month, the armies of the Lamanites were seen approaching towards the land of Ammonihah.
35052	1333	2	And behold, the city had been rebuilt, and Moroni had stationed an army by the borders of the city, and they had cast up dirt round about to shield them from the arrows and the stones of the Lamanites; for behold, they fought with stones and with arrows.
35053	1333	3	Behold, I said that the city of Ammonihah had been rebuilt. I say unto you, yea, that it was in part rebuilt; and because the Lamanites had destroyed it once because of the iniquity of the people, they supposed that it would again become an easy prey for them.
35054	1333	4	But behold, how great was their disappointment; for behold, the Nephites had dug up a ridge of earth round about them, which was so high that the Lamanites could not cast their stones and their arrows at them that they might take effect, neither could they come upon them save it was by their place of entrance.
35055	1333	5	Now at this time the chief captains of the Lamanites were astonished exceedingly, because of the wisdom of the Nephites in preparing their places of security.
35056	1333	6	Now the leaders of the Lamanites had supposed, because of the greatness of their numbers, yea, they supposed that they should be privileged to come upon them as they had hitherto done; yea, and they had also prepared themselves with shields, and with breastplates; and they had also prepared themselves with garments of skins, yea, very thick garments to cover their nakedness.
35057	1333	7	And being thus prepared they supposed that they should easily overpower and subject their brethren to the yoke of bondage, or slay and massacre them according to their pleasure.
35058	1333	8	But behold, to their uttermost astonishment, they were prepared for them, in a manner which never had been known among the children of Lehi. Now they were prepared for the Lamanites, to battle after the manner of the instructions of Moroni.
35059	1333	9	And it came to pass that the Lamanites, or the Amalickiahites, were exceedingly astonished at their manner of preparation for war.
35060	1333	10	Now, if king Amalickiah had come down out of the land of Nephi, at the head of his army, perhaps he would have caused the Lamanites to have attacked the Nephites at the city of Ammonihah; for behold, he did care not for the blood of his people.
35061	1333	11	But behold, Amalickiah did not come down himself to battle. And behold, his chief captains durst not attack the Nephites at the city of Ammonihah, for Moroni had altered the management of affairs among the Nephites, insomuch that the Lamanites were disappointed in their places of retreat and they could not come upon them.
35062	1333	12	Therefore they retreated into the wilderness, and took their camp and marched towards the land of Noah, supposing that to be the next best place for them to come against the Nephites.
35063	1333	13	For they knew not that Moroni had fortified, or had built forts of security, for every city in all the land round about; therefore, they marched forward to the land of Noah with a firm determination; yea, their chief captains came forward and took an oath that they would destroy the people of that city.
35064	1333	14	But behold, to their astonishment, the city of Noah, which had hitherto been a weak place, had now, by the means of Moroni, become strong, yea, even to exceed the strength of the city Ammonihah.
35065	1333	15	And now, behold, this was wisdom in Moroni; for he had supposed that they would be frightened at the city Ammonihah; and as the city of Noah had hitherto been the weakest part of the land, therefore they would march thither to battle; and thus it was according to his desires.
35066	1333	16	And behold, Moroni had appointed Lehi to be chief captain over the men of that city; and it was that same Lehi who fought with the Lamanites in the valley on the east of the river Sidon.
35067	1333	17	And now behold it came to pass, that when the Lamanites had found that Lehi commanded the city they were again disappointed, for they feared Lehi exceedingly; nevertheless their chief captains had sworn with an oath to attack the city; therefore, they brought up their armies.
35068	1333	18	Now behold, the Lamanites could not get into their forts of security by any other way save by the entrance, because of the highness of the bank which had been thrown up, and the depth of the ditch which had been dug round about, save it were by the entrance.
35069	1333	19	And thus were the Nephites prepared to destroy all such as should attempt to climb up to enter the fort by any other way, by casting over stones and arrows at them.
35070	1333	20	Thus they were prepared, yea, a body of their strongest men, with their swords and their slings, to smite down all who should attempt to come into their place of security by the place of entrance; and thus were they prepared to defend themselves against the Lamanites.
35071	1333	21	And it came to pass that the captains of the Lamanites brought up their armies before the place of entrance, and began to contend with the Nephites, to get into their place of security; but behold, they were driven back from time to time, insomuch that they were slain with an immense slaughter.
35072	1333	22	Now when they found that they could not obtain power over the Nephites by the pass, they began to dig down their banks of earth that they might obtain a pass to their armies, that they might have an equal chance to fight; but behold, in these attempts they were swept off by the stones and arrows which were thrown at them; and instead of filling up their ditches by pulling down the banks of earth, they were filled up in a measure with their dead and wounded bodies.
35073	1333	23	Thus the Nephites had all power over their enemies; and thus the Lamanites did attempt to destroy the Nephites until their chief captains were all slain; yea, and more than a thousand of the Lamanites were slain; while, on the other hand, there was not a single soul of the Nephites which was slain.
35074	1333	24	There were about fifty who were wounded, who had been exposed to the arrows of the Lamanites through the pass, but they were shielded by their shields, and their breastplates, and their head-plates, insomuch that their wounds were upon their legs, many of which were very severe.
35075	1333	25	And it came to pass, that when the Lamanites saw that their chief captains were all slain they fled into the wilderness. And it came to pass that they returned to the land of Nephi, to inform their king, Amalickiah, who was a Nephite by birth, concerning their great loss.
35076	1333	26	And it came to pass that he was exceedingly angry with his people, because he had not obtained his desire over the Nephites; he had not subjected them to the yoke of bondage.
35077	1333	27	Yea, he was exceedingly wroth, and he did curse God, and also Moroni, swearing with an oath that he would drink his blood; and this because Moroni had kept the commandments of God in preparing for the safety of his people.
35078	1333	28	And it came to pass, that on the other hand, the people of Nephi did thank the Lord their God, because of his matchless power in delivering them from the hands of their enemies.
35079	1333	29	And thus ended the nineteenth year of the reign of the judges over the people of Nephi.
35080	1333	30	Yea, and there was continual peace among them, and exceedingly great prosperity in the church because of their heed and diligence which they gave unto the word of God, which was declared unto them by Helaman, and Shiblon, and Corianton, and Ammon and his brethren, yea, and by all those who had been ordained by the holy order of God, being baptized unto repentance, and sent forth to preach among the people.
35081	1334	1	And now it came to pass that Moroni did not stop making preparations for war, or to defend his people against the Lamanites; for he caused that his armies should commence in the commencement of the twentieth year of the reign of the judges, that they should commence in digging up heaps of earth round about all the cities, throughout all the land which was possessed by the Nephites.
35082	1334	2	And upon the top of these ridges of earth he caused that there should be timbers, yea, works of timbers built up to the height of a man, round about the cities.
35083	1334	3	And he caused that upon those works of timbers there should be a frame of pickets built upon the timbers round about; and they were strong and high.
35084	1334	4	And he caused towers to be erected that overlooked those works of pickets, and he caused places of security to be built upon those towers, that the stones and the arrows of the Lamanites could not hurt them.
35085	1334	5	And they were prepared that they could cast stones from the top thereof, according to their pleasure and their strength, and slay him who should attempt to approach near the walls of the city.
35086	1334	6	Thus Moroni did prepare strongholds against the coming of their enemies, round about every city in all the land.
35087	1334	7	And it came to pass that Moroni caused that his armies should go forth into the east wilderness; yea, and they went forth and drove all the Lamanites who were in the east wilderness into their own lands, which were south of the land of Zarahemla.
35088	1334	8	And the land of Nephi did run in a straight course from the east sea to the west.
35089	1334	9	And it came to pass that when Moroni had driven all the Lamanites out of the east wilderness, which was north of the lands of their own possessions, he caused that the inhabitants who were in the land of Zarahemla and in the land round about should go forth into the east wilderness, even to the borders by the seashore, and possess the land.
35090	1334	10	And he also placed armies on the south, in the borders of their possessions, and caused them to erect fortifications that they might secure their armies and their people from the hands of their enemies.
35091	1334	11	And thus he cut off all the strongholds of the Lamanites in the east wilderness, yea, and also on the west, fortifying the line between the Nephites and the Lamanites, between the land of Zarahemla and the land of Nephi, from the west sea, running by the head of the river Sidon--the Nephites possessing all the land northward, yea, even all the land which was northward of the land Bountiful, according to their pleasure.
35092	1334	12	Thus Moroni, with his armies, which did increase daily because of the assurance of protection which his works did bring forth unto them, did seek to cut off the strength and the power of the Lamanites from off the lands of their possessions, that they should have no power upon the lands of their possession.
35093	1334	13	And it came to pass that the Nephites began the foundation of a city, and they called the name of the city Moroni; and it was by the east sea; and it was on the south by the line of the possessions of the Lamanites.
35094	1334	14	And they also began a foundation for a city between the city of Moroni and the city of Aaron, joining the borders of Aaron and Moroni; and they called the name of the city, or the land, Nephihah.
35095	1334	15	And they also began in that same year to build many cities on the north, one in a particular manner which they called Lehi, which was in the north by the borders of the seashore.
35096	1334	16	And thus ended the twentieth year.
35097	1334	17	And in these prosperous circumstances were the people of Nephi in the commencement of the twenty and first year of the reign of the judges over the people of Nephi.
35098	1334	18	And they did prosper exceedingly, and they became exceedingly rich; yea, and they did multiply and wax strong in the land.
35099	1334	19	And thus we see how merciful and just are all the dealings of the Lord, to the fulfilling of all his words unto the children of men; yea, we can behold that his words are verified, even at this time, which he spake unto Lehi, saying:
35100	1334	20	Blessed art thou and thy children; and they shall be blessed, inasmuch as they shall keep my commandments they shall prosper in the land. But remember, inasmuch as they will not keep my commandments they shall be cut off from the presence of the Lord.
35101	1334	21	And we see that these promises have been verified to the people of Nephi; for it has been their quarrelings and their contentions, yea, their murderings, and their plunderings, their idolatry, their whoredoms, and their abominations, which were among themselves, which brought upon them their wars and their destructions.
35102	1334	22	And those who were faithful in keeping the commandments of the Lord were delivered at all times, whilst thousands of their wicked brethren have been consigned to bondage, or to perish by the sword, or to dwindle in unbelief, and mingle with the Lamanites.
35103	1334	23	But behold there never was a happier time among the people of Nephi, since the days of Nephi, than in the days of Moroni, yea, even at this time, in the twenty and first year of the reign of the judges.
35104	1334	24	And it came to pass that the twenty and second year of the reign of the judges also ended in peace; yea, and also the twenty and third year.
35105	1334	25	And it came to pass that in the commencement of the twenty and fourth year of the reign of the judges, there would also have been peace among the people of Nephi had it not been for a contention which took place among them concerning the land of Lehi, and the land of Morianton, which joined upon the borders of Lehi; both of which were on the borders by the seashore.
35106	1334	26	For behold, the people who possessed the land of Morianton did claim a part of the land of Lehi; therefore there began to be a warm contention between them, insomuch that the people of Morianton took up arms against their brethren, and they were determined by the sword to slay them.
35107	1334	27	But behold, the people who possessed the land of Lehi fled to the camp of Moroni, and appealed unto him for assistance; for behold they were not in the wrong.
35108	1334	28	And it came to pass that when the people of Morianton, who were led by a man whose name was Morianton, found that the people of Lehi had fled to the camp of Moroni, they were exceedingly fearful lest the army of Moroni should come upon them and destroy them.
35109	1334	29	Therefore, Morianton put it into their hearts that they should flee to the land which was northward, which was covered with large bodies of water, and take possession of the land which was northward.
35110	1334	30	And behold, they would have carried this plan into effect, (which would have been a cause to have been lamented) but behold, Morianton being a man of much passion, therefore he was angry with one of his maid servants, and he fell upon her and beat her much.
35111	1334	31	And it came to pass that she fled, and came over to the camp of Moroni, and told Moroni all things concerning the matter, and also concerning their intentions to flee into the land northward.
35112	1334	32	Now behold, the people who were in the land Bountiful, or rather Moroni, feared that they would hearken to the words of Morianton and unite with his people, and thus he would obtain possession of those parts of the land, which would lay a foundation for serious consequences among the people of Nephi, yea, which consequences would lead to the overthrow of their liberty.
35113	1334	33	Therefore Moroni sent an army, with their camp, to head the people of Morianton, to stop their flight into the land northward.
35114	1334	34	And it came to pass that they did not head them until they had come to the borders of the land Desolation; and there they did head them, by the narrow pass which led by the sea into the land northward, yea, by the sea, on the west and on the east.
35115	1334	35	And it came to pass that the army which was sent by Moroni, which was led by a man whose name was Teancum, did meet the people of Morianton; and so stubborn were the people of Morianton, (being inspired by his wickedness and his flattering words) that a battle commenced between them, in the which Teancum did slay Morianton and defeat his army, and took them prisoners, and returned to the camp of Moroni. And thus ended the twenty and fourth year of the reign of the judges over the people of Nephi.
35116	1334	36	And thus were the people of Morianton brought back. And upon their covenanting to keep the peace they were restored to the land of Morianton, and a union took place between them and the people of Lehi; and they were also restored to their lands.
35117	1334	37	And it came to pass that in the same year that the people of Nephi had peace restored unto them, that Nephihah, the second chief judge, died, having filled the judgment-seat with perfect uprightness before God.
35118	1334	38	Nevertheless, he had refused Alma to take possession of those records and those things which were esteemed by Alma and his fathers to be most sacred; therefore Alma had conferred them upon his son, Helaman.
35119	1334	39	Behold, it came to pass that the son of Nephihah was appointed to fill the judgment-seat, in the stead of his father; yea, he was appointed chief judge and governor over the people, with an oath and sacred ordinance to judge righteously, and to keep the peace and the freedom of the people, and to grant unto them their sacred privileges to worship the Lord their God, yea, to support and maintain the cause of God all his days, and to bring the wicked to justice according to their crime.
35120	1334	40	Now behold, his name was Pahoran. And Pahoran did fill the seat of his father, and did commence his reign in the end of the twenty and fourth year, over the people of Nephi.
35121	1335	1	And now it came to pass in the commencement of the twenty and fifth year of the reign of the judges over the people of Nephi, they having established peace between the people of Lehi and the people of Morianton concerning their lands, and having commenced the twenty and fifth year in peace;
35122	1335	2	Nevertheless, they did not long maintain an entire peace in the land, for there began to be a contention among the people concerning the chief judge Pahoran; for behold, there were a part of the people who desired that a few particular points of the law should be altered.
35123	1335	3	But behold, Pahoran would not alter nor suffer the law to be altered; therefore, he did not hearken to those who had sent in their voices with their petitions concerning the altering of the law.
35124	1335	4	Therefore, those who were desirous that the law should be altered were angry with him, and desired that he should no longer be chief judge over the land; therefore there arose a warm dispute concerning the matter, but not unto bloodshed.
35125	1335	5	And it came to pass that those who were desirous that Pahoran should be dethroned from the judgment-seat were called king-men, for they were desirous that the law should be altered in a manner to overthrow the free government and to establish a king over the land.
35126	1335	6	And those who were desirous that Pahoran should remain chief judge over the land took upon them the name of freemen; and thus was the division among them, for the freemen had sworn or covenanted to maintain their rights and the privileges of their religion by a free government.
35127	1335	7	And it came to pass that this matter of their contention was settled by the voice of the people. And it came to pass that the voice of the people came in favor of the freemen, and Pahoran retained the judgment-seat, which caused much rejoicing among the brethren of Pahoran and also many of the people of liberty, who also put the king-men to silence, that they durst not oppose but were obliged to maintain the cause of freedom.
35128	1335	8	Now those who were in favor of kings were those of high birth, and they sought to be kings; and they were supported by those who sought power and authority over the people.
35129	1335	9	But behold, this was a critical time for such contentions to be among the people of Nephi; for behold, Amalickiah had again stirred up the hearts of the people of the Lamanites against the people of the Nephites, and he was gathering together soldiers from all parts of his land, and arming them, and preparing for war with all diligence; for he had sworn to drink the blood of Moroni.
35130	1335	10	But behold, we shall see that his promise which he made was rash; nevertheless, he did prepare himself and his armies to come to battle against the Nephites.
35131	1335	11	Now his armies were not so great as they had hitherto been, because of the many thousands who had been slain by the hand of the Nephites; but notwithstanding their great loss, Amalickiah had gathered together a wonderfully great army, insomuch that he feared not to come down to the land of Zarahemla.
35132	1335	12	Yea, even Amalickiah did himself come down, at the head of the Lamanites. And it was in the twenty and fifth year of the reign of the judges; and it was at the same time that they had begun to settle the affairs of their contentions concerning the chief judge, Pahoran.
35133	1335	13	And it came to pass that when the men who were called king-men had heard that the Lamanites were coming down to battle against them, they were glad in their hearts; and they refused to take up arms, for they were so wroth with the chief judge, and also with the people of liberty, that they would not take up arms to defend their country.
35134	1335	14	And it came to pass that when Moroni saw this, and also saw that the Lamanites were coming into the borders of the land, he was exceedingly wroth because of the stubbornness of those people whom he had labored with so much diligence to preserve; yea, he was exceedingly wroth; his soul was filled with anger against them.
35135	1335	15	And it came to pass that he sent a petition, with the voice of the people, unto the governor of the land, desiring that he should read it, and give him (Moroni) power to compel those dissenters to defend their country or to put them to death.
35136	1335	16	For it was his first care to put an end to such contentions and dissensions among the people; for behold, this had been hitherto a cause of all their destruction. And it came to pass that it was granted according to the voice of the people.
35137	1335	17	And it came to pass that Moroni commanded that his army should go against those king-men, to pull down their pride and their nobility and level them with the earth, or they should take up arms and support the cause of liberty.
35138	1335	18	And it came to pass that the armies did march forth against them; and they did pull down their pride and their nobility, insomuch that as they did lift their weapons of war to fight against the men of Moroni they were hewn down and leveled to the earth.
35139	1335	19	And it came to pass that there were four thousand of those dissenters who were hewn down by the sword; and those of their leaders who were not slain in battle were taken and cast into prison, for there was no time for their trials at this period.
35140	1335	20	And the remainder of those dissenters, rather than be smitten down to the earth by the sword, yielded to the standard of liberty, and were compelled to hoist the title of liberty upon their towers, and in their cities, and to take up arms in defence of their country.
35141	1335	21	And thus Moroni put an end to those king-men, that there were not any known by the appellation of king-men; and thus he put an end to the stubbornness and the pride of those people who professed the blood of nobility; but they were brought down to humble themselves like unto their brethren, and to fight valiantly for their freedom from bondage.
35142	1335	22	Behold, it came to pass that while Moroni was thus breaking down the wars and contentions among his own people, and subjecting them to peace and civilization, and making regulations to prepare for war against the Lamanites, behold, the Lamanites had come into the land of Moroni, which was in the borders by the seashore.
35143	1335	23	And it came to pass that the Nephites were not sufficiently strong in the city of Moroni; therefore Amalickiah did drive them, slaying many. And it came to pass that Amalickiah took possession of the city, yea, possession of all their fortifications.
35144	1335	24	And those who fled out of the city of Moroni came to the city of Nephihah; and also the people of the city of Lehi gathered themselves together, and made preparations and were ready to receive the Lamanites to battle.
35145	1335	25	But it came to pass that Amalickiah would not suffer the Lamanites to go against the city of Nephihah to battle, but kept them down by the seashore, leaving men in every city to maintain and defend it.
35146	1335	26	And thus he went on, taking possession of many cities, the city of Nephihah, and the city of Lehi, and the city of Morianton, and the city of Omner, and the city of Gid, and the city of Mulek, all of which were on the east borders by the seashore.
35147	1335	27	And thus had the Lamanites obtained, by the cunning of Amalickiah, so many cities, by their numberless hosts, all of which were strongly fortified after the manner of the fortifications of Moroni; all of which afforded strongholds for the Lamanites.
35148	1335	28	And it came to pass that they marched to the borders of the land Bountiful, driving the Nephites before them and slaying many.
35149	1335	29	But it came to pass that they were met by Teancum, who had slain Morianton and had headed his people in his flight.
35150	1335	30	And it came to pass that he headed Amalickiah also, as he was marching forth with his numerous army that he might take possession of the land Bountiful, and also the land northward.
35151	1335	31	But behold he met with a disappointment by being repulsed by Teancum and his men, for they were great warriors; for every man of Teancum did exceed the Lamanites in their strength and in their skill of war, insomuch that they did gain advantage over the Lamanites.
35152	1335	32	And it came to pass that they did harass them, insomuch that they did slay them even until it was dark. And it came to pass that Teancum and his men did pitch their tents in the borders of the land Bountiful; and Amalickiah did pitch his tents in the borders on the beach by the seashore, and after this manner were they driven.
35153	1335	33	And it came to pass that when the night had come, Teancum and his servant stole forth and went out by night, and went into the camp of Amalickiah; and behold, sleep had overpowered them because of their much fatigue, which was caused by the labors and heat of the day.
35154	1335	34	And it came to pass that Teancum stole privily into the tent of the king, and put a javelin to his heart; and he did cause the death of the king immediately that he did not awake his servants.
35155	1335	35	And he returned again privily to his own camp, and behold, his men were asleep, and he awoke them and told them all the things that he had done.
35156	1335	36	And he caused that his armies should stand in readiness, lest the Lamanites had awakened and should come upon them.
35157	1335	37	And thus endeth the twenty and fifth year of the reign of the judges over the people of Nephi; and thus endeth the days of Amalickiah.
35158	1336	1	And now, it came to pass in the twenty and sixth year of the reign of the judges over the people of Nephi, behold, when the Lamanites awoke on the first morning of the first month, behold, they found Amalickiah was dead in his own tent; and they also saw that Teancum was ready to give them battle on that day.
35159	1336	2	And now, when the Lamanites saw this they were affrighted; and they abandoned their design in marching into the land northward, and retreated with all their army into the city of Mulek, and sought protection in their fortifications.
35160	1336	3	And it came to pass that the brother of Amalickiah was appointed king over the people; and his name was Ammoron; thus king Ammoron, the brother of king Amalickiah, was appointed to reign in his stead.
35161	1336	4	And it came to pass that he did command that his people should maintain those cities, which they had taken by the shedding of blood; for they had not taken any cities save they had lost much blood.
35162	1336	5	And now, Teancum saw that the Lamanites were determined to maintain those cities which they had taken, and those parts of the land which they had obtained possession of; and also seeing the enormity of their number, Teancum thought it was not expedient that he should attempt to attack them in their forts.
35163	1336	6	But he kept his men round about, as if making preparations for war; yea, and truly he was preparing to defend himself against them, by casting up walls round about and preparing places of resort.
35164	1336	7	And it came to pass that he kept thus preparing for war until Moroni had sent a large number of men to strengthen his army.
35165	1336	8	And Moroni also sent orders unto him that he should retain all the prisoners who fell into his hands; for as the Lamanites had taken many prisoners, that he should retain all the prisoners of the Lamanites as a ransom for those whom the Lamanites had taken.
35166	1336	9	And he also sent orders unto him that he should fortify the land Bountiful, and secure the narrow pass which led into the land northward, lest the Lamanites should obtain that point and should have power to harass them on every side.
35167	1336	10	And Moroni also sent unto him, desiring him that he would be faithful in maintaining that quarter of the land, and that he would seek every opportunity to scourge the Lamanites in that quarter, as much as was in his power, that perhaps he might take again by stratagem or some other way those cities which had been taken out of their hands; and that he also would fortify and strengthen the cities round about, which had not fallen into the hands of the Lamanites.
35168	1336	11	And he also said unto him, I would come unto you, but behold, the Lamanites are upon us in the borders of the land by the west sea; and behold, I go against them, therefore I cannot come unto you.
35169	1336	12	Now, the king (Ammoron) had departed out of the land of Zarahemla, and had made known unto the queen concerning the death of his brother, and had gathered together a large number of men, and had marched forth against the Nephites on the borders by the west sea.
35170	1336	13	And thus he was endeavoring to harass the Nephites, and to draw away a part of their forces to that part of the land, while he had commanded those whom he had left to possess the cities which he had taken, that they should also harass the Nephites on the borders by the east sea, and should take possession of their lands as much as it was in their power, according to the power of their armies.
35171	1336	14	And thus were the Nephites in those dangerous circumstances in the ending of the twenty and sixth year of the reign of the judges over the people of Nephi.
35172	1336	15	But behold, it came to pass in the twenty and seventh year of the reign of the judges, that Teancum, by the command of Moroni--who had established armies to protect the south and the west borders of the land, and had begun his march towards the land Bountiful, that he might assist Teancum with his men in retaking the cities which they had lost--
35173	1336	16	And it came to pass that Teancum had received orders to make an attack upon the city of Mulek, and retake it if it were possible.
35174	1336	17	And it came to pass that Teancum made preparations to make an attack upon the city of Mulek, and march forth with his army against the Lamanites; but he saw that it was impossible that he could overpower them while they were in their fortifications; therefore he abandoned his designs and returned again to the city Bountiful, to wait for the coming of Moroni, that he might receive strength to his army.
35175	1336	18	And it came to pass that Moroni did arrive with his army at the land of Bountiful, in the latter end of the twenty and seventh year of the reign of the judges over the people of Nephi.
35176	1336	19	And in the commencement of the twenty and eighth year, Moroni and Teancum and many of the chief captains held a council of war--what they should do to cause the Lamanites to come out against them to battle; or that they might by some means flatter them out of their strongholds, that they might gain advantage over them and take again the city of Mulek.
35177	1336	20	And it came to pass they sent embassies to the army of the Lamanites, which protected the city of Mulek, to their leader, whose name was Jacob, desiring him that he would come out with his armies to meet them upon the plains between the two cities. But behold, Jacob, who was a Zoramite, would not come out with his army to meet them upon the plains.
35178	1336	21	And it came to pass that Moroni, having no hopes of meeting them upon fair grounds, therefore, he resolved upon a plan that he might decoy the Lamanites out of their strongholds.
35179	1336	22	Therefore he caused that Teancum should take a small number of men and march down near the seashore; and Moroni and his army, by night, marched in the wilderness, on the west of the city Mulek; and thus, on the morrow, when the guards of the Lamanites had discovered Teancum, they ran and told it unto Jacob, their leader.
35180	1336	23	And it came to pass that the armies of the Lamanites did march forth against Teancum, supposing by their numbers to overpower Teancum because of the smallness of his numbers. And as Teancum saw the armies of the Lamanites coming out against him he began to retreat down by the seashore, northward.
35181	1336	24	And it came to pass that when the Lamanites saw that he began to flee, they took courage and pursued them with vigor. And while Teancum was thus leading away the Lamanites who were pursuing them in vain, behold, Moroni commanded that a part of his army who were with him should march forth into the city, and take possession of it.
35182	1336	25	And thus they did, and slew all those who had been left to protect the city, yea, all those who would not yield up their weapons of war.
35183	1336	26	And thus Moroni had obtained possession of the city Mulek with a part of his army, while he marched with the remainder to meet the Lamanites when they should return from the pursuit of Teancum.
35184	1336	27	And it came to pass that the Lamanites did pursue Teancum until they came near the city Bountiful, and then they were met by Lehi and a small army, which had been left to protect the city Bountiful.
35185	1336	28	And now behold, when the chief captains of the Lamanites had beheld Lehi with his army coming against them, they fled in much confusion, lest perhaps they should not obtain the city Mulek before Lehi should overtake them; for they were wearied because of their march, and the men of Lehi were fresh.
35186	1336	29	Now the Lamanites did not know that Moroni had been in their rear with his army; and all they feared was Lehi and his men.
35187	1336	30	Now Lehi was not desirous to overtake them till they should meet Moroni and his army.
35188	1336	31	And it came to pass that before the Lamanites had retreated far they were surrounded by the Nephites, by the men of Moroni on one hand, and the men of Lehi on the other, all of whom were fresh and full of strength; but the Lamanites were wearied because of their long march.
35189	1336	32	And Moroni commanded his men that they should fall upon them until they had given up their weapons of war.
35190	1336	33	And it came to pass that Jacob, being their leader, being also a Zoramite, and having an unconquerable spirit, he led the Lamanites forth to battle with exceeding fury against Moroni.
35191	1336	34	Moroni being in their course of march, therefore Jacob was determined to slay them and cut his way through to the city of Mulek. But behold, Moroni and his men were more powerful; therefore they did not give way before the Lamanites.
35192	1336	35	And it came to pass that they fought on both hands with exceeding fury; and there were many slain on both sides; yea, and Moroni was wounded and Jacob was killed.
35193	1336	36	And Lehi pressed upon their rear with such fury with his strong men, that the Lamanites in the rear delivered up their weapons of war; and the remainder of them, being much confused, knew not whither to go or to strike.
35194	1336	37	Now Moroni seeing their confusion, he said unto them: If ye will bring forth your weapons of war and deliver them up, behold we will forbear shedding your blood.
35195	1336	38	And it came to pass that when the Lamanites had heard these words, their chief captains, all those who were not slain, came forth and threw down their weapons of war at the feet of Moroni, and also commanded their men that they should do the same.
35196	1336	39	But behold, there were many that would not; and those who would not deliver up their swords were taken and bound, and their weapons of war were taken from them, and they were compelled to march with their brethren forth into the land Bountiful.
35197	1336	40	And now the number of prisoners who were taken exceeded more than the number of those who had been slain, yea, more than those who had been slain on both sides.
35198	1337	1	And it came to pass that they did set guards over the prisoners of the Lamanites, and did compel them to go forth and bury their dead, yea, and also the dead of the Nephites who were slain; and Moroni placed men over them to guard them while they should perform their labors.
35199	1337	2	And Moroni went to the city of Mulek with Lehi, and took command of the city and gave it unto Lehi. Now behold, this Lehi was a man who had been with Moroni in the more part of all his battles; and he was a man like unto Moroni, and they rejoiced in each other's safety; yea, they were beloved by each other, and also beloved by all the people of Nephi.
35200	1337	3	And it came to pass that after the Lamanites had finished burying their dead and also the dead of the Nephites, they were marched back into the land Bountiful; and Teancum, by the orders of Moroni, caused that they should commence laboring in digging a ditch round about the land, or the city, Bountiful.
35201	1337	4	And he caused that they should build a breastwork of timbers upon the inner bank of the ditch; and they cast up dirt out of the ditch against the breastwork of timbers; and thus they did cause the Lamanites to labor until they had encircled the city of Bountiful round about with a strong wall of timbers and earth, to an exceeding height.
35202	1337	5	And this city became an exceeding stronghold ever after; and in this city they did guard the prisoners of the Lamanites; yea, even within a wall which they had caused them to build with their own hands. Now Moroni was compelled to cause the Lamanites to labor, because it was easy to guard them while at their labor; and he desired all his forces when he should make an attack upon the Lamanites.
35203	1337	6	And it came to pass that Moroni had thus gained a victory over one of the greatest of the armies of the Lamanites, and had obtained possession of the city of Mulek, which was one of the strongest holds of the Lamanites in the land of Nephi; and thus he had also built a stronghold to retain his prisoners.
35204	1337	7	And it came to pass that he did no more attempt a battle with the Lamanites in that year, but he did employ his men in preparing for war, yea, and in making fortifications to guard against the Lamanites, yea, and also delivering their women and their children from famine and affliction, and providing food for their armies.
35205	1337	8	And now it came to pass that the armies of the Lamanites, on the west sea, south, while in the absence of Moroni on account of some intrigue amongst the Nephites, which caused dissensions amongst them, had gained some ground over the Nephites, yea, insomuch that they had obtained possession of a number of their cities in that part of the land.
35206	1337	9	And thus because of iniquity amongst themselves, yea, because of dissensions and intrigue among themselves they were placed in the most dangerous circumstances.
35207	1337	10	And now behold, I have somewhat to say concerning the people of Ammon, who, in the beginning, were Lamanites; but by Ammon and his brethren, or rather by the power and word of God, they had been converted unto the Lord; and they had been brought down into the land of Zarahemla, and had ever since been protected by the Nephites.
35208	1337	11	And because of their oath they had been kept from taking up arms against their brethren; for they had taken an oath that they never would shed blood more; and according to their oath they would have perished; yea, they would have suffered themselves to have fallen into the hands of their brethren, had it not been for the pity and the exceeding love which Ammon and his brethren had had for them.
35209	1337	12	And for this cause they were brought down into the land of Zarahemla; and they ever had been protected by the Nephites.
35210	1337	13	But it came to pass that when they saw the danger, and the many afflictions and tribulations which the Nephites bore for them, they were moved with compassion and were desirous to take up arms in the defence of their country.
35211	1337	14	But behold, as they were about to take their weapons of war, they were overpowered by the persuasions of Helaman and his brethren, for they were about to break the oath which they had made.
35212	1337	15	And Helaman feared lest by so doing they should lose their souls; therefore all those who had entered into this covenant were compelled to behold their brethren wade through their afflictions, in their dangerous circumstances at this time.
35213	1337	16	But behold, it came to pass they had many sons, who had not entered into a covenant that they would not take their weapons of war to defend themselves against their enemies; therefore they did assemble themselves together at this time, as many as were able to take up arms, and they called themselves Nephites.
35214	1337	17	And they entered into a covenant to fight for the liberty of the Nephites, yea, to protect the land unto the laying down of their lives; yea, even they covenanted that they never would give up their liberty, but they would fight in all cases to protect the Nephites and themselves from bondage.
35215	1337	18	Now behold, there were two thousand of those young men, who entered into this covenant and took their weapons of war to defend their country.
35216	1337	19	And now behold, as they never had hitherto been a disadvantage to the Nephites, they became now at this period of time also a great support; for they took their weapons of war, and they would that Helaman should be their leader.
35217	1337	20	And they were all young men, and they were exceedingly valiant for courage, and also for strength and activity; but behold, this was not all--they were men who were true at all times in whatsoever thing they were entrusted.
35218	1337	21	Yea, they were men of truth and soberness, for they had been taught to keep the commandments of God and to walk uprightly before him.
35219	1337	22	And now it came to pass that Helaman did march at the head of his two thousand stripling soldiers, to the support of the people in the borders of the land on the south by the west sea.
35220	1337	23	And thus ended the twenty and eighth year of the reign of the judges over the people of Nephi.
35221	1338	1	And now it came to pass in the commencement of the twenty and ninth year of the judges, that Ammoron sent unto Moroni desiring that he would exchange prisoners.
35222	1338	2	And it came to pass that Moroni felt to rejoice exceedingly at this request, for he desired the provisions which were imparted for the support of the Lamanite prisoners for the support of his own people; and he also desired his own people for the strengthening of his army.
35223	1338	3	Now the Lamanites had taken many women and children, and there was not a woman nor a child among all the prisoners of Moroni, or the prisoners whom Moroni had taken; therefore Moroni resolved upon a stratagem to obtain as many prisoners of the Nephites from the Lamanites as it were possible.
35224	1338	4	Therefore he wrote an epistle, and sent it by the servant of Ammoron, the same who had brought an epistle to Moroni. Now these are the words which he wrote unto Ammoron, saying:
35225	1338	5	Behold, Ammoron, I have written unto you somewhat concerning this war which ye have waged against my people, or rather which thy brother hath waged against them, and which ye are still determined to carry on after his death.
35226	1338	6	Behold, I would tell you somewhat concerning the justice of God, and the sword of his almighty wrath, which doth hang over you except ye repent and withdraw your armies into your own lands, or the land of your possessions, which is the land of Nephi.
35227	1338	7	Yea, I would tell you these things if ye were capable of hearkening unto them; yea, I would tell you concerning that awful hell that awaits to receive such murderers as thou and thy brother have been, except ye repent and withdraw your murderous purposes, and return with your armies to your own lands.
35228	1338	8	But as ye have once rejected these things, and have fought against the people of the Lord, even so I may expect you will do it again.
35229	1338	9	And now behold, we are prepared to receive you; yea, and except you withdraw your purposes, behold, ye will pull down the wrath of that God whom you have rejected upon you, even to your utter destruction.
35230	1338	10	But, as the Lord liveth, our armies shall come upon you except ye withdraw, and ye shall soon be visited with death, for we will retain our cities and our lands; yea, and we will maintain our religion and the cause of our God.
35231	1338	11	But behold, it supposeth me that I talk to you concerning these things in vain; or it supposeth me that thou art a child of hell; therefore I will close my epistle by telling you that I will not exchange prisoners, save it be on conditions that ye will deliver up a man and his wife and his children, for one prisoner; if this be the case that ye will do it, I will exchange.
35232	1338	12	And behold, if ye do not this, I will come against you with my armies; yea, even I will arm my women and my children, and I will come against you, and I will follow you even into your own land, which is the land of our first inheritance; yea, and it shall be blood for blood, yea, life for life; and I will give you battle even until you are destroyed from off the face of the earth.
35233	1338	13	Behold, I am in my anger, and also my people; ye have sought to murder us, and we have only sought to defend ourselves. But behold, if ye seek to destroy us more we will seek to destroy you; yea, and we will seek our land, the land of our first inheritance.
35234	1338	14	Now I close my epistle. I am Moroni; I am a leader of the people of the Nephites.
35235	1338	15	Now it came to pass that Ammoron, when he had received this epistle, was angry; and he wrote another epistle unto Moroni, and these are the words which he wrote, saying:
35236	1338	16	I am Ammoron, the king of the Lamanites; I am the brother of Amalickiah whom ye have murdered. Behold, I will avenge his blood upon you, yea, and I will come upon you with my armies for I fear not your threatenings.
35237	1338	17	For behold, your fathers did wrong their brethren, insomuch that they did rob them of their right to the government when it rightly belonged unto them.
35238	1338	18	And now behold, if ye will lay down your arms, and subject yourselves to be governed by those to whom the government doth rightly belong, then will I cause that my people shall lay down their weapons and shall be at war no more.
35239	1338	19	Behold, ye have breathed out many threatenings against me and my people; but behold, we fear not your threatenings.
35240	1338	20	Nevertheless, I will grant to exchange prisoners according to your request, gladly, that I may preserve my food for my men of war; and we will wage a war which shall be eternal, either to the subjecting the Nephites to our authority or to their eternal extinction.
35241	1338	21	And as concerning that God whom ye say we have rejected, behold, we know not such a being; neither do ye; but if it so be that there is such a being, we know not but that he hath made us as well as you.
35242	1338	22	And if it so be that there is a devil and a hell, behold will he not send you there to dwell with my brother whom ye have murdered, whom ye have hinted that he hath gone to such a place? But behold these things matter not.
35243	1338	23	I am Ammoron, and a descendant of Zoram, whom your fathers pressed and brought out of Jerusalem.
35244	1338	24	And behold now, I am a bold Lamanite; behold, this war hath been waged to avenge their wrongs, and to maintain and to obtain their rights to the government; and I close my epistle to Moroni.
35245	1339	1	Now it came to pass that when Moroni had received this epistle he was more angry, because he knew that Ammoron had a perfect knowledge of his fraud; yea, he knew that Ammoron knew that it was not a just cause that had caused him to wage a war against the people of Nephi.
35246	1339	2	And he said: Behold, I will not exchange prisoners with Ammoron save he will withdraw his purpose, as I have stated in my epistle; for I will not grant unto him that he shall have any more power than what he hath got.
35247	1339	3	Behold, I know the place where the Lamanites do guard my people whom they have taken prisoners; and as Ammoron would not grant unto me mine epistle, behold, I will give unto him according to my words; yea, I will seek death among them until they shall sue for peace.
35248	1339	4	And now it came to pass that when Moroni had said these words, he caused that a search should be made among his men, that perhaps he might find a man who was a descendant of Laman among them.
35249	1339	5	And it came to pass that they found one, whose name was Laman; and he was one of the servants of the king who was murdered by Amalickiah.
35250	1339	6	Now Moroni caused that Laman and a small number of his men should go forth unto the guards who were over the Nephites.
35251	1339	7	Now the Nephites were guarded in the city of Gid; therefore Moroni appointed Laman and caused that a small number of men should go with him.
35252	1339	8	And when it was evening Laman went to the guards who were over the Nephites, and behold, they saw him coming and they hailed him; but he saith unto them: Fear not; behold, I am a Lamanite. Behold, we have escaped from the Nephites, and they sleep; and behold we have taken of their wine and brought with us.
35253	1339	9	Now when the Lamanites heard these words they received him with joy; and they said unto him: Give us of your wine, that we may drink; we are glad that ye have thus taken wine with you for we are weary.
35254	1339	10	But Laman said unto them: Let us keep of our wine till we go against the Nephites to battle. But this saying only made them more desirous to drink of the wine;
35255	1339	11	For, said they: We are weary, therefore let us take of the wine, and by and by we shall receive wine for our rations, which will strengthen us to go against the Nephites.
35256	1339	12	And Laman said unto them: You may do according to your desires.
35257	1339	13	And it came to pass that they did take of the wine freely; and it was pleasant to their taste, therefore they took of it more freely; and it was strong, having been prepared in its strength.
35258	1339	14	And it came to pass they did drink and were merry, and by and by they were all drunken.
35259	1339	15	And now when Laman and his men saw that they were all drunken, and were in a deep sleep, they returned to Moroni and told him all the things that had happened.
35260	1339	16	And now this was according to the design of Moroni. And Moroni had prepared his men with weapons of war; and he went to the city Gid, while the Lamanites were in a deep sleep and drunken, and cast in weapons of war unto the prisoners, insomuch that they were all armed;
35261	1339	17	Yea, even to their women, and all those of their children, as many as were able to use a weapon of war, when Moroni had armed all those prisoners; and all those things were done in a profound silence.
35262	1339	18	But had they awakened the Lamanites, behold they were drunken and the Nephites could have slain them.
35263	1339	19	But behold, this was not the desire of Moroni; he did not delight in murder or bloodshed, but he delighted in the saving of his people from destruction; and for this cause he might not bring upon him injustice, he would not fall upon the Lamanites and destroy them in their drunkenness.
35264	1339	20	But he had obtained his desires; for he had armed those prisoners of the Nephites who were within the wall of the city, and had given them power to gain possession of those parts which were within the walls.
35265	1339	21	And then he caused the men who were with him to withdraw a pace from them, and surround the armies of the Lamanites.
35266	1339	22	Now behold this was done in the night-time, so that when the Lamanites awoke in the morning they beheld that they were surrounded by the Nephites without, and that their prisoners were armed within.
35267	1339	23	And thus they saw that the Nephites had power over them; and in these circumstances they found that it was not expedient that they should fight with the Nephites; therefore their chief captains demanded their weapons of war, and they brought them forth and cast them at the feet of the Nephites, pleading for mercy.
35268	1339	24	Now behold, this was the desire of Moroni. He took them prisoners of war, and took possession of the city, and caused that all the prisoners should be liberated, who were Nephites; and they did join the army of Moroni, and were a great strength to his army.
35269	1339	25	And it came to pass that he did cause the Lamanites, whom he had taken prisoners, that they should commence a labor in strengthening the fortifications round about the city Gid.
35270	1339	26	And it came to pass that when he had fortified the city Gid, according to his desires, he caused that his prisoners should be taken to the city Bountiful; and he also guarded that city with an exceedingly strong force.
35271	1339	27	And it came to pass that they did, notwithstanding all the intrigues of the Lamanites, keep and protect all the prisoners whom they had taken, and also maintain all the ground and the advantage which they had retaken.
35272	1339	28	And it came to pass that the Nephites began again to be victorious, and to reclaim their rights and their privileges.
35273	1339	29	Many times did the Lamanites attempt to encircle them about by night, but in these attempts they did lose many prisoners.
35274	1339	30	And many times did they attempt to administer of their wine to the Nephites, that they might destroy them with poison or with drunkenness.
35275	1339	31	But behold, the Nephites were not slow to remember the Lord their God in this their time of affliction. They could not be taken in their snares; yea, they would not partake of their wine, save they had first given to some of the Lamanite prisoners.
35276	1339	32	And they were thus cautious that no poison should be administered among them; for if their wine would poison a Lamanite it would also poison a Nephite; and thus they did try all their liquors.
35277	1339	33	And now it came to pass that it was expedient for Moroni to make preparations to attack the city Morianton; for behold, the Lamanites had, by their labors, fortified the city Morianton until it had become an exceeding stronghold.
35278	1339	34	And they were continually bringing new forces into that city, and also new supplies of provisions.
35279	1339	35	And thus ended the twenty and ninth year of the reign of the judges over the people of Nephi.
35280	1340	1	And now it came to pass in the commencement of the thirtieth year of the reign of the judges, on the second day in the first month, Moroni received an epistle from Helaman, stating the affairs of the people in that quarter of the land.
35281	1340	2	And these are the words which he wrote, saying: My dearly beloved brother, Moroni, as well in the Lord as in the tribulations of our warfare; behold, my beloved brother, I have somewhat to tell you concerning our warfare in this part of the land.
35282	1340	3	Behold, two thousand of the sons of those men whom Ammon brought down out of the land of Nephi--now ye have known that these were descendants of Laman, who was the eldest son of our father Lehi;
35283	1340	4	Now I need not rehearse unto you concerning their traditions or their unbelief, for thou knowest concerning all these things--
35284	1340	5	Therefore it sufficeth me that I tell you that two thousand of these young men have taken their weapons of war, and would that I should be their leader; and we have come forth to defend our country.
35285	1340	6	And now ye also know concerning the covenant which their fathers made, that they would not take up their weapons of war against their brethren to shed blood.
35286	1340	7	But in the twenty and sixth year, when they saw our afflictions and our tribulations for them, they were about to break the covenant which they had made and take up their weapons of war in our defence.
35287	1340	8	But I would not suffer them that they should break this covenant which they had made, supposing that God would strengthen us, insomuch that we should not suffer more because of the fulfilling the oath which they had taken.
35288	1340	9	But behold, here is one thing in which we may have great joy. For behold, in the twenty and sixth year, I, Helaman, did march at the head of these two thousand young men to the city of Judea, to assist Antipus, whom ye had appointed a leader over the people of that part of the land.
35289	1340	10	And I did join my two thousand sons, (for they are worthy to be called sons) to the army of Antipus, in which strength Antipus did rejoice exceedingly; for behold, his army had been reduced by the Lamanites because their forces had slain a vast number of our men, for which cause we have to mourn.
35290	1340	11	Nevertheless, we may console ourselves in this point, that they have died in the cause of their country and of their God, yea, and they are happy.
35291	1340	12	And the Lamanites had also retained many prisoners, all of whom are chief captains, for none other have they spared alive. And we suppose that they are now at this time in the land of Nephi; it is so if they are not slain.
35292	1340	13	And now these are the cities of which the Lamanites have obtained possession by the shedding of the blood of so many of our valiant men;
35293	1340	14	The land of Manti, or the city of Manti, and the city of Zeezrom, and the city of Cumeni, and the city of Antiparah.
35294	1340	15	And these are the cities which they possessed when I arrived at the city of Judea; and I found Antipus and his men toiling with their might to fortify the city.
35295	1340	16	Yea, and they were depressed in body as well as in spirit, for they had fought valiantly by day and toiled by night to maintain their cities; and thus they had suffered great afflictions of every kind.
35296	1340	17	And now they were determined to conquer in this place or die; therefore you may well suppose that this little force which I brought with me, yea, those sons of mine, gave them great hopes and much joy.
35297	1340	18	And now it came to pass that when the Lamanites saw that Antipus had received a greater strength to his army, they were compelled by the orders of Ammoron to not come against the city of Judea, or against us, to battle.
35298	1340	19	And thus were we favored of the Lord; for had they come upon us in this our weakness they might have perhaps destroyed our little army; but thus were we preserved.
35299	1340	20	They were commanded by Ammoron to maintain those cities which they had taken. And thus ended the twenty and sixth year. And in the commencement of the twenty and seventh year we had prepared our city and ourselves for defence.
35300	1340	21	Now we were desirous that the Lamanites should come upon us; for we were not desirous to make an attack upon them in their strongholds.
35301	1340	22	And it came to pass that we kept spies out round about, to watch the movements of the Lamanites, that they might not pass us by night nor by day to make an attack upon our other cities which were on the northward.
35302	1340	23	For we knew in those cities they were not sufficiently strong to meet them; therefore we were desirous, if they should pass by us, to fall upon them in their rear, and thus bring them up in the rear at the same time they were met in the front. We supposed that we could overpower them; but behold, we were disappointed in this our desire.
35303	1340	24	They durst not pass by us with their whole army, neither durst they with a part, lest they should not be sufficiently strong and they should fall.
35304	1340	25	Neither durst they march down against the city of Zarahemla; neither durst they cross the head of Sidon, over to the city of Nephihah.
35305	1340	26	And thus, with their forces, they were determined to maintain those cities which they had taken.
35306	1340	27	And now it came to pass in the second month of this year, there was brought unto us many provisions from the fathers of those my two thousand sons.
35307	1340	28	And also there were sent two thousand men unto us from the land of Zarahemla. And thus we were prepared with ten thousand men, and provisions for them, and also for their wives and their children.
35308	1340	29	And the Lamanites, thus seeing our forces increase daily, and provisions arrive for our support, they began to be fearful, and began to sally forth, if it were possible to put an end to our receiving provisions and strength.
35309	1340	30	Now when we saw that the Lamanites began to grow uneasy on this wise, we were desirous to bring a stratagem into effect upon them; therefore Antipus ordered that I should march forth with my little sons to a neighboring city, as if we were carrying provisions to a neighboring city.
35310	1340	31	And we were to march near the city of Antiparah, as if we were going to the city beyond, in the borders by the seashore.
35311	1340	32	And it came to pass that we did march forth, as if with our provisions, to go to that city.
35312	1340	33	And it came to pass that Antipus did march forth with a part of his army, leaving the remainder to maintain the city. But he did not march forth until I had gone forth with my little army, and came near the city Antiparah.
35313	1340	34	And now, in the city Antiparah were stationed the strongest army of the Lamanites; yea, the most numerous.
35314	1340	35	And it came to pass that when they had been informed by their spies, they came forth with their army and marched against us.
35315	1340	36	And it came to pass that we did flee before them, northward. And thus we did lead away the most powerful army of the Lamanites;
35316	1340	37	Yea, even to a considerable distance, insomuch that when they saw the army of Antipus pursuing them, with their might, they did not turn to the right nor to the left, but pursued their march in a straight course after us; and, as we suppose, it was their intent to slay us before Antipus should overtake them, and this that they might not be surrounded by our people.
35317	1340	38	And now Antipus, beholding our danger, did speed the march of his army. But behold, it was night; therefore they did not overtake us, neither did Antipus overtake them; therefore we did camp for the night.
35318	1340	39	And it came to pass that before the dawn of the morning, behold, the Lamanites were pursuing us. Now we were not sufficiently strong to contend with them; yea, I would not suffer that my little sons should fall into their hands; therefore we did continue our march, and we took our march into the wilderness.
35319	1340	40	Now they durst not turn to the right nor to the left lest they should be surrounded; neither would I turn to the right nor to the left lest they should overtake me, and we could not stand against them, but be slain, and they would make their escape; and thus we did flee all that day into the wilderness, even until it was dark.
35320	1340	41	And it came to pass that again, when the light of the morning came we saw the Lamanites upon us, and we did flee before them.
35321	1340	42	But it came to pass that they did not pursue us far before they halted; and it was in the morning of the third day of the seventh month.
35322	1340	43	And now, whether they were overtaken by Antipus we knew not, but I said unto my men: Behold, we know not but they have halted for the purpose that we should come against them, that they might catch us in their snare;
35323	1340	44	Therefore what say ye, my sons, will ye go against them to battle?
35324	1340	45	And now I say unto you, my beloved brother Moroni, that never had I seen so great courage, nay, not amongst all the Nephites.
35325	1340	46	For as I had ever called them my sons (for they were all of them very young) even so they said unto me: Father, behold our God is with us, and he will not suffer that we should fall; then let us go forth; we would not slay our brethren if they would let us alone; therefore let us go, lest they should overpower the army of Antipus.
35326	1340	47	Now they never had fought, yet they did not fear death; and they did think more upon the liberty of their fathers than they did upon their lives; yea, they had been taught by their mothers, that if they did not doubt, God would deliver them.
35327	1340	48	And they rehearsed unto me the words of their mothers, saying: We do not doubt our mothers knew it.
35328	1340	49	And it came to pass that I did return with my two thousand against these Lamanites who had pursued us. And now behold, the armies of Antipus had overtaken them, and a terrible battle had commenced.
35329	1340	50	The army of Antipus being weary, because of their long march in so short a space of time, were about to fall into the hands of the Lamanites; and had I not returned with my two thousand they would have obtained their purpose.
35330	1340	51	For Antipus had fallen by the sword, and many of his leaders, because of their weariness, which was occasioned by the speed of their march--therefore the men of Antipus, being confused because of the fall of their leaders, began to give way before the Lamanites.
35331	1340	52	And it came to pass that the Lamanites took courage, and began to pursue them; and thus were the Lamanites pursuing them with great vigor when Helaman came upon their rear with his two thousand, and began to slay them exceedingly, insomuch that the whole army of the Lamanites halted and turned upon Helaman.
35332	1340	53	Now when the people of Antipus saw that the Lamanites had turned them about, they gathered together their men and came again upon the rear of the Lamanites.
35333	1340	54	And now it came to pass that we, the people of Nephi, the people of Antipus, and I with my two thousand, did surround the Lamanites, and did slay them; yea, insomuch that they were compelled to deliver up their weapons of war and also themselves as prisoners of war.
35334	1340	55	And now it came to pass that when they had surrendered themselves up unto us, behold, I numbered those young men who had fought with me, fearing lest there were many of them slain.
35335	1340	56	But behold, to my great joy, there had not one soul of them fallen to the earth; yea, and they had fought as if with the strength of God; yea, never were men known to have fought with such miraculous strength; and with such mighty power did they fall upon the Lamanites, that they did frighten them; and for this cause did the Lamanites deliver themselves up as prisoners of war.
35336	1340	57	And as we had no place for our prisoners, that we could guard them to keep them from the armies of the Lamanites, therefore we sent them to the land of Zarahemla, and a part of those men who were not slain of Antipus, with them; and the remainder I took and joined them to my stripling Ammonites, and took our march back to the city of Judea.
35337	1341	1	And now it came to pass that I received an epistle from Ammoron, the king, stating that if I would deliver up those prisoners of war whom we had taken that he would deliver up the city of Antiparah unto us.
35338	1341	2	But I sent an epistle unto the king, that we were sure our forces were sufficient to take the city of Antiparah by our force; and by delivering up the prisoners for that city we should suppose ourselves unwise, and that we would only deliver up our prisoners on exchange.
35339	1341	3	And Ammoron refused mine epistle, for he would not exchange prisoners; therefore we began to make preparations to go against the city of Antiparah.
35340	1341	4	But the people of Antiparah did leave the city, and fled to their other cities, which they had possession of, to fortify them; and thus the city of Antiparah fell into our hands.
35341	1341	5	And thus ended the twenty and eighth year of the reign of the judges.
35342	1341	6	And it came to pass that in the commencement of the twenty and ninth year, we received a supply of provisions, and also an addition to our army, from the land of Zarahemla, and from the land round about, to the number of six thousand men, besides sixty of the sons of the Ammonites who had come to join their brethren, my little band of two thousand. And now behold, we were strong, yea, and we had also plenty of provisions brought unto us.
35343	1341	7	And it came to pass that it was our desire to wage a battle with the army which was placed to protect the city Cumeni.
35344	1341	8	And now behold, I will show unto you that we soon accomplished our desire; yea, with our strong force, or with a part of our strong force, we did surround, by night, the city Cumeni, a little before they were to receive a supply of provisions.
35345	1341	9	And it came to pass that we did camp round about the city for many nights; but we did sleep upon our swords, and keep guards, that the Lamanites could not come upon us by night and slay us, which they attempted many times; but as many times as they attempted this their blood was spilt.
35346	1341	10	At length their provisions did arrive, and they were about to enter the city by night. And we, instead of being Lamanites, were Nephites; therefore, we did take them and their provisions.
35347	1341	11	And notwithstanding the Lamanites being cut off from their support after this manner, they were still determined to maintain the city; therefore it became expedient that we should take those provisions and send them to Judea, and our prisoners to the land of Zarahemla.
35348	1341	12	And it came to pass that not many days had passed away before the Lamanites began to lose all hopes of succor; therefore they yielded up the city unto our hands; and thus we had accomplished our designs in obtaining the city Cumeni.
35349	1341	13	But it came to pass that our prisoners were so numerous that, notwithstanding the enormity of our numbers, we were obliged to employ all our force to keep them, or to put them to death.
35350	1341	14	For behold, they would break out in great numbers, and would fight with stones, and with clubs, or whatsoever thing they could get into their hands, insomuch that we did slay upwards of two thousand of them after they had surrendered themselves prisoners of war.
35351	1341	15	Therefore it became expedient for us, that we should put an end to their lives, or guard them, sword in hand, down to the land of Zarahemla; and also our provisions were not any more than sufficient for our own people, notwithstanding that which we had taken from the Lamanites.
35352	1341	16	And now, in those critical circumstances, it became a very serious matter to determine concerning these prisoners of war; nevertheless, we did resolve to send them down to the land of Zarahemla; therefore we selected a part of our men, and gave them charge over our prisoners to go down to the land of Zarahemla.
35353	1341	17	But it came to pass that on the morrow they did return. And now behold, we did not inquire of them concerning the prisoners; for behold, the Lamanites were upon us, and they returned in season to save us from falling into their hands. For behold, Ammoron had sent to their support a new supply of provisions and also a numerous army of men.
35354	1341	18	And it came to pass that those men whom we sent with the prisoners did arrive in season to check them, as they were about to overpower us.
35355	1341	19	But behold, my little band of two thousand and sixty fought most desperately; yea, they were firm before the Lamanites, and did administer death unto all those who opposed them.
35356	1341	20	And as the remainder of our army were about to give way before the Lamanites, behold, those two thousand and sixty were firm and undaunted.
35357	1341	21	Yea, and they did obey and observe to perform every word of command with exactness; yea, and even according to their faith it was done unto them; and I did remember the words which they said unto me that their mothers had taught them.
35358	1341	22	And now behold, it was these my sons, and those men who had been selected to convey the prisoners, to whom we owe this great victory; for it was they who did beat the Lamanites; therefore they were driven back to the city of Manti.
35359	1341	23	And we retained our city Cumeni, and were not all destroyed by the sword; nevertheless, we had suffered great loss.
35360	1341	24	And it came to pass that after the Lamanites had fled, I immediately gave orders that my men who had been wounded should be taken from among the dead, and caused that their wounds should be dressed.
35361	1341	25	And it came to pass that there were two hundred, out of my two thousand and sixty, who had fainted because of the loss of blood; nevertheless, according to the goodness of God, and to our great astonishment, and also the joy of our whole army, there was not one soul of them who did perish; yea, and neither was there one soul among them who had not received many wounds.
35362	1341	26	And now, their preservation was astonishing to our whole army, yea, that they should be spared while there was a thousand of our brethren who were slain. And we do justly ascribe it to the miraculous power of God, because of their exceeding faith in that which they had been taught to believe--that there was a just God, and whosoever did not doubt, that they should be preserved by his marvelous power.
35363	1341	27	Now this was the faith of these of whom I have spoken; they are young, and their minds are firm, and they do put their trust in God continually.
35364	1341	28	And now it came to pass that after we had thus taken care of our wounded men, and had buried our dead and also the dead of the Lamanites, who were many, behold, we did inquire of Gid concerning the prisoners whom they had started to go down to the land of Zarahemla with.
35365	1341	29	Now Gid was the chief captain over the band who was appointed to guard them down to the land.
35366	1341	30	And now, these are the words which Gid said unto me: Behold, we did start to go down to the land of Zarahemla with our prisoners. And it came to pass that we did meet the spies of our armies, who had been sent out to watch the camp of the Lamanites.
35367	1341	31	And they cried unto us, saying--Behold, the armies of the Lamanites are marching towards the city of Cumeni; and behold, they will fall upon them, yea, and will destroy our people.
35368	1341	32	And it came to pass that our prisoners did hear their cries, which caused them to take courage; and they did rise up in rebellion against us.
35369	1341	33	And it came to pass because of their rebellion we did cause that our swords should come upon them. And it came to pass that they did in a body run upon our swords, in the which, the greater number of them were slain; and the remainder of them broke through and fled from us.
35370	1341	34	And behold, when they had fled and we could not overtake them, we took our march with speed towards the city Cumeni; and behold, we did arrive in time that we might assist our brethren in preserving the city.
35371	1341	35	And behold, we are again delivered out of the hands of our enemies. And blessed is the name of our God; for behold, it is he that has delivered us; yea, that has done this great thing for us.
35372	1341	36	Now it came to pass that when I, Helaman, had heard these words of Gid, I was filled with exceeding joy because of the goodness of God in preserving us, that we might not all perish; yea, and I trust that the souls of them who have been slain have entered into the rest of their God.
35373	1342	1	And behold, now it came to pass that our next object was to obtain the city of Manti; but behold, there was no way that we could lead them out of the city by our small bands. For behold, they remembered that which we had hitherto done; therefore we could not decoy them away from their strongholds.
35374	1342	2	And they were so much more numerous than was our army that we durst not go forth and attack them in their strongholds.
35375	1342	3	Yea, and it became expedient that we should employ our men to the maintaining those parts of the land which we had regained of our possessions; therefore it became expedient that we should wait, that we might receive more strength from the land of Zarahemla and also a new supply of provisions.
35376	1342	4	And it came to pass that I thus did send an embassy to the governor of our land, to acquaint him concerning the affairs of our people. And it came to pass that we did wait to receive provisions and strength from the land of Zarahemla.
35377	1342	5	But behold, this did profit us but little; for the Lamanites were also receiving great strength from day to day, and also many provisions; and thus were our circumstances at this period of time.
35378	1342	6	And the Lamanites were sallying forth against us from time to time, resolving by stratagem to destroy us; nevertheless we could not come to battle with them, because of their retreats and their strongholds.
35379	1342	7	And it came to pass that we did wait in these difficult circumstances for the space of many months, even until we were about to perish for the want of food.
35380	1342	8	But it came to pass that we did receive food, which was guarded to us by an army of two thousand men to our assistance; and this is all the assistance which we did receive, to defend ourselves and our country from falling into the hands of our enemies, yea, to contend with an enemy which was innumerable.
35381	1342	9	And now the cause of these our embarrassments, or the cause why they did not send more strength unto us, we knew not; therefore we were grieved and also filled with fear, lest by any means the judgments of God should come upon our land, to our overthrow and utter destruction.
35382	1342	10	Therefore we did pour out our souls in prayer to God, that he would strengthen us and deliver us out of the hands of our enemies, yea, and also give us strength that we might retain our cities, and our lands, and our possessions, for the support of our people.
35383	1342	11	Yea, and it came to pass that the Lord our God did visit us with assurances that he would deliver us; yea, insomuch that he did speak peace to our souls, and did grant unto us great faith, and did cause us that we should hope for our deliverance in him.
35384	1342	12	And we did take courage with our small force which we had received, and were fixed with a determination to conquer our enemies, and to maintain our lands, and our possessions, and our wives, and our children, and the cause of our liberty.
35385	1342	13	And thus we did go forth with all our might against the Lamanites, who were in the city of Manti; and we did pitch our tents by the wilderness side, which was near to the city.
35386	1342	14	And it came to pass that on the morrow, that when the Lamanites saw that we were in the borders by the wilderness which was near the city, that they sent out their spies round about us that they might discover the number and the strength of our army.
35387	1342	15	And it came to pass that when they saw that we were not strong, according to our numbers, and fearing that we should cut them off from their support except they should come out to battle against us and kill us, and also supposing that they could easily destroy us with their numerous hosts, therefore they began to make preparations to come out against us to battle.
35388	1342	16	And when we saw that they were making preparations to come out against us, behold, I caused that Gid, with a small number of men, should secrete himself in the wilderness, and also that Teomner and a small number of men should secrete themselves also in the wilderness.
35389	1342	17	Now Gid and his men were on the right and the others on the left; and when they had thus secreted themselves, behold, I remained, with the remainder of my army, in that same place where we had first pitched our tents against the time that the Lamanites should come out to battle.
35390	1342	18	And it came to pass that the Lamanites did come out with their numerous army against us. And when they had come and were about to fall upon us with the sword, I caused that my men, those who were with me, should retreat into the wilderness.
35391	1342	19	And it came to pass that the Lamanites did follow after us with great speed, for they were exceedingly desirous to overtake us that they might slay us; therefore they did follow us into the wilderness; and we did pass by in the midst of Gid and Teomner, insomuch that they were not discovered by the Lamanites.
35392	1342	20	And it came to pass that when the Lamanites had passed by, or when the army had passed by, Gid and Teomner did rise up from their secret places, and did cut off the spies of the Lamanites that they should not return to the city.
35393	1342	21	And it came to pass that when they had cut them off, they ran to the city and fell upon the guards who were left to guard the city, insomuch that they did destroy them and did take possession of the city.
35394	1342	22	Now this was done because the Lamanites did suffer their whole army, save a few guards only, to be led away into the wilderness.
35395	1342	23	And it came to pass that Gid and Teomner by this means had obtained possession of their strongholds. And it came to pass that we took our course, after having traveled much in the wilderness towards the land of Zarahemla.
35396	1342	24	And when the Lamanites saw that they were marching towards the land of Zarahemla, they were exceedingly afraid, lest there was a plan laid to lead them on to destruction; therefore they began to retreat into the wilderness again, yea, even back by the same way which they had come.
35397	1342	25	And behold, it was night and they did pitch their tents, for the chief captains of the Lamanites had supposed that the Nephites were weary because of their march; and supposing that they had driven their whole army therefore they took no thought concerning the city of Manti.
35398	1342	26	Now it came to pass that when it was night, I caused that my men should not sleep, but that they should march forward by another way towards the land of Manti.
35399	1342	27	And because of this our march in the night-time, behold, on the morrow we were beyond the Lamanites, insomuch that we did arrive before them at the city of Manti.
35400	1342	28	And thus it came to pass, that by this stratagem we did take possession of the city of Manti without the shedding of blood.
35401	1342	29	And it came to pass that when the armies of the Lamanites did arrive near the city, and saw that we were prepared to meet them, they were astonished exceedingly and struck with great fear, insomuch that they did flee into the wilderness.
35402	1342	30	Yea, and it came to pass that the armies of the Lamanites did flee out of all this quarter of the land. But behold, they have carried with them many women and children out of the land.
35403	1342	31	And those cities which had been taken by the Lamanites, all of them are at this period of time in our possession; and our fathers and our women and our children are returning to their homes, all save it be those who have been taken prisoners and carried off by the Lamanites.
35404	1342	32	But behold, our armies are small to maintain so great a number of cities and so great possessions.
35405	1342	33	But behold, we trust in our God who has given us victory over those lands, insomuch that we have obtained those cities and those lands, which were our own.
35406	1342	34	Now we do not know the cause that the government does not grant us more strength; neither do those men who came up unto us know why we have not received greater strength.
35407	1342	35	Behold, we do not know but what ye are unsuccessful, and ye have drawn away the forces into that quarter of the land; if so, we do not desire to murmur.
35408	1342	36	And if it is not so, behold, we fear that there is some faction in the government, that they do not send more men to our assistance; for we know that they are more numerous than that which they have sent.
35409	1342	37	But, behold, it mattereth not--we trust God will deliver us, notwithstanding the weakness of our armies, yea, and deliver us out of the hands of our enemies.
35410	1342	38	Behold, this is the twenty and ninth year, in the latter end, and we are in the possession of our lands; and the Lamanites have fled to the land of Nephi.
35411	1342	39	And those sons of the people of Ammon, of whom I have so highly spoken, are with me in the city of Manti; and the Lord had supported them, yea, and kept them from falling by the sword, insomuch that even one soul has not been slain.
35412	1342	40	But behold, they have received many wounds; nevertheless they stand fast in that liberty wherewith God has made them free; and they are strict to remember the Lord their God from day to day; yea, they do observe to keep his statutes, and his judgments, and his commandments continually; and their faith is strong in the prophecies concerning that which is to come.
35413	1342	41	And now, my beloved brother, Moroni, may the Lord our God, who has redeemed us and made us free, keep you continually in his presence; yea, and may he favor this people, even that ye may have success in obtaining the possession of all that which the Lamanites have taken from us, which was for our support. And now, behold, I close mine epistle. I am Helaman, the son of Alma.
35414	1343	1	Now it came to pass in the thirtieth year of the reign of the judges over the people of Nephi, after Moroni had received and had read Helaman's epistle, he was exceedingly rejoiced because of the welfare, yea, the exceeding success which Helaman had had, in obtaining those lands which were lost.
35415	1343	2	Yea, and he did make it known unto all his people, in all the land round about in that part where he was, that they might rejoice also.
35416	1343	3	And it came to pass that he immediately sent an epistle to Pahoran, desiring that he should cause men to be gathered together to strengthen Helaman, or the armies of Helaman, insomuch that he might with ease maintain that part of the land which he had been so miraculously prospered in regaining.
35417	1343	4	And it came to pass when Moroni had sent this epistle to the land of Zarahemla, he began again to lay a plan that he might obtain the remainder of those possessions and cities which the Lamanites had taken from them.
35418	1343	5	And it came to pass that while Moroni was thus making preparations to go against the Lamanites to battle, behold, the people of Nephihah, who were gathered together from the city of Moroni and the city of Lehi and the city of Morianton, were attacked by the Lamanites.
35419	1343	6	Yea, even those who had been compelled to flee from the land of Manti, and from the land round about, had come over and joined the Lamanites in this part of the land.
35420	1343	7	And thus being exceedingly numerous, yea, and receiving strength from day to day, by the command of Ammoron they came forth against the people of Nephihah, and they did begin to slay them with an exceedingly great slaughter.
35421	1343	8	And their armies were so numerous that the remainder of the people of Nephihah were obliged to flee before them; and they came even and joined the army of Moroni.
35422	1343	9	And now as Moroni had supposed that there should be men sent to the city of Nephihah, to the assistance of the people to maintain that city, and knowing that it was easier to keep the city from falling into the hands of the Lamanites than to retake it from them, he supposed that they would easily maintain that city.
35423	1343	10	Therefore he retained all his force to maintain those places which he had recovered.
35424	1343	11	And now, when Moroni saw that the city of Nephihah was lost he was exceedingly sorrowful, and began to doubt, because of the wickedness of the people, whether they should not fall into the hands of their brethren.
35425	1343	12	Now this was the case with all his chief captains. They doubted and marveled also because of the wickedness of the people, and this because of the success of the Lamanites over them.
35426	1343	13	And it came to pass that Moroni was angry with the government, because of their indifference concerning the freedom of their country.
35427	1344	1	And it came to pass that he wrote again to the governor of the land, who was Pahoran, and these are the words which he wrote, saying: Behold, I direct mine epistle to Pahoran, in the city of Zarahemla, who is the chief judge and the governor over the land, and also to all those who have been chosen by this people to govern and manage the affairs of this war.
35428	1344	2	For behold, I have somewhat to say unto them by the way of condemnation; for behold, ye yourselves know that ye have been appointed to gather together men, and arm them with swords, and with cimeters, and all manner of weapons of war of every kind, and send forth against the Lamanites, in whatsoever parts they should come into our land.
35429	1344	3	And now behold, I say unto you that myself, and also my men, and also Helaman and his men, have suffered exceedingly great sufferings; yea, even hunger, thirst, and fatigue, and all manner of afflictions of every kind.
35430	1344	4	But behold, were this all we had suffered we would not murmur nor complain.
35431	1344	5	But behold, great has been the slaughter among our people; yea, thousands have fallen by the sword, while it might have otherwise been if ye had rendered unto our armies sufficient strength and succor for them. Yea, great has been your neglect towards us.
35432	1344	6	And now behold, we desire to know the cause of this exceedingly great neglect; yea, we desire to know the cause of your thoughtless state.
35433	1344	7	Can you think to sit upon your thrones in a state of thoughtless stupor, while your enemies are spreading the work of death around you? Yea, while they are murdering thousands of your brethren--
35434	1344	8	Yea, even they who have looked up to you for protection, yea, have placed you in a situation that ye might have succored them, yea, ye might have sent armies unto them, to have strengthened them, and have saved thousands of them from falling by the sword.
35435	1344	9	But behold, this is not all--ye have withheld your provisions from them, insomuch that many have fought and bled out their lives because of their great desires which they had for the welfare of this people; yea, and this they have done when they were about to perish with hunger, because of your exceedingly great neglect towards them.
35436	1344	10	And now, my beloved brethren--for ye ought to be beloved; yea, and ye ought to have stirred yourselves more diligently for the welfare and the freedom of this people; but behold, ye have neglected them insomuch that the blood of thousands shall come upon your heads for vengeance; yea, for known unto God were all their cries, and all their sufferings--
35437	1344	11	Behold, could ye suppose that ye could sit upon your thrones, and because of the exceeding goodness of God ye could do nothing and he would deliver you? Behold, if ye have supposed this ye have supposed in vain.
35438	1344	12	Do ye suppose that, because so many of your brethren have been killed it is because of their wickedness? I say unto you, if ye have supposed this ye have supposed in vain; for I say unto you, there are many who have fallen by the sword; and behold it is to your condemnation;
35439	1344	13	For the Lord suffereth the righteous to be slain that his justice and judgment may come upon the wicked; therefore ye need not suppose that the righteous are lost because they are slain; but behold, they do enter into the rest of the Lord their God.
35440	1344	14	And now behold, I say unto you, I fear exceedingly that the judgments of God will come upon this people, because of their exceeding slothfulness, yea, even the slothfulness of our government, and their exceedingly great neglect towards their brethren, yea, towards those who have been slain.
35441	1344	15	For were it not for the wickedness which first commenced at our head, we could have withstood our enemies that they could have gained no power over us.
35442	1344	16	Yea, had it not been for the war which broke out among ourselves; yea, were it not for these king-men, who caused so much bloodshed among ourselves; yea, at the time we were contending among ourselves, if we had united our strength as we hitherto have done; yea, had it not been for the desire of power and authority which those king-men had over us; had they been true to the cause of our freedom, and united with us, and gone forth against our enemies, instead of taking up their swords against us, which was the cause of so much bloodshed among ourselves; yea, if we had gone forth against them in the strength of the Lord, we should have dispersed our enemies, for it would have been done, according to the fulfilling of his word.
35443	1344	17	But behold, now the Lamanites are coming upon us, taking possession of our lands, and they are murdering our people with the sword, yea, our women and our children, and also carrying them away captive, causing them that they should suffer all manner of afflictions, and this because of the great wickedness of those who are seeking for power and authority, yea, even those king-men.
35444	1344	18	But why should I say much concerning this matter? For we know not but what ye yourselves are seeking for authority. We know not but what ye are also traitors to your country.
35445	1344	19	Or is it that ye have neglected us because ye are in the heart of our country and ye are surrounded by security, that ye do not cause food to be sent unto us, and also men to strengthen our armies?
35446	1344	20	Have ye forgotten the commandments of the Lord your God? Yea, have ye forgotten the captivity of our fathers? Have ye forgotten the many times we have been delivered out of the hands of our enemies?
35447	1344	21	Or do ye suppose that the Lord will still deliver us, while we sit upon our thrones and do not make use of the means which the Lord has provided for us?
35448	1344	22	Yea, will ye sit in idleness while ye are surrounded with thousands of those, yea, and tens of thousands, who do also sit in idleness, while there are thousands round about in the borders of the land who are falling by the sword, yea, wounded and bleeding?
35449	1344	23	Do ye suppose that God will look upon you as guiltless while ye sit still and behold these things? Behold I say unto you, Nay. Now I would that ye should remember that God has said that the inward vessel shall be cleansed first, and then shall the outer vessel be cleansed also.
35450	1344	24	And now, except ye do repent of that which ye have done, and begin to be up and doing, and send forth food and men unto us, and also unto Helaman, that he may support those parts of our country which he has regained, and that we may also recover the remainder of our possessions in these parts, behold it will be expedient that we contend no more with the Lamanites until we have first cleansed our inward vessel, yea, even the great head of our government.
35451	1344	25	And except ye grant mine epistle, and come out and show unto me a true spirit of freedom, and strive to strengthen and fortify our armies, and grant unto them food for their support, behold I will leave a part of my freemen to maintain this part of our land, and I will leave the strength and the blessings of God upon them, that none other power can operate against them--
35452	1344	26	And this because of their exceeding faith, and their patience in their tribulations--
35453	1344	27	And I will come unto you, and if there be any among you that has a desire for freedom, yea, if there be even a spark of freedom remaining, behold I will stir up insurrections among you, even until those who have desires to usurp power and authority shall become extinct.
35454	1344	28	Yea, behold I do not fear your power nor your authority, but it is my God whom I fear; and it is according to his commandments that I do take my sword to defend the cause of my country, and it is because of your iniquity that we have suffered so much loss.
35455	1344	29	Behold it is time, yea, the time is now at hand, that except ye do bestir yourselves in the defence of your country and your little ones, the sword of justice doth hang over you; yea, and it shall fall upon you and visit you even to your utter destruction.
35456	1344	30	Behold, I wait for assistance from you; and, except ye do administer unto our relief, behold, I come unto you, even in the land of Zarahemla, and smite you with the sword, insomuch that ye can have no more power to impede the progress of this people in the cause of our freedom.
35457	1344	31	For behold, the Lord will not suffer that ye shall live and wax strong in your iniquities to destroy his righteous people.
35458	1344	32	Behold, can you suppose that the Lord will spare you and come out in judgment against the Lamanites, when it is the tradition of their fathers that has caused their hatred, yea, and it has been redoubled by those who have dissented from us, while your iniquity is for the cause of your love of glory and the vain things of the world?
35459	1344	33	Ye know that ye do transgress the laws of God, and ye do know that ye do trample them under your feet. Behold, the Lord saith unto me: If those whom ye have appointed your governors do not repent of their sins and iniquities, ye shall go up to battle against them.
35460	1344	34	And now behold, I, Moroni, am constrained, according to the covenant which I have made to keep the commandments of my God; therefore I would that ye should adhere to the word of God, and send speedily unto me of your provisions and of your men, and also to Helaman.
35461	1344	35	And behold, if ye will not do this I come unto you speedily; for behold, God will not suffer that we should perish with hunger; therefore he will give unto us of your food, even if it must be by the sword. Now see that ye fulfil the word of God.
35462	1344	36	Behold, I am Moroni, your chief captain. I seek not for power, but to pull it down. I seek not for honor of the world, but for the glory of my God, and the freedom and welfare of my country. And thus I close mine epistle.
35463	1345	1	Behold, now it came to pass that soon after Moroni had sent his epistle unto the chief governor, he received an epistle from Pahoran, the chief governor. And these are the words which he received:
35464	1345	2	I, Pahoran, who am the chief governor of this land, do send these words unto Moroni, the chief captain over the army. Behold, I say unto you, Moroni, that I do not joy in your great afflictions, yea, it grieves my soul.
35465	1345	3	But behold, there are those who do joy in your afflictions, yea, insomuch that they have risen up in rebellion against me, and also those of my people who are freemen, yea, and those who have risen up are exceedingly numerous.
35466	1345	4	And it is those who have sought to take away the judgment-seat from me that have been the cause of this great iniquity; for they have used great flattery, and they have led away the hearts of many people, which will be the cause of sore affliction among us; they have withheld our provisions, and have daunted our freemen that they have not come unto you.
35467	1345	5	And behold, they have driven me out before them, and I have fled to the land of Gideon, with as many men as it were possible that I could get.
35468	1345	6	And behold, I have sent a proclamation throughout this part of the land; and behold, they are flocking to us daily, to their arms, in the defence of their country and their freedom, and to avenge our wrongs.
35469	1345	7	And they have come unto us, insomuch that those who have risen up in rebellion against us are set at defiance, yea, insomuch that they do fear us and durst not come out against us to battle.
35470	1345	8	They have got possession of the land, or the city, of Zarahemla; they have appointed a king over them, and he hath written unto the king of the Lamanites, in the which he hath joined an alliance with him; in the which alliance he hath agreed to maintain the city of Zarahemla, which maintenance he supposeth will enable the Lamanites to conquer the remainder of the land, and he shall be placed king over this people when they shall be conquered under the Lamanites.
35471	1345	9	And now, in your epistle you have censured me, but it mattereth not; I am not angry, but do rejoice in the greatness of your heart. I, Pahoran, do not seek for power, save only to retain my judgment-seat that I may preserve the rights and the liberty of my people. My soul standeth fast in that liberty in the which God hath made us free.
35472	1345	10	And now, behold, we will resist wickedness even unto bloodshed. We would not shed the blood of the Lamanites if they would stay in their own land.
35473	1345	11	We would not shed the blood of our brethren if they would not rise up in rebellion and take the sword against us.
35474	1345	12	We would subject ourselves to the yoke of bondage if it were requisite with the justice of God, or if he should command us so to do.
35475	1345	13	But behold he doth not command us that we shall subject ourselves to our enemies, but that we should put our trust in him, and he will deliver us.
35476	1345	14	Therefore, my beloved brother, Moroni, let us resist evil, and whatsoever evil we cannot resist with our words, yea, such as rebellions and dissensions, let us resist them with our swords, that we may retain our freedom, that we may rejoice in the great privilege of our church, and in the cause of our Redeemer and our God.
35477	1345	15	Therefore, come unto me speedily with a few of your men, and leave the remainder in the charge of Lehi and Teancum; give unto them power to conduct the war in that part of the land, according to the Spirit of God, which is also the spirit of freedom which is in them.
35478	1345	16	Behold I have sent a few provisions unto them, that they may not perish until ye can come unto me.
35479	1345	17	Gather together whatsoever force ye can upon your march hither, and we will go speedily against those dissenters, in the strength of our God according to the faith which is in us.
35480	1345	18	And we will take possession of the city of Zarahemla, that we may obtain more food to send forth unto Lehi and Teancum; yea, we will go forth against them in the strength of the Lord, and we will put an end to this great iniquity.
35481	1345	19	And now, Moroni, I do joy in receiving your epistle, for I was somewhat worried concerning what we should do, whether it should be just in us to go against our brethren.
35482	1345	20	But ye have said, except they repent the Lord hath commanded you that ye should go against them.
35483	1345	21	See that ye strengthen Lehi and Teancum in the Lord; tell them to fear not, for God will deliver them, yea, and also all those who stand fast in that liberty wherewith God hath made them free. And now I close mine epistle to my beloved brother, Moroni.
35484	1346	1	And now it came to pass that when Moroni had received this epistle his heart did take courage, and was filled with exceedingly great joy because of the faithfulness of Pahoran, that he was not also a traitor to the freedom and cause of his country.
35485	1346	2	But he did also mourn exceedingly because of the iniquity of those who had driven Pahoran from the judgment-seat, yea, in fine because of those who had rebelled against their country and also their God.
35486	1346	3	And it came to pass that Moroni took a small number of men, according to the desire of Pahoran, and gave Lehi and Teancum command over the remainder of his army, and took his march towards the land of Gideon.
35487	1346	4	And he did raise the standard of liberty in whatsoever place he did enter, and gained whatsoever force he could in all his march towards the land of Gideon.
35488	1346	5	And it came to pass that thousands did flock unto his standard, and did take up their swords in the defence of their freedom, that they might not come into bondage.
35489	1346	6	And thus, when Moroni had gathered together whatsoever men he could in all his march, he came to the land of Gideon; and uniting his forces with those of Pahoran they became exceedingly strong, even stronger than the men of Pachus, who was the king of those dissenters who had driven the freemen out of the land of Zarahemla and had taken possession of the land.
35490	1346	7	And it came to pass that Moroni and Pahoran went down with their armies into the land of Zarahemla, and went forth against the city, and did meet the men of Pachus, insomuch that they did come to battle.
35491	1346	8	And behold, Pachus was slain and his men were taken prisoners, and Pahoran was restored to his judgment-seat.
35492	1346	9	And the men of Pachus received their trial, according to the law, and also those king-men who had been taken and cast into prison; and they were executed according to the law; yea, those men of Pachus and those king-men, whosoever would not take up arms in the defence of their country, but would fight against it, were put to death.
35493	1346	10	And thus it became expedient that this law should be strictly observed for the safety of their country; yea, and whosoever was found denying their freedom was speedily executed according to the law.
35494	1346	11	And thus ended the thirtieth year of the reign of the judges over the people of Nephi; Moroni and Pahoran having restored peace to the land of Zarahemla, among their own people, having inflicted death upon all those who were not true to the cause of freedom.
35495	1346	12	And it came to pass in the commencement of the thirty and first year of the reign of the judges over the people of Nephi, Moroni immediately caused that provisions should be sent, and also an army of six thousand men should be sent unto Helaman, to assist him in preserving that part of the land.
35496	1346	13	And he also caused that an army of six thousand men, with a sufficient quantity of food, should be sent to the armies of Lehi and Teancum. And it came to pass that this was done to fortify the land against the Lamanites.
35497	1346	14	And it came to pass that Moroni and Pahoran, leaving a large body of men in the land of Zarahemla, took their march with a large body of men towards the land of Nephihah, being determined to overthrow the Lamanites in that city.
35498	1346	15	And it came to pass that as they were marching towards the land, they took a large body of men of the Lamanites, and slew many of them, and took their provisions and their weapons of war.
35499	1346	16	And it came to pass after they had taken them, they caused them to enter into a covenant that they would no more take up their weapons of war against the Nephites.
35500	1346	17	And when they had entered into this covenant they sent them to dwell with the people of Ammon, and they were in number about four thousand who had not been slain.
35501	1346	18	And it came to pass that when they had sent them away they pursued their march towards the land of Nephihah. And it came to pass that when they had come to the city of Nephihah, they did pitch their tents in the plains of Nephihah, which is near the city of Nephihah.
35502	1346	19	Now Moroni was desirous that the Lamanites should come out to battle against them, upon the plains; but the Lamanites, knowing of their exceedingly great courage, and beholding the greatness of their numbers, therefore they durst not come out against them; therefore they did not come to battle in that day.
35503	1346	20	And when the night came, Moroni went forth in the darkness of the night, and came upon the top of the wall to spy out in what part of the city the Lamanites did camp with their army.
35504	1346	21	And it came to pass that they were on the east, by the entrance; and they were all asleep. And now Moroni returned to his army, and caused that they should prepare in haste strong cords and ladders, to be let down from the top of the wall into the inner part of the wall.
35505	1346	22	And it came to pass that Moroni caused that his men should march forth and come upon the top of the wall, and let themselves down into that part of the city, yea, even on the west, where the Lamanites did not camp with their armies.
35506	1346	23	And it came to pass that they were all let down into the city by night, by the means of their strong cords and their ladders; thus when the morning came they were all within the walls of the city.
35507	1346	24	And now, when the Lamanites awoke and saw that the armies of Moroni were within the walls, they were affrighted exceedingly, insomuch that they did flee out by the pass.
35508	1346	25	And now when Moroni saw that they were fleeing before him, he did cause that his men should march forth against them, and slew many, and surrounded many others, and took them prisoners; and the remainder of them fled into the land of Moroni, which was in the borders by the seashore.
35509	1346	26	Thus had Moroni and Pahoran obtained the possession of the city of Nephihah without the loss of one soul; and there were many of the Lamanites who were slain.
35510	1346	27	Now it came to pass that many of the Lamanites that were prisoners were desirous to join the people of Ammon and become a free people.
35511	1346	28	And it came to pass that as many as were desirous, unto them it was granted according to their desires.
35512	1346	29	Therefore, all the prisoners of the Lamanites did join the people of Ammon, and did begin to labor exceedingly, tilling the ground, raising all manner of grain, and flocks and herds of every kind; and thus were the Nephites relieved from a great burden; yea, insomuch that they were relieved from all the prisoners of the Lamanites.
35513	1346	30	Now it came to pass that Moroni, after he had obtained possession of the city of Nephihah, having taken many prisoners, which did reduce the armies of the Lamanites exceedingly, and having regained many of the Nephites who had been taken prisoners, which did strengthen the army of Moroni exceedingly; therefore Moroni went forth from the land of Nephihah to the land of Lehi.
35514	1346	31	And it came to pass that when the Lamanites saw that Moroni was coming against them, they were again frightened and fled before the army of Moroni.
35515	1346	32	And it came to pass that Moroni and his army did pursue them from city to city, until they were met by Lehi and Teancum; and the Lamanites fled from Lehi and Teancum, even down upon the borders by the seashore, until they came to the land of Moroni.
35516	1346	33	And the armies of the Lamanites were all gathered together, insomuch that they were all in one body in the land of Moroni. Now Ammoron, the king of the Lamanites, was also with them.
35517	1346	34	And it came to pass that Moroni and Lehi and Teancum did encamp with their armies round about in the borders of the land of Moroni, insomuch that the Lamanites were encircled about in the borders by the wilderness on the south, and in the borders by the wilderness on the east.
35518	1346	35	And thus they did encamp for the night. For behold, the Nephites and the Lamanites also were weary because of the greatness of the march; therefore they did not resolve upon any stratagem in the night-time, save it were Teancum; for he was exceedingly angry with Ammoron, insomuch that he considered that Ammoron, and Amalickiah his brother, had been the cause of this great and lasting war between them and the Lamanites, which had been the cause of so much war and bloodshed, yea, and so much famine.
35519	1346	36	And it came to pass that Teancum in his anger did go forth into the camp of the Lamanites, and did let himself down over the walls of the city. And he went forth with a cord, from place to place, insomuch that he did find the king; and he did cast a javelin at him, which did pierce him near the heart. But behold, the king did awaken his servants before he died, insomuch that they did pursue Teancum, and slew him.
35520	1346	37	Now it came to pass that when Lehi and Moroni knew that Teancum was dead they were exceedingly sorrowful; for behold, he had been a man who had fought valiantly for his country, yea, a true friend to liberty; and he had suffered very many exceedingly sore afflictions. But behold, he was dead, and had gone the way of all the earth.
35521	1346	38	Now it came to pass that Moroni marched forth on the morrow, and came upon the Lamanites, insomuch that they did slay them with a great slaughter; and they did drive them out of the land; and they did flee, even that they did not return at that time against the Nephites.
35522	1346	39	And thus ended the thirty and first year of the reign of the judges over the people of Nephi; and thus they had had wars, and bloodsheds, and famine, and affliction, for the space of many years.
35523	1346	40	And there had been murders, and contentions, and dissensions, and all manner of iniquity among the people of Nephi; nevertheless for the righteous' sake, yea, because of the prayers of the righteous, they were spared.
35524	1346	41	But behold, because of the exceedingly great length of the war between the Nephites and the Lamanites many had become hardened, because of the exceedingly great length of the war; and many were softened because of their afflictions, insomuch that they did humble themselves before God, even in the depth of humility.
35525	1346	42	And it came to pass that after Moroni had fortified those parts of the land which were most exposed to the Lamanites, until they were sufficiently strong, he returned to the city of Zarahemla; and also Helaman returned to the place of his inheritance; and there was once more peace established among the people of Nephi.
35526	1346	43	And Moroni yielded up the command of his armies into the hands of his son, whose name was Moronihah; and he retired to his own house that he might spend the remainder of his days in peace.
35527	1346	44	And Pahoran did return to his judgment-seat; and Helaman did take upon him again to preach unto the people the word of God; for because of so many wars and contentions it had become expedient that a regulation should be made again in the church.
35528	1346	45	Therefore, Helaman and his brethren went forth, and did declare the word of God with much power unto the convincing of many people of their wickedness, which did cause them to repent of their sins and to be baptized unto the Lord their God.
35529	1346	46	And it came to pass that they did establish again the church of God, throughout all the land.
35530	1346	47	Yea, and regulations were made concerning the law. And their judges, and their chief judges were chosen.
35531	1346	48	And the people of Nephi began to prosper again in the land, and began to multiply and to wax exceedingly strong again in the land. And they began to grow exceedingly rich.
35532	1346	49	But notwithstanding their riches, or their strength, or their prosperity, they were not lifted up in the pride of their eyes; neither were they slow to remember the Lord their God; but they did humble themselves exceedingly before him.
35533	1346	50	Yea, they did remember how great things the Lord had done for them, that he had delivered them from death, and from bonds, and from prisons, and from all manner of afflictions and he had delivered them out of the hands of their enemies.
35534	1346	51	And they did pray unto the Lord their God continually, insomuch that the Lord did bless them, according to his word, so that they did wax strong and prosper in the land.
35535	1346	52	And it came to pass that all these things were done. And Helaman died, in the thirty and fifth year of the reign of the judges over the people of Nephi.
35536	1347	1	And it came to pass in the commencement of the thirty and sixth year of the reign of the judges over the people of Nephi, that Shiblon took possession of those sacred things which had been delivered unto Helaman by Alma.
35537	1347	2	And he was a just man, and he did walk uprightly before God; and he did observe to do good continually, to keep the commandments of the Lord his God; and also did his brother.
35538	1347	3	And it came to pass that Moroni died also. And thus ended the thirty and sixth year of the reign of the judges.
35539	1347	4	And it came to pass that in the thirty and seventh year of the reign of the judges, there was a large company of men, even to the amount of five thousand and four hundred men, with their wives and their children, departed out of the land of Zarahemla into the land which was northward.
35540	1347	5	And it came to pass that Hagoth, he being an exceedingly curious man, therefore he went forth and built him an exceedingly large ship, on the borders of the land Bountiful, by the land Desolation, and launched it forth into the west sea, by the narrow neck which led into the land northward.
35541	1347	6	And behold, there were many of the Nephites who did enter therein and did sail forth with much provisions, and also many women and children; and they took their course northward. And thus ended the thirty and seventh year.
35542	1347	7	And in the thirty and eighth year, this man built other ships. And the first ship did also return, and many more people did enter into it; and they also took much provisions, and set out again to the land northward.
35543	1347	8	And it came to pass that they were never heard of more. And we suppose that they were drowned in the depths of the sea. And it came to pass that one other ship also did sail forth; and whither she did go we know not.
35544	1347	9	And it came to pass that in this year there were many people who went forth into the land northward. And thus ended the thirty and eighth year.
35545	1347	10	And it came to pass in the thirty and ninth year of the reign of the judges, Shiblon died also, and Corianton had gone forth to the land northward in a ship, to carry forth provisions unto the people who had gone forth into that land.
35546	1347	11	Therefore it became expedient for Shiblon to confer those sacred things, before his death, upon the son of Helaman, who was called Helaman, being called after the name of his father.
35547	1347	12	Now behold, all those engravings which were in the possession of Helaman were written and sent forth among the children of men throughout all the land, save it were those parts which had been commanded by Alma should not go forth.
35548	1347	13	Nevertheless, these things were to be kept sacred, and handed down from one generation to another; therefore, in this year, they had been conferred upon Helaman, before the death of Shiblon.
35549	1347	14	And it came to pass also in this year that there were some dissenters who had gone forth unto the Lamanites; and they were stirred up again to anger against the Nephites.
35550	1347	15	And also in this same year they came down with a numerous army to war against the people of Moronihah, or against the army of Moronihah, in the which they were beaten and driven back again to their own lands, suffering great loss.
35551	1347	16	And thus ended the thirty and ninth year of the reign of the judges over the people of Nephi.
35552	1347	17	And thus ended the account of Alma, and Helaman his son, and also Shiblon, who was his son.
35553	1348	1	And now behold, it came to pass in the commencement of the fortieth year of the reign of the judges over the people of Nephi, there began to be a serious difficulty among the people of the Nephites.
35554	1348	2	For behold, Pahoran had died, and gone the way of all the earth; therefore there began to be a serious contention concerning who should have the judgment-seat among the brethren, who were the sons of Pahoran.
35555	1348	3	Now these are their names who did contend for the judgment-seat, who did also cause the people to contend: Pahoran, Paanchi, and Pacumeni.
35556	1348	4	Now these are not all the sons of Pahoran (for he had many), but these are they who did contend for the judgment-seat; therefore, they did cause three divisions among the people.
35557	1348	5	Nevertheless, it came to pass that Pahoran was appointed by the voice of the people to be chief judge and a governor over the people of Nephi.
35558	1348	6	And it came to pass that Pacumeni, when he saw that he could not obtain the judgment-seat, he did unite with the voice of the people.
35559	1348	7	But behold, Paanchi, and that part of the people that were desirous that he should be their governor, was exceedingly wroth; therefore, he was about to flatter away those people to rise up in rebellion against their brethren.
35560	1348	8	And it came to pass as he was about to do this, behold, he was taken, and was tried according to the voice of the people, and condemned unto death; for he had raised up in rebellion and sought to destroy the liberty of the people.
35561	1348	9	Now when those people who were desirous that he should be their governor saw that he was condemned unto death, therefore they were angry, and behold, they sent forth one Kishkumen, even to the judgment-seat of Pahoran, and murdered Pahoran as he sat upon the judgment-seat.
35562	1348	10	And he was pursued by the servants of Pahoran; but behold, so speedy was the flight of Kishkumen that no man could overtake him.
35563	1348	11	And he went unto those that sent him, and they all entered into a covenant, yea, swearing by their everlasting Maker, that they would tell no man that Kishkumen had murdered Pahoran.
35564	1348	12	Therefore, Kishkumen was not known among the people of Nephi, for he was in disguise at the time that he murdered Pahoran. And Kishkumen and his band, who had covenanted with him, did mingle themselves among the people, in a manner that they all could not be found; but as many as were found were condemned unto death.
35565	1348	13	And now behold, Pacumeni was appointed, according to the voice of the people, to be a chief judge and a governor over the people, to reign in the stead of his brother Pahoran; and it was according to his right. And all this was done in the fortieth year of the reign of the judges; and it had an end.
35566	1348	14	And it came to pass in the forty and first year of the reign of the judges, that the Lamanites had gathered together an innumerable army of men, and armed them with swords, and with cimeters and with bows, and with arrows, and with head-plates, and with breastplates, and with all manner of shields of every kind.
35567	1348	15	And they came down again that they might pitch battle against the Nephites. And they were led by a man whose name was Coriantumr; and he was a descendant of Zarahemla; and he was a dissenter from among the Nephites; and he was a large and a mighty man.
35568	1348	16	Therefore, the king of the Lamanites, whose name was Tubaloth, who was the son of Ammoron, supposing that Coriantumr, being a mighty man, could stand against the Nephites, with his strength and also with his great wisdom, insomuch that by sending him forth he should gain power over the Nephites--
35569	1348	17	Therefore he did stir them up to anger, and he did gather together his armies, and he did appoint Coriantumr to be their leader, and did cause that they should march down to the land of Zarahemla to battle against the Nephites.
35570	1348	18	And it came to pass that because of so much contention and so much difficulty in the government, that they had not kept sufficient guards in the land of Zarahemla; for they had supposed that the Lamanites durst not come into the heart of their lands to attack that great city Zarahemla.
35571	1348	19	But it came to pass that Coriantumr did march forth at the head of his numerous host, and came upon the inhabitants of the city, and their march was with such exceedingly great speed that there was no time for the Nephites to gather together their armies.
35572	1348	20	Therefore Coriantumr did cut down the watch by the entrance of the city, and did march forth with his whole army into the city, and they did slay every one who did oppose them, insomuch that they did take possession of the whole city.
35573	1348	21	And it came to pass that Pacumeni, who was the chief judge, did flee before Coriantumr, even to the walls of the city. And it came to pass that Coriantumr did smite him against the wall, insomuch that he died. And thus ended the days of Pacumeni.
35574	1348	22	And now when Coriantumr saw that he was in possession of the city of Zarahemla, and saw that the Nephites had fled before them, and were slain, and were taken, and were cast into prison, and that he had obtained the possession of the strongest hold in all the land, his heart took courage insomuch that he was about to go forth against all the land.
35575	1348	23	And now he did not tarry in the land of Zarahemla, but he did march forth with a large army, even towards the city of Bountiful; for it was his determination to go forth and cut his way through with the sword, that he might obtain the north parts of the land.
35576	1348	24	And, supposing that their greatest strength was in the center of the land, therefore he did march forth, giving them no time to assemble themselves together save it were in small bodies; and in this manner they did fall upon them and cut them down to the earth.
35577	1348	25	But behold, this march of Coriantumr through the center of the land gave Moronihah great advantage over them, notwithstanding the greatness of the number of the Nephites who were slain.
35578	1348	26	For behold, Moronihah had supposed that the Lamanites durst not come into the center of the land, but that they would attack the cities round about in the borders as they had hitherto done; therefore Moronihah had caused that their strong armies should maintain those parts round about by the borders.
35579	1348	27	But behold, the Lamanites were not frightened according to his desire, but they had come into the center of the land, and had taken the capital city which was the city of Zarahemla, and were marching through the most capital parts of the land, slaying the people with a great slaughter, both men, women, and children, taking possession of many cities and of many strongholds.
35580	1348	28	But when Moronihah had discovered this, he immediately sent forth Lehi with an army round about to head them before they should come to the land Bountiful.
35581	1348	29	And thus he did; and he did head them before they came to the land Bountiful, and gave unto them battle, insomuch that they began to retreat back towards the land of Zarahemla.
35582	1348	30	And it came to pass that Moronihah did head them in their retreat, and did give unto them battle, insomuch that it became an exceedingly bloody battle; yea, many were slain, and among the number who were slain Coriantumr was also found.
35583	1348	31	And now, behold, the Lamanites could not retreat either way, neither on the north, nor on the south, nor on the east, nor on the west, for they were surrounded on every hand by the Nephites.
35584	1348	32	And thus had Coriantumr plunged the Lamanites into the midst of the Nephites, insomuch that they were in the power of the Nephites, and he himself was slain, and the Lamanites did yield themselves into the hands of the Nephites.
35585	1348	33	And it came to pass that Moronihah took possession of the city of Zarahemla again, and caused that the Lamanites who had been taken prisoners should depart out of the land in peace.
35586	1348	34	And thus ended the forty and first year of the reign of the judges.
35587	1349	1	And it came to pass in the forty and second year of the reign of the judges, after Moronihah had established again peace between the Nephites and the Lamanites, behold there was no one to fill the judgment-seat; therefore there began to be a contention again among the people concerning who should fill the judgment-seat.
35588	1349	2	And it came to pass that Helaman, who was the son of Helaman, was appointed to fill the judgment-seat, by the voice of the people.
35589	1349	3	But behold, Kishkumen, who had murdered Pahoran, did lay wait to destroy Helaman also; and he was upheld by his band, who had entered into a covenant that no one should know his wickedness.
35590	1349	4	For there was one Gadianton, who was exceedingly expert in many words, and also in his craft, to carry on the secret work of murder and of robbery; therefore he became the leader of the band of Kishkumen.
35591	1349	5	Therefore he did flatter them, and also Kishkumen, that if they would place him in the judgment-seat he would grant unto those who belonged to his band that they should be placed in power and authority among the people; therefore Kishkumen sought to destroy Helaman.
35592	1349	6	And it came to pass as he went forth towards the judgment-seat to destroy Helaman, behold one of the servants of Helaman, having been out by night, and having obtained, through disguise, a knowledge of those plans which had been laid by this band to destroy Helaman--
35593	1349	7	And it came to pass that he met Kishkumen, and he gave unto him a sign; therefore Kishkumen made known unto him the object of his desire, desiring that he would conduct him to the judgment-seat that he might murder Helaman.
35594	1349	8	And when the servant of Helaman had known all the heart of Kishkumen, and how that it was his object to murder, and also that it was the object of all those who belonged to his band to murder, and to rob, and to gain power, (and this was their secret plan, and their combination) the servant of Helaman said unto Kishkumen: Let us go forth unto the judgment-seat.
35595	1349	9	Now this did please Kishkumen exceedingly, for he did suppose that he should accomplish his design; but behold, the servant of Helaman, as they were going forth unto the judgment-seat, did stab Kishkumen even to the heart, that he fell dead without a groan. And he ran and told Helaman all the things which he had seen, and heard, and done.
35596	1349	10	And it came to pass that Helaman did send forth to take this band of robbers and secret murderers, that they might be executed according to the law.
35597	1349	11	But behold, when Gadianton had found that Kishkumen did not return he feared lest that he should be destroyed; therefore he caused that his band should follow him. And they took their flight out of the land, by a secret way, into the wilderness; and thus when Helaman sent forth to take them they could nowhere be found.
35598	1349	12	And more of this Gadianton shall be spoken hereafter. And thus ended the forty and second year of the reign of the judges over the people of Nephi.
35599	1349	13	And behold, in the end of this book ye shall see that this Gadianton did prove the overthrow, yea, almost the entire destruction of the people of Nephi.
35600	1349	14	Behold I do not mean the end of the book of Helaman, but I mean the end of the book of Nephi, from which I have taken all the account which I have written.
35601	1350	1	And now it came to pass in the forty and third year of the reign of the judges, there was no contention among the people of Nephi save it were a little pride which was in the church, which did cause some little dissensions among the people, which affairs were settled in the ending of the forty and third year.
35602	1350	2	And there was no contention among the people in the forty and fourth year; neither was there much contention in the forty and fifth year.
35603	1350	3	And it came to pass in the forty and sixth, yea, there was much contention and many dissensions; in the which there were an exceedingly great many who departed out of the land of Zarahemla, and went forth unto the land northward to inherit the land.
35604	1350	4	And they did travel to an exceedingly great distance, insomuch that they came to large bodies of water and many rivers.
35605	1350	5	Yea, and even they did spread forth into all parts of the land, into whatever parts it had not been rendered desolate and without timber, because of the many inhabitants who had before inherited the land.
35606	1350	6	And now no part of the land was desolate, save it were for timber; but because of the greatness of the destruction of the people who had before inhabited the land it was called desolate.
35607	1350	7	And there being but little timber upon the face of the land, nevertheless the people who went forth became exceedingly expert in the working of cement; therefore they did build houses of cement, in the which they did dwell.
35608	1350	8	And it came to pass that they did multiply and spread, and did go forth from the land southward to the land northward, and did spread insomuch that they began to cover the face of the whole earth, from the sea south to the sea north, from the sea west to the sea east.
35609	1350	9	And the people who were in the land northward did dwell in tents, and in houses of cement, and they did suffer whatsoever tree should spring up upon the face of the land that it should grow up, that in time they might have timber to build their houses, yea, their cities, and their temples, and their synagogues, and their sanctuaries, and all manner of their buildings.
35610	1350	10	And it came to pass as timber was exceedingly scarce in the land northward, they did send forth much by the way of shipping.
35611	1350	11	And thus they did enable the people in the land northward that they might build many cities, both of wood and of cement.
35612	1350	12	And it came to pass that there were many of the people of Ammon, who were Lamanites by birth, did also go forth into this land.
35613	1350	13	And now there are many records kept of the proceedings of this people, by many of this people, which are particular and very large, concerning them.
35614	1350	14	But behold, a hundredth part of the proceedings of this people, yea, the account of the Lamanites and of the Nephites, and their wars, and contentions, and dissensions, and their preaching, and their prophecies, and their shipping and their building of ships, and their building of temples, and of synagogues and their sanctuaries, and their righteousness, and their wickedness, and their murders, and their robbings, and their plundering, and all manner of abominations and whoredoms, cannot be contained in this work.
35615	1350	15	But behold, there are many books and many records of every kind, and they have been kept chiefly by the Nephites.
35616	1350	16	And they have been handed down from one generation to another by the Nephites, even until they have fallen into transgression and have been murdered, plundered, and hunted, and driven forth, and slain, and scattered upon the face of the earth, and mixed with the Lamanites until they are no more called the Nephites, becoming wicked, and wild, and ferocious, yea, even becoming Lamanites.
35617	1350	17	And now I return again to mine account; therefore, what I have spoken had passed after there had been great contentions, and disturbances, and wars, and dissensions, among the people of Nephi.
35618	1350	18	The forty and sixth year of the reign of the judges ended;
35619	1350	19	And it came to pass that there was still great contention in the land, yea, even in the forty and seventh year, and also in the forty and eighth year.
35620	1350	20	Nevertheless Helaman did fill the judgment-seat with justice and equity; yea, he did observe to keep the statutes, and the judgments, and the commandments of God; and he did do that which was right in the sight of God continually; and he did walk after the ways of his father, insomuch that he did prosper in the land.
35621	1350	21	And it came to pass that he had two sons. He gave unto the eldest the name of Nephi, and unto the youngest, the name of Lehi. And they began to grow up unto the Lord.
35622	1350	22	And it came to pass that the wars and contentions began to cease, in a small degree, among the people of the Nephites, in the latter end of the forty and eighth year of the reign of the judges over the people of Nephi.
35623	1350	23	And it came to pass in the forty and ninth year of the reign of the judges, there was continual peace established in the land, all save it were the secret combinations which Gadianton the robber had established in the more settled parts of the land, which at that time were not known unto those who were at the head of government; therefore they were not destroyed out of the land.
35624	1350	24	And it came to pass that in this same year there was exceedingly great prosperity in the church, insomuch that there were thousands who did join themselves unto the church and were baptized unto repentance.
35625	1350	25	And so great was the prosperity of the church, and so many the blessings which were poured out upon the people, that even the high priests and the teachers were themselves astonished beyond measure.
35626	1350	26	And it came to pass that the work of the Lord did prosper unto the baptizing and uniting to the church of God, many souls, yea, even tens of thousands.
35627	1350	27	Thus we may see that the Lord is merciful unto all who will, in the sincerity of their hearts, call upon his holy name.
35628	1350	28	Yea, thus we see that the gate of heaven is open unto all, even to those who will believe on the name of Jesus Christ, who is the Son of God.
35629	1350	29	Yea, we see that whosoever will may lay hold upon the word of God, which is quick and powerful, which shall divide asunder all the cunning and the snares and the wiles of the devil, and lead the man of Christ in a strait and narrow course across that everlasting gulf of misery which is prepared to engulf the wicked--
35630	1350	30	And land their souls, yea, their immortal souls, at the right hand of God in the kingdom of heaven, to sit down with Abraham, and Isaac, and with Jacob, and with all our holy fathers, to go no more out.
35631	1350	31	And in this year there was continual rejoicing in the land of Zarahemla, and in all the regions round about, even in all the land which was possessed by the Nephites.
35632	1350	32	And it came to pass that there was peace and exceedingly great joy in the remainder of the forty and ninth year; yea, and also there was continual peace and great joy in the fiftieth year of the reign of the judges.
35633	1350	33	And in the fifty and first year of the reign of the judges there was peace also, save it were the pride which began to enter into the church--not into the church of God, but into the hearts of the people who professed to belong to the church of God--
35634	1350	34	And they were lifted up in pride, even to the persecution of many of their brethren. Now this was a great evil, which did cause the more humble part of the people to suffer great persecutions, and to wade through much affliction.
35635	1350	35	Nevertheless they did fast and pray oft, and did wax stronger and stronger in their humility, and firmer and firmer in the faith of Christ, unto the filling their souls with joy and consolation, yea, even to the purifying and the sanctification of their hearts, which sanctification cometh because of their yielding their hearts unto God.
35636	1350	36	And it came to pass that the fifty and second year ended in peace also, save it were the exceedingly great pride which had gotten into the hearts of the people; and it was because of their exceedingly great riches and their prosperity in the land; and it did grow upon them from day to day.
35637	1350	37	And it came to pass in the fifty and third year of the reign of the judges, Helaman died, and his eldest son Nephi began to reign in his stead. And it came to pass that he did fill the judgment-seat with justice and equity; yea, he did keep the commandments of God, and did walk in the ways of his father.
35638	1351	1	And it came to pass in the fifty and fourth year there were many dissensions in the church, and there was also a contention among the people, insomuch that there was much bloodshed.
35639	1351	2	And the rebellious part were slain and driven out of the land, and they did go unto the king of the Lamanites.
35640	1351	3	And it came to pass that they did endeavor to stir up the Lamanites to war against the Nephites; but behold, the Lamanites were exceedingly afraid, insomuch that they would not hearken to the words of those dissenters.
35641	1351	4	But it came to pass in the fifty and sixth year of the reign of the judges, there were dissenters who went up from the Nephites unto the Lamanites; and they succeeded with those others in stirring them up to anger against the Nephites; and they were all that year preparing for war.
35642	1351	5	And in the fifty and seventh year they did come down against the Nephites to battle, and they did commence the work of death; yea, insomuch that in the fifty and eighth year of the reign of the judges they succeeded in obtaining possession of the land of Zarahemla; yea, and also all the lands, even unto the land which was near the land Bountiful.
35643	1351	6	And the Nephites and the armies of Moronihah were driven even into the land of Bountiful;
35644	1351	7	And there they did fortify against the Lamanites, from the west sea, even unto the east; it being a day's journey for a Nephite, on the line which they had fortified and stationed their armies to defend their north country.
35645	1351	8	And thus those dissenters of the Nephites, with the help of a numerous army of the Lamanites, had obtained all the possession of the Nephites which was in the land southward. And all this was done in the fifty and eighth and ninth years of the reign of the judges.
35646	1351	9	And it came to pass in the sixtieth year of the reign of the judges, Moronihah did succeed with his armies in obtaining many parts of the land; yea, they regained many cities which had fallen into the hands of the Lamanites.
35647	1351	10	And it came to pass in the sixty and first year of the reign of the judges they succeeded in regaining even the half of all their possessions.
35648	1351	11	Now this great loss of the Nephites, and the great slaughter which was among them, would not have happened had it not been for their wickedness and their abomination which was among them; yea, and it was among those also who professed to belong to the church of God.
35649	1351	12	And it was because of the pride of their hearts, because of their exceeding riches, yea, it was because of their oppression to the poor, withholding their food from the hungry, withholding their clothing from the naked, and smiting their humble brethren upon the cheek, making a mock of that which was sacred, denying the spirit of prophecy and of revelation, murdering, plundering, lying, stealing, committing adultery, rising up in great contentions, and deserting away into the land of Nephi, among the Lamanites--
35650	1351	13	And because of this their great wickedness, and their boastings in their own strength, they were left in their own strength; therefore they did not prosper, but were afflicted and smitten, and driven before the Lamanites, until they had lost possession of almost all their lands.
35651	1351	14	But behold, Moronihah did preach many things unto the people because of their iniquity, and also Nephi and Lehi, who were the sons of Helaman, did preach many things unto the people, yea, and did prophesy many things unto them concerning their iniquities, and what should come unto them if they did not repent of their sins.
35652	1351	15	And it came to pass that they did repent, and inasmuch as they did repent they did begin to prosper.
35653	1351	16	For when Moronihah saw that they did repent he did venture to lead them forth from place to place, and from city to city, even until they had regained the one-half of their property and the one-half of all their lands.
35654	1351	17	And thus ended the sixty and first year of the reign of the judges.
35655	1351	18	And it came to pass in the sixty and second year of the reign of the judges, that Moronihah could obtain no more possessions over the Lamanites.
35656	1351	19	Therefore they did abandon their design to obtain the remainder of their lands, for so numerous were the Lamanites that it became impossible for the Nephites to obtain more power over them; therefore Moronihah did employ all his armies in maintaining those parts which he had taken.
35657	1351	20	And it came to pass, because of the greatness of the number of the Lamanites the Nephites were in great fear, lest they should be overpowered, and trodden down, and slain, and destroyed.
35658	1351	21	Yea, they began to remember the prophecies of Alma, and also the words of Mosiah; and they saw that they had been a stiffnecked people, and that they had set at naught the commandments of God;
35659	1351	22	And that they had altered and trampled under their feet the laws of Mosiah, or that which the Lord commanded him to give unto the people; and they saw that their laws had become corrupted, and that they had become a wicked people, insomuch that they were wicked even like unto the Lamanites.
35660	1351	23	And because of their iniquity the church had begun to dwindle; and they began to disbelieve in the spirit of prophecy and in the spirit of revelation; and the judgments of God did stare them in the face.
35661	1351	24	And they saw that they had become weak, like unto their brethren, the Lamanites, and that the Spirit of the Lord did no more preserve them; yea, it had withdrawn from them because the Spirit of the Lord doth not dwell in unholy temples--
35662	1351	25	Therefore the Lord did cease to preserve them by his miraculous and matchless power, for they had fallen into a state of unbelief and awful wickedness; and they saw that the Lamanites were exceedingly more numerous than they, and except they should cleave unto the Lord their God they must unavoidably perish.
35663	1351	26	For behold, they saw that the strength of the Lamanites was as great as their strength, even man for man. And thus had they fallen into this great transgression; yea, thus had they become weak, because of their transgression, in the space of not many years.
35664	1352	1	And it came to pass that in this same year, behold, Nephi delivered up the judgment-seat to a man whose name was Cezoram.
35665	1352	2	For as their laws and their governments were established by the voice of the people, and they who chose evil were more numerous than they who chose good, therefore they were ripening for destruction, for the laws had become corrupted.
35666	1352	3	Yea, and this was not all; they were a stiffnecked people, insomuch that they could not be governed by the law nor justice, save it were to their destruction.
35667	1352	4	And it came to pass that Nephi had become weary because of their iniquity; and he yielded up the judgment-seat, and took it upon him to preach the word of God all the remainder of his days, and his brother Lehi also, all the remainder of his days;
35668	1352	5	For they remembered the words which their father Helaman spake unto them. And these are the words which he spake:
35669	1352	6	Behold, my sons, I desire that ye should remember to keep the commandments of God; and I would that ye should declare unto the people these words. Behold, I have given unto you the names of our first parents who came out of the land of Jerusalem; and this I have done that when you remember your names ye may remember them; and when ye remember them ye may remember their works; and when ye remember their works ye may know how that it is said, and also written, that they were good.
35670	1352	7	Therefore, my sons, I would that ye should do that which is good, that it may be said of you, and also written, even as it has been said and written of them.
35671	1352	8	And now my sons, behold I have somewhat more to desire of you, which desire is, that ye may not do these things that ye may boast, but that ye may do these things to lay up for yourselves a treasure in heaven, yea, which is eternal, and which fadeth not away; yea, that ye may have that precious gift of eternal life, which we have reason to suppose hath been given to our fathers.
35672	1352	9	O remember, remember, my sons, the words which king Benjamin spake unto his people; yea, remember that there is no other way nor means whereby man can be saved, only through the atoning blood of Jesus Christ, who shall come; yea, remember that he cometh to redeem the world.
35673	1352	10	And remember also the words which Amulek spake unto Zeezrom, in the city of Ammonihah; for he said unto him that the Lord surely should come to redeem his people, but that he should not come to redeem them in their sins, but to redeem them from their sins.
35674	1352	11	And he hath power given unto him from the Father to redeem them from their sins because of repentance; therefore he hath sent his angels to declare the tidings of the conditions of repentance, which bringeth unto the power of the Redeemer, unto the salvation of their souls.
35675	1352	12	And now, my sons, remember, remember that it is upon the rock of our Redeemer, who is Christ, the Son of God, that ye must build your foundation; that when the devil shall send forth his mighty winds, yea, his shafts in the whirlwind, yea, when all his hail and his mighty storm shall beat upon you, it shall have no power over you to drag you down to the gulf of misery and endless wo, because of the rock upon which ye are built, which is a sure foundation, a foundation whereon if men build they cannot fall.
35676	1352	13	And it came to pass that these were the words which Helaman taught to his sons; yea, he did teach them many things which are not written, and also many things which are written.
35677	1352	14	And they did remember his words; and therefore they went forth, keeping the commandments of God, to teach the word of God among all the people of Nephi, beginning at the city Bountiful;
35678	1352	15	And from thenceforth to the city of Gid; and from the city of Gid to the city of Mulek;
35679	1352	16	And even from one city to another, until they had gone forth among all the people of Nephi who were in the land southward; and from thence into the land of Zarahemla, among the Lamanites.
35680	1352	17	And it came to pass that they did preach with great power, insomuch that they did confound many of those dissenters who had gone over from the Nephites, insomuch that they came forth and did confess their sins and were baptized unto repentance, and immediately returned to the Nephites to endeavor to repair unto them the wrongs which they had done.
35681	1352	18	And it came to pass that Nephi and Lehi did preach unto the Lamanites with such great power and authority, for they had power and authority given unto them that they might speak, and they also had what they should speak given unto them--
35682	1352	19	Therefore they did speak unto the great astonishment of the Lamanites, to the convincing them, insomuch that there were eight thousand of the Lamanites who were in the land of Zarahemla and round about baptized unto repentance, and were convinced of the wickedness of the traditions of their fathers.
35683	1352	20	And it came to pass that Nephi and Lehi did proceed from thence to go to the land of Nephi.
35684	1352	21	And it came to pass that they were taken by an army of the Lamanites and cast into prison; yea, even in that same prison in which Ammon and his brethren were cast by the servants of Limhi.
35685	1352	22	And after they had been cast into prison many days without food, behold, they went forth into the prison to take them that they might slay them.
35686	1352	23	And it came to pass that Nephi and Lehi were encircled about as if by fire, even insomuch that they durst not lay their hands upon them for fear lest they should be burned. Nevertheless, Nephi and Lehi were not burned; and they were as standing in the midst of fire and were not burned.
35687	1352	24	And when they saw that they were encircled about with a pillar of fire, and that it burned them not, their hearts did take courage.
35688	1352	25	For they saw that the Lamanites durst not lay their hands upon them; neither durst they come near unto them, but stood as if they were struck dumb with amazement.
35689	1352	26	And it came to pass that Nephi and Lehi did stand forth and began to speak unto them, saying: Fear not, for behold, it is God that has shown unto you this marvelous thing, in the which is shown unto you that ye cannot lay your hands on us to slay us.
35690	1352	27	And behold, when they had said these words, the earth shook exceedingly, and the walls of the prison did shake as if they were about to tumble to the earth; but behold, they did not fall. And behold, they that were in the prison were Lamanites and Nephites who were dissenters.
35691	1352	28	And it came to pass that they were overshadowed with a cloud of darkness, and an awful solemn fear came upon them.
35692	1352	29	And it came to pass that there came a voice as if it were above the cloud of darkness, saying: Repent ye, repent ye, and seek no more to destroy my servants whom I have sent unto you to declare good tidings.
35693	1352	30	And it came to pass when they heard this voice, and beheld that it was not a voice of thunder, neither was it a voice of a great tumultuous noise, but behold, it was a still voice of perfect mildness, as if it had been a whisper, and it did pierce even to the very soul--
35694	1352	31	And notwithstanding the mildness of the voice, behold the earth shook exceedingly, and the walls of the prison trembled again, as if it were about to tumble to the earth; and behold the cloud of darkness, which had overshadowed them, did not disperse--
35695	1352	32	And behold the voice came again, saying: Repent ye, repent ye, for the kingdom of heaven is at hand; and seek no more to destroy my servants. And it came to pass that the earth shook again, and the walls trembled.
35696	1352	33	And also again the third time the voice came, and did speak unto them marvelous words which cannot be uttered by man; and the walls did tremble again, and the earth shook as if it were about to divide asunder.
35697	1352	34	And it came to pass that the Lamanites could not flee because of the cloud of darkness which did overshadow them; yea, and also they were immovable because of the fear which did come upon them.
35698	1352	35	Now there was one among them who was a Nephite by birth, who had once belonged to the church of God but had dissented from them.
35699	1352	36	And it came to pass that he turned him about, and behold, he saw through the cloud of darkness the faces of Nephi and Lehi; and behold, they did shine exceedingly, even as the faces of angels. And he beheld that they did lift their eyes to heaven; and they were in the attitude as if talking or lifting their voices to some being whom they beheld.
35700	1352	37	And it came to pass that this man did cry unto the multitude, that they might turn and look. And behold, there was power given unto them that they did turn and look; and they did behold the faces of Nephi and Lehi.
35701	1352	38	And they said unto the man: Behold, what do all these things mean, and who is it with whom these men do converse?
35702	1352	39	Now the man's name was Aminadab. And Aminadab said unto them: They do converse with the angels of God.
35703	1352	40	And it came to pass that the Lamanites said unto him: What shall we do, that this cloud of darkness may be removed from overshadowing us?
35704	1352	41	And Aminadab said unto them: You must repent, and cry unto the voice, even until ye shall have faith in Christ, who was taught unto you by Alma, and Amulek, and Zeezrom; and when ye shall do this, the cloud of darkness shall be removed from overshadowing you.
35705	1352	42	And it came to pass that they all did begin to cry unto the voice of him who had shaken the earth; yea, they did cry even until the cloud of darkness was dispersed.
35706	1352	43	And it came to pass that when they cast their eyes about, and saw that the cloud of darkness was dispersed from overshadowing them, behold, they saw that they were encircled about, yea every soul, by a pillar of fire.
35707	1352	44	And Nephi and Lehi were in the midst of them; yea, they were encircled about; yea, they were as if in the midst of a flaming fire, yet it did harm them not, neither did it take hold upon the walls of the prison; and they were filled with that joy which is unspeakable and full of glory.
35708	1352	45	And behold, the Holy Spirit of God did come down from heaven, and did enter into their hearts, and they were filled as if with fire, and they could speak forth marvelous words.
35709	1352	46	And it came to pass that there came a voice unto them, yea, a pleasant voice, as if it were a whisper, saying:
35710	1352	47	Peace, peace be unto you, because of your faith in my Well Beloved, who was from the foundation of the world.
35711	1352	48	And now, when they heard this they cast up their eyes as if to behold from whence the voice came; and behold, they saw the heavens open; and angels came down out of heaven and ministered unto them.
35712	1352	49	And there were about three hundred souls who saw and heard these things; and they were bidden to go forth and marvel not, neither should they doubt.
35713	1352	50	And it came to pass that they did go forth, and did minister unto the people, declaring throughout all the regions round about all the things which they had heard and seen, insomuch that the more part of the Lamanites were convinced of them, because of the greatness of the evidences which they had received.
35714	1352	51	And as many as were convinced did lay down their weapons of war, and also their hatred and the tradition of their fathers.
35715	1352	52	And it came to pass that they did yield up unto the Nephites the lands of their possession.
35716	1353	1	And it came to pass that when the sixty and second year of the reign of the judges had ended, all these things had happened and the Lamanites had become, the more part of them, a righteous people, insomuch that their righteousness did exceed that of the Nephites, because of their firmness and their steadiness in the faith.
35717	1353	2	For behold, there were many of the Nephites who had become hardened and impenitent and grossly wicked, insomuch that they did reject the word of God and all the preaching and prophesying which did come among them.
35718	1353	3	Nevertheless, the people of the church did have great joy because of the conversion of the Lamanites, yea, because of the church of God, which had been established among them. And they did fellowship one with another, and did rejoice one with another, and did have great joy.
35719	1353	4	And it came to pass that many of the Lamanites did come down into the land of Zarahemla, and did declare unto the people of the Nephites the manner of their conversion, and did exhort them to faith and repentance.
35720	1353	5	Yea, and many did preach with exceedingly great power and authority, unto the bringing down many of them into the depths of humility, to be the humble followers of God and the Lamb.
35721	1353	6	And it came to pass that many of the Lamanites did go into the land northward; and also Nephi and Lehi went into the land northward, to preach unto the people. And thus ended the sixty and third year.
35722	1353	7	And behold, there was peace in all the land, insomuch that the Nephites did go into whatsoever part of the land they would, whether among the Nephites or the Lamanites.
35723	1353	8	And it came to pass that the Lamanites did also go whithersoever they would, whether it were among the Lamanites or among the Nephites; and thus they did have free intercourse one with another, to buy and to sell, and to get gain, according to their desire.
35724	1353	9	And it came to pass that they became exceedingly rich, both the Lamanites and the Nephites; and they did have an exceeding plenty of gold, and of silver, and of all manner of precious metals, both in the land south and in the land north.
35725	1353	10	Now the land south was called Lehi and the land north was called Mulek, which was after the son of Zedekiah; for the Lord did bring Mulek into the land north, and Lehi into the land south.
35726	1353	11	And behold, there was all manner of gold in both these lands, and of silver, and of precious ore of every kind; and there were also curious workmen, who did work all kinds of ore and did refine it; and thus they did become rich.
35727	1353	12	They did raise grain in abundance, both in the north and in the south; and they did flourish exceedingly, both in the north and in the south. And they did multiply and wax exceedingly strong in the land. And they did raise many flocks and herds, yea, many fatlings.
35728	1353	13	Behold their women did toil and spin, and did make all manner of cloth, of fine-twined linen and cloth of every kind, to clothe their nakedness. And thus the sixty and fourth year did pass away in peace.
35729	1353	14	And in the sixty and fifth year they did also have great joy and peace, yea, much preaching and many prophecies concerning that which was to come. And thus passed away the sixty and fifth year.
35730	1353	15	And it came to pass that in the sixty and sixth year of the reign of the judges, behold, Cezoram was murdered by an unknown hand as he sat upon the judgment-seat. And it came to pass that in the same year, that his son, who had been appointed by the people in his stead, was also murdered. And thus ended the sixty and sixth year.
35731	1353	16	And in the commencement of the sixty and seventh year the people began to grow exceedingly wicked again.
35732	1353	17	For behold, the Lord had blessed them so long with the riches of the world that they had not been stirred up to anger, to wars, nor to bloodshed; therefore they began to set their hearts upon their riches; yea, they began to seek to get gain that they might be lifted up one above another; therefore they began to commit secret murders, and to rob and to plunder, that they might get gain.
35733	1353	18	And now behold, those murderers and plunderers were a band who had been formed by Kishkumen and Gadianton. And now it had come to pass that there were many, even among the Nephites, of Gadianton's band. But behold, they were more numerous among the more wicked part of the Lamanites. And they were called Gadianton's robbers and murderers.
35734	1353	19	And it was they who did murder the chief judge Cezoram, and his son, while in the judgment-seat; and behold, they were not found.
35735	1353	20	And now it came to pass that when the Lamanites found that there were robbers among them they were exceedingly sorrowful; and they did use every means in their power to destroy them off the face of the earth.
35736	1353	21	But behold, Satan did stir up the hearts of the more part of the Nephites, insomuch that they did unite with those bands of robbers, and did enter into their covenants and their oaths, that they would protect and preserve one another in whatsoever difficult circumstances they should be placed, that they should not suffer for their murders, and their plunderings, and their stealings.
35737	1353	22	And it came to pass that they did have their signs, yea, their secret signs, and their secret words; and this that they might distinguish a brother who had entered into the covenant, that whatsoever wickedness his brother should do he should not be injured by his brother, nor by those who did belong to his band, who had taken this covenant.
35738	1353	23	And thus they might murder, and plunder, and steal, and commit whoredoms and all manner of wickedness, contrary to the laws of their country and also the laws of their God.
35739	1353	24	And whosoever of those who belonged to their band should reveal unto the world of their wickedness and their abominations, should be tried, not according to the laws of their country, but according to the laws of their wickedness, which had been given by Gadianton and Kishkumen.
35740	1353	25	Now behold, it is these secret oaths and covenants which Alma commanded his son should not go forth unto the world, lest they should be a means of bringing down the people unto destruction.
35741	1353	26	Now behold, those secret oaths and covenants did not come forth unto Gadianton from the records which were delivered unto Helaman; but behold, they were put into the heart of Gadianton by that same being who did entice our first parents to partake of the forbidden fruit--
35742	1353	27	Yea, that same being who did plot with Cain, that if he would murder his brother Abel it should not be known unto the world. And he did plot with Cain and his followers from that time forth.
35743	1353	28	And also it is that same being who put it into the hearts of the people to build a tower sufficiently high that they might get to heaven. And it was that same being who led on the people who came from that tower into this land; who spread the works of darkness and abominations over all the face of the land, until he dragged the people down to an entire destruction, and to an everlasting hell.
35744	1353	29	Yea, it is that same being who put it into the heart of Gadianton to still carry on the work of darkness, and of secret murder; and he has brought it forth from the beginning of man even down to this time.
35745	1353	30	And behold, it is he who is the author of all sin. And behold, he doth carry on his works of darkness and secret murder, and doth hand down their plots, and their oaths, and their covenants, and their plans of awful wickedness, from generation to generation according as he can get hold upon the hearts of the children of men.
35746	1353	31	And now behold, he had got great hold upon the hearts of the Nephites; yea, insomuch that they had become exceedingly wicked; yea, the more part of them had turned out of the way of righteousness, and did trample under their feet the commandments of God, and did turn unto their own ways, and did build up unto themselves idols of their gold and their silver.
35747	1353	32	And it came to pass that all these iniquities did come unto them in the space of not many years, insomuch that a more part of it had come unto them in the sixty and seventh year of the reign of the judges over the people of Nephi.
35748	1353	33	And they did grow in their iniquities in the sixty and eighth year also, to the great sorrow and lamentation of the righteous.
35749	1353	34	And thus we see that the Nephites did begin to dwindle in unbelief, and grow in wickedness and abominations, while the Lamanites began to grow exceedingly in the knowledge of their God; yea, they did begin to keep his statutes and commandments, and to walk in truth and uprightness before him.
35750	1353	35	And thus we see that the Spirit of the Lord began to withdraw from the Nephites, because of the wickedness and the hardness of their hearts.
35751	1353	36	And thus we see that the Lord began to pour out his Spirit upon the Lamanites, because of their easiness and willingness to believe in his words.
35752	1353	37	And it came to pass that the Lamanites did hunt the band of robbers of Gadianton; and they did preach the word of God among the more wicked part of them, insomuch that this band of robbers was utterly destroyed from among the Lamanites.
35753	1353	38	And it came to pass on the other hand, that the Nephites did build them up and support them, beginning at the more wicked part of them, until they had overspread all the land of the Nephites, and had seduced the more part of the righteous until they had come down to believe in their works and partake of their spoils, and to join with them in their secret murders and combinations.
35754	1353	39	And thus they did obtain the sole management of the government, insomuch that they did trample under their feet and smite and rend and turn their backs upon the poor and the meek, and the humble followers of God.
35755	1353	40	And thus we see that they were in an awful state, and ripening for an everlasting destruction.
35756	1353	41	And it came to pass that thus ended the sixty and eighth year of the reign of the judges over the people of Nephi.
35757	1354	1	Behold, now it came to pass in the sixty and ninth year of the reign of the judges over the people of the Nephites, that Nephi, the son of Helaman, returned to the land of Zarahemla from the land northward.
35758	1354	2	For he had been forth among the people who were in the land northward and did preach the word of God unto them, and did prophesy many things unto them;
35759	1354	3	And they did reject all his words, insomuch that he could not stay among them, but returned again unto the land of his nativity.
35760	1354	4	And seeing the people in a state of such awful wickedness, and those Gadianton robbers filling the judgment-seats--having usurped the power and authority of the land; laying aside the commandments of God, and not in the least aright before him; doing no justice unto the children of men;
35761	1354	5	Condemning the righteous because of their righteousness; letting the guilty and the wicked go unpunished because of their money; and moreover to be held in office at the head of government, to rule and do according to their wills, that they might get gain and glory of the world, and, moreover, that they might the more easily commit adultery, and steal, and kill, and do according to their own wills--
35762	1354	6	Now this great iniquity had come upon the Nephites, in the space of not many years; and when Nephi saw it, his heart was swollen with sorrow within his breast; and he did exclaim in the agony of his soul:
35763	1354	7	Oh, that I could have had my days in the days when my father Nephi first came out of the land of Jerusalem, that I could have joyed with him in the promised land; then were his people easy to be entreated, firm to keep the commandments of God, and slow to be led to do iniquity; and they were quick to hearken unto the words of the Lord--
35764	1354	8	Yea, if my days could have been in those days, then would my soul have had joy in the righteousness of my brethren.
35765	1354	9	But behold, I am consigned that these are my days, and that my soul shall be filled with sorrow because of this the wickedness of my brethren.
35766	1354	10	And behold, now it came to pass that it was upon a tower, which was in the garden of Nephi, which was by the highway which led to the chief market, which was in the city of Zarahemla; therefore, Nephi had bowed himself upon the tower which was in his garden, which tower was also near unto the garden gate by which led the highway.
35767	1354	11	And it came to pass that there were certain men passing by and saw Nephi as he was pouring out his soul unto God upon the tower; and they ran and told the people what they had seen, and the people came together in multitudes that they might know the cause of so great mourning for the wickedness of the people.
35768	1354	12	And now, when Nephi arose he beheld the multitudes of people who had gathered together.
35769	1354	13	And it came to pass that he opened his mouth and said unto them: Behold, why have ye gathered yourselves together? That I may tell you of your iniquities?
35770	1354	14	Yea, because I have got upon my tower that I might pour out my soul unto my God, because of the exceeding sorrow of my heart, which is because of your iniquities!
35771	1354	15	And because of my mourning and lamentation ye have gathered yourselves together, and do marvel; yea, and ye have great need to marvel; yea, ye ought to marvel because ye are given away that the devil has got so great hold upon your hearts.
35772	1354	16	Yea, how could you have given way to the enticing of him who is seeking to hurl away your souls down to everlasting misery and endless wo?
35773	1354	17	O repent ye, repent ye! Why will ye die? Turn ye, turn ye unto the Lord your God. Why has he forsaken you?
35774	1354	18	It is because you have hardened your hearts; yea, ye will not hearken unto the voice of the good shepherd; yea, ye have provoked him to anger against you.
35775	1354	19	And behold, instead of gathering you, except ye will repent, behold, he shall scatter you forth that ye shall become meat for dogs and wild beasts.
35776	1354	20	O, how could you have forgotten your God in the very day that he has delivered you?
35777	1354	21	But behold, it is to get gain, to be praised of men, yea, and that ye might get gold and silver. And ye have set your hearts upon the riches and the vain things of this world, for the which ye do murder, and plunder, and steal, and bear false witness against your neighbor, and do all manner of iniquity.
35778	1354	22	And for this cause wo shall come unto you except ye shall repent. For if ye will not repent, behold, this great city, and also all those great cities which are round about, which are in the land of our possession, shall be taken away that ye shall have no place in them; for behold, the Lord will not grant unto you strength, as he has hitherto done, to withstand against your enemies.
35779	1354	23	For behold, thus saith the Lord: I will not show unto the wicked of my strength, to one more than the other, save it be unto those who repent of their sins, and hearken unto my words. Now therefore, I would that ye should behold, my brethren, that it shall be better for the Lamanites than for you except ye shall repent.
35780	1354	24	For behold, they are more righteous than you, for they have not sinned against that great knowledge which ye have received; therefore the Lord will be merciful unto them; yea, he will lengthen out their days and increase their seed, even when thou shalt be utterly destroyed except thou shalt repent.
35781	1354	25	Yea, wo be unto you because of that great abomination which has come among you; and ye have united yourselves unto it, yea, to that secret band which was established by Gadianton!
35782	1354	26	Yea, wo shall come unto you because of that pride which ye have suffered to enter your hearts, which has lifted you up beyond that which is good because of your exceedingly great riches!
35783	1354	27	Yea, wo be unto you because of your wickedness and abominations!
35784	1354	28	And except ye repent ye shall perish; yea, even your lands shall be taken from you, and ye shall be destroyed from off the face of the earth.
35785	1354	29	Behold now, I do not say that these things shall be, of myself, because it is not of myself that I know these things; but behold, I know that these things are true because the Lord God has made them known unto me, therefore I testify that they shall be.
35786	1355	1	And now it came to pass that when Nephi had said these words, behold, there were men who were judges, who also belonged to the secret band of Gadianton, and they were angry, and they cried out against him, saying unto the people: Why do ye not seize upon this man and bring him forth, that he may be condemned according to the crime which he has done?
35787	1355	2	Why seest thou this man, and hearest him revile against this people and against our law?
35788	1355	3	For behold, Nephi had spoken unto them concerning the corruptness of their law; yea, many things did Nephi speak which cannot be written; and nothing did he speak which was contrary to the commandments of God.
35789	1355	4	And those judges were angry with him because he spake plainly unto them concerning their secret works of darkness; nevertheless, they durst not lay their own hands upon him, for they feared the people lest they should cry out against them.
35790	1355	5	Therefore they did cry unto the people, saying: Why do you suffer this man to revile against us? For behold he doth condemn all this people, even unto destruction; yea, and also that these our great cities shall be taken from us, that we shall have no place in them.
35791	1355	6	And now we know that this is impossible, for behold, we are powerful, and our cities great, therefore our enemies can have no power over us.
35792	1355	7	And it came to pass that thus they did stir up the people to anger against Nephi, and raised contentions among them; for there were some who did cry out: Let this man alone, for he is a good man, and those things which he saith will surely come to pass except we repent;
35793	1355	8	Yea, behold, all the judgments will come upon us which he has testified unto us; for we know that he has testified aright unto us concerning our iniquities. And behold they are many, and he knoweth as well all things which shall befall us as he knoweth of our iniquities;
35794	1355	9	Yea, and behold, if he had not been a prophet he could not have testified concerning those things.
35795	1355	10	And it came to pass that those people who sought to destroy Nephi were compelled because of their fear, that they did not lay their hands on him; therefore he began again to speak unto them, seeing that he had gained favor in the eyes of some, insomuch that the remainder of them did fear.
35796	1355	11	Therefore he was constrained to speak more unto them saying: Behold, my brethren, have ye not read that God gave power unto one man, even Moses, to smite upon the waters of the Red Sea, and they parted hither and thither, insomuch that the Israelites, who were our fathers, came through upon dry ground, and the waters closed upon the armies of the Egyptians and swallowed them up?
35797	1355	12	And now behold, if God gave unto this man such power, then why should ye dispute among yourselves, and say that he hath given unto me no power whereby I may know concerning the judgments that shall come upon you except ye repent?
35798	1355	13	But, behold, ye not only deny my words, but ye also deny all the words which have been spoken by our fathers, and also the words which were spoken by this man, Moses, who had such great power given unto him, yea, the words which he hath spoken concerning the coming of the Messiah.
35799	1355	14	Yea, did he not bear record that the Son of God should come? And as he lifted up the brazen serpent in the wilderness, even so shall he be lifted up who should come.
35800	1355	15	And as many as should look upon that serpent should live, even so as many as should look upon the Son of God with faith, having a contrite spirit, might live, even unto that life which is eternal.
35801	1355	16	And now behold, Moses did not only testify of these things, but also all the holy prophets, from his days even to the days of Abraham.
35802	1355	17	Yea, and behold, Abraham saw of his coming, and was filled with gladness and did rejoice.
35803	1355	18	Yea, and behold I say unto you, that Abraham not only knew of these things, but there were many before the days of Abraham who were called by the order of God; yea, even after the order of his Son; and this that it should be shown unto the people, a great many thousand years before his coming, that even redemption should come unto them.
35804	1355	19	And now I would that ye should know, that even since the days of Abraham there have been many prophets that have testified these things; yea, behold, the prophet Zenos did testify boldly; for the which he was slain.
35805	1355	20	And behold, also Zenock, and also Ezias, and also Isaiah, and Jeremiah, (Jeremiah being that same prophet who testified of the destruction of Jerusalem) and now we know that Jerusalem was destroyed according to the words of Jeremiah. O then why not the Son of God come, according to his prophecy?
35806	1355	21	And now will you dispute that Jerusalem was destroyed? Will ye say that the sons of Zedekiah were not slain, all except it were Mulek? Yea, and do ye not behold that the seed of Zedekiah are with us, and they were driven out of the land of Jerusalem? But behold, this is not all--
35807	1355	22	Our father Lehi was driven out of Jerusalem because he testified of these things. Nephi also testified of these things, and also almost all of our fathers, even down to this time; yea, they have testified of the coming of Christ, and have looked forward, and have rejoiced in his day which is to come.
35808	1355	23	And behold, he is God, and he is with them, and he did manifest himself unto them, that they were redeemed by him; and they gave unto him glory, because of that which is to come.
35809	1355	24	And now, seeing ye know these things and cannot deny them except ye shall lie, therefore in this ye have sinned, for ye have rejected all these things, notwithstanding so many evidences which ye have received; yea, even ye have received all things, both things in heaven, and all things which are in the earth, as a witness that they are true.
35810	1355	25	But behold, ye have rejected the truth, and rebelled against your holy God; and even at this time, instead of laying up for yourselves treasures in heaven, where nothing doth corrupt, and where nothing can come which is unclean, ye are heaping up for yourselves wrath against the day of judgment.
35811	1355	26	Yea, even at this time ye are ripening, because of your murders and your fornication and wickedness, for everlasting destruction; yea, and except ye repent it will come unto you soon.
35812	1355	27	Yea, behold it is now even at your doors; yea, go ye in unto the judgment-seat, and search; and behold, your judge is murdered, and he lieth in his blood; and he hath been murdered by his brother, who seeketh to sit in the judgment-seat.
35813	1355	28	And behold, they both belong to your secret band, whose author is Gadianton and the evil one who seeketh to destroy the souls of men.
35814	1356	1	Behold, now it came to pass that when Nephi had spoken these words, certain men who were among them ran to the judgment-seat; yea, even there were five who went, and they said among themselves, as they went:
35815	1356	2	Behold, now we will know of a surety whether this man be a prophet and God hath commanded him to prophesy such marvelous things unto us. Behold, we do not believe that he hath; yea, we do not believe that he is a prophet; nevertheless, if this thing which he has said concerning the chief judge be true, that he be dead, then will we believe that the other words which he has spoken are true.
35816	1356	3	And it came to pass that they ran in their might, and came in unto the judgment-seat; and behold, the chief judge had fallen to the earth, and did lie in his blood.
35817	1356	4	And now behold, when they saw this they were astonished exceedingly, insomuch that they fell to the earth; for they had not believed the words which Nephi had spoken concerning the chief judge.
35818	1356	5	But now, when they saw they believed, and fear came upon them lest all the judgments which Nephi had spoken should come upon the people; therefore they did quake, and had fallen to the earth.
35819	1356	6	Now, immediately when the judge had been murdered--he being stabbed by his brother by a garb of secrecy, and he fled, and the servants ran and told the people, raising the cry of murder among them;
35820	1356	7	And behold the people did gather themselves together unto the place of the judgment-seat--and behold, to their astonishment they saw those five men who had fallen to the earth.
35821	1356	8	And now behold, the people knew nothing concerning the multitude who had gathered together at the garden of Nephi; therefore they said among themselves: These men are they who have murdered the judge, and God has smitten them that they could not flee from us.
35822	1356	9	And it came to pass that they laid hold on them, and bound them and cast them into prison. And there was a proclamation sent abroad that the judge was slain, and that the murderers had been taken and were cast into prison.
35823	1356	10	And it came to pass that on the morrow the people did assemble themselves together to mourn and to fast, at the burial of the great chief judge who had been slain.
35824	1356	11	And thus also those judges who were at the garden of Nephi, and heard his words, were also gathered together at the burial.
35825	1356	12	And it came to pass that they inquired among the people, saying: Where are the five who were sent to inquire concerning the chief judge whether he was dead? And they answered and said: Concerning this five whom ye say ye have sent, we know not; but there are five who are the murderers, whom we have cast into prison.
35826	1356	13	And it came to pass that the judges desired that they should be brought; and they were brought, and behold they were the five who were sent; and behold the judges inquired of them to know concerning the matter, and they told them all that they had done, saying:
35827	1356	14	We ran and came to the place of the judgment-seat, and when we saw all things even as Nephi had testified, we were astonished insomuch that we fell to the earth; and when we were recovered from our astonishment, behold they cast us into prison.
35828	1356	15	Now, as for the murder of this man, we know not who has done it; and only this much we know, we ran and came according as ye desired, and behold he was dead, according to the words of Nephi.
35829	1356	16	And now it came to pass that the judges did expound the matter unto the people, and did cry out against Nephi, saying: Behold, we know that this Nephi must have agreed with some one to slay the judge, and then he might declare it unto us, that he might convert us unto his faith, that he might raise himself to be a great man, chosen of God, and a prophet.
35830	1356	17	And now behold, we will detect this man, and he shall confess his fault and make known unto us the true murderer of this judge.
35831	1356	18	And it came to pass that the five were liberated on the day of the burial. Nevertheless, they did rebuke the judges in the words which they had spoken against Nephi, and did contend with them one by one, insomuch that they did confound them.
35832	1356	19	Nevertheless, they caused that Nephi should be taken and bound and brought before the multitude, and they began to question him in divers ways that they might cross him, that they might accuse him to death--
35833	1356	20	Saying unto him: Thou art confederate; who is this man that hath done this murder? Now tell us, and acknowledge thy fault; saying, Behold here is money; and also we will grant unto thee thy life if thou wilt tell us, and acknowledge the agreement which thou hast made with him.
35834	1356	21	But Nephi said unto them: O ye fools, ye uncircumcised of heart, ye blind, and ye stiffnecked people, do ye know how long the Lord your God will suffer you that ye shall go on in this your way of sin?
35835	1356	22	O ye ought to begin to howl and mourn, because of the great destruction which at this time doth await you, except ye shall repent.
35836	1356	23	Behold ye say that I have agreed with a man that he should murder Seezoram, our chief judge. But behold, I say unto you, that this is because I have testified unto you that ye might know concerning this thing; yea, even for a witness unto you, that I did know of the wickedness and abominations which are among you.
35837	1356	24	And because I have done this, ye say that I have agreed with a man that he should do this thing; yea, because I showed unto you this sign ye are angry with me, and seek to destroy my life.
35838	1356	25	And now behold, I will show unto you another sign, and see if ye will in this thing seek to destroy me.
35839	1356	26	Behold I say unto you: Go to the house of Seantum, who is the brother of Seezoram, and say unto him--
35840	1356	27	Has Nephi, the pretended prophet, who doth prophesy so much evil concerning this people, agreed with thee, in the which ye have murdered Seezoram, who is your brother?
35841	1356	28	And behold, he shall say unto you, Nay.
35842	1356	29	And ye shall say unto him: Have ye murdered your brother?
35843	1356	30	And he shall stand with fear, and wist not what to say. And behold, he shall deny unto you; and he shall make as if he were astonished; nevertheless, he shall declare unto you that he is innocent.
35844	1356	31	But behold, ye shall examine him, and ye shall find blood upon the skirts of his cloak.
35845	1356	32	And when ye have seen this, ye shall say: From whence cometh this blood? Do we not know that it is the blood of your brother?
35846	1356	33	And then shall he tremble, and shall look pale, even as if death had come upon him.
35847	1356	34	And then shall ye say: Because of this fear and this paleness which has come upon your face, behold, we know that thou art guilty.
35848	1356	35	And then shall greater fear come upon him; and then shall he confess unto you, and deny no more that he has done this murder.
35849	1356	36	And then shall he say unto you, that I, Nephi, know nothing concerning the matter save it were given unto me by the power of God. And then shall ye know that I am an honest man, and that I am sent unto you from God.
35850	1356	37	And it came to pass that they went and did, even according as Nephi had said unto them. And behold, the words which he had said were true; for according to the words he did deny; and also according to the words he did confess.
35851	1356	38	And he was brought to prove that he himself was the very murderer, insomuch that the five were set at liberty, and also was Nephi.
35852	1356	39	And there were some of the Nephites who believed on the words of Nephi; and there were some also, who believed because of the testimony of the five, for they had been converted while they were in prison.
35853	1356	40	And now there were some among the people, who said that Nephi was a prophet.
35854	1356	41	And there were others who said: Behold, he is a god, for except he was a god he could not know of all things. For behold, he has told us the thoughts of our hearts, and also has told us things; and even he has brought unto our knowledge the true murderer of our chief judge.
35855	1357	1	And it came to pass that there arose a division among the people, insomuch that they divided hither and thither and went their ways, leaving Nephi alone, as he was standing in the midst of them.
35856	1357	2	And it came to pass that Nephi went his way towards his own house, pondering upon the things which the Lord had shown unto him.
35857	1357	3	And it came to pass as he was thus pondering--being much cast down because of the wickedness of the people of the Nephites, their secret works of darkness, and their murderings, and their plunderings, and all manner of iniquities--and it came to pass as he was thus pondering in his heart, behold, a voice came unto him saying:
35858	1357	4	Blessed art thou, Nephi, for those things which thou hast done; for I have beheld how thou hast with unwearyingness declared the word, which I have given unto thee, unto this people. And thou hast not feared them, and hast not sought thine own life, but hast sought my will, and to keep my commandments.
35859	1357	5	And now, because thou hast done this with such unwearyingness, behold, I will bless thee forever; and I will make thee mighty in word and in deed, in faith and in works; yea, even that all things shall be done unto thee according to thy word, for thou shalt not ask that which is contrary to my will.
35860	1357	6	Behold, thou art Nephi, and I am God. Behold, I declare it unto thee in the presence of mine angels, that ye shall have power over this people, and shall smite the earth with famine, and with pestilence, and destruction, according to the wickedness of this people.
35861	1357	7	Behold, I give unto you power, that whatsoever ye shall seal on earth shall be sealed in heaven; and whatsoever ye shall loose on earth shall be loosed in heaven; and thus shall ye have power among this people.
35862	1357	8	And thus, if ye shall say unto this temple it shall be rent in twain, it shall be done.
35863	1357	9	And if ye shall say unto this mountain, Be thou cast down and become smooth, it shall be done.
35864	1357	10	And behold, if ye shall say that God shall smite this people, it shall come to pass.
35865	1357	11	And now behold, I command you, that ye shall go and declare unto this people, that thus saith the Lord God, who is the Almighty: Except ye repent ye shall be smitten, even unto destruction.
35866	1357	12	And behold, now it came to pass that when the Lord had spoken these words unto Nephi, he did stop and did not go unto his own house, but did return unto the multitudes who were scattered about upon the face of the land, and began to declare unto them the word of the Lord which had been spoken unto him, concerning their destruction if they did not repent.
35867	1357	13	Now behold, notwithstanding that great miracle which Nephi had done in telling them concerning the death of the chief judge, they did harden their hearts and did not hearken unto the words of the Lord.
35868	1357	14	Therefore Nephi did declare unto them the word of the Lord, saying: Except ye repent, thus saith the Lord, ye shall be smitten even unto destruction.
35869	1357	15	And it came to pass that when Nephi had declared unto them the word, behold, they did still harden their hearts and would not hearken unto his words; therefore they did revile against him, and did seek to lay their hands upon him that they might cast him into prison.
35870	1357	16	But behold, the power of God was with him, and they could not take him to cast him into prison, for he was taken by the Spirit and conveyed away out of the midst of them.
35871	1357	17	And it came to pass that thus he did go forth in the Spirit, from multitude to multitude, declaring the word of God, even until he had declared it unto them all, or sent it forth among all the people.
35872	1357	18	And it came to pass that they would not hearken unto his words; and there began to be contentions, insomuch that they were divided against themselves and began to slay one another with the sword.
35873	1357	19	And thus ended the seventy and first year of the reign of the judges over the people of Nephi.
35874	1358	1	And now it came to pass in the seventy and second year of the reign of the judges that the contentions did increase, insomuch that there were wars throughout all the land among all the people of Nephi.
35875	1358	2	And it was this secret band of robbers who did carry on this work of destruction and wickedness. And this war did last all that year; and in the seventy and third year it did also last.
35876	1358	3	And it came to pass that in this year Nephi did cry unto the Lord, saying:
35877	1358	4	O Lord, do not suffer that this people shall be destroyed by the sword; but O Lord, rather let there be a famine in the land, to stir them up in remembrance of the Lord their God, and perhaps they will repent and turn unto thee.
35878	1358	5	And so it was done, according to the words of Nephi. And there was a great famine upon the land, among all the people of Nephi. And thus in the seventy and fourth year the famine did continue, and the work of destruction did cease by the sword but became sore by famine.
35879	1358	6	And this work of destruction did also continue in the seventy and fifth year. For the earth was smitten that it was dry, and did not yield forth grain in the season of grain; and the whole earth was smitten, even among the Lamanites as well as among the Nephites, so that they were smitten that they did perish by thousands in the more wicked parts of the land.
35880	1358	7	And it came to pass that the people saw that they were about to perish by famine, and they began to remember the Lord their God; and they began to remember the words of Nephi.
35881	1358	8	And the people began to plead with their chief judges and their leaders, that they would say unto Nephi: Behold, we know that thou art a man of God, and therefore cry unto the Lord our God that he turn away from us this famine, lest all the words which thou hast spoken concerning our destruction be fulfilled.
35882	1358	9	And it came to pass that the judges did say unto Nephi, according to the words which had been desired. And it came to pass that when Nephi saw that the people had repented and did humble themselves in sackcloth, he cried again unto the Lord, saying:
35883	1358	10	O Lord, behold this people repenteth; and they have swept away the band of Gadianton from amongst them insomuch that they have become extinct, and they have concealed their secret plans in the earth.
35884	1358	11	Now, O Lord, because of this their humility wilt thou turn away thine anger, and let thine anger be appeased in the destruction of those wicked men whom thou hast already destroyed.
35885	1358	12	O Lord, wilt thou turn away thine anger, yea, thy fierce anger, and cause that this famine may cease in this land.
35886	1358	13	O Lord, wilt thou hearken unto me, and cause that it may be done according to my words, and send forth rain upon the face of the earth, that she may bring forth her fruit, and her grain in the season of grain.
35887	1358	14	O Lord, thou didst hearken unto my words when I said, Let there be a famine, that the pestilence of the sword might cease; and I know that thou wilt, even at this time, hearken unto my words, for thou saidst that: If this people repent I will spare them.
35888	1358	15	Yea, O Lord, and thou seest that they have repented, because of the famine and the pestilence and destruction which has come unto them.
35889	1358	16	And now, O Lord, wilt thou turn away thine anger, and try again if they will serve thee? And if so, O Lord, thou canst bless them according to thy words which thou hast said.
35890	1358	17	And it came to pass that in the seventy and sixth year the Lord did turn away his anger from the people, and caused that rain should fall upon the earth, insomuch that it did bring forth her fruit in the season of her fruit. And it came to pass that it did bring forth her grain in the season of her grain.
35891	1358	18	And behold, the people did rejoice and glorify God, and the whole face of the land was filled with rejoicing; and they did no more seek to destroy Nephi, but they did esteem him as a great prophet, and a man of God, having great power and authority given unto him from God.
35892	1358	19	And behold, Lehi, his brother, was not a whit behind him as to things pertaining to righteousness.
35893	1358	20	And thus it did come to pass that the people of Nephi began to prosper again in the land, and began to build up their waste places, and began to multiply and spread, even until they did cover the whole face of the land, both on the northward and on the southward, from the sea west to the sea east.
35894	1358	21	And it came to pass that the seventy and sixth year did end in peace. And the seventy and seventh year began in peace; and the church did spread throughout the face of all the land; and the more part of the people, both the Nephites and the Lamanites, did belong to the church; and they did have exceedingly great peace in the land; and thus ended the seventy and seventh year.
35895	1358	22	And also they had peace in the seventy and eighth year, save it were a few contentions concerning the points of doctrine which had been laid down by the prophets.
35896	1358	23	And in the seventy and ninth year there began to be much strife. But it came to pass that Nephi and Lehi, and many of their brethren who knew concerning the true points of doctrine, having many revelations daily, therefore they did preach unto the people, insomuch that they did put an end to their strife in that same year.
35897	1358	24	And it came to pass that in the eightieth year of the reign of the judges over the people of Nephi, there were a certain number of the dissenters from the people of Nephi, who had some years before gone over unto the Lamanites, and taken upon themselves the name of Lamanites, and also a certain number who were real descendants of the Lamanites, being stirred up to anger by them, or by those dissenters, therefore they commenced a war with their brethren.
35898	1358	25	And they did commit murder and plunder; and then they would retreat back into the mountains, and into the wilderness and secret places, hiding themselves that they could not be discovered, receiving daily an addition to their numbers, inasmuch as there were dissenters that went forth unto them.
35899	1358	26	And thus in time, yea, even in the space of not many years, they became an exceedingly great band of robbers; and they did search out all the secret plans of Gadianton; and thus they became robbers of Gadianton.
35900	1358	27	Now behold, these robbers did make great havoc, yea, even great destruction among the people of Nephi, and also among the people of the Lamanites.
35901	1358	28	And it came to pass that it was expedient that there should be a stop put to this work of destruction; therefore they sent an army of strong men into the wilderness and upon the mountains to search out this band of robbers, and to destroy them.
35902	1358	29	But behold, it came to pass that in that same year they were driven back even into their own lands. And thus ended the eightieth year of the reign of the judges over the people of Nephi.
35903	1358	30	And it came to pass in the commencement of the eighty and first year they did go forth again against this band of robbers, and did destroy many; and they were also visited with much destruction.
35904	1358	31	And they were again obliged to return out of the wilderness and out of the mountains unto their own lands, because of the exceeding greatness of the numbers of those robbers who infested the mountains and the wilderness.
35905	1358	32	And it came to pass that thus ended this year. And the robbers did still increase and wax strong, insomuch that they did defy the whole armies of the Nephites, and also of the Lamanites; and they did cause great fear to come unto the people upon all the face of the land.
35906	1358	33	Yea, for they did visit many parts of the land, and did do great destruction unto them; yea, did kill many, and did carry away others captive into the wilderness, yea, and more especially their women and their children.
35907	1358	34	Now this great evil, which came unto the people because of their iniquity, did stir them up again in remembrance of the Lord their God.
35908	1358	35	And thus ended the eighty and first year of the reign of the judges.
35909	1358	36	And in the eighty and second year they began again to forget the Lord their God. And in the eighty and third year they began to wax strong in iniquity. And in the eighty and fourth year they did not mend their ways.
35910	1358	37	And it came to pass in the eighty and fifth year they did wax stronger and stronger in their pride, and in their wickedness; and thus they were ripening again for destruction.
35911	1358	38	And thus ended the eighty and fifth year.
35912	1359	1	And thus we can behold how false, and also the unsteadiness of the hearts of the children of men; yea, we can see that the Lord in his great infinite goodness doth bless and prosper those who put their trust in him.
35913	1359	2	Yea, and we may see at the very time when he doth prosper his people, yea, in the increase of their fields, their flocks and their herds, and in gold, and in silver, and in all manner of precious things of every kind and art; sparing their lives, and delivering them out of the hands of their enemies; softening the hearts of their enemies that they should not declare wars against them; yea, and in fine, doing all things for the welfare and happiness of his people; yea, then is the time that they do harden their hearts, and do forget the Lord their God, and do trample under their feet the Holy One--yea, and this because of their ease, and their exceedingly great prosperity.
35914	1359	3	And thus we see that except the Lord doth chasten his people with many afflictions, yea, except he doth visit them with death and with terror, and with famine and with all manner of pestilence, they will not remember him.
35915	1359	4	O how foolish, and how vain, and how evil, and devilish, and how quick to do iniquity, and how slow to do good, are the children of men; yea, how quick to hearken unto the words of the evil one, and to set their hearts upon the vain things of the world!
35916	1359	5	Yea, how quick to be lifted up in pride; yea, how quick to boast, and do all manner of that which is iniquity; and how slow are they to remember the Lord their God, and to give ear unto his counsels, yea, how slow to walk in wisdom's paths!
35917	1359	6	Behold, they do not desire that the Lord their God, who hath created them, should rule and reign over them; notwithstanding his great goodness and his mercy towards them, they do set at naught his counsels, and they will not that he should be their guide.
35918	1359	7	O how great is the nothingness of the children of men; yea, even they are less than the dust of the earth.
35919	1359	8	For behold, the dust of the earth moveth hither and thither, to the dividing asunder, at the command of our great and everlasting God.
35920	1359	9	Yea, behold at his voice do the hills and the mountains tremble and quake.
35921	1359	10	And by the power of his voice they are broken up, and become smooth, yea, even like unto a valley.
35922	1359	11	Yea, by the power of his voice doth the whole earth shake;
35923	1359	12	Yea, by the power of his voice, do the foundations rock, even to the very center.
35924	1359	13	Yea, and if he say unto the earth--Move--it is moved.
35925	1359	14	Yea, if he say unto the earth--Thou shalt go back, that it lengthen out the day for many hours--it is done;
35926	1359	15	And thus, according to his word the earth goeth back, and it appeareth unto man that the sun standeth still; yea, and behold, this is so; for surely it is the earth that moveth and not the sun.
35927	1359	16	And behold, also, if he say unto the waters of the great deep--Be thou dried up--it is done.
35928	1359	17	Behold, if he say unto this mountain--Be thou raised up, and come over and fall upon that city, that it be buried up--behold it is done.
35929	1359	18	And behold, if a man hide up a treasure in the earth, and the Lord shall say--Let it be accursed, because of the iniquity of him who hath hid it up--behold, it shall be accursed.
35930	1359	19	And if the Lord shall say--Be thou accursed, that no man shall find thee from this time henceforth and forever--behold, no man getteth it henceforth and forever.
35931	1359	20	And behold, if the Lord shall say unto a man--Because of thine iniquities, thou shalt be accursed forever--it shall be done.
35932	1359	21	And if the Lord shall say--Because of thine iniquities thou shalt be cut off from my presence--he will cause that it shall be so.
35933	1359	22	And wo unto him to whom he shall say this, for it shall be unto him that will do iniquity, and he cannot be saved; therefore, for this cause, that men might be saved, hath repentance been declared.
35934	1359	23	Therefore, blessed are they who will repent and hearken unto the voice of the Lord their God; for these are they that shall be saved.
35935	1359	24	And may God grant, in his great fulness, that men might be brought unto repentance and good works, that they might be restored unto grace for grace, according to their works.
35936	1359	25	And I would that all men might be saved. But we read that in the great and last day there are some who shall be cast out, yea, who shall be cast off from the presence of the Lord;
35937	1359	26	Yea, who shall be consigned to a state of endless misery, fulfilling the words which say: They that have done good shall have everlasting life; and they that have done evil shall have everlasting damnation. And thus it is. Amen.
35938	1360	1	And now it came to pass in the eighty and sixth year, the Nephites did still remain in wickedness, yea, in great wickedness, while the Lamanites did observe strictly to keep the commandments of God, according to the law of Moses.
35939	1360	2	And it came to pass that in this year there was one Samuel, a Lamanite, came into the land of Zarahemla, and began to preach unto the people. And it came to pass that he did preach, many days, repentance unto the people, and they did cast him out, and he was about to return to his own land.
35940	1360	3	But behold, the voice of the Lord came unto him, that he should return again, and prophesy unto the people whatsoever things should come into his heart.
35941	1360	4	And it came to pass that they would not suffer that he should enter into the city; therefore he went and got upon the wall thereof, and stretched forth his hand and cried with a loud voice, and prophesied unto the people whatsoever things the Lord put into his heart.
35942	1360	5	And he said unto them: Behold, I, Samuel, a Lamanite, do speak the words of the Lord which he doth put into my heart; and behold he hath put it into my heart to say unto this people that the sword of justice hangeth over this people; and four hundred years pass not away save the sword of justice falleth upon this people.
35943	1360	6	Yea, heavy destruction awaiteth this people, and it surely cometh unto this people, and nothing can save this people save it be repentance and faith on the Lord Jesus Christ, who surely shall come into the world, and shall suffer many things and shall be slain for his people.
35944	1360	7	And behold, an angel of the Lord hath declared it unto me, and he did bring glad tidings to my soul. And behold, I was sent unto you to declare it unto you also, that ye might have glad tidings; but behold ye would not receive me.
35945	1360	8	Therefore, thus saith the Lord: Because of the hardness of the hearts of the people of the Nephites, except they repent I will take away my word from them, and I will withdraw my Spirit from them, and I will suffer them no longer, and I will turn the hearts of their brethren against them.
35946	1360	9	And four hundred years shall not pass away before I will cause that they shall be smitten; yea, I will visit them with the sword and with famine and with pestilence.
35947	1360	10	Yea, I will visit them in my fierce anger, and there shall be those of the fourth generation who shall live, of your enemies, to behold your utter destruction; and this shall surely come except ye repent, saith the Lord; and those of the fourth generation shall visit your destruction.
35948	1360	11	But if ye will repent and return unto the Lord your God I will turn away mine anger, saith the Lord; yea, thus saith the Lord, blessed are they who will repent and turn unto me, but wo unto him that repenteth not.
35949	1360	12	Yea, wo unto this great city of Zarahemla; for behold, it is because of those who are righteous that it is saved; yea, wo unto this great city, for I perceive, saith the Lord, that there are many, yea, even the more part of this great city, that will harden their hearts against me, saith the Lord.
35950	1360	13	But blessed are they who will repent, for them will I spare. But behold, if it were not for the righteous who are in this great city, behold, I would cause that fire should come down out of heaven and destroy it.
35951	1360	14	But behold, it is for the righteous' sake that it is spared. But behold, the time cometh, saith the Lord, that when ye shall cast out the righteous from among you, then shall ye be ripe for destruction; yea, wo be unto this great city, because of the wickedness and abominations which are in her.
35952	1360	15	Yea, and wo be unto the city of Gideon, for the wickedness and abominations which are in her.
35953	1360	16	Yea, and wo be unto all the cities which are in the land round about, which are possessed by the Nephites, because of the wickedness and abominations which are in them.
35954	1360	17	And behold, a curse shall come upon the land, saith the Lord of Hosts, because of the peoples' sake who are upon the land, yea, because of their wickedness and their abominations.
35955	1360	18	And it shall come to pass, saith the Lord of Hosts, yea, our great and true God, that whoso shall hide up treasures in the earth shall find them again no more, because of the great curse of the land, save he be a righteous man and shall hide it up unto the Lord.
35956	1360	19	For I will, saith the Lord, that they shall hide up their treasures unto me; and cursed be they who hide not up their treasures unto me; for none hideth up their treasures unto me save it be the righteous; and he that hideth not up his treasures unto me, cursed is he, and also the treasure, and none shall redeem it because of the curse of the land.
35957	1360	20	And the day shall come that they shall hide up their treasures, because they have set their hearts upon riches; and because they have set their hearts upon their riches, and will hide up their treasures when they shall flee before their enemies; because they will not hide them up unto me, cursed be they and also their treasures; and in that day shall they be smitten, saith the Lord.
35958	1360	21	Behold ye, the people of this great city, and hearken unto my words; yea, hearken unto the words which the Lord saith; for behold, he saith that ye are cursed because of your riches, and also are your riches cursed because ye have set your hearts upon them, and have not hearkened unto the words of him who gave them unto you.
35959	1360	22	Ye do not remember the Lord your God in the things with which he hath blessed you, but ye do always remember your riches, not to thank the Lord your God for them; yea, your hearts are not drawn out unto the Lord, but they do swell with great pride, unto boasting, and unto great swelling, envyings, strifes, malice, persecutions, and murders, and all manner of iniquities.
35960	1360	23	For this cause hath the Lord God caused that a curse should come upon the land, and also upon your riches, and this because of your iniquities.
35961	1360	24	Yea, wo unto this people, because of this time which has arrived, that ye do cast out the prophets, and do mock them, and cast stones at them, and do slay them, and do all manner of iniquity unto them, even as they did of old time.
35962	1360	25	And now when ye talk, ye say: If our days had been in the days of our fathers of old, we would not have slain the prophets; we would not have stoned them, and cast them out.
35963	1360	26	Behold ye are worse than they; for as the Lord liveth, if a prophet come among you and declareth unto you the word of the Lord, which testifieth of your sins and iniquities, ye are angry with him, and cast him out and seek all manner of ways to destroy him; yea, you will say that he is a false prophet, and that he is a sinner, and of the devil, because he testifieth that your deeds are evil.
35964	1360	27	But behold, if a man shall come among you and shall say: Do this, and there is no iniquity; do that and ye shall not suffer; yea, he will say: Walk after the pride of your own hearts; yea, walk after the pride of your eyes, and do whatsoever your heart desireth--and if a man shall come among you and say this, ye will receive him, and say that he is a prophet.
35965	1360	28	Yea, ye will lift him up, and ye will give unto him of your substance; ye will give unto him of your gold, and of your silver, and ye will clothe him with costly apparel; and because he speaketh flattering words unto you, and he saith that all is well, then ye will not find fault with him.
35966	1360	29	O ye wicked and ye perverse generation; ye hardened and ye stiffnecked people, how long will ye suppose that the Lord will suffer you? Yea, how long will ye suffer yourselves to be led by foolish and blind guides? Yea, how long will ye choose darkness rather than light?
35967	1360	30	Yea, behold, the anger of the Lord is already kindled against you; behold, he hath cursed the land because of your iniquity.
35968	1360	31	And behold, the time cometh that he curseth your riches, that they become slippery, that ye cannot hold them; and in the days of your poverty ye cannot retain them.
35969	1360	32	And in the days of your poverty ye shall cry unto the Lord; and in vain shall ye cry, for your desolation is already come upon you, and your destruction is made sure; and then shall ye weep and howl in that day, saith the Lord of Hosts. And then shall ye lament, and say:
35970	1360	33	O that I had repented, and had not killed the prophets, and stoned them, and cast them out. Yea, in that day ye shall say: O that we had remembered the Lord our God in the day that he gave us our riches, and then they would not have become slippery that we should lose them; for behold, our riches are gone from us.
35971	1360	34	Behold, we lay a tool here and on the morrow it is gone; and behold, our swords are taken from us in the day we have sought them for battle.
35972	1360	35	Yea, we have hid up our treasures and they have slipped away from us, because of the curse of the land.
35973	1360	36	O that we had repented in the day that the word of the Lord came unto us; for behold the land is cursed, and all things are become slippery, and we cannot hold them.
35974	1360	37	Behold, we are surrounded by demons, yea, we are encircled about by the angels of him who hath sought to destroy our souls. Behold, our iniquities are great. O Lord, canst thou not turn away thine anger from us? And this shall be your language in those days.
35975	1360	38	But behold, your days of probation are past; ye have procrastinated the day of your salvation until it is everlastingly too late, and your destruction is made sure; yea, for ye have sought all the days of your lives for that which ye could not obtain; and ye have sought for happiness in doing iniquity, which thing is contrary to the nature of that righteousness which is in our great and Eternal Head.
35976	1360	39	O ye people of the land, that ye would hear my words! And I pray that the anger of the Lord be turned away from you, and that ye would repent and be saved.
35977	1361	1	And now it came to pass that Samuel, the Lamanite, did prophesy a great many more things which cannot be written.
35978	1361	2	And behold, he said unto them: Behold, I give unto you a sign; for five years more cometh, and behold, then cometh the Son of God to redeem all those who shall believe on his name.
35979	1361	3	And behold, this will I give unto you for a sign at the time of his coming; for behold, there shall be great lights in heaven, insomuch that in the night before he cometh there shall be no darkness, insomuch that it shall appear unto man as if it was day.
35980	1361	4	Therefore, there shall be one day and a night and a day, as if it were one day and there were no night; and this shall be unto you for a sign; for ye shall know of the rising of the sun and also of its setting; therefore they shall know of a surety that there shall be two days and a night; nevertheless the night shall not be darkened; and it shall be the night before he is born.
35981	1361	5	And behold, there shall a new star arise, such an one as ye never have beheld; and this also shall be a sign unto you.
35982	1361	6	And behold this is not all, there shall be many signs and wonders in heaven.
35983	1361	7	And it shall come to pass that ye shall all be amazed, and wonder, insomuch that ye shall fall to the earth.
35984	1361	8	And it shall come to pass that whosoever shall believe on the Son of God, the same shall have everlasting life.
35985	1361	9	And behold, thus hath the Lord commanded me, by his angel, that I should come and tell this thing unto you; yea, he hath commanded that I should prophesy these things unto you; yea, he hath said unto me: Cry unto this people, repent and prepare the way of the Lord.
35986	1361	10	And now, because I am a Lamanite, and have spoken unto you the words which the Lord hath commanded me, and because it was hard against you, ye are angry with me and do seek to destroy me, and have cast me out from among you.
35987	1361	11	And ye shall hear my words, for, for this intent have I come up upon the walls of this city, that ye might hear and know of the judgments of God which do await you because of your iniquities, and also that ye might know the conditions of repentance;
35988	1361	12	And also that ye might know of the coming of Jesus Christ, the Son of God, the Father of heaven and of earth, the Creator of all things from the beginning; and that ye might know of the signs of his coming, to the intent that ye might believe on his name.
35989	1361	13	And if ye believe on his name ye will repent of all your sins, that thereby ye may have a remission of them through his merits.
35990	1361	14	And behold, again, another sign I give unto you, yea, a sign of his death.
35991	1361	15	For behold, he surely must die that salvation may come; yea, it behooveth him and becometh expedient that he dieth, to bring to pass the resurrection of the dead, that thereby men may be brought into the presence of the Lord.
35992	1361	16	Yea, behold, this death bringeth to pass the resurrection, and redeemeth all mankind from the first death--that spiritual death; for all mankind, by the fall of Adam being cut off from the presence of the Lord, are considered as dead, both as to things temporal and to things spiritual.
35993	1361	17	But behold, the resurrection of Christ redeemeth mankind, yea, even all mankind, and bringeth them back into the presence of the Lord.
35994	1361	18	Yea, and it bringeth to pass the condition of repentance, that whosoever repenteth the same is not hewn down and cast into the fire; but whosoever repenteth not is hewn down and cast into the fire; and there cometh upon them again a spiritual death, yea, a second death, for they are cut off again as to things pertaining to righteousness.
35995	1361	19	Therefore repent ye, repent ye, lest by knowing these things and not doing them ye shall suffer yourselves to come under condemnation, and ye are brought down unto this second death.
35996	1361	20	But behold, as I said unto you concerning another sign, a sign of his death, behold, in that day that he shall suffer death the sun shall be darkened and refuse to give his light unto you; and also the moon and the stars; and there shall be no light upon the face of this land, even from the time that he shall suffer death, for the space of three days, to the time that he shall rise again from the dead.
35997	1361	21	Yea, at the time that he shall yield up the ghost there shall be thunderings and lightnings for the space of many hours, and the earth shall shake and tremble; and the rocks which are upon the face of this earth, which are both above the earth and beneath, which ye know at this time are solid, or the more part of it is one solid mass, shall be broken up;
35998	1361	22	Yea, they shall be rent in twain, and shall ever after be found in seams and in cracks, and in broken fragments upon the face of the whole earth, yea, both above the earth and beneath.
35999	1361	23	And behold, there shall be great tempests, and there shall be many mountains laid low, like unto a valley, and there shall be many places which are now called valleys which shall become mountains, whose height is great.
36000	1361	24	And many highways shall be broken up, and many cities shall become desolate.
36001	1361	25	And many graves shall be opened, and shall yield up many of their dead; and many saints shall appear unto many.
36002	1361	26	And behold, thus hath the angel spoken unto me; for he said unto me that there should be thunderings and lightnings for the space of many hours.
36003	1361	27	And he said unto me that while the thunder and the lightning lasted, and the tempest, that these things should be, and that darkness should cover the face of the whole earth for the space of three days.
36004	1361	28	And the angel said unto me that many shall see greater things than these, to the intent that they might believe that these signs and these wonders should come to pass upon all the face of this land, to the intent that there should be no cause for unbelief among the children of men--
36005	1361	29	And this to the intent that whosoever will believe might be saved, and that whosoever will not believe, a righteous judgment might come upon them; and also if they are condemned they bring upon themselves their own condemnation.
36006	1361	30	And now remember, remember, my brethren, that whosoever perisheth, perisheth unto himself; and whosoever doeth iniquity, doeth it unto himself; for behold, ye are free; ye are permitted to act for yourselves; for behold, God hath given unto you a knowledge and he hath made you free.
36007	1361	31	He hath given unto you that ye might know good from evil, and he hath given unto you that ye might choose life or death; and ye can do good and be restored unto that which is good, or have that which is good restored unto you; or ye can do evil, and have that which is evil restored unto you.
36008	1362	1	And now, my beloved brethren, behold, I declare unto you that except ye shall repent your houses shall be left unto you desolate.
36009	1362	2	Yea, except ye repent, your women shall have great cause to mourn in the day that they shall give suck; for ye shall attempt to flee and there shall be no place for refuge; yea, and wo unto them which are with child, for they shall be heavy and cannot flee; therefore, they shall be trodden down and shall be left to perish.
36010	1362	3	Yea, wo unto this people who are called the people of Nephi except they shall repent, when they shall see all these signs and wonders which shall be showed unto them; for behold, they have been a chosen people of the Lord; yea, the people of Nephi hath he loved, and also hath he chastened them; yea, in the days of their iniquities hath he chastened them because he loveth them.
36011	1362	4	But behold my brethren, the Lamanites hath he hated because their deeds have been evil continually, and this because of the iniquity of the tradition of their fathers. But behold, salvation hath come unto them through the preaching of the Nephites; and for this intent hath the Lord prolonged their days.
36012	1362	5	And I would that ye should behold that the more part of them are in the path of their duty, and they do walk circumspectly before God, and they do observe to keep his commandments and his statutes and his judgments according to the law of Moses.
36013	1362	6	Yea, I say unto you, that the more part of them are doing this, and they are striving with unwearied diligence that they may bring the remainder of their brethren to the knowledge of the truth; therefore there are many who do add to their numbers daily.
36014	1362	7	And behold, ye do know of yourselves, for ye have witnessed it, that as many of them as are brought to the knowledge of the truth, and to know of the wicked and abominable traditions of their fathers, and are led to believe the holy scriptures, yea, the prophecies of the holy prophets, which are written, which leadeth them to faith on the Lord, and unto repentance, which faith and repentance bringeth a change of heart unto them--
36015	1362	8	Therefore, as many as have come to this, ye know of yourselves are firm and steadfast in the faith, and in the thing wherewith they have been made free.
36016	1362	9	And ye know also that they have buried their weapons of war, and they fear to take them up lest by any means they should sin; yea, ye can see that they fear to sin--for behold they will suffer themselves that they be trodden down and slain by their enemies, and will not lift their swords against them, and this because of their faith in Christ.
36017	1362	10	And now, because of their steadfastness when they do believe in that thing which they do believe, for because of their firmness when they are once enlightened, behold, the Lord shall bless them and prolong their days, notwithstanding their iniquity--
36018	1362	11	Yea, even if they should dwindle in unbelief the Lord shall prolong their days, until the time shall come which hath been spoken of by our fathers, and also by the prophet Zenos, and many other prophets, concerning the restoration of our brethren, the Lamanites, again to the knowledge of the truth--
36019	1362	12	Yea, I say unto you, that in the latter times the promises of the Lord have been extended to our brethren, the Lamanites; and notwithstanding the many afflictions which they shall have, and notwithstanding they shall be driven to and fro upon the face of the earth, and be hunted, and shall be smitten and scattered abroad, having no place for refuge, the Lord shall be merciful unto them.
36020	1362	13	And this is according to the prophecy, that they shall again be brought to the true knowledge, which is the knowledge of their Redeemer, and their great and true shepherd, and be numbered among his sheep.
36021	1362	14	Therefore I say unto you, it shall be better for them than for you except ye repent.
36022	1362	15	For behold, had the mighty works been shown unto them which have been shown unto you, yea, unto them who have dwindled in unbelief because of the traditions of their fathers, ye can see of yourselves that they never would again have dwindled in unbelief.
36023	1362	16	Therefore, saith the Lord: I will not utterly destroy them, but I will cause that in the day of my wisdom they shall return again unto me, saith the Lord.
36024	1362	17	And now behold, saith the Lord, concerning the people of the Nephites: If they will not repent, and observe to do my will, I will utterly destroy them, saith the Lord, because of their unbelief notwithstanding the many mighty works which I have done among them; and as surely as the Lord liveth shall these things be, saith the Lord.
36025	1363	1	And now, it came to pass that there were many who heard the words of Samuel, the Lamanite, which he spake upon the walls of the city. And as many as believed on his word went forth and sought for Nephi; and when they had come forth and found him they confessed unto him their sins and denied not, desiring that they might be baptized unto the Lord.
36026	1363	2	But as many as there were who did not believe in the words of Samuel were angry with him; and they cast stones at him upon the wall, and also many shot arrows at him as he stood upon the wall; but the Spirit of the Lord was with him, insomuch that they could not hit him with their stones neither with their arrows.
36027	1363	3	Now when they saw that they could not hit him, there were many more who did believe on his words, insomuch that they went away unto Nephi to be baptized.
36028	1363	4	For behold, Nephi was baptizing, and prophesying, and preaching, crying repentance unto the people, showing signs and wonders, working miracles among the people, that they might know that the Christ must shortly come--
36029	1363	5	Telling them of things which must shortly come, that they might know and remember at the time of their coming that they had been made known unto them beforehand, to the intent that they might believe; therefore as many as believed on the words of Samuel went forth unto him to be baptized, for they came repenting and confessing their sins.
36030	1363	6	But the more part of them did not believe in the words of Samuel; therefore when they saw that they could not hit him with their stones and their arrows, they cried unto their captains, saying: Take this fellow and bind him, for behold he hath a devil; and because of the power of the devil which is in him we cannot hit him with our stones and our arrows; therefore take him and bind him, and away with him.
36031	1363	7	And as they went forth to lay their hands on him, behold, he did cast himself down from the wall, and did flee out of their lands, yea, even unto his own country, and began to preach and to prophesy among his own people.
36032	1363	8	And behold, he was never heard of more among the Nephites; and thus were the affairs of the people.
36033	1363	9	And thus ended the eighty and sixth year of the reign of the judges over the people of Nephi.
36034	1363	10	And thus ended also the eighty and seventh year of the reign of the judges, the more part of the people remaining in their pride and wickedness, and the lesser part walking more circumspectly before God.
36035	1363	11	And these were the conditions also, in the eighty and eighth year of the reign of the judges.
36036	1363	12	And there was but little alteration in the affairs of the people, save it were the people began to be more hardened in iniquity, and do more and more of that which was contrary to the commandments of God, in the eighty and ninth year of the reign of the judges.
36037	1363	13	But it came to pass in the ninetieth year of the reign of the judges, there were great signs given unto the people, and wonders; and the words of the prophets began to be fulfilled.
36038	1363	14	And angels did appear unto men, wise men, and did declare unto them glad tidings of great joy; thus in this year the scriptures began to be fulfilled.
36039	1363	15	Nevertheless, the people began to harden their hearts, all save it were the most believing part of them, both of the Nephites and also of the Lamanites, and began to depend upon their own strength and upon their own wisdom, saying:
36040	1363	16	Some things they may have guessed right, among so many; but behold, we know that all these great and marvelous works cannot come to pass, of which has been spoken.
36041	1363	17	And they began to reason and to contend among themselves, saying:
36042	1363	18	That it is not reasonable that such a being as a Christ shall come; if so, and he be the Son of God, the Father of heaven and of earth, as it has been spoken, why will he not show himself unto us as well as unto them who shall be at Jerusalem?
36043	1363	19	Yea, why will he not show himself in this land as well as in the land of Jerusalem?
36044	1363	20	But behold, we know that this is a wicked tradition, which has been handed down unto us by our fathers, to cause us that we should believe in some great and marvelous thing which should come to pass, but not among us, but in a land which is far distant, a land which we know not; therefore they can keep us in ignorance, for we cannot witness with our own eyes that they are true.
36045	1363	21	And they will, by the cunning and the mysterious arts of the evil one, work some great mystery which we cannot understand, which will keep us down to be servants to their words, and also servants unto them, for we depend upon them to teach us the word; and thus will they keep us in ignorance if we will yield ourselves unto them, all the days of our lives.
36046	1363	22	And many more things did the people imagine up in their hearts, which were foolish and vain; and they were much disturbed, for Satan did stir them up to do iniquity continually; yea, he did go about spreading rumors and contentions upon all the face of the land, that he might harden the hearts of the people against that which was good and against that which should come.
36047	1363	23	And notwithstanding the signs and the wonders which were wrought among the people of the Lord, and the many miracles which they did, Satan did get great hold upon the hearts of the people upon all the face of the land.
36048	1363	24	And thus ended the ninetieth year of the reign of the judges over the people of Nephi.
36049	1363	25	And thus ended the book of Helaman, according to the record of Helaman and his sons.
36050	1364	1	Now it came to pass that the ninety and first year had passed away and it was six hundred years from the time that Lehi left Jerusalem; and it was in the year that Lachoneus was the chief judge and the governor over the land.
36051	1364	2	And Nephi, the son of Helaman, had departed out of the land of Zarahemla, giving charge unto his son Nephi, who was his eldest son, concerning the plates of brass, and all the records which had been kept, and all those things which had been kept sacred from the departure of Lehi out of Jerusalem.
36052	1364	3	Then he departed out of the land, and whither he went, no man knoweth; and his son Nephi did keep the records in his stead, yea, the record of this people.
36053	1364	4	And it came to pass that in the commencement of the ninety and second year, behold, the prophecies of the prophets began to be fulfilled more fully; for there began to be greater signs and greater miracles wrought among the people.
36054	1364	5	But there were some who began to say that the time was past for the words to be fulfilled, which were spoken by Samuel, the Lamanite.
36055	1364	6	And they began to rejoice over their brethren, saying: Behold the time is past, and the words of Samuel are not fulfilled; therefore, your joy and your faith concerning this thing hath been vain.
36056	1364	7	And it came to pass that they did make a great uproar throughout the land; and the people who believed began to be very sorrowful, lest by any means those things which had been spoken might not come to pass.
36057	1364	8	But behold, they did watch steadfastly for that day and that night and that day which should be as one day as if there were no night, that they might know that their faith had not been vain.
36058	1364	9	Now it came to pass that there was a day set apart by the unbelievers, that all those who believed in those traditions should be put to death except the sign should come to pass, which had been given by Samuel the prophet.
36059	1364	10	Now it came to pass that when Nephi, the son of Nephi, saw this wickedness of his people, his heart was exceedingly sorrowful.
36060	1364	11	And it came to pass that he went out and bowed himself down upon the earth, and cried mightily to his God in behalf of his people, yea, those who were about to be destroyed because of their faith in the tradition of their fathers.
36061	1364	12	And it came to pass that he cried mightily unto the Lord all that day; and behold, the voice of the Lord came unto him, saying:
36062	1364	13	Lift up your head and be of good cheer; for behold, the time is at hand, and on this night shall the sign be given, and on the morrow come I into the world, to show unto the world that I will fulfil all that which I have caused to be spoken by the mouth of my holy prophets.
36063	1364	14	Behold, I come unto my own, to fulfil all things which I have made known unto the children of men from the foundation of the world, and to do the will, both of the Father and of the Son--of the Father because of me, and of the Son because of my flesh. And behold, the time is at hand, and this night shall the sign be given.
36064	1364	15	And it came to pass that the words which came unto Nephi were fulfilled, according as they had been spoken; for behold, at the going down of the sun there was no darkness; and the people began to be astonished because there was no darkness when the night came.
36065	1364	16	And there were many, who had not believed the words of the prophets, who fell to the earth and became as if they were dead, for they knew that the great plan of destruction which they had laid for those who believed in the words of the prophets had been frustrated; for the sign which had been given was already at hand.
36066	1364	17	And they began to know that the Son of God must shortly appear; yea, in fine, all the people upon the face of the whole earth from the west to the east, both in the land north and in the land south, were so exceedingly astonished that they fell to the earth.
36067	1364	18	For they knew that the prophets had testified of these things for many years, and that the sign which had been given was already at hand; and they began to fear because of their iniquity and their unbelief.
36068	1364	19	And it came to pass that there was no darkness in all that night, but it was as light as though it was mid-day. And it came to pass that the sun did rise in the morning again, according to its proper order; and they knew that it was the day that the Lord should be born, because of the sign which had been given.
36069	1364	20	And it had come to pass, yea, all things, every whit, according to the words of the prophets.
36070	1364	21	And it came to pass also that a new star did appear, according to the word.
36071	1364	22	And it came to pass that from this time forth there began to be lyings sent forth among the people, by Satan, to harden their hearts, to the intent that they might not believe in those signs and wonders which they had seen; but notwithstanding these lyings and deceivings the more part of the people did believe, and were converted unto the Lord.
36072	1364	23	And it came to pass that Nephi went forth among the people, and also many others, baptizing unto repentance, in the which there was a great remission of sins. And thus the people began again to have peace in the land.
36073	1364	24	And there were no contentions, save it were a few that began to preach, endeavoring to prove by the scriptures that it was no more expedient to observe the law of Moses. Now in this thing they did err, having not understood the scriptures.
36074	1364	25	But it came to pass that they soon became converted, and were convinced of the error which they were in, for it was made known unto them that the law was not yet fulfilled, and that it must be fulfilled in every whit; yea, the word came unto them that it must be fulfilled; yea, that one jot or tittle should not pass away till it should all be fulfilled; therefore in this same year were they brought to a knowledge of their error and did confess their faults.
36075	1364	26	And thus the ninety and second year did pass away, bringing glad tidings unto the people because of the signs which did come to pass, according to the words of the prophecy of all the holy prophets.
36076	1364	27	And it came to pass that the ninety and third year did also pass away in peace, save it were for the Gadianton robbers, who dwelt upon the mountains, who did infest the land; for so strong were their holds and their secret places that the people could not overpower them; therefore they did commit many murders, and did do much slaughter among the people.
36077	1364	28	And it came to pass that in the ninety and fourth year they began to increase in a great degree, because there were many dissenters of the Nephites who did flee unto them, which did cause much sorrow unto those Nephites who did remain in the land.
36078	1364	29	And there was also a cause of much sorrow among the Lamanites; for behold, they had many children who did grow up and began to wax strong in years, that they became for themselves, and were led away by some who were Zoramites, by their lyings and their flattering words, to join those Gadianton robbers.
36079	1364	30	And thus were the Lamanites afflicted also, and began to decrease as to their faith and righteousness, because of the wickedness of the rising generation.
36080	1365	1	And it came to pass that thus passed away the ninety and fifth year also, and the people began to forget those signs and wonders which they had heard, and began to be less and less astonished at a sign or a wonder from heaven, insomuch that they began to be hard in their hearts, and blind in their minds, and began to disbelieve all which they had heard and seen--
36081	1365	2	Imagining up some vain thing in their hearts, that it was wrought by men and by the power of the devil, to lead away and deceive the hearts of the people; and thus did Satan get possession of the hearts of the people again, insomuch that he did blind their eyes and lead them away to believe that the doctrine of Christ was a foolish and a vain thing.
36082	1365	3	And it came to pass that the people began to wax strong in wickedness and abominations; and they did not believe that there should be any more signs or wonders given; and Satan did go about, leading away the hearts of the people, tempting them and causing them that they should do great wickedness in the land.
36083	1365	4	And thus did pass away the ninety and sixth year; and also the ninety and seventh year; and also the ninety and eighth year; and also the ninety and ninth year;
36084	1365	5	And also an hundred years had passed away since the days of Mosiah, who was king over the people of the Nephites.
36085	1365	6	And six hundred and nine years had passed away since Lehi left Jerusalem.
36086	1365	7	And nine years had passed away from the time when the sign was given, which was spoken of by the prophets, that Christ should come into the world.
36087	1365	8	Now the Nephites began to reckon their time from this period when the sign was given, or from the coming of Christ; therefore, nine years had passed away.
36088	1365	9	And Nephi, who was the father of Nephi, who had the charge of the records, did not return to the land of Zarahemla, and could nowhere be found in all the land.
36089	1365	10	And it came to pass that the people did still remain in wickedness, notwithstanding the much preaching and prophesying which was sent among them; and thus passed away the tenth year also; and the eleventh year also passed away in iniquity.
36090	1365	11	And it came to pass in the thirteenth year there began to be wars and contentions throughout all the land; for the Gadianton robbers had become so numerous, and did slay so many of the people, and did lay waste so many cities, and did spread so much death and carnage throughout the land, that it became expedient that all the people, both the Nephites and the Lamanites, should take up arms against them.
36091	1365	12	Therefore, all the Lamanites who had become converted unto the Lord did unite with their brethren, the Nephites, and were compelled, for the safety of their lives and their women and their children, to take up arms against those Gadianton robbers, yea, and also to maintain their rights, and the privileges of their church and of their worship, and their freedom and their liberty.
36092	1365	13	And it came to pass that before this thirteenth year had passed away the Nephites were threatened with utter destruction because of this war, which had become exceedingly sore.
36093	1365	14	And it came to pass that those Lamanites who had united with the Nephites were numbered among the Nephites;
36094	1365	15	And their curse was taken from them, and their skin became white like unto the Nephites;
36095	1365	16	And their young men and their daughters became exceedingly fair, and they were numbered among the Nephites, and were called Nephites. And thus ended the thirteenth year.
36096	1365	17	And it came to pass in the commencement of the fourteenth year, the war between the robbers and the people of Nephi did continue and did become exceedingly sore; nevertheless, the people of Nephi did gain some advantage of the robbers, insomuch that they did drive them back out of their lands into the mountains and into their secret places.
36097	1365	18	And thus ended the fourteenth year. And in the fifteenth year they did come forth against the people of Nephi; and because of the wickedness of the people of Nephi, and their many contentions and dissensions, the Gadianton robbers did gain many advantages over them.
36098	1365	19	And thus ended the fifteenth year, and thus were the people in a state of many afflictions; and the sword of destruction did hang over them, insomuch that they were about to be smitten down by it, and this because of their iniquity.
36099	1366	1	And now it came to pass that in the sixteenth year from the coming of Christ, Lachoneus, the governor of the land, received an epistle from the leader and the governor of this band of robbers; and these were the words which were written, saying:
36100	1366	2	Lachoneus, most noble and chief governor of the land, behold, I write this epistle unto you, and do give unto you exceedingly great praise because of your firmness, and also the firmness of your people, in maintaining that which ye suppose to be your right and liberty; yea, ye do stand well, as if ye were supported by the hand of a god, in the defence of your liberty, and your property, and your country, or that which ye do call so.
36101	1366	3	And it seemeth a pity unto me, most noble Lachoneus, that ye should be so foolish and vain as to suppose that ye can stand against so many brave men who are at my command, who do now at this time stand in their arms, and do await with great anxiety for the word--Go down upon the Nephites and destroy them.
36102	1366	4	And I, knowing of their unconquerable spirit, having proved them in the field of battle, and knowing of their everlasting hatred towards you because of the many wrongs which ye have done unto them, therefore if they should come down against you they would visit you with utter destruction.
36103	1366	5	Therefore I have written this epistle, sealing it with mine own hand, feeling for your welfare, because of your firmness in that which ye believe to be right, and your noble spirit in the field of battle.
36104	1366	6	Therefore I write unto you, desiring that ye would yield up unto this my people, your cities, your lands, and your possessions, rather than that they should visit you with the sword and that destruction should come upon you.
36105	1366	7	Or in other words, yield yourselves up unto us, and unite with us and become acquainted with our secret works, and become our brethren that ye may be like unto us--not our slaves, but our brethren and partners of all our substance.
36106	1366	8	And behold, I swear unto you, if ye will do this, with an oath, ye shall not be destroyed; but if ye will not do this, I swear unto you with an oath, that on the morrow month I will command that my armies shall come down against you, and they shall not stay their hand and shall spare not, but shall slay you, and shall let fall the sword upon you even until ye shall become extinct.
36107	1366	9	And behold, I am Giddianhi; and I am the governor of this the secret society of Gadianton; which society and the works thereof I know to be good; and they are of ancient date and they have been handed down unto us.
36108	1366	10	And I write this epistle unto you, Lachoneus, and I hope that ye will deliver up your lands and your possessions, without the shedding of blood, that this my people may recover their rights and government, who have dissented away from you because of your wickedness in retaining from them their rights of government, and except ye do this, I will avenge their wrongs. I am Giddianhi.
36109	1366	11	And now it came to pass when Lachoneus received this epistle he was exceedingly astonished, because of the boldness of Giddianhi demanding the possession of the land of the Nephites, and also of threatening the people and avenging the wrongs of those that had received no wrong, save it were they had wronged themselves by dissenting away unto those wicked and abominable robbers.
36110	1366	12	Now behold, this Lachoneus, the governor, was a just man, and could not be frightened by the demands and the threatenings of a robber; therefore he did not hearken to the epistle of Giddianhi, the governor of the robbers, but he did cause that his people should cry unto the Lord for strength against the time that the robbers should come down against them.
36111	1366	13	Yea, he sent a proclamation among all the people, that they should gather together their women, and their children, their flocks and their herds, and all their substance, save it were their land, unto one place.
36112	1366	14	And he caused that fortifications should be built round about them, and the strength thereof should be exceedingly great. And he caused that armies, both of the Nephites and of the Lamanites, or of all them who were numbered among the Nephites, should be placed as guards round about to watch them, and to guard them from the robbers day and night.
36113	1366	15	Yea, he said unto them: As the Lord liveth, except ye repent of all your iniquities, and cry unto the Lord, ye will in no wise be delivered out of the hands of those Gadianton robbers.
36114	1366	16	And so great and marvelous were the words and prophecies of Lachoneus that they did cause fear to come upon all the people; and they did exert themselves in their might to do according to the words of Lachoneus.
36115	1366	17	And it came to pass that Lachoneus did appoint chief captains over all the armies of the Nephites, to command them at the time that the robbers should come down out of the wilderness against them.
36116	1366	18	Now the chiefest among all the chief captains and the great commander of all the armies of the Nephites was appointed, and his name was Gidgiddoni.
36117	1366	19	Now it was the custom among all the Nephites to appoint for their chief captains, (save it were in their times of wickedness) some one that had the spirit of revelation and also prophecy; therefore, this Gidgiddoni was a great prophet among them, as also was the chief judge.
36118	1366	20	Now the people said unto Gidgiddoni: Pray unto the Lord, and let us go up upon the mountains and into the wilderness, that we may fall upon the robbers and destroy them in their own lands.
36119	1366	21	But Gidgiddoni saith unto them: The Lord forbid; for if we should go up against them the Lord would deliver us into their hands; therefore we will prepare ourselves in the center of our lands, and we will gather all our armies together, and we will not go against them, but we will wait till they shall come against us; therefore as the Lord liveth, if we do this he will deliver them into our hands.
36120	1366	22	And it came to pass in the seventeenth year, in the latter end of the year, the proclamation of Lachoneus had gone forth throughout all the face of the land, and they had taken their horses, and their chariots, and their cattle, and all their flocks, and their herds, and their grain, and all their substance, and did march forth by thousands and by tens of thousands, until they had all gone forth to the place which had been appointed that they should gather themselves together, to defend themselves against their enemies.
36121	1366	23	And the land which was appointed was the land of Zarahemla, and the land which was between the land Zarahemla and the land Bountiful, yea, to the line which was between the land Bountiful and the land Desolation.
36122	1366	24	And there were a great many thousand people who were called Nephites, who did gather themselves together in this land. Now Lachoneus did cause that they should gather themselves together in the land southward, because of the great curse which was upon the land northward.
36123	1366	25	And they did fortify themselves against their enemies; and they did dwell in one land, and in one body, and they did fear the words which had been spoken by Lachoneus, insomuch that they did repent of all their sins; and they did put up their prayers unto the Lord their God, that he would deliver them in the time that their enemies should come down against them to battle.
36124	1366	26	And they were exceedingly sorrowful because of their enemies. And Gidgiddoni did cause that they should make weapons of war of every kind, and they should be strong with armor, and with shields, and with bucklers, after the manner of his instruction.
36125	1367	1	And it came to pass that in the latter end of the eighteenth year those armies of robbers had prepared for battle, and began to come down and to sally forth from the hills, and out of the mountains, and the wilderness, and their strongholds, and their secret places, and began to take possession of the lands, both which were in the land south and which were in the land north, and began to take possession of all the lands which had been deserted by the Nephites, and the cities which had been left desolate.
36126	1367	2	But behold, there were no wild beasts nor game in those lands which had been deserted by the Nephites, and there was no game for the robbers save it were in the wilderness.
36127	1367	3	And the robbers could not exist save it were in the wilderness, for the want of food; for the Nephites had left their lands desolate, and had gathered their flocks and their herds and all their substance, and they were in one body.
36128	1367	4	Therefore, there was no chance for the robbers to plunder and to obtain food, save it were to come up in open battle against the Nephites; and the Nephites being in one body, and having so great a number, and having reserved for themselves provisions, and horses and cattle, and flocks of every kind, that they might subsist for the space of seven years, in the which time they did hope to destroy the robbers from off the face of the land; and thus the eighteenth year did pass away.
36129	1367	5	And it came to pass that in the nineteenth year Giddianhi found that it was expedient that he should go up to battle against the Nephites, for there was no way that they could subsist save it were to plunder and rob and murder.
36130	1367	6	And they durst not spread themselves upon the face of the land insomuch that they could raise grain, lest the Nephites should come upon them and slay them; therefore Giddianhi gave commandment unto his armies that in this year they should go up to battle against the Nephites.
36131	1367	7	And it came to pass that they did come up to battle; and it was in the sixth month; and behold, great and terrible was the day that they did come up to battle; and they were girded about after the manner of robbers; and they had a lamb-skin about their loins, and they were dyed in blood, and their heads were shorn, and they had head-plates upon them; and great and terrible was the appearance of the armies of Giddianhi, because of their armor, and because of their being dyed in blood.
36132	1367	8	And it came to pass that the armies of the Nephites, when they saw the appearance of the army of Giddianhi, had all fallen to the earth, and did lift their cries to the Lord their God, that he would spare them and deliver them out of the hands of their enemies.
36133	1367	9	And it came to pass that when the armies of Giddianhi saw this they began to shout with a loud voice, because of their joy, for they had supposed that the Nephites had fallen with fear because of the terror of their armies.
36134	1367	10	But in this thing they were disappointed, for the Nephites did not fear them; but they did fear their God and did supplicate him for protection; therefore, when the armies of Giddianhi did rush upon them they were prepared to meet them; yea, in the strength of the Lord they did receive them.
36135	1367	11	And the battle commenced in this the sixth month; and great and terrible was the battle thereof, yea, great and terrible was the slaughter thereof, insomuch that there never was known so great a slaughter among all the people of Lehi since he left Jerusalem.
36136	1367	12	And notwithstanding the threatenings and the oaths which Giddianhi had made, behold, the Nephites did beat them, insomuch that they did fall back from before them.
36137	1367	13	And it came to pass that Gidgiddoni commanded that his armies should pursue them as far as the borders of the wilderness, and that they should not spare any that should fall into their hands by the way; and thus they did pursue them and did slay them, to the borders of the wilderness, even until they had fulfilled the commandment of Gidgiddoni.
36138	1367	14	And it came to pass that Giddianhi, who had stood and fought with boldness, was pursued as he fled; and being weary because of his much fighting he was overtaken and slain. And thus was the end of Giddianhi the robber.
36139	1367	15	And it came to pass that the armies of the Nephites did return again to their place of security. And it came to pass that this nineteenth year did pass away, and the robbers did not come again to battle; neither did they come again in the twentieth year.
36140	1367	16	And in the twenty and first year they did not come up to battle, but they came up on all sides to lay siege round about the people of Nephi; for they did suppose that if they should cut off the people of Nephi from their lands, and should hem them in on every side, and if they should cut them off from all their outward privileges, that they could cause them to yield themselves up according to their wishes.
36141	1367	17	Now they had appointed unto themselves another leader, whose name was Zemnarihah; therefore it was Zemnarihah that did cause that this siege should take place.
36142	1367	18	But behold, this was an advantage to the Nephites; for it was impossible for the robbers to lay siege sufficiently long to have any effect upon the Nephites, because of their much provision which they had laid up in store,
36143	1367	19	And because of the scantiness of provisions among the robbers; for behold, they had nothing save it were meat for their subsistence, which meat they did obtain in the wilderness;
36144	1367	20	And it came to pass that the wild game became scarce in the wilderness insomuch that the robbers were about to perish with hunger.
36145	1367	21	And the Nephites were continually marching out by day and by night, and falling upon their armies, and cutting them off by thousands and by tens of thousands.
36146	1367	22	And thus it became the desire of the people of Zemnarihah to withdraw from their design, because of the great destruction which came upon them by night and by day.
36147	1367	23	And it came to pass that Zemnarihah did give command unto his people that they should withdraw themselves from the siege, and march into the furthermost parts of the land northward.
36148	1367	24	And now, Gidgiddoni being aware of their design, and knowing of their weakness because of the want of food, and the great slaughter which had been made among them, therefore he did send out his armies in the night-time, and did cut off the way of their retreat, and did place his armies in the way of their retreat.
36149	1367	25	And this did they do in the night-time, and got on their march beyond the robbers, so that on the morrow, when the robbers began their march, they were met by the armies of the Nephites both in their front and in their rear.
36150	1367	26	And the robbers who were on the south were also cut off in their places of retreat. And all these things were done by command of Gidgiddoni.
36151	1367	27	And there were many thousands who did yield themselves up prisoners unto the Nephites, and the remainder of them were slain.
36152	1367	28	And their leader, Zemnarihah, was taken and hanged upon a tree, yea, even upon the top thereof until he was dead. And when they had hanged him until he was dead they did fell the tree to the earth, and did cry with a loud voice, saying:
36153	1367	29	May the Lord preserve his people in righteousness and in holiness of heart, that they may cause to be felled to the earth all who shall seek to slay them because of power and secret combinations, even as this man hath been felled to the earth.
36154	1367	30	And they did rejoice and cry again with one voice, saying: May the God of Abraham, and the God of Isaac, and the God of Jacob, protect this people in righteousness, so long as they shall call on the name of their God for protection.
36155	1367	31	And it came to pass that they did break forth, all as one, in singing, and praising their God for the great thing which he had done for them, in preserving them from falling into the hands of their enemies.
36156	1367	32	Yea, they did cry: Hosanna to the Most High God. And they did cry: Blessed be the name of the Lord God Almighty, the Most High God.
36157	1367	33	And their hearts were swollen with joy, unto the gushing out of many tears, because of the great goodness of God in delivering them out of the hands of their enemies; and they knew it was because of their repentance and their humility that they had been delivered from an everlasting destruction.
36158	1368	1	And now behold, there was not a living soul among all the people of the Nephites who did doubt in the least the words of all the holy prophets who had spoken; for they knew that it must needs be that they must be fulfilled.
36159	1368	2	And they knew that it must be expedient that Christ had come, because of the many signs which had been given, according to the words of the prophets; and because of the things which had come to pass already they knew that it must needs be that all things should come to pass according to that which had been spoken.
36160	1368	3	Therefore they did forsake all their sins, and their abominations, and their whoredoms, and did serve God with all diligence day and night.
36161	1368	4	And now it came to pass that when they had taken all the robbers prisoners, insomuch that none did escape who were not slain, they did cast their prisoners into prison, and did cause the word of God to be preached unto them; and as many as would repent of their sins and enter into a covenant that they would murder no more were set at liberty.
36162	1368	5	But as many as there were who did not enter into a covenant, and who did still continue to have those secret murders in their hearts, yea, as many as were found breathing out threatenings against their brethren were condemned and punished according to the law.
36163	1368	6	And thus they did put an end to all those wicked, and secret, and abominable combinations, in the which there was so much wickedness, and so many murders committed.
36164	1368	7	And thus had the twenty and second year passed away, and the twenty and third year also, and the twenty and fourth, and the twenty and fifth; and thus had twenty and five years passed away.
36165	1368	8	And there had many things transpired which, in the eyes of some, would be great and marvelous; nevertheless, they cannot all be written in this book; yea, this book cannot contain even a hundredth part of what was done among so many people in the space of twenty and five years;
36166	1368	9	But behold there are records which do contain all the proceedings of this people; and a shorter but true account was given by Nephi.
36167	1368	10	Therefore I have made my record of these things according to the record of Nephi, which was engraven on the plates which were called the plates of Nephi.
36168	1368	11	And behold, I do make the record on plates which I have made with mine own hands.
36169	1368	12	And behold, I am called Mormon, being called after the land of Mormon, the land in which Alma did establish the church among the people, yea, the first church which was established among them after their transgression.
36170	1368	13	Behold, I am a disciple of Jesus Christ, the Son of God. I have been called of him to declare his word among his people, that they might have everlasting life.
36171	1368	14	And it hath become expedient that I, according to the will of God, that the prayers of those who have gone hence, who were the holy ones, should be fulfilled according to their faith, should make a record of these things which have been done--
36172	1368	15	Yea, a small record of that which hath taken place from the time that Lehi left Jerusalem, even down until the present time.
36173	1368	16	Therefore I do make my record from the accounts which have been given by those who were before me, until the commencement of my day;
36174	1368	17	And then I do make a record of the things which I have seen with mine own eyes.
36175	1368	18	And I know the record which I make to be a just and a true record; nevertheless there are many things which, according to our language, we are not able to write.
36176	1368	19	And now I make an end of my saying, which is of myself, and proceed to give my account of the things which have been before me.
36177	1368	20	I am Mormon, and a pure descendant of Lehi. I have reason to bless my God and my Savior Jesus Christ, that he brought our fathers out of the land of Jerusalem, (and no one knew it save it were himself and those whom he brought out of that land) and that he hath given me and my people so much knowledge unto the salvation of our souls.
36178	1368	21	Surely he hath blessed the house of Jacob, and hath been merciful unto the seed of Joseph.
36179	1368	22	And insomuch as the children of Lehi have kept his commandments he hath blessed them and prospered them according to his word.
36180	1368	23	Yea, and surely shall he again bring a remnant of the seed of Joseph to the knowledge of the Lord their God.
36181	1368	24	And as surely as the Lord liveth, will he gather in from the four quarters of the earth all the remnant of the seed of Jacob, who are scattered abroad upon all the face of the earth.
36182	1368	25	And as he hath covenanted with all the house of Jacob, even so shall the covenant wherewith he hath covenanted with the house of Jacob be fulfilled in his own due time, unto the restoring all the house of Jacob unto the knowledge of the covenant that he hath covenanted with them.
36183	1368	26	And then shall they know their Redeemer, who is Jesus Christ, the Son of God; and then shall they be gathered in from the four quarters of the earth unto their own lands, from whence they have been dispersed; yea, as the Lord liveth so shall it be. Amen.
36184	1369	1	And now it came to pass that the people of the Nephites did all return to their own lands in the twenty and sixth year, every man, with his family, his flocks and his herds, his horses and his cattle, and all things whatsoever did belong unto them.
36185	1369	2	And it came to pass that they had not eaten up all their provisions; therefore they did take with them all that they had not devoured, of all their grain of every kind, and their gold, and their silver, and all their precious things, and they did return to their own lands and their possessions, both on the north and on the south, both on the land northward and on the land southward.
36186	1369	3	And they granted unto those robbers who had entered into a covenant to keep the peace of the land, who were desirous to remain Lamanites, lands, according to their numbers, that they might have, with their labors, wherewith to subsist upon; and thus they did establish peace in all the land.
36187	1369	4	And they began again to prosper and to wax great; and the twenty and sixth and seventh years passed away, and there was great order in the land; and they had formed their laws according to equity and justice.
36188	1369	5	And now there was nothing in all the land to hinder the people from prospering continually, except they should fall into transgression.
36189	1369	6	And now it was Gidgiddoni, and the judge, Lachoneus, and those who had been appointed leaders, who had established this great peace in the land.
36190	1369	7	And it came to pass that there were many cities built anew, and there were many old cities repaired.
36191	1369	8	And there were many highways cast up, and many roads made, which led from city to city, and from land to land, and from place to place.
36192	1369	9	And thus passed away the twenty and eighth year, and the people had continual peace.
36193	1369	10	But it came to pass in the twenty and ninth year there began to be some disputings among the people; and some were lifted up unto pride and boastings because of their exceedingly great riches, yea, even unto great persecutions;
36194	1369	11	For there were many merchants in the land, and also many lawyers, and many officers.
36195	1369	12	And the people began to be distinguished by ranks, according to their riches and their chances for learning; yea, some were ignorant because of their poverty, and others did receive great learning because of their riches.
36196	1369	13	Some were lifted up in pride, and others were exceedingly humble; some did return railing for railing, while others would receive railing and persecution and all manner of afflictions, and would not turn and revile again, but were humble and penitent before God.
36197	1369	14	And thus there became a great inequality in all the land, insomuch that the church began to be broken up; yea, insomuch that in the thirtieth year the church was broken up in all the land save it were among a few of the Lamanites who were converted unto the true faith; and they would not depart from it, for they were firm, and steadfast, and immovable, willing with all diligence to keep the commandments of the Lord.
36198	1369	15	Now the cause of this iniquity of the people was this--Satan had great power, unto the stirring up of the people to do all manner of iniquity, and to the puffing them up with pride, tempting them to seek for power, and authority, and riches, and the vain things of the world.
36199	1369	16	And thus Satan did lead away the hearts of the people to do all manner of iniquity; therefore they had enjoyed peace but a few years.
36200	1369	17	And thus, in the commencement of the thirtieth year--the people having been delivered up for the space of a long time to be carried about by the temptations of the devil whithersoever he desired to carry them, and to do whatsoever iniquity he desired they should--and thus in the commencement of this, the thirtieth year, they were in a state of awful wickedness.
36201	1369	18	Now they did not sin ignorantly, for they knew the will of God concerning them, for it had been taught unto them; therefore they did wilfully rebel against God.
36202	1369	19	And now it was in the days of Lachoneus, the son of Lachoneus, for Lachoneus did fill the seat of his father and did govern the people that year.
36203	1369	20	And there began to be men inspired from heaven and sent forth, standing among the people in all the land, preaching and testifying boldly of the sins and iniquities of the people, and testifying unto them concerning the redemption which the Lord would make for his people, or in other words, the resurrection of Christ; and they did testify boldly of his death and sufferings.
36204	1369	21	Now there were many of the people who were exceedingly angry because of those who testified of these things; and those who were angry were chiefly the chief judges, and they who had been high priests and lawyers; yea, all those who were lawyers were angry with those who testified of these things.
36205	1369	22	Now there was no lawyer nor judge nor high priest that could have power to condemn any one to death save their condemnation was signed by the governor of the land.
36206	1369	23	Now there were many of those who testified of the things pertaining to Christ who testified boldly, who were taken and put to death secretly by the judges, that the knowledge of their death came not unto the governor of the land until after their death.
36207	1369	24	Now behold, this was contrary to the laws of the land, that any man should be put to death except they had power from the governor of the land--
36208	1369	25	Therefore a complaint came up unto the land of Zarahemla, to the governor of the land, against these judges who had condemned the prophets of the Lord unto death, not according to the law.
36209	1369	26	Now it came to pass that they were taken and brought up before the judge, to be judged of the crime which they had done, according to the law which had been given by the people.
36210	1369	27	Now it came to pass that those judges had many friends and kindreds; and the remainder, yea, even almost all the lawyers and the high priests, did gather themselves together, and unite with the kindreds of those judges who were to be tried according to the law.
36211	1369	28	And they did enter into a covenant one with another, yea, even into that covenant which was given by them of old, which covenant was given and administered by the devil, to combine against all righteousness.
36212	1369	29	Therefore they did combine against the people of the Lord, and enter into a covenant to destroy them, and to deliver those who were guilty of murder from the grasp of justice, which was about to be administered according to the law.
36213	1369	30	And they did set at defiance the law and the rights of their country; and they did covenant one with another to destroy the governor, and to establish a king over the land, that the land should no more be at liberty but should be subject unto kings.
36214	1370	1	Now behold, I will show unto you that they did not establish a king over the land; but in this same year, yea, the thirtieth year, they did destroy upon the judgment-seat, yea, did murder the chief judge of the land.
36215	1370	2	And the people were divided one against another; and they did separate one from another into tribes, every man according to his family and his kindred and friends; and thus they did destroy the government of the land.
36216	1370	3	And every tribe did appoint a chief or a leader over them; and thus they became tribes and leaders of tribes.
36217	1370	4	Now behold, there was no man among them save he had much family and many kindreds and friends; therefore their tribes became exceedingly great.
36218	1370	5	Now all this was done, and there were no wars as yet among them; and all this iniquity had come upon the people because they did yield themselves unto the power of Satan.
36219	1370	6	And the regulations of the government were destroyed, because of the secret combination of the friends and kindreds of those who murdered the prophets.
36220	1370	7	And they did cause a great contention in the land, insomuch that the more righteous part of the people had nearly all become wicked; yea, there were but few righteous men among them.
36221	1370	8	And thus six years had not passed away since the more part of the people had turned from their righteousness, like the dog to his vomit, or like the sow to her wallowing in the mire.
36222	1370	9	Now this secret combination, which had brought so great iniquity upon the people, did gather themselves together, and did place at their head a man whom they did call Jacob;
36223	1370	10	And they did call him their king; therefore he became a king over this wicked band; and he was one of the chiefest who had given his voice against the prophets who testified of Jesus.
36224	1370	11	And it came to pass that they were not so strong in number as the tribes of the people, who were united together save it were their leaders did establish their laws, every one according to his tribe; nevertheless they were enemies; notwithstanding they were not a righteous people, yet they were united in the hatred of those who had entered into a covenant to destroy the government.
36225	1370	12	Therefore, Jacob seeing that their enemies were more numerous than they, he being the king of the band, therefore he commanded his people that they should take their flight into the northernmost part of the land, and there build up unto themselves a kingdom, until they were joined by dissenters, (for he flattered them that there would be many dissenters) and they become sufficiently strong to contend with the tribes of the people; and they did so.
36226	1370	13	And so speedy was their march that it could not be impeded until they had gone forth out of the reach of the people. And thus ended the thirtieth year; and thus were the affairs of the people of Nephi.
36227	1370	14	And it came to pass in the thirty and first year that they were divided into tribes, every man according to his family, kindred and friends; nevertheless they had come to an agreement that they would not go to war one with another; but they were not united as to their laws, and their manner of government, for they were established according to the minds of those who were their chiefs and their leaders. But they did establish very strict laws that one tribe should not trespass against another, insomuch that in some degree they had peace in the land; nevertheless, their hearts were turned from the Lord their God, and they did stone the prophets and did cast them out from among them.
36228	1370	15	And it came to pass that Nephi--having been visited by angels and also the voice of the Lord, therefore having seen angels, and being eye-witness, and having had power given unto him that he might know concerning the ministry of Christ, and also being eye-witness to their quick return from righteousness unto their wickedness and abominations;
36229	1370	16	Therefore, being grieved for the hardness of their hearts and the blindness of their minds--went forth among them in that same year, and began to testify, boldly, repentance and remission of sins through faith on the Lord Jesus Christ.
36230	1370	17	And he did minister many things unto them; and all of them cannot be written, and a part of them would not suffice, therefore they are not written in this book. And Nephi did minister with power and with great authority.
36231	1370	18	And it came to pass that they were angry with him, even because he had greater power than they, for it were not possible that they could disbelieve his words, for so great was his faith on the Lord Jesus Christ that angels did minister unto him daily.
36232	1370	19	And in the name of Jesus did he cast out devils and unclean spirits; and even his brother did he raise from the dead, after he had been stoned and suffered death by the people.
36233	1370	20	And the people saw it, and did witness of it, and were angry with him because of his power; and he did also do many more miracles, in the sight of the people, in the name of Jesus.
36234	1370	21	And it came to pass that the thirty and first year did pass away, and there were but few who were converted unto the Lord; but as many as were converted did truly signify unto the people that they had been visited by the power and Spirit of God, which was in Jesus Christ, in whom they believed.
36235	1370	22	And as many as had devils cast out from them, and were healed of their sicknesses and their infirmities, did truly manifest unto the people that they had been wrought upon by the Spirit of God, and had been healed; and they did show forth signs also and did do some miracles among the people.
36236	1370	23	Thus passed away the thirty and second year also. And Nephi did cry unto the people in the commencement of the thirty and third year; and he did preach unto them repentance and remission of sins.
36237	1370	24	Now I would have you to remember also, that there were none who were brought unto repentance who were not baptized with water.
36238	1370	25	Therefore, there were ordained of Nephi, men unto this ministry, that all such as should come unto them should be baptized with water, and this as a witness and a testimony before God, and unto the people, that they had repented and received a remission of their sins.
36239	1370	26	And there were many in the commencement of this year that were baptized unto repentance; and thus the more part of the year did pass away.
36240	1371	1	And now it came to pass that according to our record, and we know our record to be true, for behold, it was a just man who did keep the record--for he truly did many miracles in the name of Jesus; and there was not any man who could do a miracle in the name of Jesus save he were cleansed every whit from his iniquity--
36241	1371	2	And now it came to pass, if there was no mistake made by this man in the reckoning of our time, the thirty and third year had passed away;
36242	1371	3	And the people began to look with great earnestness for the sign which had been given by the prophet Samuel, the Lamanite, yea, for the time that there should be darkness for the space of three days over the face of the land.
36243	1371	4	And there began to be great doubtings and disputations among the people, notwithstanding so many signs had been given.
36244	1371	5	And it came to pass in the thirty and fourth year, in the first month, on the fourth day of the month, there arose a great storm, such an one as never had been known in all the land.
36245	1371	6	And there was also a great and terrible tempest; and there was terrible thunder, insomuch that it did shake the whole earth as if it was about to divide asunder.
36246	1371	7	And there were exceedingly sharp lightnings, such as never had been known in all the land.
36247	1371	8	And the city of Zarahemla did take fire.
36248	1371	9	And the city of Moroni did sink into the depths of the sea, and the inhabitants thereof were drowned.
36249	1371	10	And the earth was carried up upon the city of Moronihah, that in the place of the city there became a great mountain.
36250	1371	11	And there was a great and terrible destruction in the land southward.
36251	1371	12	But behold, there was a more great and terrible destruction in the land northward; for behold, the whole face of the land was changed, because of the tempest and the whirlwinds, and the thunderings and the lightnings, and the exceedingly great quaking of the whole earth;
36252	1371	13	And the highways were broken up, and the level roads were spoiled, and many smooth places became rough.
36253	1371	14	And many great and notable cities were sunk, and many were burned, and many were shaken till the buildings thereof had fallen to the earth, and the inhabitants thereof were slain, and the places were left desolate.
36254	1371	15	And there were some cities which remained; but the damage thereof was exceedingly great, and there were many in them who were slain.
36255	1371	16	And there were some who were carried away in the whirlwind; and whither they went no man knoweth, save they know that they were carried away.
36256	1371	17	And thus the face of the whole earth became deformed, because of the tempests, and the thunderings, and the lightnings, and the quaking of the earth.
36257	1371	18	And behold, the rocks were rent in twain; they were broken up upon the face of the whole earth, insomuch that they were found in broken fragments, and in seams and in cracks, upon all the face of the land.
36258	1371	19	And it came to pass that when the thunderings, and the lightnings, and the storm, and the tempest, and the quakings of the earth did cease--for behold, they did last for about the space of three hours; and it was said by some that the time was greater; nevertheless, all these great and terrible things were done in about the space of three hours--and then behold, there was darkness upon the face of the land.
36259	1371	20	And it came to pass that there was thick darkness upon all the face of the land, insomuch that the inhabitants thereof who had not fallen could feel the vapor of darkness;
36260	1371	21	And there could be no light, because of the darkness, neither candles, neither torches; neither could there be fire kindled with their fine and exceedingly dry wood, so that there could not be any light at all;
36261	1371	22	And there was not any light seen, neither fire, nor glimmer, neither the sun, nor the moon, nor the stars, for so great were the mists of darkness which were upon the face of the land.
36262	1371	23	And it came to pass that it did last for the space of three days that there was no light seen; and there was great mourning and howling and weeping among all the people continually; yea, great were the groanings of the people, because of the darkness and the great destruction which had come upon them.
36263	1371	24	And in one place they were heard to cry, saying: O that we had repented before this great and terrible day, and then would our brethren have been spared, and they would not have been burned in that great city Zarahemla.
36264	1371	25	And in another place they were heard to cry and mourn, saying: O that we had repented before this great and terrible day, and had not killed and stoned the prophets, and cast them out; then would our mothers and our fair daughters, and our children have been spared, and not have been buried up in that great city Moronihah. And thus were the howlings of the people great and terrible.
36265	1372	1	And it came to pass that there was a voice heard among all the inhabitants of the earth, upon all the face of this land, crying:
36266	1372	2	Wo, wo, wo unto this people; wo unto the inhabitants of the whole earth except they shall repent; for the devil laugheth, and his angels rejoice, because of the slain of the fair sons and daughters of my people; and it is because of their iniquity and abominations that they are fallen!
36267	1372	3	Behold, that great city Zarahemla have I burned with fire, and the inhabitants thereof.
36268	1372	4	And behold, that great city Moroni have I caused to be sunk in the depths of the sea, and the inhabitants thereof to be drowned.
36269	1372	5	And behold, that great city Moronihah have I covered with earth, and the inhabitants thereof, to hide their iniquities and their abominations from before my face, that the blood of the prophets and the saints shall not come any more unto me against them.
36270	1372	6	And behold, the city of Gilgal have I caused to be sunk, and the inhabitants thereof to be buried up in the depths of the earth;
36271	1372	7	Yea, and the city of Onihah and the inhabitants thereof, and the city of Mocum and the inhabitants thereof, and the city of Jerusalem and the inhabitants thereof; and waters have I caused to come up in the stead thereof, to hide their wickedness and abominations from before my face, that the blood of the prophets and the saints shall not come up any more unto me against them.
36272	1372	8	And behold, the city of Gadiandi, and the city of Gadiomnah, and the city of Jacob, and the city of Gimgimno, all these have I caused to be sunk, and made hills and valleys in the places thereof; and the inhabitants thereof have I buried up in the depths of the earth, to hide their wickedness and abominations from before my face, that the blood of the prophets and the saints should not come up any more unto me against them.
36273	1372	9	And behold, that great city Jacobugath, which was inhabited by the people of king Jacob, have I caused to be burned with fire because of their sins and their wickedness, which was above all the wickedness of the whole earth, because of their secret murders and combinations; for it was they that did destroy the peace of my people and the government of the land; therefore I did cause them to be burned, to destroy them from before my face, that the blood of the prophets and the saints should not come up unto me any more against them.
36274	1372	10	And behold, the city of Laman, and the city of Josh, and the city of Gad, and the city of Kishkumen, have I caused to be burned with fire, and the inhabitants thereof, because of their wickedness in casting out the prophets, and stoning those whom I did send to declare unto them concerning their wickedness and their abominations.
36275	1372	11	And because they did cast them all out, that there were none righteous among them, I did send down fire and destroy them, that their wickedness and abominations might be hid from before my face, that the blood of the prophets and the saints whom I sent among them might not cry unto me from the ground against them.
36276	1372	12	And many great destructions have I caused to come upon this land, and upon this people, because of their wickedness and their abominations.
36277	1372	13	O all ye that are spared because ye were more righteous than they, will ye not now return unto me, and repent of your sins, and be converted, that I may heal you?
36278	1372	14	Yea, verily I say unto you, if ye will come unto me ye shall have eternal life. Behold, mine arm of mercy is extended towards you, and whosoever will come, him will I receive; and blessed are those who come unto me.
36279	1372	15	Behold, I am Jesus Christ the Son of God. I created the heavens and the earth, and all things that in them are. I was with the Father from the beginning. I am in the Father, and the Father in me; and in me hath the Father glorified his name.
36280	1372	16	I came unto my own, and my own received me not. And the scriptures concerning my coming are fulfilled.
36281	1372	17	And as many as have received me, to them have I given to become the sons of God; and even so will I to as many as shall believe on my name, for behold, by me redemption cometh, and in me is the law of Moses fulfilled.
36282	1372	18	I am the light and the life of the world. I am Alpha and Omega, the beginning and the end.
36283	1372	19	And ye shall offer up unto me no more the shedding of blood; yea, your sacrifices and your burnt offerings shall be done away, for I will accept none of your sacrifices and your burnt offerings.
36284	1372	20	And ye shall offer for a sacrifice unto me a broken heart and a contrite spirit. And whoso cometh unto me with a broken heart and a contrite spirit, him will I baptize with fire and with the Holy Ghost, even as the Lamanites, because of their faith in me at the time of their conversion, were baptized with fire and with the Holy Ghost, and they knew it not.
36285	1372	21	Behold, I have come unto the world to bring redemption unto the world, to save the world from sin.
36286	1372	22	Therefore, whoso repenteth and cometh unto me as a little child, him will I receive, for of such is the kingdom of God. Behold, for such I have laid down my life, and have taken it up again; therefore repent, and come unto me ye ends of the earth, and be saved.
36287	1373	1	And now behold, it came to pass that all the people of the land did hear these sayings, and did witness of it. And after these sayings there was silence in the land for the space of many hours;
36288	1373	2	For so great was the astonishment of the people that they did cease lamenting and howling for the loss of their kindred which had been slain; therefore there was silence in all the land for the space of many hours.
36289	1373	3	And it came to pass that there came a voice again unto the people, and all the people did hear, and did witness of it, saying:
36290	1373	4	O ye people of these great cities which have fallen, who are descendants of Jacob, yea, who are of the house of Israel, how oft have I gathered you as a hen gathereth her chickens under her wings, and have nourished you.
36291	1373	5	And again, how oft would I have gathered you as a hen gathereth her chickens under her wings, yea, O ye people of the house of Israel, who have fallen; yea, O ye people of the house of Israel, ye that dwell at Jerusalem, as ye that have fallen; yea, how oft would I have gathered you as a hen gathereth her chickens, and ye would not.
36292	1373	6	O ye house of Israel whom I have spared, how oft will I gather you as a hen gathereth her chickens under her wings, if ye will repent and return unto me with full purpose of heart.
36293	1373	7	But if not, O house of Israel, the places of your dwellings shall become desolate until the time of the fulfilling of the covenant to your fathers.
36294	1373	8	And now it came to pass that after the people had heard these words, behold, they began to weep and howl again because of the loss of their kindred and friends.
36295	1373	9	And it came to pass that thus did the three days pass away. And it was in the morning, and the darkness dispersed from off the face of the land, and the earth did cease to tremble, and the rocks did cease to rend, and the dreadful groanings did cease, and all the tumultuous noises did pass away.
36296	1373	10	And the earth did cleave together again, that it stood; and the mourning, and the weeping, and the wailing of the people who were spared alive did cease; and their mourning was turned into joy, and their lamentations into the praise and thanksgiving unto the Lord Jesus Christ, their Redeemer.
36297	1373	11	And thus far were the scriptures fulfilled which had been spoken by the prophets.
36298	1373	12	And it was the more righteous part of the people who were saved, and it was they who received the prophets and stoned them not; and it was they who had not shed the blood of the saints, who were spared--
36299	1373	13	And they were spared and were not sunk and buried up in the earth; and they were not drowned in the depths of the sea; and they were not burned by fire, neither were they fallen upon and crushed to death; and they were not carried away in the whirlwind; neither were they overpowered by the vapor of smoke and of darkness.
36300	1373	14	And now, whoso readeth, let him understand; he that hath the scriptures, let him search them, and see and behold if all these deaths and destructions by fire, and by smoke, and by tempests, and by whirlwinds, and by the opening of the earth to receive them, and all these things are not unto the fulfilling of the prophecies of many of the holy prophets.
36301	1373	15	Behold, I say unto you, Yea, many have testified of these things at the coming of Christ, and were slain because they testified of these things.
36302	1373	16	Yea, the prophet Zenos did testify of these things, and also Zenock spake concerning these things, because they testified particularly concerning us, who are the remnant of their seed.
36303	1373	17	Behold, our father Jacob also testified concerning a remnant of the seed of Joseph. And behold, are not we a remnant of the seed of Joseph? And these things which testify of us, are they not written upon the plates of brass which our father Lehi brought out of Jerusalem?
36304	1373	18	And it came to pass that in the ending of the thirty and fourth year, behold, I will show unto you that the people of Nephi who were spared, and also those who had been called Lamanites, who had been spared, did have great favors shown unto them, and great blessings poured out upon their heads, insomuch that soon after the ascension of Christ into heaven he did truly manifest himself unto them--
36305	1373	19	Showing his body unto them, and ministering unto them; and an account of his ministry shall be given hereafter. Therefore for this time I make an end of my sayings.
36306	1374	1	And now it came to pass that there were a great multitude gathered together, of the people of Nephi, round about the temple which was in the land Bountiful; and they were marveling and wondering one with another, and were showing one to another the great and marvelous change which had taken place.
36307	1374	2	And they were also conversing about this Jesus Christ, of whom the sign had been given concerning his death.
36308	1374	3	And it came to pass that while they were thus conversing one with another, they heard a voice as if it came out of heaven; and they cast their eyes round about, for they understood not the voice which they heard; and it was not a harsh voice, neither was it a loud voice; nevertheless, and notwithstanding it being a small voice it did pierce them that did hear to the center, insomuch that there was no part of their frame that it did not cause to quake; yea, it did pierce them to the very soul, and did cause their hearts to burn.
36309	1374	4	And it came to pass that again they heard the voice, and they understood it not.
36310	1374	5	And again the third time they did hear the voice, and did open their ears to hear it; and their eyes were towards the sound thereof; and they did look steadfastly towards heaven, from whence the sound came.
36311	1374	6	And behold, the third time they did understand the voice which they heard; and it said unto them:
36312	1374	7	Behold my Beloved Son, in whom I am well pleased, in whom I have glorified my name--hear ye him.
36313	1374	8	And it came to pass, as they understood they cast their eyes up again towards heaven; and behold, they saw a Man descending out of heaven; and he was clothed in a white robe; and he came down and stood in the midst of them; and the eyes of the whole multitude were turned upon him, and they durst not open their mouths, even one to another, and wist not what it meant, for they thought it was an angel that had appeared unto them.
36314	1374	9	And it came to pass that he stretched forth his hand and spake unto the people, saying:
36315	1374	10	Behold, I am Jesus Christ, whom the prophets testified shall come into the world.
36316	1374	11	And behold, I am the light and the life of the world; and I have drunk out of that bitter cup which the Father hath given me, and have glorified the Father in taking upon me the sins of the world, in the which I have suffered the will of the Father in all things from the beginning.
36317	1374	12	And it came to pass that when Jesus had spoken these words the whole multitude fell to the earth; for they remembered that it had been prophesied among them that Christ should show himself unto them after his ascension into heaven.
36318	1374	13	And it came to pass that the Lord spake unto them saying:
36319	1374	14	Arise and come forth unto me, that ye may thrust your hands into my side, and also that ye may feel the prints of the nails in my hands and in my feet, that ye may know that I am the God of Israel, and the God of the whole earth, and have been slain for the sins of the world.
36320	1374	15	And it came to pass that the multitude went forth, and thrust their hands into his side, and did feel the prints of the nails in his hands and in his feet; and this they did do, going forth one by one until they had all gone forth, and did see with their eyes and did feel with their hands, and did know of a surety and did bear record, that it was he, of whom it was written by the prophets, that should come.
36321	1374	16	And when they had all gone forth and had witnessed for themselves, they did cry out with one accord, saying:
36322	1374	17	Hosanna! Blessed be the name of the Most High God! And they did fall down at the feet of Jesus, and did worship him.
36323	1374	18	And it came to pass that he spake unto Nephi (for Nephi was among the multitude) and he commanded him that he should come forth.
36324	1374	19	And Nephi arose and went forth, and bowed himself before the Lord and did kiss his feet.
36325	1374	20	And the Lord commanded him that he should arise. And he arose and stood before him.
36326	1374	21	And the Lord said unto him: I give unto you power that ye shall baptize this people when I am again ascended into heaven.
36327	1374	22	And again the Lord called others, and said unto them likewise; and he gave unto them power to baptize. And he said unto them: On this wise shall ye baptize; and there shall be no disputations among you.
36328	1374	23	Verily I say unto you, that whoso repenteth of his sins through your words, and desireth to be baptized in my name, on this wise shall ye baptize them--Behold, ye shall go down and stand in the water, and in my name shall ye baptize them.
36329	1374	24	And now behold, these are the words which ye shall say, calling them by name, saying:
36330	1374	25	Having authority given me of Jesus Christ, I baptize you in the name of the Father, and of the Son, and of the Holy Ghost. Amen.
36331	1374	26	And then shall ye immerse them in the water, and come forth again out of the water.
36332	1374	27	And after this manner shall ye baptize in my name; for behold, verily I say unto you, that the Father, and the Son, and the Holy Ghost are one; and I am in the Father, and the Father in me, and the Father and I are one.
36333	1374	28	And according as I have commanded you thus shall ye baptize. And there shall be no disputations among you, as there have hitherto been; neither shall there be disputations among you concerning the points of my doctrine, as there have hitherto been.
36334	1374	29	For verily, verily I say unto you, he that hath the spirit of contention is not of me, but is of the devil, who is the father of contention, and he stirreth up the hearts of men to contend with anger, one with another.
36335	1374	30	Behold, this is not my doctrine, to stir up the hearts of men with anger, one against another; but this is my doctrine, that such things should be done away.
36336	1374	31	Behold, verily, verily, I say unto you, I will declare unto you my doctrine.
36337	1374	32	And this is my doctrine, and it is the doctrine which the Father hath given unto me; and I bear record of the Father, and the Father beareth record of me, and the Holy Ghost beareth record of the Father and me; and I bear record that the Father commandeth all men, everywhere, to repent and believe in me.
36338	1374	33	And whoso believeth in me, and is baptized, the same shall be saved; and they are they who shall inherit the kingdom of God.
36339	1374	34	And whoso believeth not in me, and is not baptized, shall be damned.
36340	1374	35	Verily, verily, I say unto you, that this is my doctrine, and I bear record of it from the Father; and whoso believeth in me believeth in the Father also; and unto him will the Father bear record of me, for he will visit him with fire and with the Holy Ghost.
36341	1374	36	And thus will the Father bear record of me, and the Holy Ghost will bear record unto him of the Father and me; for the Father, and I, and the Holy Ghost are one.
36342	1374	37	And again I say unto you, ye must repent, and become as a little child, and be baptized in my name, or ye can in nowise receive these things.
36343	1374	38	And again I say unto you, ye must repent, and be baptized in my name, and become as a little child, or ye can in nowise inherit the kingdom of God.
36344	1374	39	Verily, verily, I say unto you, that this is my doctrine, and whoso buildeth upon this buildeth upon my rock, and the gates of hell shall not prevail against them.
36345	1374	40	And whoso shall declare more or less than this, and establish it for my doctrine, the same cometh of evil, and is not built upon my rock; but he buildeth upon a sandy foundation, and the gates of hell stand open to receive such when the floods come and the winds beat upon them.
36346	1374	41	Therefore, go forth unto this people, and declare the words which I have spoken, unto the ends of the earth.
36347	1375	1	And it came to pass that when Jesus had spoken these words unto Nephi, and to those who had been called, (now the number of them who had been called, and received power and authority to baptize, was twelve) and behold, he stretched forth his hand unto the multitude, and cried unto them, saying: Blessed are ye if ye shall give heed unto the words of these twelve whom I have chosen from among you to minister unto you, and to be your servants; and unto them I have given power that they may baptize you with water; and after that ye are baptized with water, behold, I will baptize you with fire and with the Holy Ghost; therefore blessed are ye if ye shall believe in me and be baptized, after that ye have seen me and know that I am.
36348	1375	2	And again, more blessed are they who shall believe in your words because that ye shall testify that ye have seen me, and that ye know that I am. Yea, blessed are they who shall believe in your words, and come down into the depths of humility and be baptized, for they shall be visited with fire and with the Holy Ghost, and shall receive a remission of their sins.
36349	1375	3	Yea, blessed are the poor in spirit who come unto me, for theirs is the kingdom of heaven.
36350	1375	4	And again, blessed are all they that mourn, for they shall be comforted.
36351	1375	5	And blessed are the meek, for they shall inherit the earth.
36352	1375	6	And blessed are all they who do hunger and thirst after righteousness, for they shall be filled with the Holy Ghost.
36353	1375	7	And blessed are the merciful, for they shall obtain mercy.
36354	1375	8	And blessed are all the pure in heart, for they shall see God.
36355	1375	9	And blessed are all the peacemakers, for they shall be called the children of God.
36356	1375	10	And blessed are all they who are persecuted for my name's sake, for theirs is the kingdom of heaven.
36357	1375	11	And blessed are ye when men shall revile you and persecute, and shall say all manner of evil against you falsely, for my sake;
36358	1375	12	For ye shall have great joy and be exceedingly glad, for great shall be your reward in heaven; for so persecuted they the prophets who were before you.
36359	1375	13	Verily, verily, I say unto you, I give unto you to be the salt of the earth; but if the salt shall lose its savor wherewith shall the earth be salted? The salt shall be thenceforth good for nothing, but to be cast out and to be trodden under foot of men.
36360	1375	14	Verily, verily, I say unto you, I give unto you to be the light of this people. A city that is set on a hill cannot be hid.
36361	1375	15	Behold, do men light a candle and put it under a bushel? Nay, but on a candlestick, and it giveth light to all that are in the house;
36362	1375	16	Therefore let your light so shine before this people, that they may see your good works and glorify your Father who is in heaven.
36363	1375	17	Think not that I am come to destroy the law or the prophets. I am not come to destroy but to fulfil;
36364	1375	18	For verily I say unto you, one jot nor one tittle hath not passed away from the law, but in me it hath all been fulfilled.
36365	1375	19	And behold, I have given you the law and the commandments of my Father, that ye shall believe in me, and that ye shall repent of your sins, and come unto me with a broken heart and a contrite spirit. Behold, ye have the commandments before you, and the law is fulfilled.
36366	1375	20	Therefore come unto me and be ye saved; for verily I say unto you, that except ye shall keep my commandments, which I have commanded you at this time, ye shall in no case enter into the kingdom of heaven.
36367	1375	21	Ye have heard that it hath been said by them of old time, and it is also written before you, that thou shalt not kill, and whosoever shall kill shall be in danger of the judgment of God;
36368	1375	22	But I say unto you, that whosoever is angry with his brother shall be in danger of his judgment. And whosoever shall say to his brother, Raca, shall be in danger of the council; and whosoever shall say, Thou fool, shall be in danger of hell fire.
36369	1375	23	Therefore, if ye shall come unto me, or shall desire to come unto me, and rememberest that thy brother hath aught against thee--
36370	1375	24	Go thy way unto thy brother, and first be reconciled to thy brother, and then come unto me with full purpose of heart, and I will receive you.
36371	1375	25	Agree with thine adversary quickly while thou art in the way with him, lest at any time he shall get thee, and thou shalt be cast into prison.
36372	1375	26	Verily, verily, I say unto thee, thou shalt by no means come out thence until thou hast paid the uttermost senine. And while ye are in prison can ye pay even one senine? Verily, verily, I say unto you, Nay.
36373	1375	27	Behold, it is written by them of old time, that thou shalt not commit adultery;
36374	1375	28	But I say unto you, that whosoever looketh on a woman, to lust after her, hath committed adultery already in his heart.
36375	1375	29	Behold, I give unto you a commandment, that ye suffer none of these things to enter into your heart;
36376	1375	30	For it is better that ye should deny yourselves of these things, wherein ye will take up your cross, than that ye should be cast into hell.
36377	1375	31	It hath been written, that whosoever shall put away his wife, let him give her a writing of divorcement.
36378	1375	32	Verily, verily, I say unto you, that whosoever shall put away his wife, saving for the cause of fornication, causeth her to commit adultery; and whoso shall marry her who is divorced committeth adultery.
36379	1375	33	And again it is written, thou shalt not forswear thyself, but shalt perform unto the Lord thine oaths;
36380	1375	34	But verily, verily, I say unto you, swear not at all; neither by heaven, for it is God's throne;
36381	1375	35	Nor by the earth, for it is his footstool;
36382	1375	36	Neither shalt thou swear by thy head, because thou canst not make one hair black or white;
36383	1375	37	But let your communication be Yea, yea; Nay, nay; for whatsoever cometh of more than these is evil.
36384	1375	38	And behold, it is written, an eye for an eye, and a tooth for a tooth;
36385	1375	39	But I say unto you, that ye shall not resist evil, but whosoever shall smite thee on thy right cheek, turn to him the other also;
36386	1375	40	And if any man will sue thee at the law and take away thy coat, let him have thy cloak also;
36387	1375	41	And whosoever shall compel thee to go a mile, go with him twain.
36388	1375	42	Give to him that asketh thee, and from him that would borrow of thee turn thou not away.
36389	1375	43	And behold it is written also, that thou shalt love thy neighbor and hate thine enemy;
36390	1375	44	But behold I say unto you, love your enemies, bless them that curse you, do good to them that hate you, and pray for them who despitefully use you and persecute you;
36391	1375	45	That ye may be the children of your Father who is in heaven; for he maketh his sun to rise on the evil and on the good.
36392	1375	46	Therefore those things which were of old time, which were under the law, in me are all fulfilled.
36393	1375	47	Old things are done away, and all things have become new.
36394	1375	48	Therefore I would that ye should be perfect even as I, or your Father who is in heaven is perfect.
36395	1376	1	Verily, verily, I say that I would that ye should do alms unto the poor; but take heed that ye do not your alms before men to be seen of them; otherwise ye have no reward of your Father who is in heaven.
36396	1376	2	Therefore, when ye shall do your alms do not sound a trumpet before you, as will hypocrites do in the synagogues and in the streets, that they may have glory of men. Verily I say unto you, they have their reward.
36397	1376	3	But when thou doest alms let not thy left hand know what thy right hand doeth;
36398	1376	4	That thine alms may be in secret; and thy Father who seeth in secret, himself shall reward thee openly.
36399	1376	5	And when thou prayest thou shalt not do as the hypocrites, for they love to pray, standing in the synagogues and in the corners of the streets, that they may be seen of men. Verily I say unto you, they have their reward.
36400	1376	6	But thou, when thou prayest, enter into thy closet, and when thou hast shut thy door, pray to thy Father who is in secret; and thy Father, who seeth in secret, shall reward thee openly.
36401	1376	7	But when ye pray, use not vain repetitions, as the heathen, for they think that they shall be heard for their much speaking.
36402	1376	8	Be not ye therefore like unto them, for your Father knoweth what things ye have need of before ye ask him.
36403	1376	9	After this manner therefore pray ye: Our Father who art in heaven, hallowed be thy name.
36404	1376	10	Thy will be done on earth as it is in heaven.
36405	1376	11	And forgive us our debts, as we forgive our debtors.
36406	1376	12	And lead us not into temptation, but deliver us from evil.
36407	1376	13	For thine is the kingdom, and the power, and the glory, forever. Amen.
36408	1376	14	For, if ye forgive men their trespasses your heavenly Father will also forgive you;
36409	1376	15	But if ye forgive not men their trespasses neither will your Father forgive your trespasses.
36410	1376	16	Moreover, when ye fast be not as the hypocrites, of a sad countenance, for they disfigure their faces that they may appear unto men to fast. Verily I say unto you, they have their reward.
36411	1376	17	But thou, when thou fastest, anoint thy head, and wash thy face;
36412	1376	18	That thou appear not unto men to fast, but unto thy Father, who is in secret; and thy Father, who seeth in secret, shall reward thee openly.
36413	1376	19	Lay not up for yourselves treasures upon earth, where moth and rust doth corrupt, and thieves break through and steal;
36414	1376	20	But lay up for yourselves treasures in heaven, where neither moth nor rust doth corrupt, and where thieves do not break through nor steal.
36415	1376	21	For where your treasure is, there will your heart be also.
36416	1376	22	The light of the body is the eye; if, therefore, thine eye be single, thy whole body shall be full of light.
36417	1376	23	But if thine eye be evil, thy whole body shall be full of darkness. If, therefore, the light that is in thee be darkness, how great is that darkness!
36418	1376	24	No man can serve two masters; for either he will hate the one and love the other, or else he will hold to the one and despise the other. Ye cannot serve God and Mammon.
36419	1376	25	And now it came to pass that when Jesus had spoken these words he looked upon the twelve whom he had chosen, and said unto them: Remember the words which I have spoken. For behold, ye are they whom I have chosen to minister unto this people. Therefore I say unto you, take no thought for your life, what ye shall eat, or what ye shall drink; nor yet for your body, what ye shall put on. Is not the life more than meat, and the body than raiment?
36420	1376	26	Behold the fowls of the air, for they sow not, neither do they reap nor gather into barns; yet your heavenly Father feedeth them. Are ye not much better than they?
36421	1376	27	Which of you by taking thought can add one cubit unto his stature?
36422	1376	28	And why take ye thought for raiment? Consider the lilies of the field how they grow; they toil not, neither do they spin;
36423	1376	29	And yet I say unto you, that even Solomon, in all his glory, was not arrayed like one of these.
36424	1376	30	Wherefore, if God so clothe the grass of the field, which today is, and tomorrow is cast into the oven, even so will he clothe you, if ye are not of little faith.
36425	1376	31	Therefore take no thought, saying, What shall we eat? or, What shall we drink? or, Wherewithal shall we be clothed?
36426	1376	32	For your heavenly Father knoweth that ye have need of all these things.
36427	1376	33	But seek ye first the kingdom of God and his righteousness, and all these things shall be added unto you.
36428	1376	34	Take therefore no thought for the morrow, for the morrow shall take thought for the things of itself. Sufficient is the day unto the evil thereof.
36429	1377	1	And now it came to pass that when Jesus had spoken these words he turned again to the multitude, and did open his mouth unto them again, saying: Verily, verily, I say unto you, Judge not, that ye be not judged.
36430	1377	2	For with what judgment ye judge, ye shall be judged; and with what measure ye mete, it shall be measured to you again.
36431	1377	3	And why beholdest thou the mote that is in thy brother's eye, but considerest not the beam that is in thine own eye?
36432	1377	4	Or how wilt thou say to thy brother: Let me pull the mote out of thine eye--and behold, a beam is in thine own eye?
36433	1377	5	Thou hypocrite, first cast the beam out of thine own eye; and then shalt thou see clearly to cast the mote out of thy brother's eye.
36434	1377	6	Give not that which is holy unto the dogs, neither cast ye your pearls before swine, lest they trample them under their feet, and turn again and rend you.
36435	1377	7	Ask, and it shall be given unto you; seek, and ye shall find; knock, and it shall be opened unto you.
36436	1377	8	For every one that asketh, receiveth; and he that seeketh, findeth; and to him that knocketh, it shall be opened.
36437	1377	9	Or what man is there of you, who, if his son ask bread, will give him a stone?
36438	1377	10	Or if he ask a fish, will he give him a serpent?
36439	1377	11	If ye then, being evil, know how to give good gifts unto your children, how much more shall your Father who is in heaven give good things to them that ask him?
36440	1377	12	Therefore, all things whatsoever ye would that men should do to you, do ye even so to them, for this is the law and the prophets.
36441	1377	13	Enter ye in at the strait gate; for wide is the gate, and broad is the way, which leadeth to destruction, and many there be who go in thereat;
36442	1377	14	Because strait is the gate, and narrow is the way, which leadeth unto life, and few there be that find it.
36443	1377	15	Beware of false prophets, who come to you in sheep's clothing, but inwardly they are ravening wolves.
36444	1377	16	Ye shall know them by their fruits. Do men gather grapes of thorns, or figs of thistles?
36445	1377	17	Even so every good tree bringeth forth good fruit; but a corrupt tree bringeth forth evil fruit.
36446	1377	18	A good tree cannot bring forth evil fruit, neither a corrupt tree bring forth good fruit.
36447	1377	19	Every tree that bringeth not forth good fruit is hewn down, and cast into the fire.
36448	1377	20	Wherefore, by their fruits ye shall know them.
36449	1377	21	Not every one that saith unto me, Lord, Lord, shall enter into the kingdom of heaven; but he that doeth the will of my Father who is in heaven.
36450	1377	22	Many will say to me in that day: Lord, Lord, have we not prophesied in thy name, and in thy name have cast out devils, and in thy name done many wonderful works?
36451	1377	23	And then will I profess unto them: I never knew you; depart from me, ye that work iniquity.
36452	1377	24	Therefore, whoso heareth these sayings of mine and doeth them, I will liken him unto a wise man, who built his house upon a rock--
36453	1377	25	And the rain descended, and the floods came, and the winds blew, and beat upon that house; and it fell not, for it was founded upon a rock.
36454	1377	26	And every one that heareth these sayings of mine and doeth them not shall be likened unto a foolish man, who built his house upon the sand--
36455	1377	27	And the rain descended, and the floods came, and the winds blew, and beat upon that house; and it fell, and great was the fall of it.
36456	1378	1	And now it came to pass that when Jesus had ended these sayings he cast his eyes round about on the multitude, and said unto them: Behold, ye have heard the things which I taught before I ascended to my Father; therefore, whoso remembereth these sayings of mine and doeth them, him will I raise up at the last day.
36457	1378	2	And it came to pass that when Jesus had said these words he perceived that there were some among them who marveled, and wondered what he would concerning the law of Moses; for they understood not the saying that old things had passed away, and that all things had become new.
36458	1378	3	And he said unto them: Marvel not that I said unto you that old things had passed away, and that all things had become new.
36459	1378	4	Behold, I say unto you that the law is fulfilled that was given unto Moses.
36460	1378	5	Behold, I am he that gave the law, and I am he who covenanted with my people Israel; therefore, the law in me is fulfilled, for I have come to fulfil the law; therefore it hath an end.
36461	1378	6	Behold, I do not destroy the prophets, for as many as have not been fulfilled in me, verily I say unto you, shall all be fulfilled.
36462	1378	7	And because I said unto you that old things have passed away, I do not destroy that which hath been spoken concerning things which are to come.
36463	1378	8	For behold, the covenant which I have made with my people is not all fulfilled; but the law which was given unto Moses hath an end in me.
36464	1378	9	Behold, I am the law, and the light. Look unto me, and endure to the end, and ye shall live; for unto him that endureth to the end will I give eternal life.
36465	1378	10	Behold, I have given unto you the commandments; therefore keep my commandments. And this is the law and the prophets, for they truly testified of me.
36466	1378	11	And now it came to pass that when Jesus had spoken these words, he said unto those twelve whom he had chosen:
36467	1378	12	Ye are my disciples; and ye are a light unto this people, who are a remnant of the house of Joseph.
36468	1378	13	And behold, this is the land of your inheritance; and the Father hath given it unto you.
36469	1378	14	And not at any time hath the Father given me commandment that I should tell it unto your brethren at Jerusalem.
36470	1378	15	Neither at any time hath the Father given me commandment that I should tell unto them concerning the other tribes of the house of Israel, whom the Father hath led away out of the land.
36471	1378	16	This much did the Father command me, that I should tell unto them:
36472	1378	17	That other sheep I have which are not of this fold; them also I must bring, and they shall hear my voice; and there shall be one fold, and one shepherd.
36473	1378	18	And now, because of stiffneckedness and unbelief they understood not my word; therefore I was commanded to say no more of the Father concerning this thing unto them.
36474	1378	19	But, verily, I say unto you that the Father hath commanded me, and I tell it unto you, that ye were separated from among them because of their iniquity; therefore it is because of their iniquity that they know not of you.
36475	1378	20	And verily, I say unto you again that the other tribes hath the Father separated from them; and it is because of their iniquity that they know not of them.
36476	1378	21	And verily I say unto you, that ye are they of whom I said: Other sheep I have which are not of this fold; them also I must bring, and they shall hear my voice; and there shall be one fold, and one shepherd.
36477	1378	22	And they understood me not, for they supposed it had been the Gentiles; for they understood not that the Gentiles should be converted through their preaching.
36478	1378	23	And they understood me not that I said they shall hear my voice; and they understood me not that the Gentiles should not at any time hear my voice--that I should not manifest myself unto them save it were by the Holy Ghost.
36479	1378	24	But behold, ye have both heard my voice, and seen me; and ye are my sheep, and ye are numbered among those whom the Father hath given me.
36480	1379	1	And verily, verily, I say unto you that I have other sheep, which are not of this land, neither of the land of Jerusalem, neither in any parts of that land round about whither I have been to minister.
36481	1379	2	For they of whom I speak are they who have not as yet heard my voice; neither have I at any time manifested myself unto them.
36482	1379	3	But I have received a commandment of the Father that I shall go unto them, and that they shall hear my voice, and shall be numbered among my sheep, that there may be one fold and one shepherd; therefore I go to show myself unto them.
36483	1379	4	And I command you that ye shall write these sayings after I am gone, that if it so be that my people at Jerusalem, they who have seen me and been with me in my ministry, do not ask the Father in my name, that they may receive a knowledge of you by the Holy Ghost, and also of the other tribes whom they know not of, that these sayings which ye shall write shall be kept and shall be manifested unto the Gentiles, that through the fulness of the Gentiles, the remnant of their seed, who shall be scattered forth upon the face of the earth because of their unbelief, may be brought in, or may be brought to a knowledge of me, their Redeemer.
36484	1379	5	And then will I gather them in from the four quarters of the earth; and then will I fulfil the covenant which the Father hath made unto all the people of the house of Israel.
36485	1379	6	And blessed are the Gentiles, because of their belief in me, in and of the Holy Ghost, which witnesses unto them of me and of the Father.
36486	1379	7	Behold, because of their belief in me, saith the Father, and because of the unbelief of you, O house of Israel, in the latter day shall the truth come unto the Gentiles, that the fulness of these things shall be made known unto them.
36487	1379	8	But wo, saith the Father, unto the unbelieving of the Gentiles--for notwithstanding they have come forth upon the face of this land, and have scattered my people who are of the house of Israel; and my people who are of the house of Israel have been cast out from among them, and have been trodden under feet by them;
36488	1379	9	And because of the mercies of the Father unto the Gentiles, and also the judgments of the Father upon my people who are of the house of Israel, verily, verily, I say unto you, that after all this, and I have caused my people who are of the house of Israel to be smitten, and to be afflicted, and to be slain, and to be cast out from among them, and to become hated by them, and to become a hiss and a byword among them--
36489	1379	10	And thus commandeth the Father that I should say unto you: At that day when the Gentiles shall sin against my gospel, and shall reject the fulness of my gospel, and shall be lifted up in the pride of their hearts above all nations, and above all the people of the whole earth, and shall be filled with all manner of lyings, and of deceits, and of mischiefs, and all manner of hypocrisy, and murders, and priestcrafts, and whoredoms, and of secret abominations; and if they shall do all those things, and shall reject the fulness of my gospel, behold, saith the Father, I will bring the fulness of my gospel from among them.
36490	1379	11	And then will I remember my covenant which I have made unto my people, O house of Israel, and I will bring my gospel unto them.
36491	1379	12	And I will show unto thee, O house of Israel, that the Gentiles shall not have power over you; but I will remember my covenant unto you, O house of Israel, and ye shall come unto the knowledge of the fulness of my gospel.
36492	1379	13	But if the Gentiles will repent and return unto me, saith the Father, behold they shall be numbered among my people, O house of Israel.
36493	1379	14	And I will not suffer my people, who are of the house of Israel, to go through among them, and tread them down, saith the Father.
36494	1379	15	But if they will not turn unto me, and hearken unto my voice, I will suffer them, yea, I will suffer my people, O house of Israel, that they shall go through among them, and shall tread them down, and they shall be as salt that hath lost its savor, which is thenceforth good for nothing but to be cast out, and to be trodden under foot of my people, O house of Israel.
36495	1379	16	Verily, verily, I say unto you, thus hath the Father commanded me--that I should give unto this people this land for their inheritance.
36496	1379	17	And then the words of the prophet Isaiah shall be fulfilled, which say:
36497	1379	18	Thy watchmen shall lift up the voice; with the voice together shall they sing, for they shall see eye to eye when the Lord shall bring again Zion.
36498	1379	19	Break forth into joy, sing together, ye waste places of Jerusalem; for the Lord hath comforted his people, he hath redeemed Jerusalem.
36499	1379	20	The Lord hath made bare his holy arm in the eyes of all the nations; and all the ends of the earth shall see the salvation of God.
36500	1380	1	Behold, now it came to pass that when Jesus had spoken these words he looked round about again on the multitude, and he said unto them: Behold, my time is at hand.
36501	1380	2	I perceive that ye are weak, that ye cannot understand all my words which I am commanded of the Father to speak unto you at this time.
36502	1380	3	Therefore, go ye unto your homes, and ponder upon the things which I have said, and ask of the Father, in my name, that ye may understand, and prepare your minds for the morrow, and I come unto you again.
36503	1380	4	But now I go unto the Father, and also to show myself unto the lost tribes of Israel, for they are not lost unto the Father, for he knoweth whither he hath taken them.
36504	1380	5	And it came to pass that when Jesus had thus spoken, he cast his eyes round about again on the multitude, and beheld they were in tears, and did look steadfastly upon him as if they would ask him to tarry a little longer with them.
36505	1380	6	And he said unto them: Behold, my bowels are filled with compassion towards you.
36506	1380	7	Have ye any that are sick among you? Bring them hither. Have ye any that are lame, or blind, or halt, or maimed, or leprous, or that are withered, or that are deaf, or that are afflicted in any manner? Bring them hither and I will heal them, for I have compassion upon you; my bowels are filled with mercy.
36507	1380	8	For I perceive that ye desire that I should show unto you what I have done unto your brethren at Jerusalem, for I see that your faith is sufficient that I should heal you.
36508	1380	9	And it came to pass that when he had thus spoken, all the multitude, with one accord, did go forth with their sick and their afflicted, and their lame, and with their blind, and with their dumb, and with all them that were afflicted in any manner; and he did heal them every one as they were brought forth unto him.
36509	1380	10	And they did all, both they who had been healed and they who were whole, bow down at his feet, and did worship him; and as many as could come for the multitude did kiss his feet, insomuch that they did bathe his feet with their tears.
36510	1380	11	And it came to pass that he commanded that their little children should be brought.
36511	1380	12	So they brought their little children and set them down upon the ground round about him, and Jesus stood in the midst; and the multitude gave way till they had all been brought unto him.
36512	1380	13	And it came to pass that when they had all been brought, and Jesus stood in the midst, he commanded the multitude that they should kneel down upon the ground.
36513	1380	14	And it came to pass that when they had knelt upon the ground, Jesus groaned within himself, and said: Father, I am troubled because of the wickedness of the people of the house of Israel.
36514	1380	15	And when he had said these words, he himself also knelt upon the earth; and behold he prayed unto the Father, and the things which he prayed cannot be written, and the multitude did bear record who heard him.
36515	1380	16	And after this manner do they bear record: The eye hath never seen, neither hath the ear heard, before, so great and marvelous things as we saw and heard Jesus speak unto the Father;
36516	1380	17	And no tongue can speak, neither can there be written by any man, neither can the hearts of men conceive so great and marvelous things as we both saw and heard Jesus speak; and no one can conceive of the joy which filled our souls at the time we heard him pray for us unto the Father.
36517	1380	18	And it came to pass that when Jesus had made an end of praying unto the Father, he arose; but so great was the joy of the multitude that they were overcome.
36518	1380	19	And it came to pass that Jesus spake unto them, and bade them arise.
36519	1380	20	And they arose from the earth, and he said unto them: Blessed are ye because of your faith. And now behold, my joy is full.
36520	1380	21	And when he had said these words, he wept, and the multitude bare record of it, and he took their little children, one by one, and blessed them, and prayed unto the Father for them.
36521	1380	22	And when he had done this he wept again;
36522	1380	23	And he spake unto the multitude, and said unto them: Behold your little ones.
36523	1380	24	And as they looked to behold they cast their eyes towards heaven, and they saw the heavens open, and they saw angels descending out of heaven as it were in the midst of fire; and they came down and encircled those little ones about, and they were encircled about with fire; and the angels did minister unto them.
36524	1380	25	And the multitude did see and hear and bear record; and they know that their record is true for they all of them did see and hear, every man for himself; and they were in number about two thousand and five hundred souls; and they did consist of men, women, and children.
36525	1381	1	And it came to pass that Jesus commanded his disciples that they should bring forth some bread and wine unto him.
36526	1381	2	And while they were gone for bread and wine, he commanded the multitude that they should sit themselves down upon the earth.
36527	1381	3	And when the disciples had come with bread and wine, he took of the bread and brake and blessed it; and he gave unto the disciples and commanded that they should eat.
36528	1381	4	And when they had eaten and were filled, he commanded that they should give unto the multitude.
36529	1381	5	And when the multitude had eaten and were filled, he said unto the disciples: Behold there shall one be ordained among you, and to him will I give power that he shall break bread and bless it and give it unto the people of my church, unto all those who shall believe and be baptized in my name.
36530	1381	6	And this shall ye always observe to do, even as I have done, even as I have broken bread and blessed it and given it unto you.
36531	1381	7	And this shall ye do in remembrance of my body, which I have shown unto you. And it shall be a testimony unto the Father that ye do always remember me. And if ye do always remember me ye shall have my Spirit to be with you.
36532	1381	8	And it came to pass that when he said these words, he commanded his disciples that they should take of the wine of the cup and drink of it, and that they should also give unto the multitude that they might drink of it.
36533	1381	9	And it came to pass that they did so, and did drink of it and were filled; and they gave unto the multitude, and they did drink, and they were filled.
36534	1381	10	And when the disciples had done this, Jesus said unto them: Blessed are ye for this thing which ye have done, for this is fulfilling my commandments, and this doth witness unto the Father that ye are willing to do that which I have commanded you.
36535	1381	11	And this shall ye always do to those who repent and are baptized in my name; and ye shall do it in remembrance of my blood, which I have shed for you, that ye may witness unto the Father that ye do always remember me. And if ye do always remember me ye shall have my Spirit to be with you.
36536	1381	12	And I give unto you a commandment that ye shall do these things. And if ye shall always do these things blessed are ye, for ye are built upon my rock.
36537	1381	13	But whoso among you shall do more or less than these are not built upon my rock, but are built upon a sandy foundation; and when the rain descends, and the floods come, and the winds blow, and beat upon them, they shall fall, and the gates of hell are ready open to receive them.
36538	1381	14	Therefore blessed are ye if ye shall keep my commandments, which the Father hath commanded me that I should give unto you.
36539	1381	15	Verily, verily, I say unto you, ye must watch and pray always, lest ye be tempted by the devil, and ye be led away captive by him.
36540	1381	16	And as I have prayed among you even so shall ye pray in my church, among my people who do repent and are baptized in my name. Behold I am the light; I have set an example for you.
36541	1381	17	And it came to pass that when Jesus had spoken these words unto his disciples, he turned again unto the multitude and said unto them:
36542	1381	18	Behold, verily, verily, I say unto you, ye must watch and pray always lest ye enter into temptation; for Satan desireth to have you, that he may sift you as wheat.
36543	1381	19	Therefore ye must always pray unto the Father in my name;
36544	1381	20	And whatsoever ye shall ask the Father in my name, which is right, believing that ye shall receive, behold it shall be given unto you.
36545	1381	21	Pray in your families unto the Father, always in my name, that your wives and your children may be blessed.
36546	1381	22	And behold, ye shall meet together oft; and ye shall not forbid any man from coming unto you when ye shall meet together, but suffer them that they may come unto you and forbid them not;
36547	1381	23	But ye shall pray for them, and shall not cast them out; and if it so be that they come unto you oft ye shall pray for them unto the Father, in my name.
36548	1381	24	Therefore, hold up your light that it may shine unto the world. Behold I am the light which ye shall hold up--that which ye have seen me do. Behold ye see that I have prayed unto the Father, and ye all have witnessed.
36549	1381	25	And ye see that I have commanded that none of you should go away, but rather have commanded that ye should come unto me, that ye might feel and see; even so shall ye do unto the world; and whosoever breaketh this commandment suffereth himself to be led into temptation.
36550	1381	26	And now it came to pass that when Jesus had spoken these words, he turned his eyes again upon the disciples whom he had chosen, and said unto them:
36551	1381	27	Behold verily, verily, I say unto you, I give unto you another commandment, and then I must go unto my Father that I may fulfil other commandments which he hath given me.
36552	1381	28	And now behold, this is the commandment which I give unto you, that ye shall not suffer any one knowingly to partake of my flesh and blood unworthily, when ye shall minister it;
36553	1381	29	For whoso eateth and drinketh my flesh and blood unworthily eateth and drinketh damnation to his soul; therefore if ye know that a man is unworthy to eat and drink of my flesh and blood ye shall forbid him.
36554	1381	30	Nevertheless, ye shall not cast him out from among you, but ye shall minister unto him and shall pray for him unto the Father, in my name; and if it so be that he repenteth and is baptized in my name, then shall ye receive him, and shall minister unto him of my flesh and blood.
36555	1381	31	But if he repent not he shall not be numbered among my people, that he may not destroy my people, for behold I know my sheep, and they are numbered.
36556	1381	32	Nevertheless, ye shall not cast him out of your synagogues, or your places of worship, for unto such shall ye continue to minister; for ye know not but what they will return and repent, and come unto me with full purpose of heart, and I shall heal them; and ye shall be the means of bringing salvation unto them.
36557	1381	33	Therefore, keep these sayings which I have commanded you that ye come not under condemnation; for wo unto him whom the Father condemneth.
36558	1381	34	And I give you these commandments because of the disputations which have been among you. And blessed are ye if ye have no disputations among you.
36559	1381	35	And now I go unto the Father, because it is expedient that I should go unto the Father for your sakes.
36560	1381	36	And it came to pass that when Jesus had made an end of these sayings, he touched with his hand the disciples whom he had chosen, one by one, even until he had touched them all, and spake unto them as he touched them.
36561	1381	37	And the multitude heard not the words which he spake, therefore they did not bear record; but the disciples bare record that he gave them power to give the Holy Ghost. And I will show unto you hereafter that this record is true.
36562	1381	38	And it came to pass that when Jesus had touched them all, there came a cloud and overshadowed the multitude that they could not see Jesus.
36563	1381	39	And while they were overshadowed he departed from them, and ascended into heaven. And the disciples saw and did bear record that he ascended again into heaven.
36564	1382	1	And now it came to pass that when Jesus had ascended into heaven, the multitude did disperse, and every man did take his wife and his children and did return to his own home.
36565	1382	2	And it was noised abroad among the people immediately, before it was yet dark, that the multitude had seen Jesus, and that he had ministered unto them, and that he would also show himself on the morrow unto the multitude.
36566	1382	3	Yea, and even all the night it was noised abroad concerning Jesus; and insomuch did they send forth unto the people that there were many, yea, an exceedingly great number, did labor exceedingly all that night, that they might be on the morrow in the place where Jesus should show himself unto the multitude.
36567	1382	4	And it came to pass that on the morrow, when the multitude was gathered together, behold, Nephi and his brother whom he had raised from the dead, whose name was Timothy, and also his son, whose name was Jonas, and also Mathoni, and Mathonihah, his brother, and Kumen, and Kumenonhi, and Jeremiah, and Shemnon, and Jonas, and Zedekiah, and Isaiah--now these were the names of the disciples whom Jesus had chosen--and it came to pass that they went forth and stood in the midst of the multitude.
36568	1382	5	And behold, the multitude was so great that they did cause that they should be separated into twelve bodies.
36569	1382	6	And the twelve did teach the multitude; and behold, they did cause that the multitude should kneel down upon the face of the earth, and should pray unto the Father in the name of Jesus.
36570	1382	7	And the disciples did pray unto the Father also in the name of Jesus. And it came to pass that they arose and ministered unto the people.
36571	1382	8	And when they had ministered those same words which Jesus had spoken--nothing varying from the words which Jesus had spoken--behold, they knelt again and prayed to the Father in the name of Jesus.
36572	1382	9	And they did pray for that which they most desired; and they desired that the Holy Ghost should be given unto them.
36573	1382	10	And when they had thus prayed they went down unto the water's edge, and the multitude followed them.
36574	1382	11	And it came to pass that Nephi went down into the water and was baptized.
36575	1382	12	And he came up out of the water and began to baptize. And he baptized all those whom Jesus had chosen.
36576	1382	13	And it came to pass when they were all baptized and had come up out of the water, the Holy Ghost did fall upon them, and they were filled with the Holy Ghost and with fire.
36577	1382	14	And behold, they were encircled about as if it were by fire; and it came down from heaven, and the multitude did witness it, and did bear record; and angels did come down out of heaven and did minister unto them.
36578	1382	15	And it came to pass that while the angels were ministering unto the disciples, behold, Jesus came and stood in the midst and ministered unto them.
36579	1382	16	And it came to pass that he spake unto the multitude, and commanded them that they should kneel down again upon the earth, and also that his disciples should kneel down upon the earth.
36580	1382	17	And it came to pass that when they had all knelt down upon the earth, he commanded his disciples that they should pray.
36581	1382	18	And behold, they began to pray; and they did pray unto Jesus, calling him their Lord and their God.
36582	1382	19	And it came to pass that Jesus departed out of the midst of them, and went a little way off from them and bowed himself to the earth, and he said:
36583	1382	20	Father, I thank thee that thou hast given the Holy Ghost unto these whom I have chosen; and it is because of their belief in me that I have chosen them out of the world.
36584	1382	21	Father, I pray thee that thou wilt give the Holy Ghost unto all them that shall believe in their words.
36585	1382	22	Father, thou hast given them the Holy Ghost because they believe in me; and thou seest that they believe in me because thou hearest them, and they pray unto me; and they pray unto me because I am with them.
36586	1382	23	And now Father, I pray unto thee for them, and also for all those who shall believe on their words, that they may believe in me, that I may be in them as thou, Father, art in me, that we may be one.
36587	1382	24	And it came to pass that when Jesus had thus prayed unto the Father, he came unto his disciples, and behold, they did still continue, without ceasing, to pray unto him; and they did not multiply many words, for it was given unto them what they should pray, and they were filled with desire.
36588	1382	25	And it came to pass that Jesus blessed them as they did pray unto him; and his countenance did smile upon them, and the light of his countenance did shine upon them, and behold they were as white as the countenance and also the garments of Jesus; and behold the whiteness thereof did exceed all the whiteness, yea, even there could be nothing upon earth so white as the whiteness thereof.
36589	1382	26	And Jesus said unto them: Pray on; nevertheless they did not cease to pray.
36590	1382	27	And he turned from them again, and went a little way off and bowed himself to the earth; and he prayed again unto the Father, saying:
36591	1382	28	Father, I thank thee that thou hast purified those whom I have chosen, because of their faith, and I pray for them, and also for them who shall believe on their words, that they may be purified in me, through faith on their words, even as they are purified in me.
36592	1382	29	Father, I pray not for the world, but for those whom thou hast given me out of the world, because of their faith, that they may be purified in me, that I may be in them as thou, Father, art in me, that we may be one, that I may be glorified in them.
36593	1382	30	And when Jesus had spoken these words he came again unto his disciples; and behold they did pray steadfastly, without ceasing, unto him; and he did smile upon them again; and behold they were white, even as Jesus.
36594	1382	31	And it came to pass that he went again a little way off and prayed unto the Father;
36595	1382	32	And tongue cannot speak the words which he prayed, neither can be written by man the words which he prayed.
36596	1382	33	And the multitude did hear and do bear record; and their hearts were open and they did understand in their hearts the words which he prayed.
36597	1382	34	Nevertheless, so great and marvelous were the words which he prayed that they cannot be written, neither can they be uttered by man.
36598	1382	35	And it came to pass that when Jesus had made an end of praying he came again to the disciples, and said unto them: So great faith have I never seen among all the Jews; wherefore I could not show unto them so great miracles, because of their unbelief.
36599	1382	36	Verily I say unto you, there are none of them that have seen so great things as ye have seen; neither have they heard so great things as ye have heard.
36600	1383	1	And it came to pass that he commanded the multitude that they should cease to pray, and also his disciples. And he commanded them that they should not cease to pray in their hearts.
36601	1383	2	And he commanded them that they should arise and stand up upon their feet. And they arose up and stood upon their feet.
36602	1383	3	And it came to pass that he brake bread again and blessed it, and gave to the disciples to eat.
36603	1383	4	And when they had eaten he commanded them that they should break bread, and give unto the multitude.
36604	1383	5	And when they had given unto the multitude he also gave them wine to drink, and commanded them that they should give unto the multitude.
36605	1383	6	Now, there had been no bread, neither wine, brought by the disciples, neither by the multitude;
36606	1383	7	But he truly gave unto them bread to eat, and also wine to drink.
36607	1383	8	And he said unto them: He that eateth this bread eateth of my body to his soul; and he that drinketh of this wine drinketh of my blood to his soul; and his soul shall never hunger nor thirst, but shall be filled.
36608	1383	9	Now, when the multitude had all eaten and drunk, behold, they were filled with the Spirit; and they did cry out with one voice, and gave glory to Jesus, whom they both saw and heard.
36609	1383	10	And it came to pass that when they had all given glory unto Jesus, he said unto them: Behold now I finish the commandment which the Father hath commanded me concerning this people, who are a remnant of the house of Israel.
36610	1383	11	Ye remember that I spake unto you, and said that when the words of Isaiah should be fulfilled--behold they are written, ye have them before you, therefore search them--
36611	1383	12	And verily, verily, I say unto you, that when they shall be fulfilled then is the fulfilling of the covenant which the Father hath made unto his people, O house of Israel.
36612	1383	13	And then shall the remnants, which shall be scattered abroad upon the face of the earth, be gathered in from the east and from the west, and from the south and from the north; and they shall be brought to the knowledge of the Lord their God, who hath redeemed them.
36613	1383	14	And the Father hath commanded me that I should give unto you this land, for your inheritance.
36614	1383	15	And I say unto you, that if the Gentiles do not repent after the blessing which they shall receive, after they have scattered my people--
36615	1383	16	Then shall ye, who are a remnant of the house of Jacob, go forth among them; and ye shall be in the midst of them who shall be many; and ye shall be among them as a lion among the beasts of the forest, and as a young lion among the flocks of sheep, who, if he goeth through both treadeth down and teareth in pieces, and none can deliver.
36616	1383	17	Thy hand shall be lifted up upon thine adversaries, and all thine enemies shall be cut off.
36617	1383	18	And I will gather my people together as a man gathereth his sheaves into the floor.
36618	1383	19	For I will make my people with whom the Father hath covenanted, yea, I will make thy horn iron, and I will make thy hoofs brass. And thou shalt beat in pieces many people; and I will consecrate their gain unto the Lord, and their substance unto the Lord of the whole earth. And behold, I am he who doeth it.
36619	1383	20	And it shall come to pass, saith the Father, that the sword of my justice shall hang over them at that day; and except they repent it shall fall upon them, saith the Father, yea, even upon all the nations of the Gentiles.
36620	1383	21	And it shall come to pass that I will establish my people, O house of Israel.
36621	1383	22	And behold, this people will I establish in this land, unto the fulfilling of the covenant which I made with your father Jacob; and it shall be a New Jerusalem. And the powers of heaven shall be in the midst of this people; yea, even I will be in the midst of you.
36622	1383	23	Behold, I am he of whom Moses spake, saying: A prophet shall the Lord your God raise up unto you of your brethren, like unto me; him shall ye hear in all things whatsoever he shall say unto you. And it shall come to pass that every soul who will not hear that prophet shall be cut off from among the people.
36623	1383	24	Verily I say unto you, yea, and all the prophets from Samuel and those that follow after, as many as have spoken, have testified of me.
36624	1383	25	And behold, ye are the children of the prophets; and ye are of the house of Israel; and ye are of the covenant which the Father made with your fathers, saying unto Abraham: And in thy seed shall all the kindreds of the earth be blessed.
36625	1383	26	The Father having raised me up unto you first, and sent me to bless you in turning away every one of you from his iniquities; and this because ye are the children of the covenant--
36626	1383	27	And after that ye were blessed then fulfilleth the Father the covenant which he made with Abraham, saying: In thy seed shall all the kindreds of the earth be blessed--unto the pouring out of the Holy Ghost through me upon the Gentiles, which blessing upon the Gentiles shall make them mighty above all, unto the scattering of my people, O house of Israel.
36627	1383	28	And they shall be a scourge unto the people of this land. Nevertheless, when they shall have received the fulness of my gospel, then if they shall harden their hearts against me I will return their iniquities upon their own heads, saith the Father.
36628	1383	29	And I will remember the covenant which I have made with my people; and I have covenanted with them that I would gather them together in mine own due time, that I would give unto them again the land of their fathers for their inheritance, which is the land of Jerusalem, which is the promised land unto them forever, saith the Father.
36629	1383	30	And it shall come to pass that the time cometh, when the fulness of my gospel shall be preached unto them;
36630	1383	31	And they shall believe in me, that I am Jesus Christ, the Son of God, and shall pray unto the Father in my name.
36631	1383	32	Then shall their watchmen lift up their voice, and with the voice together shall they sing; for they shall see eye to eye.
36632	1383	33	Then will the Father gather them together again, and give unto them Jerusalem for the land of their inheritance.
36633	1383	34	Then shall they break forth into joy--Sing together, ye waste places of Jerusalem; for the Father hath comforted his people, he hath redeemed Jerusalem.
36634	1383	35	The Father hath made bare his holy arm in the eyes of all the nations; and all the ends of the earth shall see the salvation of the Father; and the Father and I are one.
36635	1383	36	And then shall be brought to pass that which is written: Awake, awake again, and put on thy strength, O Zion; put on thy beautiful garments, O Jerusalem, the holy city, for henceforth there shall no more come into thee the uncircumcised and the unclean.
36636	1383	37	Shake thyself from the dust; arise, sit down, O Jerusalem; loose thyself from the bands of thy neck, O captive daughter of Zion.
36637	1383	38	For thus saith the Lord: Ye have sold yourselves for naught, and ye shall be redeemed without money.
36638	1383	39	Verily, verily, I say unto you, that my people shall know my name; yea, in that day they shall know that I am he that doth speak.
36639	1383	40	And then shall they say: How beautiful upon the mountains are the feet of him that bringeth good tidings unto them, that publisheth peace; that bringeth good tidings unto them of good, that publisheth salvation; that saith unto Zion: Thy God reigneth!
36640	1383	41	And then shall a cry go forth: Depart ye, depart ye, go ye out from thence, touch not that which is unclean; go ye out of the midst of her; be ye clean that bear the vessels of the Lord.
36641	1383	42	For ye shall not go out with haste nor go by flight; for the Lord will go before you, and the God of Israel shall be your rearward.
36642	1383	43	Behold, my servant shall deal prudently; he shall be exalted and extolled and be very high.
36643	1383	44	As many were astonished at thee--his visage was so marred, more than any man, and his form more than the sons of men--
36644	1383	45	So shall he sprinkle many nations; the kings shall shut their mouths at him, for that which had not been told them shall they see; and that which they had not heard shall they consider.
36645	1383	46	Verily, verily, I say unto you, all these things shall surely come, even as the Father hath commanded me. Then shall this covenant which the Father hath covenanted with his people be fulfilled; and then shall Jerusalem be inhabited again with my people, and it shall be the land of their inheritance.
36646	1384	1	And verily I say unto you, I give unto you a sign, that ye may know the time when these things shall be about to take place--that I shall gather in, from their long dispersion, my people, O house of Israel, and shall establish again among them my Zion;
36647	1384	2	And behold, this is the thing which I will give unto you for a sign--for verily I say unto you that when these things which I declare unto you, and which I shall declare unto you hereafter of myself, and by the power of the Holy Ghost which shall be given unto you of the Father, shall be made known unto the Gentiles that they may know concerning this people who are a remnant of the house of Jacob, and concerning this my people who shall be scattered by them;
36648	1384	3	Verily, verily, I say unto you, when these things shall be made known unto them of the Father, and shall come forth of the Father, from them unto you;
36649	1384	4	For it is wisdom in the Father that they should be established in this land, and be set up as a free people by the power of the Father, that these things might come forth from them unto a remnant of your seed, that the covenant of the Father may be fulfilled which he hath covenanted with his people, O house of Israel;
36650	1384	5	Therefore, when these works and the works which shall be wrought among you hereafter shall come forth from the Gentiles, unto your seed which shall dwindle in unbelief because of iniquity;
36651	1384	6	For thus it behooveth the Father that it should come forth from the Gentiles, that he may show forth his power unto the Gentiles, for this cause that the Gentiles, if they will not harden their hearts, that they may repent and come unto me and be baptized in my name and know of the true points of my doctrine, that they may be numbered among my people, O house of Israel;
36652	1384	7	And when these things come to pass that thy seed shall begin to know these things--it shall be a sign unto them, that they may know that the work of the Father hath already commenced unto the fulfilling of the covenant which he hath made unto the people who are of the house of Israel.
36653	1384	8	And when that day shall come, it shall come to pass that kings shall shut their mouths; for that which had not been told them shall they see; and that which they had not heard shall they consider.
36654	1384	9	For in that day, for my sake shall the Father work a work, which shall be a great and a marvelous work among them; and there shall be among them those who will not believe it, although a man shall declare it unto them.
36655	1384	10	But behold, the life of my servant shall be in my hand; therefore they shall not hurt him, although he shall be marred because of them. Yet I will heal him, for I will show unto them that my wisdom is greater than the cunning of the devil.
36656	1384	11	Therefore it shall come to pass that whosoever will not believe in my words, who am Jesus Christ, which the Father shall cause him to bring forth unto the Gentiles, and shall give unto him power that he shall bring them forth unto the Gentiles, (it shall be done even as Moses said) they shall be cut off from among my people who are of the covenant.
36657	1384	12	And my people who are a remnant of Jacob shall be among the Gentiles, yea, in the midst of them as a lion among the beasts of the forest, as a young lion among the flocks of sheep, who, if he go through both treadeth down and teareth in pieces, and none can deliver.
36658	1384	13	Their hand shall be lifted up upon their adversaries, and all their enemies shall be cut off.
36659	1384	14	Yea, wo be unto the Gentiles except they repent; for it shall come to pass in that day, saith the Father, that I will cut off thy horses out of the midst of thee, and I will destroy thy chariots;
36660	1384	15	And I will cut off the cities of thy land, and throw down all thy strongholds;
36661	1384	16	And I will cut off witchcrafts out of thy land, and thou shalt have no more soothsayers;
36662	1384	17	Thy graven images I will also cut off, and thy standing images out of the midst of thee, and thou shalt no more worship the works of thy hands;
36663	1384	18	And I will pluck up thy groves out of the midst of thee; so will I destroy thy cities.
36664	1384	19	And it shall come to pass that all lyings, and deceivings, and envyings, and strifes, and priestcrafts, and whoredoms, shall be done away.
36665	1384	20	For it shall come to pass, saith the Father, that at that day whosoever will not repent and come unto my Beloved Son, them will I cut off from among my people, O house of Israel;
36666	1384	21	And I will execute vengeance and fury upon them, even as upon the heathen, such as they have not heard.
36667	1384	22	But if they will repent and hearken unto my words, and harden not their hearts, I will establish my church among them, and they shall come in unto the covenant and be numbered among this the remnant of Jacob, unto whom I have given this land for their inheritance;
36668	1384	23	And they shall assist my people, the remnant of Jacob, and also as many of the house of Israel as shall come, that they may build a city, which shall be called the New Jerusalem.
36669	1384	24	And then shall they assist my people that they may be gathered in, who are scattered upon all the face of the land, in unto the New Jerusalem.
36670	1384	25	And then shall the power of heaven come down among them; and I also will be in the midst.
36671	1384	26	And then shall the work of the Father commence at that day, even when this gospel shall be preached among the remnant of this people. Verily I say unto you, at that day shall the work of the Father commence among all the dispersed of my people, yea, even the tribes which have been lost, which the Father hath led away out of Jerusalem.
36672	1384	27	Yea, the work shall commence among all the dispersed of my people, with the Father to prepare the way whereby they may come unto me, that they may call on the Father in my name.
36673	1384	28	Yea, and then shall the work commence, with the Father among all nations in preparing the way whereby his people may be gathered home to the land of their inheritance.
36674	1384	29	And they shall go out from all nations; and they shall not go out in haste, nor go by flight, for I will go before them, saith the Father, and I will be their rearward.
36675	1385	1	And then shall that which is written come to pass: Sing, O barren, thou that didst not bear; break forth into singing, and cry aloud, thou that didst not travail with child; for more are the children of the desolate than the children of the married wife, saith the Lord.
36676	1385	2	Enlarge the place of thy tent, and let them stretch forth the curtains of thy habitations; spare not, lengthen thy cords and strengthen thy stakes;
36677	1385	3	For thou shalt break forth on the right hand and on the left, and thy seed shall inherit the Gentiles and make the desolate cities to be inhabited.
36678	1385	4	Fear not, for thou shalt not be ashamed; neither be thou confounded, for thou shalt not be put to shame; for thou shalt forget the shame of thy youth, and shalt not remember the reproach of thy youth, and shalt not remember the reproach of thy widowhood any more.
36679	1385	5	For thy maker, thy husband, the Lord of Hosts is his name; and thy Redeemer, the Holy One of Israel--the God of the whole earth shall he be called.
36680	1385	6	For the Lord hath called thee as a woman forsaken and grieved in spirit, and a wife of youth, when thou wast refused, saith thy God.
36681	1385	7	For a small moment have I forsaken thee, but with great mercies will I gather thee.
36682	1385	8	In a little wrath I hid my face from thee for a moment, but with everlasting kindness will I have mercy on thee, saith the Lord thy Redeemer.
36683	1385	9	For this, the waters of Noah unto me, for as I have sworn that the waters of Noah should no more go over the earth, so have I sworn that I would not be wroth with thee.
36684	1385	10	For the mountains shall depart and the hills be removed, but my kindness shall not depart from thee, neither shall the covenant of my peace be removed, saith the Lord that hath mercy on thee.
36685	1385	11	O thou afflicted, tossed with tempest, and not comforted! Behold, I will lay thy stones with fair colors, and lay thy foundations with sapphires.
36686	1385	12	And I will make thy windows of agates, and thy gates of carbuncles, and all thy borders of pleasant stones.
36687	1385	13	And all thy children shall be taught of the Lord; and great shall be the peace of thy children.
36688	1385	14	In righteousness shalt thou be established; thou shalt be far from oppression for thou shalt not fear, and from terror for it shall not come near thee.
36689	1385	15	Behold, they shall surely gather together against thee, not by me; whosoever shall gather together against thee shall fall for thy sake.
36690	1385	16	Behold, I have created the smith that bloweth the coals in the fire, and that bringeth forth an instrument for his work; and I have created the waster to destroy.
36691	1385	17	No weapon that is formed against thee shall prosper; and every tongue that shall revile against thee in judgment thou shalt condemn. This is the heritage of the servants of the Lord, and their righteousness is of me, saith the Lord.
36692	1386	1	And now, behold, I say unto you, that ye ought to search these things. Yea, a commandment I give unto you that ye search these things diligently; for great are the words of Isaiah.
36693	1386	2	For surely he spake as touching all things concerning my people which are of the house of Israel; therefore it must needs be that he must speak also to the Gentiles.
36694	1386	3	And all things that he spake have been and shall be, even according to the words which he spake.
36695	1386	4	Therefore give heed to my words; write the things which I have told you; and according to the time and the will of the Father they shall go forth unto the Gentiles.
36696	1386	5	And whosoever will hearken unto my words and repenteth and is baptized, the same shall be saved. Search the prophets, for many there be that testify of these things.
36697	1386	6	And now it came to pass that when Jesus had said these words he said unto them again, after he had expounded all the scriptures unto them which they had received, he said unto them: Behold, other scriptures I would that ye should write, that ye have not.
36698	1386	7	And it came to pass that he said unto Nephi: Bring forth the record which ye have kept.
36699	1386	8	And when Nephi had brought forth the records, and laid them before him, he cast his eyes upon them and said:
36700	1386	9	Verily I say unto you, I commanded my servant Samuel, the Lamanite, that he should testify unto this people, that at the day that the Father should glorify his name in me that there were many saints who should arise from the dead, and should appear unto many, and should minister unto them. And he said unto them: Was it not so?
36701	1386	10	And his disciples answered him and said: Yea, Lord, Samuel did prophesy according to thy words, and they were all fulfilled.
36702	1386	11	And Jesus said unto them: How be it that ye have not written this thing, that many saints did arise and appear unto many and did minister unto them?
36703	1386	12	And it came to pass that Nephi remembered that this thing had not been written.
36704	1386	13	And it came to pass that Jesus commanded that it should be written; therefore it was written according as he commanded.
36705	1386	14	And now it came to pass that when Jesus had expounded all the scriptures in one, which they had written, he commanded them that they should teach the things which he had expounded unto them.
36706	1387	1	And it came to pass that he commanded them that they should write the words which the Father had given unto Malachi, which he should tell unto them. And it came to pass that after they were written he expounded them. And these are the words which he did tell unto them, saying: Thus said the Father unto Malachi--Behold, I will send my messenger, and he shall prepare the way before me, and the Lord whom ye seek shall suddenly come to his temple, even the messenger of the covenant, whom ye delight in; behold, he shall come, saith the Lord of Hosts.
36707	1387	2	But who may abide the day of his coming, and who shall stand when he appeareth? For he is like a refiner's fire, and like fuller's soap.
36708	1387	3	And he shall sit as a refiner and purifier of silver; and he shall purify the sons of Levi, and purge them as gold and silver, that they may offer unto the Lord an offering in righteousness.
36709	1387	4	Then shall the offering of Judah and Jerusalem be pleasant unto the Lord, as in the days of old, and as in former years.
36710	1387	5	And I will come near to you to judgment; and I will be a swift witness against the sorcerers, and against the adulterers, and against false swearers, and against those that oppress the hireling in his wages, the widow and the fatherless, and that turn aside the stranger, and fear not me, saith the Lord of Hosts.
36711	1387	6	For I am the Lord, I change not; therefore ye sons of Jacob are not consumed.
36712	1387	7	Even from the days of your fathers ye are gone away from mine ordinances, and have not kept them. Return unto me and I will return unto you, saith the Lord of Hosts. But ye say: Wherein shall we return?
36713	1387	8	Will a man rob God? Yet ye have robbed me. But ye say: Wherein have we robbed thee? In tithes and offerings.
36714	1387	9	Ye are cursed with a curse, for ye have robbed me, even this whole nation.
36715	1387	10	Bring ye all the tithes into the storehouse, that there may be meat in my house; and prove me now herewith, saith the Lord of Hosts, if I will not open you the windows of heaven, and pour you out a blessing that there shall not be room enough to receive it.
36716	1387	11	And I will rebuke the devourer for your sakes, and he shall not destroy the fruits of your ground; neither shall your vine cast her fruit before the time in the fields, saith the Lord of Hosts.
36717	1387	12	And all nations shall call you blessed, for ye shall be a delightsome land, saith the Lord of Hosts.
36718	1387	13	Your words have been stout against me, saith the Lord. Yet ye say: What have we spoken against thee?
36719	1387	14	Ye have said: It is vain to serve God, and what doth it profit that we have kept his ordinances and that we have walked mournfully before the Lord of Hosts?
36720	1387	15	And now we call the proud happy; yea, they that work wickedness are set up; yea, they that tempt God are even delivered.
36721	1387	16	Then they that feared the Lord spake often one to another, and the Lord hearkened and heard; and a book of remembrance was written before him for them that feared the Lord, and that thought upon his name.
36722	1387	17	And they shall be mine, saith the Lord of Hosts, in that day when I make up my jewels; and I will spare them as a man spareth his own son that serveth him.
36723	1387	18	Then shall ye return and discern between the righteous and the wicked, between him that serveth God and him that serveth him not.
36724	1388	1	For behold, the day cometh that shall burn as an oven; and all the proud, yea, and all that do wickedly, shall be stubble; and the day that cometh shall burn them up, saith the Lord of Hosts, that it shall leave them neither root nor branch.
36725	1388	2	But unto you that fear my name, shall the Son of Righteousness arise with healing in his wings; and ye shall go forth and grow up as calves in the stall.
36726	1388	3	And ye shall tread down the wicked; for they shall be ashes under the soles of your feet in the day that I shall do this, saith the Lord of Hosts.
36727	1388	4	Remember ye the law of Moses, my servant, which I commanded unto him in Horeb for all Israel, with the statutes and judgments.
36728	1388	5	Behold, I will send you Elijah the prophet before the coming of the great and dreadful day of the Lord;
36729	1388	6	And he shall turn the heart of the fathers to the children, and the heart of the children to their fathers, lest I come and smite the earth with a curse.
36730	1389	1	And now it came to pass that when Jesus had told these things he expounded them unto the multitude; and he did expound all things unto them, both great and small.
36731	1389	2	And he saith: These scriptures, which ye had not with you, the Father commanded that I should give unto you; for it was wisdom in him that they should be given unto future generations.
36732	1389	3	And he did expound all things, even from the beginning until the time that he should come in his glory--yea, even all things which should come upon the face of the earth, even until the elements should melt with fervent heat, and the earth should be wrapt together as a scroll, and the heavens and the earth should pass away;
36733	1389	4	And even unto the great and last day, when all people, and all kindreds, and all nations and tongues shall stand before God, to be judged of their works, whether they be good or whether they be evil--
36734	1389	5	If they be good, to the resurrection of everlasting life; and if they be evil, to the resurrection of damnation; being on a parallel, the one on the one hand and the other on the other hand, according to the mercy, and the justice, and the holiness which is in Christ, who was before the world began.
36735	1389	6	And now there cannot be written in this book even a hundredth part of the things which Jesus did truly teach unto the people;
36736	1389	7	But behold the plates of Nephi do contain the more part of the things which he taught the people.
36737	1389	8	And these things have I written, which are a lesser part of the things which he taught the people; and I have written them to the intent that they may be brought again unto this people, from the Gentiles, according to the words which Jesus hath spoken.
36738	1389	9	And when they shall have received this, which is expedient that they should have first, to try their faith, and if it shall so be that they shall believe these things then shall the greater things be made manifest unto them.
36739	1389	10	And if it so be that they will not believe these things, then shall the greater things be withheld from them, unto their condemnation.
36740	1389	11	Behold, I was about to write them, all which were engraven upon the plates of Nephi, but the Lord forbade it, saying: I will try the faith of my people.
36741	1389	12	Therefore I, Mormon, do write the things which have been commanded me of the Lord. And now I, Mormon, make an end of my sayings, and proceed to write the things which have been commanded me.
36742	1389	13	Therefore, I would that ye should behold that the Lord truly did teach the people, for the space of three days; and after that he did show himself unto them oft, and did break bread oft, and bless it, and give it unto them.
36743	1389	14	And it came to pass that he did teach and minister unto the children of the multitude of whom hath been spoken, and he did loose their tongues, and they did speak unto their fathers great and marvelous things, even greater than he had revealed unto the people; and he loosed their tongues that they could utter.
36744	1389	15	And it came to pass that after he had ascended into heaven--the second time that he showed himself unto them, and had gone unto the Father, after having healed all their sick, and their lame, and opened the eyes of their blind and unstopped the ears of the deaf, and even had done all manner of cures among them, and raised a man from the dead, and had shown forth his power unto them, and had ascended unto the Father--
36745	1389	16	Behold, it came to pass on the morrow that the multitude gathered themselves together, and they both saw and heard these children; yea, even babes did open their mouths and utter marvelous things; and the things which they did utter were forbidden that there should not any man write them.
36746	1389	17	And it came to pass that the disciples whom Jesus had chosen began from that time forth to baptize and to teach as many as did come unto them; and as many as were baptized in the name of Jesus were filled with the Holy Ghost.
36747	1389	18	And many of them saw and heard unspeakable things, which are not lawful to be written.
36748	1389	19	And they taught, and did minister one to another; and they had all things common among them, every man dealing justly, one with another.
36749	1389	20	And it came to pass that they did do all things even as Jesus had commanded them.
36750	1389	21	And they who were baptized in the name of Jesus were called the church of Christ.
36751	1390	1	And it came to pass that as the disciples of Jesus were journeying and were preaching the things which they had both heard and seen, and were baptizing in the name of Jesus, it came to pass that the disciples were gathered together and were united in mighty prayer and fasting.
36752	1390	2	And Jesus again showed himself unto them, for they were praying unto the Father in his name; and Jesus came and stood in the midst of them, and said unto them: What will ye that I shall give unto you?
36753	1390	3	And they said unto him: Lord, we will that thou wouldst tell us the name whereby we shall call this church; for there are disputations among the people concerning this matter.
36754	1390	4	And the Lord said unto them: Verily, verily, I say unto you, why is it that the people should murmur and dispute because of this thing?
36755	1390	5	Have they not read the scriptures, which say ye must take upon you the name of Christ, which is my name? For by this name shall ye be called at the last day;
36756	1390	6	And whoso taketh upon him my name, and endureth to the end, the same shall be saved at the last day.
36757	1390	7	Therefore, whatsoever ye shall do, ye shall do it in my name; therefore ye shall call the church in my name; and ye shall call upon the Father in my name that he will bless the church for my sake.
36758	1390	8	And how be it my church save it be called in my name? For if a church be called in Moses' name then it be Moses' church; or if it be called in the name of a man then it be the church of a man; but if it be called in my name then it is my church, if it so be that they are built upon my gospel.
36759	1390	9	Verily I say unto you, that ye are built upon my gospel; therefore ye shall call whatsoever things ye do call, in my name; therefore if ye call upon the Father, for the church, if it be in my name the Father will hear you;
36760	1390	10	And if it so be that the church is built upon my gospel then will the Father show forth his own works in it.
36761	1390	11	But if it be not built upon my gospel, and is built upon the works of men, or upon the works of the devil, verily I say unto you they have joy in their works for a season, and by and by the end cometh, and they are hewn down and cast into the fire, from whence there is no return.
36762	1390	12	For their works do follow them, for it is because of their works that they are hewn down; therefore remember the things that I have told you.
36763	1390	13	Behold I have given unto you my gospel, and this is the gospel which I have given unto you--that I came into the world to do the will of my Father, because my Father sent me.
36764	1390	14	And my Father sent me that I might be lifted up upon the cross; and after that I had been lifted up upon the cross, that I might draw all men unto me, that as I have been lifted up by men even so should men be lifted up by the Father, to stand before me, to be judged of their works, whether they be good or whether they be evil--
36765	1390	15	And for this cause have I been lifted up; therefore, according to the power of the Father I will draw all men unto me, that they may be judged according to their works.
36766	1390	16	And it shall come to pass, that whoso repenteth and is baptized in my name shall be filled; and if he endureth to the end, behold, him will I hold guiltless before my Father at that day when I shall stand to judge the world.
36767	1390	17	And he that endureth not unto the end, the same is he that is also hewn down and cast into the fire, from whence they can no more return, because of the justice of the Father.
36768	1390	18	And this is the word which he hath given unto the children of men. And for this cause he fulfilleth the words which he hath given, and he lieth not, but fulfilleth all his words.
36769	1390	19	And no unclean thing can enter into his kingdom; therefore nothing entereth into his rest save it be those who have washed their garments in my blood, because of their faith, and the repentance of all their sins, and their faithfulness unto the end.
36770	1390	20	Now this is the commandment: Repent, all ye ends of the earth, and come unto me and be baptized in my name, that ye may be sanctified by the reception of the Holy Ghost, that ye may stand spotless before me at the last day.
36771	1390	21	Verily, verily, I say unto you, this is my gospel; and ye know the things that ye must do in my church; for the works which ye have seen me do that shall ye also do; for that which ye have seen me do even that shall ye do;
36772	1390	22	Therefore, if ye do these things blessed are ye, for ye shall be lifted up at the last day.
36773	1390	23	Write the things which ye have seen and heard, save it be those which are forbidden.
36774	1390	24	Write the works of this people, which shall be, even as hath been written, of that which hath been.
36775	1390	25	For behold, out of the books which have been written, and which shall be written, shall this people be judged, for by them shall their works be known unto men.
36776	1390	26	And behold, all things are written by the Father; therefore out of the books which shall be written shall the world be judged.
36777	1390	27	And know ye that ye shall be judges of this people, according to the judgment which I shall give unto you, which shall be just. Therefore, what manner of men ought ye to be? Verily I say unto you, even as I am.
36778	1390	28	And now I go unto the Father. And verily I say unto you, whatsoever things ye shall ask the Father in my name shall be given unto you.
36779	1390	29	Therefore, ask, and ye shall receive; knock, and it shall be opened unto you; for he that asketh, receiveth; and unto him that knocketh, it shall be opened.
36780	1390	30	And now, behold, my joy is great, even unto fulness, because of you, and also this generation; yea, and even the Father rejoiceth, and also all the holy angels, because of you and this generation; for none of them are lost.
36781	1390	31	Behold, I would that ye should understand; for I mean them who are now alive of this generation; and none of them are lost; and in them I have fulness of joy.
36782	1390	32	But behold, it sorroweth me because of the fourth generation from this generation, for they are led away captive by him even as was the son of perdition; for they will sell me for silver and for gold, and for that which moth doth corrupt and which thieves can break through and steal. And in that day will I visit them, even in turning their works upon their own heads.
36783	1390	33	And it came to pass that when Jesus had ended these sayings he said unto his disciples: Enter ye in at the strait gate; for strait is the gate, and narrow is the way that leads to life, and few there be that find it; but wide is the gate, and broad the way which leads to death, and many there be that travel therein, until the night cometh, wherein no man can work.
36784	1391	1	And it came to pass when Jesus had said these words, he spake unto his disciples, one by one, saying unto them: What is it that ye desire of me, after that I am gone to the Father?
36785	1391	2	And they all spake, save it were three, saying: We desire that after we have lived unto the age of man, that our ministry, wherein thou hast called us, may have an end, that we may speedily come unto thee in thy kingdom.
36786	1391	3	And he said unto them: Blessed are ye because ye desired this thing of me; therefore, after that ye are seventy and two years old ye shall come unto me in my kingdom; and with me ye shall find rest.
36787	1391	4	And when he had spoken unto them, he turned himself unto the three, and said unto them: What will ye that I should do unto you, when I am gone unto the Father?
36788	1391	5	And they sorrowed in their hearts, for they durst not speak unto him the thing which they desired.
36789	1391	6	And he said unto them: Behold, I know your thoughts, and ye have desired the thing which John, my beloved, who was with me in my ministry, before that I was lifted up by the Jews, desired of me.
36790	1391	7	Therefore, more blessed are ye, for ye shall never taste of death; but ye shall live to behold all the doings of the Father unto the children of men, even until all things shall be fulfilled according to the will of the Father, when I shall come in my glory with the powers of heaven.
36791	1391	8	And ye shall never endure the pains of death; but when I shall come in my glory ye shall be changed in the twinkling of an eye from mortality to immortality; and then shall ye be blessed in the kingdom of my Father.
36792	1391	9	And again, ye shall not have pain while ye shall dwell in the flesh, neither sorrow save it be for the sins of the world; and all this will I do because of the thing which ye have desired of me, for ye have desired that ye might bring the souls of men unto me, while the world shall stand.
36793	1391	10	And for this cause ye shall have fulness of joy; and ye shall sit down in the kingdom of my Father; yea, your joy shall be full, even as the Father hath given me fulness of joy; and ye shall be even as I am, and I am even as the Father; and the Father and I are one;
36794	1391	11	And the Holy Ghost beareth record of the Father and me; and the Father giveth the Holy Ghost unto the children of men, because of me.
36795	1391	12	And it came to pass that when Jesus had spoken these words, he touched every one of them with his finger save it were the three who were to tarry, and then he departed.
36796	1391	13	And behold, the heavens were opened, and they were caught up into heaven, and saw and heard unspeakable things.
36797	1391	14	And it was forbidden them that they should utter; neither was it given unto them power that they could utter the things which they saw and heard;
36798	1391	15	And whether they were in the body or out of the body, they could not tell; for it did seem unto them like a transfiguration of them, that they were changed from this body of flesh into an immortal state, that they could behold the things of God.
36799	1391	16	But it came to pass that they did again minister upon the face of the earth; nevertheless they did not minister of the things which they had heard and seen, because of the commandment which was given them in heaven.
36800	1391	17	And now, whether they were mortal or immortal, from the day of their transfiguration, I know not;
36801	1391	18	But this much I know, according to the record which hath been given--they did go forth upon the face of the land, and did minister unto all the people, uniting as many to the church as would believe in their preaching; baptizing them, and as many as were baptized did receive the Holy Ghost.
36802	1391	19	And they were cast into prison by them who did not belong to the church. And the prisons could not hold them, for they were rent in twain.
36803	1391	20	And they were cast down into the earth; but they did smite the earth with the word of God, insomuch that by his power they were delivered out of the depths of the earth; and therefore they could not dig pits sufficient to hold them.
36804	1391	21	And thrice they were cast into a furnace and received no harm.
36805	1391	22	And twice were they cast into a den of wild beasts; and behold they did play with the beasts as a child with a suckling lamb, and received no harm.
36806	1391	23	And it came to pass that thus they did go forth among all the people of Nephi, and did preach the gospel of Christ unto all people upon the face of the land; and they were converted unto the Lord, and were united unto the church of Christ, and thus the people of that generation were blessed, according to the word of Jesus.
36807	1391	24	And now I, Mormon, make an end of speaking concerning these things for a time.
36808	1391	25	Behold, I was about to write the names of those who were never to taste of death, but the Lord forbade; therefore I write them not, for they are hid from the world.
36809	1391	26	But behold, I have seen them, and they have ministered unto me.
36810	1391	27	And behold they will be among the Gentiles, and the Gentiles shall know them not.
36811	1391	28	They will also be among the Jews, and the Jews shall know them not.
36812	1391	29	And it shall come to pass, when the Lord seeth fit in his wisdom that they shall minister unto all the scattered tribes of Israel, and unto all nations, kindreds, tongues and people, and shall bring out of them unto Jesus many souls, that their desire may be fulfilled, and also because of the convincing power of God which is in them.
36813	1391	30	And they are as the angels of God, and if they shall pray unto the Father in the name of Jesus they can show themselves unto whatsoever man it seemeth them good.
36814	1391	31	Therefore, great and marvelous works shall be wrought by them, before the great and coming day when all people must surely stand before the judgment-seat of Christ;
36815	1391	32	Yea even among the Gentiles shall there be a great and marvelous work wrought by them, before that judgment day.
36816	1391	33	And if ye had all the scriptures which give an account of all the marvelous works of Christ, ye would, according to the words of Christ, know that these things must surely come.
36817	1391	34	And wo be unto him that will not hearken unto the words of Jesus, and also to them whom he hath chosen and sent among them; for whoso receiveth not the words of Jesus and the words of those whom he hath sent receiveth not him; and therefore he will not receive them at the last day;
36818	1391	35	And it would be better for them if they had not been born. For do ye suppose that ye can get rid of the justice of an offended God, who hath been trampled under feet of men, that thereby salvation might come?
36819	1391	36	And now behold, as I spake concerning those whom the Lord hath chosen, yea, even three who were caught up into the heavens, that I knew not whether they were cleansed from mortality to immortality--
36820	1391	37	But behold, since I wrote, I have inquired of the Lord, and he hath made it manifest unto me that there must needs be a change wrought upon their bodies, or else it needs be that they must taste of death;
36821	1391	38	Therefore, that they might not taste of death there was a change wrought upon their bodies, that they might not suffer pain nor sorrow save it were for the sins of the world.
36822	1391	39	Now this change was not equal to that which shall take place at the last day; but there was a change wrought upon them, insomuch that Satan could have no power over them, that he could not tempt them; and they were sanctified in the flesh, that they were holy, and that the powers of the earth could not hold them.
36823	1391	40	And in this state they were to remain until the judgment day of Christ; and at that day they were to receive a greater change, and to be received into the kingdom of the Father to go no more out, but to dwell with God eternally in the heavens.
36824	1392	1	And now behold, I say unto you that when the Lord shall see fit, in his wisdom, that these sayings shall come unto the Gentiles according to his word, then ye may know that the covenant which the Father hath made with the children of Israel, concerning their restoration to the lands of their inheritance, is already beginning to be fulfilled.
36825	1392	2	And ye may know that the words of the Lord, which have been spoken by the holy prophets, shall all be fulfilled; and ye need not say that the Lord delays his coming unto the children of Israel.
36826	1392	3	And ye need not imagine in your hearts that the words which have been spoken are vain, for behold, the Lord will remember his covenant which he hath made unto his people of the house of Israel.
36827	1392	4	And when ye shall see these sayings coming forth among you, then ye need not any longer spurn at the doings of the Lord, for the sword of his justice is in his right hand; and behold, at that day, if ye shall spurn at his doings he will cause that it shall soon overtake you.
36828	1392	5	Wo unto him that spurneth at the doings of the Lord; yea, wo unto him that shall deny the Christ and his works!
36829	1392	6	Yea, wo unto him that shall deny the revelations of the Lord, and that shall say the Lord no longer worketh by revelation, or by prophecy, or by gifts, or by tongues, or by healings, or by the power of the Holy Ghost!
36830	1392	7	Yea, and wo unto him that shall say at that day, to get gain, that there can be no miracle wrought by Jesus Christ; for he that doeth this shall become like unto the son of perdition, for whom there was no mercy, according to the word of Christ!
36831	1392	8	Yea, and ye need not any longer hiss, nor spurn, nor make game of the Jews, nor any of the remnant of the house of Israel; for behold, the Lord remembereth his covenant unto them, and he will do unto them according to that which he hath sworn.
36832	1392	9	Therefore ye need not suppose that ye can turn the right hand of the Lord unto the left, that he may not execute judgment unto the fulfilling of the covenant which he hath made unto the house of Israel.
36833	1393	1	Hearken, O ye Gentiles, and hear the words of Jesus Christ, the Son of the living God, which he hath commanded me that I should speak concerning you, for, behold he commandeth me that I should write, saying:
36834	1393	2	Turn, all ye Gentiles, from your wicked ways; and repent of your evil doings, of your lyings and deceivings, and of your whoredoms, and of your secret abominations, and your idolatries, and of your murders, and your priestcrafts, and your envyings, and your strifes, and from all your wickedness and abominations, and come unto me, and be baptized in my name, that ye may receive a remission of your sins, and be filled with the Holy Ghost, that ye may be numbered with my people who are of the house of Israel.
36835	1394	1	And it came to pass that the thirty and fourth year passed away, and also the thirty and fifth, and behold the disciples of Jesus had formed a church of Christ in all the lands round about. And as many as did come unto them, and did truly repent of their sins, were baptized in the name of Jesus; and they did also receive the Holy Ghost.
36836	1394	2	And it came to pass in the thirty and sixth year, the people were all converted unto the Lord, upon all the face of the land, both Nephites and Lamanites, and there were no contentions and disputations among them, and every man did deal justly one with another.
36837	1394	3	And they had all things common among them; therefore there were not rich and poor, bond and free, but they were all made free, and partakers of the heavenly gift.
36838	1394	4	And it came to pass that the thirty and seventh year passed away also, and there still continued to be peace in the land.
36839	1394	5	And there were great and marvelous works wrought by the disciples of Jesus, insomuch that they did heal the sick, and raise the dead, and cause the lame to walk, and the blind to receive their sight, and the deaf to hear; and all manner of miracles did they work among the children of men; and in nothing did they work miracles save it were in the name of Jesus.
36840	1394	6	And thus did the thirty and eighth year pass away, and also the thirty and ninth, and forty and first, and the forty and second, yea, even until forty and nine years had passed away, and also the fifty and first, and the fifty and second; yea, and even until fifty and nine years had passed away.
36841	1394	7	And the Lord did prosper them exceedingly in the land; yea, insomuch that they did build cities again where there had been cities burned.
36842	1394	8	Yea, even that great city Zarahemla did they cause to be built again.
36843	1394	9	But there were many cities which had been sunk, and waters came up in the stead thereof; therefore these cities could not be renewed.
36844	1394	10	And now, behold, it came to pass that the people of Nephi did wax strong, and did multiply exceedingly fast, and became an exceedingly fair and delightsome people.
36845	1394	11	And they were married, and given in marriage, and were blessed according to the multitude of the promises which the Lord had made unto them.
36846	1394	12	And they did not walk any more after the performances and ordinances of the law of Moses; but they did walk after the commandments which they had received from their Lord and their God, continuing in fasting and prayer, and in meeting together oft both to pray and to hear the word of the Lord.
36847	1394	13	And it came to pass that there was no contention among all the people, in all the land; but there were mighty miracles wrought among the disciples of Jesus.
36848	1394	14	And it came to pass that the seventy and first year passed away, and also the seventy and second year, yea, and in fine, till the seventy and ninth year had passed away; yea, even an hundred years had passed away, and the disciples of Jesus, whom he had chosen, had all gone to the paradise of God, save it were the three who should tarry; and there were other disciples ordained in their stead; and also many of that generation had passed away.
36849	1394	15	And it came to pass that there was no contention in the land, because of the love of God which did dwell in the hearts of the people.
36850	1394	16	And there were no envyings, nor strifes, nor tumults, nor whoredoms, nor lyings, nor murders, nor any manner of lasciviousness; and surely there could not be a happier people among all the people who had been created by the hand of God.
36851	1394	17	There were no robbers, nor murderers, neither were there Lamanites, nor any manner of -ites; but they were in one, the children of Christ, and heirs to the kingdom of God.
36852	1394	18	And how blessed were they! For the Lord did bless them in all their doings; yea, even they were blessed and prospered until an hundred and ten years had passed away; and the first generation from Christ had passed away, and there was no contention in all the land.
36853	1394	19	And it came to pass that Nephi, he that kept this last record, (and he kept it upon the plates of Nephi) died, and his son Amos kept it in his stead; and he kept it upon the plates of Nephi also.
36854	1394	20	And he kept it eighty and four years, and there was still peace in the land, save it were a small part of the people who had revolted from the church and taken upon them the name of Lamanites; therefore there began to be Lamanites again in the land.
36855	1394	21	And it came to pass that Amos died also, (and it was an hundred and ninety and four years from the coming of Christ) and his son Amos kept the record in his stead; and he also kept it upon the plates of Nephi; and it was also written in the book of Nephi, which is this book.
36856	1394	22	And it came to pass that two hundred years had passed away; and the second generation had all passed away save it were a few.
36857	1394	23	And now I, Mormon, would that ye should know that the people had multiplied, insomuch that they were spread upon all the face of the land, and that they had become exceedingly rich, because of their prosperity in Christ.
36858	1394	24	And now, in this two hundred and first year there began to be among them those who were lifted up in pride, such as the wearing of costly apparel, and all manner of fine pearls, and of the fine things of the world.
36859	1394	25	And from that time forth they did have their goods and their substance no more common among them.
36860	1394	26	And they began to be divided into classes; and they began to build up churches unto themselves to get gain, and began to deny the true church of Christ.
36861	1394	27	And it came to pass that when two hundred and ten years had passed away there were many churches in the land; yea, there were many churches which professed to know the Christ, and yet they did deny the more parts of his gospel, insomuch that they did receive all manner of wickedness, and did administer that which was sacred unto him to whom it had been forbidden because of unworthiness.
36862	1394	28	And this church did multiply exceedingly because of iniquity, and because of the power of Satan who did get hold upon their hearts.
36863	1394	29	And again, there was another church which denied the Christ; and they did persecute the true church of Christ, because of their humility and their belief in Christ; and they did despise them because of the many miracles which were wrought among them.
36864	1394	30	Therefore they did exercise power and authority over the disciples of Jesus who did tarry with them, and they did cast them into prison; but by the power of the word of God, which was in them, the prisons were rent in twain, and they went forth doing mighty miracles among them.
36865	1394	31	Nevertheless, and notwithstanding all these miracles, the people did harden their hearts, and did seek to kill them, even as the Jews at Jerusalem sought to kill Jesus, according to his word.
36866	1394	32	And they did cast them into furnaces of fire, and they came forth receiving no harm.
36867	1394	33	And they also cast them into dens of wild beasts, and they did play with the wild beasts even as a child with a lamb; and they did come forth from among them, receiving no harm.
36868	1394	34	Nevertheless, the people did harden their hearts, for they were led by many priests and false prophets to build up many churches, and to do all manner of iniquity. And they did smite upon the people of Jesus; but the people of Jesus did not smite again. And thus they did dwindle in unbelief and wickedness, from year to year, even until two hundred and thirty years had passed away.
36869	1394	35	And now it came to pass in this year, yea, in the two hundred and thirty and first year, there was a great division among the people.
36870	1394	36	And it came to pass that in this year there arose a people who were called the Nephites, and they were true believers in Christ; and among them there were those who were called by the Lamanites--Jacobites, and Josephites, and Zoramites;
36871	1394	37	Therefore the true believers in Christ, and the true worshipers of Christ, (among whom were the three disciples of Jesus who should tarry) were called Nephites, and Jacobites, and Josephites, and Zoramites.
36872	1394	38	And it came to pass that they who rejected the gospel were called Lamanites, and Lemuelites, and Ishmaelites; and they did not dwindle in unbelief, but they did wilfully rebel against the gospel of Christ; and they did teach their children that they should not believe, even as their fathers, from the beginning, did dwindle.
36873	1394	39	And it was because of the wickedness and abomination of their fathers, even as it was in the beginning. And they were taught to hate the children of God, even as the Lamanites were taught to hate the children of Nephi from the beginning.
36874	1394	40	And it came to pass that two hundred and forty and four years had passed away, and thus were the affairs of the people. And the more wicked part of the people did wax strong, and became exceedingly more numerous than were the people of God.
36875	1394	41	And they did still continue to build up churches unto themselves, and adorn them with all manner of precious things. And thus did two hundred and fifty years pass away, and also two hundred and sixty years.
36876	1394	42	And it came to pass that the wicked part of the people began again to build up the secret oaths and combinations of Gadianton.
36877	1394	43	And also the people who were called the people of Nephi began to be proud in their hearts, because of their exceeding riches, and become vain like unto their brethren, the Lamanites.
36878	1394	44	And from this time the disciples began to sorrow for the sins of the world.
36879	1394	45	And it came to pass that when three hundred years had passed away, both the people of Nephi and the Lamanites had become exceedingly wicked one like unto another.
36880	1394	46	And it came to pass that the robbers of Gadianton did spread over all the face of the land; and there were none that were righteous save it were the disciples of Jesus. And gold and silver did they lay up in store in abundance, and did traffic in all manner of traffic.
36881	1394	47	And it came to pass that after three hundred and five years had passed away, (and the people did still remain in wickedness) Amos died; and his brother, Ammaron, did keep the record in his stead.
36882	1394	48	And it came to pass that when three hundred and twenty years had passed away, Ammaron, being constrained by the Holy Ghost, did hide up the records which were sacred--yea, even all the sacred records which had been handed down from generation to generation, which were sacred--even until the three hundred and twentieth year from the coming of Christ.
36883	1394	49	And he did hide them up unto the Lord, that they might come again unto the remnant of the house of Jacob, according to the prophecies and the promises of the Lord. And thus is the end of the record of Ammaron.
36884	1395	1	And now I, Mormon, make a record of the things which I have both seen and heard, and call it the Book of Mormon.
36885	1395	2	And about the time that Ammaron hid up the records unto the Lord, he came unto me, (I being about ten years of age, and I began to be learned somewhat after the manner of the learning of my people) and Ammaron said unto me: I perceive that thou art a sober child, and art quick to observe;
36886	1395	3	Therefore, when ye are about twenty and four years old I would that ye should remember the things that ye have observed concerning this people; and when ye are of that age go to the land Antum, unto a hill which shall be called Shim; and there have I deposited unto the Lord all the sacred engravings concerning this people.
36887	1395	4	And behold, ye shall take the plates of Nephi unto yourself, and the remainder shall ye leave in the place where they are; and ye shall engrave on the plates of Nephi all the things that ye have observed concerning this people.
36888	1395	5	And I, Mormon, being a descendant of Nephi, (and my father's name was Mormon) I remembered the things which Ammaron commanded me.
36889	1395	6	And it came to pass that I, being eleven years old, was carried by my father into the land southward, even to the land of Zarahemla.
36890	1395	7	The whole face of the land had become covered with buildings, and the people were as numerous almost, as it were the sand of the sea.
36891	1395	8	And it came to pass in this year there began to be a war between the Nephites, who consisted of the Nephites and the Jacobites and the Josephites and the Zoramites; and this war was between the Nephites, and the Lamanites and the Lemuelites and the Ishmaelites.
36892	1395	9	Now the Lamanites and the Lemuelites and the Ishmaelites were called Lamanites, and the two parties were Nephites and Lamanites.
36893	1395	10	And it came to pass that the war began to be among them in the borders of Zarahemla, by the waters of Sidon.
36894	1395	11	And it came to pass that the Nephites had gathered together a great number of men, even to exceed the number of thirty thousand. And it came to pass that they did have in this same year a number of battles, in which the Nephites did beat the Lamanites and did slay many of them.
36895	1395	12	And it came to pass that the Lamanites withdrew their design, and there was peace settled in the land; and peace did remain for the space of about four years, that there was no bloodshed.
36896	1395	13	But wickedness did prevail upon the face of the whole land, insomuch that the Lord did take away his beloved disciples, and the work of miracles and of healing did cease because of the iniquity of the people.
36897	1395	14	And there were no gifts from the Lord, and the Holy Ghost did not come upon any, because of their wickedness and unbelief.
36898	1395	15	And I, being fifteen years of age and being somewhat of a sober mind, therefore I was visited of the Lord, and tasted and knew of the goodness of Jesus.
36899	1395	16	And I did endeavor to preach unto this people, but my mouth was shut, and I was forbidden that I should preach unto them; for behold they had wilfully rebelled against their God; and the beloved disciples were taken away out of the land, because of their iniquity.
36900	1395	17	But I did remain among them, but I was forbidden to preach unto them, because of the hardness of their hearts; and because of the hardness of their hearts the land was cursed for their sake.
36901	1395	18	And these Gadianton robbers, who were among the Lamanites, did infest the land, insomuch that the inhabitants thereof began to hide up their treasures in the earth; and they became slippery, because the Lord had cursed the land, that they could not hold them, nor retain them again.
36902	1395	19	And it came to pass that there were sorceries, and witchcrafts, and magics; and the power of the evil one was wrought upon all the face of the land, even unto the fulfilling of all the words of Abinadi, and also Samuel the Lamanite.
36903	1396	1	And it came to pass in that same year there began to be a war again between the Nephites and the Lamanites. And notwithstanding I being young, was large in stature; therefore the people of Nephi appointed me that I should be their leader, or the leader of their armies.
36904	1396	2	Therefore it came to pass that in my sixteenth year I did go forth at the head of an army of the Nephites, against the Lamanites; therefore three hundred and twenty and six years had passed away.
36905	1396	3	And it came to pass that in the three hundred and twenty and seventh year the Lamanites did come upon us with exceedingly great power, insomuch that they did frighten my armies; therefore they would not fight, and they began to retreat towards the north countries.
36906	1396	4	And it came to pass that we did come to the city of Angola, and we did take possession of the city, and make preparations to defend ourselves against the Lamanites. And it came to pass that we did fortify the city with our might; but notwithstanding all our fortifications the Lamanites did come upon us and did drive us out of the city.
36907	1396	5	And they did also drive us forth out of the land of David.
36908	1396	6	And we marched forth and came to the land of Joshua, which was in the borders west by the seashore.
36909	1396	7	And it came to pass that we did gather in our people as fast as it were possible, that we might get them together in one body.
36910	1396	8	But behold, the land was filled with robbers and with Lamanites; and notwithstanding the great destruction which hung over my people, they did not repent of their evil doings; therefore there was blood and carnage spread throughout all the face of the land, both on the part of the Nephites and also on the part of the Lamanites; and it was one complete revolution throughout all the face of the land.
36911	1396	9	And now, the Lamanites had a king, and his name was Aaron; and he came against us with an army of forty and four thousand. And behold, I withstood him with forty and two thousand. And it came to pass that I beat him with my army that he fled before me. And behold, all this was done, and three hundred and thirty years had passed away.
36912	1396	10	And it came to pass that the Nephites began to repent of their iniquity, and began to cry even as had been prophesied by Samuel the prophet; for behold no man could keep that which was his own, for the thieves, and the robbers, and the murderers, and the magic art, and the witchcraft which was in the land.
36913	1396	11	Thus there began to be a mourning and a lamentation in all the land because of these things, and more especially among the people of Nephi.
36914	1396	12	And it came to pass that when I, Mormon, saw their lamentation and their mourning and their sorrow before the Lord, my heart did begin to rejoice within me, knowing the mercies and the long-suffering of the Lord, therefore supposing that he would be merciful unto them that they would again become a righteous people.
36915	1396	13	But behold this my joy was vain, for their sorrowing was not unto repentance, because of the goodness of God; but it was rather the sorrowing of the damned, because the Lord would not always suffer them to take happiness in sin.
36916	1396	14	And they did not come unto Jesus with broken hearts and contrite spirits, but they did curse God, and wish to die. Nevertheless they would struggle with the sword for their lives.
36917	1396	15	And it came to pass that my sorrow did return unto me again, and I saw that the day of grace was passed with them, both temporally and spiritually; for I saw thousands of them hewn down in open rebellion against their God, and heaped up as dung upon the face of the land. And thus three hundred and forty and four years had passed away.
36918	1396	16	And it came to pass that in the three hundred and forty and fifth year the Nephites did begin to flee before the Lamanites; and they were pursued until they came even to the land of Jashon, before it was possible to stop them in their retreat.
36919	1396	17	And now, the city of Jashon was near the land where Ammaron had deposited the records unto the Lord, that they might not be destroyed. And behold I had gone according to the word of Ammaron, and taken the plates of Nephi, and did make a record according to the words of Ammaron.
36920	1396	18	And upon the plates of Nephi I did make a full account of all the wickedness and abominations; but upon these plates I did forbear to make a full account of their wickedness and abominations, for behold, a continual scene of wickedness and abominations has been before mine eyes ever since I have been sufficient to behold the ways of man.
36921	1396	19	And wo is me because of their wickedness; for my heart has been filled with sorrow because of their wickedness, all my days; nevertheless, I know that I shall be lifted up at the last day.
36922	1396	20	And it came to pass that in this year the people of Nephi again were hunted and driven. And it came to pass that we were driven forth until we had come northward to the land which was called Shem.
36923	1396	21	And it came to pass that we did fortify the city of Shem, and we did gather in our people as much as it were possible, that perhaps we might save them from destruction.
36924	1396	22	And it came to pass in the three hundred and forty and sixth year they began to come upon us again.
36925	1396	23	And it came to pass that I did speak unto my people, and did urge them with great energy, that they would stand boldly before the Lamanites and fight for their wives, and their children, and their houses, and their homes.
36926	1396	24	And my words did arouse them somewhat to vigor, insomuch that they did not flee from before the Lamanites, but did stand with boldness against them.
36927	1396	25	And it came to pass that we did contend with an army of thirty thousand against an army of fifty thousand. And it came to pass that we did stand before them with such firmness that they did flee from before us.
36928	1396	26	And it came to pass that when they had fled we did pursue them with our armies, and did meet them again, and did beat them; nevertheless the strength of the Lord was not with us; yea, we were left to ourselves, that the Spirit of the Lord did not abide in us; therefore we had become weak like unto our brethren.
36929	1396	27	And my heart did sorrow because of this the great calamity of my people, because of their wickedness and their abominations. But behold, we did go forth against the Lamanites and the robbers of Gadianton, until we had again taken possession of the lands of our inheritance.
36930	1396	28	And the three hundred and forty and ninth year had passed away. And in the three hundred and fiftieth year we made a treaty with the Lamanites and the robbers of Gadianton, in which we did get the lands of our inheritance divided.
36931	1396	29	And the Lamanites did give unto us the land northward, yea, even to the narrow passage which led into the land southward. And we did give unto the Lamanites all the land southward.
36932	1397	1	And it came to pass that the Lamanites did not come to battle again until ten years more had passed away. And behold, I had employed my people, the Nephites, in preparing their lands and their arms against the time of battle.
36933	1397	2	And it came to pass that the Lord did say unto me: Cry unto this people--Repent ye, and come unto me, and be ye baptized, and build up again my church, and ye shall be spared.
36934	1397	3	And I did cry unto this people, but it was in vain; and they did not realize that it was the Lord that had spared them, and granted unto them a chance for repentance. And behold they did harden their hearts against the Lord their God.
36935	1397	4	And it came to pass that after this tenth year had passed away, making, in the whole, three hundred and sixty years from the coming of Christ, the king of the Lamanites sent an epistle unto me, which gave unto me to know that they were preparing to come again to battle against us.
36936	1397	5	And it came to pass that I did cause my people that they should gather themselves together at the land Desolation, to a city which was in the borders, by the narrow pass which led into the land southward.
36937	1397	6	And there we did place our armies, that we might stop the armies of the Lamanites, that they might not get possession of any of our lands; therefore we did fortify against them with all our force.
36938	1397	7	And it came to pass that in the three hundred and sixty and first year the Lamanites did come down to the city of Desolation to battle against us; and it came to pass that in that year we did beat them, insomuch that they did return to their own lands again.
36939	1397	8	And in the three hundred and sixty and second year they did come down again to battle. And we did beat them again, and did slay a great number of them, and their dead were cast into the sea.
36940	1397	9	And now, because of this great thing which my people, the Nephites, had done, they began to boast in their own strength, and began to swear before the heavens that they would avenge themselves of the blood of their brethren who had been slain by their enemies.
36941	1397	10	And they did swear by the heavens, and also by the throne of God, that they would go up to battle against their enemies, and would cut them off from the face of the land.
36942	1397	11	And it came to pass that I, Mormon, did utterly refuse from this time forth to be a commander and a leader of this people, because of their wickedness and abomination.
36943	1397	12	Behold, I had led them, notwithstanding their wickedness I had led them many times to battle, and had loved them, according to the love of God which was in me, with all my heart; and my soul had been poured out in prayer unto my God all the day long for them; nevertheless, it was without faith, because of the hardness of their hearts.
36944	1397	13	And thrice have I delivered them out of the hands of their enemies, and they have repented not of their sins.
36945	1397	14	And when they had sworn by all that had been forbidden them by our Lord and Savior Jesus Christ, that they would go up unto their enemies to battle, and avenge themselves of the blood of their brethren, behold the voice of the Lord came unto me, saying:
36946	1397	15	Vengeance is mine, and I will repay; and because this people repented not after I had delivered them, behold, they shall be cut off from the face of the earth.
36947	1397	16	And it came to pass that I utterly refused to go up against mine enemies; and I did even as the Lord had commanded me; and I did stand as an idle witness to manifest unto the world the things which I saw and heard, according to the manifestations of the Spirit which had testified of things to come.
36948	1397	17	Therefore I write unto you, Gentiles, and also unto you, house of Israel, when the work shall commence, that ye shall be about to prepare to return to the land of your inheritance;
36949	1397	18	Yea, behold, I write unto all the ends of the earth; yea, unto you, twelve tribes of Israel, who shall be judged according to your works by the twelve whom Jesus chose to be his disciples in the land of Jerusalem.
36950	1397	19	And I write also unto the remnant of this people, who shall also be judged by the twelve whom Jesus chose in this land; and they shall be judged by the other twelve whom Jesus chose in the land of Jerusalem.
36951	1397	20	And these things doth the Spirit manifest unto me; therefore I write unto you all. And for this cause I write unto you, that ye may know that ye must all stand before the judgment-seat of Christ, yea, every soul who belongs to the whole human family of Adam; and ye must stand to be judged of your works, whether they be good or evil;
36952	1397	21	And also that ye may believe the gospel of Jesus Christ, which ye shall have among you; and also that the Jews, the covenant people of the Lord, shall have other witness besides him whom they saw and heard, that Jesus, whom they slew, was the very Christ and the very God.
36953	1397	22	And I would that I could persuade all ye ends of the earth to repent and prepare to stand before the judgment-seat of Christ.
36954	1398	1	And now it came to pass that in the three hundred and sixty and third year the Nephites did go up with their armies to battle against the Lamanites, out of the land Desolation.
36955	1398	2	And it came to pass that the armies of the Nephites were driven back again to the land of Desolation. And while they were yet weary, a fresh army of the Lamanites did come upon them; and they had a sore battle, insomuch that the Lamanites did take possession of the city Desolation, and did slay many of the Nephites, and did take many prisoners.
36956	1398	3	And the remainder did flee and join the inhabitants of the city Teancum. Now the city Teancum lay in the borders by the seashore; and it was also near the city Desolation.
36957	1398	4	And it was because the armies of the Nephites went up unto the Lamanites that they began to be smitten; for were it not for that, the Lamanites could have had no power over them.
36958	1398	5	But, behold, the judgments of God will overtake the wicked; and it is by the wicked that the wicked are punished; for it is the wicked that stir up the hearts of the children of men unto bloodshed.
36959	1398	6	And it came to pass that the Lamanites did make preparations to come against the city Teancum.
36960	1398	7	And it came to pass in the three hundred and sixty and fourth year the Lamanites did come against the city Teancum, that they might take possession of the city Teancum also.
36961	1398	8	And it came to pass that they were repulsed and driven back by the Nephites. And when the Nephites saw that they had driven the Lamanites they did again boast of their own strength; and they went forth in their own might, and took possession again of the city Desolation.
36962	1398	9	And now all these things had been done, and there had been thousands slain on both sides, both the Nephites and the Lamanites.
36963	1398	10	And it came to pass that the three hundred and sixty and sixth year had passed away, and the Lamanites came again upon the Nephites to battle; and yet the Nephites repented not of the evil they had done, but persisted in their wickedness continually.
36964	1398	11	And it is impossible for the tongue to describe, or for man to write a perfect description of the horrible scene of the blood and carnage which was among the people, both of the Nephites and of the Lamanites; and every heart was hardened, so that they delighted in the shedding of blood continually.
36965	1398	12	And there never had been so great wickedness among all the children of Lehi, nor even among all the house of Israel, according to the words of the Lord, as was among this people.
36966	1398	13	And it came to pass that the Lamanites did take possession of the city Desolation, and this because their number did exceed the number of the Nephites.
36967	1398	14	And they did also march forward against the city Teancum, and did drive the inhabitants forth out of her, and did take many prisoners both women and children, and did offer them up as sacrifices unto their idol gods.
36968	1398	15	And it came to pass that in the three hundred and sixty and seventh year, the Nephites being angry because the Lamanites had sacrificed their women and their children, that they did go against the Lamanites with exceedingly great anger, insomuch that they did beat again the Lamanites, and drive them out of their lands.
36969	1398	16	And the Lamanites did not come again against the Nephites until the three hundred and seventy and fifth year.
36970	1398	17	And in this year they did come down against the Nephites with all their powers; and they were not numbered because of the greatness of their number.
36971	1398	18	And from this time forth did the Nephites gain no power over the Lamanites, but began to be swept off by them even as a dew before the sun.
36972	1398	19	And it came to pass that the Lamanites did come down against the city Desolation; and there was an exceedingly sore battle fought in the land Desolation, in the which they did beat the Nephites.
36973	1398	20	And they fled again from before them, and they came to the city Boaz; and there they did stand against the Lamanites with exceeding boldness, insomuch that the Lamanites did not beat them until they had come again the second time.
36974	1398	21	And when they had come the second time, the Nephites were driven and slaughtered with an exceedingly great slaughter; their women and their children were again sacrificed unto idols.
36975	1398	22	And it came to pass that the Nephites did again flee from before them, taking all the inhabitants with them, both in towns and villages.
36976	1398	23	And now I, Mormon, seeing that the Lamanites were about to overthrow the land, therefore I did go to the hill Shim, and did take up all the records which Ammaron had hid up unto the Lord.
36977	1399	1	And it came to pass that I did go forth among the Nephites, and did repent of the oath which I had made that I would no more assist them; and they gave me command again of their armies, for they looked upon me as though I could deliver them from their afflictions.
36978	1399	2	But behold, I was without hope, for I knew the judgments of the Lord which should come upon them; for they repented not of their iniquities, but did struggle for their lives without calling upon that Being who created them.
36979	1399	3	And it came to pass that the Lamanites did come against us as we had fled to the city of Jordan; but behold, they were driven back that they did not take the city at that time.
36980	1399	4	And it came to pass that they came against us again, and we did maintain the city. And there were also other cities which were maintained by the Nephites, which strongholds did cut them off that they could not get into the country which lay before us, to destroy the inhabitants of our land.
36981	1399	5	And it came to pass that whatsoever lands we had passed by, and the inhabitants thereof were not gathered in, were destroyed by the Lamanites, and their towns, and villages, and cities were burned with fire; and thus three hundred and seventy and nine years passed away.
36982	1399	6	And it came to pass that in the three hundred and eightieth year the Lamanites did come again against us to battle, and we did stand against them boldly; but it was all in vain, for so great were their numbers that they did tread the people of the Nephites under their feet.
36983	1399	7	And it came to pass that we did again take to flight, and those whose flight was swifter than the Lamanites' did escape, and those whose flight did not exceed the Lamanites' were swept down and destroyed.
36984	1399	8	And now behold, I, Mormon, do not desire to harrow up the souls of men in casting before them such an awful scene of blood and carnage as was laid before mine eyes; but I, knowing that these things must surely be made known, and that all things which are hid must be revealed upon the house-tops--
36985	1399	9	And also that a knowledge of these things must come unto the remnant of these people, and also unto the Gentiles, who the Lord hath said should scatter this people, and this people should be counted as naught among them--therefore I write a small abridgment, daring not to give a full account of the things which I have seen, because of the commandment which I have received, and also that ye might not have too great sorrow because of the wickedness of this people.
36986	1399	10	And now behold, this I speak unto their seed, and also to the Gentiles who have care for the house of Israel, that realize and know from whence their blessings come.
36987	1399	11	For I know that such will sorrow for the calamity of the house of Israel; yea, they will sorrow for the destruction of this people; they will sorrow that this people had not repented that they might have been clasped in the arms of Jesus.
36988	1399	12	Now these things are written unto the remnant of the house of Jacob; and they are written after this manner, because it is known of God that wickedness will not bring them forth unto them; and they are to be hid up unto the Lord that they may come forth in his own due time.
36989	1399	13	And this is the commandment which I have received; and behold, they shall come forth according to the commandment of the Lord, when he shall see fit, in his wisdom.
36990	1399	14	And behold, they shall go unto the unbelieving of the Jews; and for this intent shall they go--that they may be persuaded that Jesus is the Christ, the Son of the living God; that the Father may bring about, through his most Beloved, his great and eternal purpose, in restoring the Jews, or all the house of Israel, to the land of their inheritance, which the Lord their God hath given them, unto the fulfilling of his covenant;
36991	1399	15	And also that the seed of this people may more fully believe his gospel, which shall go forth unto them from the Gentiles; for this people shall be scattered, and shall become a dark, a filthy, and a loathsome people, beyond the description of that which ever hath been amongst us, yea, even that which hath been among the Lamanites, and this because of their unbelief and idolatry.
36992	1399	16	For behold, the Spirit of the Lord hath already ceased to strive with their fathers; and they are without Christ and God in the world; and they are driven about as chaff before the wind.
36993	1399	17	They were once a delightsome people, and they had Christ for their shepherd; yea, they were led even by God the Father.
36994	1399	18	But now, behold, they are led about by Satan, even as chaff is driven before the wind, or as a vessel is tossed about upon the waves, without sail or anchor, or without anything wherewith to steer her; and even as she is, so are they.
36995	1399	19	And behold, the Lord hath reserved their blessings, which they might have received in the land, for the Gentiles who shall possess the land.
36996	1399	20	But behold, it shall come to pass that they shall be driven and scattered by the Gentiles; and after they have been driven and scattered by the Gentiles, behold, then will the Lord remember the covenant which he made unto Abraham and unto all the house of Israel.
36997	1399	21	And also the Lord will remember the prayers of the righteous, which have been put up unto him for them.
36998	1399	22	And then, O ye Gentiles, how can ye stand before the power of God, except ye shall repent and turn from your evil ways?
36999	1399	23	Know ye not that ye are in the hands of God? Know ye not that he hath all power, and at his great command the earth shall be rolled together as a scroll?
37000	1399	24	Therefore, repent ye, and humble yourselves before him, lest he shall come out in justice against you--lest a remnant of the seed of Jacob shall go forth among you as a lion, and tear you in pieces, and there is none to deliver.
37001	1400	1	And now I finish my record concerning the destruction of my people, the Nephites. And it came to pass that we did march forth before the Lamanites.
37002	1400	2	And I, Mormon, wrote an epistle unto the king of the Lamanites, and desired of him that he would grant unto us that we might gather together our people unto the land of Cumorah, by a hill which was called Cumorah, and there we could give them battle.
37003	1400	3	And it came to pass that the king of the Lamanites did grant unto me the thing which I desired.
37004	1400	4	And it came to pass that we did march forth to the land of Cumorah, and we did pitch our tents around about the hill Cumorah; and it was in a land of many waters, rivers, and fountains; and here we had hope to gain advantage over the Lamanites.
37005	1400	5	And when three hundred and eighty and four years had passed away, we had gathered in all the remainder of our people unto the land of Cumorah.
37006	1400	6	And it came to pass that when we had gathered in all our people in one to the land of Cumorah, behold I, Mormon, began to be old; and knowing it to be the last struggle of my people, and having been commanded of the Lord that I should not suffer the records which had been handed down by our fathers, which were sacred, to fall into the hands of the Lamanites, (for the Lamanites would destroy them) therefore I made this record out of the plates of Nephi, and hid up in the hill Cumorah all the records which had been entrusted to me by the hand of the Lord, save it were these few plates which I gave unto my son Moroni.
37007	1400	7	And it came to pass that my people, with their wives and their children, did now behold the armies of the Lamanites marching towards them; and with that awful fear of death which fills the breasts of all the wicked, did they await to receive them.
37008	1400	8	And it came to pass that they came to battle against us, and every soul was filled with terror because of the greatness of their numbers.
37009	1400	9	And it came to pass that they did fall upon my people with the sword, and with the bow, and with the arrow, and with the ax, and with all manner of weapons of war.
37010	1400	10	And it came to pass that my men were hewn down, yea, even my ten thousand who were with me, and I fell wounded in the midst; and they passed by me that they did not put an end to my life.
37011	1400	11	And when they had gone through and hewn down all my people save it were twenty and four of us, (among whom was my son Moroni) and we having survived the dead of our people, did behold on the morrow, when the Lamanites had returned unto their camps, from the top of the hill Cumorah, the ten thousand of my people who were hewn down, being led in the front by me.
37012	1400	12	And we also beheld the ten thousand of my people who were led by my son Moroni.
37013	1400	13	And behold, the ten thousand of Gidgiddonah had fallen, and he also in the midst.
37014	1400	14	And Lamah had fallen with his ten thousand; and Gilgal had fallen with his ten thousand; and Limhah had fallen with his ten thousand; and Jeneum had fallen with his ten thousand; and Cumenihah, and Moronihah, and Antionum, and Shiblom, and Shem, and Josh, had fallen with their ten thousand each.
37015	1400	15	And it came to pass that there were ten more who did fall by the sword, with their ten thousand each; yea, even all my people, save it were those twenty and four who were with me, and also a few who had escaped into the south countries, and a few who had deserted over unto the Lamanites, had fallen; and their flesh, and bones, and blood lay upon the face of the earth, being left by the hands of those who slew them to molder upon the land, and to crumble and to return to their mother earth.
37016	1400	16	And my soul was rent with anguish, because of the slain of my people, and I cried:
37017	1400	17	O ye fair ones, how could ye have departed from the ways of the Lord! O ye fair ones, how could ye have rejected that Jesus, who stood with open arms to receive you!
37018	1400	18	Behold, if ye had not done this, ye would not have fallen. But behold, ye are fallen, and I mourn your loss.
37019	1400	19	O ye fair sons and daughters, ye fathers and mothers, ye husbands and wives, ye fair ones, how is it that ye could have fallen!
37020	1400	20	But behold, ye are gone, and my sorrows cannot bring your return.
37021	1400	21	And the day soon cometh that your mortal must put on immortality, and these bodies which are now moldering in corruption must soon become incorruptible bodies; and then ye must stand before the judgment-seat of Christ, to be judged according to your works; and if it so be that ye are righteous, then are ye blessed with your fathers who have gone before you.
37022	1400	22	O that ye had repented before this great destruction had come upon you. But behold, ye are gone, and the Father, yea, the Eternal Father of heaven, knoweth your state; and he doeth with you according to his justice and mercy.
37023	1401	1	And now, behold, I would speak somewhat unto the remnant of this people who are spared, if it so be that God may give unto them my words, that they may know of the things of their fathers; yea, I speak unto you, ye remnant of the house of Israel; and these are the words which I speak:
37024	1401	2	Know ye that ye are of the house of Israel.
37025	1401	3	Know ye that ye must come unto repentance, or ye cannot be saved.
37026	1401	4	Know ye that ye must lay down your weapons of war, and delight no more in the shedding of blood, and take them not again, save it be that God shall command you.
37027	1401	5	Know ye that ye must come to the knowledge of your fathers, and repent of all your sins and iniquities, and believe in Jesus Christ, that he is the Son of God, and that he was slain by the Jews, and by the power of the Father he hath risen again, whereby he hath gained the victory over the grave; and also in him is the sting of death swallowed up.
37028	1401	6	And he bringeth to pass the resurrection of the dead, whereby man must be raised to stand before his judgment-seat.
37029	1401	7	And he hath brought to pass the redemption of the world, whereby he that is found guiltless before him at the judgment day hath it given unto him to dwell in the presence of God in his kingdom, to sing ceaseless praises with the choirs above, unto the Father, and unto the Son, and unto the Holy Ghost, which are one God, in a state of happiness which hath no end.
37030	1401	8	Therefore repent, and be baptized in the name of Jesus, and lay hold upon the gospel of Christ, which shall be set before you, not only in this record but also in the record which shall come unto the Gentiles from the Jews, which record shall come from the Gentiles unto you.
37031	1401	9	For behold, this is written for the intent that ye may believe that; and if ye believe that ye will believe this also; and if ye believe this ye will know concerning your fathers, and also the marvelous works which were wrought by the power of God among them.
37032	1401	10	And ye will also know that ye are a remnant of the seed of Jacob; therefore ye are numbered among the people of the first covenant; and if it so be that ye believe in Christ, and are baptized, first with water, then with fire and with the Holy Ghost, following the example of our Savior, according to that which he hath commanded us, it shall be well with you in the day of judgment. Amen.
37033	1402	1	Behold I, Moroni, do finish the record of my father, Mormon. Behold, I have but few things to write, which things I have been commanded by my father.
37034	1402	2	And now it came to pass that after the great and tremendous battle at Cumorah, behold, the Nephites who had escaped into the country southward were hunted by the Lamanites, until they were all destroyed.
37035	1402	3	And my father also was killed by them, and I even remain alone to write the sad tale of the destruction of my people. But behold, they are gone, and I fulfil the commandment of my father. And whether they will slay me, I know not.
37036	1402	4	Therefore I will write and hide up the records in the earth; and whither I go it mattereth not.
37037	1402	5	Behold, my father hath made this record, and he hath written the intent thereof. And behold, I would write it also if I had room upon the plates, but I have not; and ore I have none, for I am alone. My father hath been slain in battle, and all my kinsfolk, and I have not friends nor whither to go; and how long the Lord will suffer that I may live I know not.
37038	1402	6	Behold, four hundred years have passed away since the coming of our Lord and Savior.
37039	1402	7	And behold, the Lamanites have hunted my people, the Nephites, down from city to city and from place to place, even until they are no more; and great has been their fall; yea, great and marvelous is the destruction of my people, the Nephites.
37040	1402	8	And behold, it is the hand of the Lord which hath done it. And behold also, the Lamanites are at war one with another; and the whole face of this land is one continual round of murder and bloodshed; and no one knoweth the end of the war.
37041	1402	9	And now, behold, I say no more concerning them, for there are none save it be the Lamanites and robbers that do exist upon the face of the land.
37042	1402	10	And there are none that do know the true God save it be the disciples of Jesus, who did tarry in the land until the wickedness of the people was so great that the Lord would not suffer them to remain with the people; and whether they be upon the face of the land no man knoweth.
37043	1402	11	But behold, my father and I have seen them, and they have ministered unto us.
37044	1402	12	And whoso receiveth this record, and shall not condemn it because of the imperfections which are in it, the same shall know of greater things than these. Behold, I am Moroni; and were it possible, I would make all things known unto you.
37045	1402	13	Behold, I make an end of speaking concerning this people. I am the son of Mormon, and my father was a descendant of Nephi.
37046	1402	14	And I am the same who hideth up this record unto the Lord; the plates thereof are of no worth, because of the commandment of the Lord. For he truly saith that no one shall have them to get gain; but the record thereof is of great worth; and whoso shall bring it to light, him will the Lord bless.
37047	1402	15	For none can have power to bring it to light save it be given him of God; for God wills that it shall be done with an eye single to his glory, or the welfare of the ancient and long dispersed covenant people of the Lord.
37048	1402	16	And blessed be he that shall bring this thing to light; for it shall be brought out of darkness unto light, according to the word of God; yea, it shall be brought out of the earth, and it shall shine forth out of darkness, and come unto the knowledge of the people; and it shall be done by the power of God.
37049	1402	17	And if there be faults they be the faults of a man. But behold, we know no fault; nevertheless God knoweth all things; therefore, he that condemneth, let him be aware lest he shall be in danger of hell fire.
37050	1402	18	And he that saith: Show unto me, or ye shall be smitten--let him beware lest he commandeth that which is forbidden of the Lord.
37051	1402	19	For behold, the same that judgeth rashly shall be judged rashly again; for according to his works shall his wages be; therefore, he that smiteth shall be smitten again, of the Lord.
37052	1402	20	Behold what the scripture says--man shall not smite, neither shall he judge; for judgment is mine, saith the Lord, and vengeance is mine also, and I will repay.
37053	1402	21	And he that shall breathe out wrath and strifes against the work of the Lord, and against the covenant people of the Lord who are the house of Israel, and shall say: We will destroy the work of the Lord, and the Lord will not remember his covenant which he hath made unto the house of Israel--the same is in danger to be hewn down and cast into the fire;
37054	1402	22	For the eternal purposes of the Lord shall roll on, until all his promises shall be fulfilled.
37055	1402	23	Search the prophecies of Isaiah. Behold, I cannot write them. Yea, behold I say unto you, that those saints who have gone before me, who have possessed this land, shall cry, yea, even from the dust will they cry unto the Lord; and as the Lord liveth he will remember the covenant which he hath made with them.
37056	1402	24	And he knoweth their prayers, that they were in behalf of their brethren. And he knoweth their faith, for in his name could they remove mountains; and in his name could they cause the earth to shake; and by the power of his word did they cause prisons to tumble to the earth; yea, even the fiery furnace could not harm them, neither wild beasts nor poisonous serpents, because of the power of his word.
37057	1402	25	And behold, their prayers were also in behalf of him that the Lord should suffer to bring these things forth.
37058	1402	26	And no one need say they shall not come, for they surely shall, for the Lord hath spoken it; for out of the earth shall they come, by the hand of the Lord, and none can stay it; and it shall come in a day when it shall be said that miracles are done away; and it shall come even as if one should speak from the dead.
37059	1402	27	And it shall come in a day when the blood of saints shall cry unto the Lord, because of secret combinations and the works of darkness.
37060	1402	28	Yea, it shall come in a day when the power of God shall be denied, and churches become defiled and be lifted up in the pride of their hearts; yea, even in a day when leaders of churches and teachers shall rise in the pride of their hearts, even to the envying of them who belong to their churches.
37061	1402	29	Yea, it shall come in a day when there shall be heard of fires, and tempests, and vapors of smoke in foreign lands;
37062	1402	30	And there shall also be heard of wars, rumors of wars, and earthquakes in divers places.
37063	1402	31	Yea, it shall come in a day when there shall be great pollutions upon the face of the earth; there shall be murders, and robbing, and lying, and deceivings, and whoredoms, and all manner of abominations; when there shall be many who will say, Do this, or do that, and it mattereth not, for the Lord will uphold such at the last day. But wo unto such, for they are in the gall of bitterness and in the bonds of iniquity.
37064	1402	32	Yea, it shall come in a day when there shall be churches built up that shall say: Come unto me, and for your money you shall be forgiven of your sins.
37065	1402	33	O ye wicked and perverse and stiffnecked people, why have ye built up churches unto yourselves to get gain? Why have ye transfigured the holy word of God, that ye might bring damnation upon your souls? Behold, look ye unto the revelations of God; for behold, the time cometh at that day when all these things must be fulfilled.
37066	1402	34	Behold, the Lord hath shown unto me great and marvelous things concerning that which must shortly come, at that day when these things shall come forth among you.
37067	1402	35	Behold, I speak unto you as if ye were present, and yet ye are not. But behold, Jesus Christ hath shown you unto me, and I know your doing.
37068	1402	36	And I know that ye do walk in the pride of your hearts; and there are none save a few only who do not lift themselves up in the pride of their hearts, unto the wearing of very fine apparel, unto envying, and strifes, and malice, and persecutions, and all manner of iniquities; and your churches, yea, even every one, have become polluted because of the pride of your hearts.
37069	1402	37	For behold, ye do love money, and your substance, and your fine apparel, and the adorning of your churches, more than ye love the poor and the needy, the sick and the afflicted.
37070	1402	38	O ye pollutions, ye hypocrites, ye teachers, who sell yourselves for that which will canker, why have ye polluted the holy church of God? Why are ye ashamed to take upon you the name of Christ? Why do ye not think that greater is the value of an endless happiness than that misery which never dies--because of the praise of the world?
37071	1402	39	Why do ye adorn yourselves with that which hath no life, and yet suffer the hungry, and the needy, and the naked, and the sick and the afflicted to pass by you, and notice them not?
37072	1402	40	Yea, why do ye build up your secret abominations to get gain, and cause that widows should mourn before the Lord, and also orphans to mourn before the Lord, and also the blood of their fathers and their husbands to cry unto the Lord from the ground, for vengeance upon your heads?
37073	1402	41	Behold, the sword of vengeance hangeth over you; and the time soon cometh that he avengeth the blood of the saints upon you, for he will not suffer their cries any longer.
37074	1403	1	And now, I speak also concerning those who do not believe in Christ.
37075	1403	2	Behold, will ye believe in the day of your visitation--behold, when the Lord shall come, yea, even that great day when the earth shall be rolled together as a scroll, and the elements shall melt with fervent heat, yea, in that great day when ye shall be brought to stand before the Lamb of God--then will ye say that there is no God?
37076	1403	3	Then will ye longer deny the Christ, or can ye behold the Lamb of God? Do ye suppose that ye shall dwell with him under a consciousness of your guilt? Do ye suppose that ye could be happy to dwell with that holy Being, when your souls are racked with a consciousness of guilt that ye have ever abused his laws?
37077	1403	4	Behold, I say unto you that ye would be more miserable to dwell with a holy and just God, under a consciousness of your filthiness before him, than ye would to dwell with the damned souls in hell.
37078	1403	5	For behold, when ye shall be brought to see your nakedness before God, and also the glory of God, and the holiness of Jesus Christ, it will kindle a flame of unquenchable fire upon you.
37079	1403	6	O then ye unbelieving, turn ye unto the Lord; cry mightily unto the Father in the name of Jesus, that perhaps ye may be found spotless, pure, fair, and white, having been cleansed by the blood of the Lamb, at that great and last day.
37080	1403	7	And again I speak unto you who deny the revelations of God, and say that they are done away, that there are no revelations, nor prophecies, nor gifts, nor healing, nor speaking with tongues, and the interpretation of tongues;
37081	1403	8	Behold I say unto you, he that denieth these things knoweth not the gospel of Christ; yea, he has not read the scriptures; if so, he does not understand them.
37082	1403	9	For do we not read that God is the same yesterday, today, and forever, and in him there is no variableness neither shadow of changing?
37083	1403	10	And now, if ye have imagined up unto yourselves a god who doth vary, and in whom there is shadow of changing, then have ye imagined up unto yourselves a god who is not a God of miracles.
37084	1403	11	But behold, I will show unto you a God of miracles, even the God of Abraham, and the God of Isaac, and the God of Jacob; and it is that same God who created the heavens and the earth, and all things that in them are.
37085	1403	12	Behold, he created Adam, and by Adam came the fall of man. And because of the fall of man came Jesus Christ, even the Father and the Son; and because of Jesus Christ came the redemption of man.
37086	1403	13	And because of the redemption of man, which came by Jesus Christ, they are brought back into the presence of the Lord; yea, this is wherein all men are redeemed, because the death of Christ bringeth to pass the resurrection, which bringeth to pass a redemption from an endless sleep, from which sleep all men shall be awakened by the power of God when the trump shall sound; and they shall come forth, both small and great, and all shall stand before his bar, being redeemed and loosed from this eternal band of death, which death is a temporal death.
37087	1403	14	And then cometh the judgment of the Holy One upon them; and then cometh the time that he that is filthy shall be filthy still; and he that is righteous shall be righteous still; he that is happy shall be happy still; and he that is unhappy shall be unhappy still.
37088	1403	15	And now, O all ye that have imagined up unto yourselves a god who can do no miracles, I would ask of you, have all these things passed, of which I have spoken? Has the end come yet? Behold I say unto you, Nay; and God has not ceased to be a God of miracles.
37089	1403	16	Behold, are not the things that God hath wrought marvelous in our eyes? Yea, and who can comprehend the marvelous works of God?
37090	1403	17	Who shall say that it was not a miracle that by his word the heaven and the earth should be; and by the power of his word man was created of the dust of the earth; and by the power of his word have miracles been wrought?
37091	1403	18	And who shall say that Jesus Christ did not do many mighty miracles? And there were many mighty miracles wrought by the hands of the apostles.
37092	1403	19	And if there were miracles wrought then, why has God ceased to be a God of miracles and yet be an unchangeable Being? And behold, I say unto you he changeth not; if so he would cease to be God; and he ceaseth not to be God, and is a God of miracles.
37093	1403	20	And the reason why he ceaseth to do miracles among the children of men is because that they dwindle in unbelief, and depart from the right way, and know not the God in whom they should trust.
37094	1403	21	Behold, I say unto you that whoso believeth in Christ, doubting nothing, whatsoever he shall ask the Father in the name of Christ it shall be granted him; and this promise is unto all, even unto the ends of the earth.
37095	1403	22	For behold, thus said Jesus Christ, the Son of God, unto his disciples who should tarry, yea, and also to all his disciples, in the hearing of the multitude: Go ye into all the world, and preach the gospel to every creature;
37096	1403	23	And he that believeth and is baptized shall be saved, but he that believeth not shall be damned;
37097	1403	24	And these signs shall follow them that believe--in my name shall they cast out devils; they shall speak with new tongues; they shall take up serpents; and if they drink any deadly thing it shall not hurt them; they shall lay hands on the sick and they shall recover;
37098	1403	25	And whosoever shall believe in my name, doubting nothing, unto him will I confirm all my words, even unto the ends of the earth.
37099	1403	26	And now, behold, who can stand against the works of the Lord? Who can deny his sayings? Who will rise up against the almighty power of the Lord? Who will despise the works of the Lord? Who will despise the children of Christ? Behold, all ye who are despisers of the works of the Lord, for ye shall wonder and perish.
37100	1403	27	O then despise not, and wonder not, but hearken unto the words of the Lord, and ask the Father in the name of Jesus for what things soever ye shall stand in need. Doubt not, but be believing, and begin as in times of old, and come unto the Lord with all your heart, and work out your own salvation with fear and trembling before him.
37101	1403	28	Be wise in the days of your probation; strip yourselves of all uncleanness; ask not, that ye may consume it on your lusts, but ask with a firmness unshaken, that ye will yield to no temptation, but that ye will serve the true and living God.
37102	1403	29	See that ye are not baptized unworthily; see that ye partake not of the sacrament of Christ unworthily; but see that ye do all things in worthiness, and do it in the name of Jesus Christ, the Son of the living God; and if ye do this, and endure to the end, ye will in nowise be cast out.
37103	1403	30	Behold, I speak unto you as though I spake from the dead; for I know that ye shall have my words.
37104	1403	31	Condemn me not because of mine imperfection, neither my father, because of his imperfection, neither them who have written before him; but rather give thanks unto God that he hath made manifest unto you our imperfections, that ye may learn to be more wise than we have been.
37105	1403	32	And now, behold, we have written this record according to our knowledge, in the characters which are called among us the reformed Egyptian, being handed down and altered by us, according to our manner of speech.
37106	1403	33	And if our plates had been sufficiently large we should have written in Hebrew; but the Hebrew hath been altered by us also; and if we could have written in Hebrew, behold, ye would have had no imperfection in our record.
37107	1403	34	But the Lord knoweth the things which we have written, and also that none other people knoweth our language; and because that none other people knoweth our language, therefore he hath prepared means for the interpretation thereof.
37108	1403	35	And these things are written that we may rid our garments of the blood of our brethren, who have dwindled in unbelief.
37109	1403	36	And behold, these things which we have desired concerning our brethren, yea, even their restoration to the knowledge of Christ, are according to the prayers of all the saints who have dwelt in the land.
37110	1403	37	And may the Lord Jesus Christ grant that their prayers may be answered according to their faith; and may God the Father remember the covenant which he hath made with the house of Israel; and may he bless them forever, through faith on the name of Jesus Christ. Amen.
37111	1404	1	And now I, Moroni, proceed to give an account of those ancient inhabitants who were destroyed by the hand of the Lord upon the face of this north country.
37112	1404	2	And I take mine account from the twenty and four plates which were found by the people of Limhi, which is called the Book of Ether.
37113	1404	3	And as I suppose that the first part of this record, which speaks concerning the creation of the world, and also of Adam, and an account from that time even to the great tower, and whatsoever things transpired among the children of men until that time, is had among the Jews--
37114	1404	4	Therefore I do not write those things which transpired from the days of Adam until that time; but they are had upon the plates; and whoso findeth them, the same will have power that he may get the full account.
37115	1404	5	But behold, I give not the full account, but a part of the account I give, from the tower down until they were destroyed.
37116	1404	6	And on this wise do I give the account. He that wrote this record was Ether, and he was a descendant of Coriantor.
37117	1404	7	Coriantor was the son of Moron.
37118	1404	8	And Moron was the son of Ethem.
37119	1404	9	And Ethem was the son of Ahah.
37120	1404	10	And Ahah was the son of Seth.
37121	1404	11	And Seth was the son of Shiblon.
37122	1404	12	And Shiblon was the son of Com.
37123	1404	13	And Com was the son of Coriantum.
37124	1404	14	And Coriantum was the son of Amnigaddah.
37125	1404	15	And Amnigaddah was the son of Aaron.
37126	1404	16	And Aaron was a descendant of Heth, who was the son of Hearthom.
37127	1404	17	And Hearthom was the son of Lib.
37128	1404	18	And Lib was the son of Kish.
37129	1404	19	And Kish was the son of Corom.
37130	1404	20	And Corom was the son of Levi.
37131	1404	21	And Levi was the son of Kim.
37132	1404	22	And Kim was the son of Morianton.
37133	1404	23	And Morianton was a descendant of Riplakish.
37134	1404	24	And Riplakish was the son of Shez.
37135	1404	25	And Shez was the son of Heth.
37136	1404	26	And Heth was the son of Com.
37137	1404	27	And Com was the son of Coriantum.
37138	1404	28	And Coriantum was the son of Emer.
37139	1404	29	And Emer was the son of Omer.
37140	1404	30	And Omer was the son of Shule.
37141	1404	31	And Shule was the son of Kib.
37142	1404	32	And Kib was the son of Orihah, who was the son of Jared;
37143	1404	33	Which Jared came forth with his brother and their families, with some others and their families, from the great tower, at the time the Lord confounded the language of the people, and swore in his wrath that they should be scattered upon all the face of the earth; and according to the word of the Lord the people were scattered.
37144	1404	34	And the brother of Jared being a large and mighty man, and a man highly favored of the Lord, Jared, his brother, said unto him: Cry unto the Lord, that he will not confound us that we may not understand our words.
37145	1404	35	And it came to pass that the brother of Jared did cry unto the Lord, and the Lord had compassion upon Jared; therefore he did not confound the language of Jared; and Jared and his brother were not confounded.
37146	1404	36	Then Jared said unto his brother: Cry again unto the Lord, and it may be that he will turn away his anger from them who are our friends, that he confound not their language.
37147	1404	37	And it came to pass that the brother of Jared did cry unto the Lord, and the Lord had compassion upon their friends and their families also, that they were not confounded.
37148	1404	38	And it came to pass that Jared spake again unto his brother, saying: Go and inquire of the Lord whether he will drive us out of the land, and if he will drive us out of the land, cry unto him whither we shall go. And who knoweth but the Lord will carry us forth into a land which is choice above all the earth? And if it so be, let us be faithful unto the Lord, that we may receive it for our inheritance.
37149	1404	39	And it came to pass that the brother of Jared did cry unto the Lord according to that which had been spoken by the mouth of Jared.
37150	1404	40	And it came to pass that the Lord did hear the brother of Jared, and had compassion upon him, and said unto him:
37151	1404	41	Go to and gather together thy flocks, both male and female, of every kind; and also of the seed of the earth of every kind; and thy families; and also Jared thy brother and his family; and also thy friends and their families, and the friends of Jared and their families.
37152	1404	42	And when thou hast done this thou shalt go at the head of them down into the valley which is northward. And there will I meet thee, and I will go before thee into a land which is choice above all the lands of the earth.
37153	1404	43	And there will I bless thee and thy seed, and raise up unto me of thy seed, and of the seed of thy brother, and they who shall go with thee, a great nation. And there shall be none greater than the nation which I will raise up unto me of thy seed, upon all the face of the earth. And thus I will do unto thee because this long time ye have cried unto me.
37154	1405	1	And it came to pass that Jared and his brother, and their families, and also the friends of Jared and his brother and their families, went down into the valley which was northward, (and the name of the valley was Nimrod, being called after the mighty hunter) with their flocks which they had gathered together, male and female, of every kind.
37155	1405	2	And they did also lay snares and catch fowls of the air; and they did also prepare a vessel, in which they did carry with them the fish of the waters.
37156	1405	3	And they did also carry with them deseret, which, by interpretation, is a honey bee; and thus they did carry with them swarms of bees, and all manner of that which was upon the face of the land, seeds of every kind.
37157	1405	4	And it came to pass that when they had come down into the valley of Nimrod the Lord came down and talked with the brother of Jared; and he was in a cloud, and the brother of Jared saw him not.
37158	1405	5	And it came to pass that the Lord commanded them that they should go forth into the wilderness, yea, into that quarter where there never had man been. And it came to pass that the Lord did go before them, and did talk with them as he stood in a cloud, and gave directions whither they should travel.
37159	1405	6	And it came to pass that they did travel in the wilderness, and did build barges, in which they did cross many waters, being directed continually by the hand of the Lord.
37160	1405	7	And the Lord would not suffer that they should stop beyond the sea in the wilderness, but he would that they should come forth even unto the land of promise, which was choice above all other lands, which the Lord God had preserved for a righteous people.
37161	1405	8	And he had sworn in his wrath unto the brother of Jared, that whoso should possess this land of promise, from that time henceforth and forever, should serve him, the true and only God, or they should be swept off when the fulness of his wrath should come upon them.
37162	1405	9	And now, we can behold the decrees of God concerning this land, that it is a land of promise; and whatsoever nation shall possess it shall serve God, or they shall be swept off when the fulness of his wrath shall come upon them. And the fulness of his wrath cometh upon them when they are ripened in iniquity.
37163	1405	10	For behold, this is a land which is choice above all other lands; wherefore he that doth possess it shall serve God or shall be swept off; for it is the everlasting decree of God. And it is not until the fulness of iniquity among the children of the land, that they are swept off.
37164	1405	11	And this cometh unto you, O ye Gentiles, that ye may know the decrees of God--that ye may repent, and not continue in your iniquities until the fulness come, that ye may not bring down the fulness of the wrath of God upon you as the inhabitants of the land have hitherto done.
37165	1405	12	Behold, this is a choice land, and whatsoever nation shall possess it shall be free from bondage, and from captivity, and from all other nations under heaven, if they will but serve the God of the land, who is Jesus Christ, who hath been manifested by the things which we have written.
37166	1405	13	And now I proceed with my record; for behold, it came to pass that the Lord did bring Jared and his brethren forth even to that great sea which divideth the lands. And as they came to the sea they pitched their tents; and they called the name of the place Moriancumer; and they dwelt in tents, and dwelt in tents upon the seashore for the space of four years.
37167	1405	14	And it came to pass at the end of four years that the Lord came again unto the brother of Jared, and stood in a cloud and talked with him. And for the space of three hours did the Lord talk with the brother of Jared, and chastened him because he remembered not to call upon the name of the Lord.
37168	1405	15	And the brother of Jared repented of the evil which he had done, and did call upon the name of the Lord for his brethren who were with him. And the Lord said unto him: I will forgive thee and thy brethren of their sins; but thou shalt not sin any more, for ye shall remember that my Spirit will not always strive with man; wherefore, if ye will sin until ye are fully ripe ye shall be cut off from the presence of the Lord. And these are my thoughts upon the land which I shall give you for your inheritance; for it shall be a land choice above all other lands.
37169	1405	16	And the Lord said: Go to work and build, after the manner of barges which ye have hitherto built. And it came to pass that the brother of Jared did go to work, and also his brethren, and built barges after the manner which they had built, according to the instructions of the Lord. And they were small, and they were light upon the water, even like unto the lightness of a fowl upon the water.
37170	1405	17	And they were built after a manner that they were exceedingly tight, even that they would hold water like unto a dish; and the bottom thereof was tight like unto a dish; and the sides thereof were tight like unto a dish; and the ends thereof were peaked; and the top thereof was tight like unto a dish; and the length thereof was the length of a tree; and the door thereof, when it was shut, was tight like unto a dish.
37171	1405	18	And it came to pass that the brother of Jared cried unto the Lord, saying: O Lord, I have performed the work which thou hast commanded me, and I have made the barges according as thou hast directed me.
37172	1405	19	And behold, O Lord, in them there is no light; whither shall we steer? And also we shall perish, for in them we cannot breathe, save it is the air which is in them; therefore we shall perish.
37173	1405	20	And the Lord said unto the brother of Jared: Behold, thou shalt make a hole in the top, and also in the bottom; and when thou shalt suffer for air thou shalt unstop the hole and receive air. And if it be so that the water come in upon thee, behold, ye shall stop the hole, that ye may not perish in the flood.
37174	1405	21	And it came to pass that the brother of Jared did so, according as the Lord had commanded.
37175	1405	22	And he cried again unto the Lord saying: O Lord, behold I have done even as thou hast commanded me; and I have prepared the vessels for my people, and behold there is no light in them. Behold, O Lord, wilt thou suffer that we shall cross this great water in darkness?
37176	1405	23	And the Lord said unto the brother of Jared: What will ye that I should do that ye may have light in your vessels? For behold, ye cannot have windows, for they will be dashed in pieces; neither shall ye take fire with you, for ye shall not go by the light of fire.
37177	1405	24	For behold, ye shall be as a whale in the midst of the sea; for the mountain waves shall dash upon you. Nevertheless, I will bring you up again out of the depths of the sea; for the winds have gone forth out of my mouth, and also the rains and the floods have I sent forth.
37178	1405	25	And behold, I prepare you against these things; for ye cannot cross this great deep save I prepare you against the waves of the sea, and the winds which have gone forth, and the floods which shall come. Therefore what will ye that I should prepare for you that ye may have light when ye are swallowed up in the depths of the sea?
37179	1406	1	And it came to pass that the brother of Jared, (now the number of the vessels which had been prepared was eight) went forth unto the mount, which they called the mount Shelem, because of its exceeding height, and did molten out of a rock sixteen small stones; and they were white and clear, even as transparent glass; and he did carry them in his hands upon the top of the mount, and cried again unto the Lord, saying:
37180	1406	2	O Lord, thou hast said that we must be encompassed about by the floods. Now behold, O Lord, and do not be angry with thy servant because of his weakness before thee; for we know that thou art holy and dwellest in the heavens, and that we are unworthy before thee; because of the fall our natures have become evil continually; nevertheless, O Lord, thou hast given us a commandment that we must call upon thee, that from thee we may receive according to our desires.
37181	1406	3	Behold, O Lord, thou hast smitten us because of our iniquity, and hast driven us forth, and for these many years we have been in the wilderness; nevertheless, thou hast been merciful unto us. O Lord, look upon me in pity, and turn away thine anger from this thy people, and suffer not that they shall go forth across this raging deep in darkness; but behold these things which I have molten out of the rock.
37182	1406	4	And I know, O Lord, that thou hast all power, and can do whatsoever thou wilt for the benefit of man; therefore touch these stones, O Lord, with thy finger, and prepare them that they may shine forth in darkness; and they shall shine forth unto us in the vessels which we have prepared, that we may have light while we shall cross the sea.
37183	1406	5	Behold, O Lord, thou canst do this. We know that thou art able to show forth great power, which looks small unto the understanding of men.
37184	1406	6	And it came to pass that when the brother of Jared had said these words, behold, the Lord stretched forth his hand and touched the stones one by one with his finger. And the veil was taken from off the eyes of the brother of Jared, and he saw the finger of the Lord; and it was as the finger of a man, like unto flesh and blood; and the brother of Jared fell down before the Lord, for he was struck with fear.
37185	1406	7	And the Lord saw that the brother of Jared had fallen to the earth; and the Lord said unto him: Arise, why hast thou fallen?
37186	1406	8	And he saith unto the Lord: I saw the finger of the Lord, and I feared lest he should smite me; for I knew not that the Lord had flesh and blood.
37187	1406	9	And the Lord said unto him: Because of thy faith thou hast seen that I shall take upon me flesh and blood; and never has man come before me with such exceeding faith as thou hast; for were it not so ye could not have seen my finger. Sawest thou more than this?
37188	1406	10	And he answered: Nay; Lord, show thyself unto me.
37189	1406	11	And the Lord said unto him: Believest thou the words which I shall speak?
37190	1406	12	And he answered: Yea, Lord, I know that thou speakest the truth, for thou art a God of truth, and canst not lie.
37191	1406	13	And when he had said these words, behold, the Lord showed himself unto him, and said: Because thou knowest these things ye are redeemed from the fall; therefore ye are brought back into my presence; therefore I show myself unto you.
37192	1406	14	Behold, I am he who was prepared from the foundation of the world to redeem my people. Behold, I am Jesus Christ. I am the Father and the Son. In me shall all mankind have life, and that eternally, even they who shall believe on my name; and they shall become my sons and my daughters.
37193	1406	15	And never have I showed myself unto man whom I have created, for never has man believed in me as thou hast. Seest thou that ye are created after mine own image? Yea, even all men were created in the beginning after mine own image.
37194	1406	16	Behold, this body, which ye now behold, is the body of my spirit; and man have I created after the body of my spirit; and even as I appear unto thee to be in the spirit will I appear unto my people in the flesh.
37195	1406	17	And now, as I, Moroni, said I could not make a full account of these things which are written, therefore it sufficeth me to say that Jesus showed himself unto this man in the spirit, even after the manner and in the likeness of the same body even as he showed himself unto the Nephites.
37196	1406	18	And he ministered unto him even as he ministered unto the Nephites; and all this, that this man might know that he was God, because of the many great works which the Lord had showed unto him.
37197	1406	19	And because of the knowledge of this man he could not be kept from beholding within the veil; and he saw the finger of Jesus, which, when he saw, he fell with fear; for he knew that it was the finger of the Lord; and he had faith no longer, for he knew, nothing doubting.
37198	1406	20	Wherefore, having this perfect knowledge of God, he could not be kept from within the veil; therefore he saw Jesus; and he did minister unto him.
37199	1406	21	And it came to pass that the Lord said unto the brother of Jared: Behold, thou shalt not suffer these things which ye have seen and heard to go forth unto the world, until the time cometh that I shall glorify my name in the flesh; wherefore, ye shall treasure up the things which ye have seen and heard, and show it to no man.
37200	1406	22	And behold, when ye shall come unto me, ye shall write them and shall seal them up, that no one can interpret them; for ye shall write them in a language that they cannot be read.
37201	1406	23	And behold, these two stones will I give unto thee, and ye shall seal them up also with the things which ye shall write.
37202	1406	24	For behold, the language which ye shall write I have confounded; wherefore I will cause in my own due time that these stones shall magnify to the eyes of men these things which ye shall write.
37203	1406	25	And when the Lord had said these words, he showed unto the brother of Jared all the inhabitants of the earth which had been, and also all that would be; and he withheld them not from his sight, even unto the ends of the earth.
37204	1406	26	For he had said unto him in times before, that if he would believe in him that he could show unto him all things--it should be shown unto him; therefore the Lord could not withhold anything from him, for he knew that the Lord could show him all things.
37205	1406	27	And the Lord said unto him: Write these things and seal them up; and I will show them in mine own due time unto the children of men.
37206	1406	28	And it came to pass that the Lord commanded him that he should seal up the two stones which he had received, and show them not, until the Lord should show them unto the children of men.
37207	1407	1	And the Lord commanded the brother of Jared to go down out of the mount from the presence of the Lord, and write the things which he had seen; and they were forbidden to come unto the children of men until after that he should be lifted up upon the cross; and for this cause did king Mosiah keep them, that they should not come unto the world until after Christ should show himself unto his people.
37208	1407	2	And after Christ truly had showed himself unto his people he commanded that they should be made manifest.
37209	1407	3	And now, after that, they have all dwindled in unbelief; and there is none save it be the Lamanites, and they have rejected the gospel of Christ; therefore I am commanded that I should hide them up again in the earth.
37210	1407	4	Behold, I have written upon these plates the very things which the brother of Jared saw; and there never were greater things made manifest than those which were made manifest unto the brother of Jared.
37211	1407	5	Wherefore the Lord hath commanded me to write them; and I have written them. And he commanded me that I should seal them up; and he also hath commanded that I should seal up the interpretation thereof; wherefore I have sealed up the interpreters, according to the commandment of the Lord.
37212	1407	6	For the Lord said unto me: They shall not go forth unto the Gentiles until the day that they shall repent of their iniquity, and become clean before the Lord.
37213	1407	7	And in that day that they shall exercise faith in me, saith the Lord, even as the brother of Jared did, that they may become sanctified in me, then will I manifest unto them the things which the brother of Jared saw, even to the unfolding unto them all my revelations, saith Jesus Christ, the Son of God, the Father of the heavens and of the earth, and all things that in them are.
37214	1407	8	And he that will contend against the word of the Lord, let him be accursed; and he that shall deny these things, let him be accursed; for unto them will I show no greater things, saith Jesus Christ; for I am he who speaketh.
37215	1407	9	And at my command the heavens are opened and are shut; and at my word the earth shall shake; and at my command the inhabitants thereof shall pass away, even so as by fire.
37216	1407	10	And he that believeth not my words believeth not my disciples; and if it so be that I do not speak, judge ye; for ye shall know that it is I that speaketh, at the last day.
37217	1407	11	But he that believeth these things which I have spoken, him will I visit with the manifestations of my Spirit, and he shall know and bear record. For because of my Spirit he shall know that these things are true; for it persuadeth men to do good.
37218	1407	12	And whatsoever thing persuadeth men to do good is of me; for good cometh of none save it be of me. I am the same that leadeth men to all good; he that will not believe my words will not believe me--that I am; and he that will not believe me will not believe the Father who sent me. For behold, I am the Father, I am the light, and the life, and the truth of the world.
37219	1407	13	Come unto me, O ye Gentiles, and I will show unto you the greater things, the knowledge which is hid up because of unbelief.
37220	1407	14	Come unto me, O ye house of Israel, and it shall be made manifest unto you how great things the Father hath laid up for you, from the foundation of the world; and it hath not come unto you, because of unbelief.
37221	1407	15	Behold, when ye shall rend that veil of unbelief which doth cause you to remain in your awful state of wickedness, and hardness of heart, and blindness of mind, then shall the great and marvelous things which have been hid up from the foundation of the world from you--yea, when ye shall call upon the Father in my name, with a broken heart and a contrite spirit, then shall ye know that the Father hath remembered the covenant which he made unto your fathers, O house of Israel.
37222	1407	16	And then shall my revelations which I have caused to be written by my servant John be unfolded in the eyes of all the people. Remember, when ye see these things, ye shall know that the time is at hand that they shall be made manifest in very deed.
37223	1407	17	Therefore, when ye shall receive this record ye may know that the work of the Father has commenced upon all the face of the land.
37224	1407	18	Therefore, repent all ye ends of the earth, and come unto me, and believe in my gospel, and be baptized in my name; for he that believeth and is baptized shall be saved; but he that believeth not shall be damned; and signs shall follow them that believe in my name.
37225	1407	19	And blessed is he that is found faithful unto my name at the last day, for he shall be lifted up to dwell in the kingdom prepared for him from the foundation of the world. And behold it is I that hath spoken it. Amen.
37226	1408	1	And now I, Moroni, have written the words which were commanded me, according to my memory; and I have told you the things which I have sealed up; therefore touch them not in order that ye may translate; for that thing is forbidden you, except by and by it shall be wisdom in God.
37227	1408	2	And behold, ye may be privileged that ye may show the plates unto those who shall assist to bring forth this work;
37228	1408	3	And unto three shall they be shown by the power of God; wherefore they shall know of a surety that these things are true.
37229	1408	4	And in the mouth of three witnesses shall these things be established; and the testimony of three, and this work, in the which shall be shown forth the power of God and also his word, of which the Father, and the Son, and the Holy Ghost bear record--and all this shall stand as a testimony against the world at the last day.
37230	1408	5	And if it so be that they repent and come unto the Father in the name of Jesus, they shall be received into the kingdom of God.
37231	1408	6	And now, if I have no authority for these things, judge ye; for ye shall know that I have authority when ye shall see me, and we shall stand before God at the last day. Amen.
37232	1409	1	And now I, Moroni, proceed to give the record of Jared and his brother.
37233	1409	2	For it came to pass after the Lord had prepared the stones which the brother of Jared had carried up into the mount, the brother of Jared came down out of the mount, and he did put forth the stones into the vessels which were prepared, one in each end thereof; and behold, they did give light unto the vessels.
37234	1409	3	And thus the Lord caused stones to shine in darkness, to give light unto men, women, and children, that they might not cross the great waters in darkness.
37235	1409	4	And it came to pass that when they had prepared all manner of food, that thereby they might subsist upon the water, and also food for their flocks and herds, and whatsoever beast or animal or fowl that they should carry with them--and it came to pass that when they had done all these things they got aboard of their vessels or barges, and set forth into the sea, commending themselves unto the Lord their God.
37236	1409	5	And it came to pass that the Lord God caused that there should be a furious wind blow upon the face of the waters, towards the promised land; and thus they were tossed upon the waves of the sea before the wind.
37237	1409	6	And it came to pass that they were many times buried in the depths of the sea, because of the mountain waves which broke upon them, and also the great and terrible tempests which were caused by the fierceness of the wind.
37238	1409	7	And it came to pass that when they were buried in the deep there was no water that could hurt them, their vessels being tight like unto a dish, and also they were tight like unto the ark of Noah; therefore when they were encompassed about by many waters they did cry unto the Lord, and he did bring them forth again upon the top of the waters.
37239	1409	8	And it came to pass that the wind did never cease to blow towards the promised land while they were upon the waters; and thus they were driven forth before the wind.
37240	1409	9	And they did sing praises unto the Lord; yea, the brother of Jared did sing praises unto the Lord, and he did thank and praise the Lord all the day long; and when the night came, they did not cease to praise the Lord.
37241	1409	10	And thus they were driven forth; and no monster of the sea could break them, neither whale that could mar them; and they did have light continually, whether it was above the water or under the water.
37242	1409	11	And thus they were driven forth, three hundred and forty and four days upon the water.
37243	1409	12	And they did land upon the shore of the promised land. And when they had set their feet upon the shores of the promised land they bowed themselves down upon the face of the land, and did humble themselves before the Lord, and did shed tears of joy before the Lord, because of the multitude of his tender mercies over them.
37244	1409	13	And it came to pass that they went forth upon the face of the land, and began to till the earth.
37245	1409	14	And Jared had four sons; and they were called Jacom, and Gilgah, and Mahah, and Orihah.
37246	1409	15	And the brother of Jared also begat sons and daughters.
37247	1409	16	And the friends of Jared and his brother were in number about twenty and two souls; and they also begat sons and daughters before they came to the promised land; and therefore they began to be many.
37248	1409	17	And they were taught to walk humbly before the Lord; and they were also taught from on high.
37249	1409	18	And it came to pass that they began to spread upon the face of the land, and to multiply and to till the earth; and they did wax strong in the land.
37250	1409	19	And the brother of Jared began to be old, and saw that he must soon go down to the grave; wherefore he said unto Jared: Let us gather together our people that we may number them, that we may know of them what they will desire of us before we go down to our graves.
37251	1409	20	And accordingly the people were gathered together. Now the number of the sons and the daughters of the brother of Jared were twenty and two souls; and the number of sons and daughters of Jared were twelve, he having four sons.
37252	1409	21	And it came to pass that they did number their people; and after that they had numbered them, they did desire of them the things which they would that they should do before they went down to their graves.
37253	1409	22	And it came to pass that the people desired of them that they should anoint one of their sons to be a king over them.
37254	1409	23	And now behold, this was grievous unto them. And the brother of Jared said unto them: Surely this thing leadeth into captivity.
37255	1409	24	But Jared said unto his brother: Suffer them that they may have a king. And therefore he said unto them: Choose ye out from among our sons a king, even whom ye will.
37256	1409	25	And it came to pass that they chose even the firstborn of the brother of Jared; and his name was Pagag. And it came to pass that he refused and would not be their king. And the people would that his father should constrain him, but his father would not; and he commanded them that they should constrain no man to be their king.
37257	1409	26	And it came to pass that they chose all the brothers of Pagag, and they would not.
37258	1409	27	And it came to pass that neither would the sons of Jared, even all save it were one; and Orihah was anointed to be king over the people.
37259	1409	28	And he began to reign, and the people began to prosper; and they became exceedingly rich.
37260	1409	29	And it came to pass that Jared died, and his brother also.
37261	1409	30	And it came to pass that Orihah did walk humbly before the Lord, and did remember how great things the Lord had done for his father, and also taught his people how great things the Lord had done for their fathers.
37262	1410	1	And it came to pass that Orihah did execute judgment upon the land in righteousness all his days, whose days were exceedingly many.
37263	1410	2	And he begat sons and daughters; yea, he begat thirty and one, among whom were twenty and three sons.
37264	1410	3	And it came to pass that he also begat Kib in his old age. And it came to pass that Kib reigned in his stead; and Kib begat Corihor.
37265	1410	4	And when Corihor was thirty and two years old he rebelled against his father, and went over and dwelt in the land of Nehor; and he begat sons and daughters, and they became exceedingly fair; wherefore Corihor drew away many people after him.
37266	1410	5	And when he had gathered together an army he came up unto the land of Moron where the king dwelt, and took him captive, which brought to pass the saying of the brother of Jared that they would be brought into captivity.
37267	1410	6	Now the land of Moron, where the king dwelt, was near the land which is called Desolation by the Nephites.
37268	1410	7	And it came to pass that Kib dwelt in captivity, and his people under Corihor his son, until he became exceedingly old; nevertheless Kib begat Shule in his old age, while he was yet in captivity.
37269	1410	8	And it came to pass that Shule was angry with his brother; and Shule waxed strong, and became mighty as to the strength of a man; and he was also mighty in judgment.
37270	1410	9	Wherefore, he came to the hill Ephraim, and he did molten out of the hill, and made swords out of steel for those whom he had drawn away with him; and after he had armed them with swords he returned to the city Nehor and gave battle unto his brother Corihor, by which means he obtained the kingdom and restored it unto his father Kib.
37271	1410	10	And now because of the thing which Shule had done, his father bestowed upon him the kingdom; therefore he began to reign in the stead of his father.
37272	1410	11	And it came to pass that he did execute judgment in righteousness; and he did spread his kingdom upon all the face of the land, for the people had become exceedingly numerous.
37273	1410	12	And it came to pass that Shule also begat many sons and daughters.
37274	1410	13	And Corihor repented of the many evils which he had done; wherefore Shule gave him power in his kingdom.
37275	1410	14	And it came to pass that Corihor had many sons and daughters. And among the sons of Corihor there was one whose name was Noah.
37276	1410	15	And it came to pass that Noah rebelled against Shule, the king, and also his father Corihor, and drew away Cohor his brother, and also all his brethren and many of the people.
37277	1410	16	And he gave battle unto Shule, the king, in which he did obtain the land of their first inheritance; and he became a king over that part of the land.
37278	1410	17	And it came to pass that he gave battle again unto Shule, the king; and he took Shule, the king, and carried him away captive into Moron.
37279	1410	18	And it came to pass as he was about to put him to death, the sons of Shule crept into the house of Noah by night and slew him, and broke down the door of the prison and brought out their father, and placed him upon his throne in his own kingdom.
37280	1410	19	Wherefore, the son of Noah did build up his kingdom in his stead; nevertheless they did not gain power any more over Shule the king, and the people who were under the reign of Shule the king did prosper exceedingly and wax great.
37281	1410	20	And the country was divided; and there were two kingdoms, the kingdom of Shule, and the kingdom of Cohor, the son of Noah.
37282	1410	21	And Cohor, the son of Noah, caused that his people should give battle unto Shule, in which Shule did beat them and did slay Cohor.
37283	1410	22	And now Cohor had a son who was called Nimrod; and Nimrod gave up the kingdom of Cohor unto Shule, and he did gain favor in the eyes of Shule; wherefore Shule did bestow great favors upon him, and he did do in the kingdom of Shule according to his desires.
37284	1410	23	And also in the reign of Shule there came prophets among the people, who were sent from the Lord, prophesying that the wickedness and idolatry of the people was bringing a curse upon the land, and they should be destroyed if they did not repent.
37285	1410	24	And it came to pass that the people did revile against the prophets, and did mock them. And it came to pass that king Shule did execute judgment against all those who did revile against the prophets.
37286	1410	25	And he did execute a law throughout all the land, which gave power unto the prophets that they should go whithersoever they would; and by this cause the people were brought unto repentance.
37287	1410	26	And because the people did repent of their iniquities and idolatries the Lord did spare them, and they began to prosper again in the land. And it came to pass that Shule begat sons and daughters in his old age.
37288	1410	27	And there were no more wars in the days of Shule; and he remembered the great things that the Lord had done for his fathers in bringing them across the great deep into the promised land; wherefore he did execute judgment in righteousness all his days.
37289	1411	1	And it came to pass that he begat Omer, and Omer reigned in his stead. And Omer begat Jared; and Jared begat sons and daughters.
37290	1411	2	And Jared rebelled against his father, and came and dwelt in the land of Heth. And it came to pass that he did flatter many people, because of his cunning words, until he had gained the half of the kingdom.
37291	1411	3	And when he had gained the half of the kingdom he gave battle unto his father, and he did carry away his father into captivity, and did make him serve in captivity;
37292	1411	4	And now, in the days of the reign of Omer he was in captivity the half of his days. And it came to pass that he begat sons and daughters, among whom were Esrom and Coriantumr;
37293	1411	5	And they were exceedingly angry because of the doings of Jared their brother, insomuch that they did raise an army and gave battle unto Jared. And it came to pass that they did give battle unto him by night.
37294	1411	6	And it came to pass that when they had slain the army of Jared they were about to slay him also; and he plead with them that they would not slay him, and he would give up the kingdom unto his father. And it came to pass that they did grant unto him his life.
37295	1411	7	And now Jared became exceedingly sorrowful because of the loss of the kingdom, for he had set his heart upon the kingdom and upon the glory of the world.
37296	1411	8	Now the daughter of Jared being exceedingly expert, and seeing the sorrows of her father, thought to devise a plan whereby she could redeem the kingdom unto her father.
37297	1411	9	Now the daughter of Jared was exceedingly fair. And it came to pass that she did talk with her father, and said unto him: Whereby hath my father so much sorrow? Hath he not read the record which our fathers brought across the great deep? Behold, is there not an account concerning them of old, that they by their secret plans did obtain kingdoms and great glory?
37298	1411	10	And now, therefore, let my father send for Akish, the son of Kimnor; and behold, I am fair, and I will dance before him, and I will please him, that he will desire me to wife; wherefore if he shall desire of thee that ye shall give unto him me to wife, then shall ye say: I will give her if ye will bring unto me the head of my father, the king.
37299	1411	11	And now Omer was a friend to Akish; wherefore, when Jared had sent for Akish, the daughter of Jared danced before him that she pleased him, insomuch that he desired her to wife. And it came to pass that he said unto Jared: Give her unto me to wife.
37300	1411	12	And Jared said unto him: I will give her unto you, if ye will bring unto me the head of my father, the king.
37301	1411	13	And it came to pass that Akish gathered in unto the house of Jared all his kinsfolk, and said unto them: Will ye swear unto me that ye will be faithful unto me in the thing which I shall desire of you?
37302	1411	14	And it came to pass that they all sware unto him, by the God of heaven, and also by the heavens, and also by the earth, and by their heads, that whoso should vary from the assistance which Akish desired should lose his head; and whoso should divulge whatsoever thing Akish made known unto them, the same should lose his life.
37303	1411	15	And it came to pass that thus they did agree with Akish. And Akish did administer unto them the oaths which were given by them of old who also sought power, which had been handed down even from Cain, who was a murderer from the beginning.
37304	1411	16	And they were kept up by the power of the devil to administer these oaths unto the people, to keep them in darkness, to help such as sought power to gain power, and to murder, and to plunder, and to lie, and to commit all manner of wickedness and whoredoms.
37305	1411	17	And it was the daughter of Jared who put it into his heart to search up these things of old; and Jared put it into the heart of Akish; wherefore, Akish administered it unto his kindred and friends, leading them away by fair promises to do whatsoever thing he desired.
37306	1411	18	And it came to pass that they formed a secret combination, even as they of old; which combination is most abominable and wicked above all, in the sight of God;
37307	1411	19	For the Lord worketh not in secret combinations, neither doth he will that man should shed blood, but in all things hath forbidden it, from the beginning of man.
37308	1411	20	And now I, Moroni, do not write the manner of their oaths and combinations, for it hath been made known unto me that they are had among all people, and they are had among the Lamanites.
37309	1411	21	And they have caused the destruction of this people of whom I am now speaking, and also the destruction of the people of Nephi.
37310	1411	22	And whatsoever nation shall uphold such secret combinations, to get power and gain, until they shall spread over the nation, behold, they shall be destroyed; for the Lord will not suffer that the blood of his saints, which shall be shed by them, shall always cry unto him from the ground for vengeance upon them and yet he avenge them not.
37311	1411	23	Wherefore, O ye Gentiles, it is wisdom in God that these things should be shown unto you, that thereby ye may repent of your sins, and suffer not that these murderous combinations shall get above you, which are built up to get power and gain--and the work, yea, even the work of destruction come upon you, yea, even the sword of the justice of the Eternal God shall fall upon you, to your overthrow and destruction if ye shall suffer these things to be.
37312	1411	24	Wherefore, the Lord commandeth you, when ye shall see these things come among you that ye shall awake to a sense of your awful situation, because of this secret combination which shall be among you; or wo be unto it, because of the blood of them who have been slain; for they cry from the dust for vengeance upon it, and also upon those who built it up.
37313	1411	25	For it cometh to pass that whoso buildeth it up seeketh to overthrow the freedom of all lands, nations, and countries; and it bringeth to pass the destruction of all people, for it is built up by the devil, who is the father of all lies; even that same liar who beguiled our first parents, yea, even that same liar who hath caused man to commit murder from the beginning; who hath hardened the hearts of men that they have murdered the prophets, and stoned them, and cast them out from the beginning.
37314	1411	26	Wherefore, I, Moroni, am commanded to write these things that evil may be done away, and that the time may come that Satan may have no power upon the hearts of the children of men, but that they may be persuaded to do good continually, that they may come unto the fountain of all righteousness and be saved.
37315	1412	1	And now I, Moroni, proceed with my record. Therefore, behold, it came to pass that because of the secret combinations of Akish and his friends, behold, they did overthrow the kingdom of Omer.
37316	1412	2	Nevertheless, the Lord was merciful unto Omer, and also to his sons and to his daughters who did not seek his destruction.
37317	1412	3	And the Lord warned Omer in a dream that he should depart out of the land; wherefore Omer departed out of the land with his family, and traveled many days, and came over and passed by the hill of Shim, and came over by the place where the Nephites were destroyed, and from thence eastward, and came to a place which was called Ablom, by the seashore, and there he pitched his tent, and also his sons and his daughters, and all his household, save it were Jared and his family.
37318	1412	4	And it came to pass that Jared was anointed king over the people, by the hand of wickedness; and he gave unto Akish his daughter to wife.
37319	1412	5	And it came to pass that Akish sought the life of his father-in-law; and he applied unto those whom he had sworn by the oath of the ancients, and they obtained the head of his father-in-law, as he sat upon his throne, giving audience to his people.
37320	1412	6	For so great had been the spreading of this wicked and secret society that it had corrupted the hearts of all the people; therefore Jared was murdered upon his throne, and Akish reigned in his stead.
37321	1412	7	And it came to pass that Akish began to be jealous of his son, therefore he shut him up in prison, and kept him upon little or no food until he had suffered death.
37322	1412	8	And now the brother of him that suffered death, (and his name was Nimrah) was angry with his father because of that which his father had done unto his brother.
37323	1412	9	And it came to pass that Nimrah gathered together a small number of men, and fled out of the land, and came over and dwelt with Omer.
37324	1412	10	And it came to pass that Akish begat other sons, and they won the hearts of the people, notwithstanding they had sworn unto him to do all manner of iniquity according to that which he desired.
37325	1412	11	Now the people of Akish were desirous for gain, even as Akish was desirous for power; wherefore, the sons of Akish did offer them money, by which means they drew away the more part of the people after them.
37326	1412	12	And there began to be a war between the sons of Akish and Akish, which lasted for the space of many years, yea, unto the destruction of nearly all the people of the kingdom, yea, even all, save it were thirty souls, and they who fled with the house of Omer.
37327	1412	13	Wherefore, Omer was restored again to the land of his inheritance.
37328	1412	14	And it came to pass that Omer began to be old; nevertheless, in his old age he begat Emer; and he anointed Emer to be king to reign in his stead.
37329	1412	15	And after that he had anointed Emer to be king he saw peace in the land for the space of two years, and he died, having seen exceedingly many days, which were full of sorrow. And it came to pass that Emer did reign in his stead, and did fill the steps of his father.
37330	1412	16	And the Lord began again to take the curse from off the land, and the house of Emer did prosper exceedingly under the reign of Emer; and in the space of sixty and two years they had become exceedingly strong, insomuch that they became exceedingly rich--
37331	1412	17	Having all manner of fruit, and of grain, and of silks, and of fine linen, and of gold, and of silver, and of precious things;
37332	1412	18	And also all manner of cattle, of oxen, and cows, and of sheep, and of swine, and of goats, and also many other kinds of animals which were useful for the food of man.
37333	1412	19	And they also had horses, and asses, and there were elephants and cureloms and cumoms; all of which were useful unto man, and more especially the elephants and cureloms and cumoms.
37334	1412	20	And thus the Lord did pour out his blessings upon this land, which was choice above all other lands; and he commanded that whoso should possess the land should possess it unto the Lord, or they should be destroyed when they were ripened in iniquity; for upon such, saith the Lord: I will pour out the fulness of my wrath.
37335	1412	21	And Emer did execute judgment in righteousness all his days, and he begat many sons and daughters; and he begat Coriantum, and he anointed Coriantum to reign in his stead.
37336	1412	22	And after he had anointed Coriantum to reign in his stead he lived four years, and he saw peace in the land; yea, and he even saw the Son of Righteousness, and did rejoice and glory in his day; and he died in peace.
37337	1412	23	And it came to pass that Coriantum did walk in the steps of his father, and did build many mighty cities, and did administer that which was good unto his people in all his days. And it came to pass that he had no children even until he was exceedingly old.
37338	1412	24	And it came to pass that his wife died, being an hundred and two years old. And it came to pass that Coriantum took to wife, in his old age, a young maid, and begat sons and daughters; wherefore he lived until he was an hundred and forty and two years old.
37339	1412	25	And it came to pass that he begat Com, and Com reigned in his stead; and he reigned forty and nine years, and he begat Heth; and he also begat other sons and daughters.
37340	1412	26	And the people had spread again over all the face of the land, and there began again to be an exceedingly great wickedness upon the face of the land, and Heth began to embrace the secret plans again of old, to destroy his father.
37341	1412	27	And it came to pass that he did dethrone his father, for he slew him with his own sword; and he did reign in his stead.
37342	1412	28	And there came prophets in the land again, crying repentance unto them--that they must prepare the way of the Lord or there should come a curse upon the face of the land; yea, even there should be a great famine, in which they should be destroyed if they did not repent.
37343	1412	29	But the people believed not the words of the prophets, but they cast them out; and some of them they cast into pits and left them to perish. And it came to pass that they did all these things according to the commandment of the king, Heth.
37344	1412	30	And it came to pass that there began to be a great dearth upon the land, and the inhabitants began to be destroyed exceedingly fast because of the dearth, for there was no rain upon the face of the earth.
37345	1412	31	And there came forth poisonous serpents also upon the face of the land, and did poison many people. And it came to pass that their flocks began to flee before the poisonous serpents, towards the land southward, which was called by the Nephites Zarahemla.
37346	1412	32	And it came to pass that there were many of them which did perish by the way; nevertheless, there were some which fled into the land southward.
37347	1412	33	And it came to pass that the Lord did cause the serpents that they should pursue them no more, but that they should hedge up the way that the people could not pass, that whoso should attempt to pass might fall by the poisonous serpents.
37348	1412	34	And it came to pass that the people did follow the course of the beasts, and did devour the carcasses of them which fell by the way, until they had devoured them all. Now when the people saw that they must perish they began to repent of their iniquities and cry unto the Lord.
37349	1412	35	And it came to pass that when they had humbled themselves sufficiently before the Lord he did send rain upon the face of the earth; and the people began to revive again, and there began to be fruit in the north countries, and in all the countries round about. And the Lord did show forth his power unto them in preserving them from famine.
37350	1413	1	And it came to pass that Shez, who was a descendant of Heth--for Heth had perished by the famine, and all his household save it were Shez--wherefore, Shez began to build up again a broken people.
37351	1413	2	And it came to pass that Shez did remember the destruction of his fathers, and he did build up a righteous kingdom; for he remembered what the Lord had done in bringing Jared and his brother across the deep; and he did walk in the ways of the Lord; and he begat sons and daughters.
37352	1413	3	And his eldest son, whose name was Shez, did rebel against him; nevertheless, Shez was smitten by the hand of a robber, because of his exceeding riches, which brought peace again unto his father.
37353	1413	4	And it came to pass that his father did build up many cities upon the face of the land, and the people began again to spread over all the face of the land. And Shez did live to an exceedingly old age; and he begat Riplakish. And he died, and Riplakish reigned in his stead.
37354	1413	5	And it came to pass that Riplakish did not do that which was right in the sight of the Lord, for he did have many wives and concubines, and did lay that upon men's shoulders which was grievous to be borne; yea, he did tax them with heavy taxes; and with the taxes he did build many spacious buildings.
37355	1413	6	And he did erect him an exceedingly beautiful throne; and he did build many prisons, and whoso would not be subject unto taxes he did cast into prison; and whoso was not able to pay taxes he did cast into prison; and he did cause that they should labor continually for their support; and whoso refused to labor he did cause to be put to death.
37356	1413	7	Wherefore he did obtain all his fine work, yea, even his fine gold he did cause to be refined in prison; and all manner of fine workmanship he did cause to be wrought in prison. And it came to pass that he did afflict the people with his whoredoms and abominations.
37357	1413	8	And when he had reigned for the space of forty and two years the people did rise up in rebellion against him; and there began to be war again in the land, insomuch that Riplakish was killed, and his descendants were driven out of the land.
37358	1413	9	And it came to pass after the space of many years, Morianton, (he being a descendant of Riplakish) gathered together an army of outcasts, and went forth and gave battle unto the people; and he gained power over many cities; and the war became exceedingly sore, and did last for the space of many years; and he did gain power over all the land, and did establish himself king over all the land.
37359	1413	10	And after that he had established himself king he did ease the burden of the people, by which he did gain favor in the eyes of the people, and they did anoint him to be their king.
37360	1413	11	And he did do justice unto the people, but not unto himself because of his many whoredoms; wherefore he was cut off from the presence of the Lord.
37361	1413	12	And it came to pass that Morianton built up many cities, and the people became exceedingly rich under his reign, both in buildings, and in gold and silver, and in raising grain, and in flocks, and herds, and such things which had been restored unto them.
37362	1413	13	And Morianton did live to an exceedingly great age, and then he begat Kim; and Kim did reign in the stead of his father; and he did reign eight years, and his father died. And it came to pass that Kim did not reign in righteousness, wherefore he was not favored of the Lord.
37363	1413	14	And his brother did rise up in rebellion against him, by which he did bring him into captivity; and he did remain in captivity all his days; and he begat sons and daughters in captivity, and in his old age he begat Levi; and he died.
37364	1413	15	And it came to pass that Levi did serve in captivity after the death of his father, for the space of forty and two years. And he did make war against the king of the land, by which he did obtain unto himself the kingdom.
37365	1413	16	And after he had obtained unto himself the kingdom he did that which was right in the sight of the Lord; and the people did prosper in the land; and he did live to a good old age, and begat sons and daughters; and he also begat Corom, whom he anointed king in his stead.
37366	1413	17	And it came to pass that Corom did that which was good in the sight of the Lord all his days; and he begat many sons and daughters; and after he had seen many days he did pass away, even like unto the rest of the earth; and Kish reigned in his stead.
37367	1413	18	And it came to pass that Kish passed away also, and Lib reigned in his stead.
37368	1413	19	And it came to pass that Lib also did that which was good in the sight of the Lord. And in the days of Lib the poisonous serpents were destroyed. Wherefore they did go into the land southward, to hunt food for the people of the land, for the land was covered with animals of the forest. And Lib also himself became a great hunter.
37369	1413	20	And they built a great city by the narrow neck of land, by the place where the sea divides the land.
37370	1413	21	And they did preserve the land southward for a wilderness, to get game. And the whole face of the land northward was covered with inhabitants.
37371	1413	22	And they were exceedingly industrious, and they did buy and sell and traffic one with another, that they might get gain.
37372	1413	23	And they did work in all manner of ore, and they did make gold, and silver, and iron, and brass, and all manner of metals; and they did dig it out of the earth; wherefore, they did cast up mighty heaps of earth to get ore, of gold, and of silver, and of iron, and of copper. And they did work all manner of fine work.
37373	1413	24	And they did have silks, and fine-twined linen; and they did work all manner of cloth, that they might clothe themselves from their nakedness.
37374	1413	25	And they did make all manner of tools to till the earth, both to plow and to sow, to reap and to hoe, and also to thrash.
37375	1413	26	And they did make all manner of tools with which they did work their beasts.
37376	1413	27	And they did make all manner of weapons of war. And they did work all manner of work of exceedingly curious workmanship.
37377	1413	28	And never could be a people more blessed than were they, and more prospered by the hand of the Lord. And they were in a land that was choice above all lands, for the Lord had spoken it.
37378	1413	29	And it came to pass that Lib did live many years, and begat sons and daughters; and he also begat Hearthom.
37379	1413	30	And it came to pass that Hearthom reigned in the stead of his father. And when Hearthom had reigned twenty and four years, behold, the kingdom was taken away from him. And he served many years in captivity, yea, even all the remainder of his days.
37380	1413	31	And he begat Heth, and Heth lived in captivity all his days. And Heth begat Aaron, and Aaron dwelt in captivity all his days; and he begat Amnigaddah, and Amnigaddah also dwelt in captivity all his days; and he begat Coriantum, and Coriantum dwelt in captivity all his days; and he begat Com.
37381	1413	32	And it came to pass that Com drew away the half of the kingdom. And he reigned over the half of the kingdom forty and two years; and he went to battle against the king, Amgid, and they fought for the space of many years, during which time Com gained power over Amgid, and obtained power over the remainder of the kingdom.
37382	1413	33	And in the days of Com there began to be robbers in the land; and they adopted the old plans, and administered oaths after the manner of the ancients, and sought again to destroy the kingdom.
37383	1413	34	Now Com did fight against them much; nevertheless, he did not prevail against them.
37384	1414	1	And there came also in the days of Com many prophets, and prophesied of the destruction of that great people except they should repent, and turn unto the Lord, and forsake their murders and wickedness.
37385	1414	2	And it came to pass that the prophets were rejected by the people, and they fled unto Com for protection, for the people sought to destroy them.
37386	1414	3	And they prophesied unto Com many things; and he was blessed in all the remainder of his days.
37387	1414	4	And he lived to a good old age, and begat Shiblom; and Shiblom reigned in his stead. And the brother of Shiblom rebelled against him, and there began to be an exceedingly great war in all the land.
37388	1414	5	And it came to pass that the brother of Shiblom caused that all the prophets who prophesied of the destruction of the people should be put to death;
37389	1414	6	And there was great calamity in all the land, for they had testified that a great curse should come upon the land, and also upon the people, and that there should be a great destruction among them, such an one as never had been upon the face of the earth, and their bones should become as heaps of earth upon the face of the land except they should repent of their wickedness.
37390	1414	7	And they hearkened not unto the voice of the Lord, because of their wicked combinations; wherefore, there began to be wars and contentions in all the land, and also many famines and pestilences, insomuch that there was a great destruction, such an one as never had been known upon the face of the earth; and all this came to pass in the days of Shiblom.
37391	1414	8	And the people began to repent of their iniquity; and inasmuch as they did the Lord did have mercy on them.
37392	1414	9	And it came to pass that Shiblom was slain, and Seth was brought into captivity, and did dwell in captivity all his days.
37393	1414	10	And it came to pass that Ahah, his son, did obtain the kingdom; and he did reign over the people all his days. And he did do all manner of iniquity in his days, by which he did cause the shedding of much blood; and few were his days.
37394	1414	11	And Ethem, being a descendant of Ahah, did obtain the kingdom; and he also did do that which was wicked in his days.
37395	1414	12	And it came to pass that in the days of Ethem there came many prophets, and prophesied again unto the people; yea, they did prophesy that the Lord would utterly destroy them from off the face of the earth except they repented of their iniquities.
37396	1414	13	And it came to pass that the people hardened their hearts, and would not hearken unto their words; and the prophets mourned and withdrew from among the people.
37397	1414	14	And it came to pass that Ethem did execute judgment in wickedness all his days; and he begat Moron. And it came to pass that Moron did reign in his stead; and Moron did that which was wicked before the Lord.
37398	1414	15	And it came to pass that there arose a rebellion among the people, because of that secret combination which was built up to get power and gain; and there arose a mighty man among them in iniquity, and gave battle unto Moron, in which he did overthrow the half of the kingdom; and he did maintain the half of the kingdom for many years.
37399	1414	16	And it came to pass that Moron did overthrow him, and did obtain the kingdom again.
37400	1414	17	And it came to pass that there arose another mighty man; and he was a descendant of the brother of Jared.
37401	1414	18	And it came to pass that he did overthrow Moron and obtain the kingdom; wherefore, Moron dwelt in captivity all the remainder of his days; and he begat Coriantor.
37402	1414	19	And it came to pass that Coriantor dwelt in captivity all his days.
37403	1414	20	And in the days of Coriantor there also came many prophets, and prophesied of great and marvelous things, and cried repentance unto the people, and except they should repent the Lord God would execute judgment against them to their utter destruction;
37404	1414	21	And that the Lord God would send or bring forth another people to possess the land, by his power, after the manner by which he brought their fathers.
37405	1414	22	And they did reject all the words of the prophets, because of their secret society and wicked abominations.
37406	1414	23	And it came to pass that Coriantor begat Ether, and he died, having dwelt in captivity all his days.
37407	1415	1	And it came to pass that the days of Ether were in the days of Coriantumr; and Coriantumr was king over all the land.
37408	1415	2	And Ether was a prophet of the Lord; wherefore Ether came forth in the days of Coriantumr, and began to prophesy unto the people, for he could not be restrained because of the Spirit of the Lord which was in him.
37409	1415	3	For he did cry from the morning, even until the going down of the sun, exhorting the people to believe in God unto repentance lest they should be destroyed, saying unto them that by faith all things are fulfilled--
37410	1415	4	Wherefore, whoso believeth in God might with surety hope for a better world, yea, even a place at the right hand of God, which hope cometh of faith, maketh an anchor to the souls of men, which would make them sure and steadfast, always abounding in good works, being led to glorify God.
37411	1415	5	And it came to pass that Ether did prophesy great and marvelous things unto the people, which they did not believe, because they saw them not.
37412	1415	6	And now, I, Moroni, would speak somewhat concerning these things; I would show unto the world that faith is things which are hoped for and not seen; wherefore, dispute not because ye see not, for ye receive no witness until after the trial of your faith.
37413	1415	7	For it was by faith that Christ showed himself unto our fathers, after he had risen from the dead; and he showed not himself unto them until after they had faith in him; wherefore, it must needs be that some had faith in him, for he showed himself not unto the world.
37414	1415	8	But because of the faith of men he has shown himself unto the world, and glorified the name of the Father, and prepared a way that thereby others might be partakers of the heavenly gift, that they might hope for those things which they have not seen.
37415	1415	9	Wherefore, ye may also have hope, and be partakers of the gift, if ye will but have faith.
37416	1415	10	Behold it was by faith that they of old were called after the holy order of God.
37417	1415	11	Wherefore, by faith was the law of Moses given. But in the gift of his Son hath God prepared a more excellent way; and it is by faith that it hath been fulfilled.
37418	1415	12	For if there be no faith among the children of men God can do no miracle among them; wherefore, he showed not himself until after their faith.
37419	1415	13	Behold, it was the faith of Alma and Amulek that caused the prison to tumble to the earth.
37420	1415	14	Behold, it was the faith of Nephi and Lehi that wrought the change upon the Lamanites, that they were baptized with fire and with the Holy Ghost.
37421	1415	15	Behold, it was the faith of Ammon and his brethren which wrought so great a miracle among the Lamanites.
37422	1415	16	Yea, and even all they who wrought miracles wrought them by faith, even those who were before Christ and also those who were after.
37423	1415	17	And it was by faith that the three disciples obtained a promise that they should not taste of death; and they obtained not the promise until after their faith.
37424	1415	18	And neither at any time hath any wrought miracles until after their faith; wherefore they first believed in the Son of God.
37425	1415	19	And there were many whose faith was so exceedingly strong, even before Christ came, who could not be kept from within the veil, but truly saw with their eyes the things which they had beheld with an eye of faith, and they were glad.
37426	1415	20	And behold, we have seen in this record that one of these was the brother of Jared; for so great was his faith in God, that when God put forth his finger he could not hide it from the sight of the brother of Jared, because of his word which he had spoken unto him, which word he had obtained by faith.
37427	1415	21	And after the brother of Jared had beheld the finger of the Lord, because of the promise which the brother of Jared had obtained by faith, the Lord could not withhold anything from his sight; wherefore he showed him all things, for he could no longer be kept without the veil.
37428	1415	22	And it is by faith that my fathers have obtained the promise that these things should come unto their brethren through the Gentiles; therefore the Lord hath commanded me, yea, even Jesus Christ.
37429	1415	23	And I said unto him: Lord, the Gentiles will mock at these things, because of our weakness in writing; for Lord thou hast made us mighty in word by faith, but thou hast not made us mighty in writing; for thou hast made all this people that they could speak much, because of the Holy Ghost which thou hast given them;
37430	1415	24	And thou hast made us that we could write but little, because of the awkwardness of our hands. Behold, thou hast not made us mighty in writing like unto the brother of Jared, for thou madest him that the things which he wrote were mighty even as thou art, unto the overpowering of man to read them.
37431	1415	25	Thou hast also made our words powerful and great, even that we cannot write them; wherefore, when we write we behold our weakness, and stumble because of the placing of our words; and I fear lest the Gentiles shall mock at our words.
37432	1415	26	And when I had said this, the Lord spake unto me, saying: Fools mock, but they shall mourn; and my grace is sufficient for the meek, that they shall take no advantage of your weakness;
37433	1415	27	And if men come unto me I will show unto them their weakness. I give unto men weakness that they may be humble; and my grace is sufficient for all men that humble themselves before me; for if they humble themselves before me, and have faith in me, then will I make weak things become strong unto them.
37434	1415	28	Behold, I will show unto the Gentiles their weakness, and I will show unto them that faith, hope and charity bringeth unto me--the fountain of all righteousness.
37435	1415	29	And I, Moroni, having heard these words, was comforted, and said: O Lord, thy righteous will be done, for I know that thou workest unto the children of men according to their faith;
37436	1415	30	For the brother of Jared said unto the mountain Zerin, Remove--and it was removed. And if he had not had faith it would not have moved; wherefore thou workest after men have faith.
37437	1415	31	For thus didst thou manifest thyself unto thy disciples; for after they had faith, and did speak in thy name, thou didst show thyself unto them in great power.
37438	1415	32	And I also remember that thou hast said that thou hast prepared a house for man, yea, even among the mansions of thy Father, in which man might have a more excellent hope; wherefore man must hope, or he cannot receive an inheritance in the place which thou hast prepared.
37439	1415	33	And again, I remember that thou hast said that thou hast loved the world, even unto the laying down of thy life for the world, that thou mightest take it again to prepare a place for the children of men.
37440	1415	34	And now I know that this love which thou hast had for the children of men is charity; wherefore, except men shall have charity they cannot inherit that place which thou hast prepared in the mansions of thy Father.
37441	1415	35	Wherefore, I know by this thing which thou hast said, that if the Gentiles have not charity, because of our weakness, that thou wilt prove them, and take away their talent, yea, even that which they have received, and give unto them who shall have more abundantly.
37442	1415	36	And it came to pass that I prayed unto the Lord that he would give unto the Gentiles grace, that they might have charity.
37443	1415	37	And it came to pass that the Lord said unto me: If they have not charity it mattereth not unto thee, thou hast been faithful; wherefore, thy garments shall be made clean. And because thou hast seen thy weakness thou shalt be made strong, even unto the sitting down in the place which I have prepared in the mansions of my Father.
37444	1415	38	And now I, Moroni, bid farewell unto the Gentiles, yea, and also unto my brethren whom I love, until we shall meet before the judgment-seat of Christ, where all men shall know that my garments are not spotted with your blood.
37445	1415	39	And then shall ye know that I have seen Jesus, and that he hath talked with me face to face, and that he told me in plain humility, even as a man telleth another in mine own language, concerning these things;
37446	1415	40	And only a few have I written, because of my weakness in writing.
37447	1415	41	And now, I would commend you to seek this Jesus of whom the prophets and apostles have written, that the grace of God the Father, and also the Lord Jesus Christ, and the Holy Ghost, which beareth record of them, may be and abide in you forever. Amen.
37448	1416	1	And now I, Moroni, proceed to finish my record concerning the destruction of the people of whom I have been writing.
37449	1416	2	For behold, they rejected all the words of Ether; for he truly told them of all things, from the beginning of man; and that after the waters had receded from off the face of this land it became a choice land above all other lands, a chosen land of the Lord; wherefore the Lord would have that all men should serve him who dwell upon the face thereof;
37450	1416	3	And that it was the place of the New Jerusalem, which should come down out of heaven, and the holy sanctuary of the Lord.
37451	1416	4	Behold, Ether saw the days of Christ, and he spake concerning a New Jerusalem upon this land.
37452	1416	5	And he spake also concerning the house of Israel, and the Jerusalem from whence Lehi should come--after it should be destroyed it should be built up again, a holy city unto the Lord; wherefore, it could not be a new Jerusalem for it had been in a time of old; but it should be built up again, and become a holy city of the Lord; and it should be built unto the house of Israel.
37453	1416	6	And that a New Jerusalem should be built up upon this land, unto the remnant of the seed of Joseph, for which things there has been a type.
37454	1416	7	For as Joseph brought his father down into the land of Egypt, even so he died there; wherefore, the Lord brought a remnant of the seed of Joseph out of the land of Jerusalem, that he might be merciful unto the seed of Joseph that they should perish not, even as he was merciful unto the father of Joseph that he should perish not.
37455	1416	8	Wherefore, the remnant of the house of Joseph shall be built upon this land; and it shall be a land of their inheritance; and they shall build up a holy city unto the Lord, like unto the Jerusalem of old; and they shall no more be confounded, until the end come when the earth shall pass away.
37456	1416	9	And there shall be a new heaven and a new earth; and they shall be like unto the old save the old have passed away, and all things have become new.
37457	1416	10	And then cometh the New Jerusalem; and blessed are they who dwell therein, for it is they whose garments are white through the blood of the Lamb; and they are they who are numbered among the remnant of the seed of Joseph, who were of the house of Israel.
37458	1416	11	And then also cometh the Jerusalem of old; and the inhabitants thereof, blessed are they, for they have been washed in the blood of the Lamb; and they are they who were scattered and gathered in from the four quarters of the earth, and from the north countries, and are partakers of the fulfilling of the covenant which God made with their father, Abraham.
37459	1416	12	And when these things come, bringeth to pass the scripture which saith, there are they who were first, who shall be last; and there are they who were last, who shall be first.
37460	1416	13	And I was about to write more, but I am forbidden; but great and marvelous were the prophecies of Ether; but they esteemed him as naught, and cast him out; and he hid himself in the cavity of a rock by day, and by night he went forth viewing the things which should come upon the people.
37461	1416	14	And as he dwelt in the cavity of a rock he made the remainder of this record, viewing the destructions which came upon the people, by night.
37462	1416	15	And it came to pass that in that same year in which he was cast out from among the people there began to be a great war among the people, for there were many who rose up, who were mighty men, and sought to destroy Coriantumr by their secret plans of wickedness, of which hath been spoken.
37463	1416	16	And now Coriantumr, having studied, himself, in all the arts of war and all the cunning of the world, wherefore he gave battle unto them who sought to destroy him.
37464	1416	17	But he repented not, neither his fair sons nor daughters; neither the fair sons and daughters of Cohor; neither the fair sons and daughters of Corihor; and in fine, there were none of the fair sons and daughters upon the face of the whole earth who repented of their sins.
37465	1416	18	Wherefore, it came to pass that in the first year that Ether dwelt in the cavity of a rock, there were many people who were slain by the sword of those secret combinations, fighting against Coriantumr that they might obtain the kingdom.
37466	1416	19	And it came to pass that the sons of Coriantumr fought much and bled much.
37467	1416	20	And in the second year the word of the Lord came to Ether, that he should go and prophesy unto Coriantumr that, if he would repent, and all his household, the Lord would give unto him his kingdom and spare the people--
37468	1416	21	Otherwise they should be destroyed, and all his household save it were himself. And he should only live to see the fulfilling of the prophecies which had been spoken concerning another people receiving the land for their inheritance; and Coriantumr should receive a burial by them; and every soul should be destroyed save it were Coriantumr.
37469	1416	22	And it came to pass that Coriantumr repented not, neither his household, neither the people; and the wars ceased not; and they sought to kill Ether, but he fled from before them and hid again in the cavity of the rock.
37470	1416	23	And it came to pass that there arose up Shared, and he also gave battle unto Coriantumr; and he did beat him, insomuch that in the third year he did bring him into captivity.
37471	1416	24	And the sons of Coriantumr, in the fourth year, did beat Shared, and did obtain the kingdom again unto their father.
37472	1416	25	Now there began to be a war upon all the face of the land, every man with his band fighting for that which he desired.
37473	1416	26	And there were robbers, and in fine, all manner of wickedness upon all the face of the land.
37474	1416	27	And it came to pass that Coriantumr was exceedingly angry with Shared, and he went against him with his armies to battle; and they did meet in great anger, and they did meet in the valley of Gilgal; and the battle became exceedingly sore.
37475	1416	28	And it came to pass that Shared fought against him for the space of three days. And it came to pass that Coriantumr beat him, and did pursue him until he came to the plains of Heshlon.
37476	1416	29	And it came to pass that Shared gave him battle again upon the plains; and behold, he did beat Coriantumr, and drove him back again to the valley of Gilgal.
37477	1416	30	And Coriantumr gave Shared battle again in the valley of Gilgal, in which he beat Shared and slew him.
37478	1416	31	And Shared wounded Coriantumr in his thigh, that he did not go to battle again for the space of two years, in which time all the people upon the face of the land were shedding blood, and there was none to restrain them.
37479	1417	1	And now there began to be a great curse upon all the land because of the iniquity of the people, in which, if a man should lay his tool or his sword upon his shelf, or upon the place whither he would keep it, behold, upon the morrow, he could not find it, so great was the curse upon the land.
37480	1417	2	Wherefore every man did cleave unto that which was his own, with his hands, and would not borrow neither would he lend; and every man kept the hilt of his sword in his right hand, in the defence of his property and his own life and of his wives and children.
37481	1417	3	And now, after the space of two years, and after the death of Shared, behold, there arose the brother of Shared and he gave battle unto Coriantumr, in which Coriantumr did beat him and did pursue him to the wilderness of Akish.
37482	1417	4	And it came to pass that the brother of Shared did give battle unto him in the wilderness of Akish; and the battle became exceedingly sore, and many thousands fell by the sword.
37483	1417	5	And it came to pass that Coriantumr did lay siege to the wilderness; and the brother of Shared did march forth out of the wilderness by night, and slew a part of the army of Coriantumr, as they were drunken.
37484	1417	6	And he came forth to the land of Moron, and placed himself upon the throne of Coriantumr.
37485	1417	7	And it came to pass that Coriantumr dwelt with his army in the wilderness for the space of two years, in which he did receive great strength to his army.
37486	1417	8	Now the brother of Shared, whose name was Gilead, also received great strength to his army, because of secret combinations.
37487	1417	9	And it came to pass that his high priest murdered him as he sat upon his throne.
37488	1417	10	And it came to pass that one of the secret combinations murdered him in a secret pass, and obtained unto himself the kingdom; and his name was Lib; and Lib was a man of great stature, more than any other man among all the people.
37489	1417	11	And it came to pass that in the first year of Lib, Coriantumr came up unto the land of Moron, and gave battle unto Lib.
37490	1417	12	And it came to pass that he fought with Lib, in which Lib did smite upon his arm that he was wounded; nevertheless, the army of Coriantumr did press forward upon Lib, that he fled to the borders upon the seashore.
37491	1417	13	And it came to pass that Coriantumr pursued him; and Lib gave battle unto him upon the seashore.
37492	1417	14	And it came to pass that Lib did smite the army of Coriantumr, that they fled again to the wilderness of Akish.
37493	1417	15	And it came to pass that Lib did pursue him until he came to the plains of Agosh. And Coriantumr had taken all the people with him as he fled before Lib in that quarter of the land whither he fled.
37494	1417	16	And when he had come to the plains of Agosh he gave battle unto Lib, and he smote upon him until he died; nevertheless, the brother of Lib did come against Coriantumr in the stead thereof, and the battle became exceedingly sore, in the which Coriantumr fled again before the army of the brother of Lib.
37495	1417	17	Now the name of the brother of Lib was called Shiz. And it came to pass that Shiz pursued after Coriantumr, and he did overthrow many cities, and he did slay both women and children, and he did burn the cities.
37496	1417	18	And there went a fear of Shiz throughout all the land; yea, a cry went forth throughout the land--Who can stand before the army of Shiz? Behold, he sweepeth the earth before him!
37497	1417	19	And it came to pass that the people began to flock together in armies, throughout all the face of the land.
37498	1417	20	And they were divided; and a part of them fled to the army of Shiz, and a part of them fled to the army of Coriantumr.
37499	1417	21	And so great and lasting had been the war, and so long had been the scene of bloodshed and carnage, that the whole face of the land was covered with the bodies of the dead.
37500	1417	22	And so swift and speedy was the war that there was none left to bury the dead, but they did march forth from the shedding of blood to the shedding of blood, leaving the bodies of both men, women, and children strewed upon the face of the land, to become a prey to the worms of the flesh.
37501	1417	23	And the scent thereof went forth upon the face of the land, even upon all the face of the land; wherefore the people became troubled by day and by night, because of the scent thereof.
37502	1417	24	Nevertheless, Shiz did not cease to pursue Coriantumr; for he had sworn to avenge himself upon Coriantumr of the blood of his brother, who had been slain, and the word of the Lord which came to Ether that Coriantumr should not fall by the sword.
37503	1417	25	And thus we see that the Lord did visit them in the fulness of his wrath, and their wickedness and abominations had prepared a way for their everlasting destruction.
37504	1417	26	And it came to pass that Shiz did pursue Coriantumr eastward, even to the borders by the seashore, and there he gave battle unto Shiz for the space of three days.
37505	1417	27	And so terrible was the destruction among the armies of Shiz that the people began to be frightened, and began to flee before the armies of Coriantumr; and they fled to the land of Corihor, and swept off the inhabitants before them, all them that would not join them.
37506	1417	28	And they pitched their tents in the valley of Corihor; and Coriantumr pitched his tents in the valley of Shurr. Now the valley of Shurr was near the hill Comnor; wherefore, Coriantumr did gather his armies together upon the hill Comnor, and did sound a trumpet unto the armies of Shiz to invite them forth to battle.
37507	1417	29	And it came to pass that they came forth, but were driven again; and they came the second time, and they were driven again the second time. And it came to pass that they came again the third time, and the battle became exceedingly sore.
37508	1417	30	And it came to pass that Shiz smote upon Coriantumr that he gave him many deep wounds; and Coriantumr, having lost his blood, fainted, and was carried away as though he were dead.
37509	1417	31	Now the loss of men, women and children on both sides was so great that Shiz commanded his people that they should not pursue the armies of Coriantumr; wherefore, they returned to their camp.
37510	1418	1	And it came to pass when Coriantumr had recovered of his wounds, he began to remember the words which Ether had spoken unto him.
37511	1418	2	He saw that there had been slain by the sword already nearly two millions of his people, and he began to sorrow in his heart; yea, there had been slain two millions of mighty men, and also their wives and their children.
37512	1418	3	He began to repent of the evil which he had done; he began to remember the words which had been spoken by the mouth of all the prophets, and he saw them that they were fulfilled thus far, every whit; and his soul mourned and refused to be comforted.
37513	1418	4	And it came to pass that he wrote an epistle unto Shiz, desiring him that he would spare the people, and he would give up the kingdom for the sake of the lives of the people.
37514	1418	5	And it came to pass that when Shiz had received his epistle he wrote an epistle unto Coriantumr, that if he would give himself up, that he might slay him with his own sword, that he would spare the lives of the people.
37515	1418	6	And it came to pass that the people repented not of their iniquity; and the people of Coriantumr were stirred up to anger against the people of Shiz; and the people of Shiz were stirred up to anger against the people of Coriantumr; wherefore, the people of Shiz did give battle unto the people of Coriantumr.
37516	1418	7	And when Coriantumr saw that he was about to fall he fled again before the people of Shiz.
37517	1418	8	And it came to pass that he came to the waters of Ripliancum, which, by interpretation, is large, or to exceed all; wherefore, when they came to these waters they pitched their tents; and Shiz also pitched his tents near unto them; and therefore on the morrow they did come to battle.
37518	1418	9	And it came to pass that they fought an exceedingly sore battle, in which Coriantumr was wounded again, and he fainted with the loss of blood.
37519	1418	10	And it came to pass that the armies of Coriantumr did press upon the armies of Shiz that they beat them, that they caused them to flee before them; and they did flee southward, and did pitch their tents in a place which was called Ogath.
37520	1418	11	And it came to pass that the army of Coriantumr did pitch their tents by the hill Ramah; and it was that same hill where my father Mormon did hide up the records unto the Lord, which were sacred.
37521	1418	12	And it came to pass that they did gather together all the people upon all the face of the land, who had not been slain, save it was Ether.
37522	1418	13	And it came to pass that Ether did behold all the doings of the people; and he beheld that the people who were for Coriantumr were gathered together to the army of Coriantumr; and the people who were for Shiz were gathered together to the army of Shiz.
37523	1418	14	Wherefore, they were for the space of four years gathering together the people, that they might get all who were upon the face of the land, and that they might receive all the strength which it was possible that they could receive.
37524	1418	15	And it came to pass that when they were all gathered together, every one to the army which he would, with their wives and their children--both men, women and children being armed with weapons of war, having shields, and breastplates, and head-plates, and being clothed after the manner of war--they did march forth one against another to battle; and they fought all that day, and conquered not.
37525	1418	16	And it came to pass that when it was night they were weary, and retired to their camps; and after they had retired to their camps they took up a howling and a lamentation for the loss of the slain of their people; and so great were their cries, their howlings and lamentations, that they did rend the air exceedingly.
37526	1418	17	And it came to pass that on the morrow they did go again to battle, and great and terrible was that day; nevertheless, they conquered not, and when the night came again they did rend the air with their cries, and their howlings, and their mournings, for the loss of the slain of their people.
37527	1418	18	And it came to pass that Coriantumr wrote again an epistle unto Shiz, desiring that he would not come again to battle, but that he would take the kingdom, and spare the lives of the people.
37528	1418	19	But behold, the Spirit of the Lord had ceased striving with them, and Satan had full power over the hearts of the people; for they were given up unto the hardness of their hearts, and the blindness of their minds that they might be destroyed; wherefore they went again to battle.
37529	1418	20	And it came to pass that they fought all that day, and when the night came they slept upon their swords.
37530	1418	21	And on the morrow they fought even until the night came.
37531	1418	22	And when the night came they were drunken with anger, even as a man who is drunken with wine; and they slept again upon their swords.
37532	1418	23	And on the morrow they fought again; and when the night came they had all fallen by the sword save it were fifty and two of the people of Coriantumr, and sixty and nine of the people of Shiz.
37533	1418	24	And it came to pass that they slept upon their swords that night, and on the morrow they fought again, and they contended in their might with their swords and with their shields, all that day.
37534	1418	25	And when the night came there were thirty and two of the people of Shiz, and twenty and seven of the people of Coriantumr.
37535	1418	26	And it came to pass that they ate and slept, and prepared for death on the morrow. And they were large and mighty men as to the strength of men.
37536	1418	27	And it came to pass that they fought for the space of three hours, and they fainted with the loss of blood.
37537	1418	28	And it came to pass that when the men of Coriantumr had received sufficient strength that they could walk, they were about to flee for their lives; but behold, Shiz arose, and also his men, and he swore in his wrath that he would slay Coriantumr or he would perish by the sword.
37538	1418	29	Wherefore, he did pursue them, and on the morrow he did overtake them; and they fought again with the sword. And it came to pass that when they had all fallen by the sword, save it were Coriantumr and Shiz, behold Shiz had fainted with the loss of blood.
37539	1418	30	And it came to pass that when Coriantumr had leaned upon his sword, that he rested a little, he smote off the head of Shiz.
37540	1418	31	And it came to pass that after he had smitten off the head of Shiz, that Shiz raised up on his hands and fell; and after that he had struggled for breath, he died.
37541	1418	32	And it came to pass that Coriantumr fell to the earth, and became as if he had no life.
37542	1418	33	And the Lord spake unto Ether, and said unto him: Go forth. And he went forth, and beheld that the words of the Lord had all been fulfilled; and he finished his record; (and the hundredth part I have not written) and he hid them in a manner that the people of Limhi did find them.
37543	1418	34	Now the last words which are written by Ether are these: Whether the Lord will that I be translated, or that I suffer the will of the Lord in the flesh, it mattereth not, if it so be that I am saved in the kingdom of God. Amen.
37544	1419	1	Now I, Moroni, after having made an end of abridging the account of the people of Jared, I had supposed not to have written more, but I have not as yet perished; and I make not myself known to the Lamanites lest they should destroy me.
37545	1419	2	For behold, their wars are exceedingly fierce among themselves; and because of their hatred they put to death every Nephite that will not deny the Christ.
37546	1419	3	And I, Moroni, will not deny the Christ; wherefore, I wander whithersoever I can for the safety of mine own life.
37547	1419	4	Wherefore, I write a few more things, contrary to that which I had supposed; for I had supposed not to have written any more; but I write a few more things, that perhaps they may be of worth unto my brethren, the Lamanites, in some future day, according to the will of the Lord.
37548	1420	1	The words of Christ, which he spake unto his disciples, the twelve whom he had chosen, as he laid his hands upon them--
37549	1420	2	And he called them by name, saying: Ye shall call on the Father in my name, in mighty prayer; and after ye have done this ye shall have power that to him upon whom ye shall lay your hands, ye shall give the Holy Ghost; and in my name shall ye give it, for thus do mine apostles.
37550	1420	3	Now Christ spake these words unto them at the time of his first appearing; and the multitude heard it not, but the disciples heard it; and on as many as they laid their hands, fell the Holy Ghost.
37551	1421	1	The manner which the disciples, who were called the elders of the church, ordained priests and teachers--
37552	1421	2	After they had prayed unto the Father in the name of Christ, they laid their hands upon them, and said:
37553	1421	3	In the name of Jesus Christ I ordain you to be a priest, (or, if he be a teacher) I ordain you to be a teacher, to preach repentance and remission of sins through Jesus Christ, by the endurance of faith on his name to the end. Amen.
37554	1421	4	And after this manner did they ordain priests and teachers, according to the gifts and callings of God unto men; and they ordained them by the power of the Holy Ghost, which was in them.
37555	1422	1	The manner of their elders and priests administering the flesh and blood of Christ unto the church; and they administered it according to the commandments of Christ; wherefore we know the manner to be true; and the elder or priest did minister it--
37556	1422	2	And they did kneel down with the church, and pray to the Father in the name of Christ, saying:
37557	1422	3	O God, the Eternal Father, we ask thee in the name of thy Son, Jesus Christ, to bless and sanctify this bread to the souls of all those who partake of it; that they may eat in remembrance of the body of thy Son, and witness unto thee, O God, the Eternal Father, that they are willing to take upon them the name of thy Son, and always remember him, and keep his commandments which he hath given them, that they may always have his Spirit to be with them. Amen.
37558	1423	1	The manner of administering the wine--Behold, they took the cup, and said:
37559	1423	2	O God, the Eternal Father, we ask thee, in the name of thy Son, Jesus Christ, to bless and sanctify this wine to the souls of all those who drink of it, that they may do it in remembrance of the blood of thy Son, which was shed for them; that they may witness unto thee, O God, the Eternal Father, that they do always remember him, that they may have his Spirit to be with them. Amen.
37560	1424	1	And now I speak concerning baptism. Behold, elders, priests, and teachers were baptized; and they were not baptized save they brought forth fruit meet that they were worthy of it.
37561	1424	2	Neither did they receive any unto baptism save they came forth with a broken heart and a contrite spirit, and witnessed unto the church that they truly repented of all their sins.
37562	1424	3	And none were received unto baptism save they took upon them the name of Christ, having a determination to serve him to the end.
37563	1424	4	And after they had been received unto baptism, and were wrought upon and cleansed by the power of the Holy Ghost, they were numbered among the people of the church of Christ; and their names were taken, that they might be remembered and nourished by the good word of God, to keep them in the right way, to keep them continually watchful unto prayer, relying alone upon the merits of Christ, who was the author and the finisher of their faith.
37564	1424	5	And the church did meet together oft, to fast and to pray, and to speak one with another concerning the welfare of their souls.
37565	1424	6	And they did meet together oft to partake of bread and wine, in remembrance of the Lord Jesus.
37566	1424	7	And they were strict to observe that there should be no iniquity among them; and whoso was found to commit iniquity, and three witnesses of the church did condemn them before the elders, and if they repented not, and confessed not, their names were blotted out, and they were not numbered among the people of Christ.
37567	1424	8	But as oft as they repented and sought forgiveness, with real intent, they were forgiven.
37568	1424	9	And their meetings were conducted by the church after the manner of the workings of the Spirit, and by the power of the Holy Ghost; for as the power of the Holy Ghost led them whether to preach, or to exhort, or to pray, or to supplicate, or to sing, even so it was done.
37569	1425	1	And now I, Moroni, write a few of the words of my father Mormon, which he spake concerning faith, hope, and charity; for after this manner did he speak unto the people, as he taught them in the synagogue which they had built for the place of worship.
37570	1425	2	And now I, Mormon, speak unto you, my beloved brethren; and it is by the grace of God the Father, and our Lord Jesus Christ, and his holy will, because of the gift of his calling unto me, that I am permitted to speak unto you at this time.
37571	1425	3	Wherefore, I would speak unto you that are of the church, that are the peaceable followers of Christ, and that have obtained a sufficient hope by which ye can enter into the rest of the Lord, from this time henceforth until ye shall rest with him in heaven.
37572	1425	4	And now my brethren, I judge these things of you because of your peaceable walk with the children of men.
37573	1425	5	For I remember the word of God which saith by their works ye shall know them; for if their works be good, then they are good also.
37574	1425	6	For behold, God hath said a man being evil cannot do that which is good; for if he offereth a gift, or prayeth unto God, except he shall do it with real intent it profiteth him nothing.
37575	1425	7	For behold, it is not counted unto him for righteousness.
37576	1425	8	For behold, if a man being evil giveth a gift, he doeth it grudgingly; wherefore it is counted unto him the same as if he had retained the gift; wherefore he is counted evil before God.
37577	1425	9	And likewise also is it counted evil unto a man, if he shall pray and not with real intent of heart; yea, and it profiteth him nothing, for God receiveth none such.
37578	1425	10	Wherefore, a man being evil cannot do that which is good; neither will he give a good gift.
37579	1425	11	For behold, a bitter fountain cannot bring forth good water; neither can a good fountain bring forth bitter water; wherefore, a man being a servant of the devil cannot follow Christ; and if he follow Christ he cannot be a servant of the devil.
37580	1425	12	Wherefore, all things which are good cometh of God; and that which is evil cometh of the devil; for the devil is an enemy unto God, and fighteth against him continually, and inviteth and enticeth to sin, and to do that which is evil continually.
37581	1425	13	But behold, that which is of God inviteth and enticeth to do good continually; wherefore, every thing which inviteth and enticeth to do good, and to love God, and to serve him, is inspired of God.
37582	1425	14	Wherefore, take heed, my beloved brethren, that ye do not judge that which is evil to be of God, or that which is good and of God to be of the devil.
37583	1425	15	For behold, my brethren, it is given unto you to judge, that ye may know good from evil; and the way to judge is as plain, that ye may know with a perfect knowledge, as the daylight is from the dark night.
37584	1425	16	For behold, the Spirit of Christ is given to every man, that he may know good from evil; wherefore, I show unto you the way to judge; for every thing which inviteth to do good, and to persuade to believe in Christ, is sent forth by the power and gift of Christ; wherefore ye may know with a perfect knowledge it is of God.
37585	1425	17	But whatsoever thing persuadeth men to do evil, and believe not in Christ, and deny him, and serve not God, then ye may know with a perfect knowledge it is of the devil; for after this manner doth the devil work, for he persuadeth no man to do good, no, not one; neither do his angels; neither do they who subject themselves unto him.
37586	1425	18	And now, my brethren, seeing that ye know the light by which ye may judge, which light is the light of Christ, see that ye do not judge wrongfully; for with that same judgment which ye judge ye shall also be judged.
37587	1425	19	Wherefore, I beseech of you, brethren, that ye should search diligently in the light of Christ that ye may know good from evil; and if ye will lay hold upon every good thing, and condemn it not, ye certainly will be a child of Christ.
37588	1425	20	And now, my brethren, how is it possible that ye can lay hold upon every good thing?
37589	1425	21	And now I come to that faith, of which I said I would speak; and I will tell you the way whereby ye may lay hold on every good thing.
37590	1425	22	For behold, God knowing all things, being from everlasting to everlasting, behold, he sent angels to minister unto the children of men, to make manifest concerning the coming of Christ; and in Christ there should come every good thing.
37591	1425	23	And God also declared unto prophets, by his own mouth, that Christ should come.
37592	1425	24	And behold, there were divers ways that he did manifest things unto the children of men, which were good; and all things which are good cometh of Christ; otherwise men were fallen, and there could no good thing come unto them.
37593	1425	25	Wherefore, by the ministering of angels, and by every word which proceeded forth out of the mouth of God, men began to exercise faith in Christ; and thus by faith, they did lay hold upon every good thing; and thus it was until the coming of Christ.
37594	1425	26	And after that he came men also were saved by faith in his name; and by faith, they become the sons of God. And as surely as Christ liveth he spake these words unto our fathers, saying: Whatsoever thing ye shall ask the Father in my name, which is good, in faith believing that ye shall receive, behold, it shall be done unto you.
37595	1425	27	Wherefore, my beloved brethren, have miracles ceased because Christ hath ascended into heaven, and hath sat down on the right hand of God, to claim of the Father his rights of mercy which he hath upon the children of men?
37596	1425	28	For he hath answered the ends of the law, and he claimeth all those who have faith in him; and they who have faith in him will cleave unto every good thing; wherefore he advocateth the cause of the children of men; and he dwelleth eternally in the heavens.
37597	1425	29	And because he hath done this, my beloved brethren, have miracles ceased? Behold I say unto you, Nay; neither have angels ceased to minister unto the children of men.
37598	1425	30	For behold, they are subject unto him, to minister according to the word of his command, showing themselves unto them of strong faith and a firm mind in every form of godliness.
37599	1425	31	And the office of their ministry is to call men unto repentance, and to fulfil and to do the work of the covenants of the Father, which he hath made unto the children of men, to prepare the way among the children of men, by declaring the word of Christ unto the chosen vessels of the Lord, that they may bear testimony of him.
37600	1425	32	And by so doing, the Lord God prepareth the way that the residue of men may have faith in Christ, that the Holy Ghost may have place in their hearts, according to the power thereof; and after this manner bringeth to pass the Father, the covenants which he hath made unto the children of men.
37601	1425	33	And Christ hath said: If ye will have faith in me ye shall have power to do whatsoever thing is expedient in me.
37602	1425	34	And he hath said: Repent all ye ends of the earth, and come unto me, and be baptized in my name, and have faith in me, that ye may be saved.
37603	1425	35	And now, my beloved brethren, if this be the case that these things are true which I have spoken unto you, and God will show unto you, with power and great glory at the last day, that they are true, and if they are true has the day of miracles ceased?
37604	1425	36	Or have angels ceased to appear unto the children of men? Or has he withheld the power of the Holy Ghost from them? Or will he, so long as time shall last, or the earth shall stand, or there shall be one man upon the face thereof to be saved?
37605	1425	37	Behold I say unto you, Nay; for it is by faith that miracles are wrought; and it is by faith that angels appear and minister unto men; wherefore, if these things have ceased wo be unto the children of men, for it is because of unbelief, and all is vain.
37606	1425	38	For no man can be saved, according to the words of Christ, save they shall have faith in his name; wherefore, if these things have ceased, then has faith ceased also; and awful is the state of man, for they are as though there had been no redemption made.
37607	1425	39	But behold, my beloved brethren, I judge better things of you, for I judge that ye have faith in Christ because of your meekness; for if ye have not faith in him then ye are not fit to be numbered among the people of his church.
37608	1425	40	And again, my beloved brethren, I would speak unto you concerning hope. How is it that ye can attain unto faith, save ye shall have hope?
37609	1425	41	And what is it that ye shall hope for? Behold I say unto you that ye shall have hope through the atonement of Christ and the power of his resurrection, to be raised unto life eternal, and this because of your faith in him according to the promise.
37610	1425	42	Wherefore, if a man have faith he must needs have hope; for without faith there cannot be any hope.
37611	1425	43	And again, behold I say unto you that he cannot have faith and hope, save he shall be meek, and lowly of heart.
37612	1425	44	If so, his faith and hope is vain, for none is acceptable before God, save the meek and lowly in heart; and if a man be meek and lowly in heart, and confesses by the power of the Holy Ghost that Jesus is the Christ, he must needs have charity; for if he have not charity he is nothing; wherefore he must needs have charity.
37613	1425	45	And charity suffereth long, and is kind, and envieth not, and is not puffed up, seeketh not her own, is not easily provoked, thinketh no evil, and rejoiceth not in iniquity but rejoiceth in the truth, beareth all things, believeth all things, hopeth all things, endureth all things.
37614	1425	46	Wherefore, my beloved brethren, if ye have not charity, ye are nothing, for charity never faileth. Wherefore, cleave unto charity, which is the greatest of all, for all things must fail--
37615	1425	47	But charity is the pure love of Christ, and it endureth forever; and whoso is found possessed of it at the last day, it shall be well with him.
37616	1425	48	Wherefore, my beloved brethren, pray unto the Father with all the energy of heart, that ye may be filled with this love, which he hath bestowed upon all who are true followers of his Son, Jesus Christ; that ye may become the sons of God; that when he shall appear we shall be like him, for we shall see him as he is; that we may have this hope; that we may be purified even as he is pure. Amen.
37617	1426	1	An epistle of my father Mormon, written to me, Moroni; and it was written unto me soon after my calling to the ministry. And on this wise did he write unto me, saying:
37618	1426	2	My beloved son, Moroni, I rejoice exceedingly that your Lord Jesus Christ hath been mindful of you, and hath called you to his ministry, and to his holy work.
37619	1426	3	I am mindful of you always in my prayers, continually praying unto God the Father in the name of his Holy Child, Jesus, that he, through his infinite goodness and grace, will keep you through the endurance of faith on his name to the end.
37620	1426	4	And now, my son, I speak unto you concerning that which grieveth me exceedingly; for it grieveth me that there should disputations rise among you.
37621	1426	5	For, if I have learned the truth, there have been disputations among you concerning the baptism of your little children.
37622	1426	6	And now, my son, I desire that ye should labor diligently, that this gross error should be removed from among you; for, for this intent I have written this epistle.
37623	1426	7	For immediately after I had learned these things of you I inquired of the Lord concerning the matter. And the word of the Lord came to me by the power of the Holy Ghost, saying:
37624	1426	8	Listen to the words of Christ, your Redeemer, your Lord and your God. Behold, I came into the world not to call the righteous but sinners to repentance; the whole need no physician, but they that are sick; wherefore, little children are whole, for they are not capable of committing sin; wherefore the curse of Adam is taken from them in me, that it hath no power over them; and the law of circumcision is done away in me.
37625	1426	9	And after this manner did the Holy Ghost manifest the word of God unto me; wherefore, my beloved son, I know that it is solemn mockery before God, that ye should baptize little children.
37626	1426	10	Behold I say unto you that this thing shall ye teach--repentance and baptism unto those who are accountable and capable of committing sin; yea, teach parents that they must repent and be baptized, and humble themselves as their little children, and they shall all be saved with their little children.
37627	1426	11	And their little children need no repentance, neither baptism. Behold, baptism is unto repentance to the fulfilling the commandments unto the remission of sins.
37628	1426	12	But little children are alive in Christ, even from the foundation of the world; if not so, God is a partial God, and also a changeable God, and a respecter to persons; for how many little children have died without baptism!
37629	1426	13	Wherefore, if little children could not be saved without baptism, these must have gone to an endless hell.
37630	1426	14	Behold I say unto you, that he that supposeth that little children need baptism is in the gall of bitterness and in the bonds of iniquity; for he hath neither faith, hope, nor charity; wherefore, should he be cut off while in the thought, he must go down to hell.
37631	1426	15	For awful is the wickedness to suppose that God saveth one child because of baptism, and the other must perish because he hath no baptism.
37632	1426	16	Wo be unto them that shall pervert the ways of the Lord after this manner, for they shall perish except they repent. Behold, I speak with boldness, having authority from God; and I fear not what man can do; for perfect love casteth out all fear.
37633	1426	17	And I am filled with charity, which is everlasting love; wherefore, all children are alike unto me; wherefore, I love little children with a perfect love; and they are all alike and partakers of salvation.
37634	1426	18	For I know that God is not a partial God, neither a changeable being; but he is unchangeable from all eternity to all eternity.
37635	1426	19	Little children cannot repent; wherefore, it is awful wickedness to deny the pure mercies of God unto them, for they are all alive in him because of his mercy.
37636	1426	20	And he that saith that little children need baptism denieth the mercies of Christ, and setteth at naught the atonement of him and the power of his redemption.
37637	1426	21	Wo unto such, for they are in danger of death, hell, and an endless torment. I speak it boldly; God hath commanded me. Listen unto them and give heed, or they stand against you at the judgment-seat of Christ.
37638	1426	22	For behold that all little children are alive in Christ, and also all they that are without the law. For the power of redemption cometh on all them that have no law; wherefore, he that is not condemned, or he that is under no condemnation, cannot repent; and unto such baptism availeth nothing--
37639	1426	23	But it is mockery before God, denying the mercies of Christ, and the power of his Holy Spirit, and putting trust in dead works.
37640	1426	24	Behold, my son, this thing ought not to be; for repentance is unto them that are under condemnation and under the curse of a broken law.
37641	1426	25	And the first fruits of repentance is baptism; and baptism cometh by faith unto the fulfilling the commandments; and the fulfilling the commandments bringeth remission of sins;
37642	1426	26	And the remission of sins bringeth meekness, and lowliness of heart; and because of meekness and lowliness of heart cometh the visitation of the Holy Ghost, which Comforter filleth with hope and perfect love, which love endureth by diligence unto prayer, until the end shall come, when all the saints shall dwell with God.
37643	1426	27	Behold, my son, I will write unto you again if I go not out soon against the Lamanites. Behold, the pride of this nation, or the people of the Nephites, hath proven their destruction except they should repent.
37644	1426	28	Pray for them, my son, that repentance may come unto them. But behold, I fear lest the Spirit hath ceased striving with them; and in this part of the land they are also seeking to put down all power and authority which cometh from God; and they are denying the Holy Ghost.
37645	1426	29	And after rejecting so great a knowledge, my son, they must perish soon, unto the fulfilling of the prophecies which were spoken by the prophets, as well as the words of our Savior himself.
37646	1426	30	Farewell, my son, until I shall write unto you, or shall meet you again. Amen.
37647	1427	1	My beloved son, I write unto you again that ye may know that I am yet alive; but I write somewhat of that which is grievous.
37648	1427	2	For behold, I have had a sore battle with the Lamanites, in which we did not conquer; and Archeantus has fallen by the sword, and also Luram and Emron; yea, and we have lost a great number of our choice men.
37649	1427	3	And now behold, my son, I fear lest the Lamanites shall destroy this people; for they do not repent, and Satan stirreth them up continually to anger one with another.
37650	1427	4	Behold, I am laboring with them continually; and when I speak the word of God with sharpness they tremble and anger against me; and when I use no sharpness they harden their hearts against it; wherefore, I fear lest the Spirit of the Lord hath ceased striving with them.
37651	1427	5	For so exceedingly do they anger that it seemeth me that they have no fear of death; and they have lost their love, one towards another; and they thirst after blood and revenge continually.
37652	1427	6	And now, my beloved son, notwithstanding their hardness, let us labor diligently; for if we should cease to labor, we should be brought under condemnation; for we have a labor to perform whilst in this tabernacle of clay, that we may conquer the enemy of all righteousness, and rest our souls in the kingdom of God.
37653	1427	7	And now I write somewhat concerning the sufferings of this people. For according to the knowledge which I have received from Amoron, behold, the Lamanites have many prisoners, which they took from the tower of Sherrizah; and there were men, women, and children.
37654	1427	8	And the husbands and fathers of those women and children they have slain; and they feed the women upon the flesh of their husbands, and the children upon the flesh of their fathers; and no water, save a little, do they give unto them.
37655	1427	9	And notwithstanding this great abomination of the Lamanites, it doth not exceed that of our people in Moriantum. For behold, many of the daughters of the Lamanites have they taken prisoners; and after depriving them of that which was most dear and precious above all things, which is chastity and virtue--
37656	1427	10	And after they had done this thing, they did murder them in a most cruel manner, torturing their bodies even unto death; and after they have done this, they devour their flesh like unto wild beasts, because of the hardness of their hearts; and they do it for a token of bravery.
37657	1427	11	O my beloved son, how can a people like this, that are without civilization--
37658	1427	12	(And only a few years have passed away, and they were a civil and a delightsome people)
37659	1427	13	But O my son, how can a people like this, whose delight is in so much abomination--
37660	1427	14	How can we expect that God will stay his hand in judgment against us?
37661	1427	15	Behold, my heart cries: Wo unto this people. Come out in judgment, O God, and hide their sins, and wickedness, and abominations from before thy face!
37662	1427	16	And again, my son, there are many widows and their daughters who remain in Sherrizah; and that part of the provisions which the Lamanites did not carry away, behold, the army of Zenephi has carried away, and left them to wander whithersoever they can for food; and many old women do faint by the way and die.
37663	1427	17	And the army which is with me is weak; and the armies of the Lamanites are betwixt Sherrizah and me; and as many as have fled to the army of Aaron have fallen victims to their awful brutality.
37664	1427	18	O the depravity of my people! They are without order and without mercy. Behold, I am but a man, and I have but the strength of a man, and I cannot any longer enforce my commands.
37665	1427	19	And they have become strong in their perversion; and they are alike brutal, sparing none, neither old nor young; and they delight in everything save that which is good; and the suffering of our women and our children upon all the face of this land doth exceed everything; yea, tongue cannot tell, neither can it be written.
37666	1427	20	And now, my son, I dwell no longer upon this horrible scene. Behold, thou knowest the wickedness of this people; thou knowest that they are without principle, and past feeling; and their wickedness doth exceed that of the Lamanites.
37667	1427	21	Behold, my son, I cannot recommend them unto God lest he should smite me.
37668	1427	22	But behold, my son, I recommend thee unto God, and I trust in Christ that thou wilt be saved; and I pray unto God that he will spare thy life, to witness the return of his people unto him, or their utter destruction; for I know that they must perish except they repent and return unto him.
37669	1427	23	And if they perish it will be like unto the Jaredites, because of the wilfulness of their hearts, seeking for blood and revenge.
37670	1427	24	And if it so be that they perish, we know that many of our brethren have deserted over unto the Lamanites, and many more will also desert over unto them; wherefore, write somewhat a few things, if thou art spared and I shall perish and not see thee; but I trust that I may see thee soon; for I have sacred records that I would deliver up unto thee.
37671	1427	25	My son, be faithful in Christ; and may not the things which I have written grieve thee, to weigh thee down unto death; but may Christ lift thee up, and may his sufferings and death, and the showing his body unto our fathers, and his mercy and long-suffering, and the hope of his glory and of eternal life, rest in your mind forever.
37672	1427	26	And may the grace of God the Father, whose throne is high in the heavens, and our Lord Jesus Christ, who sitteth on the right hand of his power, until all things shall become subject unto him, be, and abide with you forever. Amen.
37673	1428	1	Now I, Moroni, write somewhat as seemeth me good; and I write unto my brethren, the Lamanites; and I would that they should know that more than four hundred and twenty years have passed away since the sign was given of the coming of Christ.
37674	1428	2	And I seal up these records, after I have spoken a few words by way of exhortation unto you.
37675	1428	3	Behold, I would exhort you that when ye shall read these things, if it be wisdom in God that ye should read them, that ye would remember how merciful the Lord hath been unto the children of men, from the creation of Adam even down until the time that ye shall receive these things, and ponder it in your hearts.
37676	1428	4	And when ye shall receive these things, I would exhort you that ye would ask God, the Eternal Father, in the name of Christ, if these things are not true; and if ye shall ask with a sincere heart, with real intent, having faith in Christ, he will manifest the truth of it unto you, by the power of the Holy Ghost.
37677	1428	5	And by the power of the Holy Ghost ye may know the truth of all things.
37678	1428	6	And whatsoever thing is good is just and true; wherefore, nothing that is good denieth the Christ, but acknowledgeth that he is.
37679	1428	7	And ye may know that he is, by the power of the Holy Ghost; wherefore I would exhort you that ye deny not the power of God; for he worketh by power, according to the faith of the children of men, the same today and tomorrow, and forever.
37680	1428	8	And again, I exhort you, my brethren, that ye deny not the gifts of God, for they are many; and they come from the same God. And there are different ways that these gifts are administered; but it is the same God who worketh all in all; and they are given by the manifestations of the Spirit of God unto men, to profit them.
37681	1428	9	For behold, to one is given by the Spirit of God, that he may teach the word of wisdom;
37682	1428	10	And to another, that he may teach the word of knowledge by the same Spirit;
37683	1428	11	And to another, exceedingly great faith; and to another, the gifts of healing by the same Spirit;
37684	1428	12	And again, to another, that he may work mighty miracles;
37685	1428	13	And again, to another, that he may prophesy concerning all things;
37686	1428	14	And again, to another, the beholding of angels and ministering spirits;
37687	1428	15	And again, to another, all kinds of tongues;
37688	1428	16	And again, to another, the interpretation of languages and of divers kinds of tongues.
37689	1428	17	And all these gifts come by the Spirit of Christ; and they come unto every man severally, according as he will.
37690	1428	18	And I would exhort you, my beloved brethren, that ye remember that every good gift cometh of Christ.
37691	1428	19	And I would exhort you, my beloved brethren, that ye remember that he is the same yesterday, today, and forever, and that all these gifts of which I have spoken, which are spiritual, never will be done away, even as long as the world shall stand, only according to the unbelief of the children of men.
37692	1428	20	Wherefore, there must be faith; and if there must be faith there must also be hope; and if there must be hope there must also be charity.
37693	1428	21	And except ye have charity ye can in nowise be saved in the kingdom of God; neither can ye be saved in the kingdom of God if ye have not faith; neither can ye if ye have no hope.
37694	1428	22	And if ye have no hope ye must needs be in despair; and despair cometh because of iniquity.
37695	1428	23	And Christ truly said unto our fathers: If ye have faith ye can do all things which are expedient unto me.
37696	1428	24	And now I speak unto all the ends of the earth--that if the day cometh that the power and gifts of God shall be done away among you, it shall be because of unbelief.
37697	1428	25	And wo be unto the children of men if this be the case; for there shall be none that doeth good among you, no not one. For if there be one among you that doeth good, he shall work by the power and gifts of God.
37698	1428	26	And wo unto them who shall do these things away and die, for they die in their sins, and they cannot be saved in the kingdom of God; and I speak it according to the words of Christ; and I lie not.
37699	1428	27	And I exhort you to remember these things; for the time speedily cometh that ye shall know that I lie not, for ye shall see me at the bar of God; and the Lord God will say unto you: Did I not declare my words unto you, which were written by this man, like as one crying from the dead, yea, even as one speaking out of the dust?
37700	1428	28	I declare these things unto the fulfilling of the prophecies. And behold, they shall proceed forth out of the mouth of the everlasting God; and his word shall hiss forth from generation to generation.
37701	1428	29	And God shall show unto you, that that which I have written is true.
37702	1428	30	And again I would exhort you that ye would come unto Christ, and lay hold upon every good gift, and touch not the evil gift, nor the unclean thing.
37703	1428	31	And awake, and arise from the dust, O Jerusalem; yea, and put on thy beautiful garments, O daughter of Zion; and strengthen thy stakes and enlarge thy borders forever, that thou mayest no more be confounded, that the covenants of the Eternal Father which he hath made unto thee, O house of Israel, may be fulfilled.
37704	1428	32	Yea, come unto Christ, and be perfected in him, and deny yourselves of all ungodliness; and if ye shall deny yourselves of all ungodliness, and love God with all your might, mind and strength, then is his grace sufficient for you, that by his grace ye may be perfect in Christ; and if by the grace of God ye are perfect in Christ, ye can in nowise deny the power of God.
37705	1428	33	And again, if ye by the grace of God are perfect in Christ, and deny not his power, then are ye sanctified in Christ by the grace of God, through the shedding of the blood of Christ, which is in the covenant of the Father unto the remission of your sins, that ye become holy, without spot.
37706	1428	34	And now I bid unto all, farewell. I soon go to rest in the paradise of God, until my spirit and body shall again reunite, and I am brought forth triumphant through the air, to meet you before the pleasing bar of the great Jehovah, the Eternal Judge of both quick and dead. Amen.
37707	1429	1	HEARKEN, O ye people of my church, saith the voice of him who dwells on high, and whose eyes are upon all men; yea, verily I say: Hearken ye people from afar; and ye that are upon the islands of the sea, listen together.
37708	1429	2	For verily the voice of the Lord is unto all men, and there is none to escape; and there is no eye that shall not see, neither ear that shall not hear, neither heart that shall not be penetrated.
37709	1429	3	And the rebellious shall be pierced with much sorrow; for their iniquities shall be spoken upon the housetops, and their secret acts shall be revealed.
37710	1429	4	And the voice of warning shall be unto all people, by the mouths of my disciples, whom I have chosen in these last days.
37711	1429	5	And they shall go forth and none shall stay them, for I the Lord have commanded them.
37712	1429	6	Behold, this is mine authority, and the authority of my servants, and my preface unto the book of my commandments, which I have given them to publish unto you, O inhabitants of the earth.
37713	1429	7	Wherefore, fear and tremble, O ye people, for what I the Lord have decreed in them shall be fulfilled.
37714	1429	8	And verily I say unto you, that they who go forth, bearing these tidings unto the inhabitants of the earth, to them is power given to seal both on earth and in heaven, the unbelieving and rebellious;
37715	1429	9	Yea, verily, to seal them up unto the day when the wrath of God shall be poured out upon the wicked without measure--
37716	1429	10	Unto the day when the Lord shall come to recompense unto every man according to his work, and measure to every man according to the measure which he has measured to his fellow man.
37717	1429	11	Wherefore the voice of the Lord is unto the ends of the earth, that all that will hear may hear:
37718	1429	12	Prepare ye, prepare ye for that which is to come, for the Lord is nigh;
37719	1429	13	And the anger of the Lord is kindled, and his sword is bathed in heaven, and it shall fall upon the inhabitants of the earth.
37720	1429	14	And the arm of the Lord shall be revealed; and the day cometh that they who will not hear the voice of the Lord, neither the voice of his servants, neither give heed to the words of the prophets and apostles, shall be cut off from among the people;
37721	1429	15	For they have strayed from mine ordinances, and have broken mine everlasting covenant;
37722	1429	16	They seek not the Lord to establish his righteousness, but every man walketh in his own way, and after the image of his own god, whose image is in the likeness of the world, and whose substance is that of an idol, which waxeth old and shall perish in Babylon, even Babylon the great, which shall fall.
37723	1429	17	Wherefore, I the Lord, knowing the calamity which should come upon the inhabitants of the earth, called upon my servant Joseph Smith, Jun., and spake unto him from heaven, and gave him commandments;
37724	1429	18	And also gave commandments to others, that they should proclaim these things unto the world; and all this that it might be fulfilled, which was written by the prophets--
37725	1429	19	The weak things of the world shall come forth and break down the mighty and strong ones, that man should not counsel his fellow man, neither trust in the arm of flesh--
37726	1429	20	But that every man might speak in the name of God the Lord, even the Savior of the world;
37727	1429	21	That faith also might increase in the earth;
37728	1429	22	That mine everlasting covenant might be established;
37729	1429	23	That the fulness of my gospel might be proclaimed by the weak and the simple unto the ends of the world, and before kings and rulers.
37730	1429	24	Behold, I am God and have spoken it; these commandments are of me, and were given unto my servants in their weakness, after the manner of their language, that they might come to understanding.
37731	1429	25	And inasmuch as they erred it might be made known;
37732	1429	26	And inasmuch as they sought wisdom they might be instructed;
37733	1429	27	And inasmuch as they sinned they might be chastened, that they might repent;
37734	1429	28	And inasmuch as they were humble they might be made strong, and blessed from on high, and receive knowledge from time to time.
37735	1429	29	And after having received the record of the Nephites, yea, even my servant Joseph Smith, Jun., might have power to translate through the mercy of God, by the power of God, the Book of Mormon.
37736	1429	30	And also those to whom these commandments were given, might have power to lay the foundation of this church, and to bring it forth out of obscurity and out of darkness, the only true and living church upon the face of the whole earth, with which I, the Lord, am well pleased, speaking unto the church collectively and not individually--
37737	1429	31	For I the Lord cannot look upon sin with the least degree of allowance;
37738	1429	32	Nevertheless, he that repents and does the commandments of the Lord shall be forgiven;
37739	1429	33	And he that repents not, from him shall be taken even the light which he has received; for my Spirit shall not always strive with man, saith the Lord of Hosts.
37740	1429	34	And again, verily I say unto you, O inhabitants of the earth: I the Lord am willing to make these things known unto all flesh;
37741	1429	35	For I am no respecter of persons, and will that all men shall know that the day speedily cometh; the hour is not yet, but is nigh at hand, when peace shall be taken from the earth, and the devil shall have power over his own dominion.
37742	1429	36	And also the Lord shall have power over his saints, and shall reign in their midst, and shall come down in judgment upon Idumea, or the world.
37743	1429	37	Search these commandments, for they are true and faithful, and the prophecies and promises which are in them shall all be fulfilled.
37744	1429	38	What I the Lord have spoken, I have spoken, and I excuse not myself; and though the heavens and the earth pass away, my word shall not pass away, but shall all be fulfilled, whether by mine own voice or by the voice of my servants, it is the same.
37745	1429	39	For behold, and lo, the Lord is God, and the Spirit beareth record, and the record is true, and the truth abideth forever and ever. Amen.
37746	1430	1	BEHOLD, I will reveal unto you the Priesthood, by the hand of Elijah the prophet, before the coming of the great and dreadful day of the Lord.
37747	1430	2	And he shall plant in the hearts of the children the promises made to the fathers, and the hearts of the children shall turn to their fathers.
37748	1430	3	If it were not so, the whole earth would be utterly wasted at his coming.
37749	1431	1	THE works, and the designs, and the purposes of God cannot be frustrated, neither can they come to naught.
37750	1431	2	For God doth not walk in crooked paths, neither doth he turn to the right hand nor to the left, neither doth he vary from that which he hath said, therefore his paths are straight, and his course is one eternal round.
37751	1431	3	Remember, remember that it is not the work of God that is frustrated, but the work of men;
37752	1431	4	For although a man may have many revelations, and have power to do many mighty works, yet if he boasts in his own strength, and sets at naught the counsels of God, and follows after the dictates of his own will and carnal desires, he must fall and incur the vengeance of a just God upon him.
37753	1431	5	Behold, you have been entrusted with these things, but how strict were your commandments; and remember also the promises which were made to you, if you did not transgress them.
37754	1431	6	And behold, how oft you have transgressed the commandments and the laws of God, and have gone on in the persuasions of men.
37755	1431	7	For, behold, you should not have feared man more than God. Although men set at naught the counsels of God, and despise his words--
37756	1431	8	Yet you should have been faithful; and he would have extended his arm and supported you against all the fiery darts of the adversary; and he would have been with you in every time of trouble.
37757	1431	9	Behold, thou art Joseph, and thou wast chosen to do the work of the Lord, but because of transgression, if thou art not aware thou wilt fall.
37758	1431	10	But remember, God is merciful; therefore, repent of that which thou hast done which is contrary to the commandment which I gave you, and thou art still chosen, and art again called to the work;
37759	1431	11	Except thou do this, thou shalt be delivered up and become as other men, and have no more gift.
37760	1431	12	And when thou deliveredst up that which God had given thee sight and power to translate, thou deliveredst up that which was sacred into the hands of a wicked man,
37761	1431	13	Who has set at naught the counsels of God, and has broken the most sacred promises which were made before God, and has depended upon his own judgment and boasted in his own wisdom.
37762	1431	14	And this is the reason that thou hast lost thy privileges for a season--
37763	1431	15	For thou hast suffered the counsel of thy director to be trampled upon from the beginning.
37764	1431	16	Nevertheless, my work shall go forth, for inasmuch as the knowledge of a Savior has come unto the world, through the testimony of the Jews, even so shall the knowledge of a Savior come unto my people--
37765	1431	17	And to the Nephites, and the Jacobites, and the Josephites, and the Zoramites, through the testimony of their fathers--
37766	1431	18	And this testimony shall come to the knowledge of the Lamanites, and the Lemuelites, and the Ishmaelites, who dwindled in unbelief because of the iniquity of their fathers, whom the Lord has suffered to destroy their brethren the Nephites, because of their iniquities and their abominations.
37767	1431	19	And for this very purpose are these plates preserved, which contain these records--that the promises of the Lord might be fulfilled, which he made to his people;
37768	1431	20	And that the Lamanites might come to the knowledge of their fathers, and that they might know the promises of the Lord, and that they may believe the gospel and rely upon the merits of Jesus Christ, and be glorified through faith in his name, and that through their repentance they might be saved. Amen.
37769	1432	1	NOW behold, a marvelous work is about to come forth among the children of men.
37770	1432	2	Therefore, O ye that embark in the service of God, see that ye serve him with all your heart, might, mind and strength, that ye may stand blameless before God at the last day.
37771	1432	3	Therefore, if ye have desires to serve God ye are called to the work;
37772	1432	4	For behold the field is white already to harvest; and lo, he that thrusteth in his sickle with his might, the same layeth up in store that he perisheth not, but bringeth salvation to his soul;
37773	1432	5	And faith, hope, charity and love, with an eye single to the glory of God, qualify him for the work.
37774	1432	6	Remember faith, virtue, knowledge, temperance, patience, brotherly kindness, godliness, charity, humility, diligence.
37775	1432	7	Ask, and ye shall receive; knock, and it shall be opened unto you. Amen.
37776	1433	1	BEHOLD, I say unto you, that as my servant Martin Harris has desired a witness at my hand, that you, my servant Joseph Smith, Jun., have got the plates of which you have testified and borne record that you have received of me;
37777	1433	2	And now, behold, this shall you say unto him--he who spake unto you, said unto you: I, the Lord, am God, and have given these things unto you, my servant Joseph Smith, Jun., and have commanded you that you should stand as a witness of these things;
37778	1433	3	And I have caused you that you should enter into a covenant with me, that you should not show them except to those persons to whom I commanded you; and you have no power over them except I grant it unto you.
37779	1433	4	And you have a gift to translate the plates; and this is the first gift that I bestowed upon you; and I have commanded that you should pretend to no other gift until my purpose is fulfilled in this; for I will grant unto you no other gift until it is finished.
37780	1433	5	Verily, I say unto you, that woe shall come unto the inhabitants of the earth if they will not hearken unto my words;
37781	1433	6	For hereafter you shall be ordained and go forth and deliver my words unto the children of men.
37782	1433	7	Behold, if they will not believe my words, they would not believe you, my servant Joseph, if it were possible that you should show them all these things which I have committed unto you.
37783	1433	8	Oh, this unbelieving and stiffnecked generation--mine anger is kindled against them.
37784	1433	9	Behold, verily I say unto you, I have reserved those things which I have entrusted unto you, my servant Joseph, for a wise purpose in me, and it shall be made known unto future generations;
37785	1433	10	But this generation shall have my word through you;
37786	1433	11	And in addition to your testimony, the testimony of three of my servants, whom I shall call and ordain, unto whom I will show these things, and they shall go forth with my words that are given through you.
37787	1433	12	Yea, they shall know of a surety that these things are true, for from heaven will I declare it unto them.
37788	1433	13	I will give them power that they may behold and view these things as they are;
37789	1433	14	And to none else will I grant this power, to receive this same testimony among this generation, in this the beginning of the rising up and the coming forth of my church out of the wilderness--clear as the moon, and fair as the sun, and terrible as an army with banners.
37790	1433	15	And the testimony of three witnesses will I send forth of my word.
37791	1433	16	And behold, whosoever believeth on my words, them will I visit with the manifestation of my Spirit; and they shall be born of me, even of water and of the Spirit--
37792	1433	17	And you must wait yet a little while, for ye are not yet ordained--
37793	1433	18	And their testimony shall also go forth unto the condemnation of this generation if they harden their hearts against them;
37794	1433	19	For a desolating scourge shall go forth among the inhabitants of the earth, and shall continue to be poured out from time to time, if they repent not, until the earth is empty, and the inhabitants thereof are consumed away and utterly destroyed by the brightness of my coming.
37795	1433	20	Behold, I tell you these things, even as I also told the people of the destruction of Jerusalem; and my word shall be verified at this time as it hath hitherto been verified.
37796	1433	21	And now I command you, my servant Joseph, to repent and walk more uprightly before me, and to yield to the persuasions of men no more;
37797	1433	22	And that you be firm in keeping the commandments wherewith I have commanded you; and if you do this, behold I grant unto you eternal life, even if you should be slain.
37798	1433	23	And now, again, I speak unto you, my servant Joseph, concerning the man that desires the witness--
37799	1433	24	Behold, I say unto him, he exalts himself and does not humble himself sufficiently before me; but if he will bow down before me, and humble himself in mighty prayer and faith, in the sincerity of his heart, then will I grant unto him a view of the things which he desires to see.
37800	1433	25	And then he shall say unto the people of this generation: Behold, I have seen the things which the Lord hath shown unto Joseph Smith, Jun., and I know of a surety that they are true, for I have seen them, for they have been shown unto me by the power of God and not of man.
37801	1433	26	And I the Lord command him, my servant Martin Harris, that he shall say no more unto them concerning these things, except he shall say: I have seen them, and they have been shown unto me by the power of God; and these are the words which he shall say.
37802	1433	27	But if he deny this he will break the covenant which he has before covenanted with me, and behold, he is condemned.
37803	1433	28	And now, except he humble himself and acknowledge unto me the things that he has done which are wrong, and covenant with me that he will keep my commandments, and exercise faith in me, behold, I say unto him, he shall have no such views, for I will grant unto him no views of the things of which I have spoken.
37804	1433	29	And if this be the case, I command you, my servant Joseph, that you shall say unto him, that he shall do no more, nor trouble me any more concerning this matter.
37805	1433	30	And if this be the case, behold, I say unto thee Joseph, when thou hast translated a few more pages thou shalt stop for a season, even until I command thee again; then thou mayest translate again.
37806	1433	31	And except thou do this, behold, thou shalt have no more gift, and I will take away the things which I have entrusted with thee.
37807	1433	32	And now, because I foresee the lying in wait to destroy thee, yea, I foresee that if my servant Martin Harris humbleth not himself and receive a witness from my hand, that he will fall into transgression;
37808	1433	33	And there are many that lie in wait to destroy thee from off the face of the earth; and for this cause, that thy days may be prolonged, I have given unto thee these commandments.
37809	1433	34	Yea, for this cause I have said: Stop, and stand still until I command thee, and I will provide means whereby thou mayest accomplish the thing which I have commanded thee.
37810	1433	35	And if thou art faithful in keeping my commandments, thou shalt be lifted up at the last day. Amen.
37811	1434	1	A GREAT and marvelous work is about to come forth unto the children of men.
37812	1434	2	Behold, I am God; give heed unto my word, which is quick and powerful, sharper than a two-edged sword, to the dividing asunder of both joints and marrow; therefore give heed unto my words.
37813	1434	3	Behold, the field is white already to harvest; therefore, whoso desireth to reap, let him thrust in his sickle with his might, and reap while the day lasts, that he may treasure up for his soul everlasting salvation in the kingdom of God.
37814	1434	4	Yea, whosoever will thrust in his sickle and reap, the same is called of God.
37815	1434	5	Therefore, if you will ask of me you shall receive; if you will knock it shall be opened unto you.
37816	1434	6	Now, as you have asked, behold, I say unto you, keep my commandments, and seek to bring forth and establish the cause of Zion;
37817	1434	7	Seek not for riches but for wisdom, and behold, the mysteries of God shall be unfolded unto you, and then shall you be made rich. Behold, he that hath eternal life is rich.
37818	1434	8	Verily, verily, I say unto you, even as you desire of me so it shall be unto you; and if you desire, you shall be the means of doing much good in this generation.
37819	1434	9	Say nothing but repentance unto this generation; keep my commandments, and assist to bring forth my work, according to my commandments, and you shall be blessed.
37820	1434	10	Behold thou hast a gift, and blessed art thou because of thy gift. Remember it is sacred and cometh from above--
37821	1434	11	And if thou wilt inquire, thou shalt know mysteries which are great and marvelous; therefore thou shalt exercise thy gift, that thou mayest find out mysteries, that thou mayest bring many to the knowledge of the truth, yea, convince them of the error of their ways.
37822	1434	12	Make not thy gift known unto any save it be those who are of thy faith. Trifle not with sacred things.
37823	1434	13	If thou wilt do good, yea, and hold out faithful to the end, thou shalt be saved in the kingdom of God, which is the greatest of all the gifts of God; for there is no gift greater than the gift of salvation.
37824	1434	14	Verily, verily, I say unto thee, blessed art thou for what thou hast done; for thou hast inquired of me, and behold, as often as thou hast inquired thou hast received instruction of my Spirit. If it had not been so, thou wouldst not have come to the place where thou art at this time.
37825	1434	15	Behold, thou knowest that thou hast inquired of me and I did enlighten thy mind; and now I tell thee these things that thou mayest know that thou hast been enlightened by the Spirit of truth;
37826	1434	16	Yea, I tell thee, that thou mayest know that there is none else save God that knowest thy thoughts and the intents of thy heart.
37827	1434	17	I tell thee these things as a witness unto thee--that the words or the work which thou hast been writing are true.
37828	1434	18	Therefore be diligent; stand by my servant Joseph, faithfully, in whatsoever difficult circumstances he may be for the word's sake.
37829	1434	19	Admonish him in his faults, and also receive admonition of him. Be patient; be sober; be temperate; have patience, faith, hope and charity.
37830	1434	20	Behold, thou art Oliver, and I have spoken unto thee because of thy desires; therefore treasure up these words in thy heart. Be faithful and diligent in keeping the commandments of God, and I will encircle thee in the arms of my love.
37831	1434	21	Behold, I am Jesus Christ, the Son of God. I am the same that came unto mine own, and mine own received me not. I am the light which shineth in darkness, and the darkness comprehendeth it not.
37832	1434	22	Verily, verily, I say unto you, if you desire a further witness, cast your mind upon the night that you cried unto me in your heart, that you might know concerning the truth of these things.
37833	1434	23	Did I not speak peace to your mind concerning the matter? What greater witness can you have than from God?
37834	1434	24	And now, behold, you have received a witness; for if I have told you things which no man knoweth have you not received a witness?
37835	1434	25	And, behold, I grant unto you a gift, if you desire of me, to translate, even as my servant Joseph.
37836	1434	26	Verily, verily, I say unto you, that there are records which contain much of my gospel, which have been kept back because of the wickedness of the people;
37837	1434	27	And now I command you, that if you have good desires--a desire to lay up treasures for yourself in heaven--then shall you assist in bringing to light, with your gift, those parts of my scriptures which have been hidden because of iniquity.
37838	1434	28	And now, behold, I give unto you, and also unto my servant Joseph, the keys of this gift, which shall bring to light this ministry; and in the mouth of two or three witnesses shall every word be established.
37839	1434	29	Verily, verily, I say unto you, if they reject my words, and this part of my gospel and ministry, blessed are ye, for they can do no more unto you than unto me.
37840	1434	30	And even if they do unto you even as they have done unto me, blessed are ye, for you shall dwell with me in glory.
37841	1434	31	But if they reject not my words, which shall be established by the testimony which shall be given, blessed are they, and then shall ye have joy in the fruit of your labors.
37842	1434	32	Verily, verily, I say unto you, as I said unto my disciples, where two or three are gathered together in my name, as touching one thing, behold, there will I be in the midst of them--even so am I in the midst of you.
37843	1434	33	Fear not to do good, my sons, for whatsoever ye sow, that shall ye also reap; therefore, if ye sow good ye shall also reap good for your reward.
37844	1434	34	Therefore, fear not, little flock; do good; let earth and hell combine against you, for if ye are built upon my rock, they cannot prevail.
37845	1434	35	Behold, I do not condemn you; go your ways and sin no more; perform with soberness the work which I have commanded you.
37846	1434	36	Look unto me in every thought; doubt not, fear not.
37847	1434	37	Behold the wounds which pierced my side, and also the prints of the nails in my hands and feet; be faithful, keep my commandments, and ye shall inherit the kingdom of heaven. Amen.
37848	1435	1	AND the Lord said unto me: John, my beloved, what desirest thou? For if you shall ask what you will, it shall be granted unto you.
37849	1435	2	And I said unto him: Lord, give unto me power over death, that I may live and bring souls unto thee.
37850	1435	3	And the Lord said unto me: Verily, verily, I say unto thee, because thou desirest this thou shalt tarry until I come in my glory, and shalt prophesy before nations, kindreds, tongues and people.
37851	1435	4	And for this cause the Lord said unto Peter: If I will that he tarry till I come, what is that to thee? For he desired of me that he might bring souls unto me, but thou desiredst that thou mightest speedily come unto me in my kingdom.
37852	1435	5	I say unto thee, Peter, this was a good desire; but my beloved has desired that he might do more, or a greater work yet among men than what he has before done.
37853	1435	6	Yea, he has undertaken a greater work; therefore I will make him as flaming fire and a ministering angel; he shall minister for those who shall be heirs of salvation who dwell on the earth.
37854	1435	7	And I will make thee to minister for him and for thy brother James; and unto you three I will give this power and the keys of this ministry until I come.
37855	1435	8	Verily I say unto you, ye shall both have according to your desires, for ye both joy in that which ye have desired.
37856	1436	1	OLIVER Cowdery, verily, verily, I say unto you, that assuredly as the Lord liveth, who is your God and your Redeemer, even so surely shall you receive a knowledge of whatsoever things you shall ask in faith, with an honest heart, believing that you shall receive a knowledge concerning the engravings of old records, which are ancient, which contain those parts of my scripture of which has been spoken by the manifestation of my Spirit.
37857	1436	2	Yea, behold, I will tell you in your mind and in your heart, by the Holy Ghost, which shall come upon you and which shall dwell in your heart.
37858	1436	3	Now, behold, this is the spirit of revelation; behold, this is the spirit by which Moses brought the children of Israel through the Red Sea on dry ground.
37859	1436	4	Therefore this is thy gift; apply unto it, and blessed art thou, for it shall deliver you out of the hands of your enemies, when, if it were not so, they would slay you and bring your soul to destruction.
37860	1436	5	Oh, remember these words, and keep my commandments. Remember, this is your gift.
37861	1436	6	Now this is not all thy gift; for you have another gift, which is the gift of Aaron; behold, it has told you many things;
37862	1436	7	Behold, there is no other power, save the power of God, that can cause this gift of Aaron to be with you.
37863	1436	8	Therefore, doubt not, for it is the gift of God; and you shall hold it in your hands, and do marvelous works; and no power shall be able to take it away out of your hands, for it is the work of God.
37864	1436	9	And, therefore, whatsoever you shall ask me to tell you by that means, that will I grant unto you, and you shall have knowledge concerning it.
37865	1436	10	Remember that without faith you can do nothing; therefore ask in faith. Trifle not with these things; do not ask for that which you ought not.
37866	1436	11	Ask that you may know the mysteries of God, and that you may translate and receive knowledge from all those ancient records which have been hid up, that are sacred; and according to your faith shall it be done unto you.
37867	1436	12	Behold, it is I that have spoken it; and I am the same that spake unto you from the beginning. Amen.
37868	1437	1	BEHOLD, I say unto you, my son, that because you did not translate according to that which you desired of me, and did commence again to write for my servant, Joseph Smith, Jun., even so I would that ye should continue until you have finished this record, which I have entrusted unto him.
37869	1437	2	And then, behold, other records have I, that I will give unto you power that you may assist to translate.
37870	1437	3	Be patient, my son, for it is wisdom in me, and it is not expedient that you should translate at this present time.
37871	1437	4	Behold, the work which you are called to do is to write for my servant Joseph.
37872	1437	5	And, behold, it is because that you did not continue as you commenced, when you began to translate, that I have taken away this privilege from you.
37873	1437	6	Do not murmur, my son, for it is wisdom in me that I have dealt with you after this manner.
37874	1437	7	Behold, you have not understood; you have supposed that I would give it unto you, when you took no thought save it was to ask me.
37875	1437	8	But, behold, I say unto you, that you must study it out in your mind; then you must ask me if it be right, and if it is right I will cause that your bosom shall burn within you; therefore, you shall feel that it is right.
37876	1437	9	But if it be not right you shall have no such feelings, but you shall have a stupor of thought that shall cause you to forget the thing which is wrong; therefore, you cannot write that which is sacred save it be given you from me.
37877	1437	10	Now, if you had known this you could have translated; nevertheless, it is not expedient that you should translate now.
37878	1437	11	Behold, it was expedient when you commenced; but you feared, and the time is past, and it is not expedient now;
37879	1437	12	For, do you not behold that I have given unto my servant Joseph sufficient strength, whereby it is made up? And neither of you have I condemned.
37880	1437	13	Do this thing which I have commanded you, and you shall prosper. Be faithful, and yield to no temptation.
37881	1437	14	Stand fast in the work wherewith I have called you, and a hair of your head shall not be lost, and you shall be lifted up at the last day. Amen.
37882	1438	1	NOW, behold, I say unto you, that because you delivered up those writings which you had power given unto you to translate by the means of the Urim and Thummim, into the hands of a wicked man, you have lost them.
37883	1438	2	And you also lost your gift at the same time, and your mind became darkened.
37884	1438	3	Nevertheless, it is now restored unto you again; therefore see that you are faithful and continue on unto the finishing of the remainder of the work of translation as you have begun.
37885	1438	4	Do not run faster or labor more than you have strength and means provided to enable you to translate; but be diligent unto the end.
37886	1438	5	Pray always, that you may come off conqueror; yea, that you may conquer Satan, and that you may escape the hands of the servants of Satan that do uphold his work.
37887	1438	6	Behold, they have sought to destroy you; yea, even the man in whom you have trusted has sought to destroy you.
37888	1438	7	And for this cause I said that he is a wicked man, for he has sought to take away the things wherewith you have been entrusted; and he has also sought to destroy your gift.
37889	1438	8	And because you have delivered the writings into his hands, behold, wicked men have taken them from you.
37890	1438	9	Therefore, you have delivered them up, yea, that which was sacred, unto wickedness.
37891	1438	10	And, behold, Satan hath put it into their hearts to alter the words which you have caused to be written, or which you have translated, which have gone out of your hands.
37892	1438	11	And behold, I say unto you, that because they have altered the words, they read contrary from that which you translated and caused to be written;
37893	1438	12	And, on this wise, the devil has sought to lay a cunning plan, that he may destroy this work;
37894	1438	13	For he hath put into their hearts to do this, that by lying they may say they have caught you in the words which you have pretended to translate.
37895	1438	14	Verily, I say unto you, that I will not suffer that Satan shall accomplish his evil design in this thing.
37896	1438	15	For behold, he has put it into their hearts to get thee to tempt the Lord thy God, in asking to translate it over again.
37897	1438	16	And then, behold, they say and think in their hearts--We will see if God has given him power to translate; if so, he will also give him power again;
37898	1438	17	And if God giveth him power again, or if he translates again, or, in other words, if he bringeth forth the same words, behold, we have the same with us, and we have altered them;
37899	1438	18	Therefore they will not agree, and we will say that he has lied in his words, and that he has no gift, and that he has no power;
37900	1438	19	Therefore we will destroy him, and also the work; and we will do this that we may not be ashamed in the end, and that we may get glory of the world.
37901	1438	20	Verily, verily, I say unto you, that Satan has great hold upon their hearts; he stirreth them up to iniquity against that which is good;
37902	1438	21	And their hearts are corrupt, and full of wickedness and abominations; and they love darkness rather than light, because their deeds are evil; therefore they will not ask of me.
37903	1438	22	Satan stirreth them up, that he may lead their souls to destruction.
37904	1438	23	And thus he has laid a cunning plan, thinking to destroy the work of God; but I will require this at their hands, and it shall turn to their shame and condemnation in the day of judgment.
37905	1438	24	Yea, he stirreth up their hearts to anger against this work.
37906	1438	25	Yea, he saith unto them: Deceive and lie in wait to catch, that ye may destroy; behold, this is no harm. And thus he flattereth them, and telleth them that it is no sin to lie that they may catch a man in a lie, that they may destroy him.
37907	1438	26	And thus he flattereth them, and leadeth them along until he draggeth their souls down to hell; and thus he causeth them to catch themselves in their own snare.
37908	1438	27	And thus he goeth up and down, to and fro in the earth, seeking to destroy the souls of men.
37909	1438	28	Verily, verily, I say unto you, wo be unto him that lieth to deceive because he supposeth that another lieth to deceive, for such are not exempt from the justice of God.
37910	1438	29	Now, behold, they have altered these words, because Satan saith unto them: He hath deceived you--and thus he flattereth them away to do iniquity, to get thee to tempt the Lord thy God.
37911	1438	30	Behold, I say unto you, that you shall not translate again those words which have gone forth out of your hands;
37912	1438	31	For, behold, they shall not accomplish their evil designs in lying against those words. For, behold, if you should bring forth the same words they will say that you have lied and that you have pretended to translate, but that you have contradicted yourself.
37913	1438	32	And, behold, they will publish this, and Satan will harden the hearts of the people to stir them up to anger against you, that they will not believe my words.
37914	1438	33	Thus Satan thinketh to overpower your testimony in this generation, that the work may not come forth in this generation.
37915	1438	34	But behold, here is wisdom, and because I show unto you wisdom, and give you commandments concerning these things, what you shall do, show it not unto the world until you have accomplished the work of translation.
37916	1438	35	Marvel not that I said unto you: Here is wisdom, show it not unto the world--for I said, show it not unto the world, that you may be preserved.
37917	1438	36	Behold, I do not say that you shall not show it unto the righteous;
37918	1438	37	But as you cannot always judge the righteous, or as you cannot always tell the wicked from the righteous, therefore I say unto you, hold your peace until I shall see fit to make all things known unto the world concerning the matter.
37919	1438	38	And now, verily I say unto you, that an account of those things that you have written, which have gone out of your hands, is engraven upon the plates of Nephi;
37920	1438	39	Yea, and you remember it was said in those writings that a more particular account was given of these things upon the plates of Nephi.
37921	1438	40	And now, because the account which is engraven upon the plates of Nephi is more particular concerning the things which, in my wisdom, I would bring to the knowledge of the people in this account--
37922	1438	41	Therefore, you shall translate the engravings which are on the plates of Nephi, down even till you come to the reign of king Benjamin, or until you come to that which you have translated, which you have retained;
37923	1438	42	And behold, you shall publish it as the record of Nephi; and thus I will confound those who have altered my words.
37924	1438	43	I will not suffer that they shall destroy my work; yea, I will show unto them that my wisdom is greater than the cunning of the devil.
37925	1438	44	Behold, they have only got a part, or an abridgment of the account of Nephi.
37926	1438	45	Behold, there are many things engraven upon the plates of Nephi which do throw greater views upon my gospel; therefore, it is wisdom in me that you should translate this first part of the engravings of Nephi, and send forth in this work.
37927	1438	46	And, behold, all the remainder of this work does contain all those parts of my gospel which my holy prophets, yea, and also my disciples, desired in their prayers should come forth unto this people.
37928	1438	47	And I said unto them, that it should be granted unto them according to their faith in their prayers;
37929	1438	48	Yea, and this was their faith--that my gospel, which I gave unto them that they might preach in their days, might come unto their brethren the Lamanites, and also all that had become Lamanites because of their dissensions.
37930	1438	49	Now, this is not all--their faith in their prayers was that this gospel should be made known also, if it were possible that other nations should possess this land;
37931	1438	50	And thus they did leave a blessing upon this land in their prayers, that whosoever should believe in this gospel in this land might have eternal life;
37932	1438	51	Yea, that it might be free unto all of whatsoever nation, kindred, tongue, or people they may be.
37933	1438	52	And now, behold, according to their faith in their prayers will I bring this part of my gospel to the knowledge of my people. Behold, I do not bring it to destroy that which they have received, but to build it up.
37934	1438	53	And for this cause have I said: If this generation harden not their hearts, I will establish my church among them.
37935	1438	54	Now I do not say this to destroy my church, but I say this to build up my church;
37936	1438	55	Therefore, whosoever belongeth to my church need not fear, for such shall inherit the kingdom of heaven.
37937	1438	56	But it is they who do not fear me, neither keep my commandments but build up churches unto themselves to get gain, yea, and all those that do wickedly and build up the kingdom of the devil--yea, verily, verily, I say unto you, that it is they that I will disturb, and cause to tremble and shake to the center.
37938	1438	57	Behold, I am Jesus Christ, the Son of God. I came unto mine own, and mine own received me not.
37939	1438	58	I am the light which shineth in darkness, and the darkness comprehendeth it not.
37940	1438	59	I am he who said--Other sheep have I which are not of this fold--unto my disciples, and many there were that understood me not.
37941	1438	60	And I will show unto this people that I had other sheep, and that they were a branch of the house of Jacob;
37942	1438	61	And I will bring to light their marvelous works, which they did in my name;
37943	1438	62	Yea, and I will also bring to light my gospel which was ministered unto them, and, behold, they shall not deny that which you have received, but they shall build it up, and shall bring to light the true points of my doctrine, yea, and the only doctrine which is in me.
37944	1438	63	And this I do that I may establish my gospel, that there may not be so much contention; yea, Satan doth stir up the hearts of the people to contention concerning the points of my doctrine; and in these things they do err, for they do wrest the scriptures and do not understand them.
37945	1438	64	Therefore, I will unfold unto them this great mystery;
37946	1438	65	For, behold, I will gather them as a hen gathereth her chickens under her wings, if they will not harden their hearts;
37947	1438	66	Yea, if they will come, they may, and partake of the waters of life freely.
37948	1438	67	Behold, this is my doctrine--whosoever repenteth and cometh unto me, the same is my church.
37949	1438	68	Whosoever declareth more or less than this, the same is not of me, but is against me; therefore he is not of my church.
37950	1438	69	And now, behold, whosoever is of my church, and endureth of my church to the end, him will I establish upon my rock, and the gates of hell shall not prevail against them.
37951	1438	70	And now, remember the words of him who is the life and light of the world, your Redeemer, your Lord and your God. Amen.
37952	1439	1	A GREAT and marvelous work is about to come forth among the children of men.
37953	1439	2	Behold, I am God; give heed to my word, which is quick and powerful, sharper than a two-edged sword, to the dividing asunder of both joints and marrow; therefore give heed unto my word.
37954	1439	3	Behold, the field is white already to harvest; therefore, whoso desireth to reap let him thrust in his sickle with his might, and reap while the day lasts, that he may treasure up for his soul everlasting salvation in the kingdom of God.
37955	1439	4	Yea, whosoever will thrust in his sickle and reap, the same is called of God.
37956	1439	5	Therefore, if you will ask of me you shall receive; if you will knock it shall be opened unto you.
37957	1439	6	Now, as you have asked, behold, I say unto you, keep my commandments, and seek to bring forth and establish the cause of Zion.
37958	1439	7	Seek not for riches but for wisdom; and, behold, the mysteries of God shall be unfolded unto you, and then shall you be made rich. Behold, he that hath eternal life is rich.
37959	1439	8	Verily, verily, I say unto you, even as you desire of me so it shall be done unto you; and, if you desire, you shall be the means of doing much good in this generation.
37960	1439	9	Say nothing but repentance unto this generation. Keep my commandments, and assist to bring forth my work, according to my commandments, and you shall be blessed.
37961	1439	10	Behold, thou hast a gift, or thou shalt have a gift if thou wilt desire of me in faith, with an honest heart, believing in the power of Jesus Christ, or in my power which speaketh unto thee;
37962	1439	11	For, behold, it is I that speak; behold, I am the light which shineth in darkness, and by my power I give these words unto thee.
37963	1439	12	And now, verily, verily, I say unto thee, put your trust in that Spirit which leadeth to do good--yea, to do justly, to walk humbly, to judge righteously; and this is my Spirit.
37964	1439	13	Verily, verily, I say unto you, I will impart unto you of my Spirit, which shall enlighten your mind, which shall fill your soul with joy;
37965	1439	14	And then shall ye know, or by this shall you know, all things whatsoever you desire of me, which are pertaining unto things of righteousness, in faith believing in me that you shall receive.
37966	1439	15	Behold, I command you that you need not suppose that you are called to preach until you are called.
37967	1439	16	Wait a little longer, until you shall have my word, my rock, my church, and my gospel, that you may know of a surety my doctrine.
37968	1439	17	And then, behold, according to your desires, yea, even according to your faith shall it be done unto you.
37969	1439	18	Keep my commandments; hold your peace; appeal unto my Spirit;
37970	1439	19	Yea, cleave unto me with all your heart, that you may assist in bringing to light those things of which has been spoken--yea, the translation of my work; be patient until you shall accomplish it.
37971	1439	20	Behold, this is your work, to keep my commandments, yea, with all your might, mind and strength.
37972	1439	21	Seek not to declare my word, but first seek to obtain my word, and then shall your tongue be loosed; then, if you desire, you shall have my Spirit and my word, yea, the power of God unto the convincing of men.
37973	1439	22	But now hold your peace; study my word which hath gone forth among the children of men, and also study my word which shall come forth among the children of men, or that which is now translating, yea, until you have obtained all which I shall grant unto the children of men in this generation, and then shall all things be added thereto.
37974	1439	23	Behold thou art Hyrum, my son; seek the kingdom of God, and all things shall be added according to that which is just.
37975	1439	24	Build upon my rock, which is my gospel;
37976	1439	25	Deny not the spirit of revelation, nor the spirit of prophecy, for wo unto him that denieth these things;
37977	1439	26	Therefore, treasure up in your heart until the time which is in my wisdom that you shall go forth.
37978	1439	27	Behold, I speak unto all who have good desires, and have thrust in their sickle to reap.
37979	1439	28	Behold, I am Jesus Christ, the Son of God. I am the life and the light of the world.
37980	1439	29	I am the same who came unto mine own and mine own received me not;
37981	1439	30	But verily, verily, I say unto you, that as many as receive me, to them will I give power to become the sons of God, even to them that believe on my name. Amen.
37982	1440	1	A GREAT and marvelous work is about to come forth among the children of men.
37983	1440	2	Behold, I am God; give heed to my word, which is quick and powerful, sharper than a two-edged sword, to the dividing asunder of both joints and marrow; therefore, give heed unto my word.
37984	1440	3	Behold, the field is white already to harvest; therefore, whoso desireth to reap let him thrust in his sickle with his might, and reap while the day lasts, that he may treasure up for his soul everlasting salvation in the kingdom of God.
37985	1440	4	Yea, whosoever will thrust in his sickle and reap, the same is called of God.
37986	1440	5	Therefore, if you will ask of me you shall receive; if you will knock it shall be opened unto you.
37987	1440	6	Now, as you have asked, behold, I say unto you, keep my commandments, and seek to bring forth and establish the cause of Zion.
37988	1440	7	Behold, I speak unto you, and also to all those who have desires to bring forth and establish this work;
37989	1440	8	And no one can assist in this work except he shall be humble and full of love, having faith, hope, and charity, being temperate in all things, whatsoever shall be entrusted to his care.
37990	1440	9	Behold, I am the light and the life of the world, that speak these words, therefore give heed with your might, and then you are called. Amen.
37991	1441	1	UPON you my fellow servants, in the name of Messiah I confer the Priesthood of Aaron, which holds the keys of the ministering of angels, and of the gospel of repentance, and of baptism by immersion for the remission of sins; and this shall never be taken again from the earth, until the sons of Levi do offer again an offering unto the Lord in righteousness.
37992	1442	1	A GREAT and marvelous work is about to come forth unto the children of men.
37993	1442	2	Behold, I am God; give heed to my word, which is quick and powerful, sharper than a two-edged sword, to the dividing asunder of both joints and marrow; therefore give heed unto my word.
37994	1442	3	Behold, the field is white already to harvest; therefore, whoso desireth to reap let him thrust in his sickle with his might, and reap while the day lasts, that he may treasure up for his soul everlasting salvation in the kingdom of God.
37995	1442	4	Yea, whosoever will thrust in his sickle and reap, the same is called of God.
37996	1442	5	Therefore, if you will ask of me you shall receive; if you will knock it shall be opened unto you.
37997	1442	6	Seek to bring forth and establish my Zion. Keep my commandments in all things.
37998	1442	7	And, if you keep my commandments and endure to the end you shall have eternal life, which gift is the greatest of all the gifts of God.
37999	1442	8	And it shall come to pass, that if you shall ask the Father in my name, in faith believing, you shall receive the Holy Ghost, which giveth utterance, that you may stand as a witness of the things of which you shall both hear and see, and also that you may declare repentance unto this generation.
38000	1442	9	Behold, I am Jesus Christ, the Son of the living God, who created the heavens and the earth, a light which cannot be hid in darkness;
38001	1442	10	Wherefore, I must bring forth the fulness of my gospel from the Gentiles unto the house of Israel.
38002	1442	11	And behold, thou art David, and thou art called to assist; which thing if ye do, and are faithful, ye shall be blessed both spiritually and temporally, and great shall be your reward. Amen.
38003	1443	1	HEARKEN, my servant John, and listen to the words of Jesus Christ, your Lord and your Redeemer.
38004	1443	2	For behold, I speak unto you with sharpness and with power, for mine arm is over all the earth.
38005	1443	3	And I will tell you that which no man knoweth save me and thee alone--
38006	1443	4	For many times you have desired of me to know that which would be of the most worth unto you.
38007	1443	5	Behold, blessed are you for this thing, and for speaking my words which I have given you according to my commandments.
38008	1443	6	And now, behold, I say unto you, that the thing which will be of the most worth unto you will be to declare repentance unto this people, that you may bring souls unto me, that you may rest with them in the kingdom of my Father. Amen.
38009	1444	1	HEARKEN, my servant Peter, and listen to the words of Jesus Christ, your Lord and your Redeemer.
38010	1444	2	For behold, I speak unto you with sharpness and with power, for mine arm is over all the earth.
38011	1444	3	And I will tell you that which no man knoweth save me and thee alone--
38012	1444	4	For many times you have desired of me to know that which would be of the most worth unto you.
38013	1444	5	Behold, blessed are you for this thing, and for speaking my words which I have given unto you according to my commandments.
38014	1444	6	And now, behold, I say unto you, that the thing which will be of the most worth unto you will be to declare repentance unto this people, that you may bring souls unto me, that you may rest with them in the kingdom of my Father. Amen.
38015	1445	1	BEHOLD, I say unto you, that you must rely upon my word, which if you do with full purpose of heart, you shall have a view of the plates, and also of the breastplate, the sword of Laban, the Urim and Thummim, which were given to the brother of Jared upon the mount, when he talked with the Lord face to face, and the miraculous directors which were given to Lehi while in the wilderness, on the borders of the Red Sea.
38016	1445	2	And it is by your faith that you shall obtain a view of them, even by that faith which was had by the prophets of old.
38017	1445	3	And after that you have obtained faith, and have seen them with your eyes, you shall testify of them, by the power of God;
38018	1445	4	And this you shall do that my servant Joseph Smith, Jun., may not be destroyed, that I may bring about my righteous purposes unto the children of men in this work.
38019	1445	5	And ye shall testify that you have seen them, even as my servant Joseph Smith, Jun., has seen them; for it is by my power that he has seen them, and it is because he had faith.
38020	1445	6	And he has translated the book, even that part which I have commanded him, and as your Lord and your God liveth it is true.
38021	1445	7	Wherefore, you have received the same power, and the same faith, and the same gift like unto him;
38022	1445	8	And if you do these last commandments of mine, which I have given you, the gates of hell shall not prevail against you; for my grace is sufficient for you, and you shall be lifted up at the last day.
38023	1445	9	And I, Jesus Christ, your Lord and your God, have spoken it unto you, that I might bring about my righteous purposes unto the children of men. Amen.
38024	1446	1	NOW, behold, because of the thing which you, my servant Oliver Cowdery, have desired to know of me, I give unto you these words:
38025	1446	2	Behold, I have manifested unto you, by my Spirit in many instances, that the things which you have written are true; wherefore you know that they are true.
38026	1446	3	And if you know that they are true, behold, I give unto you a commandment, that you rely upon the things which are written;
38027	1446	4	For in them are all things written concerning the foundation of my church, my gospel, and my rock.
38028	1446	5	Wherefore, if you shall build up my church, upon the foundation of my gospel and my rock, the gates of hell shall not prevail against you.
38029	1446	6	Behold, the world is ripening in iniquity; and it must needs be that the children of men are stirred up unto repentance, both the Gentiles and also the house of Israel.
38030	1446	7	Wherefore, as thou hast been baptized by the hands of my servant Joseph Smith, Jun., according to that which I have commanded him, he hath fulfilled the thing which I commanded him.
38031	1446	8	And now, marvel not that I have called him unto mine own purpose, which purpose is known in me; wherefore, if he shall be diligent in keeping my commandments he shall be blessed unto eternal life; and his name is Joseph.
38032	1446	9	And now, Oliver Cowdery, I speak unto you, and also unto David Whitmer, by the way of commandment; for, behold, I command all men everywhere to repent, and I speak unto you, even as unto Paul mine apostle, for you are called even with that same calling with which he was called.
38033	1446	10	Remember the worth of souls is great in the sight of God;
38034	1446	11	For, behold, the Lord your Redeemer suffered death in the flesh; wherefore he suffered the pain of all men, that all men might repent and come unto him.
38035	1446	12	And he hath risen again from the dead, that he might bring all men unto him, on conditions of repentance.
38036	1446	13	And how great is his joy in the soul that repenteth!
38037	1446	14	Wherefore, you are called to cry repentance unto this people.
38038	1446	15	And if it so be that you should labor all your days in crying repentance unto this people, and bring, save it be one soul unto me, how great shall be your joy with him in the kingdom of my Father!
38039	1446	16	And now, if your joy will be great with one soul that you have brought unto me into the kingdom of my Father, how great will be your joy if you should bring many souls unto me!
38040	1446	17	Behold, you have my gospel before you, and my rock, and my salvation.
38041	1446	18	Ask the Father in my name, in faith believing that you shall receive, and you shall have the Holy Ghost, which manifesteth all things which are expedient unto the children of men.
38042	1446	19	And if you have not faith, hope, and charity, you can do nothing.
38043	1446	20	Contend against no church, save it be the church of the devil.
38044	1446	21	Take upon you the name of Christ, and speak the truth in soberness.
38045	1446	22	And as many as repent and are baptized in my name, which is Jesus Christ, and endure to the end, the same shall be saved.
38046	1446	23	Behold, Jesus Christ is the name which is given of the Father, and there is none other name given whereby man can be saved;
38047	1446	24	Wherefore, all men must take upon them the name which is given of the Father, for in that name shall they be called at the last day;
38048	1446	25	Wherefore, if they know not the name by which they are called, they cannot have place in the kingdom of my Father.
38049	1446	26	And now, behold, there are others who are called to declare my gospel, both unto Gentile and unto Jew;
38050	1446	27	Yea, even twelve; and the Twelve shall be my disciples, and they shall take upon them my name; and the Twelve are they who shall desire to take upon them my name with full purpose of heart.
38051	1446	28	And if they desire to take upon them my name with full purpose of heart, they are called to go into all the world to preach my gospel unto every creature.
38052	1446	29	And they are they who are ordained of me to baptize in my name, according to that which is written;
38053	1446	30	And you have that which is written before you; wherefore, you must perform it according to the words which are written.
38054	1446	31	And now I speak unto you, the Twelve--Behold, my grace is sufficient for you; you must walk uprightly before me and sin not.
38055	1446	32	And, behold, you are they who are ordained of me to ordain priests and teachers; to declare my gospel, according to the power of the Holy Ghost which is in you, and according to the callings and gifts of God unto men;
38056	1446	33	And I, Jesus Christ, your Lord and your God, have spoken it.
38057	1446	34	These words are not of men nor of man, but of me; wherefore, you shall testify they are of me and not of man;
38058	1446	35	For it is my voice which speaketh them unto you; for they are given by my Spirit unto you, and by my power you can read them one to another; and save it were by my power you could not have them;
38059	1446	36	Wherefore, you can testify that you have heard my voice, and know my words.
38060	1446	37	And now, behold, I give unto you, Oliver Cowdery, and also unto David Whitmer, that you shall search out the Twelve, who shall have the desires of which I have spoken;
38061	1446	38	And by their desires and their works you shall know them.
38062	1446	39	And when you have found them you shall show these things unto them.
38063	1446	40	And you shall fall down and worship the Father in my name.
38064	1446	41	And you must preach unto the world, saying: You must repent and be baptized, in the name of Jesus Christ;
38065	1446	42	For all men must repent and be baptized, and not only men, but women, and children who have arrived at the years of accountability.
38066	1446	43	And now, after that you have received this, you must keep my commandments in all things;
38067	1446	44	And by your hands I will work a marvelous work among the children of men, unto the convincing of many of their sins, that they may come unto repentance, and that they may come unto the kingdom of my Father.
38068	1446	45	Wherefore, the blessings which I give unto you are above all things.
38069	1446	46	And after that you have received this, if you keep not my commandments you cannot be saved in the kingdom of my Father.
38070	1446	47	Behold, I, Jesus Christ, your Lord and your God, and your Redeemer, by the power of my Spirit have spoken it. Amen.
38071	1447	1	I AM Alpha and Omega, Christ the Lord; yea, even I am he, the beginning and the end, the Redeemer of the world.
38072	1447	2	I, having accomplished and finished the will of him whose I am, even the Father, concerning me--having done this that I might subdue all things unto myself--
38073	1447	3	Retaining all power, even to the destroying of Satan and his works at the end of the world, and the last great day of judgment, which I shall pass upon the inhabitants thereof, judging every man according to his works and the deeds which he hath done.
38074	1447	4	And surely every man must repent or suffer, for I, God, am endless.
38075	1447	5	Wherefore, I revoke not the judgments which I shall pass, but woes shall go forth, weeping, wailing and gnashing of teeth, yea, to those who are found on my left hand.
38076	1447	6	Nevertheless, it is not written that there shall be no end to this torment, but it is written endless torment.
38077	1447	7	Again, it is written eternal damnation; wherefore it is more express than other scriptures, that it might work upon the hearts of the children of men, altogether for my name's glory.
38078	1447	8	Wherefore, I will explain unto you this mystery, for it is meet unto you to know even as mine apostles.
38079	1447	9	I speak unto you that are chosen in this thing, even as one, that you may enter into my rest.
38080	1447	10	For, behold, the mystery of godliness, how great is it! For, behold, I am endless, and the punishment which is given from my hand is endless punishment, for Endless is my name. Wherefore--
38081	1447	11	Eternal punishment is God's punishment.
38082	1447	12	Endless punishment is God's punishment.
38083	1447	13	Wherefore, I command you to repent, and keep the commandments which you have received by the hand of my servant Joseph Smith, Jun., in my name;
38084	1447	14	And it is by my almighty power that you have received them;
38085	1447	15	Therefore I command you to repent--repent, lest I smite you by the rod of my mouth, and by my wrath, and by my anger, and your sufferings be sore--how sore you know not, how exquisite you know not, yea, how hard to bear you know not.
38086	1447	16	For behold, I, God, have suffered these things for all, that they might not suffer if they would repent;
38087	1447	17	But if they would not repent they must suffer even as I;
38088	1447	18	Which suffering caused myself, even God, the greatest of all, to tremble because of pain, and to bleed at every pore, and to suffer both body and spirit--and would that I might not drink the bitter cup, and shrink--
38089	1447	19	Nevertheless, glory be to the Father, and I partook and finished my preparations unto the children of men.
38090	1447	20	Wherefore, I command you again to repent, lest I humble you with my almighty power; and that you confess your sins, lest you suffer these punishments of which I have spoken, of which in the smallest, yea, even in the least degree you have tasted at the time I withdrew my Spirit.
38091	1447	21	And I command you that you preach naught but repentance, and show not these things unto the world until it is wisdom in me.
38092	1447	22	For they cannot bear meat now, but milk they must receive; wherefore, they must not know these things, lest they perish.
38093	1447	23	Learn of me, and listen to my words; walk in the meekness of my Spirit, and you shall have peace in me.
38094	1447	24	I am Jesus Christ; I came by the will of the Father, and I do his will.
38095	1447	25	And again, I command thee that thou shalt not covet thy neighbor's wife; nor seek thy neighbor's life.
38096	1447	26	And again, I command thee that thou shalt not covet thine own property, but impart it freely to the printing of the Book of Mormon, which contains the truth and the word of God--
38097	1447	27	Which is my word to the Gentile, that soon it may go to the Jew, of whom the Lamanites are a remnant, that they may believe the gospel, and look not for a Messiah to come who has already come.
38098	1447	28	And again, I command thee that thou shalt pray vocally as well as in thy heart; yea, before the world as well as in secret, in public as well as in private.
38099	1447	29	And thou shalt declare glad tidings, yea, publish it upon the mountains, and upon every high place, and among every people that thou shalt be permitted to see.
38100	1447	30	And thou shalt do it with all humility, trusting in me, reviling not against revilers.
38101	1447	31	And of tenets thou shalt not talk, but thou shalt declare repentance and faith on the Savior, and remission of sins by baptism, and by fire, yea, even the Holy Ghost.
38102	1447	32	Behold, this is a great and the last commandment which I shall give unto you concerning this matter; for this shall suffice for thy daily walk, even unto the end of thy life.
38103	1447	33	And misery thou shalt receive if thou wilt slight these counsels, yea, even the destruction of thyself and property.
38104	1447	34	Impart a portion of thy property, yea, even part of thy lands, and all save the support of thy family.
38105	1447	35	Pay the debt thou hast contracted with the printer. Release thyself from bondage.
38106	1447	36	Leave thy house and home, except when thou shalt desire to see thy family;
38107	1447	37	And speak freely to all; yea, preach, exhort, declare the truth, even with a loud voice, with a sound of rejoicing, crying--Hosanna, hosanna, blessed be the name of the Lord God!
38108	1447	38	Pray always, and I will pour out my Spirit upon you, and great shall be your blessing--yea, even more than if you should obtain treasures of earth and corruptibleness to the extent thereof.
38109	1447	39	Behold, canst thou read this without rejoicing and lifting up thy heart for gladness?
38110	1447	40	Or canst thou run about longer as a blind guide?
38111	1447	41	Or canst thou be humble and meek, and conduct thyself wisely before me? Yea, come unto me thy Savior. Amen.
38112	1448	1	THE rise of the Church of Christ in these last days, being one thousand eight hundred and thirty years since the coming of our Lord and Savior Jesus Christ in the flesh, it being regularly organized and established agreeable to the laws of our country, by the will and commandments of God, in the fourth month, and on the sixth day of the month which is called April--
38113	1448	2	Which commandments were given to Joseph Smith, Jun., who was called of God, and ordained an apostle of Jesus Christ, to be the first elder of this church;
38114	1448	3	And to Oliver Cowdery, who was also called of God, an apostle of Jesus Christ, to be the second elder of this church, and ordained under his hand;
38115	1448	4	And this according to the grace of our Lord and Savior Jesus Christ, to whom be all glory, both now and forever. Amen.
38116	1448	5	After it was truly manifested unto this first elder that he had received a remission of his sins, he was entangled again in the vanities of the world;
38117	1448	6	But after repenting, and humbling himself sincerely, through faith, God ministered unto him by an holy angel, whose countenance was as lightning, and whose garments were pure and white above all other whiteness;
38118	1448	7	And gave unto him commandments which inspired him;
38119	1448	8	And gave him power from on high, by the means which were before prepared, to translate the Book of Mormon;
38120	1448	9	Which contains a record of a fallen people, and the fulness of the gospel of Jesus Christ to the Gentiles and to the Jews also;
38121	1448	10	Which was given by inspiration, and is confirmed to others by the ministering of angels, and is declared unto the world by them--
38122	1448	11	Proving to the world that the holy scriptures are true, and that God does inspire men and call them to his holy work in this age and generation, as well as in generations of old;
38123	1448	12	Thereby showing that he is the same God yesterday, today,and forever. Amen.
38124	1448	13	Therefore, having so great witnesses, by them shall the world be judged, even as many as shall hereafter come to a knowledge of this work.
38125	1448	14	And those who receive it in faith, and work righteousness, shall receive a crown of eternal life;
38126	1448	15	But those who harden their hearts in unbelief, and reject it, it shall turn to their own condemnation--
38127	1448	16	For the Lord God has spoken it; and we, the elders of the church, have heard and bear witness to the words of the glorious Majesty on high, to whom be glory forever and ever. Amen.
38128	1448	17	By these things we know that there is a God in heaven, who is infinite and eternal, from everlasting to everlasting the same unchangeable God, the framer of heaven and earth, and all things which are in them;
38129	1448	18	And that he created man, male and female, after his own image and in his own likeness, created he them;
38130	1448	19	And gave unto them commandments that they should love and serve him, the only living and true God, and that he should be the only being whom they should worship.
38131	1448	20	But by the transgression of these holy laws man became sensual and devilish, and became fallen man.
38132	1448	21	Wherefore, the Almighty God gave his Only Begotten Son, as it is written in those scriptures which have been given of him.
38133	1448	22	He suffered temptations but gave no heed unto them.
38134	1448	23	He was crucified, died, and rose again the third day;
38135	1448	24	And ascended into heaven, to sit down on the right hand of the Father, to reign with almighty power according to the will of the Father;
38136	1448	25	That as many as would believe and be baptized in his holy name, and endure in faith to the end, should be saved--
38137	1448	26	Not only those who believed after he came in the meridian of time, in the flesh, but all those from the beginning, even as many as were before he came, who believed in the words of the holy prophets, who spake as they were inspired by the gift of the Holy Ghost, who truly testified of him in all things, should have eternal life,
38138	1448	27	As well as those who should come after, who should believe in the gifts and callings of God by the Holy Ghost, which beareth record of the Father and of the Son;
38139	1448	28	Which Father, Son, and Holy Ghost are one God, infinite and eternal, without end. Amen.
38140	1448	29	And we know that all men must repent and believe on the name of Jesus Christ, and worship the Father in his name, and endure in faith on his name to the end, or they cannot be saved in the kingdom of God.
38141	1448	30	And we know that justification through the grace of our Lord and Savior Jesus Christ is just and true;
38142	1448	31	And we know also, that sanctification through the grace of our Lord and Savior Jesus Christ is just and true, to all those who love and serve God with all their mights, minds, and strength.
38143	1448	32	But there is a possibility that man may fall from grace and depart from the living God;
38144	1448	33	Therefore let the church take heed and pray always, lest they fall into temptation;
38145	1448	34	Yea, and even let those who are sanctified take heed also.
38146	1448	35	And we know that these things are true and according to the revelations of John, neither adding to, nor diminishing from the prophecy of his book, the holy scriptures, or the revelations of God which shall come hereafter by the gift and power of the Holy Ghost, the voice of God, or the ministering of angels.
38147	1448	36	And the Lord God has spoken it; and honor, power and glory be rendered to his holy name, both now and ever. Amen.
38148	1448	37	And again, by way of commandment to the church concerning the manner of baptism--All those who humble themselves before God, and desire to be baptized, and come forth with broken hearts and contrite spirits, and witness before the church that they have truly repented of all their sins, and are willing to take upon them the name of Jesus Christ, having a determination to serve him to the end, and truly manifest by their works that they have received of the Spirit of Christ unto the remission of their sins, shall be received by baptism into his church.
38149	1448	38	The duty of the elders, priests, teachers, deacons, and members of the church of Christ--An apostle is an elder, and it is his calling to baptize;
38150	1448	39	And to ordain other elders, priests, teachers, and deacons;
38151	1448	40	And to administer bread and wine--the emblems of the flesh and blood of Christ--
38152	1448	41	And to confirm those who are baptized into the church, by the laying on of hands for the baptism of fire and the Holy Ghost, according to the scriptures;
38153	1448	42	And to teach, expound, exhort, baptize, and watch over the church;
38154	1448	43	And to confirm the church by the laying on of the hands, and the giving of the Holy Ghost;
38155	1448	44	And to take the lead of all meetings.
38156	1448	45	The elders are to conduct the meetings as they are led by the Holy Ghost, according to the commandments and revelations of God.
38157	1448	46	The priest's duty is to preach, teach, expound, exhort, and baptize, and administer the sacrament,
38158	1448	47	And visit the house of each member, and exhort them to pray vocally and in secret and attend to all family duties.
38159	1448	48	And he may also ordain other priests, teachers, and deacons.
38160	1448	49	And he is to take the lead of meetings when there is no elder present;
38161	1448	50	But when there is an elder present, he is only to preach, teach, expound, exhort, and baptize,
38162	1448	51	And visit the house of each member, exhorting them to pray vocally and in secret and attend to all family duties.
38163	1448	52	In all these duties the priest is to assist the elder if occasion requires.
38164	1448	53	The teacher's duty is to watch over the church always, and be with and strengthen them;
38165	1448	54	And see that there is no iniquity in the church, neither hardness with each other, neither lying, backbiting, nor evil speaking;
38166	1448	55	And see that the church meet together often, and also see that all the members do their duty.
38167	1448	56	And he is to take the lead of meetings in the absence of the elder or priest--
38168	1448	57	And is to be assisted always, in all his duties in the church, by the deacons, if occasion requires.
38169	1448	58	But neither teachers nor deacons have authority to baptize, administer the sacrament, or lay on hands;
38170	1448	59	They are, however, to warn, expound, exhort, and teach, and invite all to come unto Christ.
38171	1448	60	Every elder, priest, teacher, or deacon is to be ordained according to the gifts and callings of God unto him; and he is to be ordained by the power of the Holy Ghost, which is in the one who ordains him.
38172	1448	61	The several elders composing this church of Christ are to meet in conference once in three months, or from time to time as said conferences shall direct or appoint;
38173	1448	62	And said conferences are to do whatever church business is necessary to be done at the time.
38174	1448	63	The elders are to receive their licenses from other elders, by vote of the church to which they belong, or from the conferences.
38175	1448	64	Each priest, teacher, or deacon, who is ordained by a priest, may take a certificate from him at the time, which certificate, when presented to an elder, shall entitle him to a license, which shall authorize him to perform the duties of his calling, or he may receive it from a conference.
38176	1448	65	No person is to be ordained to any office in this church, where there is a regularly organized branch of the same, without the vote of that church;
38177	1448	66	But the presiding elders, traveling bishops, high councilors, high priests, and elders, may have the privilege of ordaining, where there is no branch of the church that a vote may be called.
38178	1448	67	Every president of the high priesthood (or presiding elder), bishop, high councilor, and high priest, is to be ordained by the direction of a high council or general conference.
38179	1448	68	The duty of the members after they are received by baptism.--The elders or priests are to have a sufficient time to expound all things concerning the church of Christ to their understanding, previous to their partaking of the sacrament and being confirmed by the laying on of the hands of the elders, so that all things may be done in order.
38180	1448	69	And the members shall manifest before the church, and also before the elders, by a godly walk and conversation, that they are worthy of it, that there may be works and faith agreeable to the holy scriptures--walking in holiness before the Lord.
38181	1448	70	Every member of the church of Christ having children is to bring them unto the elders before the church, who are to lay their hands upon them in the name of Jesus Christ, and bless them in his name.
38182	1448	71	No one can be received into the church of Christ unless he has arrived unto the years of accountability before God, and is capable of repentance.
38183	1448	72	Baptism is to be administered in the following manner unto all those who repent--
38184	1448	73	The person who is called of God and has authority from Jesus Christ to baptize, shall go down into the water with the person who has presented himself or herself for baptism, and shall say, calling him or her by name: Having been commissioned of Jesus Christ, I baptize you in the name of the Father, and of the Son, and of the Holy Ghost. Amen.
38185	1448	74	Then shall he immerse him or her in the water, and come forth again out of the water.
38186	1448	75	It is expedient that the church meet together often to partake of bread and wine in the remembrance of the Lord Jesus;
38187	1448	76	And the elder or priest shall administer it; and after this manner shall he administer it--he shall kneel with the church and call upon the Father in solemn prayer, saying:
38188	1448	77	O God, the Eternal Father, we ask thee in the name of thy Son, Jesus Christ, to bless and sanctify this bread to the souls of all those who partake of it, that they may eat in remembrance of the body of thy Son, and witness unto thee, O God, the Eternal Father, that they are willing to take upon them the name of thy Son, and always remember him and keep his commandments which he has given them; that they may always have his Spirit to be with them. Amen.
38189	1448	78	The manner of administering the wine--he shall take the cup also, and say:
38190	1448	79	O God, the Eternal Father, we ask thee in the name of thy Son, Jesus Christ, to bless and sanctify this wine to the souls of all those who drink of it, that they may do it in remembrance of the blood of thy Son, which was shed for them; that they may witness unto thee, O God, the Eternal Father, that they do always remember him, that they may have his Spirit to be with them. Amen.
38191	1448	80	Any member of the church of Christ transgressing, or being overtaken in a fault, shall be dealt with as the scriptures direct.
38192	1448	81	It shall be the duty of the several churches, composing the church of Christ, to send one or more of their teachers to attend the several conferences held by the elders of the church,
38193	1448	82	With a list of the names of the several members uniting themselves with the church since the last conference; or send by the hand of some priest; so that a regular list of all the names of the whole church may be kept in a book by one of the elders, whomsoever the other elders shall appoint from time to time;
38194	1448	83	And also, if any have been expelled from the church, so that their names may be blotted out of the general church record of names.
38195	1448	84	All members removing from the church where they reside, if going to a church where they are not known, may take a letter certifying that they are regular members and in good standing, which certificate may be signed by any elder or priest if the member receiving the letter is personally acquainted with the elder or priest, or it may be signed by the teachers or deacons of the church.
38196	1449	1	BEHOLD, there shall be a record kept among you; and in it thou shalt be called a seer, a translator, a prophet, an apostle of Jesus Christ, an elder of the church through the will of God the Father, and the grace of your Lord Jesus Christ,
38197	1449	2	Being inspired of the Holy Ghost to lay the foundation thereof, and to build it up unto the most holy faith.
38198	1449	3	Which church was organized and established in the year of your Lord eighteen hundred and thirty, in the fourth month, and on the sixth day of the month which is called April.
38199	1449	4	Wherefore, meaning the church, thou shalt give heed unto all his words and commandments which he shall give unto you as he receiveth them, walking in all holiness before me;
38200	1449	5	For his word ye shall receive, as if from mine own mouth, in all patience and faith.
38201	1449	6	For by doing these things the gates of hell shall not prevail against you; yea, and the Lord God will disperse the powers of darkness from before you, and cause the heavens to shake for your good, and his name's glory.
38202	1449	7	For thus saith the Lord God: Him have I inspired to move the cause of Zion in mighty power for good, and his diligence I know, and his prayers I have heard.
38203	1449	8	Yea, his weeping for Zion I have seen, and I will cause that he shall mourn for her no longer; for his days of rejoicing are come unto the remission of his sins, and the manifestations of my blessings upon his works.
38204	1449	9	For, behold, I will bless all those who labor in my vineyard with a mighty blessing, and they shall believe on his words, which are given him through me by the Comforter, which manifesteth that Jesus was crucified by sinful men for the sins of the world, yea, for the remission of sins unto the contrite heart.
38205	1449	10	Wherefore it behooveth me that he should be ordained by you, Oliver Cowdery mine apostle;
38206	1449	11	This being an ordinance unto you, that you are an elder under his hand, he being the first unto you, that you might be an elder unto this church of Christ, bearing my name--
38207	1449	12	And the first preacher of this church unto the church, and before the world, yea, before the Gentiles; yea, and thus saith the Lord God, lo, lo! to the Jews also. Amen.
38208	1450	1	BEHOLD, I say unto you that all old covenants have I caused to be done away in this thing; and this is a new and an everlasting covenant, even that which was from the beginning.
38209	1450	2	Wherefore, although a man should be baptized an hundred times it availeth him nothing, for you cannot enter in at the strait gate by the law of Moses, neither by your dead works.
38210	1450	3	For it is because of your dead works that I have caused this last covenant and this church to be built up unto me, even as in days of old.
38211	1450	4	Wherefore, enter ye in at the gate, as I have commanded, and seek not to counsel your God. Amen.
38212	1451	1	BEHOLD, I speak unto you, Oliver, a few words. Behold, thou art blessed, and art under no condemnation. But beware of pride, lest thou shouldst enter into temptation.
38213	1451	2	Make known thy calling unto the church, and also before the world, and thy heart shall be opened to preach the truth from henceforth and forever. Amen.
38214	1451	3	Behold, I speak unto you, Hyrum, a few words; for thou also art under no condemnation, and thy heart is opened, and thy tongue loosed; and thy calling is to exhortation, and to strengthen the church continually. Wherefore thy duty is unto the church forever, and this because of thy family. Amen.
38215	1451	4	Behold, I speak a few words unto you, Samuel; for thou also art under no condemnation, and thy calling is to exhortation, and to strengthen the church; and thou art not as yet called to preach before the world. Amen.
38216	1451	5	Behold, I speak a few words unto you, Joseph; for thou also art under no condemnation, and thy calling also is to exhortation, and to strengthen the church; and this is thy duty from henceforth and forever. Amen.
38217	1451	6	Behold, I manifest unto you, Joseph Knight, by these words, that you must take up your cross, in the which you must pray vocally before the world as well as in secret, and in your family, and among your friends, and in all places.
38218	1451	7	And, behold, it is your duty to unite with the true church, and give your language to exhortation continually, that you may receive the reward of the laborer. Amen.
38219	1452	1	BEHOLD, thou wast called and chosen to write the Book of Mormon, and to my ministry; and I have lifted thee up out of thine afflictions, and have counseled thee, that thou hast been delivered from all thine enemies, and thou hast been delivered from the powers of Satan and from darkness!
38220	1452	2	Nevertheless, thou art not excusable in thy transgressions; nevertheless, go thy way and sin no more.
38221	1452	3	Magnify thine office; and after thou hast sowed thy fields and secured them, go speedily unto the church which is in Colesville, Fayette, and Manchester, and they shall support thee; and I will bless them both spiritually and temporally;
38222	1452	4	But if they receive thee not, I will send upon them a cursing instead of a blessing.
38223	1452	5	And thou shalt continue in calling upon God in my name, and writing the things which shall be given thee by the Comforter, and expounding all scriptures unto the church.
38224	1452	6	And it shall be given thee in the very moment what thou shalt speak and write, and they shall hear it, or I will send unto them a cursing instead of a blessing.
38225	1452	7	For thou shalt devote all thy service in Zion; and in this thou shalt have strength.
38226	1452	8	Be patient in afflictions, for thou shalt have many; but endure them, for, lo, I am with thee, even unto the end of thy days.
38227	1452	9	And in temporal labors thou shalt not have strength, for this is not thy calling. Attend to thy calling and thou shalt have wherewith to magnify thine office, and to expound all scriptures, and continue in laying on of the hands and confirming the churches.
38228	1452	10	And thy brother Oliver shall continue in bearing my name before the world, and also to the church. And he shall not suppose that he can say enough in my cause; and lo, I am with him to the end.
38229	1452	11	In me he shall have glory, and not of himself, whether in weakness or in strength, whether in bonds or free;
38230	1452	12	And at all times, and in all places, he shall open his mouth and declare my gospel as with the voice of a trump, both day and night. And I will give unto him strength such as is not known among men.
38231	1452	13	Require not miracles, except I shall command you, except casting out devils, healing the sick, and against poisonous serpents, and against deadly poisons;
38232	1452	14	And these things ye shall not do, except it be required of you by them who desire it, that the scriptures might be fulfilled; for ye shall do according to that which is written.
38233	1452	15	And in whatsoever place ye shall enter, and they receive you not in my name, ye shall leave a cursing instead of a blessing, by casting off the dust of your feet against them as a testimony, and cleansing your feet by the wayside.
38234	1452	16	And it shall come to pass that whosoever shall lay their hands upon you by violence, ye shall command to be smitten in my name; and, behold, I will smite them according to your words, in mine own due time.
38235	1452	17	And whosoever shall go to law with thee shall be cursed by the law.
38236	1452	18	And thou shalt take no purse nor scrip, neither staves, neither two coats, for the church shall give unto thee in the very hour what thou needest for food and for raiment, and for shoes and for money, and for scrip.
38237	1452	19	For thou art called to prune my vineyard with a mighty pruning, yea, even for the last time; yea, and also all those whom thou hast ordained, and they shall do even according to this pattern. Amen.
38238	1453	1	HEARKEN unto the voice of the Lord your God, while I speak unto you, Emma Smith, my daughter; for verily I say unto you, all those who receive my gospel are sons and daughters in my kingdom.
38239	1453	2	A revelation I give unto you concerning my will; and if thou art faithful and walk in the paths of virtue before me, I will preserve thy life, and thou shalt receive an inheritance in Zion.
38240	1453	3	Behold, thy sins are forgiven thee, and thou art an elect lady, whom I have called.
38241	1453	4	Murmur not because of the things which thou hast not seen, for they are withheld from thee and from the world, which is wisdom in me in a time to come.
38242	1453	5	And the office of thy calling shall be for a comfort unto my servant, Joseph Smith, Jun., thy husband, in his afflictions, with consoling words, in the spirit of meekness.
38243	1453	6	And thou shalt go with him at the time of his going, and be unto him for a scribe, while there is no one to be a scribe for him, that I may send my servant, Oliver Cowdery, whithersoever I will.
38244	1453	7	And thou shalt be ordained under his hand to expound scriptures, and to exhort the church, according as it shall be given thee by my Spirit.
38245	1453	8	For he shall lay his hands upon thee, and thou shalt receive the Holy Ghost, and thy time shall be given to writing, and to learning much.
38246	1453	9	And thou needest not fear, for thy husband shall support thee in the church; for unto them is his calling, that all things might be revealed unto them, whatsoever I will, according to their faith.
38247	1453	10	And verily I say unto thee that thou shalt lay aside the things of this world, and seek for the things of a better.
38248	1453	11	And it shall be given thee, also, to make a selection of sacred hymns, as it shall be given thee, which is pleasing unto me, to be had in my church.
38249	1453	12	For my soul delighteth in the song of the heart; yea, the song of the righteous is a prayer unto me, and it shall be answered with a blessing upon their heads.
38250	1453	13	Wherefore, lift up thy heart and rejoice, and cleave unto the covenants which thou hast made.
38251	1453	14	Continue in the spirit of meekness, and beware of pride. Let thy soul delight in thy husband, and the glory which shall come upon him.
38252	1453	15	Keep my commandments continually, and a crown of righteousness thou shalt receive. And except thou do this, where I am you cannot come.
38253	1453	16	And verily, verily, I say unto you, that this is my voice unto all. Amen.
38254	1454	1	BEHOLD, I say unto you that you shall let your time be devoted to the studying of the scriptures, and to preaching, and to confirming the church at Colesville, and to performing your labors on the land, such as is required, until after you shall go to the west to hold the next conference; and then it shall be made known what you shall do.
38255	1454	2	And all things shall be done by common consent in the church, by much prayer and faith, for all things you shall receive by faith. Amen.
38256	1455	1	LISTEN to the voice of Jesus Christ, your Lord, your God, and your Redeemer, whose word is quick and powerful.
38257	1455	2	For, behold, I say unto you, that it mattereth not what ye shall eat or what ye shall drink when ye partake of the sacrament, if it so be that ye do it with an eye single to my glory--remembering unto the Father my body which was laid down for you, and my blood which was shed for the remission of your sins.
38258	1455	3	Wherefore, a commandment I give unto you, that you shall not purchase wine neither strong drink of your enemies;
38259	1455	4	Wherefore, you shall partake of none except it is made new among you; yea, in this my Father's kingdom which shall be built up on the earth.
38260	1455	5	Behold, this is wisdom in me; wherefore, marvel not, for the hour cometh that I will drink of the fruit of the vine with you on the earth, and with Moroni, whom I have sent unto you to reveal the Book of Mormon, containing the fulness of my everlasting gospel, to whom I have committed the keys of the record of the stick of Ephraim;
38261	1455	6	And also with Elias, to whom I have committed the keys of bringing to pass the restoration of all things spoken by the mouth of all the holy prophets since the world began, concerning the last days;
38262	1455	7	And also John the son of Zacharias, which Zacharias he (Elias) visited and gave promise that he should have a son, and his name should be John, and he should be filled with the spirit of Elias;
38263	1455	8	Which John I have sent unto you, my servants, Joseph Smith, Jun., and Oliver Cowdery, to ordain you unto the first priesthood which you have received, that you might be called and ordained even as Aaron;
38264	1455	9	And also Elijah, unto whom I have committed the keys of the power of turning the hearts of the fathers to the children, and the hearts of the children to the fathers, that the whole earth may not be smitten with a curse;
38265	1455	10	And also with Joseph and Jacob, and Isaac, and Abraham, your fathers, by whom the promises remain;
38266	1455	11	And also with Michael, or Adam, the father of all, the prince of all, the ancient of days;
38267	1455	12	And also with Peter, and James, and John, whom I have sent unto you, by whom I have ordained you and confirmed you to be apostles, and especial witnesses of my name, and bear the keys of your ministry and of the same things which I revealed unto them;
38268	1455	13	Unto whom I have committed the keys of my kingdom, and a dispensation of the gospel for the last times; and for the fulness of times, in the which I will gather together in one all things, both which are in heaven, and which are on earth;
38269	1455	14	And also with all those whom my Father hath given me out of the world.
38270	1455	15	Wherefore, lift up your hearts and rejoice, and gird up your loins, and take upon you my whole armor, that ye may be able to withstand the evil day, having done all, that ye may be able to stand.
38271	1455	16	Stand, therefore, having your loins girt about with truth, having on the breastplate of righteousness, and your feet shod with the preparation of the gospel of peace, which I have sent mine angels to commit unto you;
38272	1455	17	Taking the shield of faith wherewith ye shall be able to quench all the fiery darts of the wicked;
38273	1455	18	And take the helmet of salvation, and the sword of my Spirit, which I will pour out upon you, and my word which I reveal unto you, and be agreed as touching all things whatsoever ye ask of me, and be faithful until I come, and ye shall be caught up, that where I am ye shall be also. Amen.
38274	1456	1	BEHOLD, I say unto thee, Oliver, that it shall be given unto thee that thou shalt be heard by the church in all things whatsoever thou shalt teach them by the Comforter, concerning the revelations and commandments which I have given.
38275	1456	2	But, behold, verily, verily, I say unto thee, no one shall be appointed to receive commandments and revelations in this church excepting my servant Joseph Smith, Jun., for he receiveth them even as Moses.
38276	1456	3	And thou shalt be obedient unto the things which I shall give unto him, even as Aaron, to declare faithfully the commandments and the revelations, with power and authority unto the church.
38277	1456	4	And if thou art led at any time by the Comforter to speak or teach, or at all times by the way of commandment unto the church, thou mayest do it.
38278	1456	5	But thou shalt not write by way of commandment, but by wisdom;
38279	1456	6	And thou shalt not command him who is at thy head, and at the head of the church;
38280	1456	7	For I have given him the keys of the mysteries, and the revelations which are sealed, until I shall appoint unto them another in his stead.
38281	1456	8	And now, behold, I say unto you that you shall go unto the Lamanites and preach my gospel unto them; and inasmuch as they receive thy teachings thou shalt cause my church to be established among them; and thou shalt have revelations, but write them not by way of commandment.
38282	1456	9	And now, behold, I say unto you that it is not revealed, and no man knoweth where the city Zion shall be built, but it shall be given hereafter. Behold, I say unto you that it shall be on the borders by the Lamanites.
38283	1456	10	Thou shalt not leave this place until after the conference; and my servant Joseph shall be appointed to preside over the conference by the voice of it, and what he saith to thee thou shalt tell.
38284	1456	11	And again, thou shalt take thy brother, Hiram Page, between him and thee alone, and tell him that those things which he hath written from that stone are not of me and that Satan deceiveth him;
38285	1456	12	For, behold, these things have not been appointed unto him, neither shall anything be appointed unto any of this church contrary to the church covenants.
38286	1456	13	For all things must be done in order, and by common consent in the church, by the prayer of faith.
38287	1456	14	And thou shalt assist to settle all these things, according to the covenants of the church, before thou shalt take thy journey among the Lamanites.
38288	1456	15	And it shall be given thee from the time thou shalt go, until the time thou shalt return, what thou shalt do.
38289	1456	16	And thou must open thy mouth at all times, declaring my gospel with the sound of rejoicing. Amen.
38290	1457	1	LISTEN to the voice of Jesus Christ, your Redeemer, the Great I AM, whose arm of mercy hath atoned for your sins;
38291	1457	2	Who will gather his people even as a hen gathereth her chickens under her wings, even as many as will hearken to my voice and humble themselves before me, and call upon me in mighty prayer.
38292	1457	3	Behold, verily, verily, I say unto you, that at this time your sins are forgiven you, therefore ye receive these things; but remember to sin no more, lest perils shall come upon you.
38293	1457	4	Verily, I say unto you that ye are chosen out of the world to declare my gospel with the sound of rejoicing, as with the voice of a trump.
38294	1457	5	Lift up your hearts and be glad, for I am in your midst, and am your advocate with the Father; and it is his good will to give you the kingdom.
38295	1457	6	And, as it is written--Whatsoever ye shall ask in faith, being united in prayer according to my command, ye shall receive.
38296	1457	7	And ye are called to bring to pass the gathering of mine elect; for mine elect hear my voice and harden not their hearts;
38297	1457	8	Wherefore the decree hath gone forth from the Father that they shall be gathered in unto one place upon the face of this land, to prepare their hearts and be prepared in all things against the day when tribulation and desolation are sent forth upon the wicked.
38298	1457	9	For the hour is nigh and the day soon at hand when the earth is ripe; and all the proud and they that do wickedly shall be as stubble; and I will burn them up, saith the Lord of Hosts, that wickedness shall not be upon the earth;
38299	1457	10	For the hour is nigh, and that which was spoken by mine apostles must be fulfilled; for as they spoke so shall it come to pass;
38300	1457	11	For I will reveal myself from heaven with power and great glory, with all the hosts thereof, and dwell in righteousness with men on earth a thousand years, and the wicked shall not stand.
38301	1457	12	And again, verily, verily, I say unto you, and it hath gone forth in a firm decree, by the will of the Father, that mine apostles, the Twelve which were with me in my ministry at Jerusalem, shall stand at my right hand at the day of my coming in a pillar of fire, being clothed with robes of righteousness, with crowns upon their heads, in glory even as I am, to judge the whole house of Israel, even as many as have loved me and kept my commandments, and none else.
38302	1457	13	For a trump shall sound both long and loud, even as upon Mount Sinai, and all the earth shall quake, and they shall come forth--yea, even the dead which died in me, to receive a crown of righteousness, and to be clothed upon, even as I am, to be with me, that we may be one.
38303	1457	14	But, behold, I say unto you that before this great day shall come the sun shall be darkened, and the moon shall be turned into blood, and the stars shall fall from heaven, and there shall be greater signs in heaven above and in the earth beneath;
38304	1457	15	And there shall be weeping and wailing among the hosts of men;
38305	1457	16	And there shall be a great hailstorm sent forth to destroy the crops of the earth.
38306	1457	17	And it shall come to pass, because of the wickedness of the world, that I will take vengeance upon the wicked, for they will not repent; for the cup of mine indignation is full; for behold, my blood shall not cleanse them if they hear me not.
38307	1457	18	Wherefore, I the Lord God will send forth flies upon the face of the earth, which shall take hold of the inhabitants thereof, and shall eat their flesh, and shall cause maggots to come in upon them;
38308	1457	19	And their tongues shall be stayed that they shall not utter against me; and their flesh shall fall from off their bones, and their eyes from their sockets;
38309	1457	20	And it shall come to pass that the beasts of the forest and the fowls of the air shall devour them up.
38310	1457	21	And the great and abominable church, which is the whore of all the earth, shall be cast down by devouring fire, according as it is spoken by the mouth of Ezekiel the prophet, who spoke of these things, which have not come to pass but surely must, as I live, for abominations shall not reign.
38311	1457	22	And again, verily, verily, I say unto you that when the thousand years are ended, and men again begin to deny their God, then will I spare the earth but for a little season;
38312	1457	23	And the end shall come, and the heaven and the earth shall be consumed and pass away, and there shall be a new heaven and a new earth.
38313	1457	24	For all old things shall pass away, and all things shall become new, even the heaven and the earth, and all the fulness thereof, both men and beasts, the fowls of the air, and the fishes of the sea;
38314	1457	25	And not one hair, neither mote, shall be lost, for it is the workmanship of mine hand.
38315	1457	26	But, behold, verily I say unto you, before the earth shall pass away, Michael, mine archangel, shall sound his trump, and then shall all the dead awake, for their graves shall be opened, and they shall come forth--yea, even all.
38316	1457	27	And the righteous shall be gathered on my right hand unto eternal life; and the wicked on my left hand will I be ashamed to own before the Father;
38317	1457	28	Wherefore I will say unto them--Depart from me, ye cursed, into everlasting fire, prepared for the devil and his angels.
38318	1457	29	And now, behold, I say unto you, never at any time have I declared from mine own mouth that they should return, for where I am they cannot come, for they have no power.
38319	1457	30	But remember that all my judgments are not given unto men; and as the words have gone forth out of my mouth even so shall they be fulfilled, that the first shall be last, and that the last shall be first in all things whatsoever I have created by the word of my power, which is the power of my Spirit.
38320	1457	31	For by the power of my Spirit created I them; yea, all things both spiritual and temporal--
38321	1457	32	First spiritual, secondly temporal, which is the beginning of my work; and again, first temporal, and secondly spiritual, which is the last of my work--
38322	1457	33	Speaking unto you that you may naturally understand; but unto myself my works have no end, neither beginning; but it is given unto you that ye may understand, because ye have asked it of me and are agreed.
38323	1457	34	Wherefore, verily I say unto you that all things unto me are spiritual, and not at any time have I given unto you a law which was temporal; neither any man, nor the children of men; neither Adam, your father, whom I created.
38324	1457	35	Behold, I gave unto him that he should be an agent unto himself; and I gave unto him commandment, but no temporal commandment gave I unto him, for my commandments are spiritual; they are not natural nor temporal, neither carnal nor sensual.
38325	1457	36	And it came to pass that Adam, being tempted of the devil--for, behold, the devil was before Adam, for he rebelled against me, saying, Give me thine honor, which is my power; and also a third part of the hosts of heaven turned he away from me because of their agency;
38326	1457	37	And they were thrust down, and thus came the devil and his angels;
38327	1457	38	And, behold, there is a place prepared for them from the beginning, which place is hell.
38328	1457	39	And it must needs be that the devil should tempt the children of men, or they could not be agents unto themselves; for if they never should have bitter they could not know the sweet--
38329	1457	40	Wherefore, it came to pass that the devil tempted Adam, and he partook of the forbidden fruit and transgressed the commandment, wherein he became subject to the will of the devil, because he yielded unto temptation.
38330	1457	41	Wherefore, I, the Lord God, caused that he should be cast out from the Garden of Eden, from my presence, because of his transgression, wherein he became spiritually dead, which is the first death, even that same death which is the last death, which is spiritual, which shall be pronounced upon the wicked when I shall say: Depart, ye cursed.
38331	1457	42	But, behold, I say unto you that I, the Lord God, gave unto Adam and unto his seed, that they should not die as to the temporal death, until I, the Lord God, should send forth angels to declare unto them repentance and redemption, through faith on the name of mine Only Begotten Son.
38332	1457	43	And thus did I, the Lord God, appoint unto man the days of his probation--that by his natural death he might be raised in immortality unto eternal life, even as many as would believe;
38333	1457	44	And they that believe not unto eternal damnation; for they cannot be redeemed from their spiritual fall, because they repent not;
38334	1457	45	For they love darkness rather than light, and their deeds are evil, and they receive their wages of whom they list to obey.
38335	1457	46	But behold, I say unto you, that little children are redeemed from the foundation of the world through mine Only Begotten;
38336	1457	47	Wherefore, they cannot sin, for power is not given unto Satan to tempt little children, until they begin to become accountable before me;
38337	1457	48	For it is given unto them even as I will, according to mine own pleasure, that great things may be required at the hand of their fathers.
38338	1457	49	And, again, I say unto you, that whoso having knowledge, have I not commanded to repent?
38339	1457	50	And he that hath no understanding, it remaineth in me to do according as it is written. And now I declare no more unto you at this time. Amen.
38340	1458	1	BEHOLD, I say unto you, David, that you have feared man and have not relied on me for strength as you ought.
38341	1458	2	But your mind has been on the things of the earth more than on the things of me, your Maker, and the ministry whereunto you have been called; and you have not given heed unto my Spirit, and to those who were set over you, but have been persuaded by those whom I have not commanded.
38342	1458	3	Wherefore, you are left to inquire for yourself at my hand, and ponder upon the things which you have received.
38343	1458	4	And your home shall be at your father's house, until I give unto you further commandments. And you shall attend to the ministry in the church, and before the world, and in the regions round about. Amen.
38344	1458	5	Behold, I say unto you, Peter, that you shall take your journey with your brother Oliver; for the time has come that it is expedient in me that you shall open your mouth to declare my gospel; therefore, fear not, but give heed unto the words and advice of your brother, which he shall give you.
38345	1458	6	And be you afflicted in all his afflictions, ever lifting up your heart unto me in prayer and faith, for his and your deliverance; for I have given unto him power to build up my church among the Lamanites;
38346	1458	7	And none have I appointed to be his counselor over him in the church, concerning church matters, except it is his brother, Joseph Smith, Jun.
38347	1458	8	Wherefore, give heed unto these things and be diligent in keeping my commandments, and you shall be blessed unto eternal life. Amen.
38348	1458	9	Behold, I say unto you, my servant John, that thou shalt commence from this time forth to proclaim my gospel, as with the voice of a trump.
38349	1458	10	And your labor shall be at your brother Philip Burroughs', and in that region round about, yea, wherever you can be heard, until I command you to go from hence.
38350	1458	11	And your whole labor shall be in Zion, with all your soul, from henceforth; yea, you shall ever open your mouth in my cause, not fearing what man can do, for I am with you. Amen.
38351	1459	1	THOMAS, my son, blessed are you because of your faith in my work.
38352	1459	2	Behold, you have had many afflictions because of your family; nevertheless, I will bless you and your family, yea, your little ones; and the day cometh that they will believe and know the truth and be one with you in my church.
38353	1459	3	Lift up your heart and rejoice, for the hour of your mission is come; and your tongue shall be loosed, and you shall declare glad tidings of great joy unto this generation.
38354	1459	4	You shall declare the things which have been revealed to my servant, Joseph Smith, Jun. You shall begin to preach from this time forth, yea, to reap in the field which is white already to be burned.
38355	1459	5	Therefore, thrust in your sickle with all your soul, and your sins are forgiven you, and you shall be laden with sheaves upon your back, for the laborer is worthy of his hire. Wherefore, your family shall live.
38356	1459	6	Behold, verily I say unto you, go from them only for a little time, and declare my word, and I will prepare a place for them.
38357	1459	7	Yea, I will open the hearts of the people, and they will receive you. And I will establish a church by your hand;
38358	1459	8	And you shall strengthen them and prepare them against the time when they shall be gathered.
38359	1459	9	Be patient in afflictions, revile not against those that revile. Govern your house in meekness, and be steadfast.
38360	1459	10	Behold, I say unto you that you shall be a physician unto the church, but not unto the world, for they will not receive you.
38361	1459	11	Go your way whithersoever I will, and it shall be given you by the Comforter what you shall do and whither you shall go.
38362	1459	12	Pray always, lest you enter into temptation and lose your reward.
38363	1459	13	Be faithful unto the end, and lo, I am with you. These words are not of man nor of men, but of me, even Jesus Christ, your Redeemer, by the will of the Father. Amen.
38364	1460	1	AND now concerning my servant Parley P. Pratt, behold, I say unto him that as I live I will that he shall declare my gospel and learn of me, and be meek and lowly of heart.
38365	1460	2	And that which I have appointed unto him is that he shall go with my servants, Oliver Cowdery and Peter Whitmer, Jun., into the wilderness among the Lamanites.
38366	1460	3	And Ziba Peterson also shall go with them; and I myself will go with them and be in their midst; and I am their advocate with the Father, and nothing shall prevail against them.
38367	1460	4	And they shall give heed to that which is written, and pretend to no other revelation; and they shall pray always that I may unfold the same to their understanding.
38368	1460	5	And they shall give heed unto these words and trifle not, and I will bless them. Amen.
38369	1461	1	BEHOLD, I say unto you, my servants Ezra and Northrop, open ye your ears and hearken to the voice of the Lord your God, whose word is quick and powerful, sharper than a two-edged sword, to the dividing asunder of the joints and marrow, soul and spirit; and is a discerner of the thoughts and intents of the heart.
38370	1461	2	For verily, verily, I say unto you that ye are called to lift up your voices as with the sound of a trump, to declare my gospel unto a crooked and perverse generation.
38371	1461	3	For behold, the field is white already to harvest; and it is the eleventh hour, and the last time that I shall call laborers into my vineyard.
38372	1461	4	And my vineyard has become corrupted every whit; and there is none which doeth good save it be a few; and they err in many instances because of priestcrafts, all having corrupt minds.
38373	1461	5	And verily, verily, I say unto you, that this church have I established and called forth out of the wilderness.
38374	1461	6	And even so will I gather mine elect from the four quarters of the earth, even as many as will believe in me, and hearken unto my voice.
38375	1461	7	Yea, verily, verily, I say unto you, that the field is white already to harvest; wherefore, thrust in your sickles, and reap with all your might, mind, and strength.
38376	1461	8	Open your mouths and they shall be filled, and you shall become even as Nephi of old, who journeyed from Jerusalem in the wilderness.
38377	1461	9	Yea, open your mouths and spare not, and you shall be laden with sheaves upon your backs, for lo, I am with you.
38378	1461	10	Yea, open your mouths and they shall be filled, saying: Repent, repent, and prepare ye the way of the Lord, and make his paths straight; for the kingdom of heaven is at hand;
38379	1461	11	Yea, repent and be baptized, every one of you, for a remission of your sins; yea, be baptized even by water, and then cometh the baptism of fire and of the Holy Ghost.
38380	1461	12	Behold, verily, verily, I say unto you, this is my gospel; and remember that they shall have faith in me or they can in nowise be saved;
38381	1461	13	And upon this rock I will build my church; yea, upon this rock ye are built, and if ye continue, the gates of hell shall not prevail against you.
38382	1461	14	And ye shall remember the church articles and covenants to keep them.
38383	1461	15	And whoso having faith you shall confirm in my church, by the laying on of the hands, and I will bestow the gift of the Holy Ghost upon them.
38384	1461	16	And the Book of Mormon and the holy scriptures are given of me for your instruction; and the power of my Spirit quickeneth all things.
38385	1461	17	Wherefore, be faithful, praying always, having your lamps trimmed and burning, and oil with you, that you may be ready at the coming of the Bridegroom--
38386	1461	18	For behold, verily, verily, I say unto you, that I come quickly. Even so. Amen.
38387	1462	1	MY son Orson, hearken and hear and behold what I, the Lord God, shall say unto you, even Jesus Christ your Redeemer;
38388	1462	2	The light and the life of the world, a light which shineth in darkness and the darkness comprehendeth it not;
38389	1462	3	Who so loved the world that he gave his own life, that as many as would believe might become the sons of God. Wherefore you are my son;
38390	1462	4	And blessed are you because you have believed;
38391	1462	5	And more blessed are you because you are called of me to preach my gospel--
38392	1462	6	To lift up your voice as with the sound of a trump, both long and loud, and cry repentance unto a crooked and perverse generation, preparing the way of the Lord for his second coming.
38393	1462	7	For behold, verily, verily, I say unto you, the time is soon at hand that I shall come in a cloud with power and great glory.
38394	1462	8	And it shall be a great day at the time of my coming, for all nations shall tremble.
38395	1462	9	But before that great day shall come, the sun shall be darkened, and the moon be turned into blood; and the stars shall refuse their shining, and some shall fall, and great destructions await the wicked.
38396	1462	10	Wherefore, lift up your voice and spare not, for the Lord God hath spoken; therefore prophesy, and it shall be given by the power of the Holy Ghost.
38397	1462	11	And if you are faithful, behold, I am with you until I come--
38398	1462	12	And verily, verily, I say unto you, I come quickly. I am your Lord and your Redeemer. Even so. Amen.
38399	1463	1	LISTEN to the voice of the Lord your God, even Alpha and Omega, the beginning and the end, whose course is one eternal round, the same today as yesterday, and forever.
38400	1463	2	I am Jesus Christ, the Son of God, who was crucified for the sins of the world, even as many as will believe on my name, that they may become the sons of God, even one in me as I am one in the Father, as the Father is one in me, that we may be one.
38401	1463	3	Behold, verily, verily, I say unto my servant Sidney, I have looked upon thee and thy works. I have heard thy prayers, and prepared thee for a greater work.
38402	1463	4	Thou art blessed, for thou shalt do great things. Behold thou wast sent forth, even as John, to prepare the way before me, and before Elijah which should come, and thou knewest it not.
38403	1463	5	Thou didst baptize by water unto repentance, but they received not the Holy Ghost;
38404	1463	6	But now I give unto thee a commandment, that thou shalt baptize by water, and they shall receive the Holy Ghost by the laying on of the hands, even as the apostles of old.
38405	1463	7	And it shall come to pass that there shall be a great work in the land, even among the Gentiles, for their folly and their abominations shall be made manifest in the eyes of all people.
38406	1463	8	For I am God, and mine arm is not shortened; and I will show miracles, signs, and wonders, unto all those who believe on my name.
38407	1463	9	And whoso shall ask it in my name in faith, they shall cast out devils; they shall heal the sick; they shall cause the blind to receive their sight, and the deaf to hear, and the dumb to speak, and the lame to walk.
38408	1463	10	And the time speedily cometh that great things are to be shown forth unto the children of men;
38409	1463	11	But without faith shall not anything be shown forth except desolations upon Babylon, the same which has made all nations drink of the wine of the wrath of her fornication.
38410	1463	12	And there are none that doeth good except those who are ready to receive the fulness of my gospel, which I have sent forth unto this generation.
38411	1463	13	Wherefore, I call upon the weak things of the world, those who are unlearned and despised, to thrash the nations by the power of my Spirit;
38412	1463	14	And their arm shall be my arm, and I will be their shield and their buckler; and I will gird up their loins, and they shall fight manfully for me; and their enemies shall be under their feet; and I will let fall the sword in their behalf, and by the fire of mine indignation will I preserve them.
38413	1463	15	And the poor and the meek shall have the gospel preached unto them, and they shall be looking forth for the time of my coming, for it is nigh at hand--
38414	1463	16	And they shall learn the parable of the fig-tree, for even now already summer is nigh.
38415	1463	17	And I have sent forth the fulness of my gospel by the hand of my servant Joseph; and in weakness have I blessed him;
38416	1463	18	And I have given unto him the keys of the mystery of those things which have been sealed, even things which were from the foundation of the world, and the things which shall come from this time until the time of my coming, if he abide in me, and if not, another will I plant in his stead.
38417	1463	19	Wherefore, watch over him that his faith fail not, and it shall be given by the Comforter, the Holy Ghost, that knoweth all things.
38418	1463	20	And a commandment I give unto thee--that thou shalt write for him; and the scriptures shall be given, even as they are in mine own bosom, to the salvation of mine own elect;
38419	1463	21	For they will hear my voice, and shall see me, and shall not be asleep, and shall abide the day of my coming; for they shall be purified, even as I am pure.
38420	1463	22	And now I say unto you, tarry with him, and he shall journey with you; forsake him not, and surely these things shall be fulfilled.
38421	1463	23	And inasmuch as ye do not write, behold, it shall be given unto him to prophesy; and thou shalt preach my gospel and call on the holy prophets to prove his words, as they shall be given him.
38422	1463	24	Keep all the commandments and covenants by which ye are bound; and I will cause the heavens to shake for your good, and Satan shall tremble and Zion shall rejoice upon the hills and flourish;
38423	1463	25	And Israel shall be saved in mine own due time; and by the keys which I have given shall they be led, and no more be confounded at all.
38424	1463	26	Lift up your hearts and be glad, your redemption draweth nigh.
38425	1463	27	Fear not, little flock, the kingdom is yours until I come. Behold, I come quickly. Even so. Amen.
38426	1464	1	THUS saith the Lord God, the Mighty One of Israel: Behold, I say unto you, my servant Edward, that you are blessed, and your sins are forgiven you, and you are called to preach my gospel as with the voice of a trump;
38427	1464	2	And I will lay my hand upon you by the hand of my servant Sidney Rigdon, and you shall receive my Spirit, the Holy Ghost, even the Comforter, which shall teach you the peaceable things of the kingdom;
38428	1464	3	And you shall declare it with a loud voice, saying: Hosanna, blessed be the name of the most high God.
38429	1464	4	And now this calling and commandment give I unto you concerning all men--
38430	1464	5	That as many as shall come before my servants Sidney Rigdon and Joseph Smith, Jun., embracing this calling and commandment, shall be ordained and sent forth to preach the everlasting gospel among the nations--
38431	1464	6	Crying repentance, saying: Save yourselves from this untoward generation, and come forth out of the fire, hating even the garments spotted with the flesh.
38432	1464	7	And this commandment shall be given unto the elders of my church, that every man which will embrace it with singleness of heart may be ordained and sent forth, even as I have spoken.
38433	1464	8	I am Jesus Christ, the Son of God; wherefore, gird up your loins and I will suddenly come to my temple. Even so. Amen.
38434	1465	1	BEHOLD, I say unto you that it is not expedient in me that ye should translate any more until ye shall go to the Ohio, and this because of the enemy and for your sakes.
38435	1465	2	And again, I say unto you that ye shall not go until ye have preached my gospel in those parts, and have strengthened up the church whithersoever it is found, and more especially in Colesville; for, behold, they pray unto me in much faith.
38436	1465	3	And again, a commandment I give unto the church, that it is expedient in me that they should assemble together at the Ohio, against the time that my servant Oliver Cowdery shall return unto them.
38437	1465	4	Behold, here is wisdom, and let every man choose for himself until I come. Even so. Amen.
38438	1466	1	THUS saith the Lord your God, even Jesus Christ, the Great I AM, Alpha and Omega, the beginning and the end, the same which looked upon the wide expanse of eternity, and all the seraphic hosts of heaven, before the world was made;
38439	1466	2	The same which knoweth all things, for all things are present before mine eyes;
38440	1466	3	I am the same which spake, and the world was made, and all things came by me.
38441	1466	4	I am the same which have taken the Zion of Enoch into mine own bosom; and verily, I say, even as many as have believed in my name, for I am Christ, and in mine own name, by the virtue of the blood which I have spilt, have I pleaded before the Father for them.
38442	1466	5	But behold, the residue of the wicked have I kept in chains of darkness until the judgment of the great day, which shall come at the end of the earth;
38443	1466	6	And even so will I cause the wicked to be kept, that will not hear my voice but harden their hearts, and wo, wo, wo, is their doom.
38444	1466	7	But behold, verily, verily, I say unto you that mine eyes are upon you. I am in your midst and ye cannot see me;
38445	1466	8	But the day soon cometh that ye shall see me, and know that I am; for the veil of darkness shall soon be rent, and he that is not purified shall not abide the day.
38446	1466	9	Wherefore, gird up your loins and be prepared. Behold, the kingdom is yours, and the enemy shall not overcome.
38447	1466	10	Verily I say unto you, ye are clean, but not all; and there is none else with whom I am well pleased;
38448	1466	11	For all flesh is corrupted before me; and the powers of darkness prevail upon the earth, among the children of men, in the presence of all the hosts of heaven--
38449	1466	12	Which causeth silence to reign, and all eternity is pained, and the angels are waiting the great command to reap down the earth, to gather the tares that they may be burned; and, behold, the enemy is combined.
38450	1466	13	And now I show unto you a mystery, a thing which is had in secret chambers, to bring to pass even your destruction in process of time, and ye knew it not;
38451	1466	14	But now I tell it unto you, and ye are blessed, not because of your iniquity, neither your hearts of unbelief; for verily some of you are guilty before me, but I will be merciful unto your weakness.
38452	1466	15	Therefore, be ye strong from henceforth; fear not, for the kingdom is yours.
38453	1466	16	And for your salvation I give unto you a commandment, for I have heard your prayers, and the poor have complained before me, and the rich have I made, and all flesh is mine, and I am no respecter of persons.
38454	1466	17	And I have made the earth rich, and behold it is my footstool, wherefore, again I will stand upon it.
38455	1466	18	And I hold forth and deign to give unto you greater riches, even a land of promise, a land flowing with milk and honey, upon which there shall be no curse when the Lord cometh;
38456	1466	19	And I will give it unto you for the land of your inheritance, if you seek it with all your hearts.
38457	1466	20	And this shall be my covenant with you, ye shall have it for the land of your inheritance, and for the inheritance of your children forever, while the earth shall stand, and ye shall possess it again in eternity, no more to pass away.
38458	1466	21	But, verily I say unto you that in time ye shall have no king nor ruler, for I will be your king and watch over you.
38459	1466	22	Wherefore, hear my voice and follow me, and you shall be a free people, and ye shall have no laws but my laws when I come, for I am your lawgiver, and what can stay my hand?
38460	1466	23	But, verily I say unto you, teach one another according to the office wherewith I have appointed you;
38461	1466	24	And let every man esteem his brother as himself, and practise virtue and holiness before me.
38462	1466	25	And again I say unto you, let every man esteem his brother as himself.
38463	1466	26	For what man among you having twelve sons, and is no respecter of them, and they serve him obediently, and he saith unto the one: Be thou clothed in robes and sit thou here; and to the other: Be thou clothed in rags and sit thou there--and looketh upon his sons and saith I am just?
38464	1466	27	Behold, this I have given unto you as a parable, and it is even as I am. I say unto you, be one; and if ye are not one ye are not mine.
38465	1466	28	And again, I say unto you that the enemy in the secret chambers seeketh your lives.
38466	1466	29	Ye hear of wars in far countries, and you say that there will soon be great wars in far countries, but ye know not the hearts of men in your own land.
38467	1466	30	I tell you these things because of your prayers; wherefore, treasure up wisdom in your bosoms, lest the wickedness of men reveal these things unto you by their wickedness, in a manner which shall speak in your ears with a voice louder than that which shall shake the earth; but if ye are prepared ye shall not fear.
38468	1466	31	And that ye might escape the power of the enemy, and be gathered unto me a righteous people, without spot and blameless--
38469	1466	32	Wherefore, for this cause I gave unto you the commandment that ye should go to the Ohio; and there I will give unto you my law; and there you shall be endowed with power from on high;
38470	1466	33	And from thence, whosoever I will shall go forth among all nations, and it shall be told them what they shall do; for I have a great work laid up in store, for Israel shall be saved, and I will lead them whithersoever I will, and no power shall stay my hand.
38471	1466	34	And now, I give unto the church in these parts a commandment, that certain men among them shall be appointed, and they shall be appointed by the voice of the church;
38472	1466	35	And they shall look to the poor and the needy, and administer to their relief that they shall not suffer; and send them forth to the place which I have commanded them;
38473	1466	36	And this shall be their work, to govern the affairs of the property of this church.
38474	1466	37	And they that have farms that cannot be sold, let them be left or rented as seemeth them good.
38475	1466	38	See that all things are preserved; and when men are endowed with power from on high and sent forth, all these things shall be gathered unto the bosom of the church.
38476	1466	39	And if ye seek the riches which it is the will of the Father to give unto you, ye shall be the richest of all people, for ye shall have the riches of eternity; and it must needs be that the riches of the earth are mine to give; but beware of pride, lest ye become as the Nephites of old.
38477	1466	40	And again, I say unto you, I give unto you a commandment, that every man, both elder, priest, teacher, and also member, go to with his might, with the labor of his hands, to prepare and accomplish the things which I have commanded.
38478	1466	41	And let your preaching be the warning voice, every man to his neighbor, in mildness and in meekness.
38479	1466	42	And go ye out from among the wicked. Save yourselves. Be ye clean that bear the vessels of the Lord. Even so. Amen.
38480	1467	1	HEARKEN and listen to the voice of him who is from all eternity to all eternity, the Great I AM, even Jesus Christ--
38481	1467	2	The light and the life of the world; a light which shineth in darkness and the darkness comprehendeth it not;
38482	1467	3	The same which came in the meridian of time unto mine own, and mine own received me not;
38483	1467	4	But to as many as received me, gave I power to become my sons; and even so will I give unto as many as will receive me, power to become my sons.
38484	1467	5	And verily, verily, I say unto you, he that receiveth my gospel receiveth me; and he that receiveth not my gospel receiveth not me.
38485	1467	6	And this is my gospel--repentance and baptism by water, and then cometh the baptism of fire and the Holy Ghost, even the Comforter, which showeth all things, and teacheth the peaceable things of the kingdom.
38486	1467	7	And now, behold, I say unto you, my servant James, I have looked upon thy works and I know thee.
38487	1467	8	And verily I say unto thee, thine heart is now right before me at this time; and, behold, I have bestowed great blessings upon thy head;
38488	1467	9	Nevertheless, thou hast seen great sorrow, for thou hast rejected me many times because of pride and the cares of the world.
38489	1467	10	But, behold, the days of thy deliverance are come, if thou wilt hearken to my voice, which saith unto thee: Arise and be baptized, and wash away your sins, calling on my name, and you shall receive my Spirit, and a blessing so great as you never have known.
38490	1467	11	And if thou do this, I have prepared thee for a greater work. Thou shalt preach the fulness of my gospel, which I have sent forth in these last days, the covenant which I have sent forth to recover my people, which are of the house of Israel.
38491	1467	12	And it shall come to pass that power shall rest upon thee; thou shalt have great faith, and I will be with thee and go before thy face.
38492	1467	13	Thou art called to labor in my vineyard, and to build up my church, and to bring forth Zion, that it may rejoice upon the hills and flourish.
38493	1467	14	Behold, verily, verily, I say unto thee, thou art not called to go into the eastern countries, but thou art called to go to the Ohio.
38494	1467	15	And inasmuch as my people shall assemble themselves at the Ohio, I have kept in store a blessing such as is not known among the children of men, and it shall be poured forth upon their heads. And from thence men shall go forth into all nations.
38495	1467	16	Behold, verily, verily, I say unto you, that the people in Ohio call upon me in much faith, thinking I will stay my hand in judgment upon the nations, but I cannot deny my word.
38496	1467	17	Wherefore lay to with your might and call faithful laborers into my vineyard, that it may be pruned for the last time.
38497	1467	18	And inasmuch as they do repent and receive the fulness of my gospel, and become sanctified, I will stay mine hand in judgment.
38498	1467	19	Wherefore, go forth, crying with a loud voice, saying: The kingdom of heaven is at hand; crying: Hosanna! blessed be the name of the Most High God.
38499	1467	20	Go forth baptizing with water, preparing the way before my face for the time of my coming;
38500	1467	21	For the time is at hand; the day or the hour no man knoweth; but it surely shall come.
38501	1467	22	And he that receiveth these things receiveth me; and they shall be gathered unto me in time and in eternity.
38502	1467	23	And again, it shall come to pass that on as many as ye shall baptize with water, ye shall lay your hands, and they shall receive the gift of the Holy Ghost, and shall be looking forth for the signs of my coming, and shall know me.
38503	1467	24	Behold, I come quickly. Even so. Amen.
38504	1468	1	BEHOLD, verily I say unto you, that the heart of my servant James Covill was right before me, for he covenanted with me that he would obey my word.
38505	1468	2	And he received the word with gladness, but straightway Satan tempted him; and the fear of persecution and the cares of the world caused him to reject the word.
38506	1468	3	Wherefore he broke my covenant, and it remaineth with me to do with him as seemeth me good. Amen.
38507	1469	1	HEARKEN and hear, O ye my people, saith the Lord and your God, ye whom I delight to bless with the greatest of all blessings, ye that hear me; and ye that hear me not will I curse, that have professed my name, with the heaviest of all cursings.
38508	1469	2	Hearken, O ye elders of my church whom I have called, behold I give unto you a commandment, that ye shall assemble yourselves together to agree upon my word;
38509	1469	3	And by the prayer of your faith ye shall receive my law, that ye may know how to govern my church and have all things right before me.
38510	1469	4	And I will be your ruler when I come; and behold, I come quickly, and ye shall see that my law is kept.
38511	1469	5	He that receiveth my law and doeth it, the same is my disciple; and he that saith he receiveth it and doeth it not, the same is not my disciple, and shall be cast out from among you;
38512	1469	6	For it is not meet that the things which belong to the children of the kingdom should be given to them that are not worthy, or to dogs, or the pearls to be cast before swine.
38513	1469	7	And again, it is meet that my servant Joseph Smith, Jun., should have a house built, in which to live and translate.
38514	1469	8	And again, it is meet that my servant Sidney Rigdon should live as seemeth him good, inasmuch as he keepeth my commandments.
38515	1469	9	And again, I have called my servant Edward Partridge; and I give a commandment, that he should be appointed by the voice of the church, and ordained a bishop unto the church, to leave his merchandise and to spend all his time in the labors of the church;
38516	1469	10	To see to all things as it shall be appointed unto him in my laws in the day that I shall give them.
38517	1469	11	And this because his heart is pure before me, for he is like unto Nathanael of old, in whom there is no guile.
38518	1469	12	These words are given unto you, and they are pure before me; wherefore, beware how you hold them, for they are to be answered upon your souls in the day of judgment. Even so. Amen.
38519	1470	1	HEARKEN, O ye elders of my church, who have assembled yourselves together in my name, even Jesus Christ the Son of the living God, the Savior of the world; inasmuch as ye believe on my name and keep my commandments.
38520	1470	2	Again I say unto you, hearken and hear and obey the law which I shall give unto you.
38521	1470	3	For verily I say, as ye have assembled yourselves together according to the commandment wherewith I commanded you, and are agreed as touching this one thing, and have asked the Father in my name, even so ye shall receive.
38522	1470	4	Behold, verily I say unto you, I give unto you this first commandment, that ye shall go forth in my name, every one of you, excepting my servants Joseph Smith, Jun., and Sidney Rigdon.
38523	1470	5	And I give unto them a commandment that they shall go forth for a little season, and it shall be given by the power of the Spirit when they shall return.
38524	1470	6	And ye shall go forth in the power of my Spirit, preaching my gospel, two by two, in my name, lifting up your voices as with the sound of a trump, declaring my word like unto angels of God.
38525	1470	7	And ye shall go forth baptizing with water, saying: Repent ye, repent ye, for the kingdom of heaven is at hand.
38526	1470	8	And from this place ye shall go forth into the regions westward; and inasmuch as ye shall find them that will receive you ye shall build up my church in every region--
38527	1470	9	Until the time shall come when it shall be revealed unto you from on high, when the city of the New Jerusalem shall be prepared, that ye may be gathered in one, that ye may be my people and I will be your God.
38528	1470	10	And again, I say unto you, that my servant Edward Partridge shall stand in the office whereunto I have appointed him. And it shall come to pass, that if he transgress another shall be appointed in his stead. Even so. Amen.
38529	1470	11	Again I say unto you, that it shall not be given to any one to go forth to preach my gospel, or to build up my church, except he be ordained by some one who has authority, and it is known to the church that he has authority and has been regularly ordained by the heads of the church.
38530	1470	12	And again, the elders, priests and teachers of this church shall teach the principles of my gospel, which are in the Bible and the Book of Mormon, in the which is the fulness of the gospel.
38531	1470	13	And they shall observe the covenants and church articles to do them, and these shall be their teachings, as they shall be directed by the Spirit.
38532	1470	14	And the Spirit shall be given unto you by the prayer of faith; and if ye receive not the Spirit ye shall not teach.
38533	1470	15	And all this ye shall observe to do as I have commanded concerning your teaching, until the fulness of my scriptures is given.
38534	1470	16	And as ye shall lift up your voices by the Comforter, ye shall speak and prophesy as seemeth me good;
38535	1470	17	For, behold, the Comforter knoweth all things, and beareth record of the Father and of the Son.
38536	1470	18	And now, behold, I speak unto the church. Thou shalt not kill; and he that kills shall not have forgiveness in this world, nor in the world to come.
38537	1470	19	And again, I say, thou shalt not kill; but he that killeth shall die.
38538	1470	20	Thou shalt not steal; and he that stealeth and will not repent shall be cast out.
38539	1470	21	Thou shalt not lie; he that lieth and will not repent shall be cast out.
38540	1470	22	Thou shalt love thy wife with all thy heart, and shalt cleave unto her and none else.
38541	1470	23	And he that looketh upon a woman to lust after her shall deny the faith, and shall not have the Spirit; and if he repents not he shall be cast out.
38542	1470	24	Thou shalt not commit adultery; and he that committeth adultery, and repenteth not, shall be cast out.
38543	1470	25	But he that has committed adultery and repents with all his heart, and forsaketh it, and doeth it no more, thou shalt forgive;
38544	1470	26	But if he doeth it again, he shall not be forgiven, but shall be cast out.
38545	1470	27	Thou shalt not speak evil of thy neighbor, nor do him any harm.
38546	1470	28	Thou knowest my laws concerning these things are given in my scriptures; he that sinneth and repenteth not shall be cast out.
38547	1470	29	If thou lovest me thou shalt serve me and keep all my commandments.
38548	1470	30	And behold, thou wilt remember the poor, and consecrate of thy properties for their support that which thou hast to impart unto them, with a covenant and a deed which cannot be broken.
38549	1470	31	And inasmuch as ye impart of your substance unto the poor, ye will do it unto me; and they shall be laid before the bishop of my church and his counselors, two of the elders, or high priests, such as he shall appoint or has appointed and set apart for that purpose.
38550	1470	32	And it shall come to pass, that after they are laid before the bishop of my church, and after that he has received these testimonies concerning the consecration of the properties of my church, that they cannot be taken from the church, agreeable to my commandments, every man shall be made accountable unto me, a steward over his own property, or that which he has received by consecration, as much as is sufficient for himself and family.
38551	1470	33	And again, if there shall be properties in the hands of the church, or any individuals of it, more than is necessary for their support after this first consecration, which is a residue to be consecrated unto the bishop, it shall be kept to administer to those who have not, from time to time, that every man who has need may be amply supplied and receive according to his wants.
38552	1470	34	Therefore, the residue shall be kept in my storehouse, to administer to the poor and the needy, as shall be appointed by the high council of the church, and the bishop and his council;
38553	1470	35	And for the purpose of purchasing lands for the public benefit of the church, and building houses of worship, and building up of the New Jerusalem which is hereafter to be revealed--
38554	1470	36	That my covenant people may be gathered in one in that day when I shall come to my temple. And this I do for the salvation of my people.
38555	1470	37	And it shall come to pass, that he that sinneth and repenteth not shall be cast out of the church, and shall not receive again that which he has consecrated unto the poor and the needy of my church, or in other words, unto me--
38556	1470	38	For inasmuch as ye do it unto the least of these, ye do it unto me.
38557	1470	39	For it shall come to pass, that which I spake by the mouths of my prophets shall be fulfilled; for I will consecrate of the riches of those who embrace my gospel among the Gentiles unto the poor of my people who are of the house of Israel.
38558	1470	40	And again, thou shalt not be proud in thy heart; let all thy garments be plain, and their beauty the beauty of the work of thine own hands;
38559	1470	41	And let all things be done in cleanliness before me.
38560	1470	42	Thou shalt not be idle; for he that is idle shall not eat the bread nor wear the garments of the laborer.
38561	1470	43	And whosoever among you are sick, and have not faith to be healed, but believe, shall be nourished with all tenderness, with herbs and mild food, and that not by the hand of an enemy.
38562	1470	44	And the elders of the church, two or more, shall be called, and shall pray for and lay their hands upon them in my name; and if they die they shall die unto me, and if they live they shall live unto me.
38563	1470	45	Thou shalt live together in love, insomuch that thou shalt weep for the loss of them that die, and more especially for those that have not hope of a glorious resurrection.
38564	1470	46	And it shall come to pass that those that die in me shall not taste of death, for it shall be sweet unto them;
38565	1470	47	And they that die not in me, wo unto them, for their death is bitter.
38566	1470	48	And again, it shall come to pass that he that hath faith in me to be healed, and is not appointed unto death, shall be healed.
38567	1470	49	He who hath faith to see shall see.
38568	1470	50	He who hath faith to hear shall hear.
38569	1470	51	The lame who hath faith to leap shall leap.
38570	1470	52	And they who have not faith to do these things, but believe in me, have power to become my sons; and inasmuch as they break not my laws thou shalt bear their infirmities.
38571	1470	53	Thou shalt stand in the place of thy stewardship.
38572	1470	54	Thou shalt not take thy brother's garment; thou shalt pay for that which thou shalt receive of thy brother.
38573	1470	55	And if thou obtainest more than that which would be for thy support, thou shalt give it into my storehouse, that all things may be done according to that which I have said.
38574	1470	56	Thou shalt ask, and my scriptures shall be given as I have appointed, and they shall be preserved in safety;
38575	1470	57	And it is expedient that thou shouldst hold thy peace concerning them, and not teach them until ye have received them in full.
38576	1470	58	And I give unto you a commandment that then ye shall teach them unto all men; for they shall be taught unto all nations, kindreds, tongues and people.
38577	1470	59	Thou shalt take the things which thou hast received, which have been given unto thee in my scriptures for a law, to be my law to govern my church;
38578	1470	60	And he that doeth according to these things shall be saved, and he that doeth them not shall be damned if he so continue.
38579	1470	61	If thou shalt ask, thou shalt receive revelation upon revelation, knowledge upon knowledge, that thou mayest know the mysteries and peaceable things--that which bringeth joy, that which bringeth life eternal.
38580	1470	62	Thou shalt ask, and it shall be revealed unto you in mine own due time where the New Jerusalem shall be built.
38581	1470	63	And behold, it shall come to pass that my servants shall be sent forth to the east and to the west, to the north and to the south.
38582	1470	64	And even now, let him that goeth to the east teach them that shall be converted to flee to the west, and this in consequence of that which is coming on the earth, and of secret combinations.
38583	1470	65	Behold, thou shalt observe all these things, and great shall be thy reward; for unto you it is given to know the mysteries of the kingdom, but unto the world it is not given to know them.
38584	1470	66	Ye shall observe the laws which ye have received and be faithful.
38585	1470	67	And ye shall hereafter receive church covenants, such as shall be sufficient to establish you, both here and in the New Jerusalem.
38586	1470	68	Therefore, he that lacketh wisdom, let him ask of me, and I will give him liberally and upbraid him not.
38587	1470	69	Lift up your hearts and rejoice, for unto you the kingdom, or in other words, the keys of the church have been given. Even so. Amen.
38588	1470	70	The priests and teachers shall have their stewardships, even as the members.
38589	1470	71	And the elders or high priests who are appointed to assist the bishop as counselors in all things, are to have their families supported out of the property which is consecrated to the bishop, for the good of the poor, and for other purposes, as before mentioned;
38590	1470	72	Or they are to receive a just remuneration for all their services, either a stewardship or otherwise, as may be thought best or decided by the counselors and bishop.
38591	1470	73	And the bishop, also, shall receive his support, or a just remuneration for all his services in the church.
38592	1470	74	Behold, verily I say unto you, that whatever persons among you, having put away their companions for the cause of fornication, or in other words, if they shall testify before you in all lowliness of heart that this is the case, ye shall not cast them out from among you;
38593	1470	75	But if ye shall find that any persons have left their companions for the sake of adultery, and they themselves are the offenders, and their companions are living, they shall be cast out from among you.
38594	1470	76	And again, I say unto you, that ye shall be watchful and careful, with all inquiry, that ye receive none such among you if they are married;
38595	1470	77	And if they are not married, they shall repent of all their sins or ye shall not receive them.
38596	1470	78	And again, every person who belongeth to this church of Christ, shall observe to keep all the commandments and covenants of the church.
38597	1470	79	And it shall come to pass, that if any persons among you shall kill they shall be delivered up and dealt with according to the laws of the land; for remember that he hath no forgiveness; and it shall be proved according to the laws of the land.
38598	1470	80	And if any man or woman shall commit adultery, he or she shall be tried before two elders of the church, or more, and every word shall be established against him or her by two witnesses of the church, and not of the enemy; but if there are more than two witnesses it is better.
38599	1470	81	But he or she shall be condemned by the mouth of two witnesses; and the elders shall lay the case before the church, and the church shall lift up their hands against him or her, that they may be dealt with according to the law of God.
38600	1470	82	And if it can be, it is necessary that the bishop be present also.
38601	1470	83	And thus ye shall do in all cases which shall come before you.
38602	1470	84	And if a man or woman shall rob, he or she shall be delivered up unto the law of the land.
38603	1470	85	And if he or she shall steal, he or she shall be delivered up unto the law of the land.
38604	1470	86	And if he or she shall lie, he or she shall be delivered up unto the law of the land.
38605	1470	87	And if he or she do any manner of iniquity, he or she shall be delivered up unto the law, even that of God.
38606	1470	88	And if thy brother or sister offend thee, thou shalt take him or her between him or her and thee alone; and if he or she confess thou shalt be reconciled.
38607	1470	89	And if he or she confess not thou shalt deliver him or her up unto the church, not to the members, but to the elders. And it shall be done in a meeting, and that not before the world.
38608	1470	90	And if thy brother or sister offend many, he or she shall be chastened before many.
38609	1470	91	And if any one offend openly, he or she shall be rebuked openly, that he or she may be ashamed. And if he or she confess not, he or she shall be delivered up unto the law of God.
38610	1470	92	If any shall offend in secret, he or she shall be rebuked in secret, that he or she may have opportunity to confess in secret to him or her whom he or she has offended, and to God, that the church may not speak reproachfully of him or her.
38611	1470	93	And thus shall ye conduct in all things.
38612	1471	1	O HEARKEN, ye elders of my church, and give ear to the words which I shall speak unto you.
38613	1471	2	For behold, verily, verily, I say unto you, that ye have received a commandment for a law unto my church, through him whom I have appointed unto you to receive commandments and revelations from my hand.
38614	1471	3	And this ye shall know assuredly--that there is none other appointed unto you to receive commandments and revelations until he be taken, if he abide in me.
38615	1471	4	But verily, verily, I say unto you, that none else shall be appointed unto this gift except it be through him; for if it be taken from him he shall not have power except to appoint another in his stead.
38616	1471	5	And this shall be a law unto you, that ye receive not the teachings of any that shall come before you as revelations or commandments;
38617	1471	6	And this I give unto you that you may not be deceived, that you may know they are not of me.
38618	1471	7	For verily I say unto you, that he that is ordained of me shall come in at the gate and be ordained as I have told you before, to teach those revelations which you have received and shall receive through him whom I have appointed.
38619	1471	8	And now, behold, I give unto you a commandment, that when ye are assembled together ye shall instruct and edify each other, that ye may know how to act and direct my church, how to act upon the points of my law and commandments, which I have given.
38620	1471	9	And thus ye shall become instructed in the law of my church, and be sanctified by that which ye have received, and ye shall bind yourselves to act in all holiness before me--
38621	1471	10	That inasmuch as ye do this, glory shall be added to the kingdom which ye have received. Inasmuch as ye do it not, it shall be taken, even that which ye have received.
38622	1471	11	Purge ye out the iniquity which is among you; sanctify yourselves before me;
38623	1471	12	And if ye desire the glories of the kingdom, appoint ye my servant Joseph Smith, Jun., and uphold him before me by the prayer of faith.
38624	1471	13	And again, I say unto you, that if ye desire the mysteries of the kingdom, provide for him food and raiment, and whatsoever thing he needeth to accomplish the work wherewith I have commanded him;
38625	1471	14	And if ye do it not he shall remain unto them that have received him, that I may reserve unto myself a pure people before me.
38626	1471	15	Again I say, hearken ye elders of my church, whom I have appointed: Ye are not sent forth to be taught, but to teach the children of men the things which I have put into your hands by the power of my Spirit;
38627	1471	16	And ye are to be taught from on high. Sanctify yourselves and ye shall be endowed with power, that ye may give even as I have spoken.
38628	1471	17	Hearken ye, for, behold, the great day of the Lord is nigh at hand.
38629	1471	18	For the day cometh that the Lord shall utter his voice out of heaven; the heavens shall shake and the earth shall tremble, and the trump of God shall sound both long and loud, and shall say to the sleeping nations: Ye saints arise and live; ye sinners stay and sleep until I shall call again.
38630	1471	19	Wherefore gird up your loins lest ye be found among the wicked.
38631	1471	20	Lift up your voices and spare not. Call upon the nations to repent, both old and young, both bond and free, saying: Prepare yourselves for the great day of the Lord;
38632	1471	21	For if I, who am a man, do lift up my voice and call upon you to repent, and ye hate me, what will ye say when the day cometh when the thunders shall utter their voices from the ends of the earth, speaking to the ears of all that live, saying--Repent, and prepare for the great day of the Lord?
38633	1471	22	Yea, and again, when the lightnings shall streak forth from the east unto the west, and shall utter forth their voices unto all that live, and make the ears of all tingle that hear, saying these words--Repent ye, for the great day of the Lord is come?
38634	1471	23	And again, the Lord shall utter his voice out of heaven, saying: Hearken, O ye nations of the earth, and hear the words of that God who made you.
38635	1471	24	O, ye nations of the earth, how often would I have gathered you together as a hen gathereth her chickens under her wings, but ye would not!
38636	1471	25	How oft have I called upon you by the mouth of my servants, and by the ministering of angels, and by mine own voice, and by the voice of thunderings, and by the voice of lightnings, and by the voice of tempests, and by the voice of earthquakes, and great hailstorms, and by the voice of famines and pestilences of every kind, and by the great sound of a trump, and by the voice of judgment, and by the voice of mercy all the day long, and by the voice of glory and honor and the riches of eternal life, and would have saved you with an everlasting salvation, but ye would not!
38637	1471	26	Behold, the day has come, when the cup of the wrath of mine indignation is full.
38638	1471	27	Behold, verily I say unto you, that these are the words of the Lord your God.
38639	1471	28	Wherefore, labor ye, labor ye in my vineyard for the last time--for the last time call upon the inhabitants of the earth.
38640	1471	29	For in mine own due time will I come upon the earth in judgment, and my people shall be redeemed and shall reign with me on earth.
38641	1471	30	For the great Millennium, of which I have spoken by the mouth of my servants, shall come.
38642	1471	31	For Satan shall be bound, and when he is loosed again he shall only reign for a little season, and then cometh the end of the earth.
38643	1471	32	And he that liveth in righteousness shall be changed in the twinkling of an eye, and the earth shall pass away so as by fire.
38644	1471	33	And the wicked shall go away into unquenchable fire, and their end no man knoweth on earth, nor ever shall know, until they come before me in judgment.
38645	1471	34	Hearken ye to these words. Behold, I am Jesus Christ, the Savior of the world. Treasure these things up in your hearts, and let the solemnities of eternity rest upon your minds.
38646	1471	35	Be sober. Keep all my commandments. Even so. Amen.
38647	1472	1	BEHOLD, thus saith the Lord unto you my servants, it is expedient in me that the elders of my church should be called together, from the east and from the west, and from the north and from the south, by letter or some other way.
38648	1472	2	And it shall come to pass, that inasmuch as they are faithful, and exercise faith in me, I will pour out my Spirit upon them in the day that they assemble themselves together.
38649	1472	3	And it shall come to pass that they shall go forth into the regions round about, and preach repentance unto the people.
38650	1472	4	And many shall be converted, insomuch that ye shall obtain power to organize yourselves according to the laws of man;
38651	1472	5	That your enemies may not have power over you; that you may be preserved in all things; that you may be enabled to keep my laws; that every bond may be broken wherewith the enemy seeketh to destroy my people.
38652	1472	6	Behold, I say unto you, that ye must visit the poor and the needy and administer to their relief, that they may be kept until all things may be done according to my law which ye have received. Amen.
38653	1473	1	HEARKEN, O ye people of my church, to whom the kingdom has been given; hearken ye and give ear to him who laid the foundation of the earth, who made the heavens and all the hosts thereof, and by whom all things were made which live, and move, and have a being.
38654	1473	2	And again I say, hearken unto my voice, lest death shall overtake you; in an hour when ye think not the summer shall be past, and the harvest ended, and your souls not saved.
38655	1473	3	Listen to him who is the advocate with the Father, who is pleading your cause before him--
38656	1473	4	Saying: Father, behold the sufferings and death of him who did no sin, in whom thou wast well pleased; behold the blood of thy Son which was shed, the blood of him whom thou gavest that thyself might be glorified;
38657	1473	5	Wherefore, Father, spare these my brethren that believe on my name, that they may come unto me and have everlasting life.
38658	1473	6	Hearken, O ye people of my church, and ye elders listen together, and hear my voice while it is called today, and harden not your hearts;
38659	1473	7	For verily I say unto you that I am Alpha and Omega, the beginning and the end, the light and the life of the world--a light that shineth in darkness and the darkness comprehendeth it not.
38660	1473	8	I came unto mine own, and mine own received me not; but unto as many as received me gave I power to do many miracles, and to become the sons of God; and even unto them that believed on my name gave I power to obtain eternal life.
38661	1473	9	And even so I have sent mine everlasting covenant into the world, to be a light to the world, and to be a standard for my people, and for the Gentiles to seek to it, and to be a messenger before my face to prepare the way before me.
38662	1473	10	Wherefore, come ye unto it, and with him that cometh I will reason as with men in days of old, and I will show unto you my strong reasoning.
38663	1473	11	Wherefore, hearken ye together and let me show unto you even my wisdom--the wisdom of him whom ye say is the God of Enoch, and his brethren,
38664	1473	12	Who were separated from the earth, and were received unto myself--a city reserved until a day of righteousness shall come--a day which was sought for by all holy men, and they found it not because of wickedness and abominations;
38665	1473	13	And confessed they were strangers and pilgrims on the earth;
38666	1473	14	But obtained a promise that they should find it and see it in their flesh.
38667	1473	15	Wherefore, hearken and I will reason with you, and I will speak unto you and prophesy, as unto men in days of old.
38668	1473	16	And I will show it plainly as I showed it unto my disciples as I stood before them in the flesh, and spake unto them, saying: As ye have asked of me concerning the signs of my coming, in the day when I shall come in my glory in the clouds of heaven, to fulfil the promises that I have made unto your fathers,
38669	1473	17	For as ye have looked upon the long absence of your spirits from your bodies to be a bondage, I will show unto you how the day of redemption shall come, and also the restoration of the scattered Israel.
38670	1473	18	And now ye behold this temple which is in Jerusalem, which ye call the house of God, and your enemies say that this house shall never fall.
38671	1473	19	But, verily I say unto you, that desolation shall come upon this generation as a thief in the night, and this people shall be destroyed and scattered among all nations.
38672	1473	20	And this temple which ye now see shall be thrown down that there shall not be left one stone upon another.
38673	1473	21	And it shall come to pass, that this generation of Jews shall not pass away until every desolation which I have told you concerning them shall come to pass.
38674	1473	22	Ye say that ye know that the end of the world cometh; ye say also that ye know that the heavens and the earth shall pass away;
38675	1473	23	And in this ye say truly, for so it is; but these things which I have told you shall not pass away until all shall be fulfilled.
38676	1473	24	And this I have told you concerning Jerusalem; and when that day shall come, shall a remnant be scattered among all nations;
38677	1473	25	But they shall be gathered again; but they shall remain until the times of the Gentiles be fulfilled.
38678	1473	26	And in that day shall be heard of wars and rumors of wars, and the whole earth shall be in commotion, and men's hearts shall fail them, and they shall say that Christ delayeth his coming until the end of the earth.
38679	1473	27	And the love of men shall wax cold, and iniquity shall abound.
38680	1473	28	And when the times of the Gentiles is come in, a light shall break forth among them that sit in darkness, and it shall be the fulness of my gospel;
38681	1473	29	But they receive it not; for they perceive not the light, and they turn their hearts from me because of the precepts of men.
38682	1473	30	And in that generation shall the times of the Gentiles be fulfilled.
38683	1473	31	And there shall be men standing in that generation, that shall not pass until they shall see an overflowing scourge; for a desolating sickness shall cover the land.
38684	1473	32	But my disciples shall stand in holy places, and shall not be moved; but among the wicked, men shall lift up their voices and curse God and die.
38685	1473	33	And there shall be earthquakes also in divers places, and many desolations; yet men will harden their hearts against me, and they will take up the sword, one against another, and they will kill one another.
38686	1473	34	And now, when I the Lord had spoken these words unto my disciples, they were troubled.
38687	1473	35	And I said unto them: Be not troubled, for, when all these things shall come to pass, ye may know that the promises which have been made unto you shall be fulfilled.
38688	1473	36	And when the light shall begin to break forth, it shall be with them like unto a parable which I will show you--
38689	1473	37	Ye look and behold the fig-trees, and ye see them with your eyes, and ye say when they begin to shoot forth, and their leaves are yet tender, that summer is now nigh at hand;
38690	1473	38	Even so it shall be in that day when they shall see all these things, then shall they know that the hour is nigh.
38691	1473	39	And it shall come to pass that he that feareth me shall be looking forth for the great day of the Lord to come, even for the signs of the coming of the Son of Man.
38692	1473	40	And they shall see signs and wonders, for they shall be shown forth in the heavens above, and in the earth beneath.
38693	1473	41	And they shall behold blood, and fire, and vapors of smoke.
38694	1473	42	And before the day of the Lord shall come, the sun shall be darkened, and the moon be turned into blood, and the stars fall from heaven.
38695	1473	43	And the remnant shall be gathered unto this place;
38696	1473	44	And then they shall look for me, and, behold, I will come; and they shall see me in the clouds of heaven, clothed with power and great glory; with all the holy angels; and he that watches not for me shall be cut off.
38697	1473	45	But before the arm of the Lord shall fall, an angel shall sound his trump, and the saints that have slept shall come forth to meet me in the cloud.
38698	1473	46	Wherefore, if ye have slept in peace blessed are you; for as you now behold me and know that I am, even so shall ye come unto me and your souls shall live, and your redemption shall be perfected; and the saints shall come forth from the four quarters of the earth.
38699	1473	47	Then shall the arm of the Lord fall upon the nations.
38700	1473	48	And then shall the Lord set his foot upon this mount, and it shall cleave in twain, and the earth shall tremble, and reel to and fro, and the heavens also shall shake.
38701	1473	49	And the Lord shall utter his voice, and all the ends of the earth shall hear it; and the nations of the earth shall mourn, and they that have laughed shall see their folly.
38702	1473	50	And calamity shall cover the mocker, and the scorner shall be consumed; and they that have watched for iniquity shall be hewn down and cast into the fire.
38703	1473	51	And then shall the Jews look upon me and say: What are these wounds in thine hands and in thy feet?
38704	1473	52	Then shall they know that I am the Lord; for I will say unto them: These wounds are the wounds with which I was wounded in the house of my friends. I am he who was lifted up. I am Jesus that was crucified. I am the Son of God.
38705	1473	53	And then shall they weep because of their iniquities; then shall they lament because they persecuted their king.
38706	1473	54	And then shall the heathen nations be redeemed, and they that knew no law shall have part in the first resurrection; and it shall be tolerable for them.
38707	1473	55	And Satan shall be bound, that he shall have no place in the hearts of the children of men.
38708	1473	56	And at that day, when I shall come in my glory, shall the parable be fulfilled which I spake concerning the ten virgins.
38709	1473	57	For they that are wise and have received the truth, and have taken the Holy Spirit for their guide, and have not been deceived--verily I say unto you, they shall not be hewn down and cast into the fire, but shall abide the day.
38710	1473	58	And the earth shall be given unto them for an inheritance; and they shall multiply and wax strong, and their children shall grow up without sin unto salvation.
38711	1473	59	For the Lord shall be in their midst, and his glory shall be upon them, and he will be their king and their lawgiver.
38712	1473	60	And now, behold, I say unto you, it shall not be given unto you to know any further concerning this chapter, until the New Testament be translated, and in it all these things shall be made known;
38713	1473	61	Wherefore I give unto you that ye may now translate it, that ye may be prepared for the things to come.
38714	1473	62	For verily I say unto you, that great things await you;
38715	1473	63	Ye hear of wars in foreign lands; but, behold, I say unto you, they are nigh, even at your doors, and not many years hence ye shall hear of wars in your own lands.
38716	1473	64	Wherefore I, the Lord, have said, gather ye out from the eastern lands, assemble ye yourselves together ye elders of my church; go ye forth into the western countries, call upon the inhabitants to repent, and inasmuch as they do repent, build up churches unto me.
38717	1473	65	And with one heart and with one mind, gather up your riches that ye may purchase an inheritance which shall hereafter be appointed unto you.
38718	1473	66	And it shall be called the New Jerusalem, a land of peace, a city of refuge, a place of safety for the saints of the Most High God;
38719	1473	67	And the glory of the Lord shall be there, and the terror of the Lord also shall be there, insomuch that the wicked will not come unto it, and it shall be called Zion.
38720	1473	68	And it shall come to pass among the wicked, that every man that will not take his sword against his neighbor must needs flee unto Zion for safety.
38721	1473	69	And there shall be gathered unto it out of every nation under heaven; and it shall be the only people that shall not be at war one with another.
38722	1473	70	And it shall be said among the wicked: Let us not go up to battle against Zion, for the inhabitants of Zion are terrible; wherefore we cannot stand.
38723	1473	71	And it shall come to pass that the righteous shall be gathered out from among all nations, and shall come to Zion, singing with songs of everlasting joy.
38724	1473	72	And now I say unto you, keep these things from going abroad unto the world until it is expedient in me, that ye may accomplish this work in the eyes of the people, and in the eyes of your enemies, that they may not know your works until ye have accomplished the thing which I have commanded you;
38725	1473	73	That when they shall know it, that they may consider these things.
38726	1473	74	For when the Lord shall appear he shall be terrible unto them, that fear may seize upon them, and they shall stand afar off and tremble.
38727	1473	75	And all nations shall be afraid because of the terror of the Lord, and the power of his might. Even so. Amen.
38728	1474	1	HEARKEN, O ye people of my church; for verily I say unto you that these things were spoken unto you for your profit and learning.
38729	1474	2	But notwithstanding those things which are written, it always has been given to the elders of my church from the beginning, and ever shall be, to conduct all meetings as they are directed and guided by the Holy Spirit.
38730	1474	3	Nevertheless ye are commanded never to cast any one out from your public meetings, which are held before the world.
38731	1474	4	Ye are also commanded not to cast any one who belongeth to the church out of your sacrament meetings; nevertheless, if any have trespassed, let him not partake until he makes reconciliation.
38732	1474	5	And again I say unto you, ye shall not cast any out of your sacrament meetings who are earnestly seeking the kingdom--I speak this concerning those who are not of the church.
38733	1474	6	And again I say unto you, concerning your confirmation meetings, that if there be any that are not of the church, that are earnestly seeking after the kingdom, ye shall not cast them out.
38734	1474	7	But ye are commanded in all things to ask of God, who giveth liberally; and that which the Spirit testifies unto you even so I would that ye should do in all holiness of heart, walking uprightly before me, considering the end of your salvation, doing all things with prayer and thanksgiving, that ye may not be seduced by evil spirits, or doctrines of devils, or the commandments of men; for some are of men, and others of devils.
38735	1474	8	Wherefore, beware lest ye are deceived; and that ye may not be deceived seek ye earnestly the best gifts, always remembering for what they are given;
38736	1474	9	For verily I say unto you, they are given for the benefit of those who love me and keep all my commandments, and him that seeketh so to do; that all may be benefited that seek or that ask of me, that ask and not for a sign that they may consume it upon their lusts.
38737	1474	10	And again, verily I say unto you, I would that ye should always remember, and always retain in your minds what those gifts are, that are given unto the church.
38738	1474	11	For all have not every gift given unto them; for there are many gifts, and to every man is given a gift by the Spirit of God.
38739	1474	12	To some is given one, and to some is given another, that all may be profited thereby.
38740	1474	13	To some it is given by the Holy Ghost to know that Jesus Christ is the Son of God, and that he was crucified for the sins of the world.
38741	1474	14	To others it is given to believe on their words, that they also might have eternal life if they continue faithful.
38742	1474	15	And again, to some it is given by the Holy Ghost to know the differences of administration, as it will be pleasing unto the same Lord, according as the Lord will, suiting his mercies according to the conditions of the children of men.
38743	1474	16	And again, it is given by the Holy Ghost to some to know the diversities of operations, whether they be of God, that the manifestations of the Spirit may be given to every man to profit withal.
38744	1474	17	And again, verily I say unto you, to some is given, by the Spirit of God, the word of wisdom.
38745	1474	18	To another is given the word of knowledge, that all may be taught to be wise and to have knowledge.
38746	1474	19	And again, to some it is given to have faith to be healed;
38747	1474	20	And to others it is given to have faith to heal.
38748	1474	21	And again, to some is given the working of miracles;
38749	1474	22	And to others it is given to prophesy;
38750	1474	23	And to others the discerning of spirits.
38751	1474	24	And again, it is given to some to speak with tongues;
38752	1474	25	And to another is given the interpretation of tongues.
38753	1474	26	And all these gifts come from God, for the benefit of the children of God.
38754	1474	27	And unto the bishop of the church, and unto such as God shall appoint and ordain to watch over the church and to be elders unto the church, are to have it given unto them to discern all those gifts lest there shall be any among you professing and yet be not of God.
38755	1474	28	And it shall come to pass that he that asketh in Spirit shall receive in Spirit;
38756	1474	29	That unto some it may be given to have all those gifts, that there may be a head, in order that every member may be profited thereby.
38757	1474	30	He that asketh in the Spirit asketh according to the will of God; wherefore it is done even as he asketh.
38758	1474	31	And again, I say unto you, all things must be done in the name of Christ, whatsoever you do in the Spirit;
38759	1474	32	And ye must give thanks unto God in the Spirit for whatsoever blessing ye are blessed with.
38760	1474	33	And ye must practise virtue and holiness before me continually. Even so. Amen.
38761	1475	1	BEHOLD, it is expedient in me that my servant John should write and keep a regular history, and assist you, my servant Joseph, in transcribing all things which shall be given you, until he is called to further duties.
38762	1475	2	Again, verily I say unto you that he can also lift up his voice in meetings, whenever it shall be expedient.
38763	1475	3	And again, I say unto you that it shall be appointed unto him to keep the church record and history continually; for Oliver Cowdery I have appointed to another office.
38764	1475	4	Wherefore, it shall be given him, inasmuch as he is faithful, by the Comforter, to write these things. Even so. Amen.
38765	1476	1	IT is necessary that ye should remain for the present time in your places of abode, as it shall be suitable to your circumstances.
38766	1476	2	And inasmuch as ye have lands, ye shall impart to the eastern brethren;
38767	1476	3	And inasmuch as ye have not lands, let them buy for the present time in those regions round about, as seemeth them good, for it must needs be necessary that they have places to live for the present time.
38768	1476	4	It must needs be necessary that ye save all the money that ye can, and that ye obtain all that ye can in righteousness, that in time ye may be enabled to purchase land for an inheritance, even the city.
38769	1476	5	The place is not yet to be revealed; but after your brethren come from the east there are to be certain men appointed, and to them it shall be given to know the place, or to them it shall be revealed.
38770	1476	6	And they shall be appointed to purchase the lands, and to make a commencement to lay the foundation of the city; and then shall ye begin to be gathered with your families, every man according to his family, according to his circumstances, and as is appointed to him by the presidency and the bishop of the church, according to the laws and commandments which ye have received, and which ye shall hereafter receive. Even so. Amen.
38771	1477	1	HEARKEN unto my word, my servants Sidney, and Parley, and Leman; for behold, verily I say unto you, that I give unto you a commandment that you shall go and preach my gospel which ye have received, even as ye have received it, unto the Shakers.
38772	1477	2	Behold, I say unto you, that they desire to know the truth in part, but not all, for they are not right before me and must needs repent.
38773	1477	3	Wherefore, I send you, my servants Sidney and Parley, to preach the gospel unto them.
38774	1477	4	And my servant Leman shall be ordained unto this work, that he may reason with them, not according to that which he has received of them, but according to that which shall be taught him by you my servants; and by so doing I will bless him, otherwise he shall not prosper.
38775	1477	5	Thus saith the Lord; for I am God, and have sent mine Only Begotten Son into the world for the redemption of the world, and have decreed that he that receiveth him shall be saved, and he that receiveth him not shall be damned--
38776	1477	6	And they have done unto the Son of Man even as they listed; and he has taken his power on the right hand of his glory, and now reigneth in the heavens, and will reign till he descends on the earth to put all enemies under his feet, which time is nigh at hand--
38777	1477	7	I, the Lord God, have spoken it; but the hour and the day no man knoweth, neither the angels in heaven, nor shall they know until he comes.
38778	1477	8	Wherefore, I will that all men shall repent, for all are under sin, except those which I have reserved unto myself, holy men that ye know not of.
38779	1477	9	Wherefore, I say unto you that I have sent unto you mine everlasting covenant, even that which was from the beginning.
38780	1477	10	And that which I have promised I have so fulfilled, and the nations of the earth shall bow to it; and, if not of themselves, they shall come down, for that which is now exalted of itself shall be laid low of power.
38781	1477	11	Wherefore, I give unto you a commandment that ye go among this people, and say unto them, like unto mine apostle of old, whose name was Peter:
38782	1477	12	Believe on the name of the Lord Jesus, who was on the earth, and is to come, the beginning and the end;
38783	1477	13	Repent and be baptized in the name of Jesus Christ, according to the holy commandment, for the remission of sins;
38784	1477	14	And whoso doeth this shall receive the gift of the Holy Ghost, by the laying on of the hands of the elders of the church.
38785	1477	15	And again, verily I say unto you, that whoso forbiddeth to marry is not ordained of God, for marriage is ordained of God unto man.
38786	1477	16	Wherefore, it is lawful that he should have one wife, and they twain shall be one flesh, and all this that the earth might answer the end of its creation;
38787	1477	17	And that it might be filled with the measure of man, according to his creation before the world was made.
38788	1477	18	And whoso forbiddeth to abstain from meats, that man should not eat the same, is not ordained of God;
38789	1477	19	For, behold, the beasts of the field and the fowls of the air, and that which cometh of the earth, is ordained for the use of man for food and for raiment, and that he might have in abundance.
38790	1477	20	But it is not given that one man should possess that which is above another, wherefore the world lieth in sin.
38791	1477	21	And wo be unto man that sheddeth blood or that wasteth flesh and hath no need.
38792	1477	22	And again, verily I say unto you, that the Son of Man cometh not in the form of a woman, neither of a man traveling on the earth.
38793	1477	23	Wherefore, be not deceived, but continue in steadfastness, looking forth for the heavens to be shaken, and the earth to tremble and to reel to and fro as a drunken man, and for the valleys to be exalted, and for the mountains to be made low, and for the rough places to become smooth--and all this when the angel shall sound his trumpet.
38794	1477	24	But before the great day of the Lord shall come, Jacob shall flourish in the wilderness, and the Lamanites shall blossom as the rose.
38795	1477	25	Zion shall flourish upon the hills and rejoice upon the mountains, and shall be assembled together unto the place which I have appointed.
38796	1477	26	Behold, I say unto you, go forth as I have commanded you; repent of all your sins; ask and ye shall receive; knock and it shall be opened unto you.
38797	1477	27	Behold, I will go before you and be your rearward; and I will be in your midst, and you shall not be confounded.
38798	1477	28	Behold, I am Jesus Christ, and I come quickly. Even so. Amen.
38799	1478	1	HEARKEN, O ye elders of my church, and give ear to the voice of the living God; and attend to the words of wisdom which shall be given unto you, according as ye have asked and are agreed as touching the church, and the spirits which have gone abroad in the earth.
38800	1478	2	Behold, verily I say unto you, that there are many spirits which are false spirits, which have gone forth in the earth, deceiving the world.
38801	1478	3	And also Satan hath sought to deceive you, that he might overthrow you.
38802	1478	4	Behold, I, the Lord, have looked upon you, and have seen abominations in the church that profess my name.
38803	1478	5	But blessed are they who are faithful and endure, whether in life or in death, for they shall inherit eternal life.
38804	1478	6	But wo unto them that are deceivers and hypocrites, for, thus saith the Lord, I will bring them to judgment.
38805	1478	7	Behold, verily I say unto you, there are hypocrites among you, who have deceived some, which has given the adversary power; but behold such shall be reclaimed;
38806	1478	8	But the hypocrites shall be detected and shall be cut off, either in life or in death, even as I will; and wo unto them who are cut off from my church, for the same are overcome of the world.
38807	1478	9	Wherefore, let every man beware lest he do that which is not in truth and righteousness before me.
38808	1478	10	And now come, saith the Lord, by the Spirit, unto the elders of his church, and let us reason together, that ye may understand;
38809	1478	11	Let us reason even as a man reasoneth one with another face to face.
38810	1478	12	Now, when a man reasoneth he is understood of man, because he reasoneth as a man; even so will I, the Lord, reason with you that you may understand.
38811	1478	13	Wherefore, I the Lord ask you this question--unto what were ye ordained?
38812	1478	14	To preach my gospel by the Spirit, even the Comforter which was sent forth to teach the truth.
38813	1478	15	And then received ye spirits which ye could not understand, and received them to be of God; and in this are ye justified?
38814	1478	16	Behold ye shall answer this question yourselves; nevertheless, I will be merciful unto you; he that is weak among you hereafter shall be made strong.
38815	1478	17	Verily I say unto you, he that is ordained of me and sent forth to preach the word of truth by the Comforter, in the Spirit of truth, doth he preach it by the Spirit of truth or some other way?
38816	1478	18	And if it be by some other way it is not of God.
38817	1478	19	And again, he that receiveth the word of truth, doth he receive it by the Spirit of truth or some other way?
38818	1478	20	If it be some other way it is not of God.
38819	1478	21	Therefore, why is it that ye cannot understand and know, that he that receiveth the word by the Spirit of truth receiveth it as it is preached by the Spirit of truth?
38820	1478	22	Wherefore, he that preacheth and he that receiveth, understand one another, and both are edified and rejoice together.
38821	1478	23	And that which doth not edify is not of God, and is darkness.
38822	1478	24	That which is of God is light; and he that receiveth light, and continueth in God, receiveth more light; and that light groweth brighter and brighter until the perfect day.
38823	1478	25	And again, verily I say unto you, and I say it that you may know the truth, that you may chase darkness from among you;
38824	1478	26	He that is ordained of God and sent forth, the same is appointed to be the greatest, notwithstanding he is the least and the servant of all.
38825	1478	27	Wherefore, he is possessor of all things; for all things are subject unto him, both in heaven and on the earth, the life and the light, the Spirit and the power, sent forth by the will of the Father through Jesus Christ, his Son.
38826	1478	28	But no man is possessor of all things except he be purified and cleansed from all sin.
38827	1478	29	And if ye are purified and cleansed from all sin, ye shall ask whatsoever you will in the name of Jesus and it shall be done.
38828	1478	30	But know this, it shall be given you what you shall ask; and as ye are appointed to the head, the spirits shall be subject unto you.
38829	1478	31	Wherefore, it shall come to pass, that if you behold a spirit manifested that you cannot understand, and you receive not that spirit, ye shall ask of the Father in the name of Jesus; and if he give not unto you that spirit, then you may know that it is not of God.
38830	1478	32	And it shall be given unto you, power over that spirit; and you shall proclaim against that spirit with a loud voice that it is not of God--
38831	1478	33	Not with railing accusation, that ye be not overcome, neither with boasting nor rejoicing, lest you be seized therewith.
38832	1478	34	He that receiveth of God, let him account it of God; and let him rejoice that he is accounted of God worthy to receive.
38833	1478	35	And by giving heed and doing these things which ye have received, and which ye shall hereafter receive--and the kingdom is given you of the Father, and power to overcome all things which are not ordained of him--
38834	1478	36	And behold, verily I say unto you, blessed are you who are now hearing these words of mine from the mouth of my servant, for your sins are forgiven you.
38835	1478	37	Let my servant Joseph Wakefield, in whom I am well pleased, and my servant Parley P. Pratt go forth among the churches and strengthen them by the word of exhortation;
38836	1478	38	And also my servant John Corrill, or as many of my servants as are ordained unto this office, and let them labor in the vineyard; and let no man hinder them doing that which I have appointed unto them--
38837	1478	39	Wherefore, in this thing my servant Edward Partridge is not justified; nevertheless let him repent and he shall be forgiven.
38838	1478	40	Behold, ye are little children and ye cannot bear all things now; ye must grow in grace and in the knowledge of the truth.
38839	1478	41	Fear not, little children, for you are mine, and I have overcome the world, and you are of them that my Father hath given me;
38840	1478	42	And none of them that my Father hath given me shall be lost.
38841	1478	43	And the Father and I are one. I am in the Father and the Father in me; and inasmuch as ye have received me, ye are in me and I in you.
38842	1478	44	Wherefore, I am in your midst, and I am the good shepherd, and the stone of Israel. He that buildeth upon this rock shall never fall.
38843	1478	45	And the day cometh that you shall hear my voice and see me, and know that I am.
38844	1478	46	Watch, therefore, that ye may be ready. Even so. Amen.
38845	1479	1	HEARKEN unto me, saith the Lord your God, and I will speak unto my servant Edward Partridge, and give unto him directions; for it must needs be that he receive directions how to organize this people.
38846	1479	2	For it must needs be that they be organized according to my laws; if otherwise, they will be cut off.
38847	1479	3	Wherefore, let my servant Edward Partridge, and those whom he has chosen, in whom I am well pleased, appoint unto this people their portions, every man equal according to his family, according to his circumstances and his wants and needs.
38848	1479	4	And let my servant Edward Partridge, when he shall appoint a man his portion, give unto him a writing that shall secure unto him his portion, that he shall hold it, even this right and this inheritance in the church, until he transgresses and is not accounted worthy by the voice of the church, according to the laws and covenants of the church, to belong to the church.
38849	1479	5	And if he shall transgress and is not accounted worthy to belong to the church, he shall not have power to claim that portion which he has consecrated unto the bishop for the poor and needy of my church; therefore, he shall not retain the gift, but shall only have claim on that portion that is deeded unto him.
38850	1479	6	And thus all things shall be made sure, according to the laws of the land.
38851	1479	7	And let that which belongs to this people be appointed unto this people.
38852	1479	8	And the money which is left unto this people--let there be an agent appointed unto this people, to take the money to provide food and raiment, according to the wants of this people.
38853	1479	9	And let every man deal honestly, and be alike among this people, and receive alike, that ye may be one, even as I have commanded you.
38854	1479	10	And let that which belongeth to this people not be taken and given unto that of another church.
38855	1479	11	Wherefore, if another church would receive money of this church, let them pay unto this church again according as they shall agree;
38856	1479	12	And this shall be done through the bishop or the agent, which shall be appointed by the voice of the church.
38857	1479	13	And again, let the bishop appoint a storehouse unto this church; and let all things both in money and in meat, which are more than is needful for the wants of this people, be kept in the hands of the bishop.
38858	1479	14	And let him also reserve unto himself for his own wants, and for the wants of his family, as he shall be employed in doing this business.
38859	1479	15	And thus I grant unto this people a privilege of organizing themselves according to my laws.
38860	1479	16	And I consecrate unto them this land for a little season, until I, the Lord, shall provide for them otherwise, and command them to go hence;
38861	1479	17	And the hour and the day is not given unto them, wherefore let them act upon this land as for years, and this shall turn unto them for their good.
38862	1479	18	Behold, this shall be an example unto my servant Edward Partridge, in other places, in all churches.
38863	1479	19	And whoso is found a faithful, a just, and a wise steward shall enter into the joy of his Lord, and shall inherit eternal life.
38864	1479	20	Verily, I say unto you, I am Jesus Christ, who cometh quickly, in an hour you think not. Even so. Amen.
38865	1480	1	BEHOLD, thus saith the Lord unto the elders whom he hath called and chosen in these last days, by the voice of his Spirit--
38866	1480	2	Saying: I, the Lord, will make known unto you what I will that ye shall do from this time until the next conference, which shall be held in Missouri, upon the land which I will consecrate unto my people, which are a remnant of Jacob, and those who are heirs according to the covenant.
38867	1480	3	Wherefore, verily I say unto you, let my servants Joseph Smith, Jun., and Sidney Rigdon take their journey as soon as preparations can be made to leave their homes, and journey to the land of Missouri.
38868	1480	4	And inasmuch as they are faithful unto me, it shall be made known unto them what they shall do;
38869	1480	5	And it shall also, inasmuch as they are faithful, be made known unto them the land of your inheritance.
38870	1480	6	And inasmuch as they are not faithful, they shall be cut off, even as I will, as seemeth me good.
38871	1480	7	And again, verily I say unto you, let my servant Lyman Wight and my servant John Corrill take their journey speedily;
38872	1480	8	And also my servant John Murdock, and my servant Hyrum Smith, take their journey unto the same place by the way of Detroit.
38873	1480	9	And let them journey from thence preaching the word by the way, saying none other things than that which the prophets and apostles have written, and that which is taught them by the Comforter through the prayer of faith.
38874	1480	10	Let them go two by two, and thus let them preach by the way in every congregation, baptizing by water, and the laying on of the hands by the water's side.
38875	1480	11	For thus saith the Lord, I will cut my work short in righteousness, for the days come that I will send forth judgment unto victory.
38876	1480	12	And let my servant Lyman Wight beware, for Satan desireth to sift him as chaff.
38877	1480	13	And behold, he that is faithful shall be made ruler over many things.
38878	1480	14	And again, I will give unto you a pattern in all things, that ye may not be deceived; for Satan is abroad in the land, and he goeth forth deceiving the nations--
38879	1480	15	Wherefore he that prayeth, whose spirit is contrite, the same is accepted of me if he obey mine ordinances.
38880	1480	16	He that speaketh, whose spirit is contrite, whose language is meek and edifieth, the same is of God if he obey mine ordinances.
38881	1480	17	And again, he that trembleth under my power shall be made strong, and shall bring forth fruits of praise and wisdom, according to the revelations and truths which I have given you.
38882	1480	18	And again, he that is overcome and bringeth not forth fruits, even according to this pattern, is not of me.
38883	1480	19	Wherefore, by this pattern ye shall know the spirits in all cases under the whole heavens.
38884	1480	20	And the days have come; according to men's faith it shall be done unto them.
38885	1480	21	Behold, this commandment is given unto all the elders whom I have chosen.
38886	1480	22	And again, verily I say unto you, let my servant Thomas B. Marsh and my servant Ezra Thayre take their journey also, preaching the word by the way unto this same land.
38887	1480	23	And again, let my servant Isaac Morley and my servant Ezra Booth take their journey, also preaching the word by the way unto this same land.
38888	1480	24	And again, let my servants Edward Partridge and Martin Harris take their journey with my servants Sidney Rigdon and Joseph Smith, Jun.
38889	1480	25	Let my servants David Whitmer and Harvey Whitlock also take their journey, and preach by the way unto this same land.
38890	1480	26	And let my servants Parley P. Pratt and Orson Pratt take their journey, and preach by the way, even unto this same land.
38891	1480	27	And let my servants Solomon Hancock and Simeon Carter also take their journey unto this same land, and preach by the way.
38892	1480	28	Let my servants Edson Fuller and Jacob Scott also take their journey.
38893	1480	29	Let my servants Levi W. Hancock and Zebedee Coltrin also take their journey.
38894	1480	30	Let my servants Reynolds Cahoon and Samuel H. Smith also take their journey.
38895	1480	31	Let my servants Wheeler Baldwin and William Carter also take their journey.
38896	1480	32	And let my servants Newel Knight and Selah J. Griffin both be ordained, and also take their journey.
38897	1480	33	Yea, verily I say, let all these take their journey unto one place, in their several courses, and one man shall not build upon another's foundation, neither journey in another's track.
38898	1480	34	He that is faithful, the same shall be kept and blessed with much fruit.
38899	1480	35	And again, I say unto you, let my servants Joseph Wakefield and Solomon Humphrey take their journey into the eastern lands;
38900	1480	36	Let them labor with their families, declaring none other things than the prophets and apostles, that which they have seen and heard and most assuredly believe, that the prophecies may be fulfilled.
38901	1480	37	In consequence of transgression, let that which was bestowed upon Heman Basset be taken from him, and placed upon the head of Simonds Ryder.
38902	1480	38	And again, verily I say unto you, let Jared Carter be ordained a priest, and also George James be ordained a priest.
38903	1480	39	Let the residue of the elders watch over the churches, and declare the word in the regions round about them; and let them labor with their own hands that there be no idolatry nor wickedness practised.
38904	1480	40	And remember in all things the poor and the needy, the sick and the afflicted, for he that doeth not these things, the same is not my disciple.
38905	1480	41	And again, let my servants Joseph Smith, Jun., and Sidney Rigdon and Edward Partridge take with them a recommend from the church. And let there be one obtained for my servant Oliver Cowdery also.
38906	1480	42	And thus, even as I have said, if ye are faithful ye shall assemble yourselves together to rejoice upon the land of Missouri, which is the land of your inheritance, which is now the land of your enemies.
38907	1480	43	But, behold, I, the Lord, will hasten the city in its time, and will crown the faithful with joy and with rejoicing.
38908	1480	44	Behold, I am Jesus Christ, the Son of God, and I will lift them up at the last day. Even so. Amen.
38909	1481	1	BEHOLD, I say unto you, my servant Sidney Gilbert, that I have heard your prayers; and you have called upon me that it should be made known unto you, of the Lord your God, concerning your calling and election in the church, which I, the Lord, have raised up in these last days.
38910	1481	2	Behold, I, the Lord, who was crucified for the sins of the world, give unto you a commandment that you shall forsake the world.
38911	1481	3	Take upon you mine ordination, even that of an elder, to preach faith and repentance and remission of sins, according to my word, and the reception of the Holy Spirit by the laying on of hands;
38912	1481	4	And also to be an agent unto this church in the place which shall be appointed by the bishop, according to commandments which shall be given hereafter.
38913	1481	5	And again, verily I say unto you, you shall take your journey with my servants Joseph Smith, Jun., and Sidney Rigdon.
38914	1481	6	Behold, these are the first ordinances which you shall receive; and the residue shall be made known in a time to come, according to your labor in my vineyard.
38915	1481	7	And again, I would that ye should learn that he only is saved who endureth unto the end. Even so. Amen.
38916	1482	1	BEHOLD, thus saith the Lord, even Alpha and Omega, the beginning and the end, even he who was crucified for the sins of the world--
38917	1482	2	Behold, verily, verily, I say unto you, my servant Newel Knight, you shall stand fast in the office whereunto I have appointed you.
38918	1482	3	And if your brethren desire to escape their enemies, let them repent of all their sins, and become truly humble before me and contrite.
38919	1482	4	And as the covenant which they made unto me has been broken, even so it has become void and of none effect.
38920	1482	5	And wo to him by whom this offense cometh, for it had been better for him that he had been drowned in the depth of the sea.
38921	1482	6	But blessed are they who have kept the covenant and observed the commandment, for they shall obtain mercy.
38922	1482	7	Wherefore, go to now and flee the land, lest your enemies come upon you; and take your journey, and appoint whom you will to be your leader, and to pay moneys for you.
38923	1482	8	And thus you shall take your journey into the regions westward, unto the land of Missouri, unto the borders of the Lamanites.
38924	1482	9	And after you have done journeying, behold, I say unto you, seek ye a living like unto men, until I prepare a place for you.
38925	1482	10	And again, be patient in tribulation until I come; and, behold, I come quickly, and my reward is with me, and they who have sought me early shall find rest to their souls. Even so. Amen.
38926	1483	1	BEHOLD, thus saith the Lord unto you, my servant William, yea, even the Lord of the whole earth, thou art called and chosen; and after thou hast been baptized by water, which if you do with an eye single to my glory, you shall have a remission of your sins and a reception of the Holy Spirit by the laying on of hands;
38927	1483	2	And then thou shalt be ordained by the hand of my servant Joseph Smith, Jun., to be an elder unto this church, to preach repentance and remission of sins by way of baptism in the name of Jesus Christ, the Son of the living God.
38928	1483	3	And on whomsoever you shall lay your hands, if they are contrite before me, you shall have power to give the Holy Spirit.
38929	1483	4	And again, you shall be ordained to assist my servant Oliver Cowdery to do the work of printing, and of selecting and writing books for schools in this church, that little children also may receive instruction before me as is pleasing unto me.
38930	1483	5	And again, verily I say unto you, for this cause you shall take your journey with my servants Joseph Smith, Jun., and Sidney Rigdon, that you may be planted in the land of your inheritance to do this work.
38931	1483	6	And again, let my servant Joseph Coe also take his journey with them. The residue shall be made known hereafter, even as I will. Amen.
38932	1484	1	HEARKEN, O ye people who profess my name, saith the Lord your God; for behold, mine anger is kindled against the rebellious, and they shall know mine arm and mine indignation, in the day of visitation and of wrath upon the nations.
38933	1484	2	And he that will not take up his cross and follow me, and keep my commandments, the same shall not be saved.
38934	1484	3	Behold, I, the Lord, command; and he that will not obey shall be cut off in mine own due time, after I have commanded and the commandment is broken.
38935	1484	4	Wherefore I, the Lord, command and revoke, as it seemeth me good; and all this to be answered upon the heads of the rebellious, saith the Lord.
38936	1484	5	Wherefore, I revoke the commandment which was given unto my servants Thomas B. Marsh and Ezra Thayre, and give a new commandment unto my servant Thomas, that he shall take up his journey speedily to the land of Missouri, and my servant Selah J. Griffin shall also go with him.
38937	1484	6	For behold, I revoke the commandment which was given unto my servants Selah J. Griffin and Newel Knight, in consequence of the stiffneckedness of my people which are in Thompson, and their rebellions.
38938	1484	7	Wherefore, let my servant Newel Knight remain with them; and as many as will go may go, that are contrite before me, and be led by him to the land which I have appointed.
38939	1484	8	And again, verily I say unto you, that my servant Ezra Thayre must repent of his pride, and of his selfishness, and obey the former commandment which I have given him concerning the place upon which he lives.
38940	1484	9	And if he will do this, as there shall be no divisions made upon the land, he shall be appointed still to go to the land of Missouri;
38941	1484	10	Otherwise he shall receive the money which he has paid, and shall leave the place, and shall be cut off out of my church, saith the Lord God of hosts;
38942	1484	11	And though the heaven and the earth pass away, these words shall not pass away, but shall be fulfilled.
38943	1484	12	And if my servant Joseph Smith, Jun., must needs pay the money, behold, I, the Lord, will pay it unto him again in the land of Missouri, that those of whom he shall receive may be rewarded again according to that which they do;
38944	1484	13	For according to that which they do they shall receive, even in lands for their inheritance.
38945	1484	14	Behold, thus saith the Lord unto my people--you have many things to do and to repent of; for behold, your sins have come up unto me, and are not pardoned, because you seek to counsel in your own ways.
38946	1484	15	And your hearts are not satisfied. And ye obey not the truth, but have pleasure in unrighteousness.
38947	1484	16	Wo unto you rich men, that will not give your substance to the poor, for your riches will canker your souls; and this shall be your lamentation in the day of visitation, and of judgment, and of indignation: The harvest is past, the summer is ended, and my soul is not saved!
38948	1484	17	Wo unto you poor men, whose hearts are not broken, whose spirits are not contrite, and whose bellies are not satisfied, and whose hands are not stayed from laying hold upon other men's goods, whose eyes are full of greediness, and who will not labor with your own hands!
38949	1484	18	But blessed are the poor who are pure in heart, whose hearts are broken, and whose spirits are contrite, for they shall see the kingdom of God coming in power and great glory unto their deliverance; for the fatness of the earth shall be theirs.
38950	1484	19	For behold, the Lord shall come, and his recompense shall be with him, and he shall reward every man, and the poor shall rejoice;
38951	1484	20	And their generations shall inherit the earth from generation to generation, forever and ever. And now I make an end of speaking unto you. Even so. Amen.
38952	1485	1	HEARKEN, O ye elders of my church, saith the Lord your God, who have assembled yourselves together, according to my commandments, in this land, which is the land of Missouri, which is the land which I have appointed and consecrated for the gathering of the saints.
38953	1485	2	Wherefore, this is the land of promise, and the place for the city of Zion.
38954	1485	3	And thus saith the Lord your God, if you will receive wisdom here is wisdom. Behold, the place which is now called Independence is the center place; and a spot for the temple is lying westward, upon a lot which is not far from the courthouse.
38955	1485	4	Wherefore, it is wisdom that the land should be purchased by the saints, and also every tract lying westward, even unto the line running directly between Jew and Gentile;
38956	1485	5	And also every tract bordering by the prairies, inasmuch as my disciples are enabled to buy lands. Behold, this is wisdom, that they may obtain it for an everlasting inheritance.
38957	1485	6	And let my servant Sidney Gilbert stand in the office to which I have appointed him, to receive moneys, to be an agent unto the church, to buy land in all the regions round about, inasmuch as can be done in righteousness, and as wisdom shall direct.
38958	1485	7	And let my servant Edward Partridge stand in the office to which I have appointed him, and divide unto the saints their inheritance, even as I have commanded; and also those whom he has appointed to assist him.
38959	1485	8	And again, verily I say unto you, let my servant Sidney Gilbert plant himself in this place, and establish a store, that he may sell goods without fraud, that he may obtain money to buy lands for the good of the saints, and that he may obtain whatsoever things the disciples may need to plant them in their inheritance.
38960	1485	9	And also let my servant Sidney Gilbert obtain a license--behold here is wisdom, and whoso readeth let him understand--that he may send goods also unto the people, even by whom he will as clerks employed in his service;
38961	1485	10	And thus provide for my saints, that my gospel may be preached unto those who sit in darkness and in the region and shadow of death.
38962	1485	11	And again, verily I say unto you, let my servant William W. Phelps be planted in this place, and be established as a printer unto the church.
38963	1485	12	And lo, if the world receive his writings--behold here is wisdom--let him obtain whatsoever he can obtain in righteousness, for the good of the saints.
38964	1485	13	And let my servant Oliver Cowdery assist him, even as I have commanded, in whatsoever place I shall appoint unto him, to copy, and to correct, and select, that all things may be right before me, as it shall be proved by the Spirit through him.
38965	1485	14	And thus let those of whom I have spoken be planted in the land of Zion, as speedily as can be, with their families, to do those things even as I have spoken.
38966	1485	15	And now concerning the gathering--Let the bishop and the agent make preparations for those families which have been commanded to come to this land, as soon as possible, and plant them in their inheritance.
38967	1485	16	And unto the residue of both elders and members further directions shall be given hereafter. Even so. Amen.
38968	1486	1	HEARKEN, O ye elders of my church, and give ear to my word, and learn of me what I will concerning you, and also concerning this land unto which I have sent you.
38969	1486	2	For verily I say unto you, blessed is he that keepeth my commandments, whether in life or in death; and he that is faithful in tribulation, the reward of the same is greater in the kingdom of heaven.
38970	1486	3	Ye cannot behold with your natural eyes, for the present time, the design of your God concerning those things which shall come hereafter, and the glory which shall follow after much tribulation.
38971	1486	4	For after much tribulation come the blessings. Wherefore the day cometh that ye shall be crowned with much glory; the hour is not yet, but is nigh at hand.
38972	1486	5	Remember this, which I tell you before, that you may lay it to heart, and receive that which is to follow.
38973	1486	6	Behold, verily I say unto you, for this cause I have sent you--that you might be obedient, and that your hearts might be prepared to bear testimony of the things which are to come;
38974	1486	7	And also that you might be honored in laying the foundation, and in bearing record of the land upon which the Zion of God shall stand;
38975	1486	8	And also that a feast of fat things might be prepared for the poor; yea, a feast of fat things, of wine on the lees well refined, that the earth may know that the mouths of the prophets shall not fail;
38976	1486	9	Yea, a supper of the house of the Lord, well prepared, unto which all nations shall be invited.
38977	1486	10	First, the rich and the learned, the wise and the noble;
38978	1486	11	And after that cometh the day of my power; then shall the poor, the lame, and the blind, and the deaf, come in unto the marriage of the Lamb, and partake of the supper of the Lord, prepared for the great day to come.
38979	1486	12	Behold, I, the Lord, have spoken it.
38980	1486	13	And that the testimony might go forth from Zion, yea, from the mouth of the city of the heritage of God--
38981	1486	14	Yea, for this cause I have sent you hither, and have selected my servant Edward Partridge, and have appointed unto him his mission in this land.
38982	1486	15	But if he repent not of his sins, which are unbelief and blindness of heart, let him take heed lest he fall.
38983	1486	16	Behold his mission is given unto him, and it shall not be given again.
38984	1486	17	And whoso standeth in this mission is appointed to be a judge in Israel, like as it was in ancient days, to divide the lands of the heritage of God unto his children;
38985	1486	18	And to judge his people by the testimony of the just, and by the assistance of his counselors, according to the laws of the kingdom which are given by the prophets of God.
38986	1486	19	For verily I say unto you, my law shall be kept on this land.
38987	1486	20	Let no man think he is ruler; but let God rule him that judgeth, according to the counsel of his own will, or, in other words, him that counseleth or sitteth upon the judgment seat.
38988	1486	21	Let no man break the laws of the land, for he that keepeth the laws of God hath no need to break the laws of the land.
38989	1486	22	Wherefore, be subject to the powers that be, until he reigns whose right it is to reign, and subdues all enemies under his feet.
38990	1486	23	Behold, the laws which ye have received from my hand are the laws of the church, and in this light ye shall hold them forth. Behold, here is wisdom.
38991	1486	24	And now, as I spake concerning my servant Edward Partridge, this land is the land of his residence, and those whom he has appointed for his counselors; and also the land of the residence of him whom I have appointed to keep my storehouse;
38992	1486	25	Wherefore, let them bring their families to this land, as they shall counsel between themselves and me.
38993	1486	26	For behold, it is not meet that I should command in all things; for he that is compelled in all things, the same is a slothful and not a wise servant; wherefore he receiveth no reward.
38994	1486	27	Verily I say, men should be anxiously engaged in a good cause, and do many things of their own free will, and bring to pass much righteousness;
38995	1486	28	For the power is in them, wherein they are agents unto themselves. And inasmuch as men do good they shall in nowise lose their reward.
38996	1486	29	But he that doeth not anything until he is commanded, and receiveth a commandment with doubtful heart, and keepeth it with slothfulness, the same is damned.
38997	1486	30	Who am I that made man, saith the Lord, that will hold him guiltless that obeys not my commandments?
38998	1486	31	Who am I, saith the Lord, that have promised and have not fulfilled?
38999	1486	32	I command and men obey not; I revoke and they receive not the blessing.
39000	1486	33	Then they say in their hearts: This is not the work of the Lord, for his promises are not fulfilled. But wo unto such, for their reward lurketh beneath, and not from above.
39001	1486	34	And now I give unto you further directions concerning this land.
39002	1486	35	It is wisdom in me that my servant Martin Harris should be an example unto the church, in laying his moneys before the bishop of the church.
39003	1486	36	And also, this is a law unto every man that cometh unto this land to receive an inheritance; and he shall do with his moneys according as the law directs.
39004	1486	37	And it is wisdom also that there should be lands purchased in Independence, for the place of the storehouse, and also for the house of the printing.
39005	1486	38	And other directions concerning my servant Martin Harris shall be given him of the Spirit, that he may receive his inheritance as seemeth him good;
39006	1486	39	And let him repent of his sins, for he seeketh the praise of the world.
39007	1486	40	And also let my servant William W. Phelps stand in the office to which I have appointed him, and receive his inheritance in the land;
39008	1486	41	And also he hath need to repent, for I, the Lord, am not well pleased with him, for he seeketh to excel, and he is not sufficiently meek before me.
39009	1486	42	Behold, he who has repented of his sins, the same is forgiven, and I, the Lord, remember them no more.
39010	1486	43	By this ye may know if a man repenteth of his sins--behold, he will confess them and forsake them.
39011	1486	44	And now, verily, I say concerning the residue of the elders of my church, the time has not yet come, for many years, for them to receive their inheritance in this land, except they desire it through the prayer of faith, only as it shall be appointed unto them of the Lord.
39012	1486	45	For, behold, they shall push the people together from the ends of the earth.
39013	1486	46	Wherefore, assemble yourselves together; and they who are not appointed to stay in this land, let them preach the gospel in the regions round about; and after that let them return to their homes.
39014	1486	47	Let them preach by the way, and bear testimony of the truth in all places, and call upon the rich, the high and the low, and the poor to repent.
39015	1486	48	And let them build up churches, inasmuch as the inhabitants of the earth will repent.
39016	1486	49	And let there be an agent appointed by the voice of the church, unto the church in Ohio, to receive moneys to purchase lands in Zion.
39017	1486	50	And I give unto my servant Sidney Rigdon a commandment, that he shall write a description of the land of Zion, and a statement of the will of God, as it shall be made known by the Spirit unto him;
39018	1486	51	And an epistle and subscription, to be presented unto all the churches to obtain moneys, to be put into the hands of the bishop, of himself or the agent, as seemeth him good or as he shall direct, to purchase lands for an inheritance for the children of God.
39019	1486	52	For, behold, verily I say unto you, the Lord willeth that the disciples and the children of men should open their hearts, even to purchase this whole region of country, as soon as time will permit.
39020	1486	53	Behold, here is wisdom. Let them do this lest they receive none inheritance, save it be by the shedding of blood.
39021	1486	54	And again, inasmuch as there is land obtained, let there be workmen sent forth of all kinds unto this land, to labor for the saints of God.
39022	1486	55	Let all these things be done in order; and let the privileges of the lands be made known from time to time, by the bishop or the agent of the church.
39023	1486	56	And let the work of the gathering be not in haste, nor by flight; but let it be done as it shall be counseled by the elders of the church at the conferences, according to the knowledge which they receive from time to time.
39024	1486	57	And let my servant Sidney Rigdon consecrate and dedicate this land, and the spot for the temple, unto the Lord.
39025	1486	58	And let a conference meeting be called; and after that let my servants Sidney Rigdon and Joseph Smith, Jun., return, and also Oliver Cowdery with them, to accomplish the residue of the work which I have appointed unto them in their own land, and the residue as shall be ruled by the conferences.
39026	1486	59	And let no man return from this land except he bear record by the way, of that which he knows and most assuredly believes.
39027	1486	60	Let that which has been bestowed upon Ziba Peterson be taken from him; and let him stand as a member in the church, and labor with his own hands, with the brethren, until he is sufficiently chastened for all his sins; for he confesseth them not, and he thinketh to hide them.
39028	1486	61	Let the residue of the elders of this church, who are coming to this land, some of whom are exceedingly blessed even above measure, also hold a conference upon this land.
39029	1486	62	And let my servant Edward Partridge direct the conference which shall be held by them.
39030	1486	63	And let them also return, preaching the gospel by the way, bearing record of the things which are revealed unto them.
39031	1486	64	For, verily, the sound must go forth from this place into all the world, and unto the uttermost parts of the earth--the gospel must be preached unto every creature, with signs following them that believe.
39032	1486	65	And behold the Son of Man cometh. Amen.
39033	1487	1	BEHOLD, blessed, saith the Lord, are they who have come up unto this land with an eye single to my glory, according to my commandments.
39034	1487	2	For those that live shall inherit the earth, and those that die shall rest from all their labors, and their works shall follow them; and they shall receive a crown in the mansions of my Father, which I have prepared for them.
39035	1487	3	Yea, blessed are they whose feet stand upon the land of Zion, who have obeyed my gospel; for they shall receive for their reward the good things of the earth, and it shall bring forth in its strength.
39036	1487	4	And they shall also be crowned with blessings from above, yea, and with commandments not a few, and with revelations in their time--they that are faithful and diligent before me.
39037	1487	5	Wherefore, I give unto them a commandment, saying thus: Thou shalt love the Lord thy God with all thy heart, with all thy might, mind, and strength; and in the name of Jesus Christ thou shalt serve him.
39038	1487	6	Thou shalt love thy neighbor as thyself. Thou shalt not steal; neither commit adultery, nor kill, nor do anything like unto it.
39039	1487	7	Thou shalt thank the Lord thy God in all things.
39040	1487	8	Thou shalt offer a sacrifice unto the Lord thy God in righteousness, even that of a broken heart and a contrite spirit.
39041	1487	9	And that thou mayest more fully keep thyself unspotted from the world, thou shalt go to the house of prayer and offer up thy sacraments upon my holy day;
39042	1487	10	For verily this is a day appointed unto you to rest from your labors, and to pay thy devotions unto the Most High;
39043	1487	11	Nevertheless thy vows shall be offered up in righteousness on all days and at all times;
39044	1487	12	But remember that on this, the Lord's day, thou shalt offer thine oblations and thy sacraments unto the Most High, confessing thy sins unto thy brethren, and before the Lord.
39045	1487	13	And on this day thou shalt do none other thing, only let thy food be prepared with singleness of heart that thy fasting may be perfect, or, in other words, that thy joy may be full.
39046	1487	14	Verily, this is fasting and prayer, or in other words, rejoicing and prayer.
39047	1487	15	And inasmuch as ye do these things with thanksgiving, with cheerful hearts and countenances, not with much laughter, for this is sin, but with a glad heart and a cheerful countenance--
39048	1487	16	Verily I say, that inasmuch as ye do this, the fulness of the earth is yours, the beasts of the field and the fowls of the air, and that which climbeth upon the trees and walketh upon the earth;
39049	1487	17	Yea, and the herb, and the good things which come of the earth, whether for food or for raiment, or for houses, or for barns, or for orchards, or for gardens, or for vineyards;
39050	1487	18	Yea, all things which come of the earth, in the season thereof, are made for the benefit and the use of man, both to please the eye and to gladden the heart;
39051	1487	19	Yea, for food and for raiment, for taste and for smell, to strengthen the body and to enliven the soul.
39052	1487	20	And it pleaseth God that he hath given all these things unto man; for unto this end were they made to be used, with judgment, not to excess, neither by extortion.
39053	1487	21	And in nothing doth man offend God, or against none is his wrath kindled, save those who confess not his hand in all things, and obey not his commandments.
39054	1487	22	Behold, this is according to the law and the prophets; wherefore, trouble me no more concerning this matter.
39055	1487	23	But learn that he who doeth the works of righteousness shall receive his reward, even peace in this world and eternal life in the world to come.
39056	1487	24	I, the Lord, have spoken it, and the Spirit beareth record. Amen.
39057	1488	1	BEHOLD, thus saith the Lord unto the elders of his church, who are to return speedily to the land from whence they came: Behold, it pleaseth me, that you have come up hither;
39058	1488	2	But with some I am not well pleased, for they will not open their mouths, but they hide the talent which I have given unto them, because of the fear of man. Wo unto such, for mine anger is kindled against them.
39059	1488	3	And it shall come to pass, if they are not more faithful unto me, it shall be taken away, even that which they have.
39060	1488	4	For I, the Lord, rule in the heavens above, and among the armies of the earth; and in the day when I shall make up my jewels, all men shall know what it is that bespeaketh the power of God.
39061	1488	5	But, verily, I will speak unto you concerning your journey unto the land from whence you came. Let there be a craft made, or bought, as seemeth you good, it mattereth not unto me, and take your journey speedily for the place which is called St. Louis.
39062	1488	6	And from thence let my servants, Sidney Rigdon, Joseph Smith, Jun., and Oliver Cowdery, take their journey for Cincinnati;
39063	1488	7	And in this place let them lift up their voice and declare my word with loud voices, without wrath or doubting, lifting up holy hands upon them. For I am able to make you holy, and your sins are forgiven you.
39064	1488	8	And let the residue take their journey from St. Louis, two by two, and preach the word, not in haste, among the congregations of the wicked, until they return to the churches from whence they came.
39065	1488	9	And all this for the good of the churches; for this intent have I sent them.
39066	1488	10	And let my servant Edward Partridge impart of the money which I have given him, a portion unto mine elders who are commanded to return;
39067	1488	11	And he that is able, let him return it by the way of the agent; and he that is not, of him it is not required.
39068	1488	12	And now I speak of the residue who are to come unto this land.
39069	1488	13	Behold, they have been sent to preach my gospel among the congregations of the wicked; wherefore, I give unto them a commandment, thus: Thou shalt not idle away thy time, neither shalt thou bury thy talent that it may not be known.
39070	1488	14	And after thou hast come up unto the land of Zion, and hast proclaimed my word, thou shalt speedily return, proclaiming my word among the congregations of the wicked, not in haste, neither in wrath nor with strife.
39071	1488	15	And shake off the dust of thy feet against those who receive thee not, not in their presence, lest thou provoke them, but in secret; and wash thy feet, as a testimony against them in the day of judgment.
39072	1488	16	Behold, this is sufficient for you, and the will of him who hath sent you.
39073	1488	17	And by the mouth of my servant Joseph Smith, Jun., it shall be made known concerning Sidney Rigdon and Oliver Cowdery. The residue hereafter. Even so. Amen.
39074	1489	1	BEHOLD, and hearken unto the voice of him who has all power, who is from everlasting to everlasting, even Alpha and Omega, the beginning and the end.
39075	1489	2	Behold, verily thus saith the Lord unto you, O ye elders of my church, who are assembled upon this spot, whose sins are now forgiven you, for I, the Lord, forgive sins, and am merciful unto those who confess their sins with humble hearts;
39076	1489	3	But verily I say unto you, that it is not needful for this whole company of mine elders to be moving swiftly upon the waters, whilst the inhabitants on either side are perishing in unbelief.
39077	1489	4	Nevertheless, I suffered it that ye might bear record; behold, there are many dangers upon the waters, and more especially hereafter;
39078	1489	5	For I, the Lord, have decreed in mine anger many destructions upon the waters; yea, and especially upon these waters.
39079	1489	6	Nevertheless, all flesh is in mine hand, and he that is faithful among you shall not perish by the waters.
39080	1489	7	Wherefore, it is expedient that my servant Sidney Gilbert and my servant William W. Phelps be in haste upon their errand and mission.
39081	1489	8	Nevertheless, I would not suffer that ye should part until you were chastened for all your sins, that you might be one, that you might not perish in wickedness;
39082	1489	9	But now, verily I say, it behooveth me that ye should part. Wherefore let my servants Sidney Gilbert and William W. Phelps take their former company, and let them take their journey in haste that they may fill their mission, and through faith they shall overcome;
39083	1489	10	And inasmuch as they are faithful they shall be preserved, and I, the Lord, will be with them.
39084	1489	11	And let the residue take that which is needful for clothing.
39085	1489	12	Let my servant Sidney Gilbert take that which is not needful with him, as you shall agree.
39086	1489	13	And now, behold, for your good I gave unto you a commandment concerning these things; and I, the Lord, will reason with you as with men in days of old.
39087	1489	14	Behold, I, the Lord, in the beginning blessed the waters; but in the last days, by the mouth of my servant John, I cursed the waters.
39088	1489	15	Wherefore, the days will come that no flesh shall be safe upon the waters.
39089	1489	16	And it shall be said in days to come that none is able to go up to the land of Zion upon the waters, but he that is upright in heart.
39090	1489	17	And, as I, the Lord, in the beginning cursed the land, even so in the last days have I blessed it, in its time, for the use of my saints, that they may partake the fatness thereof.
39091	1489	18	And now I give unto you a commandment that what I say unto one I say unto all, that you shall forewarn your brethren concerning these waters, that they come not in journeying upon them, lest their faith fail and they are caught in snares;
39092	1489	19	I, the Lord, have decreed, and the destroyer rideth upon the face thereof, and I revoke not the decree.
39093	1489	20	I, the Lord, was angry with you yesterday, but today mine anger is turned away.
39094	1489	21	Wherefore, let those concerning whom I have spoken, that should take their journey in haste--again I say unto you, let them take their journey in haste.
39095	1489	22	And it mattereth not unto me, after a little, if it so be that they fill their mission, whether they go by water or by land; let this be as it is made known unto them according to their judgments hereafter.
39096	1489	23	And now, concerning my servants, Sidney Rigdon, Joseph Smith, Jun., and Oliver Cowdery, let them come not again upon the waters, save it be upon the canal, while journeying unto their homes; or in other words they shall not come upon the waters to journey, save upon the canal.
39097	1489	24	Behold, I, the Lord, have appointed a way for the journeying of my saints; and behold, this is the way--that after they leave the canal they shall journey by land, inasmuch as they are commanded to journey and go up unto the land of Zion;
39098	1489	25	And they shall do like unto the children of Israel, pitching their tents by the way.
39099	1489	26	And, behold, this commandment you shall give unto all your brethren.
39100	1489	27	Nevertheless, unto whom is given power to command the waters, unto him it is given by the Spirit to know all his ways;
39101	1489	28	Wherefore, let him do as the Spirit of the living God commandeth him, whether upon the land or upon the waters, as it remaineth with me to do hereafter.
39102	1489	29	And unto you is given the course for the saints, or the way for the saints of the camp of the Lord, to journey.
39103	1489	30	And again, verily I say unto you, my servants, Sidney Rigdon, Joseph Smith, Jun., and Oliver Cowdery, shall not open their mouths in the congregations of the wicked until they arrive at Cincinnati;
39104	1489	31	And in that place they shall lift up their voices unto God against that people, yea, unto him whose anger is kindled against their wickedness, a people who are well-nigh ripened for destruction.
39105	1489	32	And from thence let them journey for the congregations of their brethren, for their labors even now are wanted more abundantly among them than among the congregations of the wicked.
39106	1489	33	And now, concerning the residue, let them journey and declare the word among the congregations of the wicked, inasmuch as it is given;
39107	1489	34	And inasmuch as they do this they shall rid their garments, and they shall be spotless before me.
39108	1489	35	And let them journey together, or two by two, as seemeth them good, only let my servant Reynolds Cahoon, and my servant Samuel H. Smith, with whom I am well pleased, be not separated until they return to their homes, and this for a wise purpose in me.
39109	1489	36	And now, verily I say unto you, and what I say unto one I say unto all, be of good cheer, little children; for I am in your midst, and I have not forsaken you;
39110	1489	37	And inasmuch as you have humbled yourselves before me, the blessings of the kingdom are yours.
39111	1489	38	Gird up your loins and be watchful and be sober, looking forth for the coming of the Son of Man, for he cometh in an hour you think not.
39112	1489	39	Pray always that you enter not into temptation, that you may abide the day of his coming, whether in life or in death. Even so. Amen.
39113	1490	1	BEHOLD, and hearken, O ye elders of my church, saith the Lord your God, even Jesus Christ, your advocate, who knoweth the weakness of man and how to succor them who are tempted.
39114	1490	2	And verily mine eyes are upon those who have not as yet gone up unto the land of Zion; wherefore your mission is not yet full.
39115	1490	3	Nevertheless, ye are blessed, for the testimony which ye have borne is recorded in heaven for the angels to look upon; and they rejoice over you, and your sins are forgiven you.
39116	1490	4	And now continue your journey. Assemble yourselves upon the land of Zion; and hold a meeting and rejoice together, and offer a sacrament unto the Most High.
39117	1490	5	And then you may return to bear record, yea, even altogether, or two by two, as seemeth you good, it mattereth not unto me; only be faithful, and declare glad tidings unto the inhabitants of the earth, or among the congregations of the wicked.
39118	1490	6	Behold, I, the Lord, have brought you together that the promise might be fulfilled, that the faithful among you should be preserved and rejoice together in the land of Missouri. I, the Lord, promise the faithful and cannot lie.
39119	1490	7	I, the Lord, am willing, if any among you desire to ride upon horses, or upon mules, or in chariots, he shall receive this blessing, if he receive it from the hand of the Lord, with a thankful heart in all things.
39120	1490	8	These things remain with you to do according to judgment and the directions of the Spirit.
39121	1490	9	Behold, the kingdom is yours. And behold, and lo, I am with the faithful always. Even so. Amen.
39122	1491	1	HEARKEN, O ye people, and open your hearts and give ear from afar; and listen, you that call yourselves the people of the Lord, and hear the word of the Lord and his will concerning you.
39123	1491	2	Yea, verily, I say, hear the word of him whose anger is kindled against the wicked and rebellious;
39124	1491	3	Who willeth to take even them whom he will take, and preserveth in life them whom he will preserve;
39125	1491	4	Who buildeth up at his own will and pleasure; and destroyeth when he pleases, and is able to cast the soul down to hell.
39126	1491	5	Behold, I, the Lord, utter my voice, and it shall be obeyed.
39127	1491	6	Wherefore, verily I say, let the wicked take heed, and let the rebellious fear and tremble; and let the unbelieving hold their lips, for the day of wrath shall come upon them as a whirlwind, and all flesh shall know that I am God.
39128	1491	7	And he that seeketh signs shall see signs, but not unto salvation.
39129	1491	8	Verily, I say unto you, there are those among you who seek signs, and there have been such even from the beginning;
39130	1491	9	But, behold, faith cometh not by signs, but signs follow those that believe.
39131	1491	10	Yea, signs come by faith, not by the will of men, nor as they please, but by the will of God.
39132	1491	11	Yea, signs come by faith, unto mighty works, for without faith no man pleaseth God; and with whom God is angry he is not well pleased; wherefore, unto such he showeth no signs, only in wrath unto their condemnation.
39133	1491	12	Wherefore, I, the Lord, am not pleased with those among you who have sought after signs and wonders for faith, and not for the good of men unto my glory.
39134	1491	13	Nevertheless, I give commandments, and many have turned away from my commandments and have not kept them.
39135	1491	14	There were among you adulterers and adulteresses; some of whom have turned away from you, and others remain with you that hereafter shall be revealed.
39136	1491	15	Let such beware and repent speedily, lest judgment shall come upon them as a snare, and their folly shall be made manifest, and their works shall follow them in the eyes of the people.
39137	1491	16	And verily I say unto you, as I have said before, he that looketh on a woman to lust after her, or if any shall commit adultery in their hearts, they shall not have the Spirit, but shall deny the faith and shall fear.
39138	1491	17	Wherefore, I, the Lord, have said that the fearful, and the unbelieving, and all liars, and whosoever loveth and maketh a lie, and the whoremonger, and the sorcerer, shall have their part in that lake which burneth with fire and brimstone, which is the second death.
39139	1491	18	Verily I say, that they shall not have part in the first resurrection.
39140	1491	19	And now behold, I, the Lord, say unto you that ye are not justified, because these things are among you.
39141	1491	20	Nevertheless, he that endureth in faith and doeth my will, the same shall overcome, and shall receive an inheritance upon the earth when the day of transfiguration shall come;
39142	1491	21	When the earth shall be transfigured, even according to the pattern which was shown unto mine apostles upon the mount; of which account the fulness ye have not yet received.
39143	1491	22	And now, verily I say unto you, that as I said that I would make known my will unto you, behold I will make it known unto you, not by the way of commandment, for there are many who observe not to keep my commandments.
39144	1491	23	But unto him that keepeth my commandments I will give the mysteries of my kingdom, and the same shall be in him a well of living water, springing up unto everlasting life.
39145	1491	24	And now, behold, this is the will of the Lord your God concerning his saints, that they should assemble themselves together unto the land of Zion, not in haste, lest there should be confusion, which bringeth pestilence.
39146	1491	25	Behold, the land of Zion--I, the Lord, hold it in mine own hands;
39147	1491	26	Nevertheless, I, the Lord, render unto Caesar the things which are Caesar's.
39148	1491	27	Wherefore, I the Lord will that you should purchase the lands, that you may have advantage of the world, that you may have claim on the world, that they may not be stirred up unto anger.
39149	1491	28	For Satan putteth it into their hearts to anger against you, and to the shedding of blood.
39150	1491	29	Wherefore, the land of Zion shall not be obtained but by purchase or by blood, otherwise there is none inheritance for you.
39151	1491	30	And if by purchase, behold you are blessed;
39152	1491	31	And if by blood, as you are forbidden to shed blood, lo, your enemies are upon you, and ye shall be scourged from city to city, and from synagogue to synagogue, and but few shall stand to receive an inheritance.
39153	1491	32	I, the Lord, am angry with the wicked; I am holding my Spirit from the inhabitants of the earth.
39154	1491	33	I have sworn in my wrath, and decreed wars upon the face of the earth, and the wicked shall slay the wicked, and fear shall come upon every man;
39155	1491	34	And the saints also shall hardly escape; nevertheless, I, the Lord, am with them, and will come down in heaven from the presence of my Father and consume the wicked with unquenchable fire.
39156	1491	35	And behold, this is not yet, but by and by.
39157	1491	36	Wherefore, seeing that I, the Lord, have decreed all these things upon the face of the earth, I will that my saints should be assembled upon the land of Zion;
39158	1491	37	And that every man should take righteousness in his hands and faithfulness upon his loins, and lift a warning voice unto the inhabitants of the earth; and declare both by word and by flight that desolation shall come upon the wicked.
39159	1491	38	Wherefore, let my disciples in Kirtland arrange their temporal concerns, who dwell upon this farm.
39160	1491	39	Let my servant Titus Billings, who has the care thereof, dispose of the land, that he may be prepared in the coming spring to take his journey up unto the land of Zion, with those that dwell upon the face thereof, excepting those whom I shall reserve unto myself, that shall not go until I shall command them.
39161	1491	40	And let all the moneys which can be spared, it mattereth not unto me whether it be little or much, be sent up unto the land of Zion, unto them whom I have appointed to receive.
39162	1491	41	Behold, I, the Lord, will give unto my servant Joseph Smith, Jun., power that he shall be enabled to discern by the Spirit those who shall go up unto the land of Zion, and those of my disciples who shall tarry.
39163	1491	42	Let my servant Newel K. Whitney retain his store, or in other words, the store, yet for a little season.
39164	1491	43	Nevertheless, let him impart all the money which he can impart, to be sent up unto the land of Zion.
39165	1491	44	Behold, these things are in his own hands, let him do according to wisdom.
39166	1491	45	Verily I say, let him be ordained as an agent unto the disciples that shall tarry, and let him be ordained unto this power;
39167	1491	46	And now speedily visit the churches, expounding these things unto them, with my servant Oliver Cowdery. Behold, this is my will, obtaining moneys even as I have directed.
39168	1491	47	He that is faithful and endureth shall overcome the world.
39169	1491	48	He that sendeth up treasures unto the land of Zion shall receive an inheritance in this world, and his works shall follow him, and also a reward in the world to come.
39170	1491	49	Yea, and blessed are the dead that die in the Lord, from henceforth, when the Lord shall come, and old things shall pass away, and all things become new, they shall rise from the dead and shall not die after, and shall receive an inheritance before the Lord, in the holy city.
39171	1491	50	And he that liveth when the Lord shall come, and hath kept the faith, blessed is he; nevertheless, it is appointed to him to die at the age of man.
39172	1491	51	Wherefore, children shall grow up until they become old; old men shall die; but they shall not sleep in the dust, but they shall be changed in the twinkling of an eye.
39173	1491	52	Wherefore, for this cause preached the apostles unto the world the resurrection of the dead.
39174	1491	53	These things are the things that ye must look for; and, speaking after the manner of the Lord, they are now nigh at hand, and in a time to come, even in the day of the coming of the Son of Man.
39175	1491	54	And until that hour there will be foolish virgins among the wise; and at that hour cometh an entire separation of the righteous and the wicked; and in that day will I send mine angels to pluck out the wicked and cast them into unquenchable fire.
39176	1491	55	And now behold, verily I say unto you, I, the Lord, am not pleased with my servant Sidney Rigdon; he exalted himself in his heart, and received not counsel, but grieved the Spirit;
39177	1491	56	Wherefore his writing is not acceptable unto the Lord, and he shall make another; and if the Lord receive it not, behold he standeth no longer in the office to which I have appointed him.
39178	1491	57	And again, verily I say unto you, those who desire in their hearts, in meekness, to warn sinners to repentance, let them be ordained unto this power.
39179	1491	58	For this is a day of warning, and not a day of many words. For I, the Lord, am not to be mocked in the last days.
39180	1491	59	Behold, I am from above, and my power lieth beneath. I am over all, and in all, and through all, and search all things, and the day cometh that all things shall be subject unto me.
39181	1491	60	Behold, I am Alpha and Omega, even Jesus Christ.
39182	1491	61	Wherefore, let all men beware how they take my name in their lips--
39183	1491	62	For behold, verily I say, that many there be who are under this condemnation, who use the name of the Lord, and use it in vain, having not authority.
39184	1491	63	Wherefore, let the church repent of their sins, and I, the Lord, will own them; otherwise they shall be cut off.
39185	1491	64	Remember that that which cometh from above is sacred, and must be spoken with care, and by constraint of the Spirit; and in this there is no condemnation, and ye receive the Spirit through prayer; wherefore, without this there remaineth condemnation.
39186	1491	65	Let my servants, Joseph Smith, Jun., and Sidney Rigdon, seek them a home, as they are taught through prayer by the Spirit.
39187	1491	66	These things remain to overcome through patience, that such may receive a more exceeding and eternal weight of glory, otherwise, a greater condemnation. Amen.
39188	1492	1	BEHOLD, thus saith the Lord your God unto you, O ye elders of my church, hearken ye and hear, and receive my will concerning you.
39189	1492	2	For verily I say unto you, I will that ye should overcome the world; wherefore I will have compassion upon you.
39190	1492	3	There are those among you who have sinned; but verily I say, for this once, for mine own glory, and for the salvation of souls, I have forgiven you your sins.
39191	1492	4	I will be merciful unto you, for I have given unto you the kingdom.
39192	1492	5	And the keys of the mysteries of the kingdom shall not be taken from my servant Joseph Smith, Jun., through the means I have appointed, while he liveth, inasmuch as he obeyeth mine ordinances.
39193	1492	6	There are those who have sought occasion against him without cause;
39194	1492	7	Nevertheless, he has sinned; but verily I say unto you, I, the Lord, forgive sins unto those who confess their sins before me and ask forgiveness, who have not sinned unto death.
39195	1492	8	My disciples, in days of old, sought occasion against one another and forgave not one another in their hearts; and for this evil they were afflicted and sorely chastened.
39196	1492	9	Wherefore, I say unto you, that ye ought to forgive one another; for he that forgiveth not his brother his trespasses standeth condemned before the Lord; for there remaineth in him the greater sin.
39197	1492	10	I, the Lord, will forgive whom I will forgive, but of you it is required to forgive all men.
39198	1492	11	And ye ought to say in your hearts--let God judge between me and thee, and reward thee according to thy deeds.
39199	1492	12	And him that repenteth not of his sins, and confesseth them not, ye shall bring before the church, and do with him as the scripture saith unto you, either by commandment or by revelation.
39200	1492	13	And this ye shall do that God may be glorified--not because ye forgive not, having not compassion, but that ye may be justified in the eyes of the law, that ye may not offend him who is your lawgiver--
39201	1492	14	Verily I say, for this cause ye shall do these things.
39202	1492	15	Behold, I, the Lord, was angry with him who was my servant Ezra Booth, and also my servant Isaac Morley, for they kept not the law, neither the commandment;
39203	1492	16	They sought evil in their hearts, and I, the Lord, withheld my Spirit. They condemned for evil that thing in which there was no evil; nevertheless I have forgiven my servant Isaac Morley.
39204	1492	17	And also my servant Edward Partridge, behold, he hath sinned, and Satan seeketh to destroy his soul; but when these things are made known unto them, and they repent of the evil, they shall be forgiven.
39205	1492	18	And now, verily I say that it is expedient in me that my servant Sidney Gilbert, after a few weeks, shall return upon his business, and to his agency in the land of Zion;
39206	1492	19	And that which he hath seen and heard may be made known unto my disciples, that they perish not. And for this cause have I spoken these things.
39207	1492	20	And again, I say unto you, that my servant Isaac Morley may not be tempted above that which he is able to bear, and counsel wrongfully to your hurt, I gave commandment that his farm should be sold.
39208	1492	21	I will not that my servant Frederick G. Williams should sell his farm, for I, the Lord, will to retain a strong hold in the land of Kirtland, for the space of five years, in the which I will not overthrow the wicked, that thereby I may save some.
39209	1492	22	And after that day, I, the Lord, will not hold any guilty that shall go with an open heart up to the land of Zion; for I, the Lord, require the hearts of the children of men.
39210	1492	23	Behold, now it is called today until the coming of the Son of Man, and verily it is a day of sacrifice, and a day for the tithing of my people; for he that is tithed shall not be burned at his coming.
39211	1492	24	For after today cometh the burning--this is speaking after the manner of the Lord--for verily I say, tomorrow all the proud and they that do wickedly shall be as stubble; and I will burn them up, for I am the Lord of Hosts; and I will not spare any that remain in Babylon.
39212	1492	25	Wherefore, if ye believe me, ye will labor while it is called today.
39213	1492	26	And it is not meet that my servants, Newel K. Whitney and Sidney Gilbert, should sell their store and their possessions here; for this is not wisdom until the residue of the church, which remaineth in this place, shall go up unto the land of Zion.
39214	1492	27	Behold, it is said in my laws, or forbidden, to get in debt to thine enemies;
39215	1492	28	But behold, it is not said at any time that the Lord should not take when he please, and pay as seemeth him good.
39216	1492	29	Wherefore, as ye are agents, ye are on the Lord's errand; and whatever ye do according to the will of the Lord is the Lord's business.
39217	1492	30	And he hath set you to provide for his saints in these last days, that they may obtain an inheritance in the land of Zion.
39218	1492	31	And behold, I, the Lord, declare unto you, and my words are sure and shall not fail, that they shall obtain it.
39219	1492	32	But all things must come to pass in their time.
39220	1492	33	Wherefore, be not weary in well-doing, for ye are laying the foundation of a great work. And out of small things proceedeth that which is great.
39221	1492	34	Behold, the Lord requireth the heart and a willing mind; and the willing and obedient shall eat the good of the land of Zion in these last days.
39222	1492	35	And the rebellious shall be cut off out of the land of Zion, and shall be sent away, and shall not inherit the land.
39223	1492	36	For, verily I say that the rebellious are not of the blood of Ephraim, wherefore they shall be plucked out.
39224	1492	37	Behold, I, the Lord, have made my church in these last days like unto a judge sitting on a hill, or in a high place, to judge the nations.
39225	1492	38	For it shall come to pass that the inhabitants of Zion shall judge all things pertaining to Zion.
39226	1492	39	And liars and hypocrites shall be proved by them, and they who are not apostles and prophets shall be known.
39227	1492	40	And even the bishop, who is a judge, and his counselors, if they are not faithful in their stewardships shall be condemned, and others shall be planted in their stead.
39228	1492	41	For, behold, I say unto you that Zion shall flourish, and the glory of the Lord shall be upon her;
39229	1492	42	And she shall be an ensign unto the people, and there shall come unto her out of every nation under heaven.
39230	1492	43	And the day shall come when the nations of the earth shall tremble because of her, and shall fear because of her terrible ones. The Lord hath spoken it. Amen.
39231	1493	1	HEARKEN, and lo, a voice as of one sent down from on high, who is mighty and powerful, whose going forth is unto the ends of the earth, yea, whose voice is unto men--Prepare ye the way of the Lord, make his paths straight.
39232	1493	2	The keys of the kingdom of God are committed unto man on the earth, and from thence shall the gospel roll forth unto the ends of the earth, as the stone which is cut out of the mountain without hands shall roll forth, until it has filled the whole earth.
39233	1493	3	Yea, a voice crying--Prepare ye the way of the Lord, prepare ye the supper of the Lamb, make ready for the Bridegroom.
39234	1493	4	Pray unto the Lord, call upon his holy name, make known his wonderful works among the people.
39235	1493	5	Call upon the Lord, that his kingdom may go forth upon the earth, that the inhabitants thereof may receive it, and be prepared for the days to come, in the which the Son of Man shall come down in heaven, clothed in the brightness of his glory, to meet the kingdom of God which is set up on the earth.
39236	1493	6	Wherefore, may the kingdom of God go forth, that the kingdom of heaven may come, that thou, O God, mayest be glorified in heaven so on earth, that thine enemies may be subdued; for thine is the honor, power and glory, forever and ever. Amen.
39237	1494	1	BEHOLD, thus saith the Lord unto my servant William E. McLellin--Blessed are you, inasmuch as you have turned away from your iniquities, and have received my truths, saith the Lord your Redeemer, the Savior of the world, even of as many as believe on my name.
39238	1494	2	Verily I say unto you, blessed are you for receiving mine everlasting covenant, even the fulness of my gospel, sent forth unto the children of men, that they might have life and be made partakers of the glories which are to be revealed in the last days, as it was written by the prophets and apostles in days of old.
39239	1494	3	Verily I say unto you, my servant William, that you are clean, but not all; repent, therefore, of those things which are not pleasing in my sight, saith the Lord, for the Lord will show them unto you.
39240	1494	4	And now, verily, I, the Lord, will show unto you what I will concerning you, or what is my will concerning you.
39241	1494	5	Behold, verily I say unto you, that it is my will that you should proclaim my gospel from land to land, and from city to city, yea, in those regions round about where it has not been proclaimed.
39242	1494	6	Tarry not many days in this place; go not up unto the land of Zion as yet; but inasmuch as you can send, send; otherwise, think not of thy property.
39243	1494	7	Go unto the eastern lands, bear testimony in every place, unto every people and in their synagogues, reasoning with the people.
39244	1494	8	Let my servant Samuel H. Smith go with you, and forsake him not, and give him thine instructions; and he that is faithful shall be made strong in every place; and I, the Lord, will go with you.
39245	1494	9	Lay your hands upon the sick, and they shall recover. Return not till I, the Lord, shall send you. Be patient in affliction. Ask, and ye shall receive; knock, and it shall be opened unto you.
39246	1494	10	Seek not to be cumbered. Forsake all unrighteousness. Commit not adultery--a temptation with which thou hast been troubled.
39247	1494	11	Keep these sayings, for they are true and faithful; and thou shalt magnify thine office, and push many people to Zion with songs of everlasting joy upon their heads.
39248	1494	12	Continue in these things even unto the end, and you shall have a crown of eternal life at the right hand of my Father, who is full of grace and truth.
39249	1494	13	Verily, thus saith the Lord your God, your Redeemer, even Jesus Christ. Amen.
39250	1495	1	BEHOLD and hearken, O ye elders of my church, who have assembled yourselves together, whose prayers I have heard, and whose hearts I know, and whose desires have come up before me.
39251	1495	2	Behold and lo, mine eyes are upon you, and the heavens and the earth are in mine hands, and the riches of eternity are mine to give.
39252	1495	3	Ye endeavored to believe that ye should receive the blessing which was offered unto you; but behold, verily I say unto you there were fears in your hearts, and verily this is the reason that ye did not receive.
39253	1495	4	And now I, the Lord, give unto you a testimony of the truth of these commandments which are lying before you.
39254	1495	5	Your eyes have been upon my servant Joseph Smith, Jun., and his language you have known, and his imperfections you have known; and you have sought in your hearts knowledge that you might express beyond his language; this you also know.
39255	1495	6	Now, seek ye out of the Book of Commandments, even the least that is among them, and appoint him that is the most wise among you;
39256	1495	7	Or, if there be any among you that shall make one like unto it, then ye are justified in saying that ye do not know that they are true;
39257	1495	8	But if ye cannot make one like unto it, ye are under condemnation if ye do not bear record that they are true.
39258	1495	9	For ye know that there is no unrighteousness in them, and that which is righteous cometh down from above, from the Father of lights.
39259	1495	10	And again, verily I say unto you that it is your privilege, and a promise I give unto you that have been ordained unto this ministry, that inasmuch as you strip yourselves from jealousies and fears, and humble yourselves before me, for ye are not sufficiently humble, the veil shall be rent and you shall see me and know that I am--not with the carnal neither natural mind, but with the spiritual.
39260	1495	11	For no man has seen God at any time in the flesh, except quickened by the Spirit of God.
39261	1495	12	Neither can any natural man abide the presence of God, neither after the carnal mind.
39262	1495	13	Ye are not able to abide the presence of God now, neither the ministering of angels; wherefore, continue in patience until ye are perfected.
39263	1495	14	Let not your minds turn back; and when ye are worthy, in mine own due time, ye shall see and know that which was conferred upon you by the hands of my servant Joseph Smith, Jun. Amen.
39264	1496	1	MY servant, Orson Hyde, was called by his ordination to proclaim the everlasting gospel, by the Spirit of the living God, from people to people, and from land to land, in the congregations of the wicked, in their synagogues, reasoning with and expounding all scriptures unto them.
39265	1496	2	And, behold, and lo, this is an ensample unto all those who were ordained unto this priesthood, whose mission is appointed unto them to go forth--
39266	1496	3	And this is the ensample unto them, that they shall speak as they are moved upon by the Holy Ghost.
39267	1496	4	And whatsoever they shall speak when moved upon by the Holy Ghost shall be scripture, shall be the will of the Lord, shall be the mind of the Lord, shall be the word of the Lord, shall be the voice of the Lord, and the power of God unto salvation.
39268	1496	5	Behold, this is the promise of the Lord unto you, O ye my servants.
39269	1496	6	Wherefore, be of good cheer, and do not fear, for I the Lord am with you, and will stand by you; and ye shall bear record of me, even Jesus Christ, that I am the Son of the living God, that I was, that I am, and that I am to come.
39270	1496	7	This is the word of the Lord unto you, my servant Orson Hyde, and also unto my servant Luke Johnson, and unto my servant Lyman Johnson, and unto my servant William E. McLellin, and unto all the faithful elders of my church--
39271	1496	8	Go ye into all the world, preach the gospel to every creature, acting in the authority which I have given you, baptizing in the name of the Father, and of the Son, and of the Holy Ghost.
39272	1496	9	And he that believeth and is baptized shall be saved, and he that believeth not shall be damned.
39273	1496	10	And he that believeth shall be blest with signs following, even as it is written.
39274	1496	11	And unto you it shall be given to know the signs of the times, and the signs of the coming of the Son of Man;
39275	1496	12	And of as many as the Father shall bear record, to you shall be given power to seal them up unto eternal life. Amen.
39276	1496	13	And now, concerning the items in addition to the covenants and commandments, they are these--
39277	1496	14	There remain hereafter, in the due time of the Lord, other bishops to be set apart unto the church, to minister even according to the first;
39278	1496	15	Wherefore they shall be high priests who are worthy, and they shall be appointed by the First Presidency of the Melchizedek Priesthood, except they be literal descendants of Aaron.
39279	1496	16	And if they be literal descendants of Aaron they have a legal right to the bishopric, if they are the firstborn among the sons of Aaron;
39280	1496	17	For the firstborn holds the right of the presidency over this priesthood, and the keys or authority of the same.
39281	1496	18	No man has a legal right to this office, to hold the keys of this priesthood, except he be a literal descendant and the firstborn of Aaron.
39282	1496	19	But, as a high priest of the Melchizedek Priesthood has authority to officiate in all the lesser offices he may officiate in the office of bishop when no literal descendant of Aaron can be found, provided he is called and set apart and ordained unto this power, under the hands of the First Presidency of the Melchizedek Priesthood.
39283	1496	20	And a literal descendant of Aaron, also, must be designated by this Presidency, and found worthy, and anointed, and ordained under the hands of this Presidency, otherwise they are not legally authorized to officiate in their priesthood.
39284	1496	21	But, by virtue of the decree concerning their right of the priesthood descending from father to son, they may claim their anointing if at any time they can prove their lineage, or do ascertain it by revelation from the Lord under the hands of the above named Presidency.
39285	1496	22	And again, no bishop or high priest who shall be set apart for this ministry shall be tried or condemned for any crime, save it be before the First Presidency of the church;
39286	1496	23	And inasmuch as he is found guilty before this Presidency, by testimony that cannot be impeached, he shall be condemned;
39287	1496	24	And if he repent he shall be forgiven, according to the covenants and commandments of the church.
39288	1496	25	And again, inasmuch as parents have children in Zion, or in any of her stakes which are organized, that teach them not to understand the doctrine of repentance, faith in Christ the Son of the living God, and of baptism and the gift of the Holy Ghost by the laying on of the hands, when eight years old, the sin be upon the heads of the parents.
39289	1496	26	For this shall be a law unto the inhabitants of Zion, or in any of her stakes which are organized.
39290	1496	27	And their children shall be baptized for the remission of their sins when eight years old, and receive the laying on of the hands.
39291	1496	28	And they shall also teach their children to pray, and to walk uprightly before the Lord.
39292	1496	29	And the inhabitants of Zion shall also observe the Sabbath day to keep it holy.
39293	1496	30	And the inhabitants of Zion also shall remember their labors, inasmuch as they are appointed to labor, in all faithfulness; for the idler shall be had in remembrance before the Lord.
39294	1496	31	Now, I, the Lord, am not well pleased with the inhabitants of Zion, for there are idlers among them; and their children are also growing up in wickedness; they also seek not earnestly the riches of eternity, but their eyes are full of greediness.
39295	1496	32	These things ought not to be, and must be done away from among them; wherefore, let my servant Oliver Cowdery carry these sayings unto the land of Zion.
39296	1496	33	And a commandment I give unto them--that he that observeth not his prayers before the Lord in the season thereof, let him be had in remembrance before the judge of my people.
39297	1496	34	These sayings are true and faithful; wherefore, transgress them not, neither take therefrom.
39298	1496	35	Behold, I am Alpha and Omega, and I come quickly. Amen.
39299	1497	1	HEARKEN unto me, saith the Lord your God, for my servant Oliver Cowdery's sake. It is not wisdom in me that he should be entrusted with the commandments and the moneys which he shall carry unto the land of Zion, except one go with him who will be true and faithful.
39300	1497	2	Wherefore, I, the Lord, will that my servant, John Whitmer, should go with my servant Oliver Cowdery;
39301	1497	3	And also that he shall continue in writing and making a history of all the important things which he shall observe and know concerning my church;
39302	1497	4	And also that he receive counsel and assistance from my servant Oliver Cowdery and others.
39303	1497	5	And also, my servants who are abroad in the earth should send forth the accounts of their stewardships to the land of Zion;
39304	1497	6	For the land of Zion shall be a seat and a place to receive and do all these things.
39305	1497	7	Nevertheless, let my servant John Whitmer travel many times from place to place, and from church to church, that he may the more easily obtain knowledge--
39306	1497	8	Preaching and expounding, writing, copying, selecting, and obtaining all things which shall be for the good of the church, and for the rising generations that shall grow up on the land of Zion, to possess it from generation to generation, forever and ever. Amen.
39307	1498	1	BEHOLD, and hearken, O ye inhabitants of Zion, and all ye people of my church who are afar off, and hear the word of the Lord which I give unto my servant Joseph Smith, Jun., and also unto my servant Martin Harris, and also unto my servant Oliver Cowdery, and also unto my servant John Whitmer, and also unto my servant Sidney Rigdon, and also unto my servant William W. Phelps, by the way of commandment unto them.
39308	1498	2	For I give unto them a commandment; wherefore hearken and hear, for thus saith the Lord unto them--
39309	1498	3	I, the Lord, have appointed them, and ordained them to be stewards over the revelations and commandments which I have given unto them, and which I shall hereafter give unto them;
39310	1498	4	And an account of this stewardship will I require of them in the day of judgment.
39311	1498	5	Wherefore, I have appointed unto them, and this is their business in the church of God, to manage them and the concerns thereof, yea, the benefits thereof.
39312	1498	6	Wherefore, a commandment I give unto them, that they shall not give these things unto the church, neither unto the world;
39313	1498	7	Nevertheless, inasmuch as they receive more than is needful for their necessities and their wants, it shall be given into my storehouse;
39314	1498	8	And the benefits shall be consecrated unto the inhabitants of Zion, and unto their generations, inasmuch as they become heirs according to the laws of the kingdom.
39315	1498	9	Behold, this is what the Lord requires of every man in his stewardship, even as I, the Lord, have appointed or shall hereafter appoint unto any man.
39316	1498	10	And behold, none are exempt from this law who belong to the church of the living God;
39317	1498	11	Yea, neither the bishop, neither the agent who keepeth the Lord's storehouse, neither he who is appointed in a stewardship over temporal things.
39318	1498	12	He who is appointed to administer spiritual things, the same is worthy of his hire, even as those who are appointed to a stewardship to administer in temporal things;
39319	1498	13	Yea, even more abundantly, which abundance is multiplied unto them through the manifestations of the Spirit.
39320	1498	14	Nevertheless, in your temporal things you shall be equal, and this not grudgingly, otherwise the abundance of the manifestations of the Spirit shall be withheld.
39321	1498	15	Now, this commandment I give unto my servants for their benefit while they remain, for a manifestation of my blessings upon their heads, and for a reward of their diligence and for their security;
39322	1498	16	For food and for raiment; for an inheritance; for houses and for lands, in whatsoever circumstances I, the Lord, shall place them, and whithersoever I, the Lord, shall send them.
39323	1498	17	For they have been faithful over many things, and have done well inasmuch as they have not sinned.
39324	1498	18	Behold, I, the Lord, am merciful and will bless them, and they shall enter into the joy of these things. Even so. Amen.
39325	1499	1	BEHOLD, thus saith the Lord unto you my servants Joseph Smith, Jun., and Sidney Rigdon, that the time has verily come that it is necessary and expedient in me that you should open your mouths in proclaiming my gospel, the things of the kingdom, expounding the mysteries thereof out of the scriptures, according to that portion of Spirit and power which shall be given unto you, even as I will.
39326	1499	2	Verily I say unto you, proclaim unto the world in the regions round about, and in the church also, for the space of a season, even until it shall be made known unto you.
39327	1499	3	Verily this is a mission for a season, which I give unto you.
39328	1499	4	Wherefore, labor ye in my vineyard. Call upon the inhabitants of the earth, and bear record, and prepare the way for the commandments and revelations which are to come.
39329	1499	5	Now, behold this is wisdom; whoso readeth, let him understand and receive also;
39330	1499	6	For unto him that receiveth it shall be given more abundantly, even power.
39331	1499	7	Wherefore, confound your enemies; call upon them to meet you both in public and in private; and inasmuch as ye are faithful their shame shall be made manifest.
39332	1499	8	Wherefore, let them bring forth their strong reasons against the Lord.
39333	1499	9	Verily, thus saith the Lord unto you--there is no weapon that is formed against you shall prosper;
39334	1499	10	And if any man lift his voice against you he shall be confounded in mine own due time.
39335	1499	11	Wherefore, keep my commandments; they are true and faithful. Even so. Amen.
39336	1500	1	HEARKEN, and listen to the voice of the Lord, O ye who have assembled yourselves together, who are the high priests of my church, to whom the kingdom and power have been given.
39337	1500	2	For verily thus saith the Lord, it is expedient in me for a bishop to be appointed unto you, or of you, unto the church in this part of the Lord's vineyard.
39338	1500	3	And verily in this thing ye have done wisely, for it is required of the Lord, at the hand of every steward, to render an account of his stewardship, both in time and in eternity.
39339	1500	4	For he who is faithful and wise in time is accounted worthy to inherit the mansions prepared for him of my Father.
39340	1500	5	Verily I say unto you, the elders of the church in this part of my vineyard shall render an account of their stewardship unto the bishop, who shall be appointed of me in this part of my vineyard.
39341	1500	6	These things shall be had on record, to be handed over unto the bishop in Zion.
39342	1500	7	And the duty of the bishop shall be made known by the commandments which have been given, and the voice of the conference.
39343	1500	8	And now, verily I say unto you, my servant Newel K. Whitney is the man who shall be appointed and ordained unto this power. This is the will of the Lord your God, your Redeemer. Even so. Amen.
39344	1500	9	The word of the Lord, in addition to the law which has been given, making known the duty of the bishop who has been ordained unto the church in this part of the vineyard, which is verily this--
39345	1500	10	To keep the Lord's storehouse; to receive the funds of the church in this part of the vineyard;
39346	1500	11	To take an account of the elders as before has been commanded; and to administer to their wants, who shall pay for that which they receive, inasmuch as they have wherewith to pay;
39347	1500	12	That this also may be consecrated to the good of the church, to the poor and needy.
39348	1500	13	And he who hath not wherewith to pay, an account shall be taken and handed over to the bishop of Zion, who shall pay the debt out of that which the Lord shall put into his hands.
39349	1500	14	And the labors of the faithful who labor in spiritual things, in administering the gospel and the things of the kingdom unto the church, and unto the world, shall answer the debt unto the bishop in Zion;
39350	1500	15	Thus it cometh out of the church, for according to the law every man that cometh up to Zion must lay all things before the bishop in Zion.
39351	1500	16	And now, verily I say unto you, that as every elder in this part of the vineyard must give an account of his stewardship unto the bishop in this part of the vineyard--
39352	1500	17	A certificate from the judge or bishop in this part of the vineyard, unto the bishop in Zion, rendereth every man acceptable, and answereth all things, for an inheritance, and to be received as a wise steward and as a faithful laborer;
39353	1500	18	Otherwise he shall not be accepted of the bishop of Zion.
39354	1500	19	And now, verily I say unto you, let every elder who shall give an account unto the bishop of the church in this part of the vineyard be recommended by the church or churches, in which he labors, that he may render himself and his accounts approved in all things.
39355	1500	20	And again, let my servants who are appointed as stewards over the literary concerns of my church have claim for assistance upon the bishop or bishops in all things--
39356	1500	21	That the revelations may be published, and go forth unto the ends of the earth; that they also may obtain funds which shall benefit the church in all things;
39357	1500	22	That they also may render themselves approved in all things, and be accounted as wise stewards.
39358	1500	23	And now, behold, this shall be an ensample for all the extensive branches of my church, in whatsoever land they shall be established. And now I make an end of my sayings. Amen.
39359	1500	24	A few words in addition to the laws of the kingdom, respecting the members of the church--they that are appointed by the Holy Spirit to go up unto Zion, and they who are privileged to go up unto Zion--
39360	1500	25	Let them carry up unto the bishop a certificate from three elders of the church, or a certificate from the bishop;
39361	1500	26	Otherwise he who shall go up unto the land of Zion shall not be accounted as a wise steward. This is also an ensample. Amen.
39362	1501	1	FOR verily, thus saith the Lord, it is expedient in me that they should continue preaching the gospel, and in exhortation to the churches in the regions round about, until conference;
39363	1501	2	And then, behold, it shall be made known unto them, by the voice of the conference, their several missions.
39364	1501	3	Now, verily I say unto you my servants, Joseph Smith, Jun., and Sidney Rigdon, saith the Lord, it is expedient to translate again;
39365	1501	4	And, inasmuch as it is practicable, to preach in the regions round about until conference; and after that it is expedient to continue the work of translation until it be finished.
39366	1501	5	And let this be a pattern unto the elders until further knowledge, even as it is written.
39367	1501	6	Now I give no more unto you at this time. Gird up your loins and be sober. Even so. Amen.
39368	1502	1	FOR the unbelieving husband is sanctified by the wife, and the unbelieving wife is sanctified by the husband; else were your children unclean, but now are they holy.
39369	1502	2	Now, in the days of the apostles the law of circumcision was had among all the Jews who believed not the gospel of Jesus Christ.
39370	1502	3	And it came to pass that there arose a great contention among the people concerning the law of circumcision, for the unbelieving husband was desirous that his children should be circumcised and become subject to the law of Moses, which law was fulfilled.
39371	1502	4	And it came to pass that the children, being brought up in subjection to the law of Moses, gave heed to the traditions of their fathers and believed not the gospel of Christ, wherein they became unholy.
39372	1502	5	Wherefore, for this cause the apostle wrote unto the church, giving unto them a commandment, not of the Lord, but of himself, that a believer should not be united to an unbeliever; except the law of Moses should be done away among them,
39373	1502	6	That their children might remain without circumcision; and that the tradition might be done away, which saith that little children are unholy; for it was had among the Jews;
39374	1502	7	But little children are holy, being sanctified through the atonement of Jesus Christ; and this is what the scriptures mean.
39375	1503	1	VERILY, verily I say unto you, I who speak even by the voice of my Spirit, even Alpha and Omega, your Lord and your God--
39376	1503	2	Hearken, O ye who have given your names to go forth to proclaim my gospel, and to prune my vineyard.
39377	1503	3	Behold, I say unto you that it is my will that you should go forth and not tarry, neither be idle but labor with your might--
39378	1503	4	Lifting up your voices as with the sound of a trump, proclaiming the truth according to the revelations and commandments which I have given you.
39379	1503	5	And thus, if ye are faithful ye shall be laden with many sheaves, and crowned with honor, and glory, and immortality, and eternal life.
39380	1503	6	Therefore, verily I say unto my servant William E. McLellin, I revoke the commission which I gave unto him to go unto the eastern countries;
39381	1503	7	And I give unto him a new commission and a new commandment, in the which I, the Lord, chasten him for the murmurings of his heart;
39382	1503	8	And he sinned; nevertheless, I forgive him and say unto him again, Go ye into the south countries.
39383	1503	9	And let my servant Luke Johnson go with him, and proclaim the things which I have commanded them--
39384	1503	10	Calling on the name of the Lord for the Comforter, which shall teach them all things that are expedient for them--
39385	1503	11	Praying always that they faint not; and inasmuch as they do this, I will be with them even unto the end.
39386	1503	12	Behold, this is the will of the Lord your God concerning you. Even so. Amen.
39387	1503	13	And again, verily thus saith the Lord, let my servant Orson Hyde and my servant Samuel H. Smith take their journey into the eastern countries, and proclaim the things which I have commanded them; and inasmuch as they are faithful, lo, I will be with them even unto the end.
39388	1503	14	And again, verily I say unto my servant Lyman Johnson, and unto my servant Orson Pratt, they shall also take their journey into the eastern countries; and behold, and lo, I am with them also, even unto the end.
39389	1503	15	And again, I say unto my servant Asa Dodds, and unto my servant Calves Wilson, that they also shall take their journey unto the western countries, and proclaim my gospel, even as I have commanded them.
39390	1503	16	And he who is faithful shall overcome all things, and shall be lifted up at the last day.
39391	1503	17	And again, I say unto my servant Major N. Ashley, and my servant Burr Riggs, let them take their journey also into the south country.
39392	1503	18	Yea, let all those take their journey, as I have commanded them, going from house to house, and from village to village, and from city to city.
39393	1503	19	And in whatsoever house ye enter, and they receive you, leave your blessing upon that house.
39394	1503	20	And in whatsoever house ye enter, and they receive you not, ye shall depart speedily from that house, and shake off the dust of your feet as a testimony against them.
39395	1503	21	And you shall be filled with joy and gladness; and know this, that in the day of judgment you shall be judges of that house, and condemn them;
39396	1503	22	And it shall be more tolerable for the heathen in the day of judgment, than for that house; therefore, gird up your loins and be faithful, and ye shall overcome all things, and be lifted up at the last day. Even so. Amen.
39397	1503	23	And again, thus saith the Lord unto you, O ye elders of my church, who have given your names that you might know his will concerning you--
39398	1503	24	Behold, I say unto you, that it is the duty of the church to assist in supporting the families of those, and also to support the families of those who are called and must needs be sent unto the world to proclaim the gospel unto the world.
39399	1503	25	Wherefore, I, the Lord, give unto you this commandment, that ye obtain places for your families, inasmuch as your brethren are willing to open their hearts.
39400	1503	26	And let all such as can obtain places for their families, and support of the church for them, not fail to go into the world, whether to the east or to the west, or to the north, or to the south.
39401	1503	27	Let them ask and they shall receive, knock and it shall be opened unto them, and be made known from on high, even by the Comforter, whither they shall go.
39402	1503	28	And again, verily I say unto you, that every man who is obliged to provide for his own family, let him provide, and he shall in nowise lose his crown; and let him labor in the church.
39403	1503	29	Let every man be diligent in all things. And the idler shall not have place in the church, except he repent and mend his ways.
39404	1503	30	Wherefore, let my servant Simeon Carter and my servant Emer Harris be united in the ministry;
39405	1503	31	And also my servant Ezra Thayre and my servant Thomas B. Marsh;
39406	1503	32	Also my servant Hyrum Smith and my servant Reynolds Cahoon;
39407	1503	33	And also my servant Daniel Stanton and my servant Seymour Brunson;
39408	1503	34	And also my servant Sylvester Smith and my servant Gideon Carter;
39409	1503	35	And also my servant Ruggles Eames and my servant Stephen Burnett;
39410	1503	36	And also my servant Micah B. Welton and also my servant Eden Smith. Even so. Amen.
39411	1504	1	HEAR, O ye heavens, and give ear, O earth, and rejoice ye inhabitants thereof, for the Lord is God, and beside him there is no Savior.
39412	1504	2	Great is his wisdom, marvelous are his ways, and the extent of his doings none can find out.
39413	1504	3	His purposes fail not, neither are there any who can stay his hand.
39414	1504	4	From eternity to eternity he is the same, and his years never fail.
39415	1504	5	For thus saith the Lord--I, the Lord, am merciful and gracious unto those who fear me, and delight to honor those who serve me in righteousness and in truth unto the end.
39416	1504	6	Great shall be their reward and eternal shall be their glory.
39417	1504	7	And to them will I reveal all mysteries, yea, all the hidden mysteries of my kingdom from days of old, and for ages to come, will I make known unto them the good pleasure of my will concerning all things pertaining to my kingdom.
39418	1504	8	Yea, even the wonders of eternity shall they know, and things to come will I show them, even the things of many generations.
39419	1504	9	And their wisdom shall be great, and their understanding reach to heaven; and before them the wisdom of the wise shall perish, and the understanding of the prudent shall come to naught.
39420	1504	10	For by my Spirit will I enlighten them, and by my power will I make known unto them the secrets of my will--yea, even those things which eye has not seen, nor ear heard, nor yet entered into the heart of man.
39421	1504	11	We, Joseph Smith, Jun., and Sidney Rigdon, being in the Spirit on the sixteenth day of February, in the year of our Lord one thousand eight hundred and thirty-two--
39422	1504	12	By the power of the Spirit our eyes were opened and our understandings were enlightened, so as to see and understand the things of God--
39423	1504	13	Even those things which were from the beginning before the world was, which were ordained of the Father, through his Only Begotten Son, who was in the bosom of the Father, even from the beginning;
39424	1504	14	Of whom we bear record; and the record which we bear is the fulness of the gospel of Jesus Christ, who is the Son, whom we saw and with whom we conversed in the heavenly vision.
39425	1504	15	For while we were doing the work of translation, which the Lord had appointed unto us, we came to the twenty-ninth verse of the fifth chapter of John, which was given unto us as follows--
39426	1504	16	Speaking of the resurrection of the dead, concerning those who shall hear the voice of the Son of Man:
39427	1504	17	And shall come forth; they who have done good in the resurrection of the just; and they who have done evil, in the resurrection of the unjust.
39428	1504	18	Now this caused us to marvel, for it was given unto us of the Spirit.
39429	1504	19	And while we meditated upon these things, the Lord touched the eyes of our understandings and they were opened, and the glory of the Lord shone round about.
39430	1504	20	And we beheld the glory of the Son, on the right hand of the Father, and received of his fulness;
39431	1504	21	And saw the holy angels, and them who are sanctified before his throne, worshiping God, and the Lamb, who worship him forever and ever.
39432	1504	22	And now, after the many testimonies which have been given of him, this is the testimony, last of all, which we give of him: That he lives!
39433	1504	23	For we saw him, even on the right hand of God; and we heard the voice bearing record that he is the Only Begotten of the Father--
39434	1504	24	That by him, and through him, and of him, the worlds are and were created, and the inhabitants thereof are begotten sons and daughters unto God.
39435	1504	25	And this we saw also, and bear record, that an angel of God who was in authority in the presence of God, who rebelled against the Only Begotten Son whom the Father loved and who was in the bosom of the Father, was thrust down from the presence of God and the Son,
39436	1504	26	And was called Perdition, for the heavens wept over him--he was Lucifer, a son of the morning.
39437	1504	27	And we beheld, and lo, he is fallen! is fallen, even a son of the morning!
39438	1504	28	And while we were yet in the Spirit, the Lord commanded us that we should write the vision; for we beheld Satan, that old serpent, even the devil, who rebelled against God, and sought to take the kingdom of our God and his Christ--
39439	1504	29	Wherefore, he maketh war with the saints of God, and encompasseth them round about.
39440	1504	30	And we saw a vision of the sufferings of those with whom he made war and overcame, for thus came the voice of the Lord unto us:
39441	1504	31	Thus saith the Lord concerning all those who know my power, and have been made partakers thereof, and suffered themselves through the power of the devil to be overcome, and to deny the truth and defy my power--
39442	1504	32	They are they who are the sons of perdition, of whom I say that it had been better for them never to have been born;
39443	1504	33	For they are vessels of wrath, doomed to suffer the wrath of God, with the devil and his angels in eternity;
39444	1504	34	Concerning whom I have said there is no forgiveness in this world nor in the world to come--
39445	1504	35	Having denied the Holy Spirit after having received it, and having denied the Only Begotten Son of the Father, having crucified him unto themselves and put him to an open shame.
39446	1504	36	These are they who shall go away into the lake of fire and brimstone, with the devil and his angels--
39447	1504	37	And the only ones on whom the second death shall have any power;
39448	1504	38	Yea, verily, the only ones who shall not be redeemed in the due time of the Lord, after the sufferings of his wrath.
39449	1504	39	For all the rest shall be brought forth by the resurrection of the dead, through the triumph and the glory of the Lamb, who was slain, who was in the bosom of the Father before the worlds were made.
39450	1504	40	And this is the gospel, the glad tidings, which the voice out of the heavens bore record unto us--
39451	1504	41	That he came into the world, even Jesus, to be crucified for the world, and to bear the sins of the world, and to sanctify the world, and to cleanse it from all unrighteousness;
39452	1504	42	That through him all might be saved whom the Father had put into his power and made by him;
39453	1504	43	Who glorifies the Father, and saves all the works of his hands, except those sons of perdition who deny the Son after the Father has revealed him.
39454	1504	44	Wherefore, he saves all except them--they shall go away into everlasting punishment, which is endless punishment, which is eternal punishment, to reign with the devil and his angels in eternity, where their worm dieth not, and the fire is not quenched, which is their torment--
39455	1504	45	And the end thereof, neither the place thereof, nor their torment, no man knows;
39456	1504	46	Neither was it revealed, neither is, neither will be revealed unto man, except to them who are made partakers thereof;
39457	1504	47	Nevertheless, I, the Lord, show it by vision unto many, but straightway shut it up again;
39458	1504	48	Wherefore, the end, the width, the height, the depth, and the misery thereof, they understand not, neither any man except those who are ordained unto this condemnation.
39459	1504	49	And we heard the voice, saying: Write the vision, for lo, this is the end of the vision of the sufferings of the ungodly.
39460	1504	50	And again we bear record--for we saw and heard, and this is the testimony of the gospel of Christ concerning them who shall come forth in the resurrection of the just--
39461	1504	51	They are they who received the testimony of Jesus, and believed on his name and were baptized after the manner of his burial, being buried in the water in his name, and this according to the commandment which he has given--
39462	1504	52	That by keeping the commandments they might be washed and cleansed from all their sins, and receive the Holy Spirit by the laying on of the hands of him who is ordained and sealed unto this power;
39463	1504	53	And who overcome by faith, and are sealed by the Holy Spirit of promise, which the Father sheds forth upon all those who are just and true.
39464	1504	54	They are they who are the church of the Firstborn.
39465	1504	55	They are they into whose hands the Father has given all things--
39466	1504	56	They are they who are priests and kings, who have received of his fulness, and of his glory;
39467	1504	57	And are priests of the Most High, after the order of Melchizedek, which was after the order of Enoch, which was after the order of the Only Begotten Son.
39468	1504	58	Wherefore, as it is written, they are gods, even the sons of God--
39469	1504	59	Wherefore, all things are theirs, whether life or death, or things present, or things to come, all are theirs and they are Christ's, and Christ is God's.
39470	1504	60	And they shall overcome all things.
39471	1504	61	Wherefore, let no man glory in man, but rather let him glory in God, who shall subdue all enemies under his feet.
39472	1504	62	These shall dwell in the presence of God and his Christ forever and ever.
39473	1504	63	These are they whom he shall bring with him, when he shall come in the clouds of heaven to reign on the earth over his people.
39474	1504	64	These are they who shall have part in the first resurrection.
39475	1504	65	These are they who shall come forth in the resurrection of the just.
39476	1504	66	These are they who are come unto Mount Zion, and unto the city of the living God, the heavenly place, the holiest of all.
39477	1504	67	These are they who have come to an innumerable company of angels, to the general assembly and church of Enoch, and of the Firstborn.
39478	1504	68	These are they whose names are written in heaven, where God and Christ are the judge of all.
39479	1504	69	These are they who are just men made perfect through Jesus the mediator of the new covenant, who wrought out this perfect atonement through the shedding of his own blood.
39480	1504	70	These are they whose bodies are celestial, whose glory is that of the sun, even the glory of God, the highest of all, whose glory the sun of the firmament is written of as being typical.
39481	1504	71	And again, we saw the terrestrial world, and behold and lo, these are they who are of the terrestrial, whose glory differs from that of the church of the Firstborn who have received the fulness of the Father, even as that of the moon differs from the sun in the firmament.
39482	1504	72	Behold, these are they who died without law;
39483	1504	73	And also they who are the spirits of men kept in prison, whom the Son visited, and preached the gospel unto them, that they might be judged according to men in the flesh;
39484	1504	74	Who received not the testimony of Jesus in the flesh, but afterwards received it.
39485	1504	75	These are they who are honorable men of the earth, who were blinded by the craftiness of men.
39486	1504	76	These are they who receive of his glory, but not of his fulness.
39487	1504	77	These are they who receive of the presence of the Son, but not of the fulness of the Father.
39488	1504	78	Wherefore, they are bodies terrestrial, and not bodies celestial, and differ in glory as the moon differs from the sun.
39489	1504	79	These are they who are not valiant in the testimony of Jesus; wherefore, they obtain not the crown over the kingdom of our God.
39490	1504	80	And now this is the end of the vision which we saw of the terrestrial, that the Lord commanded us to write while we were yet in the Spirit.
39491	1504	81	And again, we saw the glory of the telestial, which glory is that of the lesser, even as the glory of the stars differs from that of the glory of the moon in the firmament.
39492	1504	82	These are they who received not the gospel of Christ, neither the testimony of Jesus.
39493	1504	83	These are they who deny not the Holy Spirit.
39494	1504	84	These are they who are thrust down to hell.
39495	1504	85	These are they who shall not be redeemed from the devil until the last resurrection, until the Lord, even Christ the Lamb, shall have finished his work.
39496	1504	86	These are they who receive not of his fulness in the eternal world, but of the Holy Spirit through the ministration of the terrestrial;
39497	1504	87	And the terrestrial through the ministration of the celestial.
39498	1504	88	And also the telestial receive it of the administering of angels who are appointed to minister for them, or who are appointed to be ministering spirits for them; for they shall be heirs of salvation.
39499	1504	89	And thus we saw, in the heavenly vision, the glory of the telestial, which surpasses all understanding;
39500	1504	90	And no man knows it except him to whom God has revealed it.
39501	1504	91	And thus we saw the glory of the terrestrial which excels in all things the glory of the telestial, even in glory, and in power, and in might, and in dominion.
39502	1504	92	And thus we saw the glory of the celestial, which excels in all things--where God, even the Father, reigns upon his throne forever and ever;
39503	1504	93	Before whose throne all things bow in humble reverence, and give him glory forever and ever.
39504	1504	94	They who dwell in his presence are the church of the Firstborn; and they see as they are seen, and know as they are known, having received of his fulness and of his grace;
39505	1504	95	And he makes them equal in power, and in might, and in dominion.
39506	1504	96	And the glory of the celestial is one, even as the glory of the sun is one.
39507	1504	97	And the glory of the terrestrial is one, even as the glory of the moon is one.
39508	1504	98	And the glory of the telestial is one, even as the glory of the stars is one; for as one star differs from another star in glory, even so differs one from another in glory in the telestial world;
39509	1504	99	For these are they who are of Paul, and of Apollos, and of Cephas.
39510	1504	100	These are they who say they are some of one and some of another--some of Christ and some of John, and some of Moses, and some of Elias, and some of Esaias, and some of Isaiah, and some of Enoch;
39511	1504	101	But received not the gospel, neither the testimony of Jesus, neither the prophets, neither the everlasting covenant.
39512	1504	102	Last of all, these all are they who will not be gathered with the saints, to be caught up unto the church of the Firstborn, and received into the cloud.
39513	1504	103	These are they who are liars, and sorcerers, and adulterers, and whoremongers, and whosoever loves and makes a lie.
39514	1504	104	These are they who suffer the wrath of God on earth.
39515	1504	105	These are they who suffer the vengeance of eternal fire.
39516	1504	106	These are they who are cast down to hell and suffer the wrath of Almighty God, until the fulness of times, when Christ shall have subdued all enemies under his feet, and shall have perfected his work;
39517	1504	107	When he shall deliver up the kingdom, and present it unto the Father, spotless, saying: I have overcome and have trodden the wine-press alone, even the wine-press of the fierceness of the wrath of Almighty God.
39518	1504	108	Then shall he be crowned with the crown of his glory, to sit on the throne of his power to reign forever and ever.
39519	1504	109	But behold, and lo, we saw the glory and the inhabitants of the telestial world, that they were as innumerable as the stars in the firmament of heaven, or as the sand upon the seashore;
39520	1504	110	And heard the voice of the Lord saying: These all shall bow the knee, and every tongue shall confess to him who sits upon the throne forever and ever;
39521	1504	111	For they shall be judged according to their works, and every man shall receive according to his own works, his own dominion, in the mansions which are prepared;
39522	1504	112	And they shall be servants of the Most High; but where God and Christ dwell they cannot come, worlds without end.
39523	1504	113	This is the end of the vision which we saw, which we were commanded to write while we were yet in the Spirit.
39524	1504	114	But great and marvelous are the works of the Lord, and the mysteries of his kingdom which he showed unto us, which surpass all understanding in glory, and in might, and in dominion;
39525	1504	115	Which he commanded us we should not write while we were yet in the Spirit, and are not lawful for man to utter;
39526	1504	116	Neither is man capable to make them known, for they are only to be seen and understood by the power of the Holy Spirit, which God bestows on those who love him, and purify themselves before him;
39527	1504	117	To whom he grants this privilege of seeing and knowing for themselves;
39528	1504	118	That through the power and manifestation of the Spirit, while in the flesh, they may be able to bear his presence in the world of glory.
39529	1504	119	And to God and the Lamb be glory, and honor, and dominion forever and ever. Amen.
39530	1505	1	Q. What is the sea of glass spoken of by John, 4th chapter, and 6th verse of the Revelation? A. It is the earth, in its sanctified, immortal, and eternal state.
39531	1505	2	Q. What are we to understand by the four beasts, spoken of in the same verse? A. They are figurative expressions, used by the Revelator, John, in describing heaven, the paradise of God, the happiness of man, and of beasts, and of creeping things, and of the fowls of the air; that which is spiritual being in the likeness of that which is temporal; and that which is temporal in the likeness of that which is spiritual; the spirit of man in the likeness of his person, as also the spirit of the beast, and every other creature which God has created.
39532	1505	3	Q. Are the four beasts limited to individual beasts, or do they represent classes or orders? A. They are limited to four individual beasts, which were shown to John, to represent the glory of the classes of beings in their destined order or sphere of creation, in the enjoyment of their eternal felicity.
39533	1505	4	Q. What are we to understand by the eyes and wings, which the beasts had? A. Their eyes are a representation of light and knowledge, that is, they are full of knowledge; and their wings are a representation of power, to move, to act, etc.
39534	1505	5	Q. What are we to understand by the four and twenty elders, spoken of by John? A. We are to understand that these elders whom John saw, were elders who had been faithful in the work of the ministry and were dead; who belonged to the seven churches, and were then in the paradise of God.
39535	1505	6	Q. What are we to understand by the book which John saw, which was sealed on the back with seven seals? A. We are to understand that it contains the revealed will, mysteries, and the works of God; the hidden things of his economy concerning this earth during the seven thousand years of its continuance, or its temporal existence.
39536	1505	7	Q. What are we to understand by the seven seals with which it was sealed? A. We are to understand that the first seal contains the things of the first thousand years, and the second also of the second thousand years, and so on until the seventh.
39537	1505	8	Q. What are we to understand by the four angels, spoken of in the 7th chapter and 1st verse of Revelation? A. We are to understand that they are four angels sent forth from God, to whom is given power over the four parts of the earth, to save life and to destroy; these are they who have the everlasting gospel to commit to every nation, kindred, tongue, and people; having power to shut up the heavens, to seal up unto life, or to cast down to the regions of darkness.
39538	1505	9	Q. What are we to understand by the angel ascending from the east, Revelation 7th chapter and 2nd verse? A. We are to understand that the angel ascending from the east is he to whom is given the seal of the living God over the twelve tribes of Israel; wherefore, he crieth unto the four angels having the everlasting gospel, saying: Hurt not the earth, neither the sea, nor the trees, till we have sealed the servants of our God in their foreheads. And, if you will receive it, this is Elias which was to come to gather together the tribes of Israel and restore all things.
39539	1505	10	Q. What time are the things spoken of in this chapter to be accomplished? A. They are to be accomplished in the sixth thousand years, or the opening of the sixth seal.
39540	1505	11	Q. What are we to understand by sealing the one hundred and forty-four thousand, out of all the tribes of Israel--twelve thousand out of every tribe? A. We are to understand that those who are sealed are high priests, ordained unto the holy order of God, to administer the everlasting gospel; for they are they who are ordained out of every nation, kindred, tongue, and people, by the angels to whom is given power over the nations of the earth, to bring as many as will come to the church of the Firstborn.
39541	1505	12	Q. What are we to understand by the sounding of the trumpets, mentioned in the 8th chapter of Revelation? A. We are to understand that as God made the world in six days, and on the seventh day he finished his work, and sanctified it, and also formed man out of the dust of the earth, even so, in the beginning of the seventh thousand years will the Lord God sanctify the earth, and complete the salvation of man, and judge all things, and shall redeem all things, except that which he hath not put into his power, when he shall have sealed all things, unto the end of all things; and the sounding of the trumpets of the seven angels are the preparing and finishing of his work, in the beginning of the seventh thousand years--the preparing of the way before the time of his coming.
39542	1505	13	Q. When are the things to be accomplished, which are written in the 9th chapter of Revelation? A. They are to be accomplished after the opening of the seventh seal, before the coming of Christ.
39543	1505	14	Q. What are we to understand by the little book which was eaten by John, as mentioned in the 10th chapter of Revelation? A. We are to understand that it was a mission, and an ordinance, for him to gather the tribes of Israel; behold, this is Elias, who, as it is written, must come and restore all things.
39544	1505	15	Q. What is to be understood by the two witnesses, in the eleventh chapter of Revelation? A. They are two prophets that are to be raised up to the Jewish nation in the last days, at the time of the restoration, and to prophesy to the Jews after they are gathered and have built the city of Jerusalem in the land of their fathers.
39545	1506	1	THE Lord spake unto Joseph Smith, Jun., saying: Hearken unto me, saith the Lord your God, who are ordained unto the high priesthood of my church, who have assembled yourselves together;
39546	1506	2	And listen to the counsel of him who has ordained you from on high, who shall speak in your ears the words of wisdom, that salvation may be unto you in that thing which you have presented before me, saith the Lord God.
39547	1506	3	For verily I say unto you, the time has come, and is now at hand; and behold, and lo, it must needs be that there be an organization of my people, in regulating and establishing the affairs of the storehouse for the poor of my people, both in this place and in the land of Zion--
39548	1506	4	For a permanent and everlasting establishment and order unto my church, to advance the cause, which ye have espoused, to the salvation of man, and to the glory of your Father who is in heaven;
39549	1506	5	That you may be equal in the bonds of heavenly things, yea, and earthly things also, for the obtaining of heavenly things.
39550	1506	6	For if ye are not equal in earthly things ye cannot be equal in obtaining heavenly things;
39551	1506	7	For if you will that I give unto you a place in the celestial world, you must prepare yourselves by doing the things which I have commanded you and required of you.
39552	1506	8	And now, verily thus saith the Lord, it is expedient that all things be done unto my glory, by you who are joined together in this order;
39553	1506	9	Or, in other words, let my servant Newel K. Whitney and my servant Joseph Smith, Jun., and my servant Sidney Rigdon sit in council with the saints which are in Zion;
39554	1506	10	Otherwise Satan seeketh to turn their hearts away from the truth, that they become blinded and understand not the things which are prepared for them.
39555	1506	11	Wherefore, a commandment I give unto you, to prepare and organize yourselves by a bond or everlasting covenant that cannot be broken.
39556	1506	12	And he who breaketh it shall lose his office and standing in the church, and shall be delivered over to the buffetings of Satan until the day of redemption.
39557	1506	13	Behold, this is the preparation wherewith I prepare you, and the foundation, and the ensample which I give unto you, whereby you may accomplish the commandments which are given you;
39558	1506	14	That through my providence, notwithstanding the tribulation which shall descend upon you, that the church may stand independent above all other creatures beneath the celestial world;
39559	1506	15	That you may come up unto the crown prepared for you, and be made rulers over many kingdoms, saith the Lord God, the Holy One of Zion, who hath established the foundations of Adam-ondi-Ahman;
39560	1506	16	Who hath appointed Michael your prince, and established his feet, and set him upon high, and given unto him the keys of salvation under the counsel and direction of the Holy One, who is without beginning of days or end of life.
39561	1506	17	Verily, verily, I say unto you, ye are little children, and ye have not as yet understood how great blessings the Father hath in his own hands and prepared for you;
39562	1506	18	And ye cannot bear all things now; nevertheless, be of good cheer, for I will lead you along. The kingdom is yours and the blessings thereof are yours, and the riches of eternity are yours.
39563	1506	19	And he who receiveth all things with thankfulness shall be made glorious; and the things of this earth shall be added unto him, even an hundred fold, yea, more.
39564	1506	20	Wherefore, do the things which I have commanded you, saith your Redeemer, even the Son Ahman, who prepareth all things before he taketh you;
39565	1506	21	For ye are the church of the Firstborn, and he will take you up in a cloud, and appoint every man his portion.
39566	1506	22	And he that is a faithful and wise steward shall inherit all things. Amen.
39567	1507	1	VERILY I say unto you, that it is my will that my servant Jared Carter should go again into the eastern countries, from place to place, and from city to city, in the power of the ordination wherewith he has been ordained, proclaiming glad tidings of great joy, even the everlasting gospel.
39568	1507	2	And I will send upon him the Comforter, which shall teach him the truth and the way whither he shall go;
39569	1507	3	And inasmuch as he is faithful, I will crown him again with sheaves.
39570	1507	4	Wherefore, let your heart be glad, my servant Jared Carter, and fear not, saith your Lord, even Jesus Christ. Amen.
39571	1508	1	VERILY, thus saith the Lord unto you my servant Stephen Burnett: Go ye, go ye into the world and preach the gospel to every creature that cometh under the sound of your voice.
39572	1508	2	And inasmuch as you desire a companion, I will give unto you my servant Eden Smith.
39573	1508	3	Wherefore, go ye and preach my gospel, whether to the north or to the south, to the east or to the west, it mattereth not, for ye cannot go amiss.
39574	1508	4	Therefore, declare the things which ye have heard, and verily believe, and know to be true.
39575	1508	5	Behold, this is the will of him who hath called you, your Redeemer, even Jesus Christ. Amen.
39576	1509	1	VERILY, verily, I say unto you my servant Frederick G. Williams: Listen to the voice of him who speaketh, to the word of the Lord your God, and hearken to the calling wherewith you are called, even to be a high priest in my church, and a counselor unto my servant Joseph Smith, Jun.;
39577	1509	2	Unto whom I have given the keys of the kingdom, which belong always unto the Presidency of the High Priesthood:
39578	1509	3	Therefore, verily I acknowledge him and will bless him, and also thee, inasmuch as thou art faithful in counsel, in the office which I have appointed unto you, in prayer always, vocally and in thy heart, in public and in private, also in thy ministry in proclaiming the gospel in the land of the living, and among thy brethren.
39579	1509	4	And in doing these things thou wilt do the greatest good unto thy fellow beings, and wilt promote the glory of him who is your Lord.
39580	1509	5	Wherefore, be faithful; stand in the office which I have appointed unto you; succor the weak, lift up the hands which hang down, and strengthen the feeble knees.
39581	1509	6	And if thou art faithful unto the end thou shalt have a crown of immortality, and eternal life in the mansions which I have prepared in the house of my Father.
39582	1509	7	Behold, and lo, these are the words of Alpha and Omega, even Jesus Christ. Amen.
39583	1510	1	VERILY, verily, I say unto you, my servants, that inasmuch as you have forgiven one another your trespasses, even so I, the Lord, forgive you.
39584	1510	2	Nevertheless, there are those among you who have sinned exceedingly; yea, even all of you have sinned; but verily I say unto you, beware from henceforth, and refrain from sin, lest sore judgments fall upon your heads.
39585	1510	3	For of him unto whom much is given much is required; and he who sins against the greater light shall receive the greater condemnation.
39586	1510	4	Ye call upon my name for revelations, and I give them unto you; and inasmuch as ye keep not my sayings, which I give unto you, ye become transgressors; and justice and judgment are the penalty which is affixed unto my law.
39587	1510	5	Therefore, what I say unto one I say unto all: Watch, for the adversary spreadeth his dominions, and darkness reigneth;
39588	1510	6	And the anger of God kindleth against the inhabitants of the earth; and none doeth good, for all have gone out of the way.
39589	1510	7	And now, verily I say unto you, I, the Lord, will not lay any sin to your charge; go your ways and sin no more; but unto that soul who sinneth shall the former sins return, saith the Lord your God.
39590	1510	8	And again, I say unto you, I give unto you a new commandment, that you may understand my will concerning you;
39591	1510	9	Or, in other words, I give unto you directions how you may act before me, that it may turn to you for your salvation.
39592	1510	10	I, the Lord, am bound when ye do what I say; but when ye do not what I say, ye have no promise.
39593	1510	11	Therefore, verily I say unto you, that it is expedient for my servants Edward Partridge and Newel K. Whitney, A. Sidney Gilbert and Sidney Rigdon, and my servant Joseph Smith, and John Whitmer and Oliver Cowdery, and W. W. Phelps and Martin Harris to be bound together by a bond and covenant that cannot be broken by transgression, except judgment shall immediately follow, in your several stewardships--
39594	1510	12	To manage the affairs of the poor, and all things pertaining to the bishopric both in the land of Zion and in the land of Kirtland;
39595	1510	13	For I have consecrated the land of Kirtland in mine own due time for the benefit of the saints of the Most High, and for a stake to Zion.
39596	1510	14	For Zion must increase in beauty, and in holiness; her borders must be enlarged; her stakes must be strengthened; yea, verily I say unto you, Zion must arise and put on her beautiful garments.
39597	1510	15	Therefore, I give unto you this commandment, that ye bind yourselves by this covenant, and it shall be done according to the laws of the Lord.
39598	1510	16	Behold, here is wisdom also in me for your good.
39599	1510	17	And you are to be equal, or in other words, you are to have equal claims on the properties, for the benefit of managing the concerns of your stewardships, every man according to his wants and his needs, inasmuch as his wants are just--
39600	1510	18	And all this for the benefit of the church of the living God, that every man may improve upon his talent, that every man may gain other talents, yea, even an hundred fold, to be cast into the Lord's storehouse, to become the common property of the whole church--
39601	1510	19	Every man seeking the interest of his neighbor, and doing all things with an eye single to the glory of God.
39602	1510	20	This order I have appointed to be an everlasting order unto you, and unto your successors, inasmuch as you sin not.
39603	1510	21	And the soul that sins against this covenant, and hardeneth his heart against it, shall be dealt with according to the laws of my church, and shall be delivered over to the buffetings of Satan until the day of redemption.
39604	1510	22	And now, verily I say unto you, and this is wisdom, make unto yourselves friends with the mammon of unrighteousness, and they will not destroy you.
39605	1510	23	Leave judgment alone with me, for it is mine and I will repay. Peace be with you; my blessings continue with you.
39606	1510	24	For even yet the kingdom is yours, and shall be forever, if you fall not from your steadfastness. Even so. Amen.
39607	1511	1	VERILY, thus saith the Lord, in addition to the laws of the church concerning women and children, those who belong to the church, who have lost their husbands or fathers:
39608	1511	2	Women have claim on their husbands for their maintenance, until their husbands are taken; and if they are not found transgressors they shall have fellowship in the church.
39609	1511	3	And if they are not faithful they shall not have fellowship in the church; yet they may remain upon their inheritances according to the laws of the land.
39610	1511	4	All children have claim upon their parents for their maintenance until they are of age.
39611	1511	5	And after that, they have claim upon the church, or in other words upon the Lord's storehouse, if their parents have not wherewith to give them inheritances.
39612	1511	6	And the storehouse shall be kept by the consecrations of the church; and widows and orphans shall be provided for, as also the poor. Amen.
39613	1512	1	A REVELATION of Jesus Christ unto his servant Joseph Smith, Jun., and six elders, as they united their hearts and lifted their voices on high.
39614	1512	2	Yea, the word of the Lord concerning his church, established in the last days for the restoration of his people, as he has spoken by the mouth of his prophets, and for the gathering of his saints to stand upon Mount Zion, which shall be the city of New Jerusalem.
39615	1512	3	Which city shall be built, beginning at the temple lot, which is appointed by the finger of the Lord, in the western boundaries of the State of Missouri, and dedicated by the hand of Joseph Smith, Jun., and others with whom the Lord was well pleased.
39616	1512	4	Verily this is the word of the Lord, that the city New Jerusalem shall be built by the gathering of the saints, beginning at this place, even the place of the temple, which temple shall be reared in this generation.
39617	1512	5	For verily this generation shall not all pass away until an house shall be built unto the Lord, and a cloud shall rest upon it, which cloud shall be even the glory of the Lord, which shall fill the house.
39618	1512	6	And the sons of Moses, according to the Holy Priesthood which he received under the hand of his father-in-law, Jethro;
39619	1512	7	And Jethro received it under the hand of Caleb;
39620	1512	8	And Caleb received it under the hand of Elihu;
39621	1512	9	And Elihu under the hand of Jeremy;
39622	1512	10	And Jeremy under the hand of Gad;
39623	1512	11	And Gad under the hand of Esaias;
39624	1512	12	And Esaias received it under the hand of God.
39625	1512	13	Esaias also lived in the days of Abraham, and was blessed of him--
39626	1512	14	Which Abraham received the priesthood from Melchizedek, who received it through the lineage of his fathers, even till Noah;
39627	1512	15	And from Noah till Enoch, through the lineage of their fathers;
39628	1512	16	And from Enoch to Abel, who was slain by the conspiracy of his brother, who received the priesthood by the commandments of God, by the hand of his father Adam, who was the first man--
39629	1512	17	Which priesthood continueth in the church of God in all generations, and is without beginning of days or end of years.
39630	1512	18	And the Lord confirmed a priesthood also upon Aaron and his seed, throughout all their generations, which priesthood also continueth and abideth forever with the priesthood which is after the holiest order of God.
39631	1512	19	And this greater priesthood administereth the gospel and holdeth the key of the mysteries of the kingdom, even the key of the knowledge of God.
39632	1512	20	Therefore, in the ordinances thereof, the power of godliness is manifest.
39633	1512	21	And without the ordinances thereof, and the authority of the priesthood, the power of godliness is not manifest unto men in the flesh;
39634	1512	22	For without this no man can see the face of God, even the Father, and live.
39635	1512	23	Now this Moses plainly taught to the children of Israel in the wilderness, and sought diligently to sanctify his people that they might behold the face of God;
39636	1512	24	But they hardened their hearts and could not endure his presence; therefore, the Lord in his wrath, for his anger was kindled against them, swore that they should not enter into his rest while in the wilderness, which rest is the fulness of his glory.
39637	1512	25	Therefore, he took Moses out of their midst, and the Holy Priesthood also;
39638	1512	26	And the lesser priesthood continued, which priesthood holdeth the key of the ministering of angels and the preparatory gospel;
39639	1512	27	Which gospel is the gospel of repentance and of baptism, and the remission of sins, and the law of carnal commandments, which the Lord in his wrath caused to continue with the house of Aaron among the children of Israel until John, whom God raised up, being filled with the Holy Ghost from his mother's womb.
39640	1512	28	For he was baptized while he was yet in his childhood, and was ordained by the angel of God at the time he was eight days old unto this power, to overthrow the kingdom of the Jews, and to make straight the way of the Lord before the face of his people, to prepare them for the coming of the Lord, in whose hand is given all power.
39641	1512	29	And again, the offices of elder and bishop are necessary appendages belonging unto the high priesthood.
39642	1512	30	And again, the offices of teacher and deacon are necessary appendages belonging to the lesser priesthood, which priesthood was confirmed upon Aaron and his sons.
39643	1512	31	Therefore, as I said concerning the sons of Moses--for the sons of Moses and also the sons of Aaron shall offer an acceptable offering and sacrifice in the house of the Lord, which house shall be built unto the Lord in this generation, upon the consecrated spot as I have appointed--
39644	1512	32	And the sons of Moses and of Aaron shall be filled with the glory of the Lord, upon Mount Zion in the Lord's house, whose sons are ye; and also many whom I have called and sent forth to build up my church.
39645	1512	33	For whoso is faithful unto the obtaining these two priesthoods of which I have spoken, and the magnifying their calling, are sanctified by the Spirit unto the renewing of their bodies.
39646	1512	34	They become the sons of Moses and of Aaron and the seed of Abraham, and the church and kingdom, and the elect of God.
39647	1512	35	And also all they who receive this priesthood receive me, saith the Lord;
39648	1512	36	For he that receiveth my servants receiveth me;
39649	1512	37	And he that receiveth me receiveth my Father;
39650	1512	38	And he that receiveth my Father receiveth my Father's kingdom; therefore all that my Father hath shall be given unto him.
39651	1512	39	And this is according to the oath and covenant which belongeth to the priesthood.
39652	1512	40	Therefore, all those who receive the priesthood, receive this oath and covenant of my Father, which he cannot break, neither can it be moved.
39653	1512	41	But whoso breaketh this covenant after he hath received it, and altogether turneth therefrom, shall not have forgiveness of sins in this world nor in the world to come.
39654	1512	42	And wo unto all those who come not unto this priesthood which ye have received, which I now confirm upon you who are present this day, by mine own voice out of the heavens; and even I have given the heavenly hosts and mine angels charge concerning you.
39655	1512	43	And I now give unto you a commandment to beware concerning yourselves, to give diligent heed to the words of eternal life.
39656	1512	44	For you shall live by every word that proceedeth forth from the mouth of God.
39657	1512	45	For the word of the Lord is truth, and whatsoever is truth is light, and whatsoever is light is Spirit, even the Spirit of Jesus Christ.
39658	1512	46	And the Spirit giveth light to every man that cometh into the world; and the Spirit enlighteneth every man through the world, that hearkeneth to the voice of the Spirit.
39659	1512	47	And every one that hearkeneth to the voice of the Spirit cometh unto God, even the Father.
39660	1512	48	And the Father teacheth him of the covenant which he has renewed and confirmed upon you, which is confirmed upon you for your sakes, and not for your sakes only, but for the sake of the whole world.
39661	1512	49	And the whole world lieth in sin, and groaneth under darkness and under the bondage of sin.
39662	1512	50	And by this you may know they are under the bondage of sin, because they come not unto me.
39663	1512	51	For whoso cometh not unto me is under the bondage of sin.
39664	1512	52	And whoso receiveth not my voice is not acquainted with my voice, and is not of me.
39665	1512	53	And by this you may know the righteous from the wicked, and that the whole world groaneth under sin and darkness even now.
39666	1512	54	And your minds in times past have been darkened because of unbelief, and because you have treated lightly the things you have received--
39667	1512	55	Which vanity and unbelief have brought the whole church under condemnation.
39668	1512	56	And this condemnation resteth upon the children of Zion, even all.
39669	1512	57	And they shall remain under this condemnation until they repent and remember the new covenant, even the Book of Mormon and the former commandments which I have given them, not only to say, but to do according to that which I have written--
39670	1512	58	That they may bring forth fruit meet for their Father's kingdom; otherwise there remaineth a scourge and judgment to be poured out upon the children of Zion.
39671	1512	59	For shall the children of the kingdom pollute my holy land? Verily, I say unto you, Nay.
39672	1512	60	Verily, verily, I say unto you who now hear my words, which are my voice, blessed are ye inasmuch as you receive these things;
39673	1512	61	For I will forgive you of your sins with this commandment--that you remain steadfast in your minds in solemnity and the spirit of prayer, in bearing testimony to all the world of those things which are communicated unto you.
39674	1512	62	Therefore, go ye into all the world; and unto whatsoever place ye cannot go ye shall send, that the testimony may go from you into all the world unto every creature.
39675	1512	63	And as I said unto mine apostles, even so I say unto you, for you are mine apostles, even God's high priests; ye are they whom my Father hath given me; ye are my friends;
39676	1512	64	Therefore, as I said unto mine apostles I say unto you again, that every soul who believeth on your words, and is baptized by water for the remission of sins, shall receive the Holy Ghost.
39677	1512	65	And these signs shall follow them that believe--
39678	1512	66	In my name they shall do many wonderful works;
39679	1512	67	In my name they shall cast out devils;
39680	1512	68	In my name they shall heal the sick;
39681	1512	69	In my name they shall open the eyes of the blind, and unstop the ears of the deaf;
39682	1512	70	And the tongue of the dumb shall speak;
39683	1512	71	And if any man shall administer poison unto them it shall not hurt them;
39684	1512	72	And the poison of a serpent shall not have power to harm them.
39685	1512	73	But a commandment I give unto them, that they shall not boast themselves of these things, neither speak them before the world; for these things are given unto you for your profit and for salvation.
39686	1512	74	Verily, verily, I say unto you, they who believe not on your words, and are not baptized in water in my name, for the remission of their sins, that they may receive the Holy Ghost, shall be damned, and shall not come into my Father's kingdom where my Father and I am.
39687	1512	75	And this revelation unto you, and commandment, is in force from this very hour upon all the world, and the gospel is unto all who have not received it.
39688	1512	76	But, verily I say unto all those to whom the kingdom has been given--from you it must be preached unto them, that they shall repent of their former evil works; for they are to be upbraided for their evil hearts of unbelief, and your brethren in Zion for their rebellion against you at the time I sent you.
39689	1512	77	And again I say unto you, my friends, for from henceforth I shall call you friends, it is expedient that I give unto you this commandment, that ye become even as my friends in days when I was with them, traveling to preach the gospel in my power;
39690	1512	78	For I suffered them not to have purse or scrip, neither two coats.
39691	1512	79	Behold, I send you out to prove the world, and the laborer is worthy of his hire.
39692	1512	80	And any man that shall go and preach this gospel of the kingdom, and fail not to continue faithful in all things, shall not be weary in mind, neither darkened, neither in body, limb, nor joint; and a hair of his head shall not fall to the ground unnoticed. And they shall not go hungry, neither athirst.
39693	1512	81	Therefore, take ye no thought for the morrow, for what ye shall eat, or what ye shall drink, or wherewithal ye shall be clothed.
39694	1512	82	For, consider the lilies of the field, how they grow, they toil not, neither do they spin; and the kingdoms of the world, in all their glory, are not arrayed like one of these.
39695	1512	83	For your Father, who is in heaven, knoweth that you have need of all these things.
39696	1512	84	Therefore, let the morrow take thought for the things of itself.
39697	1512	85	Neither take ye thought beforehand what ye shall say; but treasure up in your minds continually the words of life, and it shall be given you in the very hour that portion that shall be meted unto every man.
39698	1512	86	Therefore, let no man among you, for this commandment is unto all the faithful who are called of God in the church unto the ministry, from this hour take purse or scrip, that goeth forth to proclaim this gospel of the kingdom.
39699	1512	87	Behold, I send you out to reprove the world of all their unrighteous deeds, and to teach them of a judgment which is to come.
39700	1512	88	And whoso receiveth you, there I will be also, for I will go before your face. I will be on your right hand and on your left, and my Spirit shall be in your hearts, and mine angels round about you, to bear you up.
39701	1512	89	Whoso receiveth you receiveth me; and the same will feed you, and clothe you, and give you money.
39702	1512	90	And he who feeds you, or clothes you, or gives you money, shall in nowise lose his reward.
39703	1512	91	And he that doeth not these things is not my disciple; by this you may know my disciples.
39704	1512	92	He that receiveth you not, go away from him alone by yourselves, and cleanse your feet even with water, pure water, whether in heat or in cold, and bear testimony of it unto your Father which is in heaven, and return not again unto that man.
39705	1512	93	And in whatsoever village or city ye enter, do likewise.
39706	1512	94	Nevertheless, search diligently and spare not; and wo unto that house, or that village or city that rejecteth you, or your words, or your testimony concerning me.
39707	1512	95	Wo, I say again, unto that house, or that village or city that rejecteth you, or your words, or your testimony of me;
39708	1512	96	For I, the Almighty, have laid my hands upon the nations, to scourge them for their wickedness.
39709	1512	97	And plagues shall go forth, and they shall not be taken from the earth until I have completed my work, which shall be cut short in righteousness--
39710	1512	98	Until all shall know me, who remain, even from the least unto the greatest, and shall be filled with the knowledge of the Lord, and shall see eye to eye, and shall lift up their voice, and with the voice together sing this new song, saying:
39711	1512	99	The Lord hath brought again Zion;
39712	1512	100	The Lord hath redeemed his people;
39713	1512	101	The earth hath travailed and brought forth her strength;
39714	1512	102	Glory, and honor, and power, and might,
39715	1512	103	And again, verily, verily, I say unto you, it is expedient that every man who goes forth to proclaim mine everlasting gospel, that inasmuch as they have families, and receive money by gift, that they should send it unto them or make use of it for their benefit, as the Lord shall direct them, for thus it seemeth me good.
39716	1512	104	And let all those who have not families, who receive money, send it up unto the bishop in Zion, or unto the bishop in Ohio, that it may be consecrated for the bringing forth of the revelations and the printing thereof, and for establishing Zion.
39717	1512	105	And if any man shall give unto any of you a coat, or a suit, take the old and cast it unto the poor, and go on your way rejoicing.
39718	1512	106	And if any man among you be strong in the Spirit, let him take with him him that is weak, that he may be edified in all meekness, that he may become strong also.
39719	1512	107	Therefore, take with you those who are ordained unto the lesser priesthood, and send them before you to make appointments, and to prepare the way, and to fill appointments that you yourselves are not able to fill.
39720	1512	108	Behold, this is the way that mine apostles, in ancient days, built up my church unto me.
39721	1512	109	Therefore, let every man stand in his own office, and labor in his own calling; and let not the head say unto the feet it hath no need of the feet; for without the feet how shall the body be able to stand?
39722	1512	110	Also the body hath need of every member, that all may be edified together, that the system may be kept perfect.
39723	1512	111	And behold, the high priests should travel, and also the elders, and also the lesser priests; but the deacons and teachers should be appointed to watch over the church, to be standing ministers unto the church.
39724	1512	112	And the bishop, Newel K. Whitney, also should travel round about and among all the churches, searching after the poor to administer to their wants by humbling the rich and the proud.
39725	1512	113	He should also employ an agent to take charge and to do his secular business as he shall direct.
39726	1512	114	Nevertheless, let the bishop go unto the city of New York, also to the city of Albany, and also to the city of Boston, and warn the people of those cities with the sound of the gospel, with a loud voice, of the desolation and utter abolishment which await them if they do reject these things.
39727	1512	115	For if they do reject these things the hour of their judgment is nigh, and their house shall be left unto them desolate.
39728	1512	116	Let him trust in me and he shall not be confounded; and a hair of his head shall not fall to the ground unnoticed.
39729	1512	117	And verily I say unto you, the rest of my servants, go ye forth as your circumstances shall permit, in your several callings, unto the great and notable cities and villages, reproving the world in righteousness of all their unrighteous and ungodly deeds, setting forth clearly and understandingly the desolation of abomination in the last days.
39730	1512	118	For, with you saith the Lord Almighty, I will rend their kingdoms; I will not only shake the earth, but the starry heavens shall tremble.
39731	1512	119	For I, the Lord, have put forth my hand to exert the powers of heaven; ye cannot see it now, yet a little while and ye shall see it, and know that I am, and that I will come and reign with my people.
39732	1512	120	I am Alpha and Omega, the beginning and the end. Amen.
39733	1513	1	IT is the duty of the Lord's clerk, whom he has appointed, to keep a history, and a general church record of all things that transpire in Zion, and of all those who consecrate properties, and receive inheritances legally from the bishop;
39734	1513	2	And also their manner of life, their faith, and works; and also of the apostates who apostatize after receiving their inheritances.
39735	1513	3	It is contrary to the will and commandment of God that those who receive not their inheritance by consecration, agreeable to his law, which he has given, that he may tithe his people, to prepare them against the day of vengeance and burning, should have their names enrolled with the people of God.
39736	1513	4	Neither is their genealogy to be kept, or to be had where it may be found on any of the records or history of the church.
39737	1513	5	Their names shall not be found, neither the names of the fathers, nor the names of the children written in the book of the law of God, saith the Lord of Hosts.
39738	1513	6	Yea, thus saith the still small voice, which whispereth through and pierceth all things, and often times it maketh my bones to quake while it maketh manifest, saying:
39739	1513	7	And it shall come to pass that I, the Lord God, will send one mighty and strong, holding the scepter of power in his hand, clothed with light for a covering, whose mouth shall utter words, eternal words; while his bowels shall be a fountain of truth, to set in order the house of God, and to arrange by lot the inheritances of the saints whose names are found, and the names of their fathers, and of their children, enrolled in the book of the law of God;
39740	1513	8	While that man, who was called of God and appointed, that putteth forth his hand to steady the ark of God, shall fall by the shaft of death, like as a tree that is smitten by the vivid shaft of lightning.
39741	1513	9	And all they who are not found written in the book of remembrance shall find none inheritance in that day, but they shall be cut asunder, and their portion shall be appointed them among unbelievers, where are wailing and gnashing of teeth.
39742	1513	10	These things I say not of myself; therefore, as the Lord speaketh, he will also fulfil.
39743	1513	11	And they who are of the High Priesthood, whose names are not found written in the book of the law, or that are found to have apostatized, or to have been cut off from the church, as well as the lesser priesthood, or the members, in that day shall not find an inheritance among the saints of the Most High;
39744	1513	12	Therefore, it shall be done unto them as unto the children of the priest, as will be found recorded in the second chapter and sixty-first and second verses of Ezra.
39745	1514	1	VERILY, thus saith the Lord unto you my servants, concerning the parable of the wheat and of the tares:
39746	1514	2	Behold, verily I say, the field was the world, and the apostles were the sowers of the seed;
39747	1514	3	And after they have fallen asleep the great persecutor of the church, the apostate, the whore, even Babylon, that maketh all nations to drink of her cup, in whose hearts the enemy, even Satan, sitteth to reign--behold he soweth the tares; wherefore, the tares choke the wheat and drive the church into the wilderness.
39748	1514	4	But behold, in the last days, even now while the Lord is beginning to bring forth the word, and the blade is springing up and is yet tender--
39749	1514	5	Behold, verily I say unto you, the angels are crying unto the Lord day and night, who are ready and waiting to be sent forth to reap down the fields;
39750	1514	6	But the Lord saith unto them, pluck not up the tares while the blade is yet tender (for verily your faith is weak), lest you destroy the wheat also.
39751	1514	7	Therefore, let the wheat and the tares grow together until the harvest is fully ripe; then ye shall first gather out the wheat from among the tares, and after the gathering of the wheat, behold and lo, the tares are bound in bundles, and the field remaineth to be burned.
39752	1514	8	Therefore, thus saith the Lord unto you, with whom the priesthood hath continued through the lineage of your fathers--
39753	1514	9	For ye are lawful heirs, according to the flesh, and have been hid from the world with Christ in God--
39754	1514	10	Therefore your life and the priesthood have remained, and must needs remain through you and your lineage until the restoration of all things spoken by the mouths of all the holy prophets since the world began.
39755	1514	11	Therefore, blessed are ye if ye continue in my goodness, a light unto the Gentiles, and through this priesthood, a savior unto my people Israel. The Lord hath said it. Amen.
39756	1515	1	VERILY, thus saith the Lord concerning the wars that will shortly come to pass, beginning at the rebellion of South Carolina, which will eventually terminate in the death and misery of many souls;
39757	1515	2	And the time will come that war will be poured out upon all nations, beginning at this place.
39758	1515	3	For behold, the Southern States shall be divided against the Northern States, and the Southern States will call on other nations, even the nation of Great Britain, as it is called, and they shall also call upon other nations, in order to defend themselves against other nations; and then war shall be poured out upon all nations.
39759	1515	4	And it shall come to pass, after many days, slaves shall rise up against their masters, who shall be marshaled and disciplined for war.
39760	1515	5	And it shall come to pass also that the remnants who are left of the land will marshal themselves, and shall become exceedingly angry, and shall vex the Gentiles with a sore vexation.
39761	1515	6	And thus, with the sword and by bloodshed the inhabitants of the earth shall mourn; and with famine, and plague, and earthquake, and the thunder of heaven, and the fierce and vivid lightning also, shall the inhabitants of the earth be made to feel the wrath, and indignation, and chastening hand of an Almighty God, until the consumption decreed hath made a full end of all nations;
39762	1515	7	That the cry of the saints, and of the blood of the saints, shall cease to come up into the ears of the Lord of Sabaoth, from the earth, to be avenged of their enemies.
39763	1515	8	Wherefore, stand ye in holy places, and be not moved, until the day of the Lord come; for behold, it cometh quickly, saith the Lord. Amen.
39764	1516	1	VERILY, thus saith the Lord unto you who have assembled yourselves together to receive his will concerning you:
39765	1516	2	Behold, this is pleasing unto your Lord, and the angels rejoice over you; the alms of your prayers have come up into the ears of the Lord of Sabaoth, and are recorded in the book of the names of the sanctified, even them of the celestial world.
39766	1516	3	Wherefore, I now send upon you another Comforter, even upon you my friends, that it may abide in your hearts, even the Holy Spirit of promise; which other Comforter is the same that I promised unto my disciples, as is recorded in the testimony of John.
39767	1516	4	This Comforter is the promise which I give unto you of eternal life, even the glory of the celestial kingdom;
39768	1516	5	Which glory is that of the church of the Firstborn, even of God, the holiest of all, through Jesus Christ his Son--
39769	1516	6	He that ascended up on high, as also he descended below all things, in that he comprehended all things, that he might be in all and through all things, the light of truth;
39770	1516	7	Which truth shineth. This is the light of Christ. As also he is in the sun, and the light of the sun, and the power thereof by which it was made.
39771	1516	8	As also he is in the moon, and is the light of the moon, and the power thereof by which it was made;
39772	1516	9	As also the light of the stars, and the power thereof by which they were made;
39773	1516	10	And the earth also, and the power thereof, even the earth upon which you stand.
39774	1516	11	And the light which shineth, which giveth you light, is through him who enlighteneth your eyes, which is the same light that quickeneth your understandings;
39775	1516	12	Which light proceedeth forth from the presence of God to fill the immensity of space--
39776	1516	13	The light which is in all things, which giveth life to all things, which is the law by which all things are governed, even the power of God who sitteth upon his throne, who is in the bosom of eternity, who is in the midst of all things.
39777	1516	14	Now, verily I say unto you, that through the redemption which is made for you is brought to pass the resurrection from the dead.
39778	1516	15	And the spirit and the body are the soul of man.
39779	1516	16	And the resurrection from the dead is the redemption of the soul.
39780	1516	17	And the redemption of the soul is through him that quickeneth all things, in whose bosom it is decreed that the poor and the meek of the earth shall inherit it.
39781	1516	18	Therefore, it must needs be sanctified from all unrighteousness, that it may be prepared for the celestial glory;
39782	1516	19	For after it hath filled the measure of its creation, it shall be crowned with glory, even with the presence of God the Father;
39783	1516	20	That bodies who are of the celestial kingdom may possess it forever and ever; for, for this intent was it made and created, and for this intent are they sanctified.
39784	1516	21	And they who are not sanctified through the law which I have given unto you, even the law of Christ, must inherit another kingdom, even that of a terrestrial kingdom, or that of a telestial kingdom.
39785	1516	22	For he who is not able to abide the law of a celestial kingdom cannot abide a celestial glory.
39786	1516	23	And he who cannot abide the law of a terrestrial kingdom cannot abide a terrestrial glory.
39787	1516	24	And he who cannot abide the law of a telestial kingdom cannot abide a telestial glory; therefore he is not meet for a kingdom of glory. Therefore he must abide a kingdom which is not a kingdom of glory.
39788	1516	25	And again, verily I say unto you, the earth abideth the law of a celestial kingdom, for it filleth the measure of its creation, and transgresseth not the law--
39789	1516	26	Wherefore, it shall be sanctified; yea, notwithstanding it shall die, it shall be quickened again, and shall abide the power by which it is quickened, and the righteous shall inherit it.
39790	1516	27	For notwithstanding they die, they also shall rise again, a spiritual body.
39791	1516	28	They who are of a celestial spirit shall receive the same body which was a natural body; even ye shall receive your bodies, and your glory shall be that glory by which your bodies are quickened.
39792	1516	29	Ye who are quickened by a portion of the celestial glory shall then receive of the same, even a fulness.
39793	1516	30	And they who are quickened by a portion of the terrestrial glory shall then receive of the same, even a fulness.
39794	1516	31	And also they who are quickened by a portion of the telestial glory shall then receive of the same, even a fulness.
39795	1516	32	And they who remain shall also be quickened; nevertheless, they shall return again to their own place, to enjoy that which they are willing to receive, because they were not willing to enjoy that which they might have received.
39796	1516	33	For what doth it profit a man if a gift is bestowed upon him, and he receive not the gift? Behold, he rejoices not in that which is given unto him, neither rejoices in him who is the giver of the gift.
39797	1516	34	And again, verily I say unto you, that which is governed by law is also preserved by law and perfected and sanctified by the same.
39798	1516	35	That which breaketh a law, and abideth not by law, but seeketh to become a law unto itself, and willeth to abide in sin, and altogether abideth in sin, cannot be sanctified by law, neither by mercy, justice, nor judgment. Therefore, they must remain filthy still.
39799	1516	36	All kingdoms have a law given;
39800	1516	37	And there are many kingdoms; for there is no space in the which there is no kingdom; and there is no kingdom in which there is no space, either a greater or a lesser kingdom.
39801	1516	38	And unto every kingdom is given a law; and unto every law there are certain bounds also and conditions.
39802	1516	39	All beings who abide not in those conditions are not justified.
39803	1516	40	For intelligence cleaveth unto intelligence; wisdom receiveth wisdom; truth embraceth truth; virtue loveth virtue; light cleaveth unto light; mercy hath compassion on mercy and claimeth her own; justice continueth its course and claimeth its own; judgment goeth before the face of him who sitteth upon the throne and governeth and executeth all things.
39804	1516	41	He comprehendeth all things, and all things are before him, and all things are round about him; and he is above all things, and in all things, and is through all things, and is round about all things; and all things are by him, and of him, even God, forever and ever.
39805	1516	42	And again, verily I say unto you, he hath given a law unto all things, by which they move in their times and their seasons;
39806	1516	43	And their courses are fixed, even the courses of the heavens and the earth, which comprehend the earth and all the planets.
39807	1516	44	And they give light to each other in their times and in their seasons, in their minutes, in their hours, in their days, in their weeks, in their months, in their years--all these are one year with God, but not with man.
39808	1516	45	The earth rolls upon her wings, and the sun giveth his light by day, and the moon giveth her light by night, and the stars also give their light, as they roll upon their wings in their glory, in the midst of the power of God.
39809	1516	46	Unto what shall I liken these kingdoms, that ye may understand?
39810	1516	47	Behold, all these are kingdoms, and any man who hath seen any or the least of these hath seen God moving in his majesty and power.
39811	1516	48	I say unto you, he hath seen him; nevertheless, he who came unto his own was not comprehended.
39812	1516	49	The light shineth in darkness, and the darkness comprehendeth it not; nevertheless, the day shall come when you shall comprehend even God, being quickened in him and by him.
39813	1516	50	Then shall ye know that ye have seen me, that I am, and that I am the true light that is in you, and that you are in me; otherwise ye could not abound.
39814	1516	51	Behold, I will liken these kingdoms unto a man having a field, and he sent forth his servants into the field to dig in the field.
39815	1516	52	And he said unto the first: Go ye and labor in the field, and in the first hour I will come unto you, and ye shall behold the joy of my countenance.
39816	1516	53	And he said unto the second: Go ye also into the field, and in the second hour I will visit you with the joy of my countenance.
39817	1516	54	And also unto the third, saying: I will visit you;
39818	1516	55	And unto the fourth, and so on unto the twelfth.
39819	1516	56	And the lord of the field went unto the first in the first hour, and tarried with him all that hour, and he was made glad with the light of the countenance of his lord.
39820	1516	57	And then he withdrew from the first that he might visit the second also, and the third, and the fourth, and so on unto the twelfth.
39821	1516	58	And thus they all received the light of the countenance of their lord, every man in his hour, and in his time, and in his season--
39822	1516	59	Beginning at the first, and so on unto the last, and from the last unto the first, and from the first unto the last;
39823	1516	60	Every man in his own order, until his hour was finished, even according as his lord had commanded him, that his lord might be glorified in him, and he in his lord, that they all might be glorified.
39824	1516	61	Therefore, unto this parable I will liken all these kingdoms, and the inhabitants thereof--every kingdom in its hour, and in its time, and in its season, even according to the decree which God hath made.
39825	1516	62	And again, verily I say unto you, my friends, I leave these sayings with you to ponder in your hearts, with this commandment which I give unto you, that ye shall call upon me while I am near--
39826	1516	63	Draw near unto me and I will draw near unto you; seek me diligently and ye shall find me; ask, and ye shall receive; knock, and it shall be opened unto you.
39827	1516	64	Whatsoever ye ask the Father in my name it shall be given unto you, that is expedient for you;
39828	1516	65	And if ye ask anything that is not expedient for you, it shall turn unto your condemnation.
39829	1516	66	Behold, that which you hear is as the voice of one crying in the wilderness--in the wilderness, because you cannot see him--my voice, because my voice is Spirit; my Spirit is truth; truth abideth and hath no end; and if it be in you it shall abound.
39830	1516	67	And if your eye be single to my glory, your whole bodies shall be filled with light, and there shall be no darkness in you; and that body which is filled with light comprehendeth all things.
39831	1516	68	Therefore, sanctify yourselves that your minds become single to God, and the days will come that you shall see him; for he will unveil his face unto you, and it shall be in his own time, and in his own way, and according to his own will.
39832	1516	69	Remember the great and last promise which I have made unto you; cast away your idle thoughts and your excess of laughter far from you.
39833	1516	70	Tarry ye, tarry ye in this place, and call a solemn assembly, even of those who are the first laborers in this last kingdom.
39834	1516	71	And let those whom they have warned in their traveling call on the Lord, and ponder the warning in their hearts which they have received, for a little season.
39835	1516	72	Behold, and lo, I will take care of your flocks, and will raise up elders and send unto them.
39836	1516	73	Behold, I will hasten my work in its time.
39837	1516	74	And I give unto you, who are the first laborers in this last kingdom, a commandment that you assemble yourselves together, and organize yourselves, and prepare yourselves, and sanctify yourselves; yea, purify your hearts, and cleanse your hands and your feet before me, that I may make you clean;
39838	1516	75	That I may testify unto your Father, and your God, and my God, that you are clean from the blood of this wicked generation; that I may fulfil this promise, this great and last promise, which I have made unto you, when I will.
39839	1516	76	Also, I give unto you a commandment that ye shall continue in prayer and fasting from this time forth.
39840	1516	77	And I give unto you a commandment that you shall teach one another the doctrine of the kingdom.
39841	1516	78	Teach ye diligently and my grace shall attend you, that you may be instructed more perfectly in theory, in principle, in doctrine, in the law of the gospel, in all things that pertain unto the kingdom of God, that are expedient for you to understand;
39842	1516	79	Of things both in heaven and in the earth, and under the earth; things which have been, things which are, things which must shortly come to pass; things which are at home, things which are abroad; the wars and the perplexities of the nations, and the judgments which are on the land; and a knowledge also of countries and of kingdoms--
39843	1516	80	That ye may be prepared in all things when I shall send you again to magnify the calling whereunto I have called you, and the mission with which I have commissioned you.
39844	1516	81	Behold, I sent you out to testify and warn the people, and it becometh every man who hath been warned to warn his neighbor.
39845	1516	82	Therefore, they are left without excuse, and their sins are upon their own heads.
39846	1516	83	He that seeketh me early shall find me, and shall not be forsaken.
39847	1516	84	Therefore, tarry ye, and labor diligently, that you may be perfected in your ministry to go forth among the Gentiles for the last time, as many as the mouth of the Lord shall name, to bind up the law and seal up the testimony, and to prepare the saints for the hour of judgment which is to come;
39848	1516	85	That their souls may escape the wrath of God, the desolation of abomination which awaits the wicked, both in this world and in the world to come. Verily, I say unto you, let those who are not the first elders continue in the vineyard until the mouth of the Lord shall call them, for their time is not yet come; their garments are not clean from the blood of this generation.
39849	1516	86	Abide ye in the liberty wherewith ye are made free; entangle not yourselves in sin, but let your hands be clean, until the Lord comes.
39850	1516	87	For not many days hence and the earth shall tremble and reel to and fro as a drunken man; and the sun shall hide his face, and shall refuse to give light; and the moon shall be bathed in blood; and the stars shall become exceedingly angry, and shall cast themselves down as a fig that falleth from off a fig-tree.
39851	1516	88	And after your testimony cometh wrath and indignation upon the people.
39852	1516	89	For after your testimony cometh the testimony of earthquakes, that shall cause groanings in the midst of her, and men shall fall upon the ground and shall not be able to stand.
39853	1516	90	And also cometh the testimony of the voice of thunderings, and the voice of lightnings, and the voice of tempests, and the voice of the waves of the sea heaving themselves beyond their bounds.
39854	1516	91	And all things shall be in commotion; and surely, men's hearts shall fail them; for fear shall come upon all people.
39855	1516	92	And angels shall fly through the midst of heaven, crying with a loud voice, sounding the trump of God, saying: Prepare ye, prepare ye, O inhabitants of the earth; for the judgment of our God is come. Behold, and lo, the Bridegroom cometh; go ye out to meet him.
39856	1516	93	And immediately there shall appear a great sign in heaven, and all people shall see it together.
39857	1516	94	And another angel shall sound his trump, saying: That great church, the mother of abominations, that made all nations drink of the wine of the wrath of her fornication, that persecuteth the saints of God, that shed their blood--she who sitteth upon many waters, and upon the islands of the sea--behold, she is the tares of the earth; she is bound in bundles; her bands are made strong, no man can loose them; therefore, she is ready to be burned. And he shall sound his trump both long and loud, and all nations shall hear it.
39858	1516	95	And there shall be silence in heaven for the space of half an hour; and immediately after shall the curtain of heaven be unfolded, as a scroll is unfolded after it is rolled up, and the face of the Lord shall be unveiled;
39859	1516	96	And the saints that are upon the earth, who are alive, shall be quickened and be caught up to meet him.
39860	1516	97	And they who have slept in their graves shall come forth, for their graves shall be opened; and they also shall be caught up to meet him in the midst of the pillar of heaven--
39861	1516	98	They are Christ's, the first fruits, they who shall descend with him first, and they who are on the earth and in their graves, who are first caught up to meet him; and all this by the voice of the sounding of the trump of the angel of God.
39862	1516	99	And after this another angel shall sound, which is the second trump; and then cometh the redemption of those who are Christ's at his coming; who have received their part in that prison which is prepared for them, that they might receive the gospel, and be judged according to men in the flesh.
39863	1516	100	And again, another trump shall sound, which is the third trump; and then come the spirits of men who are to be judged, and are found under condemnation;
39864	1516	101	And these are the rest of the dead; and they live not again until the thousand years are ended, neither again, until the end of the earth.
39865	1516	102	And another trump shall sound, which is the fourth trump, saying: There are found among those who are to remain until that great and last day, even the end, who shall remain filthy still.
39866	1516	103	And another trump shall sound, which is the fifth trump, which is the fifth angel who committeth the everlasting gospel--flying through the midst of heaven, unto all nations, kindreds, tongues, and people;
39867	1516	104	And this shall be the sound of his trump, saying to all people, both in heaven and in earth, and that are under the earth--for every ear shall hear it, and every knee shall bow, and every tongue shall confess, while they hear the sound of the trump, saying: Fear God, and give glory to him who sitteth upon the throne, forever and ever; for the hour of his judgment is come.
39868	1516	105	And again, another angel shall sound his trump, which is the sixth angel, saying: She is fallen who made all nations drink of the wine of the wrath of her fornication; she is fallen, is fallen!
39869	1516	106	And again, another angel shall sound his trump, which is the seventh angel, saying: It is finished; it is finished! The Lamb of God hath overcome and trodden the wine-press alone, even the wine-press of the fierceness of the wrath of Almighty God.
39870	1516	107	And then shall the angels be crowned with the glory of his might, and the saints shall be filled with his glory, and receive their inheritance and be made equal with him.
39871	1516	108	And then shall the first angel again sound his trump in the ears of all living, and reveal the secret acts of men, and the mighty works of God in the first thousand years.
39872	1516	109	And then shall the second angel sound his trump, and reveal the secret acts of men, and the thoughts and intents of their hearts, and the mighty works of God in the second thousand years--
39873	1516	110	And so on, until the seventh angel shall sound his trump; and he shall stand forth upon the land and upon the sea, and swear in the name of him who sitteth upon the throne, that there shall be time no longer; and Satan shall be bound, that old serpent, who is called the devil, and shall not be loosed for the space of a thousand years.
39874	1516	111	And then he shall be loosed for a little season, that he may gather together his armies.
39875	1516	112	And Michael, the seventh angel, even the archangel, shall gather together his armies, even the hosts of heaven.
39876	1516	113	And the devil shall gather together his armies; even the hosts of hell, and shall come up to battle against Michael and his armies.
39877	1516	114	And then cometh the battle of the great God; and the devil and his armies shall be cast away into their own place, that they shall not have power over the saints any more at all.
39878	1516	115	For Michael shall fight their battles, and shall overcome him who seeketh the throne of him who sitteth upon the throne, even the Lamb.
39879	1516	116	This is the glory of God, and the sanctified; and they shall not any more see death.
39880	1516	117	Therefore, verily I say unto you, my friends, call your solemn assembly, as I have commanded you.
39881	1516	118	And as all have not faith, seek ye diligently and teach one another words of wisdom; yea, seek ye out of the best books words of wisdom; seek learning, even by study and also by faith.
39882	1516	119	Organize yourselves; prepare every needful thing; and establish a house, even a house of prayer, a house of fasting, a house of faith, a house of learning, a house of glory, a house of order, a house of God;
39883	1516	120	That your incomings may be in the name of the Lord; that your outgoings may be in the name of the Lord; that all your salutations may be in the name of the Lord, with uplifted hands unto the Most High.
39884	1516	121	Therefore, cease from all your light speeches, from all laughter, from all your lustful desires, from all your pride and light-mindedness, and from all your wicked doings.
39885	1516	122	Appoint among yourselves a teacher, and let not all be spokesmen at once; but let one speak at a time and let all listen unto his sayings, that when all have spoken that all may be edified of all, and that every man may have an equal privilege.
39886	1516	123	See that ye love one another; cease to be covetous; learn to impart one to another as the gospel requires.
39887	1516	124	Cease to be idle; cease to be unclean; cease to find fault one with another; cease to sleep longer than is needful; retire to thy bed early, that ye may not be weary; arise early, that your bodies and your minds may be invigorated.
39888	1516	125	And above all things, clothe yourselves with the bond of charity, as with a mantle, which is the bond of perfectness and peace.
39889	1516	126	Pray always, that ye may not faint, until I come. Behold, and lo, I will come quickly, and receive you unto myself. Amen.
39890	1516	127	And again, the order of the house prepared for the presidency of the school of the prophets, established for their instruction in all things that are expedient for them, even for all the officers of the church, or in other words, those who are called to the ministry in the church, beginning at the high priests, even down to the deacons--
39891	1516	128	And this shall be the order of the house of the presidency of the school: He that is appointed to be president, or teacher, shall be found standing in his place, in the house which shall be prepared for him.
39892	1516	129	Therefore, he shall be first in the house of God, in a place that the congregation in the house may hear his words carefully and distinctly, not with loud speech.
39893	1516	130	And when he cometh into the house of God, for he should be first in the house--behold, this is beautiful, that he may be an example--
39894	1516	131	Let him offer himself in prayer upon his knees before God, in token or remembrance of the everlasting covenant.
39895	1516	132	And when any shall come in after him, let the teacher arise, and, with uplifted hands to heaven, yea, even directly, salute his brother or brethren with these words:
39896	1516	133	Art thou a brother or brethren? I salute you in the name of the Lord Jesus Christ, in token or remembrance of the everlasting covenant, in which covenant I receive you to fellowship, in a determination that is fixed, immovable, and unchangeable, to be your friend and brother through the grace of God in the bonds of love, to walk in all the commandments of God blameless, in thanksgiving, forever and ever. Amen.
39897	1516	134	And he that is found unworthy of this salutation shall not have place among you; for ye shall not suffer that mine house shall be polluted by him.
39898	1516	135	And he that cometh in and is faithful before me, and is a brother, or if they be brethren, they shall salute the president or teacher with uplifted hands to heaven, with this same prayer and covenant, or by saying Amen, in token of the same.
39899	1516	136	Behold, verily, I say unto you, this is an ensample unto you for a salutation to one another in the house of God, in the school of the prophets.
39900	1516	137	And ye are called to do this by prayer and thanksgiving, as the Spirit shall give utterance in all your doings in the house of the Lord, in the school of the prophets, that it may become a sanctuary, a tabernacle of the Holy Spirit to your edification.
39901	1516	138	And ye shall not receive any among you into this school save he is clean from the blood of this generation;
39902	1516	139	And he shall be received by the ordinance of the washing of feet, for unto this end was the ordinance of the washing of feet instituted.
39903	1516	140	And again, the ordinance of washing feet is to be administered by the president, or presiding elder of the church.
39904	1516	141	It is to be commenced with prayer; and after partaking of bread and wine, he is to gird himself according to the pattern given in the thirteenth chapter of John's testimony concerning me. Amen.
39905	1517	1	A WORD OF WISDOM, for the benefit of the council of high priests, assembled in Kirtland, and the church, and also the saints in Zion--
39906	1517	2	To be sent greeting; not by commandment or constraint, but by revelation and the word of wisdom, showing forth the order and will of God in the temporal salvation of all saints in the last days--
39907	1517	3	Given for a principle with promise, adapted to the capacity of the weak and the weakest of all saints, who are or can be called saints.
39908	1517	4	Behold, verily, thus saith the Lord unto you: In consequence of evils and designs which do and will exist in the hearts of conspiring men in the last days, I have warned you, and forewarn you, by giving unto you this word of wisdom by revelation--
39909	1517	5	That inasmuch as any man drinketh wine or strong drink among you, behold it is not good, neither meet in the sight of your Father, only in assembling yourselves together to offer up your sacraments before him.
39910	1517	6	And, behold, this should be wine, yea, pure wine of the grape of the vine, of your own make.
39911	1517	7	And, again, strong drinks are not for the belly, but for the washing of your bodies.
39912	1517	8	And again, tobacco is not for the body, neither for the belly, and is not good for man, but is an herb for bruises and all sick cattle, to be used with judgment and skill.
39913	1517	9	And again, hot drinks are not for the body or belly.
39914	1517	10	And again, verily I say unto you, all wholesome herbs God hath ordained for the constitution, nature, and use of man--
39915	1517	11	Every herb in the season thereof, and every fruit in the season thereof; all these to be used with prudence and thanksgiving.
39916	1517	12	Yea, flesh also of beasts and of the fowls of the air, I, the Lord, have ordained for the use of man with thanksgiving; nevertheless they are to be used sparingly;
39917	1517	13	And it is pleasing unto me that they should not be used, only in times of winter, or of cold, or famine.
39918	1517	14	All grain is ordained for the use of man and of beasts, to be the staff of life, not only for man but for the beasts of the field, and the fowls of heaven, and all wild animals that run or creep on the earth;
39919	1517	15	And these hath God made for the use of man only in times of famine and excess of hunger.
39920	1517	16	All grain is good for the food of man; as also the fruit of the vine; that which yieldeth fruit, whether in the ground or above the ground--
39921	1517	17	Nevertheless, wheat for man, and corn for the ox, and oats for the horse, and rye for the fowls and for swine, and for all beasts of the field, and barley for all useful animals, and for mild drinks, as also other grain.
39922	1517	18	And all saints who remember to keep and do these sayings, walking in obedience to the commandments, shall receive health in their navel and marrow to their bones;
39923	1517	19	And shall find wisdom and great treasures of knowledge, even hidden treasures;
39924	1517	20	And shall run and not be weary, and shall walk and not faint.
39925	1517	21	And I, the Lord, give unto them a promise, that the destroying angel shall pass by them, as the children of Israel, and not slay them. Amen.
39926	1518	1	THUS saith the Lord, verily, verily I say unto you my son, thy sins are forgiven thee, according to thy petition, for thy prayers and the prayers of thy brethren have come up into my ears.
39927	1518	2	Therefore, thou art blessed from henceforth that bear the keys of the kingdom given unto you; which kingdom is coming forth for the last time.
39928	1518	3	Verily I say unto you, the keys of this kingdom shall never be taken from you, while thou art in the world, neither in the world to come;
39929	1518	4	Nevertheless, through you shall the oracles be given to another, yea, even unto the church.
39930	1518	5	And all they who receive the oracles of God, let them beware how they hold them lest they are accounted as a light thing, and are brought under condemnation thereby, and stumble and fall when the storms descend, and the winds blow, and the rains descend, and beat upon their house.
39931	1518	6	And again, verily I say unto thy brethren, Sidney Rigdon and Frederick G. Williams, their sins are forgiven them also, and they are accounted as equal with thee in holding the keys of this last kingdom;
39932	1518	7	As also through your administration the keys of the school of the prophets, which I have commanded to be organized;
39933	1518	8	That thereby they may be perfected in their ministry for the salvation of Zion, and of the nations of Israel, and of the Gentiles, as many as will believe;
39934	1518	9	That through your administration they may receive the word, and through their administration the word may go forth unto the ends of the earth, unto the Gentiles first, and then, behold, and lo, they shall turn unto the Jews.
39935	1518	10	And then cometh the day when the arm of the Lord shall be revealed in power in convincing the nations, the heathen nations, the house of Joseph, of the gospel of their salvation.
39936	1518	11	For it shall come to pass in that day, that every man shall hear the fulness of the gospel in his own tongue, and in his own language, through those who are ordained unto this power, by the administration of the Comforter, shed forth upon them for the revelation of Jesus Christ.
39937	1518	12	And now, verily I say unto you, I give unto you a commandment that you continue in the ministry and presidency.
39938	1518	13	And when you have finished the translation of the prophets, you shall from thenceforth preside over the affairs of the church and the school;
39939	1518	14	And from time to time, as shall be manifested by the Comforter, receive revelations to unfold the mysteries of the kingdom;
39940	1518	15	And set in order the churches, and study and learn, and become acquainted with all good books, and with languages, tongues, and people.
39941	1518	16	And this shall be your business and mission in all your lives, to preside in council, and set in order all the affairs of this church and kingdom.
39942	1518	17	Be not ashamed, neither confounded; but be admonished in all your high-mindedness and pride, for it bringeth a snare upon your souls.
39943	1518	18	Set in order your houses; keep slothfulness and uncleanness far from you.
39944	1518	19	Now, verily I say unto you, let there be a place provided, as soon as it is possible, for the family of thy counselor and scribe, even Frederick G. Williams.
39945	1518	20	And let mine aged servant, Joseph Smith, Sen., continue with his family upon the place where he now lives; and let it not be sold until the mouth of the Lord shall name.
39946	1518	21	And let my counselor, even Sidney Rigdon, remain where he now resides until the mouth of the Lord shall name.
39947	1518	22	And let the bishop search diligently to obtain an agent, and let him be a man who has got riches in store--a man of God, and of strong faith--
39948	1518	23	That thereby he may be enabled to discharge every debt; that the storehouse of the Lord may not be brought into disrepute before the eyes of the people.
39949	1518	24	Search diligently, pray always, and be believing, and all things shall work together for your good, if ye walk uprightly and remember the covenant wherewith ye have covenanted one with another.
39950	1518	25	Let your families be small, especially mine aged servant Joseph Smith's, Sen., as pertaining to those who do not belong to your families;
39951	1518	26	That those things that are provided for you, to bring to pass my work, be not taken from you and given to those that are not worthy--
39952	1518	27	And thereby you be hindered in accomplishing those things which I have commanded you.
39953	1518	28	And again, verily I say unto you, it is my will that my handmaid Vienna Jaques should receive money to bear her expenses, and go up unto the land of Zion;
39954	1518	29	And the residue of the money may be consecrated unto me, and she be rewarded in mine own due time.
39955	1518	30	Verily I say unto you, that it is meet in mine eyes that she should go up unto the land of Zion, and receive an inheritance from the hand of the bishop;
39956	1518	31	That she may settle down in peace inasmuch as she is faithful, and not be idle in her days from thenceforth.
39957	1518	32	And behold, verily I say unto you, that ye shall write this commandment, and say unto your brethren in Zion, in love greeting, that I have called you also to preside over Zion in mine own due time.
39958	1518	33	Therefore, let them cease wearying me concerning this matter.
39959	1518	34	Behold, I say unto you that your brethren in Zion begin to repent, and the angels rejoice over them.
39960	1518	35	Nevertheless, I am not well pleased with many things; and I am not well pleased with my servant William E. McLellin, neither with my servant Sidney Gilbert; and the bishop also, and others have many things to repent of.
39961	1518	36	But verily I say unto you, that I, the Lord, will contend with Zion, and plead with her strong ones, and chasten her until she overcomes and is clean before me.
39962	1518	37	For she shall not be removed out of her place. I, the Lord, have spoken it. Amen.
39963	1519	1	VERILY, thus saith the Lord unto you concerning the Apocrypha--There are many things contained therein that are true, and it is mostly translated correctly;
39964	1519	2	There are many things contained therein that are not true, which are interpolations by the hands of men.
39965	1519	3	Verily, I say unto you, that it is not needful that the Apocrypha should be translated.
39966	1519	4	Therefore, whoso readeth it, let him understand, for the Spirit manifesteth truth;
39967	1519	5	And whoso is enlightened by the Spirit shall obtain benefit therefrom;
39968	1519	6	And whoso receiveth not by the Spirit, cannot be benefited. Therefore it is not needful that it should be translated. Amen.
39969	1520	1	VERILY, thus saith the Lord, I give unto the united order, organized agreeable to the commandment previously given, a revelation and commandment concerning my servant Frederick G. Williams, that ye shall receive him into the order. What I say unto one I say unto all.
39970	1520	2	And again, I say unto you my servant Frederick G. Williams, you shall be a lively member in this order; and inasmuch as you are faithful in keeping all former commandments you shall be blessed forever. Amen.
39971	1521	1	VERILY, thus saith the Lord: It shall come to pass that every soul who forsaketh his sins and cometh unto me, and calleth on my name, and obeyeth my voice, and keepeth my commandments, shall see my face and know that I am;
39972	1521	2	And that I am the true light that lighteth every man that cometh into the world;
39973	1521	3	And that I am in the Father, and the Father in me, and the Father and I are one--
39974	1521	4	The Father because he gave me of his fulness, and the Son because I was in the world and made flesh my tabernacle, and dwelt among the sons of men.
39975	1521	5	I was in the world and received of my Father, and the works of him were plainly manifest.
39976	1521	6	And John saw and bore record of the fulness of my glory, and the fulness of John's record is hereafter to be revealed.
39977	1521	7	And he bore record, saying: I saw his glory, that he was in the beginning, before the world was;
39978	1521	8	Therefore, in the beginning the Word was, for he was the Word, even the messenger of salvation--
39979	1521	9	The light and the Redeemer of the world; the Spirit of truth, who came into the world, because the world was made by him, and in him was the life of men and the light of men.
39980	1521	10	The worlds were made by him; men were made by him; all things were made by him, and through him, and of him.
39981	1521	11	And I, John, bear record that I beheld his glory, as the glory of the Only Begotten of the Father, full of grace and truth, even the Spirit of truth, which came and dwelt in the flesh, and dwelt among us.
39982	1521	12	And I, John, saw that he received not of the fulness at the first, but received grace for grace;
39983	1521	13	And he received not of the fulness at first, but continued from grace to grace, until he received a fulness;
39984	1521	14	And thus he was called the Son of God, because he received not of the fulness at the first.
39985	1521	15	And I, John, bear record, and lo, the heavens were opened, and the Holy Ghost descended upon him in the form of a dove, and sat upon him, and there came a voice out of heaven saying: This is my beloved Son.
39986	1521	16	And I, John, bear record that he received a fulness of the glory of the Father;
39987	1521	17	And he received all power, both in heaven and on earth, and the glory of the Father was with him, for he dwelt in him.
39988	1521	18	And it shall come to pass, that if you are faithful you shall receive the fulness of the record of John.
39989	1521	19	I give unto you these sayings that you may understand and know how to worship, and know what you worship, that you may come unto the Father in my name, and in due time receive of his fulness.
39990	1521	20	For if you keep my commandments you shall receive of his fulness, and be glorified in me as I am in the Father; therefore, I say unto you, you shall receive grace for grace.
39991	1521	21	And now, verily I say unto you, I was in the beginning with the Father, and am the Firstborn;
39992	1521	22	And all those who are begotten through me are partakers of the glory of the same, and are the church of the Firstborn.
39993	1521	23	Ye were also in the beginning with the Father; that which is Spirit, even the Spirit of truth;
39994	1521	24	And truth is knowledge of things as they are, and as they were, and as they are to come;
39995	1521	25	And whatsoever is more or less than this is the spirit of that wicked one who was a liar from the beginning.
39996	1521	26	The Spirit of truth is of God. I am the Spirit of truth, and John bore record of me, saying: He received a fulness of truth, yea, even of all truth;
39997	1521	27	And no man receiveth a fulness unless he keepeth his commandments.
39998	1521	28	He that keepeth his commandments receiveth truth and light, until he is glorified in truth and knoweth all things.
39999	1521	29	Man was also in the beginning with God. Intelligence, or the light of truth, was not created or made, neither indeed can be.
40000	1521	30	All truth is independent in that sphere in which God has placed it, to act for itself, as all intelligence also; otherwise there is no existence.
40001	1521	31	Behold, here is the agency of man, and here is the condemnation of man; because that which was from the beginning is plainly manifest unto them, and they receive not the light.
40002	1521	32	And every man whose spirit receiveth not the light is under condemnation.
40003	1521	33	For man is spirit. The elements are eternal, and spirit and element, inseparably connected, receive a fulness of joy;
40004	1521	34	And when separated, man cannot receive a fulness of joy.
40005	1521	35	The elements are the tabernacle of God; yea, man is the tabernacle of God, even temples; and whatsoever temple is defiled, God shall destroy that temple.
40006	1521	36	The glory of God is intelligence, or, in other words, light and truth.
40007	1521	37	Light and truth forsake that evil one.
40008	1521	38	Every spirit of man was innocent in the beginning; and God having redeemed man from the fall, men became again, in their infant state, innocent before God.
40009	1521	39	And that wicked one cometh and taketh away light and truth, through disobedience, from the children of men, and because of the tradition of their fathers.
40010	1521	40	But I have commanded you to bring up your children in light and truth.
40011	1521	41	But verily I say unto you, my servant Frederick G. Williams, you have continued under this condemnation;
40012	1521	42	You have not taught your children light and truth, according to the commandments; and that wicked one hath power, as yet, over you, and this is the cause of your affliction.
40013	1521	43	And now a commandment I give unto you--if you will be delivered you shall set in order your own house, for there are many things that are not right in your house.
40014	1521	44	Verily, I say unto my servant Sidney Rigdon, that in some things he hath not kept the commandments concerning his children; therefore, first set in order thy house.
40015	1521	45	Verily, I say unto my servant Joseph Smith, Jun., or in other words, I will call you friends, for you are my friends, and ye shall have an inheritance with me--
40016	1521	46	I called you servants for the world's sake, and ye are their servants for my sake--
40017	1521	47	And now, verily I say unto Joseph Smith, Jun.--You have not kept the commandments, and must needs stand rebuked before the Lord;
40018	1521	48	Your family must needs repent and forsake some things, and give more earnest heed unto your sayings, or be removed out of their place.
40019	1521	49	What I say unto one I say unto all; pray always lest that wicked one have power in you, and remove you out of your place.
40020	1521	50	My servant Newel K. Whitney also, a bishop of my church, hath need to be chastened, and set in order his family, and see that they are more diligent and concerned at home, and pray always, or they shall be removed out of their place.
40021	1521	51	Now, I say unto you, my friends, let my servant Sidney Rigdon go on his journey, and make haste, and also proclaim the acceptable year of the Lord, and the gospel of salvation, as I shall give him utterance; and by your prayer of faith with one consent I will uphold him.
40022	1521	52	And let my servants Joseph Smith, Jun., and Frederick G. Williams make haste also, and it shall be given them even according to the prayer of faith; and inasmuch as you keep my sayings you shall not be confounded in this world, nor in the world to come.
40023	1521	53	And, verily I say unto you, that it is my will that you should hasten to translate my scriptures, and to obtain a knowledge of history, and of countries, and of kingdoms, of laws of God and man, and all this for the salvation of Zion. Amen.
40024	1522	1	AND again, verily I say unto you, my friends, a commandment I give unto you, that ye shall commence a work of laying out and preparing a beginning and foundation of the city of the stake of Zion, here in the land of Kirtland, beginning at my house.
40025	1522	2	And behold, it must be done according to the pattern which I have given unto you.
40026	1522	3	And let the first lot on the south be consecrated unto me for the building of a house for the presidency, for the work of the presidency, in obtaining revelations; and for the work of the ministry of the presidency, in all things pertaining to the church and kingdom.
40027	1522	4	Verily I say unto you, that it shall be built fifty-five by sixty-five feet in the width thereof and in the length thereof, in the inner court.
40028	1522	5	And there shall be a lower court and a higher court, according to the pattern which shall be given unto you hereafter.
40029	1522	6	And it shall be dedicated unto the Lord from the foundation thereof, according to the order of the priesthood, according to the pattern which shall be given unto you hereafter.
40030	1522	7	And it shall be wholly dedicated unto the Lord for the work of the presidency.
40031	1522	8	And ye shall not suffer any unclean thing to come in unto it; and my glory shall be there, and my presence shall be there.
40032	1522	9	But if there shall come into it any unclean thing, my glory shall not be there; and my presence shall not come into it.
40033	1522	10	And again, verily I say unto you, the second lot on the south shall be dedicated unto me for the building of a house unto me, for the work of the printing of the translation of my scriptures, and all things whatsoever I shall command you.
40034	1522	11	And it shall be fifty-five by sixty-five feet in the width thereof and the length thereof, in the inner court; and there shall be a lower and a higher court.
40035	1522	12	And this house shall be wholly dedicated unto the Lord from the foundation thereof, for the work of the printing, in all things whatsoever I shall command you, to be holy, undefiled, according to the pattern in all things as it shall be given unto you.
40036	1522	13	And on the third lot shall my servant Hyrum Smith receive his inheritance.
40037	1522	14	And on the first and second lots on the north shall my servants Reynolds Cahoon and Jared Carter receive their inheritances--
40038	1522	15	That they may do the work which I have appointed unto them, to be a committee to build mine houses, according to the commandment, which I, the Lord God, have given unto you.
40039	1522	16	These two houses are not to be built until I give unto you a commandment concerning them.
40040	1522	17	And now I give unto you no more at this time. Amen.
40041	1523	1	VERILY, thus saith the Lord unto you whom I love, and whom I love I also chasten that their sins may be forgiven, for with the chastisement I prepare a way for their deliverance in all things out of temptation, and I have loved you--
40042	1523	2	Wherefore, ye must needs be chastened and stand rebuked before my face;
40043	1523	3	For ye have sinned against me a very grievous sin, in that ye have not considered the great commandment in all things, that I have given unto you concerning the building of mine house;
40044	1523	4	For the preparation wherewith I design to prepare mine apostles to prune my vineyard for the last time, that I may bring to pass my strange act, that I may pour out my Spirit upon all flesh--
40045	1523	5	But behold, verily I say unto you, that there are many who have been ordained among you, whom I have called but few of them are chosen.
40046	1523	6	They who are not chosen have sinned a very grievous sin, in that they are walking in darkness at noon-day.
40047	1523	7	And for this cause I gave unto you a commandment that you should call your solemn assembly, that your fastings and your mourning might come up into the ears of the Lord of Sabaoth, which is by interpretation, the creator of the first day, the beginning and the end.
40048	1523	8	Yea, verily I say unto you, I gave unto you a commandment that you should build a house, in the which house I design to endow those whom I have chosen with power from on high;
40049	1523	9	For this is the promise of the Father unto you; therefore I command you to tarry, even as mine apostles at Jerusalem.
40050	1523	10	Nevertheless, my servants sinned a very grievous sin; and contentions arose in the school of the prophets; which was very grievous unto me, saith your Lord; therefore I sent them forth to be chastened.
40051	1523	11	Verily I say unto you, it is my will that you should build a house. If you keep my commandments you shall have power to build it.
40052	1523	12	If you keep not my commandments, the love of the Father shall not continue with you, therefore you shall walk in darkness.
40053	1523	13	Now here is wisdom, and the mind of the Lord--let the house be built, not after the manner of the world, for I give not unto you that ye shall live after the manner of the world;
40054	1523	14	Therefore, let it be built after the manner which I shall show unto three of you, whom ye shall appoint and ordain unto this power.
40055	1523	15	And the size thereof shall be fifty and five feet in width, and let it be sixty-five feet in length, in the inner court thereof.
40056	1523	16	And let the lower part of the inner court be dedicated unto me for your sacrament offering, and for your preaching, and your fasting, and your praying, and the offering up of your most holy desires unto me, saith your Lord.
40057	1523	17	And let the higher part of the inner court be dedicated unto me for the school of mine apostles, saith Son Ahman; or, in other words, Alphus; or, in other words, Omegus; even Jesus Christ your Lord. Amen.
40058	1524	1	BEHOLD, I say unto you, here is wisdom, whereby ye may know how to act concerning this matter, for it is expedient in me that this stake that I have set for the strength of Zion should be made strong.
40059	1524	2	Therefore, let my servant Newel K. Whitney take charge of the place which is named among you, upon which I design to build mine holy house.
40060	1524	3	And again, let it be divided into lots, according to wisdom, for the benefit of those who seek inheritances, as it shall be determined in council among you.
40061	1524	4	Therefore, take heed that ye see to this matter, and that portion that is necessary to benefit mine order, for the purpose of bringing forth my word to the children of men.
40062	1524	5	For behold, verily I say unto you, this is the most expedient in me, that my word should go forth unto the children of men, for the purpose of subduing the hearts of the children of men for your good. Even so. Amen.
40063	1524	6	And again, verily I say unto you, it is wisdom and expedient in me, that my servant John Johnson whose offering I have accepted, and whose prayers I have heard, unto whom I give a promise of eternal life inasmuch as he keepeth my commandments from henceforth--
40064	1524	7	For he is a descendant of Joseph and a partaker of the blessings of the promise made unto his fathers--
40065	1524	8	Verily I say unto you, it is expedient in me that he should become a member of the order, that he may assist in bringing forth my word unto the children of men.
40066	1524	9	Therefore ye shall ordain him unto this blessing, and he shall seek diligently to take away incumbrances that are upon the house named among you, that he may dwell therein. Even so. Amen.
40067	1525	1	VERILY I say unto you my friends, I speak unto you with my voice, even the voice of my Spirit, that I may show unto you my will concerning your brethren in the land of Zion, many of whom are truly humble and are seeking diligently to learn wisdom and to find truth.
40068	1525	2	Verily, verily I say unto you, blessed are such, for they shall obtain; for I, the Lord, show mercy unto all the meek, and upon all whomsoever I will, that I may be justified when I shall bring them unto judgment.
40069	1525	3	Behold, I say unto you, concerning the school in Zion, I, the Lord, am well pleased that there should be a school in Zion, and also with my servant Parley P. Pratt, for he abideth in me.
40070	1525	4	And inasmuch as he continueth to abide in me he shall continue to preside over the school in the land of Zion until I shall give unto him other commandments.
40071	1525	5	And I will bless him with a multiplicity of blessings, in expounding all scriptures and mysteries to the edification of the school, and of the church in Zion.
40072	1525	6	And to the residue of the school, I, the Lord, am willing to show mercy; nevertheless, there are those that must needs be chastened, and their works shall be made known.
40073	1525	7	The ax is laid at the root of the trees; and every tree that bringeth not forth good fruit shall be hewn down and cast into the fire. I, the Lord, have spoken it.
40074	1525	8	Verily I say unto you, all among them who know their hearts are honest, and are broken, and their spirits contrite, and are willing to observe their covenants by sacrifice--yea, every sacrifice which I, the Lord, shall command--they are accepted of me.
40075	1525	9	For I, the Lord, will cause them to bring forth as a very fruitful tree which is planted in a goodly land, by a pure stream, that yieldeth much precious fruit.
40076	1525	10	Verily I say unto you, that it is my will that a house should be built unto me in the land of Zion, like unto the pattern which I have given you.
40077	1525	11	Yea, let it be built speedily, by the tithing of my people.
40078	1525	12	Behold, this is the tithing and the sacrifice which I, the Lord, require at their hands, that there may be a house built unto me for the salvation of Zion--
40079	1525	13	For a place of thanksgiving for all saints, and for a place of instruction for all those who are called to the work of the ministry in all their several callings and offices;
40080	1525	14	That they may be perfected in the understanding of their ministry, in theory, in principle, and in doctrine, in all things pertaining to the kingdom of God on the earth, the keys of which kingdom have been conferred upon you.
40081	1525	15	And inasmuch as my people build a house unto me in the name of the Lord, and do not suffer any unclean thing to come into it, that it be not defiled, my glory shall rest upon it;
40082	1525	16	Yea, and my presence shall be there, for I will come into it, and all the pure in heart that shall come into it shall see God.
40083	1525	17	But if it be defiled I will not come into it, and my glory shall not be there; for I will not come into unholy temples.
40084	1525	18	And, now, behold, if Zion do these things she shall prosper, and spread herself and become very glorious, very great, and very terrible.
40085	1525	19	And the nations of the earth shall honor her, and shall say: Surely Zion is the city of our God, and surely Zion cannot fall, neither be moved out of her place, for God is there, and the hand of the Lord is there;
40086	1525	20	And he hath sworn by the power of his might to be her salvation and her high tower.
40087	1525	21	Therefore, verily, thus saith the Lord, let Zion rejoice, for this is Zion--THE PURE IN HEART; therefore, let Zion rejoice, while all the wicked shall mourn.
40088	1525	22	For behold, and lo, vengeance cometh speedily upon the ungodly as the whirlwind; and who shall escape it?
40089	1525	23	The Lord's scourge shall pass over by night and by day, and the report thereof shall vex all people; yea, it shall not be stayed until the Lord come;
40090	1525	24	For the indignation of the Lord is kindled against their abominations and all their wicked works.
40091	1525	25	Nevertheless, Zion shall escape if she observe to do all things whatsoever I have commanded her.
40092	1525	26	But if she observe not to do whatsoever I have commanded her, I will visit her according to all her works, with sore affliction, with pestilence, with plague, with sword, with vengeance, with devouring fire.
40093	1525	27	Nevertheless, let it be read this once to her ears, that I, the Lord, have accepted of her offering; and if she sin no more none of these things shall come upon her;
40094	1525	28	And I will bless her with blessings, and multiply a multiplicity of blessings upon her, and upon her generations forever and ever, saith the Lord your God. Amen.
40095	1526	1	VERILY I say unto you my friends, fear not, let your hearts be comforted; yea, rejoice evermore, and in everything give thanks;
40096	1526	2	Waiting patiently on the Lord, for your prayers have entered into the ears of the Lord of Sabaoth, and are recorded with this seal and testament--the Lord hath sworn and decreed that they shall be granted.
40097	1526	3	Therefore, he giveth this promise unto you, with an immutable covenant that they shall be fulfilled; and all things wherewith you have been afflicted shall work together for your good, and to my name's glory, saith the Lord.
40098	1526	4	And now, verily I say unto you concerning the laws of the land, it is my will that my people should observe to do all things whatsoever I command them.
40099	1526	5	And that law of the land which is constitutional, supporting that principle of freedom in maintaining rights and privileges, belongs to all mankind, and is justifiable before me.
40100	1526	6	Therefore, I, the Lord, justify you, and your brethren of my church, in befriending that law which is the constitutional law of the land;
40101	1526	7	And as pertaining to law of man, whatsoever is more or less than this, cometh of evil.
40102	1526	8	I, the Lord God, make you free, therefore ye are free indeed; and the law also maketh you free.
40103	1526	9	Nevertheless, when the wicked rule the people mourn.
40104	1526	10	Wherefore, honest men and wise men should be sought for diligently, and good men and wise men ye should observe to uphold; otherwise whatsoever is less than these cometh of evil.
40105	1526	11	And I give unto you a commandment, that ye shall forsake all evil and cleave unto all good, that ye shall live by every word which proceedeth forth out of the mouth of God.
40106	1526	12	For he will give unto the faithful line upon line, precept upon precept; and I will try you and prove you herewith.
40107	1526	13	And whoso layeth down his life in my cause, for my name's sake, shall find it again, even life eternal.
40108	1526	14	Therefore, be not afraid of your enemies, for I have decreed in my heart, saith the Lord, that I will prove you in all things, whether you will abide in my covenant, even unto death, that you may be found worthy.
40109	1526	15	For if ye will not abide in my covenant ye are not worthy of me.
40110	1526	16	Therefore, renounce war and proclaim peace, and seek diligently to turn the hearts of the children to their fathers, and the hearts of the fathers to the children;
40111	1526	17	And again, the hearts of the Jews unto the prophets, and the prophets unto the Jews; lest I come and smite the whole earth with a curse, and all flesh be consumed before me.
40112	1526	18	Let not your hearts be troubled; for in my Father's house are many mansions, and I have prepared a place for you; and where my Father and I am, there ye shall be also.
40113	1526	19	Behold, I, the Lord, am not well pleased with many who are in the church at Kirtland;
40114	1526	20	For they do not forsake their sins, and their wicked ways, the pride of their hearts, and their covetousness, and all their detestable things, and observe the words of wisdom and eternal life which I have given unto them.
40115	1526	21	Verily I say unto you, that I, the Lord, will chasten them and will do whatsoever I list, if they do not repent and observe all things whatsoever I have said unto them.
40116	1526	22	And again I say unto you, if ye observe to do whatsoever I command you, I, the Lord, will turn away all wrath and indignation from you, and the gates of hell shall not prevail against you.
40117	1526	23	Now, I speak unto you concerning your families--if men will smite you, or your families, once, and ye bear it patiently and revile not against them, neither seek revenge, ye shall be rewarded;
40118	1526	24	But if ye bear it not patiently, it shall be accounted unto you as being meted out as a just measure unto you.
40119	1526	25	And again, if your enemy shall smite you the second time, and you revile not against your enemy, and bear it patiently, your reward shall be an hundred fold.
40120	1526	26	And again, if he shall smite you the third time, and ye bear it patiently, your reward shall be doubled unto you four-fold;
40121	1526	27	And these three testimonies shall stand against your enemy if he repent not, and shall not be blotted out.
40122	1526	28	And now, verily I say unto you, if that enemy shall escape my vengeance, that he be not brought into judgment before me, then ye shall see to it that ye warn him in my name, that he come no more upon you, neither upon your family, even your children's children unto the third and fourth generation.
40123	1526	29	And then, if he shall come upon you or your children, or your children's children unto the third and fourth generation, I have delivered thine enemy into thine hands;
40124	1526	30	And then if thou wilt spare him, thou shalt be rewarded for thy righteousness; and also thy children and thy children's children unto the third and fourth generation.
40125	1526	31	Nevertheless, thine enemy is in thine hands; and if thou rewardest him according to his works thou art justified; if he has sought thy life, and thy life is endangered by him, thine enemy is in thine hands and thou art justified.
40126	1526	32	Behold, this is the law I gave unto my servant Nephi, and thy fathers, Joseph, and Jacob, and Isaac, and Abraham, and all mine ancient prophets and apostles.
40127	1526	33	And again, this is the law that I gave unto mine ancients, that they should not go out unto battle against any nation, kindred, tongue, or people, save I, the Lord, commanded them.
40128	1526	34	And if any nation, tongue, or people should proclaim war against them, they should first lift a standard of peace unto that people, nation, or tongue;
40129	1526	35	And if that people did not accept the offering of peace, neither the second nor the third time, they should bring these testimonies before the Lord;
40130	1526	36	Then I, the Lord, would give unto them a commandment, and justify them in going out to battle against that nation, tongue, or people.
40131	1526	37	And I, the Lord, would fight their battles, and their children's battles, and their children's children's, until they had avenged themselves on all their enemies, to the third and fourth generation.
40132	1526	38	Behold, this is an ensample unto all people, saith the Lord your God, for justification before me.
40133	1526	39	And again, verily I say unto you, if after thine enemy has come upon thee the first time, he repent and come unto thee praying thy forgiveness, thou shalt forgive him, and shalt hold it no more as a testimony against thine enemy--
40134	1526	40	And so on unto the second and third time; and as oft as thine enemy repenteth of the trespass wherewith he has trespassed against thee, thou shalt forgive him, until seventy times seven.
40135	1526	41	And if he trespass against thee and repent not the first time, nevertheless thou shalt forgive him.
40136	1526	42	And if he trespass against thee the second time, and repent not, nevertheless thou shalt forgive him.
40137	1526	43	And if he trespass against thee the third time, and repent not, thou shalt also forgive him.
40138	1526	44	But if he trespass against thee the fourth time thou shalt not forgive him, but shalt bring these testimonies before the Lord; and they shall not be blotted out until he repent and reward thee four-fold in all things wherewith he has trespassed against thee.
40139	1526	45	And if he do this, thou shalt forgive him with all thine heart; and if he do not this, I, the Lord, will avenge thee of thine enemy an hundred-fold;
40140	1526	46	And upon his children, and upon his children's children of all them that hate me, unto the third and fourth generation.
40141	1526	47	But if the children shall repent, or the children's children, and turn to the Lord their God, with all their hearts and with all their might, mind, and strength, and restore four-fold for all their trespasses wherewith they have trespassed, or wherewith their fathers have trespassed, or their fathers' fathers, then thine indignation shall be turned away;
40142	1526	48	And vengeance shall no more come upon them, saith the Lord thy God, and their trespasses shall never be brought any more as a testimony before the Lord against them. Amen.
40143	1527	1	BEHOLD, thus saith the Lord unto my servant John Murdock--thou art called to go into the eastern countries from house to house, from village to village, and from city to city, to proclaim mine everlasting gospel unto the inhabitants thereof, in the midst of persecution and wickedness.
40144	1527	2	And who receiveth you receiveth me; and you shall have power to declare my word in the demonstration of my Holy Spirit.
40145	1527	3	And who receiveth you as a little child, receiveth my kingdom; and blessed are they, for they shall obtain mercy.
40146	1527	4	And whoso rejecteth you shall be rejected of my Father and his house; and you shall cleanse your feet in the secret places by the way for a testimony against them.
40147	1527	5	And behold, and lo, I come quickly to judgment, to convince all of their ungodly deeds which they have committed against me, as it is written of me in the volume of the book.
40148	1527	6	And now, verily I say unto you, that it is not expedient that you should go until your children are provided for, and sent up kindly unto the bishop of Zion.
40149	1527	7	And after a few years, if thou desirest of me, thou mayest go up also unto the goodly land, to possess thine inheritance;
40150	1527	8	Otherwise thou shalt continue proclaiming my gospel until thou be taken. Amen.
40151	1528	1	VERILY, thus saith the Lord unto you, my friends Sidney and Joseph, your families are well; they are in mine hands, and I will do with them as seemeth me good; for in me there is all power.
40152	1528	2	Therefore, follow me, and listen to the counsel which I shall give unto you.
40153	1528	3	Behold, and lo, I have much people in this place, in the regions round about; and an effectual door shall be opened in the regions round about in this eastern land.
40154	1528	4	Therefore, I, the Lord, have suffered you to come unto this place; for thus it was expedient in me for the salvation of souls.
40155	1528	5	Therefore, verily I say unto you, lift up your voices unto this people; speak the thoughts that I shall put into your hearts, and you shall not be confounded before men;
40156	1528	6	For it shall be given you in the very hour, yea, in the very moment, what ye shall say.
40157	1528	7	But a commandment I give unto you, that ye shall declare whatsoever thing ye declare in my name, in solemnity of heart, in the spirit of meekness, in all things.
40158	1528	8	And I give unto you this promise, that inasmuch as ye do this the Holy Ghost shall be shed forth in bearing record unto all things whatsoever ye shall say.
40159	1528	9	And it is expedient in me that you, my servant Sidney, should be a spokesman unto this people; yea, verily, I will ordain you unto this calling, even to be a spokesman unto my servant Joseph.
40160	1528	10	And I will give unto him power to be mighty in testimony.
40161	1528	11	And I will give unto thee power to be mighty in expounding all scriptures, that thou mayest be a spokesman unto him, and he shall be a revelator unto thee, that thou mayest know the certainty of all things pertaining to the things of my kingdom on the earth.
40162	1528	12	Therefore, continue your journey and let your hearts rejoice; for behold, and lo, I am with you even unto the end.
40163	1528	13	And now I give unto you a word concerning Zion. Zion shall be redeemed, although she is chastened for a little season.
40164	1528	14	Thy brethren, my servants Orson Hyde and John Gould, are in my hands; and inasmuch as they keep my commandments they shall be saved.
40165	1528	15	Therefore, let your hearts be comforted; for all things shall work together for good to them that walk uprightly, and to the sanctification of the church.
40166	1528	16	For I will raise up unto myself a pure people, that will serve me in righteousness;
40167	1528	17	And all that call upon the name of the Lord, and keep his commandments, shall be saved. Even so. Amen.
40168	1529	1	VERILY I say unto you, concerning your brethren who have been afflicted, and persecuted, and cast out from the land of their inheritance--
40169	1529	2	I, the Lord, have suffered the affliction to come upon them, wherewith they have been afflicted, in consequence of their transgressions;
40170	1529	3	Yet I will own them, and they shall be mine in that day when I shall come to make up my jewels.
40171	1529	4	Therefore, they must needs be chastened and tried, even as Abraham, who was commanded to offer up his only son.
40172	1529	5	For all those who will not endure chastening, but deny me, cannot be sanctified.
40173	1529	6	Behold, I say unto you, there were jarrings, and contentions, and envyings, and strifes, and lustful and covetous desires among them; therefore by these things they polluted their inheritances.
40174	1529	7	They were slow to hearken unto the voice of the Lord their God; therefore, the Lord their God is slow to hearken unto their prayers, to answer them in the day of their trouble.
40175	1529	8	In the day of their peace they esteemed lightly my counsel; but, in the day of their trouble, of necessity they feel after me.
40176	1529	9	Verily I say unto you, notwithstanding their sins, my bowels are filled with compassion towards them. I will not utterly cast them off; and in the day of wrath I will remember mercy.
40177	1529	10	I have sworn, and the decree hath gone forth by a former commandment which I have given unto you, that I would let fall the sword of mine indignation in behalf of my people; and even as I have said, it shall come to pass.
40178	1529	11	Mine indignation is soon to be poured out without measure upon all nations; and this will I do when the cup of their iniquity is full.
40179	1529	12	And in that day all who are found upon the watch-tower, or in other words, all mine Israel, shall be saved.
40180	1529	13	And they that have been scattered shall be gathered.
40181	1529	14	And all they who have mourned shall be comforted.
40182	1529	15	And all they who have given their lives for my name shall be crowned.
40183	1529	16	Therefore, let your hearts be comforted concerning Zion; for all flesh is in mine hands; be still and know that I am God.
40184	1529	17	Zion shall not be moved out of her place, notwithstanding her children are scattered.
40185	1529	18	They that remain, and are pure in heart, shall return, and come to their inheritances, they and their children, with songs of everlasting joy, to build up the waste places of Zion--
40186	1529	19	And all these things that the prophets might be fulfilled.
40187	1529	20	And, behold, there is none other place appointed than that which I have appointed; neither shall there be any other place appointed than that which I have appointed, for the work of the gathering of my saints--
40188	1529	21	Until the day cometh when there is found no more room for them; and then I have other places which I will appoint unto them, and they shall be called stakes, for the curtains or the strength of Zion.
40189	1529	22	Behold, it is my will, that all they who call on my name, and worship me according to mine everlasting gospel, should gather together, and stand in holy places;
40190	1529	23	And prepare for the revelation which is to come, when the veil of the covering of my temple, in my tabernacle, which hideth the earth, shall be taken off, and all flesh shall see me together.
40191	1529	24	And every corruptible thing, both of man, or of the beasts of the field, or of the fowls of the heavens, or of the fish of the sea, that dwells upon all the face of the earth, shall be consumed;
40192	1529	25	And also that of element shall melt with fervent heat; and all things shall become new, that my knowledge and glory may dwell upon all the earth.
40193	1529	26	And in that day the enmity of man, and the enmity of beasts, yea, the enmity of all flesh, shall cease from before my face.
40194	1529	27	And in that day whatsoever any man shall ask, it shall be given unto him.
40195	1529	28	And in that day Satan shall not have power to tempt any man.
40196	1529	29	And there shall be no sorrow because there is no death.
40197	1529	30	In that day an infant shall not die until he is old; and his life shall be as the age of a tree;
40198	1529	31	And when he dies he shall not sleep, that is to say in the earth, but shall be changed in the twinkling of an eye, and shall be caught up, and his rest shall be glorious.
40199	1529	32	Yea, verily I say unto you, in that day when the Lord shall come, he shall reveal all things--
40200	1529	33	Things which have passed, and hidden things which no man knew, things of the earth, by which it was made, and the purpose and the end thereof--
40201	1529	34	Things most precious, things that are above, and things that are beneath, things that are in the earth, and upon the earth, and in heaven.
40202	1529	35	And all they who suffer persecution for my name, and endure in faith, though they are called to lay down their lives for my sake yet shall they partake of all this glory.
40203	1529	36	Wherefore, fear not even unto death; for in this world your joy is not full, but in me your joy is full.
40204	1529	37	Therefore, care not for the body, neither the life of the body; but care for the soul, and for the life of the soul.
40205	1529	38	And seek the face of the Lord always, that in patience ye may possess your souls, and ye shall have eternal life.
40206	1529	39	When men are called unto mine everlasting gospel, and covenant with an everlasting covenant, they are accounted as the salt of the earth and the savor of men;
40207	1529	40	They are called to be the savor of men; therefore, if that salt of the earth lose its savor, behold, it is thenceforth good for nothing only to be cast out and trodden under the feet of men.
40208	1529	41	Behold, here is wisdom concerning the children of Zion, even many, but not all; they were found transgressors, therefore they must needs be chastened--
40209	1529	42	He that exalteth himself shall be abased, and he that abaseth himself shall be exalted.
40210	1529	43	And now, I will show unto you a parable, that you may know my will concerning the redemption of Zion.
40211	1529	44	A certain nobleman had a spot of land, very choice; and he said unto his servants: Go ye unto my vineyard, even upon this very choice piece of land, and plant twelve olive-trees;
40212	1529	45	And set watchmen round about them, and build a tower, that one may overlook the land round about, to be a watchman upon the tower, that mine olive-trees may not be broken down when the enemy shall come to spoil and take upon themselves the fruit of my vineyard.
40213	1529	46	Now, the servants of the nobleman went and did as their lord commanded them, and planted the olive-trees, and built a hedge round about, and set watchmen, and began to build a tower.
40214	1529	47	And while they were yet laying the foundation thereof, they began to say among themselves: And what need hath my lord of this tower?
40215	1529	48	And consulted for a long time, saying among themselves: What need hath my lord of this tower, seeing this is a time of peace?
40216	1529	49	Might not this money be given to the exchangers? For there is no need of these things.
40217	1529	50	And while they were at variance one with another they became very slothful, and they hearkened not unto the commandments of their lord.
40218	1529	51	And the enemy came by night, and broke down the hedge; and the servants of the nobleman arose and were affrighted, and fled; and the enemy destroyed their works, and broke down the olive-trees.
40219	1529	52	Now, behold, the nobleman, the lord of the vineyard, called upon his servants, and said unto them, Why! what is the cause of this great evil?
40220	1529	53	Ought ye not to have done even as I commanded you, and--after ye had planted the vineyard, and built the hedge round about, and set watchmen upon the walls thereof--built the tower also, and set a watchman upon the tower, and watched for my vineyard, and not have fallen asleep, lest the enemy should come upon you?
40221	1529	54	And behold, the watchman upon the tower would have seen the enemy while he was yet afar off; and then ye could have made ready and kept the enemy from breaking down the hedge thereof, and saved my vineyard from the hands of the destroyer.
40222	1529	55	And the lord of the vineyard said unto one of his servants: Go and gather together the residue of my servants, and take all the strength of mine house, which are my warriors, my young men, and they that are of middle age also among all my servants, who are the strength of mine house, save those only whom I have appointed to tarry;
40223	1529	56	And go ye straightway unto the land of my vineyard, and redeem my vineyard; for it is mine; I have bought it with money.
40224	1529	57	Therefore, get ye straightway unto my land; break down the walls of mine enemies; throw down their tower, and scatter their watchmen.
40225	1529	58	And inasmuch as they gather together against you, avenge me of mine enemies, that by and by I may come with the residue of mine house and possess the land.
40226	1529	59	And the servant said unto his lord: When shall these things be?
40227	1529	60	And he said unto his servant: When I will; go ye straightway, and do all things whatsoever I have commanded you;
40228	1529	61	And this shall be my seal and blessing upon you--a faithful and wise steward in the midst of mine house, a ruler in my kingdom.
40229	1529	62	And his servant went straightway, and did all things whatsoever his lord commanded him; and after many days all things were fulfilled.
40230	1529	63	Again, verily I say unto you, I will show unto you wisdom in me concerning all the churches, inasmuch as they are willing to be guided in a right and proper way for their salvation--
40231	1529	64	That the work of the gathering together of my saints may continue, that I may build them up unto my name upon holy places; for the time of harvest is come, and my word must needs be fulfilled.
40232	1529	65	Therefore, I must gather together my people, according to the parable of the wheat and the tares, that the wheat may be secured in the garners to possess eternal life, and be crowned with celestial glory, when I shall come in the kingdom of my Father to reward every man according as his work shall be;
40233	1529	66	While the tares shall be bound in bundles, and their bands made strong, that they may be burned with unquenchable fire.
40234	1529	67	Therefore, a commandment I give unto all the churches, that they shall continue to gather together unto the places which I have appointed.
40235	1529	68	Nevertheless, as I have said unto you in a former commandment, let not your gathering be in haste, nor by flight; but let all things be prepared before you.
40236	1529	69	And in order that all things be prepared before you, observe the commandment which I have given concerning these things--
40237	1529	70	Which saith, or teacheth, to purchase all the lands with money, which can be purchased for money, in the region round about the land which I have appointed to be the land of Zion, for the beginning of the gathering of my saints;
40238	1529	71	All the land which can be purchased in Jackson county, and the counties round about, and leave the residue in mine hand.
40239	1529	72	Now, verily I say unto you, let all the churches gather together all their moneys; let these things be done in their time, but not in haste; and observe to have all things prepared before you.
40240	1529	73	And let honorable men be appointed, even wise men, and send them to purchase these lands.
40241	1529	74	And the churches in the eastern countries, when they are built up, if they will hearken unto this counsel they may buy lands and gather together upon them; and in this way they may establish Zion.
40242	1529	75	There is even now already in store sufficient, yea, even an abundance, to redeem Zion, and establish her waste places, no more to be thrown down, were the churches, who call themselves after my name, willing to hearken to my voice.
40243	1529	76	And again I say unto you, those who have been scattered by their enemies, it is my will that they should continue to importune for redress, and redemption, by the hands of those who are placed as rulers and are in authority over you--
40244	1529	77	According to the laws and constitution of the people, which I have suffered to be established, and should be maintained for the rights and protection of all flesh, according to just and holy principles;
40245	1529	78	That every man may act in doctrine and principle pertaining to futurity, according to the moral agency which I have given unto him, that every man may be accountable for his own sins in the day of judgment.
40246	1529	79	Therefore, it is not right that any man should be in bondage one to another.
40247	1529	80	And for this purpose have I established the Constitution of this land, by the hands of wise men whom I raised up unto this very purpose, and redeemed the land by the shedding of blood.
40248	1529	81	Now, unto what shall I liken the children of Zion? I will liken them unto the parable of the woman and the unjust judge, for men ought always to pray and not to faint, which saith--
40249	1529	82	There was in a city a judge which feared not God, neither regarded man.
40250	1529	83	And there was a widow in that city, and she came unto him, saying: Avenge me of mine adversary.
40251	1529	84	And he would not for a while, but afterward he said within himself: Though I fear not God, nor regard man, yet because this widow troubleth me I will avenge her, lest by her continual coming she weary me.
40252	1529	85	Thus will I liken the children of Zion.
40253	1529	86	Let them importune at the feet of the judge;
40254	1529	87	And if he heed them not, let them importune at the feet of the governor;
40255	1529	88	And if the governor heed them not, let them importune at the feet of the president;
40256	1529	89	And if the president heed them not, then will the Lord arise and come forth out of his hiding place, and in his fury vex the nation;
40257	1529	90	And in his hot displeasure, and in his fierce anger, in his time, will cut off those wicked, unfaithful, and unjust stewards, and appoint them their portion among hypocrites, and unbelievers;
40258	1529	91	Even in outer darkness, where there is weeping, and wailing, and gnashing of teeth.
40259	1529	92	Pray ye, therefore, that their ears may be opened unto your cries, that I may be merciful unto them, that these things may not come upon them.
40260	1529	93	What I have said unto you must needs be, that all men may be left without excuse;
40261	1529	94	That wise men and rulers may hear and know that which they have never considered;
40262	1529	95	That I may proceed to bring to pass my act, my strange act, and perform my work, my strange work, that men may discern between the righteous and the wicked, saith your God.
40263	1529	96	And again, I say unto you, it is contrary to my commandment and my will that my servant Sidney Gilbert should sell my storehouse, which I have appointed unto my people, into the hands of mine enemies.
40264	1529	97	Let not that which I have appointed be polluted by mine enemies, by the consent of those who call themselves after my name;
40265	1529	98	For this is a very sore and grievous sin against me, and against my people, in consequence of those things which I have decreed and which are soon to befall the nations.
40266	1529	99	Therefore, it is my will that my people should claim, and hold claim upon that which I have appointed unto them, though they should not be permitted to dwell thereon.
40267	1529	100	Nevertheless, I do not say they shall not dwell thereon; for inasmuch as they bring forth fruit and works meet for my kingdom they shall dwell thereon.
40268	1529	101	They shall build, and another shall not inherit it; they shall plant vineyards, and they shall eat the fruit thereof. Even so. Amen.
40269	1530	1	THIS day a general council of twenty-four high priests assembled at the house of Joseph Smith, Jun., by revelation, and proceeded to organize the high council of the church of Christ, which was to consist of twelve high priests, and one or three presidents as the case might require.
40270	1530	2	The high council was appointed by revelation for the purpose of settling important difficulties which might arise in the church, which could not be settled by the church or the bishop's council to the satisfaction of the parties.
40271	1530	3	Joseph Smith, Jun., Sidney Rigdon and Frederick G. Williams were acknowledged presidents by the voice of the council; and Joseph Smith, Sen., John Smith, Joseph Coe, John Johnson, Martin Harris, John S. Carter, Jared Carter, Oliver Cowdery, Samuel H. Smith, Orson Hyde, Sylvester Smith, and Luke Johnson, high priests, were chosen to be a standing council for the church, by the unanimous voice of the council.
40272	1530	4	The above-named councilors were then asked whether they accepted their appointments, and whether they would act in that office according to the law of heaven, to which they all answered that they accepted their appointments, and would fill their offices according to the grace of God bestowed upon them.
40273	1530	5	The number composing the council, who voted in the name and for the church in appointing the above-named councilors were forty-three, as follows: nine high priests, seventeen elders, four priests, and thirteen members.
40274	1530	6	Voted: that the high council cannot have power to act without seven of the above-named councilors, or their regularly appointed successors are present.
40275	1530	7	These seven shall have power to appoint other high priests, whom they may consider worthy and capable to act in the place of absent councilors.
40276	1530	8	Voted: that whenever any vacancy shall occur by the death, removal from office for transgression, or removal from the bounds of this church government, of any one of the above-named councilors, it shall be filled by the nomination of the president or presidents, and sanctioned by the voice of a general council of high priests, convened for that purpose, to act in the name of the church.
40277	1530	9	The president of the church, who is also the president of the council, is appointed by revelation, and acknowledged in his administration by the voice of the church.
40278	1530	10	And it is according to the dignity of his office that he should preside over the council of the church; and it is his privilege to be assisted by two other presidents, appointed after the same manner that he himself was appointed.
40279	1530	11	And in case of the absence of one or both of those who are appointed to assist him, he has power to preside over the council without an assistant; and in case he himself is absent, the other presidents have power to preside in his stead, both or either of them.
40280	1530	12	Whenever a high council of the church of Christ is regularly organized, according to the foregoing pattern, it shall be the duty of the twelve councilors to cast lots by numbers, and thereby ascertain who of the twelve shall speak first, commencing with number one and so in succession to number twelve.
40281	1530	13	Whenever this council convenes to act upon any case, the twelve councilors shall consider whether it is a difficult one or not; if it is not, two only of the councilors shall speak upon it, according to the form above written.
40282	1530	14	But if it is thought to be difficult, four shall be appointed; and if more difficult, six; but in no case shall more than six be appointed to speak.
40283	1530	15	The accused, in all cases, has a right to one-half of the council, to prevent insult or injustice.
40284	1530	16	And the councilors appointed to speak before the council are to present the case, after the evidence is examined, in its true light before the council; and every man is to speak according to equity and justice.
40285	1530	17	Those councilors who draw even numbers, that is, 2, 4, 6, 8, 10, and 12, are the individuals who are to stand up in behalf of the accused, and prevent insult and injustice.
40286	1530	18	In all cases the accuser and the accused shall have a privilege of speaking for themselves before the council, after the evidences are heard and the councilors who are appointed to speak on the case have finished their remarks.
40287	1530	19	After the evidences are heard, the councilors, accuser and accused have spoken, the president shall give a decision according to the understanding which he shall have of the case, and call upon the twelve councilors to sanction the same by their vote.
40288	1530	20	But should the remaining councilors, who have not spoken, or any one of them, after hearing the evidences and pleadings impartially, discover an error in the decision of the president, they can manifest it, and the case shall have a re-hearing.
40289	1530	21	And if, after a careful re-hearing, any additional light is shown upon the case, the decision shall be altered accordingly.
40290	1530	22	But in case no additional light is given, the first decision shall stand, the majority of the council having power to determine the same.
40291	1530	23	In case of difficulty respecting doctrine or principle, if there is not a sufficiency written to make the case clear to the minds of the council, the president may inquire and obtain the mind of the Lord by revelation.
40292	1530	24	The high priests, when abroad, have power to call and organize a council after the manner of the foregoing, to settle difficulties, when the parties or either of them shall request it.
40293	1530	25	And the said council of high priests shall have power to appoint one of their own number to preside over such council for the time being.
40294	1530	26	It shall be the duty of said council to transmit, immediately, a copy of their proceedings, with a full statement of the testimony accompanying their decision, to the high council of the seat of the First Presidency of the Church.
40295	1530	27	Should the parties or either of them be dissatisfied with the decision of said council, they may appeal to the high council of the seat of the First Presidency of the Church, and have a re-hearing, which case shall there be conducted, according to the former pattern written, as though no such decision had been made.
40296	1530	28	This council of high priests abroad is only to be called on the most difficult cases of church matters; and no common or ordinary case is to be sufficient to call such council.
40297	1530	29	The traveling or located high priests abroad have power to say whether it is necessary to call such a council or not.
40298	1530	30	There is a distinction between the high council or traveling high priests abroad, and the traveling high council composed of the twelve apostles, in their decisions.
40299	1530	31	From the decision of the former there can be an appeal; but from the decision of the latter there cannot.
40300	1530	32	The latter can only be called in question by the general authorities of the church in case of transgression.
40301	1530	33	Resolved: that the president or presidents of the seat of the First Presidency of the Church shall have power to determine whether any such case, as may be appealed, is justly entitled to a re-hearing, after examining the appeal and the evidences and statements accompanying it.
40302	1530	34	The twelve councilors then proceeded to cast lots or ballot, to ascertain who should speak first, and the following was the result, namely: 1, Oliver Cowdery; 2, Joseph Coe; 3, Samuel H. Smith; 4, Luke Johnson; 5, John S. Carter; 6, Sylvester Smith; 7, John Johnson; 8, Orson Hyde; 9, Jared Carter; 10, Joseph Smith, Sen.; 11, John Smith; 12, Martin Harris.
40303	1531	1	VERILY I say unto you, my friends, behold, I will give unto you a revelation and commandment, that you may know how to act in the discharge of your duties concerning the salvation and redemption of your brethren, who have been scattered on the land of Zion;
40304	1531	2	Being driven and smitten by the hands of mine enemies, on whom I will pour out my wrath without measure in mine own time.
40305	1531	3	For I have suffered them thus far, that they might fill up the measure of their iniquities, that their cup might be full;
40306	1531	4	And that those who call themselves after my name might be chastened for a little season with a sore and grievous chastisement, because they did not hearken altogether unto the precepts and commandments which I gave unto them.
40307	1531	5	But verily I say unto you, that I have decreed a decree which my people shall realize, inasmuch as they hearken from this very hour unto the counsel which I, the Lord their God, shall give unto them.
40308	1531	6	Behold they shall, for I have decreed it, begin to prevail against mine enemies from this very hour.
40309	1531	7	And by hearkening to observe all the words which I, the Lord their God, shall speak unto them, they shall never cease to prevail until the kingdoms of the world are subdued under my feet, and the earth is given unto the saints, to possess it forever and ever.
40310	1531	8	But inasmuch as they keep not my commandments, and hearken not to observe all my words, the kingdoms of the world shall prevail against them.
40311	1531	9	For they were set to be a light unto the world, and to be the saviors of men;
40312	1531	10	And inasmuch as they are not the saviors of men, they are as salt that has lost its savor, and is thenceforth good for nothing but to be cast out and trodden under foot of men.
40313	1531	11	But verily I say unto you, I have decreed that your brethren which have been scattered shall return to the lands of their inheritances, and shall build up the waste places of Zion.
40314	1531	12	For after much tribulation, as I have said unto you in a former commandment, cometh the blessing.
40315	1531	13	Behold, this is the blessing which I have promised after your tribulations, and the tribulations of your brethren--your redemption, and the redemption of your brethren, even their restoration to the land of Zion, to be established, no more to be thrown down.
40316	1531	14	Nevertheless, if they pollute their inheritances they shall be thrown down; for I will not spare them if they pollute their inheritances.
40317	1531	15	Behold, I say unto you, the redemption of Zion must needs come by power;
40318	1531	16	Therefore, I will raise up unto my people a man, who shall lead them like as Moses led the children of Israel.
40319	1531	17	For ye are the children of Israel, and of the seed of Abraham, and ye must needs be led out of bondage by power, and with a stretched-out arm.
40320	1531	18	And as your fathers were led at the first, even so shall the redemption of Zion be.
40321	1531	19	Therefore, let not your hearts faint, for I say not unto you as I said unto your fathers: Mine angel shall go up before you, but not my presence.
40322	1531	20	But I say unto you: Mine angels shall go up before you, and also my presence, and in time ye shall possess the goodly land.
40323	1531	21	Verily, verily I say unto you, that my servant Joseph Smith, Jun. is the man to whom I likened the servant to whom the Lord of the vineyard spake in the parable which I have given unto you.
40324	1531	22	Therefore let my servant Joseph Smith, Jun. say unto the strength of my house, my young men and the middle aged--Gather yourselves together unto the land of Zion, upon the land which I have bought with money that has been consecrated unto me.
40325	1531	23	And let all the churches send up wise men with their moneys, and purchase lands even as I have commanded them.
40326	1531	24	And inasmuch as mine enemies come against you to drive you from my goodly land, which I have consecrated to be the land of Zion, even from your own lands after these testimonies, which ye have brought before me against them, ye shall curse them;
40327	1531	25	And whomsoever ye curse, I will curse, and ye shall avenge me of mine enemies.
40328	1531	26	And my presence shall be with you even in avenging me of mine enemies, unto the third and fourth generation of them that hate me.
40329	1531	27	Let no man be afraid to lay down his life for my sake; for whoso layeth down his life for my sake shall find it again.
40330	1531	28	And whoso is not willing to lay down his life for my sake is not my disciple.
40331	1531	29	It is my will that my servant Sidney Rigdon shall lift up his voice in the congregations in the eastern countries, in preparing the churches to keep the commandments which I have given unto them concerning the restoration and redemption of Zion.
40332	1531	30	It is my will that my servant Parley P. Pratt and my servant Lyman Wight should not return to the land of their brethren, until they have obtained companies to go up unto the land of Zion, by tens, or by twenties, or by fifties, or by an hundred, until they have obtained to the number of five hundred of the strength of my house.
40333	1531	31	Behold this is my will; ask and ye shall receive; but men do not always do my will.
40334	1531	32	Therefore, if you cannot obtain five hundred, seek diligently that peradventure you may obtain three hundred.
40335	1531	33	And if ye cannot obtain three hundred, seek diligently that peradventure ye may obtain one hundred.
40336	1531	34	But verily I say unto you, a commandment I give unto you, that ye shall not go up unto the land of Zion until you have obtained a hundred of the strength of my house, to go up with you unto the land of Zion.
40337	1531	35	Therefore, as I said unto you, ask and ye shall receive; pray earnestly that peradventure my servant Joseph Smith, Jun., may go with you, and preside in the midst of my people, and organize my kingdom upon the consecrated land, and establish the children of Zion upon the laws and commandments which have been and which shall be given unto you.
40338	1531	36	All victory and glory is brought to pass unto you through your diligence, faithfulness, and prayers of faith.
40339	1531	37	Let my servant Parley P. Pratt journey with my servant Joseph Smith, Jun.
40340	1531	38	Let my servant Lyman Wight journey with my servant Sidney Rigdon.
40341	1531	39	Let my servant Hyrum Smith journey with my servant Frederick G. Williams.
40342	1531	40	Let my servant Orson Hyde journey with my servant Orson Pratt, whithersoever my servant Joseph Smith, Jun., shall counsel them, in obtaining the fulfilment of these commandments which I have given unto you, and leave the residue in my hands. Even so. Amen.
40343	1532	1	VERILY I say unto you, my friends, I give unto you counsel, and a commandment, concerning all the properties which belong to the order which I commanded to be organized and established, to be a united order, and an everlasting order for the benefit of my church, and for the salvation of men until I come--
40344	1532	2	With promise immutable and unchangeable, that inasmuch as those whom I commanded were faithful they should be blessed with a multiplicity of blessings;
40345	1532	3	But inasmuch as they were not faithful they were nigh unto cursing.
40346	1532	4	Therefore, inasmuch as some of my servants have not kept the commandment, but have broken the covenant through covetousness, and with feigned words, I have cursed them with a very sore and grievous curse.
40347	1532	5	For I, the Lord, have decreed in my heart, that inasmuch as any man belonging to the order shall be found a transgressor, or, in other words, shall break the covenant with which ye are bound, he shall be cursed in his life, and shall be trodden down by whom I will;
40348	1532	6	For I, the Lord, am not to be mocked in these things--
40349	1532	7	And all this that the innocent among you may not be condemned with the unjust; and that the guilty among you may not escape; because I, the Lord, have promised unto you a crown of glory at my right hand.
40350	1532	8	Therefore, inasmuch as you are found transgressors, you cannot escape my wrath in your lives.
40351	1532	9	Inasmuch as ye are cut off for transgression, ye cannot escape the buffetings of Satan until the day of redemption.
40352	1532	10	And I now give unto you power from this very hour, that if any man among you, of the order, is found a transgressor and repenteth not of the evil, that ye shall deliver him over unto the buffetings of Satan; and he shall not have power to bring evil upon you.
40353	1532	11	It is wisdom in me; therefore, a commandment I give unto you, that ye shall organize yourselves and appoint every man his stewardship;
40354	1532	12	That every man may give an account unto me of the stewardship which is appointed unto him.
40355	1532	13	For it is expedient that I, the Lord, should make every man accountable, as a steward over earthly blessings, which I have made and prepared for my creatures.
40356	1532	14	I, the Lord, stretched out the heavens, and built the earth, my very handiwork; and all things therein are mine.
40357	1532	15	And it is my purpose to provide for my saints, for all things are mine.
40358	1532	16	But it must needs be done in mine own way; and behold this is the way that I, the Lord, have decreed to provide for my saints, that the poor shall be exalted, in that the rich are made low.
40359	1532	17	For the earth is full, and there is enough and to spare; yea, I prepared all things, and have given unto the children of men to be agents unto themselves.
40360	1532	18	Therefore, if any man shall take of the abundance which I have made, and impart not his portion, according to the law of my gospel, unto the poor and the needy, he shall, with the wicked, lift up his eyes in hell, being in torment.
40361	1532	19	And now, verily I say unto you, concerning the properties of the order--
40362	1532	20	Let my servant Sidney Rigdon have appointed unto him the place where he now resides, and the lot of the tannery for his stewardship, for his support while he is laboring in my vineyard, even as I will, when I shall command him.
40363	1532	21	And let all things be done according to the counsel of the order, and united consent or voice of the order, which dwell in the land of Kirtland.
40364	1532	22	And this stewardship and blessing, I, the Lord, confer upon my servant Sidney Rigdon for a blessing upon him, and his seed after him;
40365	1532	23	And I will multiply blessings upon him, inasmuch as he will be humble before me.
40366	1532	24	And again, let my servant Martin Harris have appointed unto him, for his stewardship, the lot of land which my servant John Johnson obtained in exchange for his former inheritance, for him and his seed after him;
40367	1532	25	And inasmuch as he is faithful, I will multiply blessings upon him and his seed after him.
40368	1532	26	And let my servant Martin Harris devote his moneys for the proclaiming of my words, according as my servant Joseph Smith, Jun., shall direct.
40369	1532	27	And again, let my servant Frederick G. Williams have the place upon which he now dwells.
40370	1532	28	And let my servant Oliver Cowdery have the lot which is set off joining the house, which is to be for the printing office, which is lot number one, and also the lot upon which his father resides.
40371	1532	29	And let my servants Frederick G. Williams and Oliver Cowdery have the printing office and all things that pertain unto it.
40372	1532	30	And this shall be their stewardship which shall be appointed unto them.
40373	1532	31	And inasmuch as they are faithful, behold I will bless, and multiply blessings upon them.
40374	1532	32	And this is the beginning of the stewardship which I have appointed them, for them and their seed after them.
40375	1532	33	And, inasmuch as they are faithful, I will multiply blessings upon them and their seed after them, even a multiplicity of blessings.
40376	1532	34	And again, let my servant John Johnson have the house in which he lives, and the inheritance, all save the ground which has been reserved for the building of my houses, which pertains to that inheritance, and those lots which have been named for my servant Oliver Cowdery.
40377	1532	35	And inasmuch as he is faithful, I will multiply blessings upon him.
40378	1532	36	And it is my will that he should sell the lots that are laid off for the building up of the city of my saints, inasmuch as it shall be made known to him by the voice of the Spirit, and according to the counsel of the order, and by the voice of the order.
40379	1532	37	And this is the beginning of the stewardship which I have appointed unto him, for a blessing unto him and his seed after him.
40380	1532	38	And inasmuch as he is faithful, I will multiply a multiplicity of blessings upon him.
40381	1532	39	And again, let my servant Newel K. Whitney have appointed unto him the houses and lot where he now resides, and the lot and building on which the mercantile establishment stands, and also the lot which is on the corner south of the mercantile establishment, and also the lot on which the ashery is situated.
40382	1532	40	And all this I have appointed unto my servant Newel K. Whitney for his stewardship, for a blessing upon him and his seed after him, for the benefit of the mercantile establishment of my order which I have established for my stake in the land of Kirtland.
40383	1532	41	Yea, verily, this is the stewardship which I have appointed unto my servant N. K. Whitney, even this whole mercantile establishment, him and his agent, and his seed after him.
40384	1532	42	And inasmuch as he is faithful in keeping my commandments, which I have given unto him, I will multiply blessings upon him and his seed after him, even a multiplicity of blessings.
40385	1532	43	And again, let my servant Joseph Smith, Jun., have appointed unto him the lot which is laid off for the building of my house, which is forty rods long and twelve wide, and also the inheritance upon which his father now resides;
40386	1532	44	And this is the beginning of the stewardship which I have appointed unto him, for a blessing upon him, and upon his father.
40387	1532	45	For behold, I have reserved an inheritance for his father, for his support; therefore he shall be reckoned in the house of my servant Joseph Smith, Jun.
40388	1532	46	And I will multiply blessings upon the house of my servant Joseph Smith, Jun., inasmuch as he is faithful, even a multiplicity of blessings.
40389	1532	47	And now, a commandment I give unto you concerning Zion, that you shall no longer be bound as a united order to your brethren of Zion, only on this wise--
40390	1532	48	After you are organized, you shall be called the United Order of the Stake of Zion, the City of Kirtland. And your brethren, after they are organized, shall be called the United Order of the City of Zion.
40391	1532	49	And they shall be organized in their own names, and in their own name; and they shall do their business in their own name, and in their own names;
40392	1532	50	And you shall do your business in your own name, and in your own names.
40393	1532	51	And this I have commanded to be done for your salvation, and also for their salvation, in consequence of their being driven out and that which is to come.
40394	1532	52	The covenants being broken through transgression, by covetousness and feigned words--
40395	1532	53	Therefore, you are dissolved as a united order with your brethren, that you are not bound only up to this hour unto them, only on this wise, as I said, by loan as shall be agreed by this order in council, as your circumstances will admit and the voice of the council direct.
40396	1532	54	And again, a commandment I give unto you concerning your stewardship which I have appointed unto you.
40397	1532	55	Behold, all these properties are mine, or else your faith is vain, and ye are found hypocrites, and the covenants which ye have made unto me are broken;
40398	1532	56	And if the properties are mine, then ye are stewards; otherwise ye are no stewards.
40399	1532	57	But, verily I say unto you, I have appointed unto you to be stewards over mine house, even stewards indeed.
40400	1532	58	And for this purpose I have commanded you to organize yourselves, even to print my words, the fulness of my scriptures, the revelations which I have given unto you, and which I shall, hereafter, from time to time give unto you--
40401	1532	59	For the purpose of building up my church and kingdom on the earth, and to prepare my people for the time when I shall dwell with them, which is nigh at hand.
40402	1532	60	And ye shall prepare for yourselves a place for a treasury, and consecrate it unto my name.
40403	1532	61	And ye shall appoint one among you to keep the treasury, and he shall be ordained unto this blessing.
40404	1532	62	And there shall be a seal upon the treasury, and all the sacred things shall be delivered into the treasury; and no man among you shall call it his own, or any part of it, for it shall belong to you all with one accord.
40405	1532	63	And I give it unto you from this very hour; and now see to it, that ye go to and make use of the stewardship which I have appointed unto you, exclusive of the sacred things, for the purpose of printing these sacred things as I have said.
40406	1532	64	And the avails of the sacred things shall be had in the treasury, and a seal shall be upon it; and it shall not be used or taken out of the treasury by any one, neither shall the seal be loosed which shall be placed upon it, only by the voice of the order, or by commandment.
40407	1532	65	And thus shall ye preserve the avails of the sacred things in the treasury, for sacred and holy purposes.
40408	1532	66	And this shall be called the sacred treasury of the Lord; and a seal shall be kept upon it that it may be holy and consecrated unto the Lord.
40409	1532	67	And again, there shall be another treasury prepared, and a treasurer appointed to keep the treasury, and a seal shall be placed upon it;
40410	1532	68	And all moneys that you receive in your stewardships, by improving upon the properties which I have appointed unto you, in houses, or in lands, or in cattle, or in all things save it be the holy and sacred writings, which I have reserved unto myself for holy and sacred purposes, shall be cast into the treasury as fast as you receive moneys, by hundreds, or by fifties, or by twenties, or by tens, or by fives.
40411	1532	69	Or in other words, if any man among you obtain five dollars let him cast them into the treasury; or if he obtain ten, or twenty, or fifty, or an hundred, let him do likewise;
40412	1532	70	And let not any among you say that it is his own; for it shall not be called his, nor any part of it.
40413	1532	71	And there shall not any part of it be used, or taken out of the treasury, only by the voice and common consent of the order.
40414	1532	72	And this shall be the voice and common consent of the order--that any man among you say to the treasurer: I have need of this to help me in my stewardship--
40415	1532	73	If it be five dollars, or if it be ten dollars, or twenty, or fifty, or a hundred, the treasurer shall give unto him the sum which he requires to help him in his stewardship--
40416	1532	74	Until he be found a transgressor, and it is manifest before the council of the order plainly that he is an unfaithful and an unwise steward.
40417	1532	75	But so long as he is in full fellowship, and is faithful and wise in his stewardship, this shall be his token unto the treasurer that the treasurer shall not withhold.
40418	1532	76	But in case of transgression, the treasurer shall be subject unto the council and voice of the order.
40419	1532	77	And in case the treasurer is found an unfaithful and an unwise steward, he shall be subject to the council and voice of the order, and shall be removed out of his place, and another shall be appointed in his stead.
40420	1532	78	And again, verily I say unto you, concerning your debts--behold it is my will that you shall pay all your debts.
40421	1532	79	And it is my will that you shall humble yourselves before me, and obtain this blessing by your diligence and humility and the prayer of faith.
40422	1532	80	And inasmuch as you are diligent and humble, and exercise the prayer of faith, behold, I will soften the hearts of those to whom you are in debt, until I shall send means unto you for your deliverance.
40423	1532	81	Therefore write speedily to New York and write according to that which shall be dictated by my Spirit; and I will soften the hearts of those to whom you are in debt, that it shall be taken away out of their minds to bring affliction upon you.
40424	1532	82	And inasmuch as ye are humble and faithful and call upon my name, behold, I will give you the victory.
40425	1532	83	I give unto you a promise, that you shall be delivered this once out of your bondage.
40426	1532	84	Inasmuch as you obtain a chance to loan money by hundreds, or thousands, even until you shall loan enough to deliver yourself from bondage, it is your privilege.
40427	1532	85	And pledge the properties which I have put into your hands, this once, by giving your names by common consent or otherwise, as it shall seem good unto you.
40428	1532	86	I give unto you this privilege, this once; and behold, if you proceed to do the things which I have laid before you, according to my commandments, all these things are mine, and ye are my stewards, and the master will not suffer his house to be broken up. Even so. Amen.
40429	1533	1	VERILY I say unto you who have assembled yourselves together that you may learn my will concerning the redemption of mine afflicted people--
40430	1533	2	Behold, I say unto you, were it not for the transgressions of my people, speaking concerning the church and not individuals, they might have been redeemed even now.
40431	1533	3	But behold, they have not learned to be obedient to the things which I required at their hands, but are full of all manner of evil, and do not impart of their substance, as becometh saints, to the poor and afflicted among them;
40432	1533	4	And are not united according to the union required by the law of the celestial kingdom;
40433	1533	5	And Zion cannot be built up unless it is by the principles of the law of the celestial kingdom; otherwise I cannot receive her unto myself.
40434	1533	6	And my people must needs be chastened until they learn obedience, if it must needs be, by the things which they suffer.
40435	1533	7	I speak not concerning those who are appointed to lead my people, who are the first elders of my church, for they are not all under this condemnation;
40436	1533	8	But I speak concerning my churches abroad--there are many who will say: Where is their God? Behold, he will deliver them in time of trouble, otherwise we will not go up unto Zion, and will keep our moneys.
40437	1533	9	Therefore, in consequence of the transgressions of my people, it is expedient in me that mine elders should wait for a little season for the redemption of Zion--
40438	1533	10	That they themselves may be prepared, and that my people may be taught more perfectly, and have experience, and know more perfectly concerning their duty, and the things which I require at their hands.
40439	1533	11	And this cannot be brought to pass until mine elders are endowed with power from on high.
40440	1533	12	For behold, I have prepared a great endowment and blessing to be poured out upon them, inasmuch as they are faithful and continue in humility before me.
40441	1533	13	Therefore it is expedient in me that mine elders should wait for a little season, for the redemption of Zion.
40442	1533	14	For behold, I do not require at their hands to fight the battles of Zion; for, as I said in a former commandment, even so will I fulfil--I will fight your battles.
40443	1533	15	Behold, the destroyer I have sent forth to destroy and lay waste mine enemies; and not many years hence they shall not be left to pollute mine heritage, and to blaspheme my name upon the lands which I have consecrated for the gathering together of my saints.
40444	1533	16	Behold, I have commanded my servant Joseph Smith, Jun., to say unto the strength of my house, even my warriors, my young men, and middle-aged, to gather together for the redemption of my people, and throw down the towers of mine enemies, and scatter their watchmen;
40445	1533	17	But the strength of mine house have not hearkened unto my words.
40446	1533	18	But inasmuch as there are those who have hearkened unto my words, I have prepared a blessing and an endowment for them, if they continue faithful.
40447	1533	19	I have heard their prayers, and will accept their offering; and it is expedient in me that they should be brought thus far for a trial of their faith.
40448	1533	20	And now, verily I say unto you, a commandment I give unto you, that as many as have come up hither, that can stay in the region round about, let them stay;
40449	1533	21	And those that cannot stay, who have families in the east, let them tarry for a little season, inasmuch as my servant Joseph shall appoint unto them;
40450	1533	22	For I will counsel him concerning this matter, and all things whatsoever he shall appoint unto them shall be fulfilled.
40451	1533	23	And let all my people who dwell in the regions round about be very faithful, and prayerful, and humble before me, and reveal not the things which I have revealed unto them, until it is wisdom in me that they should be revealed.
40452	1533	24	Talk not of judgments, neither boast of faith nor of mighty works, but carefully gather together, as much in one region as can be, consistently with the feelings of the people;
40453	1533	25	And behold, I will give unto you favor and grace in their eyes, that you may rest in peace and safety, while you are saying unto the people: Execute judgment and justice for us according to law, and redress us of our wrongs.
40454	1533	26	Now, behold, I say unto you, my friends, in this way you may find favor in the eyes of the people, until the army of Israel becomes very great.
40455	1533	27	And I will soften the hearts of the people, as I did the heart of Pharaoh, from time to time, until my servant Joseph Smith, Jun., and mine elders, whom I have appointed, shall have time to gather up the strength of my house,
40456	1533	28	And to have sent wise men, to fulfil that which I have commanded concerning the purchasing of all the lands in Jackson county that can be purchased, and in the adjoining counties round about.
40457	1533	29	For it is my will that these lands should be purchased; and after they are purchased that my saints should possess them according to the laws of consecration which I have given.
40458	1533	30	And after these lands are purchased, I will hold the armies of Israel guiltless in taking possession of their own lands, which they have previously purchased with their moneys, and of throwing down the towers of mine enemies that may be upon them, and scattering their watchmen, and avenging me of mine enemies unto the third and fourth generation of them that hate me.
40459	1533	31	But first let my army become very great, and let it be sanctified before me, that it may become fair as the sun, and clear as the moon, and that her banners may be terrible unto all nations;
40460	1533	32	That the kingdoms of this world may be constrained to acknowledge that the kingdom of Zion is in very deed the kingdom of our God and his Christ; therefore, let us become subject unto her laws.
40461	1533	33	Verily I say unto you, it is expedient in me that the first elders of my church should receive their endowment from on high in my house, which I have commanded to be built unto my name in the land of Kirtland.
40462	1533	34	And let those commandments which I have given concerning Zion and her law be executed and fulfilled, after her redemption.
40463	1533	35	There has been a day of calling, but the time has come for a day of choosing; and let those be chosen that are worthy.
40464	1533	36	And it shall be manifest unto my servant, by the voice of the Spirit, those that are chosen; and they shall be sanctified;
40465	1533	37	And inasmuch as they follow the counsel which they receive, they shall have power after many days to accomplish all things pertaining to Zion.
40466	1533	38	And again I say unto you, sue for peace, not only to the people that have smitten you, but also to all people;
40467	1533	39	And lift up an ensign of peace, and make a proclamation of peace unto the ends of the earth;
40468	1533	40	And make proposals for peace unto those who have smitten you, according to the voice of the Spirit which is in you, and all things shall work together for your good.
40469	1533	41	Therefore, be faithful; and behold, and lo, I am with you even unto the end. Even so. Amen.
40470	1534	1	IT is my will that my servant Warren A. Cowdery should be appointed and ordained a presiding high priest over my church, in the land of Freedom and the regions round about;
40471	1534	2	And should preach my everlasting gospel, and lift up his voice and warn the people, not only in his own place, but in the adjoining counties;
40472	1534	3	And devote his whole time to this high and holy calling, which I now give unto him, seeking diligently the kingdom of heaven and its righteousness, and all things necessary shall be added thereunto; for the laborer is worthy of his hire.
40473	1534	4	And again, verily I say unto you, the coming of the Lord draweth nigh, and it overtaketh the world as a thief in the night--
40474	1534	5	Therefore, gird up your loins, that you may be the children of light, and that day shall not overtake you as a thief.
40475	1534	6	And again, verily I say unto you, there was joy in heaven when my servant Warren bowed to my scepter, and separated himself from the crafts of men;
40476	1534	7	Therefore, blessed is my servant Warren, for I will have mercy on him; and, notwithstanding the vanity of his heart, I will lift him up inasmuch as he will humble himself before me.
40477	1534	8	And I will give him grace and assurance wherewith he may stand; and if he continue to be a faithful witness and a light unto the church I have prepared a crown for him in the mansions of my Father. Even so. Amen.
40478	1535	1	THERE are, in the church, two priesthoods, namely, the Melchizedek and Aaronic, including the Levitical Priesthood.
40479	1535	2	Why the first is called the Melchizedek Priesthood is because Melchizedek was such a great high priest.
40480	1535	3	Before his day it was called the Holy Priesthood, after the Order of the Son of God.
40481	1535	4	But out of respect or reverence to the name of the Supreme Being, to avoid the too frequent repetition of his name, they, the church, in ancient days, called that priesthood after Melchizedek, or the Melchizedek Priesthood.
40482	1535	5	All other authorities or offices in the church are appendages to this priesthood.
40483	1535	6	But there are two divisions or grand heads--one is the Melchizedek Priesthood, and the other is the Aaronic or Levitical Priesthood.
40484	1535	7	The office of an elder comes under the priesthood of Melchizedek.
40485	1535	8	The Melchizedek Priesthood holds the right of presidency, and has power and authority over all the offices in the church in all ages of the world, to administer in spiritual things.
40486	1535	9	The Presidency of the High Priesthood, after the order of Melchizedek, have a right to officiate in all the offices in the church.
40487	1535	10	High priests after the order of the Melchizedek Priesthood have a right to officiate in their own standing, under the direction of the presidency, in administering spiritual things, and also in the office of an elder, priest (of the Levitical order), teacher, deacon, and member.
40488	1535	11	An elder has a right to officiate in his stead when the high priest is not present.
40489	1535	12	The high priest and elder are to administer in spiritual things, agreeable to the covenants and commandments of the church; and they have a right to officiate in all these offices of the church when there are no higher authorities present.
40490	1535	13	The second priesthood is called the Priesthood of Aaron, because it was conferred upon Aaron and his seed, throughout all their generations.
40491	1535	14	Why it is called the lesser priesthood is because it is an appendage to the greater, or the Melchizedek Priesthood, and has power in administering outward ordinances.
40492	1535	15	The bishopric is the presidency of this priesthood, and holds the keys or authority of the same.
40493	1535	16	No man has a legal right to this office, to hold the keys of this priesthood, except he be a literal descendant of Aaron.
40494	1535	17	But as a high priest of the Melchizedek Priesthood has authority to officiate in all the lesser offices, he may officiate in the office of bishop when no literal descendant of Aaron can be found, provided he is called and set apart and ordained unto this power by the hands of the Presidency of the Melchizedek Priesthood.
40495	1535	18	The power and authority of the higher, or Melchizedek Priesthood, is to hold the keys of all the spiritual blessings of the church--
40496	1535	19	To have the privilege of receiving the mysteries of the kingdom of heaven, to have the heavens opened unto them, to commune with the general assembly and church of the Firstborn, and to enjoy the communion and presence of God the Father, and Jesus the mediator of the new covenant.
40497	1535	20	The power and authority of the lesser, or Aaronic Priesthood, is to hold the keys of the ministering of angels, and to administer in outward ordinances, the letter of the gospel, the baptism of repentance for the remission of sins, agreeable to the covenants and commandments.
40498	1535	21	Of necessity there are presidents, or presiding officers growing out of, or appointed of or from among those who are ordained to the several offices in these two priesthoods.
40499	1535	22	Of the Melchizedek Priesthood, three Presiding High Priests, chosen by the body, appointed and ordained to that office, and upheld by the confidence, faith, and prayer of the church, form a quorum of the Presidency of the Church.
40500	1535	23	The twelve traveling councilors are called to be the Twelve Apostles, or special witnesses of the name of Christ in all the world--thus differing from other officers in the church in the duties of their calling.
40501	1535	24	And they form a quorum, equal in authority and power to the three presidents previously mentioned.
40502	1535	25	The Seventy are also called to preach the gospel, and to be especial witnesses unto the Gentiles and in all the world--thus differing from other officers in the church in the duties of their calling.
40503	1535	26	And they form a quorum, equal in authority to that of the Twelve special witnesses or Apostles just named.
40504	1535	27	And every decision made by either of these quorums must be by the unanimous voice of the same; that is, every member in each quorum must be agreed to its decisions, in order to make their decisions of the same power or validity one with the other--
40505	1535	28	A majority may form a quorum when circumstances render it impossible to be otherwise--
40506	1535	29	Unless this is the case, their decisions are not entitled to the same blessings which the decisions of a quorum of three presidents were anciently, who were ordained after the order of Melchizedek, and were righteous and holy men.
40507	1535	30	The decisions of these quorums, or either of them, are to be made in all righteousness, in holiness, and lowliness of heart, meekness and long suffering, and in faith, and virtue, and knowledge, temperance, patience, godliness, brotherly kindness and charity;
40508	1535	31	Because the promise is, if these things abound in them they shall not be unfruitful in the knowledge of the Lord.
40509	1535	32	And in case that any decision of these quorums is made in unrighteousness, it may be brought before a general assembly of the several quorums, which constitute the spiritual authorities of the church; otherwise there can be no appeal from their decision.
40510	1535	33	The Twelve are a Traveling Presiding High Council, to officiate in the name of the Lord, under the direction of the Presidency of the Church, agreeable to the institution of heaven; to build up the church, and regulate all the affairs of the same in all nations, first unto the Gentiles and secondly unto the Jews.
40511	1535	34	The Seventy are to act in the name of the Lord, under the direction of the Twelve or the traveling high council, in building up the church and regulating all the affairs of the same in all nations, first unto the Gentiles and then to the Jews;
40512	1535	35	The Twelve being sent out, holding the keys, to open the door by the proclamation of the gospel of Jesus Christ, and first unto the Gentiles and then unto the Jews.
40513	1535	36	The standing high councils, at the stakes of Zion, form a quorum equal in authority in the affairs of the church, in all their decisions, to the quorum of the presidency, or to the traveling high council.
40514	1535	37	The high council in Zion form a quorum equal in authority in the affairs of the church, in all their decisions, to the councils of the Twelve at the stakes of Zion.
40515	1535	38	It is the duty of the traveling high council to call upon the Seventy, when they need assistance, to fill the several calls for preaching and administering the gospel, instead of any others.
40516	1535	39	It is the duty of the Twelve, in all large branches of the church, to ordain evangelical ministers, as they shall be designated unto them by revelation--
40517	1535	40	The order of this priesthood was confirmed to be handed down from father to son, and rightly belongs to the literal descendants of the chosen seed, to whom the promises were made.
40518	1535	41	This order was instituted in the days of Adam, and came down by lineage in the following manner:
40519	1535	42	From Adam to Seth, who was ordained by Adam at the age of sixty-nine years, and was blessed by him three years previous to his (Adam's) death, and received the promise of God by his father, that his posterity should be the chosen of the Lord, and that they should be preserved unto the end of the earth;
40520	1535	43	Because he (Seth) was a perfect man, and his likeness was the express likeness of his father, insomuch that he seemed to be like unto his father in all things, and could be distinguished from him only by his age.
40521	1535	44	Enos was ordained at the age of one hundred and thirty-four years and four months, by the hand of Adam.
40522	1535	45	God called upon Cainan in the wilderness in the fortieth year of his age; and he met Adam in journeying to the place Shedolamak. He was eighty-seven years old when he received his ordination.
40523	1535	46	Mahalaleel was four hundred and ninety-six years and seven days old when he was ordained by the hand of Adam, who also blessed him.
40524	1535	47	Jared was two hundred years old when he was ordained under the hand of Adam, who also blessed him.
40525	1535	48	Enoch was twenty-five years old when he was ordained under the hand of Adam; and he was sixty-five and Adam blessed him.
40526	1535	49	And he saw the Lord, and he walked with him, and was before his face continually; and he walked with God three hundred and sixty-five years, making him four hundred and thirty years old when he was translated.
40527	1535	50	Methuselah was one hundred years old when he was ordained under the hand of Adam.
40528	1535	51	Lamech was thirty-two years old when he was ordained under the hand of Seth.
40529	1535	52	Noah was ten years old when he was ordained under the hand of Methuselah.
40530	1535	53	Three years previous to the death of Adam, he called Seth, Enos, Cainan, Mahalaleel, Jared, Enoch, and Methuselah, who were all high priests, with the residue of his posterity who were righteous, into the valley of Adam-ondi-Ahman, and there bestowed upon them his last blessing.
40531	1535	54	And the Lord appeared unto them, and they rose up and blessed Adam, and called him Michael, the prince, the archangel.
40532	1535	55	And the Lord administered comfort unto Adam, and said unto him: I have set thee to be at the head; a multitude of nations shall come of thee, and thou art a prince over them forever.
40533	1535	56	And Adam stood up in the midst of the congregation; and, notwithstanding he was bowed down with age, being full of the Holy Ghost, predicted whatsoever should befall his posterity unto the latest generation.
40534	1535	57	These things were all written in the book of Enoch, and are to be testified of in due time.
40535	1535	58	It is the duty of the Twelve, also, to ordain and set in order all the other officers of the church, agreeable to the revelation which says:
40536	1535	59	To the church of Christ in the land of Zion, in addition to the church laws respecting church business--
40537	1535	60	Verily, I say unto you, saith the Lord of Hosts, there must needs be presiding elders to preside over those who are of the office of an elder;
40538	1535	61	And also priests to preside over those who are of the office of a priest;
40539	1535	62	And also teachers to preside over those who are of the office of a teacher, in like manner, and also the deacons--
40540	1535	63	Wherefore, from deacon to teacher, and from teacher to priest, and from priest to elder, severally as they are appointed, according to the covenants and commandments of the church.
40541	1535	64	Then comes the High Priesthood, which is the greatest of all.
40542	1535	65	Wherefore, it must needs be that one be appointed of the High Priesthood to preside over the priesthood, and he shall be called President of the High Priesthood of the Church;
40543	1535	66	Or, in other words, the Presiding High Priest over the High Priesthood of the Church.
40544	1535	67	From the same comes the administering of ordinances and blessings upon the church, by the laying on of the hands.
40545	1535	68	Wherefore, the office of a bishop is not equal unto it; for the office of a bishop is in administering all temporal things;
40546	1535	69	Nevertheless a bishop must be chosen from the High Priesthood, unless he is a literal descendant of Aaron;
40547	1535	70	For unless he is a literal descendant of Aaron he cannot hold the keys of that priesthood.
40548	1535	71	Nevertheless, a high priest, that is, after the order of Melchizedek, may be set apart unto the ministering of temporal things, having a knowledge of them by the Spirit of truth;
40549	1535	72	And also to be a judge in Israel, to do the business of the church, to sit in judgment upon transgressors upon testimony as it shall be laid before him according to the laws, by the assistance of his counselors, whom he has chosen or will choose among the elders of the church.
40550	1535	73	This is the duty of a bishop who is not a literal descendant of Aaron, but has been ordained to the High Priesthood after the order of Melchizedek.
40551	1535	74	Thus shall he be a judge, even a common judge among the inhabitants of Zion, or in a stake of Zion, or in any branch of the church where he shall be set apart unto this ministry, until the borders of Zion are enlarged and it becomes necessary to have other bishops or judges in Zion or elsewhere.
40552	1535	75	And inasmuch as there are other bishops appointed they shall act in the same office.
40553	1535	76	But a literal descendant of Aaron has a legal right to the presidency of this priesthood, to the keys of this ministry, to act in the office of bishop independently, without counselors, except in a case where a President of the High Priesthood, after the order of Melchizedek, is tried, to sit as a judge in Israel.
40554	1535	77	And the decision of either of these councils, agreeable to the commandment which says:
40555	1535	78	Again, verily, I say unto you, the most important business of the church, and the most difficult cases of the church, inasmuch as there is not satisfaction upon the decision of the bishop or judges, it shall be handed over and carried up unto the council of the church, before the Presidency of the High Priesthood.
40556	1535	79	And the Presidency of the council of the High Priesthood shall have power to call other high priests, even twelve, to assist as counselors; and thus the Presidency of the High Priesthood and its counselors shall have power to decide upon testimony according to the laws of the church.
40557	1535	80	And after this decision it shall be had in remembrance no more before the Lord; for this is the highest council of the church of God, and a final decision upon controversies in spiritual matters.
40558	1535	81	There is not any person belonging to the church who is exempt from this council of the church.
40559	1535	82	And inasmuch as a President of the High Priesthood shall transgress, he shall be had in remembrance before the common council of the church, who shall be assisted by twelve counselors of the High Priesthood;
40560	1535	83	And their decision upon his head shall be an end of controversy concerning him.
40561	1535	84	Thus, none shall be exempted from the justice and the laws of God, that all things may be done in order and in solemnity before him, according to truth and righteousness.
40562	1535	85	And again, verily I say unto you, the duty of a president over the office of a deacon is to preside over twelve deacons, to sit in council with them, and to teach them their duty, edifying one another, as it is given according to the covenants.
40563	1535	86	And also the duty of the president over the office of the teachers is to preside over twenty-four of the teachers, and to sit in council with them, teaching them the duties of their office, as given in the covenants.
40564	1535	87	Also the duty of the president over the Priesthood of Aaron is to preside over forty-eight priests, and sit in council with them, to teach them the duties of their office, as is given in the covenants--
40565	1535	88	This president is to be a bishop; for this is one of the duties of this priesthood.
40566	1535	89	Again, the duty of the president over the office of elders is to preside over ninety-six elders, and to sit in council with them, and to teach them according to the covenants.
40567	1535	90	This presidency is a distinct one from that of the seventy, and is designed for those who do not travel into all the world.
40568	1535	91	And again, the duty of the President of the office of the High Priesthood is to preside over the whole church, and to be like unto Moses--
40569	1535	92	Behold, here is wisdom; yea, to be a seer, a revelator, a translator, and a prophet, having all the gifts of God which he bestows upon the head of the church.
40570	1535	93	And it is according to the vision showing the order of the Seventy, that they should have seven presidents to preside over them, chosen out of the number of the seventy;
40571	1535	94	And the seventh president of these presidents is to preside over the six;
40572	1535	95	And these seven presidents are to choose other seventy besides the first seventy to whom they belong, and are to preside over them;
40573	1535	96	And also other seventy, until seven times seventy, if the labor in the vineyard of necessity requires it.
40574	1535	97	And these seventy are to be traveling ministers, unto the Gentiles first and also unto the Jews.
40575	1535	98	Whereas other officers of the church, who belong not unto the Twelve, neither to the Seventy, are not under the responsibility to travel among all nations, but are to travel as their circumstances shall allow, notwithstanding they may hold as high and responsible offices in the church.
40576	1535	99	Wherefore, now let every man learn his duty, and to act in the office in which he is appointed, in all diligence.
40577	1535	100	He that is slothful shall not be counted worthy to stand, and he that learns not his duty and shows himself not approved shall not be counted worthy to stand. Even so. Amen.
40578	1536	1	VERILY thus saith the Lord unto you, my servant Lyman: Your sins are forgiven you, because you have obeyed my voice in coming up hither this morning to receive counsel of him whom I have appointed.
40579	1536	2	Therefore, let your soul be at rest concerning your spiritual standing, and resist no more my voice.
40580	1536	3	And arise up and be more careful henceforth in observing your vows, which you have made and do make, and you shall be blessed with exceeding great blessings.
40581	1536	4	Wait patiently until the solemn assembly shall be called of my servants, then you shall be remembered with the first of mine elders, and receive right by ordination with the rest of mine elders whom I have chosen.
40582	1536	5	Behold, this is the promise of the Father unto you if you continue faithful.
40583	1536	6	And it shall be fulfilled upon you in that day that you shall have right to preach my gospel wheresoever I shall send you, from henceforth from that time.
40584	1536	7	Therefore, strengthen your brethren in all your conversation, in all your prayers, in all your exhortations, and in all your doings.
40585	1536	8	And behold, and lo, I am with you to bless you and deliver you forever. Amen.
40586	1537	1	THANKS be to thy name, O Lord God of Israel, who keepest covenant and showest mercy unto thy servants who walk uprightly before thee, with all their hearts--
40587	1537	2	Thou who hast commanded thy servants to build a house to thy name in this place [Kirtland].
40588	1537	3	And now thou beholdest, O Lord, that thy servants have done according to thy commandment.
40589	1537	4	And now we ask thee, Holy Father, in the name of Jesus Christ, the Son of thy bosom, in whose name alone salvation can be administered to the children of men, we ask thee, O Lord, to accept of this house, the workmanship of the hands of us, thy servants, which thou didst command us to build.
40590	1537	5	For thou knowest that we have done this work through great tribulation; and out of our poverty we have given of our substance to build a house to thy name, that the Son of Man might have a place to manifest himself to his people.
40591	1537	6	And as thou hast said in a revelation, given to us, calling us thy friends, saying--Call your solemn assembly, as I have commanded you;
40592	1537	7	And as all have not faith, seek ye diligently and teach one another words of wisdom; yea, seek ye out of the best books words of wisdom, seek learning even by study and also by faith;
40593	1537	8	Organize yourselves; prepare every needful thing, and establish a house, even a house of prayer, a house of fasting, a house of faith, a house of learning, a house of glory, a house of order, a house of God;
40594	1537	9	That your incomings may be in the name of the Lord, that your outgoings may be in the name of the Lord, that all your salutations may be in the name of the Lord, with uplifted hands unto the Most High--
40595	1537	10	And now, Holy Father, we ask thee to assist us, thy people, with thy grace, in calling our solemn assembly, that it may be done to thine honor and to thy divine acceptance;
40596	1537	11	And in a manner that we may be found worthy, in thy sight, to secure a fulfilment of the promises which thou hast made unto us, thy people, in the revelations given unto us;
40597	1537	12	That thy glory may rest down upon thy people, and upon this thy house, which we now dedicate to thee, that it may be sanctified and consecrated to be holy, and that thy holy presence may be continually in this house;
40598	1537	13	And that all people who shall enter upon the threshold of the Lord's house may feel thy power, and feel constrained to acknowledge that thou hast sanctified it, and that it is thy house, a place of thy holiness.
40599	1537	14	And do thou grant, Holy Father, that all those who shall worship in this house may be taught words of wisdom out of the best books, and that they may seek learning even by study, and also by faith, as thou hast said;
40600	1537	15	And that they may grow up in thee, and receive a fulness of the Holy Ghost, and be organized according to thy laws, and be prepared to obtain every needful thing;
40601	1537	16	And that this house may be a house of prayer, a house of fasting, a house of faith, a house of glory and of God, even thy house;
40602	1537	17	That all the incomings of thy people, into this house, may be in the name of the Lord;
40603	1537	18	That all their outgoings from this house may be in the name of the Lord;
40604	1537	19	And that all their salutations may be in the name of the Lord, with holy hands, uplifted to the Most High;
40605	1537	20	And that no unclean thing shall be permitted to come into thy house to pollute it;
40606	1537	21	And when thy people transgress, any of them, they may speedily repent and return unto thee, and find favor in thy sight, and be restored to the blessings which thou hast ordained to be poured out upon those who shall reverence thee in thy house.
40607	1537	22	And we ask thee, Holy Father, that thy servants may go forth from this house armed with thy power, and that thy name may be upon them, and thy glory be round about them, and thine angels have charge over them;
40608	1537	23	And from this place they may bear exceedingly great and glorious tidings, in truth, unto the ends of the earth, that they may know that this is thy work, and that thou hast put forth thy hand, to fulfil that which thou hast spoken by the mouths of the prophets, concerning the last days.
40609	1537	24	We ask thee, Holy Father, to establish the people that shall worship, and honorably hold a name and standing in this thy house, to all generations and for eternity;
40610	1537	25	That no weapon formed against them shall prosper; that he who diggeth a pit for them shall fall into the same himself;
40611	1537	26	That no combination of wickedness shall have power to rise up and prevail over thy people upon whom thy name shall be put in this house;
40612	1537	27	And if any people shall rise against this people, that thine anger be kindled against them;
40613	1537	28	And if they shall smite this people thou wilt smite them; thou wilt fight for thy people as thou didst in the day of battle, that they may be delivered from the hands of all their enemies.
40614	1537	29	We ask thee, Holy Father, to confound, and astonish, and to bring to shame and confusion, all those who have spread lying reports abroad, over the world, against thy servant or servants, if they will not repent, when the everlasting gospel shall be proclaimed in their ears;
40615	1537	30	And that all their works may be brought to naught, and be swept away by the hail, and by the judgments which thou wilt send upon them in thine anger, that there may be an end to lyings and slanders against thy people.
40616	1537	31	For thou knowest, O Lord, that thy servants have been innocent before thee in bearing record of thy name, for which they have suffered these things.
40617	1537	32	Therefore we plead before thee for a full and complete deliverance from under this yoke;
40618	1537	33	Break it off, O Lord; break it off from the necks of thy servants, by thy power, that we may rise up in the midst of this generation and do thy work.
40619	1537	34	O Jehovah, have mercy upon this people, and as all men sin forgive the transgressions of thy people, and let them be blotted out forever.
40620	1537	35	Let the anointing of thy ministers be sealed upon them with power from on high.
40621	1537	36	Let it be fulfilled upon them, as upon those on the day of Pentecost; let the gift of tongues be poured out upon thy people, even cloven tongues as of fire, and the interpretation thereof.
40622	1537	37	And let thy house be filled, as with a rushing mighty wind, with thy glory.
40623	1537	38	Put upon thy servants the testimony of the covenant, that when they go out and proclaim thy word they may seal up the law, and prepare the hearts of thy saints for all those judgments thou art about to send, in thy wrath, upon the inhabitants of the earth, because of their transgressions, that thy people may not faint in the day of trouble.
40624	1537	39	And whatsoever city thy servants shall enter, and the people of that city receive their testimony, let thy peace and thy salvation be upon that city; that they may gather out of that city the righteous, that they may come forth to Zion, or to her stakes, the places of thine appointment, with songs of everlasting joy;
40625	1537	40	And until this be accomplished, let not thy judgments fall upon that city.
40626	1537	41	And whatsoever city thy servants shall enter, and the people of that city receive not the testimony of thy servants, and thy servants warn them to save themselves from this untoward generation, let it be upon that city according to that which thou hast spoken by the mouths of thy prophets.
40627	1537	42	But deliver thou, O Jehovah, we beseech thee, thy servants from their hands, and cleanse them from their blood.
40628	1537	43	O Lord, we delight not in the destruction of our fellow men; their souls are precious before thee;
40629	1537	44	But thy word must be fulfilled. Help thy servants to say, with thy grace assisting them: Thy will be done, O Lord, and not ours.
40630	1537	45	We know that thou hast spoken by the mouth of thy prophets terrible things concerning the wicked, in the last days--that thou wilt pour out thy judgments, without measure;
40631	1537	46	Therefore, O Lord, deliver thy people from the calamity of the wicked; enable thy servants to seal up the law, and bind up the testimony, that they may be prepared against the day of burning.
40632	1537	47	We ask thee, Holy Father, to remember those who have been driven by the inhabitants of Jackson county, Missouri, from the lands of their inheritance, and break off, O Lord, this yoke of affliction that has been put upon them.
40633	1537	48	Thou knowest, O Lord, that they have been greatly oppressed and afflicted by wicked men; and our hearts flow out with sorrow because of their grievous burdens.
40634	1537	49	O Lord, how long wilt thou suffer this people to bear this affliction, and the cries of their innocent ones to ascend up in thine ears, and their blood come up in testimony before thee, and not make a display of thy testimony in their behalf?
40635	1537	50	Have mercy, O Lord, upon the wicked mob, who have driven thy people, that they may cease to spoil, that they may repent of their sins if repentance is to be found;
40636	1537	51	But if they will not, make bare thine arm, O Lord, and redeem that which thou didst appoint a Zion unto thy people.
40637	1537	52	And if it cannot be otherwise, that the cause of thy people may not fail before thee may thine anger be kindled, and thine indignation fall upon them, that they may be wasted away, both root and branch, from under heaven;
40638	1537	53	But inasmuch as they will repent, thou art gracious and merciful, and wilt turn away thy wrath when thou lookest upon the face of thine Anointed.
40639	1537	54	Have mercy, O Lord, upon all the nations of the earth; have mercy upon the rulers of our land; may those principles, which were so honorably and nobly defended, namely, the Constitution of our land, by our fathers, be established forever.
40640	1537	55	Remember the kings, the princes, the nobles, and the great ones of the earth, and all people, and the churches, all the poor, the needy, and afflicted ones of the earth;
40641	1537	56	That their hearts may be softened when thy servants shall go out from thy house, O Jehovah, to bear testimony of thy name; that their prejudices may give way before the truth, and thy people may obtain favor in the sight of all;
40642	1537	57	That all the ends of the earth may know that we, thy servants, have heard thy voice, and that thou hast sent us;
40643	1537	58	That from among all these, thy servants, the sons of Jacob, may gather out the righteous to build a holy city to thy name, as thou hast commanded them.
40644	1537	59	We ask thee to appoint unto Zion other stakes besides this one which thou hast appointed, that the gathering of thy people may roll on in great power and majesty, that thy work may be cut short in righteousness.
40645	1537	60	Now these words, O Lord, we have spoken before thee, concerning the revelations and commandments which thou hast given unto us, who are identified with the Gentiles.
40646	1537	61	But thou knowest that thou hast a great love for the children of Jacob, who have been scattered upon the mountains for a long time, in a cloudy and dark day.
40647	1537	62	We therefore ask thee to have mercy upon the children of Jacob, that Jerusalem, from this hour, may begin to be redeemed;
40648	1537	63	And the yoke of bondage may begin to be broken off from the house of David;
40649	1537	64	And the children of Judah may begin to return to the lands which thou didst give to Abraham, their father.
40650	1537	65	And cause that the remnants of Jacob, who have been cursed and smitten because of their transgression, be converted from their wild and savage condition to the fulness of the everlasting gospel;
40651	1537	66	That they may lay down their weapons of bloodshed, and cease their rebellions.
40652	1537	67	And may all the scattered remnants of Israel, who have been driven to the ends of the earth, come to a knowledge of the truth, believe in the Messiah, and be redeemed from oppression, and rejoice before thee.
40653	1537	68	O Lord, remember thy servant, Joseph Smith, Jun., and all his afflictions and persecutions--how he has covenanted with Jehovah, and vowed to thee, O Mighty God of Jacob--and the commandments which thou hast given unto him, and that he hath sincerely striven to do thy will.
40654	1537	69	Have mercy, O Lord, upon his wife and children, that they may be exalted in thy presence, and preserved by thy fostering hand.
40655	1537	70	Have mercy upon all their immediate connections, that their prejudices may be broken up and swept away as with a flood; that they may be converted and redeemed with Israel, and know that thou art God.
40656	1537	71	Remember, O Lord, the presidents, even all the presidents of thy church, that thy right hand may exalt them, with all their families, and their immediate connections, that their names may be perpetuated and had in everlasting remembrance from generation to generation.
40657	1537	72	Remember all thy church, O Lord, with all their families, and all their immediate connections, with all their sick and afflicted ones, with all the poor and meek of the earth; that the kingdom, which thou hast set up without hands, may become a great mountain and fill the whole earth;
40658	1537	73	That thy church may come forth out of the wilderness of darkness, and shine forth fair as the moon, clear as the sun, and terrible as an army with banners;
40659	1537	74	And be adorned as a bride for that day when thou shalt unveil the heavens, and cause the mountains to flow down at thy presence, and the valleys to be exalted, the rough places made smooth; that thy glory may fill the earth;
40660	1537	75	That when the trump shall sound for the dead, we shall be caught up in the cloud to meet thee, that we may ever be with the Lord;
40661	1537	76	That our garments may be pure, that we may be clothed upon with robes of righteousness, with palms in our hands, and crowns of glory upon our heads, and reap eternal joy for all our sufferings.
40662	1537	77	O Lord God Almighty, hear us in these our petitions, and answer us from heaven, thy holy habitation, where thou sittest enthroned, with glory, honor, power, majesty, might, dominion, truth, justice, judgment, mercy, and an infinity of fulness, from everlasting to everlasting.
40663	1537	78	O hear, O hear, O hear us, O Lord! And answer these petitions, and accept the dedication of this house unto thee, the work of our hands, which we have built unto thy name;
40664	1537	79	And also this church, to put upon it thy name. And help us by the power of thy Spirit, that we may mingle our voices with those bright, shining seraphs around thy throne, with acclamations of praise, singing Hosanna to God and the Lamb!
40665	1537	80	And let these, thine anointed ones, be clothed with salvation, and thy saints shout aloud for joy. Amen, and Amen.
40666	1538	1	THE veil was taken from our minds, and the eyes of our understanding were opened.
40667	1538	2	We saw the Lord standing upon the breastwork of the pulpit, before us; and under his feet was a paved work of pure gold, in color like amber.
40668	1538	3	His eyes were as a flame of fire; the hair of his head was white like the pure snow; his countenance shone above the brightness of the sun; and his voice was as the sound of the rushing of great waters, even the voice of Jehovah, saying:
40669	1538	4	I am the first and the last; I am he who liveth, I am he who was slain; I am your advocate with the Father.
40670	1538	5	Behold, your sins are forgiven you; you are clean before me; therefore, lift up your heads and rejoice.
40671	1538	6	Let the hearts of your brethren rejoice, and let the hearts of all my people rejoice, who have, with their might, built this house to my name.
40672	1538	7	For behold, I have accepted this house, and my name shall be here; and I will manifest myself to my people in mercy in this house.
40673	1538	8	Yea, I will appear unto my servants, and speak unto them with mine own voice, if my people will keep my commandments, and do not pollute this holy house.
40674	1538	9	Yea the hearts of thousands and tens of thousands shall greatly rejoice in consequence of the blessings which shall be poured out, and the endowment with which my servants have been endowed in this house.
40675	1538	10	And the fame of this house shall spread to foreign lands; and this is the beginning of the blessing which shall be poured out upon the heads of my people. Even so. Amen.
40676	1538	11	After this vision closed, the heavens were again opened unto us; and Moses appeared before us, and committed unto us the keys of the gathering of Israel from the four parts of the earth, and the leading of the ten tribes from the land of the north.
40677	1538	12	After this, Elias appeared, and committed the dispensation of the gospel of Abraham, saying that in us and our seed all generations after us should be blessed.
40678	1538	13	After this vision had closed, another great and glorious vision burst upon us; for Elijah the prophet, who was taken to heaven without tasting death, stood before us, and said:
40679	1538	14	Behold, the time has fully come, which was spoken of by the mouth of Malachi--testifying that he [Elijah] should be sent, before the great and dreadful day of the Lord come--
40680	1538	15	To turn the hearts of the fathers to the children, and the children to the fathers, lest the whole earth be smitten with a curse--
40681	1538	16	Therefore, the keys of this dispensation are committed into your hands; and by this ye may know that the great and dreadful day of the Lord is near, even at the doors.
40682	1539	1	I, THE Lord your God, am not displeased with your coming this journey, notwithstanding your follies.
40683	1539	2	I have much treasure in this city for you, for the benefit of Zion, and many people in this city, whom I will gather out in due time for the benefit of Zion, through your instrumentality.
40684	1539	3	Therefore, it is expedient that you should form acquaintance with men in this city, as you shall be led, and as it shall be given you.
40685	1539	4	And it shall come to pass in due time that I will give this city into your hands, that you shall have power over it, insomuch that they shall not discover your secret parts; and its wealth pertaining to gold and silver shall be yours.
40686	1539	5	Concern not yourselves about your debts, for I will give you power to pay them.
40687	1539	6	Concern not yourselves about Zion, for I will deal mercifully with her.
40688	1539	7	Tarry in this place, and in the regions round about;
40689	1539	8	And the place where it is my will that you should tarry, for the main, shall be signalized unto you by the peace and power of my Spirit, that shall flow unto you.
40690	1539	9	This place you may obtain by hire. And inquire diligently concerning the more ancient inhabitants and founders of this city;
40691	1539	10	For there are more treasures than one for you in this city.
40692	1539	11	Therefore, be ye as wise as serpents and yet without sin; and I will order all things for your good, as fast as ye are able to receive them. Amen.
40693	1540	1	VERILY thus saith the Lord unto you my servant Thomas: I have heard thy prayers; and thine alms have come up as a memorial before me, in behalf of those, thy brethren, who were chosen to bear testimony of my name and to send it abroad among all nations, kindreds, tongues, and people, and ordained through the instrumentality of my servants,
40694	1540	2	Verily I say unto you, there have been some few things in thine heart and with thee with which I, the Lord, was not well pleased.
40695	1540	3	Nevertheless, inasmuch as thou hast abased thyself thou shalt be exalted; therefore, all thy sins are forgiven thee.
40696	1540	4	Let thy heart be of good cheer before my face; and thou shalt bear record of my name, not only unto the Gentiles, but also unto the Jews; and thou shalt send forth my word unto the ends of the earth.
40697	1540	5	Contend thou, therefore, morning by morning; and day after day let thy warning voice go forth; and when the night cometh let not the inhabitants of the earth slumber, because of thy speech.
40698	1540	6	Let thy habitation be known in Zion, and remove not thy house; for I, the Lord, have a great work for thee to do, in publishing my name among the children of men.
40699	1540	7	Therefore, gird up thy loins for the work. Let thy feet be shod also, for thou art chosen, and thy path lieth among the mountains, and among many nations.
40700	1540	8	And by thy word many high ones shall be brought low, and by thy word many low ones shall be exalted.
40701	1540	9	Thy voice shall be a rebuke unto the transgressor; and at thy rebuke let the tongue of the slanderer cease its perverseness.
40702	1540	10	Be thou humble; and the Lord thy God shall lead thee by the hand, and give thee answer to thy prayers.
40703	1540	11	I know thy heart, and have heard thy prayers concerning thy brethren. Be not partial towards them in love above many others, but let thy love be for them as for thyself; and let thy love abound unto all men, and unto all who love my name.
40704	1540	12	And pray for thy brethren of the Twelve. Admonish them sharply for my name's sake, and let them be admonished for all their sins, and be ye faithful before me unto my name.
40705	1540	13	And after their temptations, and much tribulation, behold, I, the Lord, will feel after them, and if they harden not their hearts, and stiffen not their necks against me, they shall be converted, and I will heal them.
40706	1540	14	Now, I say unto you, and what I say unto you, I say unto all the Twelve: Arise and gird up your loins, take up your cross, follow me, and feed my sheep.
40707	1540	15	Exalt not yourselves; rebel not against my servant Joseph; for verily I say unto you, I am with him, and my hand shall be over him; and the keys which I have given unto him, and also to youward, shall not be taken from him till I come.
40708	1540	16	Verily I say unto you, my servant Thomas, thou art the man whom I have chosen to hold the keys of my kingdom, as pertaining to the Twelve, abroad among all nations--
40709	1540	17	That thou mayest be my servant to unlock the door of the kingdom in all places where my servant Joseph, and my servant Sidney, and my servant Hyrum, cannot come;
40710	1540	18	For on them have I laid the burden of all the churches for a little season.
40711	1540	19	Wherefore, whithersoever they shall send you, go ye, and I will be with you; and in whatsoever place ye shall proclaim my name an effectual door shall be opened unto you, that they may receive my word.
40712	1540	20	Whosoever receiveth my word receiveth me, and whosoever receiveth me, receiveth those, the First Presidency, whom I have sent, whom I have made counselors for my name's sake unto you.
40713	1540	21	And again, I say unto you, that whosoever ye shall send in my name, by the voice of your brethren, the Twelve, duly recommended and authorized by you, shall have power to open the door of my kingdom unto any nation whithersoever ye shall send them--
40714	1540	22	Inasmuch as they shall humble themselves before me, and abide in my word, and hearken to the voice of my Spirit.
40715	1540	23	Verily, verily, I say unto you, darkness covereth the earth, and gross darkness the minds of the people, and all flesh has become corrupt before my face.
40716	1540	24	Behold, vengeance cometh speedily upon the inhabitants of the earth, a day of wrath, a day of burning, a day of desolation, of weeping, of mourning, and of lamentation; and as a whirlwind it shall come upon all the face of the earth, saith the Lord.
40717	1540	25	And upon my house shall it begin, and from my house shall it go forth, saith the Lord;
40718	1540	26	First among those among you, saith the Lord, who have professed to know my name and have not known me, and have blasphemed against me in the midst of my house, saith the Lord.
40719	1540	27	Therefore, see to it that ye trouble not yourselves concerning the affairs of my church in this place, saith the Lord.
40720	1540	28	But purify your hearts before me; and then go ye into all the world, and preach my gospel unto every creature who has not received it;
40721	1540	29	And he that believeth and is baptized shall be saved, and he that believeth not, and is not baptized, shall be damned.
40722	1540	30	For unto you, the Twelve, and those, the First Presidency, who are appointed with you to be your counselors and your leaders, is the power of this priesthood given, for the last days and for the last time, in the which is the dispensation of the fulness of times.
40723	1540	31	Which power you hold, in connection with all those who have received a dispensation at any time from the beginning of the creation;
40724	1540	32	For verily I say unto you, the keys of the dispensation, which ye have received, have come down from the fathers, and last of all, being sent down from heaven unto you.
40725	1540	33	Verily I say unto you, behold how great is your calling. Cleanse your hearts and your garments, lest the blood of this generation be required at your hands.
40726	1540	34	Be faithful until I come, for I come quickly; and my reward is with me to recompense every man according as his work shall be. I am Alpha and Omega. Amen.
40727	1541	1	WHO is the Stem of Jesse spoken of in the 1st, 2d, 3d, 4th, and 5th verses of the 11th chapter of Isaiah?
40728	1541	2	Verily thus saith the Lord: It is Christ.
40729	1541	3	What is the rod spoken of in the first verse of the 11th chapter of Isaiah, that should come of the Stem of Jesse?
40730	1541	4	Behold, thus saith the Lord: It is a servant in the hands of Christ, who is partly a descendant of Jesse as well as of Ephraim, or of the house of Joseph, on whom there is laid much power.
40731	1541	5	What is the root of Jesse spoken of in the 10th verse of the 11th chapter?
40732	1541	6	Behold, thus saith the Lord, it is a descendant of Jesse, as well as of Joseph, unto whom rightly belongs the priesthood, and the keys of the kingdom, for an ensign, and for the gathering of my people in the last days.
40733	1541	7	Questions by Elias Higbee: What is meant by the command in Isaiah, 52d chapter, 1st verse, which saith: Put on thy strength, O Zion--and what people had Isaiah reference to?
40734	1541	8	He had reference to those whom God should call in the last days, who should hold the power of priesthood to bring again Zion, and the redemption of Israel; and to put on her strength is to put on the authority of the priesthood, which she, Zion, has a right to by lineage; also to return to that power which she had lost.
40735	1541	9	What are we to understand by Zion loosing herself from the bands of her neck; 2d verse?
40736	1541	10	We are to understand that the scattered remnants are exhorted to return to the Lord from whence they have fallen; which if they do, the promise of the Lord is that he will speak to them, or give them revelation. See the 6th, 7th, and 8th verses. The bands of her neck are the curses of God upon her, or the remnants of Israel in their scattered condition among the Gentiles.
40737	1542	1	VERILY thus saith the Lord: It is wisdom in my servant David W. Patten, that he settle up all his business as soon as he possibly can, and make a disposition of his merchandise, that he may perform a mission unto me next spring, in company with others, even twelve including himself, to testify of my name and bear glad tidings unto all the world.
40738	1542	2	For verily thus saith the Lord, that inasmuch as there are those among you who deny my name, others shall be planted in their stead and receive their bishopric. Amen.
40739	1543	1	VERILY thus saith the Lord unto you, my servant Joseph Smith, Jun., and also my servant Sidney Rigdon, and also my servant Hyrum Smith, and your counselors who are and shall be appointed hereafter;
40740	1543	2	And also unto you, my servant Edward Partridge, and his counselors;
40741	1543	3	And also unto my faithful servants who are of the high council of my church in Zion, for thus it shall be called, and unto all the elders and people of my Church of Jesus Christ of Latter-day Saints, scattered abroad in all the world;
40742	1543	4	For thus shall my church be called in the last days, even The Church of Jesus Christ of Latter-day Saints.
40743	1543	5	Verily I say unto you all: Arise and shine forth, that thy light may be a standard for the nations;
40744	1543	6	And that the gathering together upon the land of Zion, and upon her stakes, may be for a defense, and for a refuge from the storm, and from wrath when it shall be poured out without mixture upon the whole earth.
40745	1543	7	Let the city, Far West, be a holy and consecrated land unto me; and it shall be called most holy, for the ground upon which thou standest is holy.
40746	1543	8	Therefore, I command you to build a house unto me, for the gathering together of my saints, that they may worship me.
40747	1543	9	And let there be a beginning of this work, and a foundation, and a preparatory work, this following summer;
40748	1543	10	And let the beginning be made on the fourth day of July next; and from that time forth let my people labor diligently to build a house unto my name;
40749	1543	11	And in one year from this day let them re-commence laying the foundation of my house.
40750	1543	12	Thus let them from that time forth labor diligently until it shall be finished, from the corner stone thereof unto the top thereof, until there shall not anything remain that is not finished.
40751	1543	13	Verily I say unto you, let not my servant Joseph, neither my servant Sidney, neither my servant Hyrum, get in debt any more for the building of a house unto my name;
40752	1543	14	But let a house be built unto my name according to the pattern which I will show unto them.
40753	1543	15	And if my people build it not according to the pattern which I shall show unto their presidency, I will not accept it at their hands.
40754	1543	16	But if my people do build it according to the pattern which I shall show unto their presidency, even my servant Joseph and his counselors, then I will accept it at the hands of my people.
40755	1543	17	And again, verily I say unto you, it is my will that the city of Far West should be built up speedily by the gathering of my saints;
40756	1543	18	And also that other places should be appointed for stakes in the regions round about, as they shall be manifested unto my servant Joseph, from time to time.
40757	1543	19	For behold, I will be with him, and I will sanctify him before the people; for unto him have I given the keys of this kingdom and ministry. Even so. Amen.
40758	1544	1	SPRING Hill is named by the Lord Adam-ondi-Ahman, because, said he, it is the place where Adam shall come to visit his people, or the Ancient of Days shall sit, as spoken of by Daniel the prophet.
40759	1545	1	VERILY thus saith the Lord unto my servant William Marks, and also unto my servant Newel K. Whitney, let them settle up their business speedily and journey from the land of Kirtland, before I, the Lord, send again the snows upon the earth.
40760	1545	2	Let them awake, and arise, and come forth, and not tarry, for I, the Lord, command it.
40761	1545	3	Therefore, if they tarry it shall not be well with them.
40762	1545	4	Let them repent of all their sins, and of all their covetous desires, before me, saith the Lord; for what is property unto me? saith the Lord.
40763	1545	5	Let the properties of Kirtland be turned out for debts, saith the Lord. Let them go, saith the Lord, and whatsoever remaineth, let it remain in your hands, saith the Lord.
40764	1545	6	For have I not the fowls of heaven, and also the fish of the sea, and the beasts of the mountains? Have I not made the earth? Do I not hold the destinies of all the armies of the nations of the earth?
40765	1545	7	Therefore, will I not make solitary places to bud and to blossom, and to bring forth in abundance? saith the Lord.
40766	1545	8	Is there not room enough on the mountains of Adam-ondi-Ahman, and on the plains of Olaha Shinehah, or the land where Adam dwelt, that you should covet that which is but the drop, and neglect the more weighty matters?
40767	1545	9	Therefore, come up hither unto the land of my people, even Zion.
40768	1545	10	Let my servant William Marks be faithful over a few things, and he shall be a ruler over many. Let him preside in the midst of my people in the city of Far West, and let him be blessed with the blessings of my people.
40769	1545	11	Let my servant Newel K. Whitney be ashamed of the Nicolaitane band and of all their secret abominations, and of all his littleness of soul before me, saith the Lord, and come up to the land of Adam-ondi-Ahman, and be a bishop unto my people, saith the Lord, not in name but in deed, saith the Lord.
40770	1545	12	And again, I say unto you, I remember my servant Oliver Granger; behold, verily I say unto him that his name shall be had in sacred remembrance from generation to generation, forever and ever, saith the Lord.
40771	1545	13	Therefore, let him contend earnestly for the redemption of the First Presidency of my Church, saith the Lord; and when he falls he shall rise again, for his sacrifice shall be more sacred unto me than his increase, saith the Lord.
40772	1545	14	Therefore, let him come up hither speedily, unto the land of Zion; and in the due time he shall be made a merchant unto my name, saith the Lord, for the benefit of my people.
40773	1545	15	Therefore let no man despise my servant Oliver Granger, but let the blessings of my people be on him forever and ever.
40774	1545	16	And again, verily I say unto you, let all my servants in the land of Kirtland remember the Lord their God, and mine house also, to keep and preserve it holy, and to overthrow the moneychangers in mine own due time, saith the Lord. Even so. Amen.
40775	1546	1	VERILY, thus saith the Lord: Let a conference be held immediately; let the Twelve be organized; and let men be appointed to supply the place of those who are fallen.
40776	1546	2	Let my servant Thomas remain for a season in the land of Zion, to publish my word.
40777	1546	3	Let the residue continue to preach from that hour, and if they will do this in all lowliness of heart, in meekness and humility, and long-suffering, I, the Lord, give unto them a promise that I will provide for their families; and an effectual door shall be opened for them, from henceforth.
40778	1546	4	And next spring let them depart to go over the great waters, and there promulgate my gospel, the fulness thereof, and bear record of my name.
40779	1546	5	Let them take leave of my saints in the city of Far West, on the twenty-sixth day of April next, on the building-spot of my house, saith the Lord.
40780	1546	6	Let my servant John Taylor, and also my servant John E. Page, and also my servant Wilford Woodruff, and also my servant Willard Richards, be appointed to fill the places of those who have fallen, and be officially notified of their appointment.
40781	1547	1	VERILY, thus saith the Lord, I require all their surplus property to be put into the hands of the bishop of my church in Zion,
40782	1547	2	For the building of mine house, and for the laying of the foundation of Zion and for the priesthood, and for the debts of the Presidency of my Church.
40783	1547	3	And this shall be the beginning of the tithing of my people.
40784	1547	4	And after that, those who have thus been tithed shall pay one-tenth of all their interest annually; and this shall be a standing law unto them forever, for my holy priesthood, saith the Lord.
40785	1547	5	Verily I say unto you, it shall come to pass that all those who gather unto the land of Zion shall be tithed of their surplus properties, and shall observe this law, or they shall not be found worthy to abide among you.
40786	1547	6	And I say unto you, if my people observe not this law, to keep it holy, and by this law sanctify the land of Zion unto me, that my statutes and my judgments may be kept thereon, that it may be most holy, behold, verily I say unto you, it shall not be a land of Zion unto you.
40787	1547	7	And this shall be an ensample unto all the stakes of Zion. Even so. Amen.
40788	1548	1	VERILY, thus saith the Lord, the time is now come, that it shall be disposed of by a council, composed of the First Presidency of my Church, and of the bishop and his council, and by my high council; and by mine own voice unto them, saith the Lord. Even so. Amen.
40789	1549	1	O GOD, where art thou? And where is the pavilion that covereth thy hiding place?
40790	1549	2	How long shall thy hand be stayed, and thine eye, yea thy pure eye, behold from the eternal heavens the wrongs of thy people and of thy servants, and thine ear be penetrated with their cries?
40791	1549	3	Yea, O Lord, how long shall they suffer these wrongs and unlawful oppressions, before thine heart shall be softened toward them, and thy bowels be moved with compassion toward them?
40792	1549	4	O Lord God Almighty, maker of heaven, earth, and seas, and of all things that in them are, and who controllest and subjectest the devil, and the dark and benighted dominion of Sheol--stretch forth thy hand; let thine eye pierce; let thy pavilion be taken up; let thy hiding place no longer be covered; let thine ear be inclined; let thine heart be softened, and thy bowels moved with compassion toward us.
40793	1549	5	Let thine anger be kindled against our enemies; and, in the fury of thine heart, with thy sword avenge us of our wrongs.
40794	1549	6	Remember thy suffering saints, O our God; and thy servants will rejoice in thy name forever.
40795	1549	7	My son, peace be unto thy soul; thine adversity and thine afflictions shall be but a small moment;
40796	1549	8	And then, if thou endure it well, God shall exalt thee on high; thou shalt triumph over all thy foes.
40797	1549	9	Thy friends do stand by thee, and they shall hail thee again with warm hearts and friendly hands.
40798	1549	10	Thou art not yet as Job; thy friends do not contend against thee, neither charge thee with transgression, as they did Job.
40799	1549	11	And they who do charge thee with transgression, their hope shall be blasted, and their prospects shall melt away as the hoar frost melteth before the burning rays of the rising sun;
40800	1549	12	And also that God hath set his hand and seal to change the times and seasons, and to blind their minds, that they may not understand his marvelous workings; that he may prove them also and take them in their own craftiness;
40801	1549	13	Also because their hearts are corrupted, and the things which they are willing to bring upon others, and love to have others suffer, may come upon themselves to the very uttermost;
40802	1549	14	That they may be disappointed also, and their hopes may be cut off;
40803	1549	15	And not many years hence, that they and their posterity shall be swept from under heaven, saith God, that not one of them is left to stand by the wall.
40804	1549	16	Cursed are all those that shall lift up the heel against mine anointed, saith the Lord, and cry they have sinned when they have not sinned before me, saith the Lord, but have done that which was meet in mine eyes, and which I commanded them.
40805	1549	17	But those who cry transgression do it because they are the servants of sin, and are the children of disobedience themselves.
40806	1549	18	And those who swear falsely against my servants, that they might bring them into bondage and death--
40807	1549	19	Wo unto them; because they have offended my little ones they shall be severed from the ordinances of mine house.
40808	1549	20	Their basket shall not be full, their houses and their barns shall perish, and they themselves shall be despised by those that flattered them.
40809	1549	21	They shall not have right to the priesthood, nor their posterity after them from generation to generation.
40810	1549	22	It had been better for them that a millstone had been hanged about their necks, and they drowned in the depth of the sea.
40811	1549	23	Wo unto all those that discomfort my people, and drive, and murder, and testify against them, saith the Lord of Hosts; a generation of vipers shall not escape the damnation of hell.
40812	1549	24	Behold, mine eyes see and know all their works, and I have in reserve a swift judgment in the season thereof, for them all;
40813	1549	25	For there is a time appointed for every man, according as his works shall be.
40814	1549	26	God shall give unto you knowledge by his Holy Spirit, yea, by the unspeakable gift of the Holy Ghost, that has not been revealed since the world was until now;
40815	1549	27	Which our forefathers have awaited with anxious expectation to be revealed in the last times, which their minds were pointed to by the angels, as held in reserve for the fulness of their glory;
40816	1549	28	A time to come in the which nothing shall be withheld, whether there be one God or many gods, they shall be manifest.
40817	1549	29	All thrones and dominions, principalities and powers, shall be revealed and set forth upon all who have endured valiantly for the gospel of Jesus Christ.
40818	1549	30	And also, if there be bounds set to the heavens or to the seas, or to the dry land, or to the sun, moon, or stars--
40819	1549	31	All the times of their revolutions, all the appointed days, months, and years, and all the days of their days, months, and years, and all their glories, laws, and set times, shall be revealed in the days of the dispensation of the fulness of times--
40820	1549	32	According to that which was ordained in the midst of the Council of the Eternal God of all other gods before this world was, that should be reserved unto the finishing and the end thereof, when every man shall enter into his eternal presence and into his immortal rest.
40821	1549	33	How long can rolling waters remain impure? What power shall stay the heavens? As well might man stretch forth his puny arm to stop the Missouri river in its decreed course, or to turn it up stream, as to hinder the Almighty from pouring down knowledge from heaven upon the heads of the Latter-day Saints.
40822	1549	34	Behold, there are many called, but few are chosen. And why are they not chosen?
40823	1549	35	Because their hearts are set so much upon the things of this world, and aspire to the honors of men, that they do not learn this one lesson--
40824	1549	36	That the rights of the priesthood are inseparably connected with the powers of heaven, and that the powers of heaven cannot be controlled nor handled only upon the principles of righteousness.
40825	1549	37	That they may be conferred upon us, it is true; but when we undertake to cover our sins, or to gratify our pride, our vain ambition, or to exercise control or dominion or compulsion upon the souls of the children of men, in any degree of unrighteousness, behold, the heavens withdraw themselves; the Spirit of the Lord is grieved; and when it is withdrawn, Amen to the priesthood or the authority of that man.
40826	1549	38	Behold, ere he is aware, he is left unto himself, to kick against the pricks, to persecute the saints, and to fight against God.
40827	1549	39	We have learned by sad experience that it is the nature and disposition of almost all men, as soon as they get a little authority, as they suppose, they will immediately begin to exercise unrighteous dominion.
40828	1549	40	Hence many are called, but few are chosen.
40829	1549	41	No power or influence can or ought to be maintained by virtue of the priesthood, only by persuasion, by long-suffering, by gentleness and meekness, and by love unfeigned;
40830	1549	42	By kindness, and pure knowledge, which shall greatly enlarge the soul without hypocrisy, and without guile--
40831	1549	43	Reproving betimes with sharpness, when moved upon by the Holy Ghost; and then showing forth afterwards an increase of love toward him whom thou hast reproved, lest he esteem thee to be his enemy;
40832	1549	44	That he may know that thy faithfulness is stronger than the cords of death.
40833	1549	45	Let thy bowels also be full of charity towards all men, and to the household of faith, and let virtue garnish thy thoughts unceasingly; then shall thy confidence wax strong in the presence of God; and the doctrine of the priesthood shall distil upon thy soul as the dews from heaven.
40834	1549	46	The Holy Ghost shall be thy constant companion, and thy scepter an unchanging scepter of righteousness and truth; and thy dominion shall be an everlasting dominion, and without compulsory means it shall flow unto thee forever and ever.
40835	1550	1	THE ends of the earth shall inquire after thy name, and fools shall have thee in derision, and hell shall rage against thee;
40836	1550	2	While the pure in heart, and the wise, and the noble, and the virtuous, shall seek counsel, and authority, and blessings constantly from under thy hand.
40837	1550	3	And thy people shall never be turned against thee by the testimony of traitors.
40838	1550	4	And although their influence shall cast thee into trouble, and into bars and walls, thou shalt be had in honor; and but for a small moment and thy voice shall be more terrible in the midst of thine enemies than the fierce lion, because of thy righteousness; and thy God shall stand by thee forever and ever.
40839	1550	5	If thou art called to pass through tribulation; if thou art in perils among false brethren; if thou art in perils among robbers; if thou art in perils by land or by sea;
40840	1550	6	If thou art accused with all manner of false accusations; if thine enemies fall upon thee; if they tear thee from the society of thy father and mother and brethren and sisters; and if with a drawn sword thine enemies tear thee from the bosom of thy wife, and of thine offspring, and thine elder son, although but six years of age, shall cling to thy garments, and shall say, My father, my father, why can't you stay with us? O, my father, what are the men going to do with you? and if then he shall be thrust from thee by the sword, and thou be dragged to prison, and thine enemies prowl around thee like wolves for the blood of the lamb;
40841	1550	7	And if thou shouldst be cast into the pit, or into the hands of murderers, and the sentence of death passed upon thee; if thou be cast into the deep; if the billowing surge conspire against thee; if fierce winds become thine enemy; if the heavens gather blackness, and all the elements combine to hedge up the way; and above all, if the very jaws of hell shall gape open the mouth wide after thee, know thou, my son, that all these things shall give thee experience, and shall be for thy good.
40842	1550	8	The Son of Man hath descended below them all. Art thou greater than he?
40843	1550	9	Therefore, hold on thy way, and the priesthood shall remain with thee; for their bounds are set, they cannot pass. Thy days are known, and thy years shall not be numbered less; therefore, fear not what man can do, for God shall be with you forever and ever.
40844	1551	1	AND again, we would suggest for your consideration the propriety of all the saints gathering up a knowledge of all the facts, and sufferings and abuses put upon them by the people of this State;
40845	1551	2	And also of all the property and amount of damages which they have sustained, both of character and personal injuries, as well as real property;
40846	1551	3	And also the names of all persons that have had a hand in their oppressions, as far as they can get hold of them and find them out.
40847	1551	4	And perhaps a committee can be appointed to find out these things, and to take statements and affidavits; and also to gather up the libelous publications that are afloat;
40848	1551	5	And all that are in the magazines, and in the encyclopedias, and all the libelous histories that are published, and are writing, and by whom, and present the whole concatenation of diabolical rascality and nefarious and murderous impositions that have been practised upon this people--
40849	1551	6	That we may not only publish to all the world, but present them to the heads of government in all their dark and hellish hue, as the last effort which is enjoined on us by our Heavenly Father, before we can fully and completely claim that promise which shall call him forth from his hiding place; and also that the whole nation may be left without excuse before he can send forth the power of his mighty arm.
40850	1551	7	It is an imperative duty that we owe to God, to angels, with whom we shall be brought to stand, and also to ourselves, to our wives and children, who have been made to bow down with grief, sorrow, and care, under the most damning hand of murder, tyranny, and oppression, supported and urged on and upheld by the influence of that spirit which hath so strongly riveted the creeds of the fathers, who have inherited lies, upon the hearts of the children, and filled the world with confusion, and has been growing stronger and stronger, and is now the very mainspring of all corruption, and the whole earth groans under the weight of its iniquity.
40851	1551	8	It is an iron yoke, it is a strong band; they are the very handcuffs, and chains, and shackles, and fetters of hell.
40852	1551	9	Therefore it is an imperative duty that we owe, not only to our own wives and children, but to the widows and fatherless, whose husbands and fathers have been murdered under its iron hand;
40853	1551	10	Which dark and blackening deeds are enough to make hell itself shudder, and to stand aghast and pale, and the hands of the very devil to tremble and palsy.
40854	1551	11	And also it is an imperative duty that we owe to all the rising generation, and to all the pure in heart--
40855	1551	12	For there are many yet on the earth among all sects, parties, and denominations, who are blinded by the subtle craftiness of men, whereby they lie in wait to deceive, and who are only kept from the truth because they know not where to find it--
40856	1551	13	Therefore, that we should waste and wear out our lives in bringing to light all the hidden things of darkness, wherein we know them; and they are truly manifest from heaven--
40857	1551	14	These should then be attended to with great earnestness.
40858	1551	15	Let no man count them as small things; for there is much which lieth in futurity, pertaining to the saints, which depends upon these things.
40859	1551	16	You know, brethren, that a very large ship is benefited very much by a very small helm in the time of a storm, by being kept workways with the wind and the waves.
40860	1551	17	Therefore, dearly beloved brethren, let us cheerfully do all things that lie in our power; and then may we stand still, with the utmost assurance, to see the salvation of God, and for his arm to be revealed.
40861	1552	1	VERILY, thus saith the Lord unto you, my servant Joseph Smith, I am well pleased with your offering and acknowledgments, which you have made; for unto this end have I raised you up, that I might show forth my wisdom through the weak things of the earth.
40862	1552	2	Your prayers are acceptable before me; and in answer to them I say unto you, that you are now called immediately to make a solemn proclamation of my gospel, and of this stake which I have planted to be a cornerstone of Zion, which shall be polished with the refinement which is after the similitude of a palace.
40863	1552	3	This proclamation shall be made to all the kings of the world, to the four corners thereof, to the honorable president-elect, and the high-minded governors of the nation in which you live, and to all the nations of the earth scattered abroad.
40864	1552	4	Let it be written in the spirit of meekness and by the power of the Holy Ghost, which shall be in you at the time of the writing of the same;
40865	1552	5	For it shall be given you by the Holy Ghost to know my will concerning those kings and authorities, even what shall befall them in a time to come.
40866	1552	6	For, behold, I am about to call upon them to give heed to the light and glory of Zion, for the set time has come to favor her.
40867	1552	7	Call ye, therefore, upon them with loud proclamation, and with your testimony, fearing them not, for they are as grass, and all their glory as the flower thereof which soon falleth, that they may be left also without excuse--
40868	1552	8	And that I may visit them in the day of visitation, when I shall unveil the face of my covering, to appoint the portion of the oppressor among hypocrites, where there is gnashing of teeth, if they reject my servants and my testimony which I have revealed unto them.
40869	1552	9	And again, I will visit and soften their hearts, many of them for your good, that ye may find grace in their eyes, that they may come to the light of truth, and the Gentiles to the exaltation or lifting up of Zion.
40870	1552	10	For the day of my visitation cometh speedily, in an hour when ye think not of; and where shall be the safety of my people, and refuge for those who shall be left of them?
40871	1552	11	Awake, O kings of the earth! Come ye, O, come ye, with your gold and your silver, to the help of my people, to the house of the daughters of Zion.
40872	1552	12	And again, verily I say unto you, let my servant Robert B. Thompson help you to write this proclamation, for I am well pleased with him, and that he should be with you;
40873	1552	13	Let him, therefore, hearken to your counsel, and I will bless him with a multiplicity of blessings; let him be faithful and true in all things from henceforth, and he shall be great in mine eyes;
40874	1552	14	But let him remember that his stewardship will I require at his hands.
40875	1552	15	And again, verily I say unto you, blessed is my servant Hyrum Smith; for I, the Lord, love him because of the integrity of his heart, and because he loveth that which is right before me, saith the Lord.
40876	1552	16	Again, let my servant John C. Bennett help you in your labor in sending my word to the kings and people of the earth, and stand by you, even you my servant Joseph Smith, in the hour of affliction; and his reward shall not fail if he receive counsel.
40877	1552	17	And for his love he shall be great, for he shall be mine if he do this, saith the Lord. I have seen the work which he hath done, which I accept if he continue, and will crown him with blessings and great glory.
40878	1552	18	And again, I say unto you that it is my will that my servant Lyman Wight should continue in preaching for Zion, in the spirit of meekness, confessing me before the world; and I will bear him up as on eagles' wings; and he shall beget glory and honor to himself and unto my name.
40879	1552	19	That when he shall finish his work I may receive him unto myself, even as I did my servant David Patten, who is with me at this time, and also my servant Edward Partridge, and also my aged servant Joseph Smith, Sen., who sitteth with Abraham at his right hand, and blessed and holy is he, for he is mine.
40880	1552	20	And again, verily I say unto you, my servant George Miller is without guile; he may be trusted because of the integrity of his heart; and for the love which he has to my testimony I, the Lord, love him.
40881	1552	21	I therefore say unto you, I seal upon his head the office of a bishopric, like unto my servant Edward Partridge, that he may receive the consecrations of mine house, that he may administer blessings upon the heads of the poor of my people, saith the Lord. Let no man despise my servant George, for he shall honor me.
40882	1552	22	Let my servant George, and my servant Lyman, and my servant John Snider, and others, build a house unto my name, such a one as my servant Joseph shall show unto them, upon the place which he shall show unto them also.
40883	1552	23	And it shall be for a house for boarding, a house that strangers may come from afar to lodge therein; therefore let it be a good house, worthy of all acceptation, that the weary traveler may find health and safety while he shall contemplate the word of the Lord; and the corner-stone I have appointed for Zion.
40884	1552	24	This house shall be a healthful habitation if it be built unto my name, and if the governor which shall be appointed unto it shall not suffer any pollution to come upon it. It shall be holy, or the Lord your God will not dwell therein.
40885	1552	25	And again, verily I say unto you, let all my saints come from afar.
40886	1552	26	And send ye swift messengers, yea, chosen messengers, and say unto them: Come ye, with all your gold, and your silver, and your precious stones, and with all your antiquities; and with all who have knowledge of antiquities, that will come, may come, and bring the box-tree, and the fir-tree, and the pine-tree, together with all the precious trees of the earth;
40887	1552	27	And with iron, with copper, and with brass, and with zinc, and with all your precious things of the earth; and build a house to my name, for the Most High to dwell therein.
40888	1552	28	For there is not a place found on earth that he may come to and restore again that which was lost unto you, or which he hath taken away, even the fulness of the priesthood.
40889	1552	29	For a baptismal font there is not upon the earth, that they, my saints, may be baptized for those who are dead--
40890	1552	30	For this ordinance belongeth to my house, and cannot be acceptable to me, only in the days of your poverty, wherein ye are not able to build a house unto me.
40891	1552	31	But I command you, all ye my saints, to build a house unto me; and I grant unto you a sufficient time to build a house unto me; and during this time your baptisms shall be acceptable unto me.
40892	1552	32	But behold, at the end of this appointment your baptisms for your dead shall not be acceptable unto me; and if you do not these things at the end of the appointment ye shall be rejected as a church, with your dead, saith the Lord your God.
40893	1552	33	For verily I say unto you, that after you have had sufficient time to build a house to me, wherein the ordinance of baptizing for the dead belongeth, and for which the same was instituted from before the foundation of the world, your baptisms for your dead cannot be acceptable unto me;
40894	1552	34	For therein are the keys of the holy priesthood ordained, that you may receive honor and glory.
40895	1552	35	And after this time, your baptisms for the dead, by those who are scattered abroad, are not acceptable unto me, saith the Lord.
40896	1552	36	For it is ordained that in Zion, and in her stakes, and in Jerusalem, those places which I have appointed for refuge, shall be the places for your baptisms for your dead.
40897	1552	37	And again, verily I say unto you, how shall your washings be acceptable unto me, except ye perform them in a house which you have built to my name?
40898	1552	38	For, for this cause I commanded Moses that he should build a tabernacle, that they should bear it with them in the wilderness, and to build a house in the land of promise, that those ordinances might be revealed which had been hid from before the world was.
40899	1552	39	Therefore, verily I say unto you, that your anointings, and your washings, and your baptisms for the dead, and your solemn assemblies, and your memorials for your sacrifices by the sons of Levi, and for your oracles in your most holy places wherein you receive conversations, and your statutes and judgments, for the beginning of the revelations and foundation of Zion, and for the glory, honor, and endowment of all her municipals, are ordained by the ordinance of my holy house, which my people are always commanded to build unto my holy name.
40900	1552	40	And verily I say unto you, let this house be built unto my name, that I may reveal mine ordinances therein unto my people;
40901	1552	41	For I deign to reveal unto my church things which have been kept hid from before the foundation of the world, things that pertain to the dispensation of the fulness of times.
40902	1552	42	And I will show unto my servant Joseph all things pertaining to this house, and the priesthood thereof, and the place whereon it shall be built.
40903	1552	43	And ye shall build it on the place where you have contemplated building it, for that is the spot which I have chosen for you to build it.
40904	1552	44	If ye labor with all your might, I will consecrate that spot that it shall be made holy.
40905	1552	45	And if my people will hearken unto my voice, and unto the voice of my servants whom I have appointed to lead my people, behold, verily I say unto you, they shall not be moved out of their place.
40906	1552	46	But if they will not hearken to my voice, nor unto the voice of these men whom I have appointed, they shall not be blest, because they pollute mine holy grounds, and mine holy ordinances, and charters, and my holy words which I give unto them.
40907	1552	47	And it shall come to pass that if you build a house unto my name, and do not do the things that I say, I will not perform the oath which I make unto you, neither fulfil the promises which ye expect at my hands, saith the Lord.
40908	1552	48	For instead of blessings, ye, by your own works, bring cursings, wrath, indignation, and judgments upon your own heads, by your follies, and by all your abominations, which you practise before me, saith the Lord.
40909	1552	49	Verily, verily, I say unto you, that when I give a commandment to any of the sons of men to do a work unto my name, and those sons of men go with all their might and with all they have to perform that work, and cease not their diligence, and their enemies come upon them and hinder them from performing that work, behold, it behooveth me to require that work no more at the hands of those sons of men, but to accept of their offerings.
40910	1552	50	And the iniquity and transgression of my holy laws and commandments I will visit upon the heads of those who hindered my work, unto the third and fourth generation, so long as they repent not, and hate me, saith the Lord God.
40911	1552	51	Therefore, for this cause have I accepted the offerings of those whom I commanded to build up a city and a house unto my name, in Jackson county, Missouri, and were hindered by their enemies, saith the Lord your God.
40912	1552	52	And I will answer judgment, wrath, and indignation, wailing, and anguish, and gnashing of teeth upon their heads, unto the third and fourth generation, so long as they repent not, and hate me, saith the Lord your God.
40913	1552	53	And this I make an example unto you, for your consolation concerning all those who have been commanded to do a work and have been hindered by the hands of their enemies, and by oppression, saith the Lord your God.
40914	1552	54	For I am the Lord your God, and will save all those of your brethren who have been pure in heart, and have been slain in the land of Missouri, saith the Lord.
40915	1552	55	And again, verily I say unto you, I command you again to build a house to my name, even in this place, that you may prove yourselves unto me that ye are faithful in all things whatsoever I command you, that I may bless you, and crown you with honor, immortality, and eternal life.
40916	1552	56	And now I say unto you, as pertaining to my boarding house which I have commanded you to build for the boarding of strangers, let it be built unto my name, and let my name be named upon it, and let my servant Joseph and his house have place therein, from generation to generation.
40917	1552	57	For this anointing have I put upon his head, that his blessing shall also be put upon the head of his posterity after him.
40918	1552	58	And as I said unto Abraham concerning the kindreds of the earth, even so I say unto my servant Joseph: In thee and in thy seed shall the kindred of the earth be blessed.
40919	1552	59	Therefore, let my servant Joseph and his seed after him have place in that house, from generation to generation, forever and ever, saith the Lord.
40920	1552	60	And let the name of that house be called Nauvoo House; and let it be a delightful habitation for man, and a resting-place for the weary traveler, that he may contemplate the glory of Zion, and the glory of this, the corner-stone thereof;
40921	1552	61	That he may receive also the counsel from those whom I have set to be as plants of renown, and as watchmen upon her walls.
40922	1552	62	Behold, verily I say unto you, let my servant George Miller, and my servant Lyman Wight, and my servant John Snider, and my servant Peter Haws, organize themselves, and appoint one of them to be a president over their quorum for the purpose of building that house.
40923	1552	63	And they shall form a constitution, whereby they may receive stock for the building of that house.
40924	1552	64	And they shall not receive less than fifty dollars for a share of stock in that house, and they shall be permitted to receive fifteen thousand dollars from any one man for stock in that house.
40925	1552	65	But they shall not be permitted to receive over fifteen thousand dollars stock from any one man.
40926	1552	66	And they shall not be permitted to receive under fifty dollars for a share of stock from any one man in that house.
40927	1552	67	And they shall not be permitted to receive any man, as a stockholder in this house, except the same shall pay his stock into their hands at the time he receives stock;
40928	1552	68	And in proportion to the amount of stock he pays into their hands he shall receive stock in that house; but if he pays nothing into their hands he shall not receive any stock in that house.
40929	1552	69	And if any pay stock into their hands it shall be for stock in that house, for himself, and for his generation after him, from generation to generation, so long as he and his heirs shall hold that stock, and do not sell or convey the stock away out of their hands by their own free will and act, if you will do my will, saith the Lord your God.
40930	1552	70	And again, verily I say unto you, if my servant George Miller, and my servant Lyman Wight, and my servant John Snider, and my servant Peter Haws, receive any stock into their hands, in moneys, or in properties wherein they receive the real value of moneys, they shall not appropriate any portion of that stock to any other purpose, only in that house.
40931	1552	71	And if they do appropriate any portion of that stock anywhere else, only in that house, without the consent of the stockholder, and do not repay fourfold for the stock which they appropriate anywhere else, only in that house, they shall be accursed, and shall be moved out of their place, saith the Lord God; for I, the Lord, am God, and cannot be mocked in any of these things.
40932	1552	72	Verily I say unto you, let my servant Joseph pay stock into their hands for the building of that house, as seemeth him good; but my servant Joseph cannot pay over fifteen thousand dollars stock in that house, nor under fifty dollars; neither can any other man, saith the Lord.
40933	1552	73	And there are others also who wish to know my will concerning them, for they have asked it at my hands.
40934	1552	74	Therefore, I say unto you concerning my servant Vinson Knight, if he will do my will let him put stock into that house for himself, and for his generation after him, from generation to generation.
40935	1552	75	And let him lift up his voice long and loud, in the midst of the people, to plead the cause of the poor and the needy; and let him not fail, neither let his heart faint; and I will accept of his offerings, for they shall not be unto me as the offerings of Cain, for he shall be mine, saith the Lord.
40936	1552	76	Let his family rejoice and turn away their hearts from affliction; for I have chosen him and anointed him, and he shall be honored in the midst of his house, for I will forgive all his sins, saith the Lord. Amen.
40937	1552	77	Verily I say unto you, let my servant Hyrum put stock into that house as seemeth him good, for himself and his generation after him, from generation to generation.
40938	1552	78	Let my servant Isaac Galland put stock into that house; for I, the Lord, love him for the work he hath done, and will forgive all his sins; therefore, let him be remembered for an interest in that house from generation to generation.
40939	1552	79	Let my servant Isaac Galland be appointed among you, and be ordained by my servant William Marks, and be blessed of him, to go with my servant Hyrum to accomplish the work that my servant Joseph shall point out to them, and they shall be greatly blessed.
40940	1552	80	Let my servant William Marks pay stock into that house, as seemeth him good, for himself and his generation, from generation to generation.
40941	1552	81	Let my servant Henry G. Sherwood pay stock into that house, as seemeth him good, for himself and his seed after him, from generation to generation.
40942	1552	82	Let my servant William Law pay stock into that house, for himself and his seed after him, from generation to generation.
40943	1552	83	If he will do my will let him not take his family unto the eastern lands, even unto Kirtland; nevertheless, I, the Lord, will build up Kirtland, but I, the Lord, have a scourge prepared for the inhabitants thereof.
40944	1552	84	And with my servant Almon Babbitt, there are many things with which I am not pleased; behold, he aspireth to establish his counsel instead of the counsel which I have ordained, even that of the Presidency of my Church; and he setteth up a golden calf for the worship of my people.
40945	1552	85	Let no man go from this place who has come here essaying to keep my commandments.
40946	1552	86	If they live here let them live unto me; and if they die let them die unto me; for they shall rest from all their labors here, and shall continue their works.
40947	1552	87	Therefore, let my servant William put his trust in me, and cease to fear concerning his family, because of the sickness of the land. If ye love me, keep my commandments; and the sickness of the land shall redound to your glory.
40948	1552	88	Let my servant William go and proclaim my everlasting gospel with a loud voice, and with great joy, as he shall be moved upon by my Spirit, unto the inhabitants of Warsaw, and also unto the inhabitants of Carthage, and also unto the inhabitants of Burlington, and also unto the inhabitants of Madison, and await patiently and diligently for further instructions at my general conference, saith the Lord.
40949	1552	89	If he will do my will let him from henceforth hearken to the counsel of my servant Joseph, and with his interest support the cause of the poor, and publish the new translation of my holy word unto the inhabitants of the earth.
40950	1552	90	And if he will do this I will bless him with a multiplicity of blessings, that he shall not be forsaken, nor his seed be found begging bread.
40951	1552	91	And again, verily I say unto you, let my servant William be appointed, ordained, and anointed, as counselor unto my servant Joseph, in the room of my servant Hyrum, that my servant Hyrum may take the office of Priesthood and Patriarch, which was appointed unto him by his father, by blessing and also by right;
40952	1552	92	That from henceforth he shall hold the keys of the patriarchal blessings upon the heads of all my people,
40953	1552	93	That whoever he blesses shall be blessed, and whoever he curses shall be cursed; that whatsoever he shall bind on earth shall be bound in heaven; and whatsoever he shall loose on earth shall be loosed in heaven.
40954	1552	94	And from this time forth I appoint unto him that he may be a prophet, and a seer, and a revelator unto my church, as well as my servant Joseph;
40955	1552	95	That he may act in concert also with my servant Joseph; and that he shall receive counsel from my servant Joseph, who shall show unto him the keys whereby he may ask and receive, and be crowned with the same blessing, and glory, and honor, and priesthood, and gifts of the priesthood, that once were put upon him that was my servant Oliver Cowdery;
40956	1552	96	That my servant Hyrum may bear record of the things which I shall show unto him, that his name may be had in honorable remembrance from generation to generation, forever and ever.
40957	1552	97	Let my servant William Law also receive the keys by which he may ask and receive blessings; let him be humble before me, and be without guile, and he shall receive of my Spirit, even the Comforter, which shall manifest unto him the truth of all things, and shall give him, in the very hour, what he shall say.
40958	1552	98	And these signs shall follow him--he shall heal the sick, he shall cast out devils, and shall be delivered from those who would administer unto him deadly poison;
40959	1552	99	And he shall be led in paths where the poisonous serpent cannot lay hold upon his heel, and he shall mount up in the imagination of his thoughts as upon eagles' wings.
40960	1552	100	And what if I will that he should raise the dead, let him not withhold his voice.
40961	1552	101	Therefore, let my servant William cry aloud and spare not, with joy and rejoicing, and with hosannas to him that sitteth upon the throne forever and ever, saith the Lord your God.
40962	1552	102	Behold, I say unto you, I have a mission in store for my servant William, and my servant Hyrum, and for them alone; and let my servant Joseph tarry at home, for he is needed. The remainder I will show unto you hereafter. Even so. Amen.
40963	1552	103	And again, verily I say unto you, if my servant Sidney will serve me and be counselor unto my servant Joseph, let him arise and come up and stand in the office of his calling, and humble himself before me.
40964	1552	104	And if he will offer unto me an acceptable offering, and acknowledgments, and remain with my people, behold, I, the Lord your God, will heal him that he shall be healed; and he shall lift up his voice again on the mountains, and be a spokesman before my face.
40965	1552	105	Let him come and locate his family in the neighborhood in which my servant Joseph resides.
40966	1552	106	And in all his journeyings let him lift up his voice as with the sound of a trump, and warn the inhabitants of the earth to flee the wrath to come.
40967	1552	107	Let him assist my servant Joseph, and also let my servant William Law assist my servant Joseph, in making a solemn proclamation unto the kings of the earth, even as I have before said unto you.
40968	1552	108	If my servant Sidney will do my will, let him not remove his family unto the eastern lands, but let him change their habitation, even as I have said.
40969	1552	109	Behold, it is not my will that he shall seek to find safety and refuge out of the city which I have appointed unto you, even the city of Nauvoo.
40970	1552	110	Verily I say unto you, even now, if he will hearken unto my voice, it shall be well with him. Even so. Amen.
40971	1552	111	And again, verily I say unto you, let my servant Amos Davies pay stock into the hands of those whom I have appointed to build a house for boarding, even the Nauvoo House.
40972	1552	112	This let him do if he will have an interest; and let him hearken unto the counsel of my servant Joseph, and labor with his own hands that he may obtain the confidence of men.
40973	1552	113	And when he shall prove himself faithful in all things that shall be entrusted unto his care, yea, even a few things, he shall be made ruler over many;
40974	1552	114	Let him therefore abase himself that he may be exalted. Even so. Amen.
40975	1552	115	And again, verily I say unto you, if my servant Robert D. Foster will obey my voice, let him build a house for my servant Joseph, according to the contract which he has made with him, as the door shall be open to him from time to time.
40976	1552	116	And let him repent of all his folly, and clothe himself with charity; and cease to do evil, and lay aside all his hard speeches;
40977	1552	117	And pay stock also into the hands of the quorum of the Nauvoo House, for himself and for his generation after him, from generation to generation;
40978	1552	118	And hearken unto the counsel of my servants Joseph, and Hyrum, and William Law, and unto the authorities which I have called to lay the foundation of Zion; and it shall be well with him forever and ever. Even so. Amen.
40979	1552	119	And again, verily I say unto you, let no man pay stock to the quorum of the Nauvoo House unless he shall be a believer in the Book of Mormon, and the revelations I have given unto you, saith the Lord your God;
40980	1552	120	For that which is more or less than this cometh of evil, and shall be attended with cursings and not blessings, saith the Lord your God. Even so. Amen.
40981	1552	121	And again, verily I say unto you, let the quorum of the Nauvoo House have a just recompense of wages for all their labors which they do in building the Nauvoo House; and let their wages be as shall be agreed among themselves, as pertaining to the price thereof.
40982	1552	122	And let every man who pays stock bear his proportion of their wages, if it must needs be, for their support, saith the Lord; otherwise, their labors shall be accounted unto them for stock in that house. Even so. Amen.
40983	1552	123	Verily I say unto you, I now give unto you the officers belonging to my Priesthood, that ye may hold the keys thereof, even the Priesthood which is after the order of Melchizedek, which is after the order of mine Only Begotten Son.
40984	1552	124	First, I give unto you Hyrum Smith to be a patriarch unto you, to hold the sealing blessings of my church, even the Holy Spirit of promise, whereby ye are sealed up unto the day of redemption, that ye may not fall notwithstanding the hour of temptation that may come upon you.
40985	1552	125	I give unto you my servant Joseph to be a presiding elder over all my church, to be a translator, a revelator, a seer, and prophet.
40986	1552	126	I give unto him for counselors my servant Sidney Rigdon and my servant William Law, that these may constitute a quorum and First Presidency, to receive the oracles for the whole church.
40987	1552	127	I give unto you my servant Brigham Young to be a president over the Twelve traveling council;
40988	1552	128	Which Twelve hold the keys to open up the authority of my kingdom upon the four corners of the earth, and after that to send my word to every creature.
40989	1552	129	They are Heber C. Kimball, Parley P. Pratt, Orson Pratt, Orson Hyde, William Smith, John Taylor, John E. Page, Wilford Woodruff, Willard Richards, George A. Smith;
40990	1552	130	David Patten I have taken unto myself; behold, his priesthood no man taketh from him; but, verily I say unto you, another may be appointed unto the same calling.
40991	1552	131	And again, I say unto you, I give unto you a high council, for the corner-stone of Zion--
40992	1552	132	Namely, Samuel Bent, Henry G. Sherwood, George W. Harris, Charles C. Rich, Thomas Grover, Newel Knight, David Dort, Dunbar Wilson--Seymour Brunson I have taken unto myself; no man taketh his priesthood, but another may be appointed unto the same priesthood in his stead; and verily I say unto you, let my servant Aaron Johnson be ordained unto this calling in his stead--David Fullmer, Alpheus Cutler, William Huntington.
40993	1552	133	And again, I give unto you Don C. Smith to be a president over a quorum of high priests;
40994	1552	134	Which ordinance is instituted for the purpose of qualifying those who shall be appointed standing presidents or servants over different stakes scattered abroad;
40995	1552	135	And they may travel also if they choose, but rather be ordained for standing presidents; this is the office of their calling, saith the Lord your God.
40996	1552	136	I give unto him Amasa Lyman and Noah Packard for counselors, that they may preside over the quorum of high priests of my church, saith the Lord.
40997	1552	137	And again, I say unto you, I give unto you John A. Hicks, Samuel Williams, and Jesse Baker, which priesthood is to preside over the quorum of elders, which quorum is instituted for standing ministers; nevertheless they may travel, yet they are ordained to be standing ministers to my church, saith the Lord.
40998	1552	138	And again, I give unto you Joseph Young, Josiah Butterfield, Daniel Miles, Henry Herriman, Zera Pulsipher, Levi Hancock, James Foster, to preside over the quorum of seventies;
40999	1552	139	Which quorum is instituted for traveling elders to bear record of my name in all the world, wherever the traveling high council, mine apostles, shall send them to prepare a way before my face.
41000	1552	140	The difference between this quorum and the quorum of elders is that one is to travel continually, and the other is to preside over the churches from time to time; the one has the responsibility of presiding from time to time, and the other has no responsibility of presiding, saith the Lord your God.
41001	1552	141	And again, I say unto you, I give unto you Vinson Knight, Samuel H. Smith, and Shadrach Roundy, if he will receive it, to preside over the bishopric; a knowledge of said bishopric is given unto you in the book of Doctrine and Covenants.
41002	1552	142	And again, I say unto you, Samuel Rolfe and his counselors for priests, and the president of the teachers and his counselors, and also the president of the deacons and his counselors, and also the president of the stake and his counselors.
41003	1552	143	The above offices I have given unto you, and the keys thereof, for helps and for governments, for the work of the ministry and the perfecting of my saints.
41004	1552	144	And a commandment I give unto you, that you should fill all these offices and approve of those names which I have mentioned, or else disapprove of them at my general conference;
41005	1552	145	And that ye should prepare rooms for all these offices in my house when you build it unto my name, saith the Lord your God. Even so. Amen.
41006	1553	1	WHAT is the will of the Lord concerning the saints in the Territory of Iowa?
41007	1553	2	Verily, thus saith the Lord, I say unto you, if those who call themselves by my name and are essaying to be my saints, if they will do my will and keep my commandments concerning them, let them gather themselves together unto the places which I shall appoint unto them by my servant Joseph, and build up cities unto my name, that they may be prepared for that which is in store for a time to come.
41008	1553	3	Let them build up a city unto my name upon the land opposite the city of Nauvoo, and let the name of Zarahemla be named upon it.
41009	1553	4	And let all those who come from the east, and the west, and the north, and the south, that have desires to dwell therein, take up their inheritance in the same, as well as in the city of Nashville, or in the city of Nauvoo, and in all the stakes which I have appointed, saith the Lord.
41010	1554	1	DEAR and well-beloved brother, Brigham Young, verily thus saith the Lord unto you: My servant Brigham, it is no more required at your hand to leave your family as in times past, for your offering is acceptable to me.
41011	1554	2	I have seen your labor and toil in journeyings for my name.
41012	1554	3	I therefore command you to send my word abroad, and take especial care of your family from this time, henceforth and forever. Amen.
41013	1555	1	FORASMUCH as the Lord has revealed unto me that my enemies, both in Missouri and this State, were again in the pursuit of me; and inasmuch as they pursue me without a cause, and have not the least shadow or coloring of justice or right on their side in the getting up of their prosecutions against me; and inasmuch as their pretensions are all founded in falsehood of the blackest dye, I have thought it expedient and wisdom in me to leave the place for a short season, for my own safety and the safety of this people. I would say to all those with whom I have business, that I have left my affairs with agents and clerks who will transact all business in a prompt and proper manner, and will see that all my debts are canceled in due time, by turning out property, or otherwise, as the case may require, or as the circumstances may admit of. When I learn that the storm is fully blown over, then I will return to you again.
41014	1555	2	And as for the perils which I am called to pass through, they seem but a small thing to me, as the envy and wrath of man have been my common lot all the days of my life; and for what cause it seems mysterious, unless I was ordained from before the foundation of the world for some good end, or bad, as you may choose to call it. Judge ye for yourselves. God knoweth all these things, whether it be good or bad. But nevertheless, deep water is what I am wont to swim in. It all has become a second nature to me; and I feel, like Paul, to glory in tribulation; for to this day has the God of my fathers delivered me out of them all, and will deliver me from henceforth; for behold, and lo, I shall triumph over all my enemies, for the Lord God hath spoken it.
41015	1555	3	Let all the saints rejoice, therefore, and be exceedingly glad; for Israel's God is their God, and he will mete out a just recompense of reward upon the heads of all their oppressors.
41016	1555	4	And again, verily thus saith the Lord: Let the work of my temple, and all the works which I have appointed unto you, be continued on and not cease; and let your diligence, and your perseverance, and patience, and your works be redoubled, and you shall in nowise lose your reward, saith the Lord of Hosts. And if they persecute you, so persecuted they the prophets and righteous men that were before you. For all this there is a reward in heaven.
41017	1555	5	And again, I give unto you a word in relation to the baptism for your dead.
41018	1555	6	Verily, thus saith the Lord unto you concerning your dead: When any of you are baptized for your dead, let there be a recorder, and let him be eye-witness of your baptisms; let him hear with his ears, that he may testify of a truth, saith the Lord;
41019	1555	7	That in all your recordings it may be recorded in heaven; whatsoever you bind on earth, may be bound in heaven; whatsoever you loose on earth, may be loosed in heaven;
41020	1555	8	For I am about to restore many things to the earth, pertaining to the priesthood, saith the Lord of Hosts.
41021	1555	9	And again, let all the records be had in order, that they may be put in the archives of my holy temple, to be held in remembrance from generation to generation, saith the Lord of Hosts.
41022	1555	10	I will say to all the saints, that I desired, with exceedingly great desire, to have addressed them from the stand on the subject of baptism for the dead, on the following Sabbath. But inasmuch as it is out of my power to do so, I will write the word of the Lord from time to time, on that subject, and send it to you by mail, as well as many other things.
41023	1555	11	I now close my letter for the present, for the want of more time; for the enemy is on the alert, and as the Savior said, the prince of this world cometh, but he hath nothing in me.
41024	1555	12	Behold, my prayer to God is that you all may be saved. And I subscribe myself your servant in the Lord, prophet and seer of the Church of Jesus Christ of Latter-day Saints.
41025	1556	1	AS I stated to you in my letter before I left my place, that I would write to you from time to time and give you information in relation to many subjects, I now resume the subject of the baptism for the dead, as that subject seems to occupy my mind, and press itself upon my feelings the strongest, since I have been pursued by my enemies.
41026	1556	2	I wrote a few words of revelation to you concerning a recorder. I have had a few additional views in relation to this matter, which I now certify. That is, it was declared in my former letter that there should be a recorder, who should be eye-witness, and also to hear with his ears, that he might make a record of a truth before the Lord.
41027	1556	3	Now, in relation to this matter, it would be very difficult for one recorder to be present at all times, and to do all the business. To obviate this difficulty, there can be a recorder appointed in each ward of the city, who is well qualified for taking accurate minutes; and let him be very particular and precise in taking the whole proceedings, certifying in his record that he saw with his eyes, and heard with his ears, giving the date, and names, and so forth, and the history of the whole transaction; naming also some three individuals that are present, if there be any present, who can at any time when called upon certify to the same, that in the mouth of two or three witnesses every word may be established.
41028	1556	4	Then, let there be a general recorder, to whom these other records can be handed, being attended with certificates over their own signatures, certifying that the record they have made is true. Then the general church recorder can enter the record on the general church book, with the certificates and all the attending witnesses, with his own statement that he verily believes the above statement and records to be true, from his knowledge of the general character and appointment of those men by the church. And when this is done on the general church book, the record shall be just as holy, and shall answer the ordinance just the same as if he had seen with his eyes and heard with his ears, and made a record of the same on the general church book.
41029	1556	5	You may think this order of things to be very particular; but let me tell you that it is only to answer the will of God, by conforming to the ordinance and preparation that the Lord ordained and prepared before the foundation of the world, for the salvation of the dead who should die without a knowledge of the gospel.
41030	1556	6	And further, I want you to remember that John the Revelator was contemplating this very subject in relation to the dead, when he declared, as you will find recorded in Revelation 20: 12--And I saw the dead, small and great, stand before God; and the books were opened; and another book was opened, which is the book of life; and the dead were judged out of those things which were written in the books, according to their works.
41031	1556	7	You will discover in this quotation that the books were opened; and another book was opened, which was the book of life; but the dead were judged out of those things which were written in the books, according to their works; consequently, the books spoken of must be the books which contained the record of their works, and refer to the records which are kept on the earth. And the book which was the book of life is the record which is kept in heaven; the principle agreeing precisely with the doctrine which is commanded you in the revelation contained in the letter which I wrote to you previous to my leaving my place--that in all your recordings it may be recorded in heaven.
41032	1556	8	Now, the nature of this ordinance consists in the power of the priesthood, by the revelation of Jesus Christ, wherein it is granted that whatsoever you bind on earth shall be bound in heaven, and whatsoever you loose on earth shall be loosed in heaven. Or, in other words, taking a different view of the translation, whatsoever you record on earth shall be recorded in heaven, and whatsoever you do not record on earth shall not be recorded in heaven; for out of the books shall your dead be judged, according to their own works, whether they themselves have attended to the ordinances in their own propria persona, or by the means of their own agents, according to the ordinance which God has prepared for their salvation from before the foundation of the world, according to the records which they have kept concerning their dead.
41033	1556	9	It may seem to some to be a very bold doctrine that we talk of--a power which records or binds on earth and binds in heaven. Nevertheless, in all ages of the world, whenever the Lord has given a dispensation of the priesthood to any man by actual revelation, or any set of men, this power has always been given. Hence, whatsoever those men did in authority, in the name of the Lord, and did it truly and faithfully, and kept a proper and faithful record of the same, it became a law on earth and in heaven, and could not be annulled, according to the decrees of the great Jehovah. This is a faithful saying. Who can hear it?
41034	1556	10	And again, for the precedent, Matthew 16: 18, 19: And I say also unto thee, That thou art Peter, and upon this rock I will build my church; and the gates of hell shall not prevail against it. And I will give unto thee the keys of the kingdom of heaven: and whatsoever thou shalt bind on earth shall be bound in heaven; and whatsoever thou shalt loose on earth shall be loosed in heaven.
41035	1556	11	Now the great and grand secret of the whole matter, and the summum bonum of the whole subject that is lying before us, consists in obtaining the powers of the Holy Priesthood. For him to whom these keys are given there is no difficulty in obtaining a knowledge of facts in relation to the salvation of the children of men, both as well for the dead as for the living.
41036	1556	12	Herein is glory and honor, and immortality and eternal life--The ordinance of baptism by water, to be immersed therein in order to answer to the likeness of the dead, that one principle might accord with the other; to be immersed in the water and come forth out of the water is in the likeness of the resurrection of the dead in coming forth out of their graves; hence, this ordinance was instituted to form a relationship with the ordinance of baptism for the dead, being in likeness of the dead.
41037	1556	13	Consequently, the baptismal font was instituted as a similitude of the grave, and was commanded to be in a place underneath where the living are wont to assemble, to show forth the living and the dead, and that all things may have their likeness, and that they may accord one with another--that which is earthly conforming to that which is heavenly, as Paul hath declared, 1 Corinthians 15: 46, 47, and 48:
41038	1556	14	Howbeit that was not first which is spiritual, but that which is natural; and afterward that which is spiritual. The first man is of the earth, earthy; the second man is the Lord from heaven. As is the earthy, such are they also that are earthy; and as is the heavenly, such are they also that are heavenly. And as are the records on the earth in relation to your dead, which are truly made out, so also are the records in heaven. This, therefore, is the sealing and binding power, and, in one sense of the word, the keys of the kingdom, which consist in the key of knowledge.
41039	1556	15	And now, my dearly beloved brethren and sisters, let me assure you that these are principles in relation to the dead and the living that cannot be lightly passed over, as pertaining to our salvation. For their salvation is necessary and essential to our salvation, as Paul says concerning the fathers--that they without us cannot be made perfect--neither can we without our dead be made perfect.
41040	1556	16	And now, in relation to the baptism for the dead, I will give you another quotation of Paul, 1 Corinthians 15: 29: Else what shall they do which are baptized for the dead, if the dead rise not at all? Why are they then baptized for the dead?
41041	1556	17	And again, in connection with this quotation I will give you a quotation from one of the prophets, who had his eye fixed on the restoration of the priesthood, the glories to be revealed in the last days, and in an especial manner this most glorious of all subjects belonging to the everlasting gospel, namely, the baptism for the dead; for Malachi says, last chapter, verses 5th and 6th: Behold, I will send you Elijah the prophet before the coming of the great and dreadful day of the Lord: And he shall turn the heart of the fathers to the children, and the heart of the children to their fathers, lest I come and smite the earth with a curse.
41042	1556	18	I might have rendered a plainer translation to this, but it is sufficiently plain to suit my purpose as it stands. It is sufficient to know, in this case, that the earth will be smitten with a curse unless there is a welding link of some kind or other between the fathers and the children, upon some subject or other--and behold what is that subject? It is the baptism for the dead. For we without them cannot be made perfect; neither can they without us be made perfect. Neither can they nor we be made perfect without those who have died in the gospel also; for it is necessary in the ushering in of the dispensation of the fulness of times, which dispensation is now beginning to usher in, that a whole and complete and perfect union, and welding together of dispensations, and keys, and powers, and glories should take place, and be revealed from the days of Adam even to the present time. And not only this, but those things which never have been revealed from the foundation of the world, but have been kept hid from the wise and prudent, shall be revealed unto babes and sucklings in this, the dispensation of the fulness of times.
41043	1556	19	Now, what do we hear in the gospel which we have received? A voice of gladness! A voice of mercy from heaven; and a voice of truth out of the earth; glad tidings for the dead; a voice of gladness for the living and the dead; glad tidings of great joy. How beautiful upon the mountains are the feet of those that bring glad tidings of good things, and that say unto Zion: Behold, thy God reigneth! As the dews of Carmel, so shall the knowledge of God descend upon them!
41044	1556	20	And again, what do we hear? Glad tidings from Cumorah! Moroni, an angel from heaven, declaring the fulfilment of the prophets--the book to be revealed. A voice of the Lord in the wilderness of Fayette, Seneca county, declaring the three witnesses to bear record of the book! The voice of Michael on the banks of the Susquehanna, detecting the devil when he appeared as an angel of light! The voice of Peter, James, and John in the wilderness between Harmony, Susquehanna county, and Colesville, Broome county, on the Susquehanna river, declaring themselves as possessing the keys of the kingdom, and of the dispensation of the fulness of times!
41045	1556	21	And again, the voice of God in the chamber of old Father Whitmer, in Fayette, Seneca county, and at sundry times, and in divers places through all the travels and tribulations of this Church of Jesus Christ of Latter-day Saints! And the voice of Michael, the archangel; the voice of Gabriel, and of Raphael, and of divers angels, from Michael or Adam down to the present time, all declaring their dispensation, their rights, their keys, their honors, their majesty and glory, and the power of their priesthood; giving line upon line, precept upon precept; here a little, and there a little; giving us consolation by holding forth that which is to come, confirming our hope!
41046	1556	22	Brethren, shall we not go on in so great a cause? Go forward and not backward. Courage, brethren; and on, on to the victory! Let your hearts rejoice, and be exceedingly glad. Let the earth break forth into singing. Let the dead speak forth anthems of eternal praise to the King Immanuel, who hath ordained, before the world was, that which would enable us to redeem them out of their prison; for the prisoners shall go free.
41047	1556	23	Let the mountains shout for joy, and all ye valleys cry aloud; and all ye seas and dry lands tell the wonders of your Eternal King! And ye rivers, and brooks, and rills, flow down with gladness. Let the woods and all the trees of the field praise the Lord; and ye solid rocks weep for joy! And let the sun, moon, and the morning stars sing together, and let all the sons of God shout for joy! And let the eternal creations declare his name forever and ever! And again I say, how glorious is the voice we hear from heaven, proclaiming in our ears, glory, and salvation, and honor, and immortality, and eternal life; kingdoms, principalities, and powers!
41048	1556	24	Behold, the great day of the Lord is at hand; and who can abide the day of his coming, and who can stand when he appeareth? For he is like a refiner's fire, and like fuller's soap; and he shall sit as a refiner and purifier of silver, and he shall purify the sons of Levi, and purge them as gold and silver, that they may offer unto the Lord an offering in righteousness. Let us, therefore, as a church and a people, and as Latter-day Saints, offer unto the Lord an offering in righteousness; and let us present in his holy temple, when it is finished, a book containing the records of our dead, which shall be worthy of all acceptation.
41049	1556	25	Brethren, I have many things to say to you on the subject; but shall now close for the present, and continue the subject another time. I am, as ever, your humble servant and never deviating friend,
41050	1557	1	THERE are two kinds of beings in heaven, namely: Angels, who are resurrected personages, having bodies of flesh and bones--
41051	1557	2	For instance, Jesus said: Handle me and see, for a spirit hath not flesh and bones, as ye see me have.
41052	1557	3	Secondly: the spirits of just men made perfect, they who are not resurrected, but inherit the same glory.
41053	1557	4	When a messenger comes saying he has a message from God, offer him your hand and request him to shake hands with you.
41054	1557	5	If he be an angel he will do so, and you will feel his hand.
41055	1557	6	If he be the spirit of a just man made perfect he will come in his glory; for that is the only way he can appear--
41056	1557	7	Ask him to shake hands with you, but he will not move, because it is contrary to the order of heaven for a just man to deceive; but he will still deliver his message.
41057	1557	8	If it be the devil as an angel of light, when you ask him to shake hands he will offer you his hand, and you will not feel anything; you may therefore detect him.
41058	1557	9	These are three grand keys whereby you may know whether any administration is from God.
41059	1558	1	WHEN the Savior shall appear we shall see him as he is. We shall see that he is a man like ourselves.
41060	1558	2	And that same sociality which exists among us here will exist among us there, only it will be coupled with eternal glory, which glory we do not now enjoy.
41061	1558	3	John 14: 23--The appearing of the Father and the Son, in that verse, is a personal appearance; and the idea that the Father and the Son dwell in a man's heart is an old sectarian notion, and is false.
41062	1558	4	In answer to the question--Is not the reckoning of God's time, angel's time, prophet's time, and man's time, according to the planet on which they reside?
41063	1558	5	I answer, Yes. But there are no angels who minister to this earth but those who do belong or have belonged to it.
41064	1558	6	The angels do not reside on a planet like this earth;
41065	1558	7	But they reside in the presence of God, on a globe like a sea of glass and fire, where all things for their glory are manifest, past, present, and future, and are continually before the Lord.
41066	1558	8	The place where God resides is a great Urim and Thummim.
41067	1558	9	This earth, in its sanctified and immortal state, will be made like unto crystal and will be a Urim and Thummim to the inhabitants who dwell thereon, whereby all things pertaining to an inferior kingdom, or all kingdoms of a lower order, will be manifest to those who dwell on it; and this earth will be Christ's.
41068	1558	10	Then the white stone mentioned in Revelation 2: 17, will become a Urim and Thummim to each individual who receives one, whereby things pertaining to a higher order of kingdoms will be made known;
41069	1558	11	And a white stone is given to each of those who come into the celestial kingdom, whereon is a new name written, which no man knoweth save he that receiveth it. The new name is the key word.
41070	1558	12	I prophesy, in the name of the Lord God, that the commencement of the difficulties which will cause much bloodshed previous to the coming of the Son of Man will be in South Carolina.
41071	1558	13	It may probably arise through the slave question. This a voice declared to me, while I was praying earnestly on the subject, December 25th, 1832.
41072	1558	14	I was once praying very earnestly to know the time of the coming of the Son of Man, when I heard a voice repeat the following:
41073	1558	15	Joseph, my son, if thou livest until thou art eighty-five years old, thou shalt see the face of the Son of Man; therefore let this suffice, and trouble me no more on this matter.
41074	1558	16	I was left thus, without being able to decide whether this coming referred to the beginning of the millennium or to some previous appearing, or whether I should die and thus see his face.
41075	1558	17	I believe the coming of the Son of Man will not be any sooner than that time.
41076	1558	18	Whatever principle of intelligence we attain unto in this life, it will rise with us in the resurrection.
41077	1558	19	And if a person gains more knowledge and intelligence in this life through his diligence and obedience than another, he will have so much the advantage in the world to come.
41078	1558	20	There is a law, irrevocably decreed in heaven before the foundations of this world, upon which all blessings are predicated--
41079	1558	21	And when we obtain any blessing from God, it is by obedience to that law upon which it is predicated.
41080	1558	22	The Father has a body of flesh and bones as tangible as man's; the Son also; but the Holy Ghost has not a body of flesh and bones, but is a personage of Spirit. Were it not so, the Holy Ghost could not dwell in us.
41081	1558	23	A man may receive the Holy Ghost, and it may descend upon him and not tarry with him.
41082	1559	1	IN the celestial glory there are three heavens or degrees;
41083	1559	2	And in order to obtain the highest, a man must enter into this order of the priesthood [meaning the new and everlasting covenant of marriage];
41084	1559	3	And if he does not, he cannot obtain it.
41085	1559	4	He may enter into the other, but that is the end of his kingdom; he cannot have an increase.
41086	1559	5	(May 17th, 1843.) The more sure word of prophecy means a man's knowing that he is sealed up unto eternal life, by revelation and the spirit of prophecy, through the power of the Holy Priesthood.
41087	1559	6	It is impossible for a man to be saved in ignorance.
41088	1559	7	There is no such thing as immaterial matter. All spirit is matter, but it is more fine or pure, and can only be discerned by purer eyes;
41089	1559	8	We cannot see it; but when our bodies are purified we shall see that it is all matter.
41090	1560	1	VERILY, thus saith the Lord unto you my servant Joseph, that inasmuch as you have inquired of my hand to know and understand wherein I, the Lord, justified my servants Abraham, Isaac, and Jacob, as also Moses, David and Solomon, my servants, as touching the principle and doctrine of their having many wives and concubines--
41091	1560	2	Behold, and lo, I am the Lord thy God, and will answer thee as touching this matter.
41092	1560	3	Therefore, prepare thy heart to receive and obey the instructions which I am about to give unto you; for all those who have this law revealed unto them must obey the same.
41093	1560	4	For behold, I reveal unto you a new and an everlasting covenant; and if ye abide not that covenant, then are ye damned; for no one can reject this covenant and be permitted to enter into my glory.
41094	1560	5	For all who will have a blessing at my hands shall abide the law which was appointed for that blessing, and the conditions thereof, as were instituted from before the foundation of the world.
41095	1560	6	And as pertaining to the new and everlasting covenant, it was instituted for the fulness of my glory; and he that receiveth a fulness thereof must and shall abide the law, or he shall be damned, saith the Lord God.
41096	1560	7	And verily I say unto you, that the conditions of this law are these: All covenants, contracts, bonds, obligations, oaths, vows, performances, connections, associations, or expectations, that are not made and entered into and sealed by the Holy Spirit of promise, of him who is anointed, both as well for time and for all eternity, and that too most holy, by revelation and commandment through the medium of mine anointed, whom I have appointed on the earth to hold this power (and I have appointed unto my servant Joseph to hold this power in the last days, and there is never but one on the earth at a time on whom this power and the keys of this priesthood are conferred), are of no efficacy, virtue, or force in and after the resurrection from the dead; for all contracts that are not made unto this end have an end when men are dead.
41097	1560	8	Behold, mine house is a house of order, saith the Lord God, and not a house of confusion.
41098	1560	9	Will I accept of an offering, saith the Lord, that is not made in my name?
41099	1560	10	Or will I receive at your hands that which I have not appointed?
41100	1560	11	And will I appoint unto you, saith the Lord, except it be by law, even as I and my Father ordained unto you, before the world was?
41101	1560	12	I am the Lord thy God; and I give unto you this commandment--that no man shall come unto the Father but by me or by my word, which is my law, saith the Lord.
41102	1560	13	And everything that is in the world, whether it be ordained of men, by thrones, or principalities, or powers, or things of name, whatsoever they may be, that are not by me or by my word, saith the Lord, shall be thrown down, and shall not remain after men are dead, neither in nor after the resurrection, saith the Lord your God.
41103	1560	14	For whatsoever things remain are by me; and whatsoever things are not by me shall be shaken and destroyed.
41104	1560	15	Therefore, if a man marry him a wife in the world, and he marry her not by me nor by my word, and he covenant with her so long as he is in the world and she with him, their covenant and marriage are not of force when they are dead, and when they are out of the world; therefore, they are not bound by any law when they are out of the world.
41105	1560	16	Therefore, when they are out of the world they neither marry nor are given in marriage; but are appointed angels in heaven, which angels are ministering servants, to minister for those who are worthy of a far more, and an exceeding, and an eternal weight of glory.
41106	1560	17	For these angels did not abide my law; therefore, they cannot be enlarged, but remain separately and singly, without exaltation, in their saved condition, to all eternity; and from henceforth are not gods, but are angels of God forever and ever.
41107	1560	18	And again, verily I say unto you, if a man marry a wife, and make a covenant with her for time and for all eternity, if that covenant is not by me or by my word, which is my law, and is not sealed by the Holy Spirit of promise, through him whom I have anointed and appointed unto this power, then it is not valid neither of force when they are out of the world, because they are not joined by me, saith the Lord, neither by my word; when they are out of the world it cannot be received there, because the angels and the gods are appointed there, by whom they cannot pass; they cannot, therefore, inherit my glory; for my house is a house of order, saith the Lord God.
41108	1560	19	And again, verily I say unto you, if a man marry a wife by my word, which is my law, and by the new and everlasting covenant, and it is sealed unto them by the Holy Spirit of promise, by him who is anointed, unto whom I have appointed this power and the keys of this priesthood; and it shall be said unto them--Ye shall come forth in the first resurrection; and if it be after the first resurrection, in the next resurrection; and shall inherit thrones, kingdoms, principalities, and powers, dominions, all heights and depths--then shall it be written in the Lamb's Book of Life, that he shall commit no murder whereby to shed innocent blood, and if ye abide in my covenant, and commit no murder whereby to shed innocent blood, it shall be done unto them in all things whatsoever my servant hath put upon them, in time, and through all eternity; and shall be of full force when they are out of the world; and they shall pass by the angels, and the gods, which are set there, to their exaltation and glory in all things, as hath been sealed upon their heads, which glory shall be a fulness and a continuation of the seeds forever and ever.
41109	1560	20	Then shall they be gods, because they have no end; therefore shall they be from everlasting to everlasting, because they continue; then shall they be above all, because all things are subject unto them. Then shall they be gods, because they have all power, and the angels are subject unto them.
41110	1560	21	Verily, verily, I say unto you, except ye abide my law ye cannot attain to this glory.
41111	1560	22	For strait is the gate, and narrow the way that leadeth unto the exaltation and continuation of the lives, and few there be that find it, because ye receive me not in the world neither do ye know me.
41112	1560	23	But if ye receive me in the world, then shall ye know me, and shall receive your exaltation; that where I am ye shall be also.
41113	1560	24	This is eternal lives--to know the only wise and true God, and Jesus Christ, whom he hath sent. I am he. Receive ye, therefore, my law.
41114	1560	25	Broad is the gate, and wide the way that leadeth to the deaths; and many there are that go in thereat, because they receive me not, neither do they abide in my law.
41115	1560	26	Verily, verily, I say unto you, if a man marry a wife according to my word, and they are sealed by the Holy Spirit of promise, according to mine appointment, and he or she shall commit any sin or transgression of the new and everlasting covenant whatever, and all manner of blasphemies, and if they commit no murder wherein they shed innocent blood, yet they shall come forth in the first resurrection, and enter into their exaltation; but they shall be destroyed in the flesh, and shall be delivered unto the buffetings of Satan unto the day of redemption, saith the Lord God.
41116	1560	27	The blasphemy against the Holy Ghost, which shall not be forgiven in the world nor out of the world, is in that ye commit murder wherein ye shed innocent blood, and assent unto my death, after ye have received my new and everlasting covenant, saith the Lord God; and he that abideth not this law can in nowise enter into my glory, but shall be damned, saith the Lord.
41117	1560	28	I am the Lord thy God, and will give unto thee the law of my Holy Priesthood, as was ordained by me and my Father before the world was.
41118	1560	29	Abraham received all things, whatsoever he received, by revelation and commandment, by my word, saith the Lord, and hath entered into his exaltation and sitteth upon his throne.
41119	1560	30	Abraham received promises concerning his seed, and of the fruit of his loins--from whose loins ye are, namely, my servant Joseph--which were to continue so long as they were in the world; and as touching Abraham and his seed, out of the world they should continue; both in the world and out of the world should they continue as innumerable as the stars; or, if ye were to count the sand upon the seashore ye could not number them.
41120	1560	31	This promise is yours also, because ye are of Abraham, and the promise was made unto Abraham; and by this law is the continuation of the works of my Father, wherein he glorifieth himself.
41121	1560	32	Go ye, therefore, and do the works of Abraham; enter ye into my law and ye shall be saved.
41122	1560	33	But if ye enter not into my law ye cannot receive the promise of my Father, which he made unto Abraham.
41123	1560	34	God commanded Abraham, and Sarah gave Hagar to Abraham to wife. And why did she do it? Because this was the law; and from Hagar sprang many people. This, therefore, was fulfilling, among other things, the promises.
41124	1560	35	Was Abraham, therefore, under condemnation? Verily I say unto you, Nay; for I, the Lord, commanded it.
41125	1560	36	Abraham was commanded to offer his son Isaac; nevertheless, it was written: Thou shalt not kill. Abraham, however, did not refuse, and it was accounted unto him for righteousness.
41126	1560	37	Abraham received concubines, and they bore him children; and it was accounted unto him for righteousness, because they were given unto him, and he abode in my law; as Isaac also and Jacob did none other things than that which they were commanded; and because they did none other things than that which they were commanded, they have entered into their exaltation, according to the promises, and sit upon thrones, and are not angels but are gods.
41127	1560	38	David also received many wives and concubines, and also Solomon and Moses my servants, as also many others of my servants, from the beginning of creation until this time; and in nothing did they sin save in those things which they received not of me.
41128	1560	39	David's wives and concubines were given unto him of me, by the hand of Nathan, my servant, and others of the prophets who had the keys of this power; and in none of these things did he sin against me save in the case of Uriah and his wife; and, therefore he hath fallen from his exaltation, and received his portion; and he shall not inherit them out of the world, for I gave them unto another, saith the Lord.
41129	1560	40	I am the Lord thy God, and I gave unto thee, my servant Joseph, an appointment, and restore all things. Ask what ye will, and it shall be given unto you according to my word.
41130	1560	41	And as ye have asked concerning adultery, verily, verily, I say unto you, if a man receiveth a wife in the new and everlasting covenant, and if she be with another man, and I have not appointed unto her by the holy anointing, she hath committed adultery and shall be destroyed.
41131	1560	42	If she be not in the new and everlasting covenant, and she be with another man, she has committed adultery.
41132	1560	43	And if her husband be with another woman, and he was under a vow, he hath broken his vow and hath committed adultery.
41133	1560	44	And if she hath not committed adultery, but is innocent and hath not broken her vow, and she knoweth it, and I reveal it unto you, my servant Joseph, then shall you have power, by the power of my Holy Priesthood, to take her and give her unto him that hath not committed adultery but hath been faithful; for he shall be made ruler over many.
41134	1560	45	For I have conferred upon you the keys and power of the priesthood, wherein I restore all things, and make known unto you all things in due time.
41135	1560	46	And verily, verily, I say unto you, that whatsoever you seal on earth shall be sealed in heaven; and whatsoever you bind on earth, in my name and by my word, saith the Lord, it shall be eternally bound in the heavens; and whosesoever sins you remit on earth shall be remitted eternally in the heavens; and whosesoever sins you retain on earth shall be retained in heaven.
41136	1560	47	And again, verily I say, whomsoever you bless I will bless, and whomsoever you curse I will curse, saith the Lord; for I, the Lord, am thy God.
41137	1560	48	And again, verily I say unto you, my servant Joseph, that whatsoever you give on earth, and to whomsoever you give any one on earth, by my word and according to my law, it shall be visited with blessings and not cursings, and with my power, saith the Lord, and shall be without condemnation on earth and in heaven.
41138	1560	49	For I am the Lord thy God, and will be with thee even unto the end of the world, and through all eternity; for verily I seal upon you your exaltation, and prepare a throne for you in the kingdom of my Father, with Abraham your father.
41139	1560	50	Behold, I have seen your sacrifices, and will forgive all your sins; I have seen your sacrifices in obedience to that which I have told you. Go, therefore, and I make a way for your escape, as I accepted the offering of Abraham of his son Isaac.
41140	1560	51	Verily, I say unto you: A commandment I give unto mine handmaid, Emma Smith, your wife, whom I have given unto you, that she stay herself and partake not of that which I commanded you to offer unto her; for I did it, saith the Lord, to prove you all, as I did Abraham, and that I might require an offering at your hand, by covenant and sacrifice.
41141	1560	52	And let mine handmaid, Emma Smith, receive all those that have been given unto my servant Joseph, and who are virtuous and pure before me; and those who are not pure, and have said they were pure, shall be destroyed, saith the Lord God.
41142	1560	53	For I am the Lord thy God, and ye shall obey my voice; and I give unto my servant Joseph that he shall be made ruler over many things; for he hath been faithful over a few things, and from henceforth I will strengthen him.
41143	1560	54	And I command mine handmaid, Emma Smith, to abide and cleave unto my servant Joseph, and to none else. But if she will not abide this commandment she shall be destroyed, saith the Lord; for I am the Lord thy God, and will destroy her if she abide not in my law.
41144	1560	55	But if she will not abide this commandment, then shall my servant Joseph do all things for her, even as he hath said; and I will bless him and multiply him and give unto him an hundredfold in this world, of fathers and mothers, brothers and sisters, houses and lands, wives and children, and crowns of eternal lives in the eternal worlds.
41145	1560	56	And again, verily I say, let mine handmaid forgive my servant Joseph his trespasses; and then shall she be forgiven her trespasses, wherein she has trespassed against me; and I, the Lord thy God, will bless her, and multiply her, and make her heart to rejoice.
41146	1560	57	And again, I say, let not my servant Joseph put his property out of his hands, lest an enemy come and destroy him; for Satan seeketh to destroy; for I am the Lord thy God, and he is my servant; and behold, and lo, I am with him, as I was with Abraham, thy father, even unto his exaltation and glory.
41147	1560	58	Now, as touching the law of the priesthood, there are many things pertaining thereunto.
41148	1560	59	Verily, if a man be called of my Father, as was Aaron, by mine own voice, and by the voice of him that sent me, and I have endowed him with the keys of the power of this priesthood, if he do anything in my name, and according to my law and by my word, he will not commit sin, and I will justify him.
41149	1560	60	Let no one, therefore, set on my servant Joseph; for I will justify him; for he shall do the sacrifice which I require at his hands for his transgressions, saith the Lord your God.
41150	1560	61	And again, as pertaining to the law of the priesthood--if any man espouse a virgin, and desire to espouse another, and the first give her consent, and if he espouse the second, and they are virgins, and have vowed to no other man, then is he justified; he cannot commit adultery for they are given unto him; for he cannot commit adultery with that that belongeth unto him and to no one else.
41151	1560	62	And if he have ten virgins given unto him by this law, he cannot commit adultery, for they belong to him, and they are given unto him; therefore is he justified.
41152	1560	63	But if one or either of the ten virgins, after she is espoused, shall be with another man, she has committed adultery, and shall be destroyed; for they are given unto him to multiply and replenish the earth, according to my commandment, and to fulfil the promise which was given by my Father before the foundation of the world, and for their exaltation in the eternal worlds, that they may bear the souls of men; for herein is the work of my Father continued, that he may be glorified.
41153	1560	64	And again, verily, verily, I say unto you, if any man have a wife, who holds the keys of this power, and he teaches unto her the law of my priesthood, as pertaining to these things, then shall she believe and administer unto him, or she shall be destroyed, saith the Lord your God; for I will destroy her; for I will magnify my name upon all those who receive and abide in my law.
41154	1560	65	Therefore, it shall be lawful in me, if she receive not this law, for him to receive all things whatsoever I, the Lord his God, will give unto him, because she did not believe and administer unto him according to my word; and she then becomes the transgressor; and he is exempt from the law of Sarah, who administered unto Abraham according to the law when I commanded Abraham to take Hagar to wife.
41155	1560	66	And now, as pertaining to this law, verily, verily, I say unto you, I will reveal more unto you, hereafter; therefore, let this suffice for the present. Behold, I am Alpha and Omega. Amen.
41156	1561	1	HEARKEN, O ye people of my church, saith the Lord your God, and hear the word of the Lord concerning you--
41157	1561	2	The Lord who shall suddenly come to his temple; the Lord who shall come down upon the world with a curse to judgment; yea, upon all the nations that forget God, and upon all the ungodly among you.
41158	1561	3	For he shall make bare his holy arm in the eyes of all the nations, and all the ends of the earth shall see the salvation of their God.
41159	1561	4	Wherefore, prepare ye, prepare ye, O my people; sanctify yourselves; gather ye together, O ye people of my church, upon the land of Zion, all you that have not been commanded to tarry.
41160	1561	5	Go ye out from Babylon. Be ye clean that bear the vessels of the Lord.
41161	1561	6	Call your solemn assemblies, and speak often one to another. And let every man call upon the name of the Lord.
41162	1561	7	Yea, verily I say unto you again, the time has come when the voice of the Lord is unto you: Go ye out of Babylon; gather ye out from among the nations, from the four winds, from one end of heaven to the other.
41163	1561	8	Send forth the elders of my church unto the nations which are afar off; unto the islands of the sea; send forth unto foreign lands; call upon all nations, first upon the Gentiles, and then upon the Jews.
41164	1561	9	And behold, and lo, this shall be their cry, and the voice of the Lord unto all people: Go ye forth unto the land of Zion, that the borders of my people may be enlarged, and that her stakes may be strengthened, and that Zion may go forth unto the regions round about.
41165	1561	10	Yea, let the cry go forth among all people: Awake and arise and go forth to meet the Bridegroom; behold and lo, the Bridegroom cometh; go ye out to meet him. Prepare yourselves for the great day of the Lord.
41166	1561	11	Watch, therefore, for ye know neither the day nor the hour.
41167	1561	12	Let them, therefore, who are among the Gentiles flee unto Zion.
41168	1561	13	And let them who be of Judah flee unto Jerusalem, unto the mountains of the Lord's house.
41169	1561	14	Go ye out from among the nations, even from Babylon, from the midst of wickedness, which is spiritual Babylon.
41170	1561	15	But verily, thus saith the Lord, let not your flight be in haste, but let all things be prepared before you; and he that goeth, let him not look back lest sudden destruction shall come upon him.
41171	1561	16	Hearken and hear, O ye inhabitants of the earth. Listen, ye elders of my church together, and hear the voice of the Lord; for he calleth upon all men, and he commandeth all men everywhere to repent.
41172	1561	17	For behold, the Lord God hath sent forth the angel crying through the midst of heaven, saying: Prepare ye the way of the Lord, and make his paths straight, for the hour of his coming is nigh--
41173	1561	18	When the Lamb shall stand upon Mount Zion, and with him a hundred and forty-four thousand, having his Father's name written on their foreheads.
41174	1561	19	Wherefore, prepare ye for the coming of the Bridegroom; go ye, go ye out to meet him.
41175	1561	20	For behold, he shall stand upon the mount of Olivet, and upon the mighty ocean, even the great deep, and upon the islands of the sea, and upon the land of Zion.
41176	1561	21	And he shall utter his voice out of Zion, and he shall speak from Jerusalem, and his voice shall be heard among all people;
41177	1561	22	And it shall be a voice as the voice of many waters, and as the voice of a great thunder, which shall break down the mountains, and the valleys shall not be found.
41178	1561	23	He shall command the great deep, and it shall be driven back into the north countries, and the islands shall become one land;
41179	1561	24	And the land of Jerusalem and the land of Zion shall be turned back into their own place, and the earth shall be like as it was in the days before it was divided.
41180	1561	25	And the Lord, even the Savior, shall stand in the midst of his people, and shall reign over all flesh.
41181	1561	26	And they who are in the north countries shall come in remembrance before the Lord; and their prophets shall hear his voice, and shall no longer stay themselves; and they shall smite the rocks, and the ice shall flow down at their presence.
41182	1561	27	And an highway shall be cast up in the midst of the great deep.
41183	1561	28	Their enemies shall become a prey unto them,
41184	1561	29	And in the barren deserts there shall come forth pools of living water; and the parched ground shall no longer be a thirsty land.
41185	1561	30	And they shall bring forth their rich treasures unto the children of Ephraim, my servants.
41186	1561	31	And the boundaries of the everlasting hills shall tremble at their presence.
41187	1561	32	And there shall they fall down and be crowned with glory, even in Zion, by the hands of the servants of the Lord, even the children of Ephraim.
41188	1561	33	And they shall be filled with songs of everlasting joy.
41189	1561	34	Behold, this is the blessing of the everlasting God upon the tribes of Israel, and the richer blessing upon the head of Ephraim and his fellows.
41190	1561	35	And they also of the tribe of Judah, after their pain, shall be sanctified in holiness before the Lord, to dwell in his presence day and night, forever and ever.
41191	1561	36	And now, verily saith the Lord, that these things might be known among you, O inhabitants of the earth, I have sent forth mine angel flying through the midst of heaven, having the everlasting gospel, who hath appeared unto some and hath committed it unto man, who shall appear unto many that dwell on the earth.
41192	1561	37	And this gospel shall be preached unto every nation, and kindred, and tongue, and people.
41193	1561	38	And the servants of God shall go forth, saying with a loud voice: Fear God and give glory to him, for the hour of his judgment is come;
41194	1561	39	And worship him that made heaven, and earth, and the sea, and the fountains of waters--
41195	1561	40	Calling upon the name of the Lord day and night, saying: O that thou wouldst rend the heavens, that thou wouldst come down, that the mountains might flow down at thy presence.
41196	1561	41	And it shall be answered upon their heads; for the presence of the Lord shall be as the melting fire that burneth, and as the fire which causeth the waters to boil.
41197	1561	42	O Lord, thou shalt come down to make thy name known to thine adversaries, and all nations shall tremble at thy presence--
41198	1561	43	When thou doest terrible things, things they look not for;
41199	1561	44	Yea, when thou comest down, and the mountains flow down at thy presence, thou shalt meet him who rejoiceth and worketh righteousness, who remembereth thee in thy ways.
41200	1561	45	For since the beginning of the world have not men heard nor perceived by the ear, neither hath any eye seen, O God, besides thee, how great things thou hast prepared for him that waiteth for thee.
41201	1561	46	And it shall be said: Who is this that cometh down from God in heaven with dyed garments; yea, from the regions which are not known, clothed in his glorious apparel, traveling in the greatness of his strength?
41202	1561	47	And he shall say: I am he who spake in righteousness, mighty to save.
41203	1561	48	And the Lord shall be red in his apparel, and his garments like him that treadeth in the wine-vat.
41204	1561	49	And so great shall be the glory of his presence that the sun shall hide his face in shame, and the moon shall withhold its light, and the stars shall be hurled from their places.
41205	1561	50	And his voice shall be heard: I have trodden the wine-press alone, and have brought judgment upon all people; and none were with me;
41206	1561	51	And I have trampled them in my fury, and I did tread upon them in mine anger, and their blood have I sprinkled upon my garments, and stained all my raiment; for this was the day of vengeance which was in my heart.
41207	1561	52	And now the year of my redeemed is come; and they shall mention the loving kindness of their Lord, and all that he has bestowed upon them according to his goodness, and according to his loving kindness, forever and ever.
41208	1561	53	In all their afflictions he was afflicted. And the angel of his presence saved them; and in his love, and in his pity, he redeemed them, and bore them, and carried them all the days of old;
41209	1561	54	Yea, and Enoch also, and they who were with him; the prophets who were before him; and Noah also, and they who were before him; and Moses also, and they who were before him;
41210	1561	55	And from Moses to Elijah, and from Elijah to John, who were with Christ in his resurrection, and the holy apostles, with Abraham, Isaac, and Jacob, shall be in the presence of the Lamb.
41211	1561	56	And the graves of the saints shall be opened; and they shall come forth and stand on the right hand of the Lamb, when he shall stand upon Mount Zion, and upon the holy city, the New Jerusalem; and they shall sing the song of the Lamb, day and night forever and ever.
41212	1561	57	And for this cause, that men might be made partakers of the glories which were to be revealed, the Lord sent forth the fulness of his gospel, his everlasting covenant, reasoning in plainness and simplicity--
41213	1561	58	To prepare the weak for those things which are coming on the earth, and for the Lord's errand in the day when the weak shall confound the wise, and the little one become a strong nation, and two shall put their tens of thousands to flight.
41214	1561	59	And by the weak things of the earth the Lord shall thrash the nations by the power of his Spirit.
41215	1561	60	And for this cause these commandments were given; they were commanded to be kept from the world in the day that they were given, but now are to go forth unto all flesh--
41216	1561	61	And this according to the mind and will of the Lord, who ruleth over all flesh.
41217	1561	62	And unto him that repenteth and sanctifieth himself before the Lord shall be given eternal life.
41218	1561	63	And upon them that hearken not to the voice of the Lord shall be fulfilled that which was written by the prophet Moses, that they should be cut off from among the people.
41219	1561	64	And also that which was written by the prophet Malachi: For, behold, the day cometh that shall burn as an oven, and all the proud, yea, and all that do wickedly, shall be stubble; and the day that cometh shall burn them up, saith the Lord of hosts, that it shall leave them neither root nor branch.
41220	1561	65	Wherefore, this shall be the answer of the Lord unto them:
41221	1561	66	In that day when I came unto mine own, no man among you received me, and you were driven out.
41222	1561	67	When I called again there was none of you to answer; yet my arm was not shortened at all that I could not redeem, neither my power to deliver.
41223	1561	68	Behold, at my rebuke I dry up the sea. I make the rivers a wilderness; their fish stink, and die for thirst.
41224	1561	69	I clothe the heavens with blackness, and make sackcloth their covering.
41225	1561	70	And this shall ye have of my hand--ye shall lie down in sorrow.
41226	1561	71	Behold, and lo, there are none to deliver you; for ye obeyed not my voice when I called to you out of the heavens; ye believed not my servants, and when they were sent unto you ye received them not.
41227	1561	72	Wherefore, they sealed up the testimony and bound up the law, and ye were delivered over unto darkness.
41228	1561	73	These shall go away into outer darkness, where there is weeping, and wailing, and gnashing of teeth.
41229	1561	74	Behold the Lord your God hath spoken it. Amen.
41230	1562	1	WE believe that governments were instituted of God for the benefit of man; and that he holds men accountable for their acts in relation to them, both in making laws and administering them, for the good and safety of society.
41231	1562	2	We believe that no government can exist in peace, except such laws are framed and held inviolate as will secure to each individual the free exercise of conscience, the right and control of property, and the protection of life.
41232	1562	3	We believe that all governments necessarily require civil officers and magistrates to enforce the laws of the same; and that such as will administer the law in equity and justice should be sought for and upheld by the voice of the people if a republic, or the will of the sovereign.
41233	1562	4	We believe that religion is instituted of God; and that men are amenable to him, and to him only, for the exercise of it, unless their religious opinions prompt them to infringe upon the rights and liberties of others; but we do not believe that human law has a right to interfere in prescribing rules of worship to bind the consciences of men, nor dictate forms for public or private devotion; that the civil magistrate should restrain crime, but never control conscience; should punish guilt, but never suppress the freedom of the soul.
41234	1562	5	We believe that all men are bound to sustain and uphold the respective governments in which they reside, while protected in their inherent and inalienable rights by the laws of such governments; and that sedition and rebellion are unbecoming every citizen thus protected, and should be punished accordingly; and that all governments have a right to enact such laws as in their own judgments are best calculated to secure the public interest; at the same time, however, holding sacred the freedom of conscience.
41235	1562	6	We believe that every man should be honored in his station, rulers and magistrates as such, being placed for the protection of the innocent and the punishment of the guilty; and that to the laws all men show respect and deference, as without them peace and harmony would be supplanted by anarchy and terror; human laws being instituted for the express purpose of regulating our interests as individuals and nations, between man and man; and divine laws given of heaven, prescribing rules on spiritual concerns, for faith and worship, both to be answered by man to his Maker.
41236	1562	7	We believe that rulers, states, and governments have a right, and are bound to enact laws for the protection of all citizens in the free exercise of their religious belief; but we do not believe that they have a right in justice to deprive citizens of this privilege, or proscribe them in their opinions, so long as a regard and reverence are shown to the laws and such religious opinions do not justify sedition nor conspiracy.
41237	1562	8	We believe that the commission of crime should be punished according to the nature of the offense; that murder, treason, robbery, theft, and the breach of the general peace, in all respects, should be punished according to their criminality and their tendency to evil among men, by the laws of that government in which the offense is committed; and for the public peace and tranquility all men should step forward and use their ability in bringing offenders against good laws to punishment.
41238	1562	9	We do not believe it just to mingle religious influence with civil government, whereby one religious society is fostered and another proscribed in its spiritual privileges, and the individual rights of its members, as citizens, denied.
41239	1562	10	We believe that all religious societies have a right to deal with their members for disorderly conduct, according to the rules and regulations of such societies; provided that such dealings be for fellowship and good standing; but we do not believe that any religious society has authority to try men on the right of property or life, to take from them this world's goods, or to put them in jeopardy of either life or limb, or to inflict any physical punishment upon them. They can only excommunicate them from their society, and withdraw from them their fellowship.
41240	1562	11	We believe that men should appeal to the civil law for redress of all wrongs and grievances, where personal abuse is inflicted or the right of property or character infringed, where such laws exist as will protect the same; but we believe that all men are justified in defending themselves, their friends, and property, and the government, from the unlawful assaults and encroachments of all persons in times of exigency, where immediate appeal cannot be made to the laws, and relief afforded.
41241	1562	12	We believe it just to preach the gospel to the nations of the earth, and warn the righteous to save themselves from the corruption of the world; but we do not believe it right to interfere with bond-servants, neither preach the gospel to, nor baptize them contrary to the will and wish of their masters, nor to meddle with or influence them in the least to cause them to be dissatisfied with their situations in this life, thereby jeopardizing the lives of men; such interference we believe to be unlawful and unjust, and dangerous to the peace of every government allowing human beings to be held in servitude.
41242	1563	1	TO seal the testimony of this book and the Book of Mormon, we announce the martyrdom of Joseph Smith the Prophet, and Hyrum Smith the Patriarch. They were shot in Carthage jail, on the 27th of June, 1844, about five o'clock p.m., by an armed mob--painted black--of from 150 to 200 persons. Hyrum was shot first and fell calmly, exclaiming: I am a dead man! Joseph leaped from the window, and was shot dead in the attempt, exclaiming: O Lord my God! They were both shot after they were dead, in a brutal manner, and both received four balls.
41243	1563	2	John Taylor and Willard Richards, two of the Twelve, were the only persons in the room at the time; the former was wounded in a savage manner with four balls, but has since recovered; the latter, through the providence of God, escaped, without even a hole in his robe.
41244	1563	3	Joseph Smith, the Prophet and Seer of the Lord, has done more, save Jesus only, for the salvation of men in this world, than any other man that ever lived in it. In the short space of twenty years, he has brought forth the Book of Mormon, which he translated by the gift and power of God, and has been the means of publishing it on two continents; has sent the fulness of the everlasting gospel, which it contained, to the four quarters of the earth; has brought forth the revelations and commandments which compose this book of Doctrine and Covenants, and many other wise documents and instructions for the benefit of the children of men; gathered many thousands of the Latter-day Saints, founded a great city, and left a fame and name that cannot be slain. He lived great, and he died great in the eyes of God and his people; and like most of the Lord's anointed in ancient times, has sealed his mission and his works with his own blood; and so has his brother Hyrum. In life they were not divided, and in death they were not separated!
41245	1563	4	When Joseph went to Carthage to deliver himself up to the pretended requirements of the law, two or three days previous to his assassination, he said: "I am going like a lamb to the slaughter; but I am calm as a summer's morning; I have a conscience void of offense towards God, and towards all men. I SHALL DIE INNOCENT, AND IT SHALL YET BE SAID OF ME--HE WAS MURDERED IN COLD BLOOD."--The same morning, after Hyrum had made ready to go--shall it be said to the slaughter? yes, for so it was--he read the following paragraph, near the close of the twelfth chapter of Ether, in the Book of Mormon, and turned down the leaf upon it:
41246	1563	5	And it came to pass that I prayed unto the Lord that he would give unto the Gentiles grace, that they might have charity. And it came to pass that the Lord said unto me: If they have not charity it mattereth not unto thee, thou hast been faithful; wherefore thy garments shall be made clean. And because thou hast seen thy weakness, thou shalt be made strong, even unto the sitting down in the place which I have prepared in the mansions of my Father. And now I . . . bid farewell unto the Gentiles; yea, and also unto my brethren whom I love, until we shall meet before the judgment-seat of Christ, where all men shall know that my garments are not spotted with your blood. The testators are now dead, and their testament is in force.
41247	1563	6	Hyrum Smith was forty-four years old in February, 1844, and Joseph Smith was thirty-eight in December, 1843; and henceforward their names will be classed among the martyrs of religion; and the reader in every nation will be reminded that the Book of Mormon, and this book of Doctrine and Covenants of the church, cost the best blood of the nineteenth century to bring them forth for the salvation of a ruined world; and that if the fire can scathe a green tree for the glory of God, how easy it will burn up the dry trees to purify the vineyard of corruption. They lived for glory; they died for glory; and glory is their eternal reward. From age to age shall their names go down to posterity as gems for the sanctified.
41248	1563	7	They were innocent of any crime, as they had often been proved before, and were only confined in jail by the conspiracy of traitors and wicked men; and their innocent blood on the floor of Carthage jail is a broad seal affixed to "Mormonism" that cannot be rejected by any court on earth, and their innocent blood on the escutcheon of the State of Illinois, with the broken faith of the State as pledged by the governor, is a witness to the truth of the everlasting gospel that all the world cannot impeach; and their innocent blood on the banner of liberty, and on the magna charta of the United States, is an ambassador for the religion of Jesus Christ, that will touch the hearts of honest men among all nations; and their innocent blood, with the innocent blood of all the martyrs under the altar that John saw, will cry unto the Lord of Hosts till he avenges that blood on the earth. Amen.
41249	1564	1	THE Word and Will of the Lord concerning the Camp of Israel in their journeyings to the West:
41250	1564	2	Let all the people of the Church of Jesus Christ of Latter-day Saints, and those who journey with them, be organized into companies, with a covenant and promise to keep all the commandments and statutes of the Lord our God.
41251	1564	3	Let the companies be organized with captains of hundreds, captains of fifties, and captains of tens, with a president and his two counselors at their head, under the direction of the Twelve Apostles.
41252	1564	4	And this shall be our covenant--that we will walk in all the ordinances of the Lord.
41253	1564	5	Let each company provide themselves with all the teams, wagons, provisions, clothing, and other necessaries for the journey, that they can.
41254	1564	6	When the companies are organized let them go to with their might, to prepare for those who are to tarry.
41255	1564	7	Let each company, with their captains and presidents, decide how many can go next spring; then choose out a sufficient number of able-bodied and expert men, to take teams, seeds, and farming utensils, to go as pioneers to prepare for putting in spring crops.
41256	1564	8	Let each company bear an equal proportion, according to the dividend of their property, in taking the poor, the widows, the fatherless, and the families of those who have gone into the army, that the cries of the widow and the fatherless come not up into the ears of the Lord against this people.
41257	1564	9	Let each company prepare houses, and fields for raising grain, for those who are to remain behind this season; and this is the will of the Lord concerning his people.
41258	1564	10	Let every man use all his influence and property to remove this people to the place where the Lord shall locate a stake of Zion.
41259	1564	11	And if ye do this with a pure heart, in all faithfulness, ye shall be blessed; you shall be blessed in your flocks, and in your herds, and in your fields, and in your houses, and in your families.
41260	1564	12	Let my servants Ezra T. Benson and Erastus Snow organize a company.
41261	1564	13	And let my servants Orson Pratt and Wilford Woodruff organize a company.
41262	1564	14	Also, let my servants Amasa Lyman and George A. Smith organize a company.
41263	1564	15	And appoint presidents, and captains of hundreds, and of fifties, and of tens.
41264	1564	16	And let my servants that have been appointed go and teach this, my will, to the saints, that they may be ready to go to a land of peace.
41265	1564	17	Go thy way and do as I have told you, and fear not thine enemies; for they shall not have power to stop my work.
41266	1564	18	Zion shall be redeemed in mine own due time.
41267	1564	19	And if any man shall seek to build up himself, and seeketh not my counsel, he shall have no power, and his folly shall be made manifest.
41268	1564	20	Seek ye; and keep all your pledges one with another; and covet not that which is thy brother's.
41269	1564	21	Keep yourselves from evil to take the name of the Lord in vain, for I am the Lord your God, even the God of your fathers, the God of Abraham and of Isaac and of Jacob.
41270	1564	22	I am he who led the children of Israel out of the land of Egypt; and my arm is stretched out in the last days, to save my people Israel.
41271	1564	23	Cease to contend one with another; cease to speak evil one of another.
41272	1564	24	Cease drunkenness; and let your words tend to edifying one another.
41273	1564	25	If thou borrowest of thy neighbor, thou shalt restore that which thou hast borrowed; and if thou canst not repay then go straightway and tell thy neighbor, lest he condemn thee.
41274	1564	26	If thou shalt find that which thy neighbor has lost, thou shalt make diligent search till thou shalt deliver it to him again.
41275	1564	27	Thou shalt be diligent in preserving what thou hast, that thou mayest be a wise steward; for it is the free gift of the Lord thy God, and thou art his steward.
41276	1564	28	If thou art merry, praise the Lord with singing, with music, with dancing, and with a prayer of praise and thanksgiving.
41277	1564	29	If thou art sorrowful, call on the Lord thy God with supplication, that your souls may be joyful.
41278	1564	30	Fear not thine enemies, for they are in mine hands and I will do my pleasure with them.
41279	1564	31	My people must be tried in all things, that they may be prepared to receive the glory that I have for them, even the glory of Zion; and he that will not bear chastisement is not worthy of my kingdom.
41280	1564	32	Let him that is ignorant learn wisdom by humbling himself and calling upon the Lord his God, that his eyes may be opened that he may see, and his ears opened that he may hear;
41281	1564	33	For my Spirit is sent forth into the world to enlighten the humble and contrite, and to the condemnation of the ungodly.
41282	1564	34	Thy brethren have rejected you and your testimony, even the nation that has driven you out;
41283	1564	35	And now cometh the day of their calamity, even the days of sorrow, like a woman that is taken in travail; and their sorrow shall be great unless they speedily repent, yea, very speedily.
41284	1564	36	For they killed the prophets, and them that were sent unto them; and they have shed innocent blood, which crieth from the ground against them.
41285	1564	37	Therefore, marvel not at these things, for ye are not yet pure; ye can not yet bear my glory; but ye shall behold it if ye are faithful in keeping all my words that I have given you, from the days of Adam to Abraham, from Abraham to Moses, from Moses to Jesus and his apostles, and from Jesus and his apostles to Joseph Smith, whom I did call upon by mine angels, my ministering servants, and by mine own voice out of the heavens, to bring forth my work;
41286	1564	38	Which foundation he did lay, and was faithful; and I took him to myself.
41287	1564	39	Many have marveled because of his death; but it was needful that he should seal his testimony with his blood, that he might be honored and the wicked might be condemned.
41288	1564	40	Have I not delivered you from your enemies, only in that I have left a witness of my name?
41289	1564	41	Now, therefore, hearken, O ye people of my church; and ye elders listen together; you have received my kingdom.
41290	1564	42	Be diligent in keeping all my commandments, lest judgments come upon you, and your faith fail you, and your enemies triumph over you. So no more at present. Amen and Amen.
41291	1565	1	THE heavens were opened upon us, and I beheld the celestial kingdom of God, and the glory thereof, whether in the body or out I cannot tell.
41292	1565	2	I saw the transcendent beauty of the gate through which the heirs of that kingdom will enter, which was like unto circling flames of fire;
41293	1565	3	Also the blazing throne of God, whereon was seated the Father and the Son.
41294	1565	4	I saw the beautiful streets of that kingdom, which had the appearance of being paved with gold.
41295	1565	5	I saw Father Adam and Abraham; and my father and my mother; my brother Alvin, that has long since slept;
41296	1565	6	And marveled how it was that he had obtained an inheritance in that kingdom, seeing that he had departed this life before the Lord had set his hand to gather Israel the second time, and had not been baptized for the remission of sins.
41297	1565	7	Thus came the voice of the Lord unto me, saying: All who have died without a knowledge of this gospel, who would have received it if they had been permitted to tarry, shall be heirs of the celestial kingdom of God;
41298	1565	8	Also all that shall die henceforth without a knowledge of it, who would have received it with all their hearts, shall be heirs of that kingdom;
41299	1565	9	For I, the Lord, will judge all men according to their works, according to the desire of their hearts.
41300	1565	10	And I also beheld that all children who die before they arrive at the years of accountability are saved in the celestial kingdom of heaven.
41301	1566	1	ON the third of October, in the year nineteen hundred and eighteen, I sat in my room pondering over the scriptures;
41302	1566	2	And reflecting upon the great atoning sacrifice that was made by the Son of God, for the redemption of the world;
41303	1566	3	And the great and wonderful love made manifest by the Father and the Son in the coming of the Redeemer into the world;
41304	1566	4	That through his atonement, and by obedience to the principles of the gospel, mankind might be saved.
41305	1566	5	While I was thus engaged, my mind reverted to the writings of the apostle Peter, to the primitive saints scattered abroad throughout Pontus, Galatia, Cappadocia, and other parts of Asia, where the gospel had been preached after the crucifixion of the Lord.
41306	1566	6	I opened the Bible and read the third and fourth chapters of the first epistle of Peter, and as I read I was greatly impressed, more than I had ever been before, with the following passages:
41307	1566	7	"For Christ also hath once suffered for sins, the just for the unjust, that he might bring us to God, being put to death in the flesh, but quickened by the Spirit:
41308	1566	8	"By which also he went and preached unto the spirits in prison;
41309	1566	9	"Which sometime were disobedient, when once the long-suffering of God waited in the days of Noah, while the ark was a preparing, wherein few, that is, eight souls were saved by water." (1 Peter 3: 18--20.)
41310	1566	10	"For for this cause was the gospel preached also to them that are dead, that they might be judged according to men in the flesh, but live according to God in the spirit." (1 Peter 4: 6.)
41311	1566	11	As I pondered over these things which are written, the eyes of my understanding were opened, and the Spirit of the Lord rested upon me, and I saw the hosts of the dead, both small and great.
41312	1566	12	And there were gathered together in one place an innumerable company of the spirits of the just, who had been faithful in the testimony of Jesus while they lived in mortality;
41313	1566	13	And who had offered sacrifice in the similitude of the great sacrifice of the Son of God, and had suffered tribulation in their Redeemer's name.
41314	1566	14	All these had departed the mortal life, firm in the hope of a glorious resurrection, through the grace of God the Father and his Only Begotten Son, Jesus Christ.
41315	1566	15	I beheld that they were filled with joy and gladness, and were rejoicing together because the day of their deliverance was at hand.
41316	1566	16	They were assembled awaiting the advent of the Son of God into the spirit world, to declare their redemption from the bands of death.
41317	1566	17	Their sleeping dust was to be restored unto its perfect frame, bone to his bone, and the sinews and the flesh upon them, the spirit and the body to be united never again to be divided, that they might receive a fulness of joy.
41318	1566	18	While this vast multitude waited and conversed, rejoicing in the hour of their deliverance from the chains of death, the Son of God appeared, declaring liberty to the captives who had been faithful;
41319	1566	19	And there he preached to them the everlasting gospel, the doctrine of the resurrection and the redemption of mankind from the fall, and from individual sins on conditions of repentance.
41320	1566	20	But unto the wicked he did not go, and among the ungodly and the unrepentant who had defiled themselves while in the flesh, his voice was not raised;
41321	1566	21	Neither did the rebellious who rejected the testimonies and the warnings of the ancient prophets behold his presence, nor look upon his face.
41322	1566	22	Where these were, darkness reigned, but among the righteous there was peace;
41323	1566	23	And the saints rejoiced in their redemption, and bowed the knee and acknowledged the Son of God as their Redeemer and Deliverer from death and the chains of hell.
41324	1566	24	Their countenances shone, and the radiance from the presence of the Lord rested upon them, and they sang praises unto his holy name.
41325	1566	25	I marveled, for I understood that the Savior spent about three years in his ministry among the Jews and those of the house of Israel, endeavoring to teach them the everlasting gospel and call them unto repentance;
41326	1566	26	And yet, notwithstanding his mighty works, and miracles, and proclamation of the truth, in great power and authority, there were but few who hearkened to his voice, and rejoiced in his presence, and received salvation at his hands.
41327	1566	27	But his ministry among those who were dead was limited to the brief time intervening between the crucifixion and his resurrection;
41328	1566	28	And I wondered at the words of Peter--wherein he said that the Son of God preached unto the spirits in prison, who sometime were disobedient, when once the long-suffering of God waited in the days of Noah--and how it was possible for him to preach to those spirits and perform the necessary labor among them in so short a time.
41329	1566	29	And as I wondered, my eyes were opened, and my understanding quickened, and I perceived that the Lord went not in person among the wicked and the disobedient who had rejected the truth, to teach them;
41330	1566	30	But behold, from among the righteous, he organized his forces and appointed messengers, clothed with power and authority, and commissioned them to go forth and carry the light of the gospel to them that were in darkness, even to all the spirits of men; and thus was the gospel preached to the dead.
41331	1566	31	And the chosen messengers went forth to declare the acceptable day of the Lord and proclaim liberty to the captives who were bound, even unto all who would repent of their sins and receive the gospel.
41332	1566	32	Thus was the gospel preached to those who had died in their sins, without a knowledge of the truth, or in transgression, having rejected the prophets.
41333	1566	33	These were taught faith in God, repentance from sin, vicarious baptism for the remission of sins, the gift of the Holy Ghost by the laying on of hands,
41334	1566	34	And all other principles of the gospel that were necessary for them to know in order to qualify themselves that they might be judged according to men in the flesh, but live according to God in the spirit.
41335	1566	35	And so it was made known among the dead, both small and great, the unrighteous as well as the faithful, that redemption had been wrought through the sacrifice of the Son of God upon the cross.
41336	1566	36	Thus was it made known that our Redeemer spent his time during his sojourn in the world of spirits, instructing and preparing the faithful spirits of the prophets who had testified of him in the flesh;
41337	1566	37	That they might carry the message of redemption unto all the dead, unto whom he could not go personally, because of their rebellion and transgression, that they through the ministration of his servants might also hear his words.
41338	1566	38	Among the great and mighty ones who were assembled in this vast congregation of the righteous were Father Adam, the Ancient of Days and father of all,
41339	1566	39	And our glorious Mother Eve, with many of her faithful daughters who had lived through the ages and worshiped the true and living God.
41340	1566	40	Abel, the first martyr, was there, and his brother Seth, one of the mighty ones, who was in the express image of his father, Adam.
41341	1566	41	Noah, who gave warning of the flood; Shem, the great high priest; Abraham, the father of the faithful; Isaac, Jacob, and Moses, the great law-giver of Israel;
41342	1566	42	And Isaiah, who declared by prophecy that the Redeemer was anointed to bind up the broken-hearted, to proclaim liberty to the captives, and the opening of the prison to them that were bound, were also there.
41343	1566	43	Moreover, Ezekiel, who was shown in vision the great valley of dry bones, which were to be clothed upon with flesh, to come forth again in the resurrection of the dead, living souls;
41344	1566	44	Daniel, who foresaw and foretold the establishment of the kingdom of God in the latter days, never again to be destroyed nor given to other people;
41345	1566	45	Elias, who was with Moses on the Mount of Transfiguration;
41346	1566	46	And Malachi, the prophet who testified of the coming of Elijah--of whom also Moroni spake to the Prophet Joseph Smith, declaring that he should come before the ushering in of the great and dreadful day of the Lord--were also there.
41347	1566	47	The Prophet Elijah was to plant in the hearts of the children the promises made to their fathers,
41348	1566	48	Foreshadowing the great work to be done in the temples of the Lord in the dispensation of the fulness of times, for the redemption of the dead, and the sealing of the children to their parents, lest the whole earth be smitten with a curse and utterly wasted at his coming.
41349	1566	49	All these and many more, even the prophets who dwelt among the Nephites and testified of the coming of the Son of God, mingled in the vast assembly and waited for their deliverance,
41350	1566	50	For the dead had looked upon the long absence of their spirits from their bodies as a bondage.
41351	1566	51	These the Lord taught, and gave them power to come forth, after his resurrection from the dead, to enter into his Father's kingdom, there to be crowned with immortality and eternal life,
41352	1566	52	And continue thenceforth their labor as had been promised by the Lord, and be partakers of all blessings which were held in reserve for them that love him.
41353	1566	53	The Prophet Joseph Smith, and my father, Hyrum Smith, Brigham Young, John Taylor, Wilford Woodruff, and other choice spirits who were reserved to come forth in the fulness of times to take part in laying the foundations of the great latter-day work,
41354	1566	54	Including the building of the temples and the performance of ordinances therein for the redemption of the dead, were also in the spirit world.
41355	1566	55	I observed that they were also among the noble and great ones who were chosen in the beginning to be rulers in the Church of God.
41356	1566	56	Even before they were born, they, with many others, received their first lessons in the world of spirits and were prepared to come forth in the due time of the Lord to labor in his vineyard for the salvation of the souls of men.
41357	1566	57	I beheld that the faithful elders of this dispensation, when they depart from mortal life, continue their labors in the preaching of the gospel of repentance and redemption, through the sacrifice of the Only Begotten Son of God, among those who are in darkness and under the bondage of sin in the great world of the spirits of the dead.
41358	1566	58	The dead who repent will be redeemed, through obedience to the ordinances of the house of God,
41359	1566	59	And after they have paid the penalty of their transgressions, and are washed clean, shall receive a reward according to their works, for they are heirs of salvation.
41360	1566	60	Thus was the vision of the redemption of the dead revealed to me, and I bear record, and I know that this record is true, through the blessing of our Lord and Savior, Jesus Christ, even so. Amen.
41361	1567	1	THE words of God, which he spake unto Moses at a time when Moses was caught up into an exceedingly high mountain,
41362	1567	2	And he saw God face to face, and he talked with him, and the glory of God was upon Moses; therefore Moses could endure his presence.
41363	1567	3	And God spake unto Moses, saying: Behold, I am the Lord God Almighty, and Endless is my name; for I am without beginning of days or end of years; and is not this endless?
41364	1567	4	And, behold, thou art my son; wherefore look, and I will show thee the workmanship of mine hands; but not all, for my works are without end, and also my words, for they never cease.
41365	1567	5	Wherefore, no man can behold all my works, except he behold all my glory; and no man can behold all my glory, and afterwards remain in the flesh on the earth.
41366	1567	6	And I have a work for thee, Moses, my son; and thou art in the similitude of mine Only Begotten; and mine Only Begotten is and shall be the Savior, for he is full of grace and truth; but there is no God beside me, and all things are present with me, for I know them all.
41367	1567	7	And now, behold, this one thing I show unto thee, Moses, my son, for thou art in the world, and now I show it unto thee.
41368	1567	8	And it came to pass that Moses looked, and beheld the world upon which he was created; and Moses beheld the world and the ends thereof, and all the children of men which are, and which were created; of the same he greatly marveled and wondered.
41369	1567	9	And the presence of God withdrew from Moses, that his glory was not upon Moses; and Moses was left unto himself. And as he was left unto himself, he fell unto the earth.
41370	1567	10	And it came to pass that it was for the space of many hours before Moses did again receive his natural strength like unto man; and he said unto himself: Now, for this cause I know that man is nothing, which thing I never had supposed.
41371	1567	11	But now mine own eyes have beheld God; but not my natural, but my spiritual eyes, for my natural eyes could not have beheld; for I should have withered and died in his presence; but his glory was upon me; and I beheld his face, for I was transfigured before him.
41372	1567	12	And it came to pass that when Moses had said these words, behold, Satan came tempting him, saying: Moses, son of man, worship me.
41373	1567	13	And it came to pass that Moses looked upon Satan and said: Who art thou? For behold, I am a son of God, in the similitude of his Only Begotten; and where is thy glory, that I should worship thee?
41374	1567	14	For behold, I could not look upon God, except his glory should come upon me, and I were transfigured before him. But I can look upon thee in the natural man. Is it not so, surely?
41375	1567	15	Blessed be the name of my God, for his Spirit hath not altogether withdrawn from me, or else where is thy glory, for it is darkness unto me? And I can judge between thee and God; for God said unto me: Worship God, for him only shalt thou serve.
41376	1567	16	Get thee hence, Satan; deceive me not; for God said unto me: Thou art after the similitude of mine Only Begotten.
41377	1567	17	And he also gave me commandments when he called unto me out of the burning bush, saying: Call upon God in the name of mine Only Begotten, and worship me.
41378	1567	18	And again Moses said: I will not cease to call upon God, I have other things to inquire of him: for his glory has been upon me, wherefore I can judge between him and thee. Depart hence, Satan.
41379	1567	19	And now, when Moses had said these words, Satan cried with a loud voice, and ranted upon the earth, and commanded, saying: I am the Only Begotten, worship me.
41380	1567	20	And it came to pass that Moses began to fear exceedingly; and as he began to fear, he saw the bitterness of hell. Nevertheless, calling upon God, he received strength, and he commanded, saying: Depart from me, Satan, for this one God only will I worship, which is the God of glory.
41381	1567	21	And now Satan began to tremble, and the earth shook; and Moses received strength, and called upon God, saying: In the name of the Only Begotten, depart hence, Satan.
41382	1567	22	And it came to pass that Satan cried with a loud voice, with weeping, and wailing, and gnashing of teeth; and he departed hence, even from the presence of Moses, that he beheld him not.
41383	1567	23	And now of this thing Moses bore record; but because of wickedness it is not had among the children of men.
41384	1567	24	And it came to pass that when Satan had departed from the presence of Moses, that Moses lifted up his eyes unto heaven, being filled with the Holy Ghost, which beareth record of the Father and the Son;
41385	1567	25	And calling upon the name of God, he beheld his glory again, for it was upon him; and he heard a voice, saying: Blessed art thou, Moses, for I, the Almighty, have chosen thee, and thou shalt be made stronger than many waters; for they shall obey thy command as if thou wert God.
41386	1567	26	And lo, I am with thee, even unto the end of thy days; for thou shalt deliver my people from bondage, even Israel my chosen.
41387	1567	27	And it came to pass, as the voice was still speaking, Moses cast his eyes and beheld the earth, yea, even all of it; and there was not a particle of it which he did not behold, discerning it by the spirit of God.
41388	1567	28	And he beheld also the inhabitants thereof, and there was not a soul which he beheld not; and he discerned them by the Spirit of God; and their numbers were great, even numberless as the sand upon the sea shore.
41389	1567	29	And he beheld many lands; and each land was called earth, and there were inhabitants on the face thereof.
41390	1567	30	And it came to pass that Moses called upon God, saying: Tell me, I pray thee, why these things are so, and by what thou madest them?
41391	1567	31	And behold, the glory of the Lord was upon Moses, so that Moses stood in the presence of God, and talked with him face to face. And the Lord God said unto Moses: For mine own purpose have I made these things. Here is wisdom and it remaineth in me.
41392	1567	32	And by the word of my power, have I created them, which is mine Only Begotten Son, who is full of grace and truth.
41393	1567	33	And worlds without number have I created; and I also created them for mine own purpose; and by the Son I created them, which is mine Only Begotten.
41394	1567	34	And the first man of all men have I called Adam, which is many.
41395	1567	35	But only an account of this earth, and the inhabitants thereof, give I unto you. For behold, there are many worlds that have passed away by the word of my power. And there are many that now stand, and innumerable are they unto man; but all things are numbered unto me, for they are mine and I know them.
41396	1567	36	And it came to pass that Moses spake unto the Lord, saying: Be merciful unto thy servant, O God, and tell me concerning this earth, and the inhabitants thereof, and also the heavens, and then thy servant will be content.
41397	1567	37	And the Lord God spake unto Moses, saying: The heavens, they are many, and they cannot be numbered unto man; but they are numbered unto me, for they are mine.
41398	1567	38	And as one earth shall pass away, and the heavens thereof even so shall another come, and there is no end to my works, neither to my words.
41399	1567	39	For behold, this is my work and my glory--to bring to pass the immortality and eternal life of man.
41400	1567	40	And now, Moses, my son, I will speak unto thee concerning this earth upon which thou standest; and thou shalt write the things which I shall speak.
41401	1567	41	And in a day when the children of men shall esteem my words as naught and take many of them from the book which thou shalt write, behold, I will raise up another like unto thee; and they shall be had again among the children of men--among as many as shall believe.
41402	1567	42	(These words were spoken unto Moses in the mount, the name of which shall not be known among the children of men. And now they are spoken unto you. Show them not unto any except them that believe. Even so. Amen.)
41403	1568	1	AND it came to pass that the Lord spake unto Moses, saying: Behold, I reveal unto you concerning this heaven, and this earth; write the words which I speak. I am the Beginning and the End, the Almighty God; by mine Only Begotten I created these things; yea, in the beginning I created the heaven, and the earth upon which thou standest.
41404	1568	2	And the earth was without form, and void; and I caused darkness to come up upon the face of the deep; and my Spirit moved upon the face of the water; for I am God.
41405	1568	3	And I, God, said: Let there be light; and there was light.
41406	1568	4	And I, God, saw the light; and that light was good. And I, God, divided the light from the darkness.
41407	1568	5	And I, God, called the light Day; and the darkness, I called Night; and this I did by the word of my power, and it was done as I spake; and the evening and the morning were the first day.
41408	1568	6	And again, I, God, said: Let there be a firmament in the midst of the water, and it was so, even as I spake; and I said: Let it divide the waters from the waters; and it was done;
41409	1568	7	And I, God, made the firmament and divided the waters, yea, the great waters under the firmament from the waters which were above the firmament, and it was so even as I spake.
41410	1568	8	And I, God, called the firmament Heaven; and the evening and the morning were the second day.
41411	1568	9	And I, God, said: Let the waters under the heaven be gathered together unto one place, and it was so; and I, God, said: Let there be dry land; and it was so.
41412	1568	10	And I, God, called the dry land Earth; and the gathering together of the waters, called I the Sea; and I, God, saw that all things which I had made were good.
41413	1568	11	And I, God, said: Let the earth bring forth grass, the herb yielding seed, the fruit tree yielding fruit, after his kind, and the tree yielding fruit, whose seed should be in itself upon the earth, and it was so even as I spake.
41414	1568	12	And the earth brought forth grass, every herb yielding seed after his kind, and the tree yielding fruit, whose seed should be in itself, after his kind; and I, God, saw that all things which I had made were good;
41415	1568	13	And the evening and the morning were the third day.
41416	1568	14	And I, God, said: Let there be lights in the firmament of the heaven, to divide the day from the night, and let them be for signs, and for seasons, and for days, and for years;
41417	1568	15	And let them be for lights in the firmament of the heaven to give light upon the earth; and it was so.
41418	1568	16	And I, God, made two great lights; the greater light to rule the day, and the lesser light to rule the night, and the greater light was the sun, and the lesser light was the moon; and the stars also were made even according to my word.
41419	1568	17	And I, God, set them in the firmament of the heaven to give light upon the earth,
41420	1568	18	And the sun to rule over the day, and the moon to rule over the night, and to divide the light from the darkness; and I, God, saw that all things which I had made were good;
41421	1568	19	And the evening and the morning were the fourth day.
41422	1568	20	And I, God, said: Let the waters bring forth abundantly the moving creature that hath life, and fowl which may fly above the earth in the open firmament of heaven.
41423	1568	21	And I, God, created great whales, and every living creature that moveth, which the waters brought forth abundantly, after their kind, and every winged fowl after his kind; and I, God, saw that all things which I had created were good.
41424	1568	22	And I, God, blessed them, saying: Be fruitful, and multiply, and fill the waters in the sea; and let fowl multiply in the earth;
41425	1568	23	And the evening and the morning were the fifth day.
41426	1568	24	And I, God, said: Let the earth bring forth the living creature after his kind, cattle, and creeping things, and beasts of the earth after their kind, and it was so;
41427	1568	25	And I, God, made the beasts of the earth after their kind, and cattle after their kind, and everything which creepeth upon the earth after his kind; and I, God, saw that all these things were good.
41428	1568	26	And I, God, said unto mine Only Begotten, which was with me from the beginning: Let us make man in our image, after our likeness; and it was so. And I, God, said: Let them have dominion over the fishes of the sea, and over the fowl of the air, and over the cattle, and over all the earth, and over every creeping thing that creepeth upon the earth.
41429	1568	27	And I, God, created man in mine own image, in the image of mine Only Begotten created I him; male and female created I them.
41430	1568	28	And I, God, blessed them, and said unto them: Be fruitful, and multiply, and replenish the earth, and subdue it, and have dominion over the fish of the sea, and over the fowl of the air, and over every living thing that moveth upon the earth.
41431	1568	29	And I, God, said unto man: Behold, I have given you every herb bearing seed, which is upon the face of all the earth, and every tree in the which shall be the fruit of a tree yielding seed; to you it shall be for meat.
41432	1568	30	And to every beast of the earth, and to every fowl of the air, and to everything that creepeth upon the earth, wherein I grant life, there shall be given every clean herb for meat; and it was so, even as I spake.
41433	1568	31	And I, God, saw everything that I had made, and, behold, all things which I had made were very good; and the evening and the morning were the sixth day.
41434	1569	1	THUS the heaven and the earth were finished, and all the host of them.
41435	1569	2	And on the seventh day I, God, ended my work, and all things which I had made; and I rested on the seventh day from all my work, and all things which I had made were finished, and I, God, saw that they were good;
41436	1569	3	And I, God, blessed the seventh day, and sanctified it; because that in it I had rested from all my work which I, God, had created and made.
41437	1569	4	And now, behold, I say unto you, that these are the generations of the heaven and of the earth, when they were created, in the day that I, the Lord God, made the heaven and the earth,
41438	1569	5	And every plant of the field before it was in the earth, and every herb of the field before it grew. For I, the Lord God, created all things, of which I have spoken, spiritually, before they were naturally upon the face of the earth. For I, the Lord God, had not caused it to rain upon the face of the earth. And I, the Lord God, had created all the children of men; and not yet a man to till the ground; for in heaven created I them; and there was not yet flesh upon the earth, neither in the water, neither in the air;
41439	1569	6	But I, the Lord God, spake, and there went up a mist from the earth, and watered the whole face of the ground.
41440	1569	7	And I, the Lord God, formed man from the dust of the ground, and breathed into his nostrils the breath of life; and man became a living soul, the first flesh upon the earth, the first man also; nevertheless, all things were before created; but spiritually were they created and made according to my word.
41441	1569	8	And I, the Lord God, planted a garden eastward in Eden, and there I put the man whom I had formed.
41442	1569	9	And out of the ground made I, the Lord God, to grow every tree, naturally, that is pleasant to the sight of man; and man could behold it. And it became also a living soul. For it was spiritual in the day that I created it; for it remaineth in the sphere in which I, God, created it, yea, even all things which I prepared for the use of man; and man saw that it was good for food. And I, the Lord God, planted the tree of life also in the midst of the garden, and also the tree of knowledge of good and evil.
41443	1569	10	And I, the Lord God, caused a river to go out of Eden to water the garden; and from thence it was parted, and became into four heads.
41444	1569	11	And I, the Lord God, called the name of the first Pison, and it compasseth the whole land of Havilah, where I, the Lord God, created much gold;
41445	1569	12	And the gold of that land was good, and there was bdellium and the onyx stone.
41446	1569	13	And the name of the second river was called Gihon; the same that compasseth the whole land of Ethiopia.
41447	1569	14	And the name of the third river was Hiddekel; that which goeth toward the east of Assyria. And the fourth river was the Euphrates.
41448	1569	15	And I, the Lord God, took the man, and put him into the Garden of Eden, to dress it, and to keep it.
41449	1569	16	And I, the Lord God, commanded the man, saying: Of every tree of the garden thou mayest freely eat,
41450	1569	17	But of the tree of the knowledge of good and evil, thou shalt not eat of it, nevertheless, thou mayest choose for thyself, for it is given unto thee; but, remember that I forbid it, for in the day thou eatest thereof thou shalt surely die.
41451	1569	18	And I, the Lord God, said unto mine Only Begotten, that it was not good that the man should be alone; wherefore, I will make an help meet for him.
41452	1569	19	And out of the ground I, the Lord God, formed every beast of the field, and every fowl of the air; and commanded that they should come unto Adam, to see what he would call them; and they were also living souls; for I, God, breathed into them the breath of life, and commanded that whatsoever Adam called every living creature, that should be the name thereof.
41453	1569	20	And Adam gave names to all cattle, and to the fowl of the air, and to every beast of the field; but as for Adam, there was not found an help meet for him.
41454	1569	21	And I, the Lord God, caused a deep sleep to fall upon Adam; and he slept, and I took one of his ribs and closed up the flesh in the stead thereof;
41455	1569	22	And the rib which I, the Lord God, had taken from man, made I a woman, and brought her unto the man.
41456	1569	23	And Adam said: This I know now is bone of my bones, and flesh of my flesh; she shall be called Woman, because she was taken out of man.
41457	1569	24	Therefore shall a man leave his father and his mother, and shall cleave unto his wife; and they shall be one flesh.
41458	1569	25	And they were both naked, the man and his wife, and were not ashamed.
41459	1570	1	AND I, the Lord God, spake unto Moses, saying: That Satan, whom thou hast commanded in the name of mine Only Begotten, is the same which was from the beginning, and he came before me, saying--Behold, here am I, send me, I will be thy son, and I will redeem all mankind, that one soul shall not be lost, and surely I will do it; wherefore give me thine honor.
41460	1570	2	But, behold, my Beloved Son, which was my Beloved and Chosen from the beginning, said unto me--Father, thy will be done, and the glory be thine forever.
41461	1570	3	Wherefore, because that Satan rebelled against me, and sought to destroy the agency of man, which I, the Lord God, had given him, and also, that I should give unto him mine own power; by the power of mine Only Begotten, I caused that he should be cast down;
41462	1570	4	And he became Satan, yea, even the devil, the father of all lies, to deceive and to blind men, and to lead them captive at his will, even as many as would not hearken unto my voice.
41463	1570	5	And now the serpent was more subtle than any beast of the field which I, the Lord God, had made.
41464	1570	6	And Satan put it into the heart of the serpent, (for he had drawn away many after him,) and he sought also to beguile Eve, for he knew not the mind of God, wherefore he sought to destroy the world.
41465	1570	7	And he said unto the woman: Yea, hath God said--Ye shall not eat of every tree of the garden? (And he spake by the mouth of the serpent.)
41466	1570	8	And the woman said unto the serpent: We may eat of the fruit of the trees of the garden;
41467	1570	9	But of the fruit of the tree which thou beholdest in the midst of the garden, God hath said--Ye shall not eat of it, neither shall ye touch it, lest ye die.
41468	1570	10	And the serpent said unto the woman: Ye shall not surely die;
41469	1570	11	For God doth know that in the day ye eat thereof, then your eyes shall be opened, and ye shall be as gods, knowing good and evil.
41470	1570	12	And when the woman saw that the tree was good for food, and that it became pleasant to the eyes, and a tree to be desired to make her wise, she took of the fruit thereof, and did eat, and also gave unto her husband with her, and he did eat.
41471	1570	13	And the eyes of them both were opened, and they knew that they had been naked. And they sewed fig-leaves together and made themselves aprons.
41472	1570	14	And they heard the voice of the Lord God, as they were walking in the garden, in the cool of the day; and Adam and his wife went to hide themselves from the presence of the Lord God amongst the trees of the garden.
41473	1570	15	And I, the Lord God, called unto Adam, and said unto him: Where goest thou?
41474	1570	16	And he said: I heard thy voice in the garden, and I was afraid, because I beheld that I was naked, and I hid myself.
41475	1570	17	And I, the Lord God, said unto Adam: Who told thee thou wast naked? Hast thou eaten of the tree whereof I commanded thee that thou shouldst not eat, if so thou shouldst surely die?
41476	1570	18	And the man said: The woman thou gavest me, and commandest that she should remain with me, she gave me of the fruit of the tree and I did eat.
41477	1570	19	And I, the Lord God, said unto the woman: What is this thing which thou hast done? And the woman said: The serpent beguiled me, and I did eat.
41478	1570	20	And I, the Lord God, said unto the serpent: Because thou hast done this thou shalt be cursed above all cattle, and above every beast of the field; upon thy belly shalt thou go, and dust shalt thou eat all the days of thy life;
41479	1570	21	And I will put enmity between thee and the woman, between thy seed and her seed; and he shall bruise thy head, and thou shalt bruise his heel.
41480	1570	22	Unto the woman, I, the Lord God, said: I will greatly multiply thy sorrow and thy conception. In sorrow thou shalt bring forth children, and thy desire shall be to thy husband, and he shall rule over thee.
41481	1570	23	And unto Adam, I, the Lord God, said: Because thou hast hearkened unto the voice of thy wife, and hast eaten of the fruit of the tree of which I commanded thee, saying--Thou shalt not eat of it, cursed shall be the ground for thy sake; in sorrow shalt thou eat of it all the days of thy life.
41482	1570	24	Thorns also, and thistles shall it bring forth to thee, and thou shalt eat the herb of the field.
41483	1570	25	By the sweat of thy face shalt thou eat bread, until thou shalt return unto the ground--for thou shalt surely die--for out of it wast thou taken: for dust thou wast, and unto dust shalt thou return.
41484	1570	26	And Adam called his wife's name Eve, because she was the mother of all living; for thus have I, the Lord God, called the first of all women, which are many.
41485	1570	27	Unto Adam, and also unto his wife, did I, the Lord God, make coats of skins, and clothed them.
41486	1570	28	And I, the Lord God, said unto mine Only Begotten: Behold, the man is become as one of us to know good and evil; and now lest he put forth his hand and partake also of the tree of life, and eat and live forever,
41487	1570	29	Therefore I, the Lord God, will send him forth from the Garden of Eden, to till the ground from whence he was taken;
41488	1570	30	For as I, the Lord God, liveth, even so my words cannot return void, for as they go forth out of my mouth they must be fulfilled.
41489	1570	31	So I drove out the man, and I placed at the east of the Garden of Eden, cherubim and a flaming sword, which turned every way to keep the way of the tree of life.
41490	1570	32	(And these are the words which I spake unto my servant Moses, and they are true even as I will; and I have spoken them unto you. See thou show them unto no man, until I command you, except to them that believe. Amen.)
41491	1571	1	AND it came to pass that after I, the Lord God, had driven them out, that Adam began to till the earth, and to have dominion over all the beasts of the field, and to eat his bread by the sweat of his brow, as I the Lord had commanded him. And Eve, also, his wife, did labor with him.
41492	1571	2	And Adam knew his wife, and she bare unto him sons and daughters, and they began to multiply and to replenish the earth.
41493	1571	3	And from that time forth, the sons and daughters of Adam began to divide two and two in the land, and to till the land, and to tend flocks, and they also begat sons and daughters.
41494	1571	4	And Adam and Eve, his wife, called upon the name of the Lord, and they heard the voice of the Lord from the way toward the Garden of Eden, speaking unto them, and they saw him not; for they were shut out from his presence.
41495	1571	5	And he gave unto them commandments, that they should worship the Lord their God, and should offer the firstlings of their flocks, for an offering unto the Lord. And Adam was obedient unto the commandments of the Lord.
41496	1571	6	And after many days an angel of the Lord appeared unto Adam, saying: Why dost thou offer sacrifices unto the Lord? And Adam said unto him: I know not, save the Lord commanded me.
41497	1571	7	And then the angel spake, saying: This thing is a similitude of the sacrifice of the Only Begotten of the Father, which is full of grace and truth.
41498	1571	8	Wherefore, thou shalt do all that thou doest in the name of the Son, and thou shalt repent and call upon God in the name of the Son forevermore.
41499	1571	9	And in that day the Holy Ghost fell upon Adam, which beareth record of the Father and the Son, saying: I am the Only Begotten of the Father from the beginning, henceforth and forever, that as thou hast fallen thou mayest be redeemed, and all mankind, even as many as will.
41500	1571	10	And in that day Adam blessed God and was filled, and began to prophesy concerning all the families of the earth, saying: Blessed be the name of God, for because of my transgression my eyes are opened, and in this life I shall have joy, and again in the flesh I shall see God.
41501	1571	11	And Eve, his wife, heard all these things and was glad, saying: Were it not for our transgression we never should have had seed, and never should have known good and evil, and the joy of our redemption, and the eternal life which God giveth unto all the obedient.
41502	1571	12	And Adam and Eve blessed the name of God, and they made all things known unto their sons and their daughters.
41503	1571	13	And Satan came among them, saying: I am also a son of God; and he commanded them, saying: Believe it not; and they believed it not, and they loved Satan more than God. And men began from that time forth to be carnal, sensual, and devilish.
41504	1571	14	And the Lord God called upon men by the Holy Ghost everywhere and commanded them that they should repent;
41505	1571	15	And as many as believed in the Son, and repented of their sins, should be saved; and as many as believed not and repented not, should be damned; and the words went forth out of the mouth of God in a firm decree; wherefore they must be fulfilled.
41506	1571	16	And Adam and Eve, his wife, ceased not to call upon God. And Adam knew Eve his wife, and she conceived and bare Cain, and said: I have gotten a man from the Lord; wherefore he may not reject his words. But behold, Cain hearkened not, saying: Who is the Lord that I should know him?
41507	1571	17	And she again conceived and bare his brother Abel. And Abel hearkened unto the voice of the Lord. And Abel was a keeper of sheep, but Cain was a tiller of the ground.
41508	1571	18	And Cain loved Satan more than God. And Satan commanded him, saying: Make an offering unto the Lord.
41509	1571	19	And in process of time it came to pass that Cain brought of the fruit of the ground an offering unto the Lord.
41510	1571	20	And Abel he also brought of the firstlings of his flock, and of the fat thereof. And the Lord had respect unto Abel, and to his offering;
41511	1571	21	But unto Cain, and to his offering, he had not respect. Now Satan knew this, and it pleased him. And Cain was very wroth, and his countenance fell.
41512	1571	22	And the Lord said unto Cain: Why art thou wroth? Why is thy countenance fallen?
41513	1571	23	If thou doest well, thou shalt be accepted. And if thou doest not well, sin lieth at the door, and Satan desireth to have thee; and except thou shalt hearken unto my commandments, I will deliver thee up, and it shall be unto thee according to his desire. And thou shalt rule over him;
41514	1571	24	For from this time forth thou shalt be the father of his lies; thou shalt be called Perdition; for thou wast also before the world.
41515	1571	25	And it shall be said in time to come--That these abominations were had from Cain; for he rejected the greater counsel which was had from God; and this is a cursing which I will put upon thee, except thou repent.
41516	1571	26	And Cain was wroth, and listened not any more to the voice of the Lord, neither to Abel, his brother, who walked in holiness before the Lord.
41517	1571	27	And Adam and his wife mourned before the Lord, because of Cain and his brethren.
41518	1571	28	And it came to pass that Cain took one of his brothers' daughters to wife, and they loved Satan more than God.
41519	1571	29	And Satan said unto Cain: Swear unto me by thy throat, and if thou tell it thou shalt die; and swear thy brethren by their heads, and by the living God, that they tell it not; for if they tell it, they shall surely die; and this that thy father may not know it; and this day I will deliver thy brother Abel into thine hands.
41520	1571	30	And Satan sware unto Cain that he would do according to his commands. And all these things were done in secret.
41521	1571	31	And Cain said: Truly I am Mahan, the master of this great secret, that I may murder and get gain. Wherefore Cain was called Master Mahan, and he gloried in his wickedness.
41522	1571	32	And Cain went into the field, and Cain talked with Abel, his brother. And it came to pass that while they were in the field, Cain rose up against Abel, his brother, and slew him.
41523	1571	33	And Cain gloried in that which he had done, saying: I am free; surely the flocks of my brother falleth into my hands.
41524	1571	34	And the Lord said unto Cain: Where is Abel, thy brother? And he said: I know not. Am I my brother's keeper?
41525	1571	35	And the Lord said: What hast thou done? The voice of thy brother's blood cries unto me from the ground.
41526	1571	36	And now thou shalt be cursed from the earth which hath opened her mouth to receive thy brother's blood from thy hand.
41527	1571	37	When thou tillest the ground it shall not henceforth yield unto thee her strength. A fugitive and a vagabond shalt thou be in the earth.
41528	1571	38	And Cain said unto the Lord: Satan tempted me because of my brother's flocks. And I was wroth also; for his offering thou didst accept and not mine; my punishment is greater than I can bear.
41529	1571	39	Behold thou hast driven me out this day from the face of the Lord, and from thy face shall I be hid; and I shall be a fugitive and a vagabond in the earth; and it shall come to pass, that he that findeth me will slay me, because of mine iniquities, for these things are not hid from the Lord.
41530	1571	40	And I the Lord said unto him: Whosoever slayeth thee, vengeance shall be taken on him sevenfold. And I the Lord set a mark upon Cain, lest any finding him should kill him.
41531	1571	41	And Cain was shut out from the presence of the Lord, and with his wife and many of his brethren dwelt in the land of Nod, on the east of Eden.
41532	1571	42	And Cain knew his wife, and she conceived and bare Enoch, and he also begat many sons and daughters. And he builded a city, and he called the name of the city after the name of his son, Enoch.
41533	1571	43	And unto Enoch was born Irad, and other sons and daughters. And Irad begat Mahujael, and other sons and daughters. And Mahujael begat Methusael, and other sons and daughters. And Methusael begat Lamech.
41534	1571	44	And Lamech took unto himself two wives; the name of one being Adah, and the name of the other, Zillah.
41535	1571	45	And Adah bare Jabal; he was the father of such as dwell in tents, and they were keepers of cattle; and his brother's name was Jubal, who was the father of all such as handle the harp and organ.
41536	1571	46	And Zillah, she also bare Tubal Cain, an instructor of every artificer in brass and iron. And the sister of Tubal Cain was called Naamah.
41537	1571	47	And Lamech said unto his wives, Adah and Zillah: Hear my voice, ye wives of Lamech, hearken unto my speech; for I have slain a man to my wounding, and a young man to my hurt.
41538	1571	48	If Cain shall be avenged sevenfold, truly Lamech shall be seventy and seven fold;
41539	1571	49	For Lamech having entered into a covenant with Satan, after the manner of Cain, wherein he became Master Mahan, master of that great secret which was administered unto Cain by Satan; and Irad, the son of Enoch, having known their secret, began to reveal it unto the sons of Adam;
41540	1571	50	Wherefore Lamech, being angry, slew him, not like unto Cain, his brother Abel, for the sake of getting gain, but he slew him for the oath's sake.
41541	1571	51	For, from the days of Cain, there was a secret combination, and their works were in the dark, and they knew every man his brother.
41542	1571	52	Wherefore the Lord cursed Lamech, and his house, and all them that had covenanted with Satan; for they kept not the commandments of God, and it displeased God, and he ministered not unto them, and their works were abominations, and began to spread among all the sons of men. And it was among the sons of men.
41543	1571	53	And among the daughters of men these things were not spoken, because that Lamech had spoken the secret unto his wives, and they rebelled against him, and declared these things abroad, and had not compassion;
41544	1571	54	Wherefore Lamech was despised, and cast out, and came not among the sons of men, lest he should die.
41545	1571	55	And thus the works of darkness began to prevail among all the sons of men.
41546	1571	56	And God cursed the earth with a sore curse, and was angry with the wicked, with all the sons of men whom he had made;
41547	1571	57	For they would not hearken unto his voice, nor believe on his Only Begotten Son, even him whom he declared should come in the meridian of time, who was prepared from before the foundation of the world.
41548	1571	58	And thus the Gospel began to be preached, from the beginning, being declared by holy angels sent forth from the presence of God, and by his own voice, and by the gift of the Holy Ghost.
41549	1571	59	And thus all things were confirmed unto Adam, by an holy ordinance, and the Gospel preached, and a decree sent forth, that it should be in the world, until the end thereof; and thus it was. Amen.
41550	1572	1	AND Adam hearkened unto the voice of God, and called upon his sons to repent.
41551	1572	2	And Adam knew his wife again, and she bare a son, and he called his name Seth. And Adam glorified the name of God; for he said: God hath appointed me another seed, instead of Abel, whom Cain slew.
41552	1572	3	And God revealed himself unto Seth, and he rebelled not, but offered an acceptable sacrifice, like unto his brother Abel. And to him also was born a son, and he called his name Enos.
41553	1572	4	And then began these men to call upon the name of the Lord, and the Lord blessed them;
41554	1572	5	And a book of remembrance was kept, in the which was recorded, in the language of Adam, for it was given unto as many as called upon God to write by the spirit of inspiration;
41555	1572	6	And by them their children were taught to read and write, having a language which was pure and undefiled.
41556	1572	7	Now this same Priesthood, which was in the beginning, shall be in the end of the world also.
41557	1572	8	Now this prophecy Adam spake, as he was moved upon by the Holy Ghost, and a genealogy was kept of the children of God. And this was the book of the generations of Adam, saying: In the day that God created man, in the likeness of God made he him;
41558	1572	9	In the image of his own body, male and female, created he them, and blessed them, and called their name Adam, in the day when they were created and became living souls in the land upon the footstool of God.
41559	1572	10	And Adam lived one hundred and thirty years, and begat a son in his own likeness, after his own image, and called his name Seth.
41560	1572	11	And the days of Adam, after he had begotten Seth, were eight hundred years, and he begat many sons and daughters;
41561	1572	12	And all the days that Adam lived were nine hundred and thirty years, and he died.
41562	1572	13	Seth lived one hundred and five years, and begat Enos, and prophesied in all his days, and taught his son Enos in the ways of God; wherefore Enos prophesied also.
41563	1572	14	And Seth lived, after he begat Enos, eight hundred and seven years, and begat many sons and daughters.
41564	1572	15	And the children of men were numerous upon all the face of the land. And in those days Satan had great dominion among men, and raged in their hearts; and from thenceforth came wars and bloodshed; and a man's hand was against his own brother, in administering death, because of secret works, seeking for power.
41565	1572	16	All the days of Seth were nine hundred and twelve years, and he died.
41566	1572	17	And Enos lived ninety years, and begat Cainan. And Enos and the residue of the people of God came out from the land, which was called Shulon, and dwelt in a land of promise, which he called after his own son, whom he had named Cainan.
41567	1572	18	And Enos lived, after he begat Cainan, eight hundred and fifteen years, and begat many sons and daughters. And all the days of Enos were nine hundred and five years, and he died.
41568	1572	19	And Cainan lived seventy years, and begat Mahalaleel; and Cainan lived after he begat Mahalaleel eight hundred and forty years, and begat sons and daughters. And all the days of Cainan were nine hundred and ten years, and he died.
41569	1572	20	And Mahalaleel lived sixty-five years, and begat Jared; and Mahalaleel lived, after he begat Jared, eight hundred and thirty years, and begat sons and daughters. And all the days of Mahalaleel were eight hundred and ninety-five years, and he died.
41570	1572	21	And Jared lived one hundred and sixty-two years, and begat Enoch; and Jared lived, after he begat Enoch, eight hundred years, and begat sons and daughters. And Jared taught Enoch in all the ways of God.
41571	1572	22	And this is the genealogy of the sons of Adam, who was the son of God, with whom God, himself, conversed.
41572	1572	23	And they were preachers of righteousness, and spake and prophesied, and called upon all men, everywhere, to repent; and faith was taught unto the children of men.
41573	1572	24	And it came to pass that all the days of Jared were nine hundred and sixty-two years, and he died.
41574	1572	25	And Enoch lived sixty-five years, and begat Methuselah.
41575	1572	26	And it came to pass that Enoch journeyed in the land, among the people; and as he journeyed, the Spirit of God descended out of heaven, and abode upon him.
41576	1572	27	And he heard a voice from heaven, saying: Enoch, my son, prophesy unto this people, and say unto them--Repent, for thus saith the Lord: I am angry with this people, and my fierce anger is kindled against them; for their hearts have waxed hard, and their ears are dull of hearing, and their eyes cannot see afar off;
41577	1572	28	And for these many generations, ever since the day that I created them, have they gone astray, and have denied me, and have sought their own counsels in the dark; and in their own abominations have they devised murder, and have not kept the commandments, which I gave unto their father, Adam.
41578	1572	29	Wherefore, they have foresworn themselves, and, by their oaths, they have brought upon themselves death; and a hell I have prepared for them, if they repent not;
41579	1572	30	And this is a decree, which I have sent forth in the beginning of the world, from my own mouth, from the foundation thereof, and by the mouths of my servants, thy fathers, have I decreed it, even as it shall be sent forth in the world, unto the ends thereof.
41580	1572	31	And when Enoch had heard these words, he bowed himself to the earth, before the Lord, and spake before the Lord, saying: Why is it that I have found favor in thy sight, and am but a lad, and all the people hate me; for I am slow of speech; wherefore am I thy servant?
41581	1572	32	And the Lord said unto Enoch: Go forth and do as I have commanded thee, and no man shall pierce thee. Open thy mouth, and it shall be filled, and I will give thee utterance, for all flesh is in my hands, and I will do as seemeth me good.
41582	1572	33	Say unto this people: Choose ye this day, to serve the Lord God who made you.
41583	1572	34	Behold my Spirit is upon you, wherefore all thy words will I justify; and the mountains shall flee before you, and the rivers shall turn from their course; and thou shalt abide in me, and I in you; therefore walk with me.
41584	1572	35	And the Lord spake unto Enoch, and said unto him: Anoint thine eyes with clay, and wash them, and thou shalt see. And he did so.
41585	1572	36	And he beheld the spirits that God had created; and he beheld also things which were not visible to the natural eye; and from thenceforth came the saying abroad in the land: A seer hath the Lord raised up unto his people.
41586	1572	37	And it came to pass that Enoch went forth in the land, among the people, standing upon the hills and the high places, and cried with a loud voice, testifying against their works; and all men were offended because of him.
41587	1572	38	And they came forth to hear him, upon the high places, saying unto the tent-keepers: Tarry ye here and keep the tents, while we go yonder to behold the seer, for he prophesieth, and there is a strange thing in the land; a wild man hath come among us.
41588	1572	39	And it came to pass when they heard him, no man laid hands on him; for fear came on all them that heard him; for he walked with God.
41589	1572	40	And there came a man unto him, whose name was Mahijah, and said unto him: Tell us plainly who thou art, and from whence thou comest?
41590	1572	41	And he said unto them: I came out from the land of Cainan, the land of my fathers, a land of righteousness unto this day. And my father taught me in all the ways of God.
41591	1572	42	And it came to pass, as I journeyed from the land of Cainan, by the sea east, I beheld a vision; and lo, the heavens I saw, and the Lord spake with me, and gave me commandment; wherefore, for this cause, to keep the commandment, I speak forth these words.
41592	1572	43	And Enoch continued his speech, saying: The Lord which spake with me, the same is the God of heaven, and he is my God, and your God, and ye are my brethren, and why counsel ye yourselves, and deny the God of heaven?
41593	1572	44	The heavens he made; the earth is his footstool; and the foundation thereof is his. Behold, he laid it, an host of men hath he brought in upon the face thereof.
41594	1572	45	And death hath come upon our fathers; nevertheless we know them, and cannot deny, and even the first of all we know, even Adam.
41595	1572	46	For a book of remembrance we have written among us, according to the pattern given by the finger of God; and it is given in our own language.
41596	1572	47	And as Enoch spake forth the words of God, the people trembled, and could not stand in his presence.
41597	1572	48	And he said unto them: Because that Adam fell, we are; and by his fall came death; and we are made partakers of misery and woe.
41598	1572	49	Behold Satan hath come among the children of men, and tempteth them to worship him; and men have become carnal, sensual, and devilish, and are shut out from the presence of God.
41599	1572	50	But God hath made known unto our fathers that all men must repent.
41600	1572	51	And he called upon our father Adam by his own voice, saying: I am God; I made the world, and men before they were in the flesh.
41601	1572	52	And he also said unto him: If thou wilt turn unto me, and hearken unto my voice, and believe, and repent of all thy transgressions, and be baptized, even in water, in the name of mine Only Begotten Son, who is full of grace and truth, which is Jesus Christ, the only name which shall be given under heaven, whereby salvation shall come unto the children of men, ye shall receive the gift of the Holy Ghost, asking all things in his name, and whatsoever ye shall ask, it shall be given you.
41602	1572	53	And our father Adam spake unto the Lord, and said: Why is it that men must repent and be baptized in water? And the Lord said unto Adam: Behold I have forgiven thee thy transgression in the Garden of Eden.
41603	1572	54	Hence came the saying abroad among the people, that the Son of God hath atoned for original guilt, wherein the sins of the parents cannot be answered upon the heads of the children, for they are whole from the foundation of the world.
41604	1572	55	And the Lord spake unto Adam, saying: Inasmuch as thy children are conceived in sin, even so when they begin to grow up, sin conceiveth in their hearts, and they taste the bitter, that they may know to prize the good.
41605	1572	56	And it is given unto them to know good from evil; wherefore they are agents unto themselves, and I have given unto you another law and commandment.
41606	1572	57	Wherefore teach it unto your children, that all men, everywhere, must repent, or they can in nowise inherit the kingdom of God, for no unclean thing can dwell there, or dwell in his presence; for, in the language of Adam, Man of Holiness is his name, and the name of his Only Begotten is the Son of Man, even Jesus Christ, a righteous Judge, who shall come in the meridian of time.
41607	1572	58	Therefore I give unto you a commandment, to teach these things freely unto your children, saying:
41608	1572	59	That by reason of transgression cometh the fall, which fall bringeth death, and inasmuch as ye were born into the world by water, and blood, and the spirit, which I have made, and so became of dust a living soul, even so ye must be born again into the kingdom of heaven, of water, and of the Spirit, and be cleansed by blood, even the blood of mine Only Begotten; that ye might be sanctified from all sin, and enjoy the words of eternal life in this world, and eternal life in the world to come, even immortal glory;
41609	1572	60	For by the water ye keep the commandment; by the Spirit ye are justified, and by the blood ye are sanctified;
41610	1572	61	Therefore it is given to abide in you; the record of heaven; the Comforter; the peaceable things of immortal glory; the truth of all things; that which quickeneth all things, which maketh alive all things; that which knoweth all things, and hath all power according to wisdom, mercy, truth, justice, and judgment.
41611	1572	62	And now, behold, I say unto you: This is the plan of salvation unto all men, through the blood of mine Only Begotten, who shall come in the meridian of time.
41612	1572	63	And behold, all things have their likeness, and all things are created and made to bear record of me, both things which are temporal, and things which are spiritual; things which are in the heavens above, and things which are on the earth, and things which are in the earth, and things which are under the earth, both above and beneath: all things bear record of me.
41613	1572	64	And it came to pass, when the Lord had spoken with Adam, our father, that Adam cried unto the Lord, and he was caught away by the Spirit of the Lord, and was carried down into the water, and was laid under the water, and was brought forth out of the water.
41614	1572	65	And thus he was baptized, and the Spirit of God descended upon him, and thus he was born of the Spirit, and became quickened in the inner man.
41615	1572	66	And he heard a voice out of heaven, saying: Thou art baptized with fire, and with the Holy Ghost. This is the record of the Father, and the Son, from henceforth and forever;
41616	1572	67	And thou art after the order of him who was without beginning of days or end of years, from all eternity to all eternity.
41617	1572	68	Behold, thou art one in me, a son of God; and thus may all become my sons. Amen.
41618	1573	1	AND it came to pass that Enoch continued his speech, saying: Behold, our father Adam taught these things, and many have believed and become the sons of God, and many have believed not, and have perished in their sins, and are looking forth with fear, in torment, for the fiery indignation of the wrath of God to be poured out upon them.
41619	1573	2	And from that time forth Enoch began to prophesy, saying unto the people, that: As I was journeying, and stood upon the place Mahujah, and cried unto the Lord, there came a voice out of heaven, saying--Turn ye, and get ye upon the mount Simeon.
41620	1573	3	And it came to pass that I turned and went up on the mount; and as I stood upon the mount, I beheld the heavens open, and I was clothed upon with glory;
41621	1573	4	And I saw the Lord; and he stood before my face, and he talked with me, even as a man talketh one with another, face to face; and he said unto me: Look, and I will show unto thee the world for the space of many generations.
41622	1573	5	And it came to pass that I beheld in the valley of Shum, and lo, a great people which dwelt in tents, which were the people of Shum.
41623	1573	6	And again the Lord said unto me: Look; and I looked towards the north, and I beheld the people of Canaan, which dwelt in tents.
41624	1573	7	And the Lord said unto me: Prophesy; and I prophesied, saying: Behold the people of Canaan, which are numerous, shall go forth in battle array against the people of Shum, and shall slay them that they shall utterly be destroyed; and the people of Canaan shall divide themselves in the land, and the land shall be barren and unfruitful, and none other people shall dwell there but the people of Canaan;
41625	1573	8	For behold, the Lord shall curse the land with much heat, and the barrenness thereof shall go forth forever; and there was a blackness came upon all the children of Canaan, that they were despised among all people.
41626	1573	9	And it came to pass that the Lord said unto me: Look; and I looked, and I beheld the land of Sharon, and the land of Enoch, and the land of Omner, and the land of Heni, and the land of Shem, and the land of Haner, and the land of Hanannihah, and all the inhabitants thereof;
41627	1573	10	And the Lord said unto me: Go to this people, and say unto them--Repent, lest I come out and smite them with a curse, and they die.
41628	1573	11	And he gave unto me a commandment that I should baptize in the name of the Father, and of the Son, which is full of grace and truth, and of the Holy Ghost, which beareth record of the Father and the Son.
41629	1573	12	And it came to pass that Enoch continued to call upon all the people, save it were the people of Canaan, to repent;
41630	1573	13	And so great was the faith of Enoch that he led the people of God, and their enemies came to battle against them; and he spake the word of the Lord, and the earth trembled, and the mountains fled, even according to his command; and the rivers of water were turned out of their course; and the roar of the lions was heard out of the wilderness; and all nations feared greatly, so powerful was the word of Enoch, and so great was the power of the language which God had given him.
41631	1573	14	There also came up a land out of the depth of the sea, and so great was the fear of the enemies of the people of God, that they fled and stood afar off and went upon the land which came up out of the depth of the sea.
41632	1573	15	And the giants of the land, also, stood afar off; and there went forth a curse upon all people that fought against God;
41633	1573	16	And from that time forth there were wars and bloodshed among them; but the Lord came and dwelt with his people, and they dwelt in righteousness.
41634	1573	17	The fear of the Lord was upon all nations, so great was the glory of the Lord, which was upon his people. And the Lord blessed the land, and they were blessed upon the mountains, and upon the high places, and did flourish.
41635	1573	18	And the Lord called his people ZION, because they were of one heart and one mind, and dwelt in righteousness; and there was no poor among them.
41636	1573	19	And Enoch continued his preaching in righteousness unto the people of God. And it came to pass in his days, that he built a city that was called the City of Holiness, even ZION.
41637	1573	20	And it came to pass that Enoch talked with the Lord; and he said unto the Lord: Surely Zion shall dwell in safety forever. But the Lord said unto Enoch: Zion have I blessed, but the residue of the people have I cursed.
41638	1573	21	And it came to pass that the Lord showed unto Enoch all the inhabitants of the earth; and he beheld, and lo, Zion, in process of time, was taken up into heaven. And the Lord said unto Enoch: Behold mine abode forever.
41639	1573	22	And Enoch also beheld the residue of the people which were the sons of Adam; and they were a mixture of all the seed of Adam save it was the seed of Cain, for the seed of Cain were black, and had not place among them.
41640	1573	23	And after that Zion was taken up into heaven, Enoch beheld, and lo, all the nations of the earth were before him;
41641	1573	24	And there came generation upon generation; and Enoch was high and lifted up, even in the bosom of the Father, and of the Son of Man; and behold, the power of Satan was upon all the face of the earth.
41642	1573	25	And he saw angels descending out of heaven; and he heard a loud voice saying: Wo, wo be unto the inhabitants of the earth.
41643	1573	26	And he beheld Satan; and he had a great chain in his hand, and it veiled the whole face of the earth with darkness; and he looked up and laughed, and his angels rejoiced.
41644	1573	27	And Enoch beheld angels descending out of heaven, bearing testimony of the Father and Son; and the Holy Ghost fell on many, and they were caught up by the powers of heaven into Zion.
41645	1573	28	And it came to pass that the God of heaven looked upon the residue of the people, and he wept; and Enoch bore record of it, saying: How is it that the heavens weep, and shed forth their tears as the rain upon the mountains?
41646	1573	29	And Enoch said unto the Lord: How is it that thou canst weep, seeing thou art holy, and from all eternity to all eternity?
41647	1573	30	And were it possible that man could number the particles of the earth, yea, millions of earths like this, it would not be a beginning to the number of thy creations; and thy curtains are stretched out still; and yet thou art there, and thy bosom is there; and also thou art just; thou art merciful and kind forever;
41648	1573	31	And thou hast taken Zion to thine own bosom, from all thy creations, from all eternity to all eternity; and naught but peace, justice, and truth is the habitation of thy throne; and mercy shall go before thy face and have no end; how is it thou canst weep?
41649	1573	32	The Lord said unto Enoch: Behold these thy brethren; they are the workmanship of mine own hands, and I gave unto them their knowledge, in the day I created them; and in the Garden of Eden, gave I unto man his agency;
41650	1573	33	And unto thy brethren have I said, and also given commandment, that they should love one another, and that they should choose me, their Father; but behold, they are without affection, and they hate their own blood;
41651	1573	34	And the fire of mine indignation is kindled against them; and in my hot displeasure will I send in the floods upon them, for my fierce anger is kindled against them.
41652	1573	35	Behold, I am God; Man of Holiness is my name; Man of Counsel is my name; and Endless and Eternal is my name, also.
41653	1573	36	Wherefore, I can stretch forth mine hands and hold all the creations which I have made; and mine eye can pierce them also, and among all the workmanship of mine hands there has not been so great wickedness as among thy brethren.
41654	1573	37	But behold, their sins shall be upon the heads of their fathers; Satan shall be their father, and misery shall be their doom; and the whole heavens shall weep over them, even all the workmanship of mine hands; wherefore should not the heavens weep, seeing these shall suffer?
41655	1573	38	But behold, these which thine eyes are upon shall perish in the floods; and behold, I will shut them up; a prison have I prepared for them.
41656	1573	39	And That which I have chosen hath pled before my face. Wherefore, he suffereth for their sins; inasmuch as they will repent in the day that my Chosen shall return unto me, and until that day they shall be in torment;
41657	1573	40	Wherefore, for this shall the heavens weep, yea, and all the workmanship of mine hands.
41658	1573	41	And it came to pass that the Lord spake unto Enoch, and told Enoch all the doings of the children of men; wherefore Enoch knew, and looked upon their wickedness, and their misery, and wept and stretched forth his arms, and his heart swelled wide as eternity; and his bowels yearned; and all eternity shook.
41659	1573	42	And Enoch also saw Noah, and his family; that the posterity of all the sons of Noah should be saved with a temporal salvation;
41660	1573	43	Wherefore Enoch saw that Noah built an ark; and that the Lord smiled upon it, and held it in his own hand; but upon the residue of the wicked the floods came and swallowed them up.
41661	1573	44	And as Enoch saw this, he had bitterness of soul, and wept over his brethren, and said unto the heavens: I will refuse to be comforted; but the Lord said unto Enoch: Lift up your heart, and be glad; and look.
41662	1573	45	And it came to pass that Enoch looked; and from Noah, he beheld all the families of the earth; and he cried unto the Lord, saying: When shall the day of the Lord come? When shall the blood of the Righteous be shed, that all they that mourn may be sanctified and have eternal life?
41663	1573	46	And the Lord said: It shall be in the meridian of time, in the days of wickedness and vengeance.
41664	1573	47	And behold, Enoch saw the day of the coming of the Son of Man, even in the flesh; and his soul rejoiced, saying: The Righteous is lifted up, and the Lamb is slain from the foundation of the world; and through faith I am in the bosom of the Father, and behold, Zion is with me.
41665	1573	48	And it came to pass that Enoch looked upon the earth; and he heard a voice from the bowels thereof, saying: Wo, wo is me, the mother of men; I am pained, I am weary, because of the wickedness of my children. When shall I rest, and be cleansed from the filthiness which is gone forth out of me? When will my Creator sanctify me, that I may rest, and righteousness for a season abide upon my face?
41666	1573	49	And when Enoch heard the earth mourn, he wept, and cried unto the Lord, saying: O Lord, wilt thou not have compassion upon the earth? Wilt thou not bless the children of Noah?
41667	1573	50	And it came to pass that Enoch continued his cry unto the Lord, saying: I ask thee, O Lord, in the name of thine Only Begotten, even Jesus Christ, that thou wilt have mercy upon Noah and his seed, that the earth might never more be covered by the floods.
41668	1573	51	And the Lord could not withhold; and he covenanted with Enoch, and sware unto him with an oath, that he would stay the floods; that he would call upon the children of Noah;
41669	1573	52	And he sent forth an unalterable decree, that a remnant of his seed should always be found among all nations, while the earth should stand;
41670	1573	53	And the Lord said: Blessed is he through whose seed Messiah shall come; for he saith--I am Messiah, the King of Zion, the Rock of Heaven, which is broad as eternity; whoso cometh in at the gate and climbeth up by me shall never fall; wherefore, blessed are they of whom I have spoken, for they shall come forth with songs of everlasting joy.
41671	1573	54	And it came to pass that Enoch cried unto the Lord, saying: When the Son of Man cometh in the flesh, shall the earth rest? I pray thee, show me these things.
41672	1573	55	And the Lord said unto Enoch: Look, and he looked and beheld the Son of Man lifted up on the cross, after the manner of men;
41673	1573	56	And he heard a loud voice; and the heavens were veiled; and all the creations of God mourned; and the earth groaned; and the rocks were rent; and the saints arose, and were crowned at the right hand of the Son of Man, with crowns of glory;
41674	1573	57	And as many of the spirits as were in prison came forth, and stood on the right hand of God; and the remainder were reserved in chains of darkness until the judgment of the great day.
41675	1573	58	And again Enoch wept and cried unto the Lord, saying: When shall the earth rest?
41676	1573	59	And Enoch beheld the Son of Man ascend up unto the Father; and he called unto the Lord, saying: Wilt thou not come again upon the earth? Forasmuch as thou art God, and I know thee, and thou hast sworn unto me, and commanded me that I should ask in the name of thine Only Begotten; thou hast made me, and given unto me a right to thy throne, and not of myself, but through thine own grace; wherefore, I ask thee if thou wilt not come again on the earth.
41677	1573	60	And the Lord said unto Enoch: As I live, even so will I come in the last days, in the days of wickedness and vengeance, to fulfil the oath which I have made unto you concerning the children of Noah;
41678	1573	61	And the day shall come that the earth shall rest, but before that day the heavens shall be darkened, and a veil of darkness shall cover the earth; and the heavens shall shake, and also the earth; and great tribulations shall be among the children of men, but my people will I preserve;
41679	1573	62	And righteousness will I send down out of heaven; and truth will I send forth out of the earth, to bear testimony of mine Only Begotten; his resurrection from the dead; yea, and also the resurrection of all men; and righteousness and truth will I cause to sweep the earth as with a flood, to gather out mine elect from the four quarters of the earth, unto a place which I shall prepare, an Holy City, that my people may gird up their loins, and be looking forth for the time of my coming; for there shall be my tabernacle, and it shall be called Zion, a New Jerusalem.
41680	1573	63	And the Lord said unto Enoch: Then shalt thou and all thy city meet them there, and we will receive them into our bosom, and they shall see us; and we will fall upon their necks, and they shall fall upon our necks, and we will kiss each other;
41681	1573	64	And there shall be mine abode, and it shall be Zion, which shall come forth out of all the creations which I have made; and for the space of a thousand years the earth shall rest.
41682	1573	65	And it came to pass that Enoch saw the day of the coming of the Son of Man, in the last days, to dwell on the earth in righteousness for the space of a thousand years;
41683	1573	66	But before that day he saw great tribulations among the wicked; and he also saw the sea, that it was troubled, and men's hearts failing them, looking forth with fear for the judgments of the Almighty God, which should come upon the wicked.
41684	1573	67	And the Lord showed Enoch all things, even unto the end of the world; and he saw the day of the righteous, the hour of their redemption, and received a fulness of joy;
41685	1573	68	And all the days of Zion, in the days of Enoch, were three hundred and sixty-five years.
41686	1573	69	And Enoch and all his people walked with God, and he dwelt in the midst of Zion; and it came to pass that Zion was not, for God received it up into his own bosom; and from thence went forth the saying, ZION IS FLED.
41687	1574	1	AND all the days of Enoch were four hundred and thirty years.
41688	1574	2	And it came to pass that Methuselah, the son of Enoch, was not taken, that the covenants of the Lord might be fulfilled, which he made to Enoch; for he truly covenanted with Enoch that Noah should be of the fruit of his loins.
41689	1574	3	And it came to pass that Methuselah prophesied that from his loins should spring all the kingdoms of the earth (through Noah), and he took glory unto himself.
41690	1574	4	And there came forth a great famine into the land, and the Lord cursed the earth with a sore curse, and many of the inhabitants thereof died.
41691	1574	5	And it came to pass that Methuselah lived one hundred and eighty-seven years, and begat Lamech;
41692	1574	6	And Methuselah lived, after he begat Lamech, seven hundred and eighty-two years, and begat sons and daughters;
41693	1574	7	And all the days of Methuselah were nine hundred and sixty-nine years, and he died.
41694	1574	8	And Lamech lived one hundred and eighty-two years, and begat a son,
41695	1574	9	And he called his name Noah, saying: This son shall comfort us concerning our work and toil of our hands, because of the ground which the Lord hath cursed.
41696	1574	10	And Lamech lived, after he begat Noah, five hundred and ninety-five years, and begat sons and daughters;
41697	1574	11	And all the days of Lamech were seven hundred and seventy-seven years, and he died.
41698	1574	12	And Noah was four hundred and fifty years old, and begat Japheth; and forty-two years afterward he begat Shem of her who was the mother of Japheth, and when he was five hundred years old he begat Ham.
41699	1574	13	And Noah and his sons hearkened unto the Lord, and gave heed, and they were called the sons of God.
41700	1574	14	And when these men began to multiply on the face of the earth, and daughters were born unto them, the sons of men saw that those daughters were fair, and they took them wives, even as they chose.
41701	1574	15	And the Lord said unto Noah: The daughters of thy sons have sold themselves; for behold mine anger is kindled against the sons of men, for they will not hearken to my voice.
41702	1574	16	And it came to pass that Noah prophesied, and taught the things of God, even as it was in the beginning.
41703	1574	17	And the Lord said unto Noah: My Spirit shall not always strive with man, for he shall know that all flesh shall die; yet his days shall be an hundred and twenty years; and if men do not repent, I will send in the floods upon them.
41704	1574	18	And in those days there were giants on the earth, and they sought Noah to take away his life; but the Lord was with Noah, and the power of the Lord was upon him.
41705	1574	19	And the Lord ordained Noah after his own order, and commanded him that he should go forth and declare his Gospel unto the children of men, even as it was given unto Enoch.
41706	1574	20	And it came to pass that Noah called upon the children of men that they should repent; but they hearkened not unto his words;
41707	1574	21	And also, after that they had heard him, they came up before him, saying: Behold, we are the sons of God; have we not taken unto ourselves the daughters of men? And are we not eating and drinking, and marrying and giving in marriage? And our wives bear unto us children, and the same are mighty men, which are like unto men of old, men of great renown. And they hearkened not unto the words of Noah.
41708	1574	22	And God saw that the wickedness of men had become great in the earth; and every man was lifted up in the imagination of the thoughts of his heart, being only evil continually.
41709	1574	23	And it came to pass that Noah continued his preaching unto the people, saying: Hearken, and give heed unto my words;
41710	1574	24	Believe and repent of your sins and be baptized in the name of Jesus Christ, the Son of God, even as our fathers, and ye shall receive the Holy Ghost, that ye may have all things made manifest; and if ye do not this, the floods will come in upon you; nevertheless they hearkened not.
41711	1574	25	And it repented Noah, and his heart was pained that the Lord had made man on the earth, and it grieved him at the heart.
41712	1574	26	And the Lord said: I will destroy man whom I have created, from the face of the earth, both man and beast, and the creeping things, and the fowls of the air; for it repenteth Noah that I have created them, and that I have made them; and he hath called upon me; for they have sought his life.
41713	1574	27	And thus Noah found grace in the eyes of the Lord; for Noah was a just man, and perfect in his generation; and he walked with God, as did also his three sons, Shem, Ham, and Japheth.
41714	1574	28	The earth was corrupt before God, and it was filled with violence.
41715	1574	29	And God looked upon the earth, and, behold, it was corrupt, for all flesh had corrupted its way upon the earth.
41716	1574	30	And God said unto Noah: The end of all flesh is come before me, for the earth is filled with violence, and behold I will destroy all flesh from off the earth.
41717	1575	1	IN the land of the Chaldeans, at the residence of my fathers, I, Abraham, saw that it was needful for me to obtain another place of residence;
41718	1575	2	And, finding there was greater happiness and peace and rest for me, I sought for the blessings of the fathers, and the right whereunto I should be ordained to administer the same; having been myself a follower of righteousness, desiring also to be one who possessed great knowledge, and to be a greater follower of righteousness, and to possess a greater knowledge, and to be a father of many nations, a prince of peace, and desiring to receive instructions, and to keep the commandments of God, I became a rightful heir, a High Priest, holding the right belonging to the fathers.
41719	1575	3	It was conferred upon me from the fathers; it came down from the fathers, from the beginning of time, yea, even from the beginning, or before the foundation of the earth, down to the present time, even the right of the firstborn, or the first man, who is Adam, or first father, through the fathers unto me.
41720	1575	4	I sought for mine appointment unto the Priesthood according to the appointment of God unto the fathers concerning the seed.
41721	1575	5	My fathers having turned from their righteousness, and from the holy commandments which the Lord their God had given unto them, unto the worshiping of the gods of the heathen, utterly refused to hearken to my voice;
41722	1575	6	For their hearts were set to do evil, and were wholly turned to the god of Elkenah, and the god of Libnah, and the god of Mahmackrah, and the god of Korash, and the god of Pharaoh, king of Egypt;
41723	1575	7	Therefore they turned their hearts to the sacrifice of the heathen in offering up their children unto these dumb idols, and hearkened not unto my voice, but endeavored to take away my life by the hand of the priest of Elkenah. The priest of Elkenah was also the priest of Pharaoh.
41724	1575	8	Now, at this time it was the custom of the priest of Pharaoh, the king of Egypt, to offer up upon the altar which was built in the land of Chaldea, for the offering unto these strange gods, men, women, and children.
41725	1575	9	And it came to pass that the priest made an offering unto the god of Pharaoh, and also unto the god of Shagreel, even after the manner of the Egyptians. Now the god of Shagreel was the sun.
41726	1575	10	Even the thank-offering of a child did the priest of Pharaoh offer upon the altar which stood by the hill called Potiphar's Hill, at the head of the plain of Olishem.
41727	1575	11	Now, this priest had offered upon this altar three virgins at one time, who were the daughters of Onitah, one of the royal descent directly from the loins of Ham. These virgins were offered up because of their virtue; they would not bow down to worship gods of wood or of stone, therefore they were killed upon this altar, and it was done after the manner of the Egyptians.
41728	1575	12	And it came to pass that the priests laid violence upon me, that they might slay me also, as they did those virgins upon this altar; and that you may have a knowledge of this altar, I will refer you to the representation at the commencement of this record.
41729	1575	13	It was made after the form of a bedstead, such as was had among the Chaldeans, and it stood before the gods of Elkenah, Libnah, Mahmackrah, Korash, and also a god like unto that of Pharaoh, king of Egypt.
41730	1575	14	That you may have an understanding of these gods, I have given you the fashion of them in the figures at the beginning, which manner of figures is called by the Chaldeans Rahleenos, which signifies hieroglyphics.
41731	1575	15	And as they lifted up their hands upon me, that they might offer me up and take away my life, behold, I lifted up my voice unto the Lord my God, and the Lord hearkened and heard, and he filled me with the vision of the Almighty, and the angel of his presence stood by me, and immediately unloosed my bands;
41732	1575	16	And his voice was unto me: Abraham, Abraham, behold, my name is Jehovah, and I have heard thee, and have come down to deliver thee, and to take thee away from thy father's house, and from all thy kinsfolk, into a strange land which thou knowest not of;
41733	1575	17	And this because they have turned their hearts away from me, to worship the god of Elkenah, and the god of Libnah, and the god of Mahmackrah, and the god of Korash, and the god of Pharaoh, king of Egypt; therefore I have come down to visit them, and to destroy him who hath lifted up his hand against thee, Abraham, my son, to take away thy life.
41734	1575	18	Behold, I will lead thee by my hand, and I will take thee, to put upon thee my name, even the Priesthood of thy father, and my power shall be over thee.
41735	1575	19	As it was with Noah so shall it be with thee; but through thy ministry my name shall be known in the earth forever, for I am thy God.
41736	1575	20	Behold, Potiphar's Hill was in the land of Ur, of Chaldea. And the Lord broke down the altar of Elkenah, and of the gods of the land, and utterly destroyed them, and smote the priest that he died; and there was great mourning in Chaldea, and also in the court of Pharaoh; which Pharaoh signifies king by royal blood.
41737	1575	21	Now this king of Egypt was a descendant from the loins of Ham, and was a partaker of the blood of the Canaanites by birth.
41738	1575	22	From this descent sprang all the Egyptians, and thus the blood of the Canaanites was preserved in the land.
41739	1575	23	The land of Egypt being first discovered by a woman, who was the daughter of Ham, and the daughter of Egyptus, which in the Chaldean signifies Egypt, which signifies that which is forbidden;
41740	1575	24	When this woman discovered the land it was under water, who afterward settled her sons in it; and thus, from Ham, sprang that race which preserved the curse in the land.
41741	1575	25	Now the first government of Egypt was established by Pharaoh, the eldest son of Egyptus, the daughter of Ham, and it was after the manner of the government of Ham, which was patriarchal.
41742	1575	26	Pharaoh, being a righteous man, established his kingdom and judged his people wisely and justly all his days, seeking earnestly to imitate that order established by the fathers in the first generations, in the days of the first patriarchal reign, even in the reign of Adam, and also of Noah, his father, who blessed him with the blessings of the earth, and with the blessings of wisdom, but cursed him as pertaining to the Priesthood.
41743	1575	27	Now, Pharaoh being of that lineage by which he could not have the right of Priesthood, notwithstanding the Pharaohs would fain claim it from Noah, through Ham, therefore my father was led away by their idolatry;
41744	1575	28	But I shall endeavor, hereafter, to delineate the chronology running back from myself to the beginning of the creation, for the records have come into my hands, which I hold unto this present time.
41745	1575	29	Now, after the priest of Elkenah was smitten that he died, there came a fulfilment of those things which were said unto me concerning the land of Chaldea, that there should be a famine in the land.
41746	1575	30	Accordingly a famine prevailed throughout all the land of Chaldea, and my father was sorely tormented because of the famine, and he repented of the evil which he had determined against me, to take away my life.
41747	1575	31	But the records of the fathers, even the patriarchs, concerning the right of Priesthood, the Lord my God preserved in mine own hands; therefore a knowledge of the beginning of the creation, and also of the planets, and of the stars, as they were made known unto the fathers, have I kept even unto this day, and I shall endeavor to write some of these things upon this record, for the benefit of my posterity that shall come after me.
41748	1576	1	NOW the Lord God caused the famine to wax sore in the land of Ur, insomuch that Haran, my brother, died; but Terah, my father, yet lived in the land of Ur, of the Chaldees.
41749	1576	2	And it came to pass that I, Abraham, took Sarai to wife, and Nahor, my brother, took Milcah to wife, who was the daughter of Haran.
41750	1576	3	Now the Lord had said unto me: Abraham, get thee out of thy country, and from thy kindred, and from thy father's house, unto a land that I will show thee.
41751	1576	4	Therefore I left the land of Ur, of the Chaldees, to go into the land of Canaan; and I took Lot, my brother's son, and his wife, and Sarai my wife; and also my father followed after me, unto the land which we denominated Haran.
41752	1576	5	And the famine abated; and my father tarried in Haran and dwelt there, as there were many flocks in Haran; and my father turned again unto his idolatry, therefore he continued in Haran.
41753	1576	6	But I, Abraham, and Lot, my brother's son, prayed unto the Lord, and the Lord appeared unto me, and said unto me: Arise, and take Lot with thee; for I have purposed to take thee away out of Haran, and to make of thee a minister to bear my name in a strange land which I will give unto thy seed after thee for an everlasting possession, when they hearken to my voice.
41754	1576	7	For I am the Lord thy God; I dwell in heaven; the earth is my footstool; I stretch my hand over the sea, and it obeys my voice; I cause the wind and the fire to be my chariot; I say to the mountains--Depart hence--and behold, they are taken away by a whirlwind, in an instant, suddenly.
41755	1576	8	My name is Jehovah, and I know the end from the beginning; therefore my hand shall be over thee.
41756	1576	9	And I will make of thee a great nation, and I will bless thee above measure, and make thy name great among all nations, and thou shalt be a blessing unto thy seed after thee, that in their hands they shall bear this ministry and Priesthood unto all nations;
41757	1576	10	And I will bless them through thy name; for as many as receive this Gospel shall be called after thy name, and shall be accounted thy seed, and shall rise up and bless thee, as their father;
41758	1576	11	And I will bless them that bless thee, and curse them that curse thee; and in thee (that is, in thy Priesthood) and in thy seed (that is, thy Priesthood), for I give unto thee a promise that this right shall continue in thee, and in thy seed after thee (that is to say, the literal seed, or the seed of the body) shall all the families of the earth be blessed, even with the blessings of the Gospel, which are the blessings of salvation, even of life eternal.
41759	1576	12	Now, after the Lord had withdrawn from speaking to me, and withdrawn his face from me, I said in my heart: Thy servant has sought thee earnestly; now I have found thee;
41760	1576	13	Thou didst send thine angel to deliver me from the gods of Elkenah, and I will do well to hearken unto thy voice, therefore let thy servant rise up and depart in peace.
41761	1576	14	So I, Abraham, departed as the Lord had said unto me, and Lot with me; and I, Abraham, was sixty and two years old when I departed out of Haran.
41762	1576	15	And I took Sarai, whom I took to wife when I was in Ur, in Chaldea, and Lot, my brother's son, and all our substance that we had gathered, and the souls that we had won in Haran, and came forth in the way to the land of Canaan, and dwelt in tents as we came on our way;
41763	1576	16	Therefore, eternity was our covering and our rock and our salvation, as we journeyed from Haran by the way of Jershon, to come to the land of Canaan.
41764	1576	17	Now I, Abraham, built an altar in the land of Jershon, and made an offering unto the Lord, and prayed that the famine might be turned away from my father's house, that they might not perish.
41765	1576	18	And then we passed from Jershon through the land unto the place of Sechem; it was situated in the plains of Moreh, and we had already come into the borders of the land of the Canaanites, and I offered sacrifice there in the plains of Moreh, and called on the Lord devoutly, because we had already come into the land of this idolatrous nation.
41766	1576	19	And the Lord appeared unto me in answer to my prayers, and said unto me: Unto thy seed will I give this land.
41767	1576	20	And I, Abraham, arose from the place of the altar which I had built unto the Lord, and removed from thence unto a mountain on the east of Bethel, and pitched my tent there, Bethel on the west, and Hai on the east; and there I built another altar unto the Lord, and called again upon the name of the Lord.
41768	1576	21	And I, Abraham, journeyed, going on still towards the south; and there was a continuation of a famine in the land; and I, Abraham, concluded to go down into Egypt, to sojourn there, for the famine became very grievous.
41769	1576	22	And it came to pass when I was come near to enter into Egypt, the Lord said unto me: Behold, Sarai, thy wife, is a very fair woman to look upon;
41770	1576	23	Therefore it shall come to pass, when the Egyptians shall see her, they will say--She is his wife; and they will kill you, but they will save her alive; therefore see that ye do on this wise:
41771	1576	24	Let her say unto the Egyptians, she is thy sister, and thy soul shall live.
41772	1576	25	And it came to pass that I, Abraham, told Sarai, my wife, all that the Lord had said unto me--Therefore say unto them, I pray thee, thou art my sister, that it may be well with me for thy sake, and my soul shall live because of thee.
41773	1577	1	AND I, Abraham, had the Urim and Thummim, which the Lord my God had given unto me, in Ur of the Chaldees;
41774	1577	2	And I saw the stars, that they were very great, and that one of them was nearest unto the throne of God; and there were many great ones which were near unto it;
41775	1577	3	And the Lord said unto me: These are the governing ones; and the name of the great one is Kolob, because it is near unto me, for I am the Lord thy God: I have set this one to govern all those which belong to the same order as that upon which thou standest.
41776	1577	4	And the Lord said unto me, by the Urim and Thummim, that Kolob was after the manner of the Lord, according to its times and seasons in the revolutions thereof; that one revolution was a day unto the Lord, after his manner of reckoning, it being one thousand years according to the time appointed unto that whereon thou standest. This is the reckoning of the Lord's time, according to the reckoning of Kolob.
41777	1577	5	And the Lord said unto me: The planet which is the lesser light, lesser than that which is to rule the day, even the night, is above or greater than that upon which thou standest in point of reckoning, for it moveth in order more slow; this is in order because it standeth above the earth upon which thou standest, therefore the reckoning of its time is not so many as to its number of days, and of months, and of years.
41778	1577	6	And the Lord said unto me: Now, Abraham, these two facts exist, behold thine eyes see it; it is given unto thee to know the times of reckoning, and the set time, yea, the set time of the earth upon which thou standest, and the set time of the greater light which is set to rule the day, and the set time of the lesser light which is set to rule the night.
41779	1577	7	Now the set time of the lesser light is a longer time as to its reckoning than the reckoning of the time of the earth upon which thou standest.
41780	1577	8	And where these two facts exist, there shall be another fact above them, that is, there shall be another planet whose reckoning of time shall be longer still;
41781	1577	9	And thus there shall be the reckoning of the time of one planet above another, until thou come nigh unto Kolob, which Kolob is after the reckoning of the Lord's time; which Kolob is set nigh unto the throne of God, to govern all those planets which belong to the same order as that upon which thou standest.
41782	1577	10	And it is given unto thee to know the set time of all the stars that are set to give light, until thou come near unto the throne of God.
41783	1577	11	Thus I, Abraham, talked with the Lord, face to face, as one man talketh with another; and he told me of the works which his hands had made;
41784	1577	12	And he said unto me: My son, my son (and his hand was stretched out), behold I will show you all these. And he put his hand upon mine eyes, and I saw those things which his hands had made, which were many; and they multiplied before mine eyes, and I could not see the end thereof.
41785	1577	13	And he said unto me: This is Shinehah, which is the sun. And he said unto me: Kokob, which is star. And he said unto me: Olea, which is the moon. And he said unto me: Kokaubeam, which signifies stars, or all the great lights, which were in the firmament of heaven.
41786	1577	14	And it was in the night time when the Lord spake these words unto me: I will multiply thee, and thy seed after thee, like unto these; and if thou canst count the number of sands, so shall be the number of thy seeds.
41787	1577	15	And the Lord said unto me: Abraham, I show these things unto thee before ye go into Egypt, that ye may declare all these words.
41788	1577	16	If two things exist, and there be one above the other, there shall be greater things above them; therefore Kolob is the greatest of all the Kokaubeam that thou hast seen, because it is nearest unto me.
41789	1577	17	Now, if there be two things, one above the other, and the moon be above the earth, then it may be that a planet or a star may exist above it; and there is nothing that the Lord thy God shall take in his heart to do but what he will do it.
41790	1577	18	Howbeit that he made the greater star; as, also, if there be two spirits, and one shall be more intelligent than the other, yet these two spirits, notwithstanding one is more intelligent than the other, have no beginning; they existed before, they shall have no end, they shall exist after, for they are gnolaum, or eternal.
41791	1577	19	And the Lord said unto me: These two facts do exist, that there are two spirits, one being more intelligent than the other; there shall be another more intelligent than they; I am the Lord thy God, I am more intelligent than they all.
41792	1577	20	The Lord thy God sent his angel to deliver thee from the hands of the priest of Elkenah.
41793	1577	21	I dwell in the midst of them all; I now, therefore, have come down unto thee to declare unto thee the works which my hands have made, wherein my wisdom excelleth them all, for I rule in the heavens above, and in the earth beneath, in all wisdom and prudence, over all the intelligences thine eyes have seen from the beginning; I came down in the beginning in the midst of all the intelligences thou hast seen.
41794	1577	22	Now the Lord had shown unto me, Abraham, the intelligences that were organized before the world was; and among all these there were many of the noble and great ones;
41795	1577	23	And God saw these souls that they were good, and he stood in the midst of them, and he said: These I will make my rulers; for he stood among those that were spirits, and he saw that they were good; and he said unto me: Abraham, thou art one of them; thou wast chosen before thou wast born.
41796	1577	24	And there stood one among them that was like unto God, and he said unto those who were with him: We will go down, for there is space there, and we will take of these materials, and we will make an earth whereon these may dwell;
41797	1577	25	And we will prove them herewith, to see if they will do all things whatsoever the Lord their God shall command them;
41798	1577	26	And they who keep their first estate shall be added upon; and they who keep not their first estate shall not have glory in the same kingdom with those who keep their first estate; and they who keep their second estate shall have glory added upon their heads for ever and ever.
41799	1577	27	And the Lord said: Whom shall I send? And one answered like unto the Son of Man: Here am I, send me. And another answered and said: Here am I, send me. And the Lord said: I will send the first.
41800	1577	28	And the second was angry, and kept not his first estate; and, at that day, many followed after him.
41801	1578	1	AND then the Lord said: Let us go down. And they went down at the beginning, and they, that is the Gods, organized and formed the heavens and the earth.
41802	1578	2	And the earth, after it was formed, was empty and desolate, because they had not formed anything but the earth; and darkness reigned upon the face of the deep, and the Spirit of the Gods was brooding upon the face of the waters.
41803	1578	3	And they (the Gods) said: Let there be light; and there was light.
41804	1578	4	And they (the Gods) comprehended the light, for it was bright; and they divided the light, or caused it to be divided, from the darkness.
41805	1578	5	And the Gods called the light Day, and the darkness they called Night. And it came to pass that from the evening until morning they called night; and from the morning until the evening they called day; and this was the first, or the beginning, of that which they called day and night.
41806	1578	6	And the Gods also said: Let there be an expanse in the midst of the waters, and it shall divide the waters from the waters.
41807	1578	7	And the Gods ordered the expanse, so that it divided the waters which were under the expanse from the waters which were above the expanse; and it was so, even as they ordered.
41808	1578	8	And the Gods called the expanse, Heaven. And it came to pass that it was from evening until morning that they called night; and it came to pass that it was from morning until evening that they called day; and this was the second time that they called night and day.
41809	1578	9	And the Gods ordered, saying: Let the waters under the heaven be gathered together unto one place, and let the earth come up dry; and it was so as they ordered;
41810	1578	10	And the Gods pronounced the dry land, Earth; and the gathering together of the waters, pronounced they, Great Waters; and the Gods saw that they were obeyed.
41811	1578	11	And the Gods said: Let us prepare the earth to bring forth grass; the herb yielding seed; the fruit tree yielding fruit, after his kind, whose seed in itself yieldeth its own likeness upon the earth; and it was so, even as they ordered.
41812	1578	12	And the Gods organized the earth to bring forth grass from its own seed, and the herb to bring forth herb from its own seed, yielding seed after his kind; and the earth to bring forth the tree from its own seed, yielding fruit, whose seed could only bring forth the same in itself, after his kind; and the Gods saw that they were obeyed.
41813	1578	13	And it came to pass that they numbered the days; from the evening until the morning they called night; and it came to pass, from the morning until the evening they called day; and it was the third time.
41814	1578	14	And the Gods organized the lights in the expanse of the heaven, and caused them to divide the day from the night; and organized them to be for signs and for seasons, and for days and for years;
41815	1578	15	And organized them to be for lights in the expanse of the heaven to give light upon the earth; and it was so.
41816	1578	16	And the Gods organized the two great lights, the greater light to rule the day, and the lesser light to rule the night; with the lesser light they set the stars also;
41817	1578	17	And the Gods set them in the expanse of the heavens, to give light upon the earth, and to rule over the day and over the night, and to cause to divide the light from the darkness.
41818	1578	18	And the Gods watched those things which they had ordered until they obeyed.
41819	1578	19	And it came to pass that it was from evening until morning that it was night; and it came to pass that it was from morning until evening that it was day; and it was the fourth time.
41820	1578	20	And the Gods said: Let us prepare the waters to bring forth abundantly the moving creatures that have life; and the fowl, that they may fly above the earth in the open expanse of heaven.
41821	1578	21	And the Gods prepared the waters that they might bring forth great whales, and every living creature that moveth, which the waters were to bring forth abundantly after their kind; and every winged fowl after their kind. And the Gods saw that they would be obeyed, and that their plan was good.
41822	1578	22	And the Gods said: We will bless them, and cause them to be fruitful and multiply, and fill the waters in the seas or great waters; and cause the fowl to multiply in the earth.
41823	1578	23	And it came to pass that it was from evening until morning that they called night; and it came to pass that it was from morning until evening that they called day; and it was the fifth time.
41824	1578	24	And the Gods prepared the earth to bring forth the living creature after his kind, cattle and creeping things, and beasts of the earth after their kind; and it was so, as they had said.
41825	1578	25	And the Gods organized the earth to bring forth the beasts after their kind, and cattle after their kind, and every thing that creepeth upon the earth after its kind; and the Gods saw they would obey.
41826	1578	26	And the Gods took counsel among themselves and said: Let us go down and form man in our image, after our likeness; and we will give them dominion over the fish of the sea, and over the fowl of the air, and over the cattle, and over all the earth, and over every creeping thing that creepeth upon the earth.
41827	1578	27	So the Gods went down to organize man in their own image, in the image of the Gods to form they him, male and female to form they them.
41828	1578	28	And the Gods said: We will bless them. And the Gods said: We will cause them to be fruitful and multiply, and replenish the earth, and subdue it, and to have dominion over the fish of the sea, and over the fowl of the air, and over every living thing that moveth upon the earth.
41829	1578	29	And the Gods said: Behold, we will give them every herb bearing seed that shall come upon the face of all the earth, and every tree which shall have fruit upon it; yea, the fruit of the tree yielding seed to them we will give it; it shall be for their meat.
41830	1578	30	And to every beast of the earth, and to every fowl of the air, and to every thing that creepeth upon the earth, behold, we will give them life, and also we will give to them every green herb for meat, and all these things shall be thus organized.
41831	1578	31	And the Gods said: We will do everything that we have said, and organize them; and behold, they shall be very obedient. And it came to pass that it was from evening until morning they called night; and it came to pass that it was from morning until evening that they called day; and they numbered the sixth time.
41832	1579	1	AND thus we will finish the heavens and the earth, and all the hosts of them.
41833	1579	2	And the Gods said among themselves: On the seventh time we will end our work, which we have counseled; and we will rest on the seventh time from all our work which we have counseled.
41834	1579	3	And the Gods concluded upon the seventh time, because that on the seventh time they would rest from all their works which they (the Gods) counseled among themselves to form; and sanctified it. And thus were their decisions at the time that they counseled among themselves to form the heavens and the earth.
41835	1579	4	And the Gods came down and formed these the generations of the heavens and of the earth, when they were formed in the day that the Gods formed the earth and the heavens,
41836	1579	5	According to all that which they had said concerning every plant of the field before it was in the earth, and every herb of the field before it grew; for the Gods had not caused it to rain upon the earth when they counseled to do them, and had not formed a man to till the ground.
41837	1579	6	But there went up a mist from the earth, and watered the whole face of the ground.
41838	1579	7	And the Gods formed man from the dust of the ground, and took his spirit (that is, the man's spirit), and put it into him; and breathed into his nostrils the breath of life, and man became a living soul.
41839	1579	8	And the Gods planted a garden, eastward in Eden, and there they put the man, whose spirit they had put into the body which they had formed.
41840	1579	9	And out of the ground made the Gods to grow every tree that is pleasant to the sight and good for food; the tree of life, also, in the midst of the garden, and the tree of knowledge of good and evil.
41841	1579	10	There was a river running out of Eden, to water the garden, and from thence it was parted and became into four heads.
41842	1579	11	And the Gods took the man and put him in the Garden of Eden, to dress it and to keep it.
41843	1579	12	And the Gods commanded the man, saying: Of every tree of the garden thou mayest freely eat,
41844	1579	13	But of the tree of knowledge of good and evil, thou shalt not eat of it; for in the time that thou eatest thereof, thou shalt surely die. Now I, Abraham, saw that it was after the Lord's time, which was after the time of Kolob; for as yet the Gods had not appointed unto Adam his reckoning.
41845	1579	14	And the Gods said: Let us make an help meet for the man, for it is not good that the man should be alone, therefore we will form an help meet for him.
41846	1579	15	And the Gods caused a deep sleep to fall upon Adam; and he slept, and they took one of his ribs, and closed up the flesh in the stead thereof;
41847	1579	16	And of the rib which the Gods had taken from man, formed they a woman, and brought her unto the man.
41848	1579	17	And Adam said: This was bone of my bones, and flesh of my flesh; now she shall be called Woman, because she was taken out of man;
41849	1579	18	Therefore shall a man leave his father and his mother, and shall cleave unto his wife, and they shall be one flesh.
41850	1579	19	And they were both naked, the man and his wife, and were not ashamed.
41851	1579	20	And out of the ground the Gods formed every beast of the field, and every fowl of the air, and brought them unto Adam to see what he would call them; and whatsoever Adam called every living creature, that should be the name thereof.
41852	1579	21	And Adam gave names to all cattle, to the fowl of the air, to every beast of the field; and for Adam, there was found an help meet for him.
41853	1580	1	FOR I say unto you, that ye shall not see me henceforth and know that I am he of whom it is written by the prophets, until ye shall say: Blessed is he who cometh in the name of the Lord, in the clouds of heaven, and all the holy angels with him. Then understood his disciples that he should come again on the earth, after that he was glorified and crowned on the right hand of God.
41854	1580	2	And Jesus went out, and departed from the temple; and his disciples came to him, for to hear him, saying: Master, show us concerning the buildings of the temple, as thou hast said--They shall be thrown down, and left unto you desolate.
41855	1580	3	And Jesus said unto them: See ye not all these things, and do ye not understand them? Verily I say unto you, there shall not be left here, upon this temple, one stone upon another that shall not be thrown down.
41856	1580	4	And Jesus left them, and went upon the Mount of Olives. And as he sat upon the Mount of Olives, the disciples came unto him privately, saying: Tell us when shall these things be which thou hast said concerning the destruction of the temple, and the Jews; and what is the sign of thy coming, and of the end of the world, or the destruction of the wicked, which is the end of the world?
41857	1580	5	And Jesus answered, and said unto them: Take heed that no man deceive you;
41858	1580	6	For many shall come in my name, saying--I am Christ--and shall deceive many;
41859	1580	7	Then shall they deliver you up to be afflicted, and shall kill you, and ye shall be hated of all nations, for my name's sake;
41860	1580	8	And then shall many be offended, and shall betray one another, and shall hate one another;
41861	1580	9	And many false prophets shall arise, and shall deceive many;
41862	1580	10	And because iniquity shall abound, the love of many shall wax cold;
41863	1580	11	But he that remaineth steadfast and is not overcome, the same shall be saved.
41864	1580	12	When you, therefore, shall see the abomination of desolation, spoken of by Daniel the prophet, concerning the destruction of Jerusalem, then you shall stand in the holy place; whoso readeth let him understand.
41865	1580	13	Then let them who are in Judea flee into the mountains;
41866	1580	14	Let him who is on the housetop flee, and not return to take anything out of his house;
41867	1580	15	Neither let him who is in the field return back to take his clothes;
41868	1580	16	And wo unto them that are with child, and unto them that give suck in those days;
41869	1580	17	Therefore, pray ye the Lord that your flight be not in the winter, neither on the Sabbath day;
41870	1580	18	For then, in those days, shall be great tribulation on the Jews, and upon the inhabitants of Jerusalem, such as was not before sent upon Israel, of God, since the beginning of their kingdom until this time; no, nor ever shall be sent again upon Israel.
41871	1580	19	All things which have befallen them are only the beginning of the sorrows which shall come upon them.
41872	1580	20	And except those days should be shortened, there should none of their flesh be saved; but for the elect's sake, according to the covenant, those days shall be shortened.
41873	1580	21	Behold, these things I have spoken unto you concerning the Jews; and again, after the tribulation of those days which shall come upon Jerusalem, if any man shall say unto you, Lo, here is Christ, or there, believe him not;
41874	1580	22	For in those days there shall also arise false Christs, and false prophets, and shall show great signs and wonders, insomuch, that, if possible, they shall deceive the very elect, who are the elect according to the covenant.
41875	1580	23	Behold, I speak these things unto you for the elect's sake; and you also shall hear of wars, and rumors of wars; see that ye be not troubled, for all I have told you must come to pass; but the end is not yet.
41876	1580	24	Behold, I have told you before;
41877	1580	25	Wherefore, if they shall say unto you: Behold, he is in the desert; go not forth: Behold, he is in the secret chambers; believe it not;
41878	1580	26	For as the light of the morning cometh out of the east, and shineth even unto the west, and covereth the whole earth, so shall also the coming of the Son of Man be.
41879	1580	27	And now I show unto you a parable. Behold, wheresoever the carcass is, there will the eagles be gathered together; so likewise shall mine elect be gathered from the four quarters of the earth.
41880	1580	28	And they shall hear of wars, and rumors of wars.
41881	1580	29	Behold I speak for mine elect's sake; for nation shall rise against nation, and kingdom against kingdom; there shall be famines, and pestilences, and earthquakes, in divers places.
41882	1580	30	And again, because iniquity shall abound, the love of men shall wax cold; but he that shall not be overcome, the same shall be saved.
41883	1580	31	And again, this Gospel of the Kingdom shall be preached in all the world, for a witness unto all nations, and then shall the end come, or the destruction of the wicked;
41884	1580	32	And again shall the abomination of desolation, spoken of by Daniel the prophet, be fulfilled.
41885	1580	33	And immediately after the tribulation of those days, the sun shall be darkened, and the moon shall not give her light, and the stars shall fall from heaven, and the powers of heaven shall be shaken.
41886	1580	34	Verily, I say unto you, this generation, in which these things shall be shown forth, shall not pass away until all I have told you shall be fulfilled.
41887	1580	35	Although, the days will come, that heaven and earth shall pass away; yet my words shall not pass away, but all shall be fulfilled.
41888	1580	36	And, as I said before, after the tribulation of those days, and the powers of the heavens shall be shaken, then shall appear the sign of the Son of Man in heaven, and then shall all the tribes of the earth mourn; and they shall see the Son of Man coming in the clouds of heaven, with power and great glory;
41889	1580	37	And whoso treasureth up my word, shall not be deceived, for the Son of Man shall come, and he shall send his angels before him with the great sound of a trumpet, and they shall gather together the remainder of his elect from the four winds, from one end of heaven to the other.
41890	1580	38	Now learn a parable of the fig-tree--When its branches are yet tender, and it begins to put forth leaves, you know that summer is nigh at hand;
41891	1580	39	So likewise, mine elect, when they shall see all these things, they shall know that he is near, even at the doors;
41892	1580	40	But of that day, and hour, no one knoweth; no, not the angels of God in heaven, but my Father only.
41893	1580	41	But as it was in the days of Noah, so it shall be also at the coming of the Son of Man;
41894	1580	42	For it shall be with them, as it was in the days which were before the flood; for until the day that Noah entered into the ark they were eating and drinking, marrying and giving in marriage;
41895	1580	43	And knew not until the flood came, and took them all away; so shall also the coming of the Son of Man be.
41896	1580	44	Then shall be fulfilled that which is written, that in the last days, two shall be in the field, the one shall be taken, and the other left;
41897	1580	45	Two shall be grinding at the mill, the one shall be taken, and the other left;
41898	1580	46	And what I say unto one, I say unto all men; watch, therefore, for you know not at what hour your Lord doth come.
41899	1580	47	But know this, if the good man of the house had known in what watch the thief would come, he would have watched, and would not have suffered his house to have been broken up, but would have been ready.
41900	1580	48	Therefore be ye also ready, for in such an hour as ye think not, the Son of Man cometh.
41901	1580	49	Who, then, is a faithful and wise servant, whom his lord hath made ruler over his household, to give them meat in due season?
41902	1580	50	Blessed is that servant whom his lord, when he cometh, shall find so doing; and verily I say unto you, he shall make him ruler over all his goods.
41903	1580	51	But if that evil servant shall say in his heart: My lord delayeth his coming,
41904	1580	52	And shall begin to smite his fellow-servants, and to eat and drink with the drunken,
41905	1580	53	The lord of that servant shall come in a day when he looketh not for him, and in an hour that he is not aware of,
41906	1580	54	And shall cut him asunder, and shall appoint him his portion with the hypocrites; there shall be weeping and gnashing of teeth.
41907	1580	55	And thus cometh the end of the wicked, according to the prophecy of Moses, saying: They shall be cut off from among the people; but the end of the earth is not yet, but by and by.
41908	1581	1	OWING to the many reports which have been put in circulation by evil-disposed and designing persons, in relation to the rise and progress of the Church of Jesus Christ of Latter-day Saints, all of which have been designed by the authors thereof to militate against its character as a Church and its progress in the world--I have been induced to write this history, to disabuse the public mind, and put all inquirers after truth in possession of the facts, as they have transpired, in relation both to myself and the Church, so far as I have such facts in my possession.
41909	1581	2	In this history I shall present the various events in relation to this Church, in truth and righteousness, as they have transpired, or as they at present exist, being now [1838] the eighth year since the organization of the said Church.
41910	1581	3	I was born in the year of our Lord one thousand eight hundred and five, on the twenty-third day of December, in the town of Sharon, Windsor county, State of Vermont . . . My father, Joseph Smith, Sen., left the State of Vermont, and moved to Palmyra, Ontario (now Wayne) county, in the State of New York, when I was in my tenth year, or thereabouts. In about four years after my father's arrival in Palmyra, he moved with his family into Manchester in the same county of Ontario--
41911	1581	4	His family consisting of eleven souls, namely, my father, Joseph Smith; my mother, Lucy Smith (whose name, previous to her marriage, was Mack, daughter of Solomon Mack); my brothers, Alvin (who died November 19th, 1823, in the 26th year of his age), Hyrum, myself, Samuel Harrison, William, Don Carlos; and my sisters, Sophronia, Catherine, and Lucy.
41912	1581	5	Some time in the second year after our removal to Manchester, there was in the place where we lived an unusual excitement on the subject of religion. It commenced with the Methodists, but soon became general among all the sects in that region of country. Indeed, the whole district of country seemed affected by it, and great multitudes united themselves to the different religious parties, which created no small stir and division amongst the people, some crying, "Lo, here!" and others, "Lo, there!" Some were contending for the Methodist faith, some for the Presbyterian, and some for the Baptist.
41913	1581	6	For, notwithstanding the great love which the converts to these different faiths expressed at the time of their conversion, and the great zeal manifested by the respective clergy, who were active in getting up and promoting this extraordinary scene of religious feeling, in order to have everybody converted, as they were pleased to call it, let them join what sect they pleased; yet when the converts began to file off, some to one party and some to another, it was seen that the seemingly good feelings of both the priests and the converts were more pretended than real; for a scene of great confusion and bad feeling ensued--priest contending against priest, and convert against convert; so that all their good feelings one for another, if they ever had any, were entirely lost in a strife of words and a contest about opinions.
41914	1581	7	I was at this time in my fifteenth year. My father's family was proselyted to the Presbyterian faith, and four of them joined that church, namely, my mother, Lucy; my brothers Hyrum and Samuel Harrison; and my sister Sophronia.
41915	1581	8	During this time of great excitement my mind was called up to serious reflection and great uneasiness; but though my feelings were deep and often poignant, still I kept myself aloof from all these parties, though I attended their several meetings as often as occasion would permit. In process of time my mind became somewhat partial to the Methodist sect, and I felt some desire to be united with them; but so great were the confusion and strife among the different denominations, that it was impossible for a person young as I was, and so unacquainted with men and things, to come to any certain conclusion who was right and who was wrong.
41916	1581	9	My mind at times was greatly excited, the cry and tumult were so great and incessant. The Presbyterians were most decided against the Baptists and Methodists, and used all the powers of both reason and sophistry to prove their errors, or, at least, to make the people think they were in error. On the other hand, the Baptists and Methodists in their turn were equally zealous in endeavoring to establish their own tenets and disprove all others.
41917	1581	10	In the midst of this war of words and tumult of opinions, I often said to myself: What is to be done? Who of all these parties are right; or, are they all wrong together? If any one of them be right, which is it, and how shall I know it?
41918	1581	11	While I was laboring under the extreme difficulties caused by the contests of these parties of religionists, I was one day reading the Epistle of James, first chapter and fifth verse, which reads: If any of you lack wisdom, let him ask of God, that giveth to all men liberally, and upbraideth not; and it shall be given him.
41919	1581	12	Never did any passage of scripture come with more power to the heart of man than this did at this time to mine. It seemed to enter with great force into every feeling of my heart. I reflected on it again and again, knowing that if any person needed wisdom from God, I did; for how to act I did not know, and unless I could get more wisdom than I then had, I would never know; for the teachers of religion of the different sects understood the same passages of scripture so differently as to destroy all confidence in settling the question by an appeal to the Bible.
41920	1581	13	At length I came to the conclusion that I must either remain in darkness and confusion, or else I must do as James directs, that is, ask of God. I at length came to the determination to "ask of God," concluding that if he gave wisdom to them that lacked wisdom, and would give liberally, and not upbraid, I might venture.
41921	1581	14	So, in accordance with this, my determination to ask of God, I retired to the woods to make the attempt. It was on the morning of a beautiful, clear day, early in the spring of eighteen hundred and twenty. It was the first time in my life that I had made such an attempt, for amidst all my anxieties I had never as yet made the attempt to pray vocally.
41922	1581	15	After I had retired to the place where I had previously designed to go, having looked around me, and finding myself alone, I kneeled down and began to offer up the desires of my heart to God. I had scarcely done so, when immediately I was seized upon by some power which entirely overcame me, and had such an astonishing influence over me as to bind my tongue so that I could not speak. Thick darkness gathered around me, and it seemed to me for a time as if I were doomed to sudden destruction.
41923	1581	16	But, exerting all my powers to call upon God to deliver me out of the power of this enemy which had seized upon me, and at the very moment when I was ready to sink into despair and abandon myself to destruction--not to an imaginary ruin, but to the power of some actual being from the unseen world, who had such marvelous power as I had never before felt in any being--just at this moment of great alarm, I saw a pillar of light exactly over my head, above the brightness of the sun, which descended gradually until it fell upon me.
41924	1581	17	It no sooner appeared than I found myself delivered from the enemy which held me bound. When the light rested upon me I saw two Personages, whose brightness and glory defy all description, standing above me in the air. One of them spake unto me, calling me by name and said, pointing to the other--This is My Beloved Son. Hear Him!
41925	1581	18	My object in going to inquire of the Lord was to know which of all the sects was right, that I might know which to join. No sooner, therefore, did I get possession of myself, so as to be able to speak, than I asked the Personages who stood above me in the light, which of all the sects was right (for at this time it had never entered into my heart that all were wrong)--and which I should join.
41926	1581	19	I was answered that I must join none of them, for they were all wrong; and the Personage who addressed me said that all their creeds were an abomination in his sight; that those professors were all corrupt; that: "they draw near to me with their lips, but their hearts are far from me, they teach for doctrines the commandments of men, having a form of godliness, but they deny the power thereof."
41927	1581	20	He again forbade me to join with any of them; and many other things did he say unto me, which I cannot write at this time. When I came to myself again, I found myself lying on my back, looking up into heaven. When the light had departed, I had no strength; but soon recovering in some degree, I went home. And as I leaned up to the fireplace, mother inquired what the matter was. I replied, "Never mind, all is well--I am well enough off." I then said to my mother, "I have learned for myself that Presbyterianism is not true." It seems as though the adversary was aware, at a very early period of my life, that I was destined to prove a disturber and an annoyer of his kingdom; else why should the powers of darkness combine against me? Why the opposition and persecution that arose against me, almost in my infancy?
41928	1581	21	Some few days after I had this vision, I happened to be in company with one of the Methodist preachers, who was very active in the before mentioned religious excitement; and, conversing with him on the subject of religion, I took occasion to give him an account of the vision which I had had. I was greatly surprised at his behavior; he treated my communication not only lightly, but with great contempt, saying it was all of the devil, that there were no such things as visions or revelations in these days; that all such things had ceased with the apostles, and that there would never be any more of them.
41929	1581	22	I soon found, however, that my telling the story had excited a great deal of prejudice against me among professors of religion, and was the cause of great persecution, which continued to increase; and though I was an obscure boy, only between fourteen and fifteen years of age, and my circumstances in life such as to make a boy of no consequence in the world, yet men of high standing would take notice sufficient to excite the public mind against me, and create a bitter persecution; and this was common among all the sects--all united to persecute me.
41930	1581	23	It caused me serious reflection then, and often has since, how very strange it was that an obscure boy, of a little over fourteen years of age, and one, too, who was doomed to the necessity of obtaining a scanty maintenance by his daily labor, should be thought a character of sufficient importance to attract the attention of the great ones of the most popular sects of the day, and in a manner to create in them a spirit of the most bitter persecution and reviling. But strange or not, so it was, and it was often the cause of great sorrow to myself.
41931	1581	24	However, it was nevertheless a fact that I had beheld a vision. I have thought since, that I felt much like Paul, when he made his defense before King Agrippa, and related the account of the vision he had when he saw a light, and heard a voice; but still there were but few who believed him; some said he was dishonest, others said he was mad; and he was ridiculed and reviled. But all this did not destroy the reality of his vision. He had seen a vision, he knew he had, and all the persecution under heaven could not make it otherwise; and though they should persecute him unto death, yet he knew, and would know to his latest breath, that he had both seen a light and heard a voice speaking unto him, and all the world could not make him think or believe otherwise.
41932	1581	25	So it was with me. I had actually seen a light, and in the midst of that light I saw two Personages, and they did in reality speak to me; and though I was hated and persecuted for saying that I had seen a vision, yet it was true; and while they were persecuting me, reviling me, and speaking all manner of evil against me falsely for so saying, I was led to say in my heart: Why persecute me for telling the truth? I have actually seen a vision; and who am I that I can withstand God, or why does the world think to make me deny what I have actually seen? For I had seen a vision; I knew it, and I knew that God knew it, and I could not deny it, neither dared I do it; at least I knew that by so doing I would offend God, and come under condemnation.
41933	1581	26	I had now got my mind satisfied so far as the sectarian world was concerned--that it was not my duty to join with any of them, but to continue as I was until further directed. I had found the testimony of James to be true--that a man who lacked wisdom might ask of God, and obtain, and not be upbraided.
41934	1581	27	I continued to pursue my common vocations in life until the twenty--first of September, one thousand eight hundred and twenty-three, all the time suffering severe persecution at the hands of all classes of men, both religious and irreligious, because I continued to affirm that I had seen a vision.
41935	1581	28	During the space of time which intervened between the time I had the vision and the year eighteen hundred and twenty-three--having been forbidden to join any of the religious sects of the day, and being of very tender years, and persecuted by those who ought to have been my friends and to have treated me kindly, and if they supposed me to be deluded to have endeavored in a proper and affectionate manner to have reclaimed me--I was left to all kinds of temptations; and, mingling with all kinds of society, I frequently fell into many foolish errors, and displayed the weakness of youth, and the foibles of human nature; which, I am sorry to say, led me into divers temptations, offensive in the sight of God. In making this confession, no one need suppose me guilty of any great or malignant sins. A disposition to commit such was never in my nature. But I was guilty of levity, and sometimes associated with jovial company, etc., not consistent with that character which ought to be maintained by one who was called of God as I had been. But this will not seem very strange to any one who recollects my youth, and is acquainted with my native cheery temperament.
41936	1581	29	In consequence of these things, I often felt condemned for my weakness and imperfections; when, on the evening of the above-mentioned twenty-first of September, after I had retired to my bed for the night, I betook myself to prayer and supplication to Almighty God for forgiveness of all my sins and follies, and also for a manifestation to me, that I might know of my state and standing before him; for I had full confidence in obtaining a divine manifestation, as I previously had one.
41937	1581	30	While I was thus in the act of calling upon God, I discovered a light appearing in my room, which continued to increase until the room was lighter than at noonday, when immediately a personage appeared at my bedside, standing in the air, for his feet did not touch the floor.
41938	1581	31	He had on a loose robe of most exquisite whiteness. It was a whiteness beyond anything earthly I had ever seen; nor do I believe that any earthly thing could be made to appear so exceedingly white and brilliant. His hands were naked, and his arms also, a little above the wrist; so, also, were his feet naked, as were his legs, a little above the ankles. His head and neck were also bare. I could discover that he had no other clothing on but this robe, as it was open, so that I could see into his bosom.
41939	1581	32	Not only was his robe exceedingly white, but his whole person was glorious beyond description, and his countenance truly like lightning. The room was exceedingly light, but not so very bright as immediately around his person. When I first looked upon him, I was afraid; but the fear soon left me.
41940	1581	33	He called me by name, and said unto me that he was a messenger sent from the presence of God to me, and that his name was Moroni; that God had a work for me to do; and that my name should be had for good and evil among all nations, kindreds, and tongues, or that it should be both good and evil spoken of among all people.
41941	1581	34	He said there was a book deposited, written upon gold plates, giving an account of the former inhabitants of this continent, and the source from whence they sprang. He also said that the fulness of the everlasting Gospel was contained in it, as delivered by the Savior to the ancient inhabitants;
41942	1581	35	Also, that there were two stones in silver bows--and these stones, fastened to a breastplate, constituted what is called the Urim and Thummim--deposited with the plates; and the possession and use of these stones were what constituted "seers" in ancient or former times; and that God had prepared them for the purpose of translating the book.
41943	1581	36	After telling me these things, he commenced quoting the prophecies of the Old Testament. He first quoted part of the third chapter of Malachi; and he quoted also the fourth or last chapter of the same prophecy, though with a little variation from the way it reads in our Bibles. Instead of quoting the first verse as it reads in our books, he quoted it thus:
41944	1581	37	For behold, the day cometh that shall burn as an oven, and all the proud, yea, and all that do wickedly shall burn as stubble; for they that come shall burn them, saith the Lord of Hosts, that it shall leave them neither root nor branch.
41945	1581	38	And again, he quoted the fifth verse thus: Behold, I will reveal unto you the Priesthood, by the hand of Elijah the prophet, before the coming of the great and dreadful day of the Lord.
41946	1581	39	He also quoted the next verse differently: And he shall plant in the hearts of the children the promises made to the fathers, and the hearts of the children shall turn to their fathers. If it were not so, the whole earth would be utterly wasted at his coming.
41947	1581	40	In addition to these, he quoted the eleventh chapter of Isaiah, saying that it was about to be fulfilled. He quoted also the third chapter of Acts, twenty-second and twenty-third verses, precisely as they stand in our New Testament. He said that that prophet was Christ; but the day had not yet come when "they who would not hear his voice should be cut off from among the people," but soon would come.
41948	1581	41	He also quoted the second chapter of Joel, from the twenty-eighth verse to the last. He also said that this was not yet fulfilled, but was soon to be. And he further stated that the fulness of the Gentiles was soon to come in. He quoted many other passages of scripture, and offered many explanations which cannot be mentioned here.
41949	1581	42	Again, he told me, that when I got those plates of which he had spoken--for the time that they should be obtained was not yet fulfilled--I should not show them to any person; neither the breastplate with the Urim and Thummim; only to those to whom I should be commanded to show them; if I did I should be destroyed. While he was conversing with me about the plates, the vision was opened to my mind that I could see the place where the plates were deposited, and that so clearly and distinctly that I knew the place again when I visited it.
41950	1581	43	After this communication, I saw the light in the room begin to gather immediately around the person of him who had been speaking to me, and it continued to do so until the room was again left dark, except just around him; when, instantly I saw, as it were, a conduit open right up into heaven, and he ascended till he entirely disappeared, and the room was left as it had been before this heavenly light had made its appearance.
41951	1581	44	I lay musing on the singularity of the scene, and marveling greatly at what had been told to me by this extraordinary messenger; when, in the midst of my meditation, I suddenly discovered that my room was again beginning to get lighted, and in an instant, as it were, the same heavenly messenger was again by my bedside.
41952	1581	45	He commenced, and again related the very same things which he had done at his first visit, without the least variation; which having done, he informed me of great judgments which were coming upon the earth, with great desolations by famine, sword, and pestilence; and that these grievous judgments would come on the earth in this generation. Having related these things, he again ascended as he had done before.
41953	1581	46	By this time, so deep were the impressions made on my mind, that sleep had fled from my eyes, and I lay overwhelmed in astonishment at what I had both seen and heard. But what was my surprise when again I beheld the same messenger at my bedside, and heard him rehearse or repeat over again to me the same things as before; and added a caution to me, telling me that Satan would try to tempt me (in consequence of the indigent circumstances of my father's family), to get the plates for the purpose of getting rich. This he forbade me, saying that I must have no other object in view in getting the plates but to glorify God, and must not be influenced by any other motive than that of building his kingdom; otherwise I could not get them.
41954	1581	47	After this third visit, he again ascended into heaven as before, and I was again left to ponder on the strangeness of what I had just experienced; when almost immediately after the heavenly messenger had ascended from me for the third time, the cock crowed, and I found that day was approaching, so that our interviews must have occupied the whole of that night.
41955	1581	48	I shortly after arose from my bed, and, as usual, went to the necessary labors of the day; but, in attempting to work as at other times, I found my strength so exhausted as to render me entirely unable. My father, who was laboring along with me, discovered something to be wrong with me, and told me to go home. I started with the intention of going to the house; but, in attempting to cross the fence out of the field where we were, my strength entirely failed me, and I fell helpless on the ground, and for a time was quite unconscious of anything.
41956	1581	49	The first thing that I can recollect was a voice speaking unto me, calling me by name. I looked up, and beheld the same messenger standing over my head, surrounded by light as before. He then again related unto me all that he had related to me the previous night, and commanded me to go to my father and tell him of the vision and commandments which I had received.
41957	1581	50	I obeyed; I returned to my father in the field, and rehearsed the whole matter to him. He replied to me that it was of God, and told me to go and do as commanded by the messenger. I left the field, and went to the place where the messenger had told me the plates were deposited; and owing to the distinctness of the vision which I had had concerning it, I knew the place the instant that I arrived there.
41958	1581	51	Convenient to the village of Manchester, Ontario county, New York, stands a hill of considerable size, and the most elevated of any in the neighborhood. On the west side of this hill, not far from the top, under a stone of considerable size, lay the plates, deposited in a stone box. This stone was thick and rounding in the middle on the upper side, and thinner towards the edges, so that the middle part of it was visible above the ground, but the edge all around was covered with earth.
41959	1581	52	Having removed the earth, I obtained a lever, which I got fixed under the edge of the stone, and with a little exertion raised it up. I looked in, and there indeed did I behold the plates, the Urim and Thummim, and the breastplate, as stated by the messenger. The box in which they lay was formed by laying stones together in some kind of cement. In the bottom of the box were laid two stones crossways of the box, and on these stones lay the plates and the other things with them.
41960	1581	53	I made an attempt to take them out, but was forbidden by the messenger, and was again informed that the time for bringing them forth had not yet arrived, neither would it, until four years from that time; but he told me that I should come to that place precisely in one year from that time, and that he would there meet with me, and that I should continue to do so until the time should come for obtaining the plates.
41961	1581	54	Accordingly, as I had been commanded, I went at the end of each year, and at each time I found the same messenger there, and received instruction and intelligence from him at each of our interviews, respecting what the Lord was going to do, and how and in what manner his kingdom was to be conducted in the last days.
41962	1581	55	As my father's worldly circumstances were very limited, we were under the necessity of laboring with our hands, hiring out by day's work and otherwise, as we could get opportunity. Sometimes we were at home, and sometimes abroad, and by continuous labor were enabled to get a comfortable maintenance.
41963	1581	56	In the year 1823 my father's family met with a great affliction by the death of my eldest brother, Alvin. In the month of October, 1825, I hired with an old gentleman by the name of Josiah Stoal, who lived in Chenango county, State of New York. He had heard something of a silver mine having been opened by the Spaniards in Harmony, Susquehanna county, State of Pennsylvania; and had, previous to my hiring to him, been digging, in order, if possible, to discover the mine. After I went to live with him, he took me, with the rest of his hands, to dig for the silver mine, at which I continued to work for nearly a month, without success in our undertaking, and finally I prevailed with the old gentleman to cease digging after it. Hence arose the very prevalent story of my having been a money-digger.
41964	1581	57	During the time that I was thus employed, I was put to board with a Mr. Isaac Hale, of that place; it was there I first saw my wife (his daughter), Emma Hale. On the 18th of January, 1827, we were married, while I was yet employed in the service of Mr. Stoal.
41965	1581	58	Owing to my continuing to assert that I had seen a vision, persecution still followed me, and my wife's father's family were very much opposed to our being married. I was, therefore, under the necessity of taking her elsewhere; so we went and were married at the house of Squire Tarbill, in South Bainbridge, Chenango county, New York. Immediately after my marriage, I left Mr. Stoal's, and went to my father's, and farmed with him that season.
41966	1581	59	At length the time arrived for obtaining the plates, the Urim and Thummim, and the breastplate. On the twenty-second day of September, one thousand eight hundred and twenty-seven, having gone as usual at the end of another year to the place where they were deposited, the same heavenly messenger delivered them up to me with this charge: that I should be responsible for them; that if I should let them go carelessly, or through any neglect of mine, I should be cut off; but that if I would use all my endeavors to preserve them, until he, the messenger, should call for them, they should be protected.
41967	1581	60	I soon found out the reason why I had received such strict charges to keep them safe, and why it was that the messenger had said that when I had done what was required at my hand, he would call for them. For no sooner was it known that I had them, than the most strenuous exertions were used to get them from me. Every stratagem that could be invented was resorted to for that purpose. The persecution became more bitter and severe than before, and multitudes were on the alert continually to get them from me if possible. But by the wisdom of God, they remained safe in my hands, until I had accomplished by them what was required at my hand. When, according to arrangements, the messenger called for them, I delivered them up to him; and he has them in his charge until this day, being the second day of May, one thousand eight hundred and thirty-eight.
41968	1581	61	The excitement, however, still continued, and rumor with her thousand tongues was all the time employed in circulating falsehoods about my father's family, and about myself. If I were to relate a thousandth part of them, it would fill up volumes. The persecution, however, became so intolerable that I was under the necessity of leaving Manchester, and going with my wife to Susquehanna county, in the State of Pennsylvania. While preparing to start--being very poor, and the persecution so heavy upon us that there was no probability that we would ever be otherwise--in the midst of our afflictions we found a friend in a gentleman by the name of Martin Harris, who came to us and gave me fifty dollars to assist us on our journey. Mr. Harris was a resident of Palmyra township, Wayne county, in the State of New York, and a farmer of respectability.
41969	1581	62	By this timely aid was I enabled to reach the place of my destination in Pennsylvania; and immediately after my arrival there I commenced copying the characters off the plates. I copied a considerable number of them, and by means of the Urim and Thummim I translated some of them, which I did between the time I arrived at the house of my wife's father, in the month of December, and the February following.
41970	1581	63	Sometime in this month of February, the aforementioned Mr. Martin Harris came to our place, got the characters which I had drawn off the plates, and started with them to the city of New York. For what took place relative to him and the characters, I refer to his own account of the circumstances, as he related them to me after his return, which was as follows:
41971	1581	64	"I went to the city of New York, and presented the characters which had been translated, with the translation thereof, to Professor Charles Anthon, a gentleman celebrated for his literary attainments. Professor Anthon stated that the translation was correct, more so than any he had before seen translated from the Egyptian. I then showed him those which were not yet translated, and he said that they were Egyptian, Chaldaic, Assyriac, and Arabic; and he said they were true characters. He gave me a certificate, certifying to the people of Palmyra that they were true characters, and that the translation of such of them as had been translated was also correct. I took the certificate and put it into my pocket, and was just leaving the house, when Mr. Anthon called me back, and asked me how the young man found out that there were gold plates in the place where he found them. I answered that an angel of God had revealed it unto him.
41972	1581	65	"He then said to me, 'Let me see that certificate.' I accordingly took it out of my pocket and gave it to him, when he took it and tore it to pieces, saying that there was no such thing now as ministering of angels, and that if I would bring the plates to him he would translate them. I informed him that part of the plates were sealed, and that I was forbidden to bring them. He replied, 'I cannot read a sealed book.' I left him and went to Dr. Mitchell, who sanctioned what Professor Anthon had said respecting both the characters and the translation."
41973	1581	66	On the 5th day of April, 1829, Oliver Cowdery came to my house, until which time I had never seen him. He stated to me that having been teaching school in the neighborhood where my father resided, and my father being one of those who sent to the school, he went to board for a season at his house, and while there the family related to him the circumstances of my having received the plates, and accordingly he had come to make inquiries of me.
41974	1581	67	Two days after the arrival of Mr. Cowdery (being the 7th of April) I commenced to translate the Book of Mormon, and he began to write for me.
41975	1581	68	We still continued the work of translation, when, in the ensuing month (May, 1829), we on a certain day went into the woods to pray and inquire of the Lord respecting baptism for the remission of sins, that we found mentioned in the translation of the plates. While we were thus employed, praying and calling upon the Lord, a messenger from heaven descended in a cloud of light, and having laid his hands upon us, he ordained us, saying:
41976	1581	69	Upon you my fellow servants, in the name of Messiah, I confer the Priesthood of Aaron, which holds the keys of the ministering of angels, and of the gospel of repentance, and of baptism by immersion for the remission of sins; and this shall never be taken again from the earth until the sons of Levi do offer again an offering unto the Lord in righteousness.
41977	1581	70	He said this Aaronic Priesthood had not the power of laying on hands for the gift of the Holy Ghost, but that this should be conferred on us hereafter; and he commanded us to go and be baptized, and gave us directions that I should baptize Oliver Cowdery, and that afterwards he should baptize me.
41978	1581	71	Accordingly we went and were baptized. I baptized him first, and afterwards he baptized me--after which I laid my hands upon his head and ordained him to the Aaronic Priesthood, and afterwards he laid his hands on me and ordained me to the same Priesthood--for so we were commanded.
41979	1581	72	The messenger who visited us on this occasion and conferred this Priesthood upon us, said that his name was John, the same that is called John the Baptist in the New Testament, and that he acted under the direction of Peter, James and John, who held the keys of the Priesthood of Melchizedek, which Priesthood, he said, would in due time be conferred on us, and that I should be called the first Elder of the Church, and he (Oliver Cowdery) the second. It was on the fifteenth day of May, 1829, that we were ordained under the hand of this messenger, and baptized.
41980	1581	73	Immediately on our coming up out of the water after we had been baptized, we experienced great and glorious blessings from our Heavenly Father. No sooner had I baptized Oliver Cowdery, than the Holy Ghost fell upon him, and he stood up and prophesied many things which should shortly come to pass. And again, so soon as I had been baptized by him, I also had the spirit of prophecy, when, standing up, I prophesied concerning the rise of this Church, and many other things connected with the Church, and this generation of the children of men. We were filled with the Holy Ghost, and rejoiced in the God of our salvation.
41981	1581	74	Our minds being now enlightened, we began to have the scriptures laid open to our understandings, and the true meaning and intention of their more mysterious passages revealed unto us in a manner which we never could attain to previously, nor ever before had thought of. In the meantime we were forced to keep secret the circumstances of having received the Priesthood and our having been baptized, owing to a spirit of persecution which had already manifested itself in the neighborhood.
41982	1581	75	We had been threatened with being mobbed, from time to time, and this, too, by professors of religion. And their intentions of mobbing us were only counteracted by the influence of my wife's father's family (under Divine providence), who had become very friendly to me, and who were opposed to mobs, and were willing that I should be allowed to continue the work of translation without interruption; and therefore offered and promised us protection from all unlawful proceedings, as far as in them lay.
41983	1582	1	WE believe in God, the Eternal Father, and in His Son, Jesus Christ, and in the Holy Ghost.
41984	1582	2	We believe that men will be punished for their own sins, and not for Adam's transgression.
41985	1582	3	We believe that through the Atonement of Christ, all mankind may be saved, by obedience to the laws and ordinances of the Gospel.
41986	1582	4	We believe that the first principles and ordinances of the Gospel are: first, Faith in the Lord Jesus Christ; second, Repentance; third, Baptism by immersion for the remission of sins; fourth, Laying on of hands for the gift of the Holy Ghost.
41987	1582	5	We believe that a man must be called of God, by prophecy, and by the laying on of hands by those who are in authority, to preach the Gospel and administer in the ordinances thereof.
41988	1582	6	We believe in the same organization that existed in the Primitive Church, namely, apostles, prophets, pastors, teachers, evangelists, and so forth.
41989	1582	7	We believe in the gift of tongues, prophecy, revelation, visions, healing, interpretation of tongues, and so forth.
41990	1582	8	We believe the Bible to be the word of God as far as it is translated correctly; we also believe the Book of Mormon to be the word of God.
41991	1582	9	We believe all that God has revealed, all that He does now reveal, and we believe that He will yet reveal many great and important things pertaining to the Kingdom of God.
41992	1582	10	We believe in the literal gathering of Israel and in the restoration of the Ten Tribes; that Zion (the New Jerusalem) will be built upon the American continent; that Christ will reign personally upon the earth; and, that the earth will be renewed and receive its paradisiacal glory.
41993	1582	11	We claim the privilege of worshiping Almighty God according to the dictates of our own conscience, and allow all men the same privilege, let them worship how, where, or what they may.
41994	1582	12	We believe in being subject to kings, presidents, rulers, and magistrates, in obeying, honoring, and sustaining the law.
41995	1582	13	We believe in being honest, true, chaste, benevolent, virtuous, and in doing good to all men; indeed, we may say that we follow the admonition of Paul--We believe all things, we hope all things, we have endured many things, and hope to be able to endure all things. If there is anything virtuous, lovely, or of good report or praiseworthy, we seek after these things.
\.


--
-- Data for Name: volumes; Type: TABLE DATA; Schema: public; Owner: -
--

COPY volumes (id, volume_title, volume_long_title, volume_subtitle, volume_short_title, volume_lds_url) FROM stdin;
1	Old Testament	The Old Testament		OT	ot
2	New Testament	The New Testament	Of our Lord and Saviour Jesus Christ	NT	nt
3	Book of Mormon	The Book of Mormon	Another Testament of Jesus Christ	BoM	bm
4	Doctrine and Covenants	The Doctrine and Covenants		D&C	dc
5	Pearl of Great Price	The Pearl of Great Price		PGP	pgp
\.


--
-- Name: pkey_books; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY books
    ADD CONSTRAINT pkey_books PRIMARY KEY (id);

ALTER TABLE books CLUSTER ON pkey_books;


--
-- Name: pkey_chapters; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY chapters
    ADD CONSTRAINT pkey_chapters PRIMARY KEY (id);

ALTER TABLE chapters CLUSTER ON pkey_chapters;


--
-- Name: pkey_verses; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY verses
    ADD CONSTRAINT pkey_verses PRIMARY KEY (id);

ALTER TABLE verses CLUSTER ON pkey_verses;


--
-- Name: pkey_volumes; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY volumes
    ADD CONSTRAINT pkey_volumes PRIMARY KEY (id);

ALTER TABLE volumes CLUSTER ON pkey_volumes;


--
-- Name: idx_pilcrows; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE UNIQUE INDEX idx_pilcrows ON pilcrow USING btree (verse_id);

ALTER TABLE pilcrow CLUSTER ON idx_pilcrows;


--
-- Name: fkey_books_volumes; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY books
    ADD CONSTRAINT fkey_books_volumes FOREIGN KEY (volume_id) REFERENCES volumes(id) ON DELETE CASCADE;


--
-- Name: fkey_chapters_books; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY chapters
    ADD CONSTRAINT fkey_chapters_books FOREIGN KEY (book_id) REFERENCES books(id) ON DELETE CASCADE;


--
-- Name: fkey_verses_chapter; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY verses
    ADD CONSTRAINT fkey_verses_chapter FOREIGN KEY (chapter_id) REFERENCES chapters(id) ON DELETE CASCADE;


--
-- PostgreSQL database dump complete
--

